@@ -86,6 +86,7 @@ static const options_entry cli_options[] =
 	{ "listfull;ll",              "0",        OPTION_COMMAND,    "short name, full name" },
 	{ "listsource;ls",            "0",        OPTION_COMMAND,    "driver sourcefile" },
 	{ "listclones;lc",            "0",        OPTION_COMMAND,    "show clones" },
+	{ "listbrothers;lb",          "0",        OPTION_COMMAND,    "show \"brothers\", or other drivers from same sourcefile" },
 	{ "listcrc",                  "0",        OPTION_COMMAND,    "CRC-32s" },
 	{ "listroms",                 "0",        OPTION_COMMAND,    "list required roms for a driver" },
 	{ "listsamples",              "0",        OPTION_COMMAND,    "list optional samples for a driver" },
@@ -240,6 +241,7 @@ static int execute_commands(core_options *options, const char *exename, const ga
 		{ CLIOPTION_LISTFULL,		cli_info_listfull },
 		{ CLIOPTION_LISTSOURCE,		cli_info_listsource },
 		{ CLIOPTION_LISTCLONES,		cli_info_listclones },
+		{ CLIOPTION_LISTBROTHERS,	cli_info_listbrothers },
 		{ CLIOPTION_LISTCRC,		cli_info_listcrc },
 #ifdef MESS
 		{ CLIOPTION_LISTDEVICES,	info_listdevices },
@@ -337,7 +339,6 @@ int cli_info_listxml(core_options *options, const char *gamename)
 {
 	/* since print_mame_xml expands the machine driver, we need to set things up */
 	init_resource_tracking();
-	cpuintrf_init(NULL);
 	sndintrf_init(NULL);
 
 	print_mame_xml(stdout, drivers, gamename);
@@ -358,7 +359,7 @@ int cli_info_listfull(core_options *options, const char *gamename)
 	int drvindex, count = 0;
 
 	/* iterate over drivers */
-	for (drvindex = 0; drivers[drvindex]; drvindex++)
+	for (drvindex = 0; drivers[drvindex] != NULL; drvindex++)
 		if ((drivers[drvindex]->flags & GAME_NO_STANDALONE) == 0 && mame_strwildcmp(gamename, drivers[drvindex]->name) == 0)
 		{
 			/* print the header on the first one */
@@ -386,7 +387,7 @@ int cli_info_listsource(core_options *options, const char *gamename)
 	int drvindex, count = 0;
 
 	/* iterate over drivers */
-	for (drvindex = 0; drivers[drvindex]; drvindex++)
+	for (drvindex = 0; drivers[drvindex] != NULL; drvindex++)
 		if (mame_strwildcmp(gamename, drivers[drvindex]->name) == 0)
 		{
 			/* output the remaining information */
@@ -410,7 +411,7 @@ int cli_info_listclones(core_options *options, const char *gamename)
 	int drvindex, count = 0;
 
 	/* iterate over drivers */
-	for (drvindex = 0; drivers[drvindex]; drvindex++)
+	for (drvindex = 0; drivers[drvindex] != NULL; drvindex++)
 	{
 		const game_driver *clone_of = driver_get_clone(drivers[drvindex]);
 
@@ -433,6 +434,54 @@ int cli_info_listclones(core_options *options, const char *gamename)
 }
 
 
+/*-------------------------------------------------
+    cli_info_listbrothers - output the name and
+    source filename of one or more games
+-------------------------------------------------*/
+
+int cli_info_listbrothers(core_options *options, const char *gamename)
+{
+	UINT8 *didit = malloc_or_die(driver_list_get_count(drivers));
+	astring *filename = astring_alloc();
+	int drvindex, count = 0;
+
+	memset(didit, 0, driver_list_get_count(drivers));
+
+	/* iterate over drivers */
+	for (drvindex = 0; drivers[drvindex] != NULL; drvindex++)
+		if (!didit[drvindex] && mame_strwildcmp(gamename, drivers[drvindex]->name) == 0)
+		{
+			int matchindex;
+
+			didit[drvindex] = TRUE;
+			if (count > 0)
+				mame_printf_info("\n");
+			mame_printf_info("%s ... other drivers in %s:\n", drivers[drvindex]->name, astring_c(core_filename_extract_base(filename, drivers[drvindex]->source_file, FALSE)));
+
+			/* now iterate again over drivers, finding those with the same source file */
+			for (matchindex = 0; drivers[matchindex]; matchindex++)
+				if (matchindex != drvindex && strcmp(drivers[drvindex]->source_file, drivers[matchindex]->source_file) == 0)
+				{
+					const char *matchstring = (mame_strwildcmp(gamename, drivers[matchindex]->name) == 0) ? "-> " : "   ";
+					const game_driver *clone_of = driver_get_clone(drivers[matchindex]);
+
+					if (clone_of != NULL && (clone_of->flags & GAME_IS_BIOS_ROOT) == 0)
+						mame_printf_info("%s%-8s [%s]\n", matchstring, drivers[matchindex]->name, clone_of->name);
+					else
+						mame_printf_info("%s%s\n", matchstring, drivers[matchindex]->name);
+					didit[matchindex] = TRUE;
+				}
+
+			count++;
+		}
+
+	/* return an error if none found */
+	astring_free(filename);
+	free(didit);
+	return (count > 0) ? MAMERR_NONE : MAMERR_NO_SUCH_GAME;
+}
+
+
 /*-------------------------------------------------
     cli_info_listcrc - output the CRC and name of
     all ROMs referenced by MAME
@@ -443,23 +492,27 @@ int cli_info_listcrc(core_options *options, const char *gamename)
 	int drvindex, count = 0;
 
 	/* iterate over drivers */
-	for (drvindex = 0; drivers[drvindex]; drvindex++)
+	for (drvindex = 0; drivers[drvindex] != NULL; drvindex++)
 		if (mame_strwildcmp(gamename, drivers[drvindex]->name) == 0)
 		{
+			machine_config *config = machine_config_alloc(drivers[drvindex]->machine_config);
 			const rom_entry *region, *rom;
+			const rom_source *source;
 
-			/* iterate over regions, and then ROMs within the region */
-			for (region = rom_first_region(drivers[drvindex]); region; region = rom_next_region(region))
-				for (rom = rom_first_file(region); rom; rom = rom_next_file(rom))
-				{
-					char hashbuf[HASH_BUF_SIZE];
+			/* iterate over sources, regions, and then ROMs within the region */
+			for (source = rom_first_source(drivers[drvindex], config); source != NULL; source = rom_next_source(drivers[drvindex], config, source))
+				for (region = rom_first_region(drivers[drvindex], source); region; region = rom_next_region(region))
+					for (rom = rom_first_file(region); rom; rom = rom_next_file(rom))
+					{
+						char hashbuf[HASH_BUF_SIZE];
 
-					/* if we have a CRC, display it */
-					if (hash_data_extract_printable_checksum(ROM_GETHASHDATA(rom), HASH_CRC, hashbuf))
-						mame_printf_info("%s %-12s %s\n", hashbuf, ROM_GETNAME(rom), drivers[drvindex]->description);
-				}
+						/* if we have a CRC, display it */
+						if (hash_data_extract_printable_checksum(ROM_GETHASHDATA(rom), HASH_CRC, hashbuf))
+							mame_printf_info("%s %-12s %s\n", hashbuf, ROM_GETNAME(rom), drivers[drvindex]->description);
+					}
 
 			count++;
+			machine_config_free(config);
 		}
 
 	/* return an error if none found */
@@ -477,10 +530,12 @@ int cli_info_listroms(core_options *options, const char *gamename)
 	int drvindex, count = 0;
 
 	/* iterate over drivers */
-	for (drvindex = 0; drivers[drvindex]; drvindex++)
+	for (drvindex = 0; drivers[drvindex] != NULL; drvindex++)
 		if (mame_strwildcmp(gamename, drivers[drvindex]->name) == 0)
 		{
-			const rom_entry *region, *rom, *chunk;
+			machine_config *config = machine_config_alloc(drivers[drvindex]->machine_config);
+			const rom_entry *region, *rom;
+			const rom_source *source;
 
 			/* print the header */
 			if (count > 0)
@@ -488,49 +543,47 @@ int cli_info_listroms(core_options *options, const char *gamename)
 			mame_printf_info("This is the list of the ROMs required for driver \"%s\".\n"
 					"Name            Size Checksum\n", drivers[drvindex]->name);
 
-			/* iterate over regions and then ROMs within the region */
-			for (region = drivers[drvindex]->rom; region; region = rom_next_region(region))
-				for (rom = rom_first_file(region); rom; rom = rom_next_file(rom))
-				{
-					const char *name = ROM_GETNAME(rom);
-					const char* hash = ROM_GETHASHDATA(rom);
-					char hashbuf[HASH_BUF_SIZE];
-					int length = -1;
-
-					/* accumulate the total length of all chunks */
-					if (ROMREGION_ISROMDATA(region))
+			/* iterate over sources, regions and then ROMs within the region */
+			for (source = rom_first_source(drivers[drvindex], config); source != NULL; source = rom_next_source(drivers[drvindex], config, source))
+				for (region = rom_first_region(drivers[drvindex], source); region != NULL; region = rom_next_region(region))
+					for (rom = rom_first_file(region); rom != NULL; rom = rom_next_file(rom))
 					{
-						length = 0;
-						for (chunk = rom_first_chunk(rom); chunk; chunk = rom_next_chunk(chunk))
-							length += ROM_GETLENGTH(chunk);
+						const char *name = ROM_GETNAME(rom);
+						const char *hash = ROM_GETHASHDATA(rom);
+						char hashbuf[HASH_BUF_SIZE];
+						int length = -1;
+
+						/* accumulate the total length of all chunks */
+						if (ROMREGION_ISROMDATA(region))
+							length = rom_file_size(rom);
+
+						/* start with the name */
+						mame_printf_info("%-12s ", name);
+
+						/* output the length next */
+						if (length >= 0)
+							mame_printf_info("%7d", length);
+						else
+							mame_printf_info("       ");
+
+						/* output the hash data */
+						if (!hash_data_has_info(hash, HASH_INFO_NO_DUMP))
+						{
+							if (hash_data_has_info(hash, HASH_INFO_BAD_DUMP))
+								mame_printf_info(" BAD");
+
+							hash_data_print(hash, 0, hashbuf);
+							mame_printf_info(" %s", hashbuf);
+						}
+						else
+							mame_printf_info(" NO GOOD DUMP KNOWN");
+
+						/* end with a CR */
+						mame_printf_info("\n");
 					}
 
-					/* start with the name */
-					mame_printf_info("%-12s ", name);
-
-					/* output the length next */
-					if (length >= 0)
-						mame_printf_info("%7d", length);
-					else
-						mame_printf_info("       ");
-
-					/* output the hash data */
-					if (!hash_data_has_info(hash, HASH_INFO_NO_DUMP))
-					{
-						if (hash_data_has_info(hash, HASH_INFO_BAD_DUMP))
-							mame_printf_info(" BAD");
-
-						hash_data_print(hash, 0, hashbuf);
-						mame_printf_info(" %s", hashbuf);
-					}
-					else
-						mame_printf_info(" NO GOOD DUMP KNOWN");
-
-					/* end with a CR */
-					mame_printf_info("\n");
-				}
-
 			count++;
+			machine_config_free(config);
 		}
 
 	return (count > 0) ? MAMERR_NONE : MAMERR_NO_SUCH_GAME;
@@ -551,24 +604,20 @@ int cli_info_listsamples(core_options *options, const char *gamename)
 
 	/* since we expand the machine driver, we need to set things up */
 	init_resource_tracking();
-	cpuintrf_init(NULL);
 	sndintrf_init(NULL);
 
 	/* iterate over drivers */
-	for (drvindex = 0; drivers[drvindex]; drvindex++)
+	for (drvindex = 0; drivers[drvindex] != NULL; drvindex++)
 		if (mame_strwildcmp(gamename, drivers[drvindex]->name) == 0)
 		{
-			machine_config drv;
+			machine_config *config = machine_config_alloc(drivers[drvindex]->machine_config);
 			int sndnum;
 
-			/* expand the machine driver */
-			expand_machine_driver(drivers[drvindex]->drv, &drv);
-
 			/* find samples interfaces */
-			for (sndnum = 0; sndnum < MAX_SOUND && drv.sound[sndnum].type != SOUND_DUMMY; sndnum++)
-				if (drv.sound[sndnum].type == SOUND_SAMPLES)
+			for (sndnum = 0; sndnum < MAX_SOUND && config->sound[sndnum].type != SOUND_DUMMY; sndnum++)
+				if (config->sound[sndnum].type == SOUND_SAMPLES)
 				{
-					const char *const *samplenames = ((const struct Samplesinterface *)drv.sound[sndnum].config)->samplenames;
+					const char *const *samplenames = ((const samples_interface *)config->sound[sndnum].config)->samplenames;
 					int sampnum;
 
 					/* if the list is legit, walk it and print the sample info */
@@ -578,6 +627,7 @@ int cli_info_listsamples(core_options *options, const char *gamename)
 				}
 
 			count++;
+			machine_config_free(config);
 		}
 
 	/* clean up our tracked resources */
@@ -603,7 +653,7 @@ static int info_verifyroms(core_options *options, const char *gamename)
 	int drvindex;
 
 	/* iterate over drivers */
-	for (drvindex = 0; drivers[drvindex]; drvindex++)
+	for (drvindex = 0; drivers[drvindex] != NULL; drvindex++)
 		if (mame_strwildcmp(gamename, drivers[drvindex]->name) == 0)
 		{
 			audit_record *audit;
@@ -683,11 +733,11 @@ static int info_verifysamples(core_options *options, const char *gamename)
 {
 	int correct = 0;
 	int incorrect = 0;
-	int notfound = 0;
+	int notfound = FALSE;
 	int drvindex;
 
 	/* now iterate over drivers */
-	for (drvindex = 0; drivers[drvindex]; drvindex++)
+	for (drvindex = 0; drivers[drvindex] != NULL; drvindex++)
 		if (mame_strwildcmp(gamename, drivers[drvindex]->name) == 0)
 		{
 			audit_record *audit;
@@ -702,9 +752,12 @@ static int info_verifysamples(core_options *options, const char *gamename)
 			else
 				continue;
 
-			/* if not found, count that and leave it at that */
+			/* if not found, print a message and set the flag */
 			if (res == NOTFOUND)
-				notfound++;
+			{
+				mame_printf_error("sampleset \"%s\" not found!\n", drivers[drvindex]->name);
+				notfound = TRUE;
+			}
 
 			/* else display information about what we discovered */
 			else
@@ -732,12 +785,13 @@ static int info_verifysamples(core_options *options, const char *gamename)
 			}
 		}
 
-	/* if we didn't get anything at all, display a generic end message */
+	/* clear out any cached files */
+	zip_file_cache_clear();
+
+	/* if we didn't get anything at all because of an unsupported set, display message */
 	if (correct + incorrect == 0)
 	{
-		if (notfound > 0)
-			mame_printf_error("sampleset \"%s\" not found!\n", gamename);
-		else
+		if (!notfound)
 			mame_printf_error("sampleset \"%s\" not supported!\n", gamename);
 		return MAMERR_NO_SUCH_GAME;
 	}
@@ -958,22 +1012,27 @@ static void match_roms(const char *hash, int length, int *found)
 	int drvindex;
 
 	/* iterate over drivers */
-	for (drvindex = 0; drivers[drvindex]; drvindex++)
+	for (drvindex = 0; drivers[drvindex] != NULL; drvindex++)
 	{
+		machine_config *config = machine_config_alloc(drivers[drvindex]->machine_config);
 		const rom_entry *region, *rom;
+		const rom_source *source;
 
-		/* iterate over regions and files within the region */
-		for (region = rom_first_region(drivers[drvindex]); region; region = rom_next_region(region))
-			for (rom = rom_first_file(region); rom; rom = rom_next_file(rom))
-				if (hash_data_is_equal(hash, ROM_GETHASHDATA(rom), 0))
-				{
-					int baddump = hash_data_has_info(ROM_GETHASHDATA(rom), HASH_INFO_BAD_DUMP);
+		/* iterate over sources, regions and files within the region */
+		for (source = rom_first_source(drivers[drvindex], config); source != NULL; source = rom_next_source(drivers[drvindex], config, source))
+			for (region = rom_first_region(drivers[drvindex], source); region; region = rom_next_region(region))
+				for (rom = rom_first_file(region); rom; rom = rom_next_file(rom))
+					if (hash_data_is_equal(hash, ROM_GETHASHDATA(rom), 0))
+					{
+						int baddump = hash_data_has_info(ROM_GETHASHDATA(rom), HASH_INFO_BAD_DUMP);
 
-					/* output information about the match */
-					if (*found != 0)
-						mame_printf_info("                    ");
-					mame_printf_info("= %s%-20s  %s\n", baddump ? "(BAD) " : "", ROM_GETNAME(rom), drivers[drvindex]->description);
-					(*found)++;
-				}
+						/* output information about the match */
+						if (*found != 0)
+							mame_printf_info("                    ");
+						mame_printf_info("= %s%-20s  %s\n", baddump ? "(BAD) " : "", ROM_GETNAME(rom), drivers[drvindex]->description);
+						(*found)++;
+					}
+
+		machine_config_free(config);
 	}
 }
