@@ -1,5 +1,7 @@
-#ifndef ARM_H
-#define ARM_H
+#pragma once
+
+#ifndef __ARM_H__
+#define __ARM_H__
 
 #include "cpuintrf.h"
 
@@ -14,11 +16,10 @@
  *  PUBLIC FUNCTIONS
  ***************************************************************************************************/
 
-extern void arm_get_info(UINT32 state, cpuinfo *info);
+extern CPU_GET_INFO( arm );
+#define CPU_ARM CPU_GET_INFO_NAME( arm )
 
-#ifdef ENABLE_DEBUGGER
-extern UINT32 arm_disasm( char *pBuf, UINT32 pc, UINT32 opcode );
-#endif
+extern UINT32 arm_disasm(char *pBuf, UINT32 pc, UINT32 opcode);
 
 enum
 {
@@ -29,4 +30,4 @@ enum
 	ARM32_IR13, ARM32_IR14, ARM32_SR13, ARM32_SR14
 };
 
-#endif /* ARM_H */
+#endif /* __ARM_H__ */
