@@ -13,68 +13,25 @@
 
     TODO:
 
-    - serial I/O
+    - COP413/COP414/COP415/COP405
+    - get rid of LBIOps/InstLen
+    - run interrupt test suite
+    - run production test suite
+    - run microbus test suite
 
 */
 
+#include "driver.h"
 #include "cpuintrf.h"
 #include "debugger.h"
-#include "deprecat.h"
 #include "cop400.h"
 
-/* The opcode table now is a combination of cycle counts and function pointers */
-typedef struct {
-	unsigned cycles;
-	void (*function) (void);
-}	s_opcode;
-
-#define UINT1	UINT8
-#define UINT4	UINT8
-#define UINT6	UINT8
-#define UINT9	UINT16
-
-typedef struct
-{
-	UINT9 	PC;
-	UINT9	PREVPC;
-	UINT4	A;
-	UINT6	B;
-	UINT1	C;
-	UINT4	EN;
-	UINT4	G;
-	UINT8	Q;
-	UINT9	SA, SB;
-	UINT4	SIO;
-	UINT1	SKL;
-	UINT8   skip, skipLBI;
-	UINT8	G_mask;
-	UINT8	D_mask;
-} COP410_Regs;
-
-static COP410_Regs R;
-static int    cop410_ICount;
-
-static int InstLen[256];
-static int LBIops[256];
-
 #include "410ops.c"
 
-static const s_opcode cop410_opcode_op33[256]=
+/* Opcode Maps */
+
+static const s_opcode COP410_OPCODE_23_MAP[]=
 {
-	{1, illegal 	},{1, skgbz0	},{1, illegal   },{1, skgbz2	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
-	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
-	{1, illegal 	},{1, skgbz1 	},{1, illegal 	},{1, skgbz3 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
-	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
-	{1, illegal 	},{1, skgz 		},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
-	{1, illegal 	},{1, illegal 	},{1, ing	 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, inl	 	},{1, illegal 	},
-	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
-	{1, illegal 	},{1, illegal 	},{1, omg	 	},{1, illegal 	},{1, camq	 	},{1, illegal 	},{1, obd	 	},{1, illegal 	},
-	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
-	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
-	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
-	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
-	{1, lei0 		},{1, lei1 		},{1, lei2 		},{1, lei3 		},{1, lei4 		},{1, lei5 		},{1, lei6 		},{1, lei7 		},
-	{1, lei8 		},{1, lei9 		},{1, lei10 	},{1, lei11 	},{1, lei12 	},{1, lei13 	},{1, lei14 	},{1, lei15 	},
 	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
 	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
 	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
@@ -83,8 +40,25 @@ static const s_opcode cop410_opcode_op33[256]=
 	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
 	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
 	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+
 	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
 	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, xad	 	},
+
 	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
 	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
 	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
@@ -95,188 +69,309 @@ static const s_opcode cop410_opcode_op33[256]=
 	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	}
 };
 
-static void cop410_op33(void)
+static void cop410_op23(cop400_state *cop400, UINT8 opcode)
 {
-	(*(cop410_opcode_op33[ROM(PC++)].function))();
+	UINT8 opcode23 = ROM(PC++);
+
+	(*(COP410_OPCODE_23_MAP[opcode23].function))(cop400, opcode23);
 }
 
-static const s_opcode cop410_opcode_main[256]=
+static const s_opcode COP410_OPCODE_33_MAP[]=
 {
-	{1, clra		},{1, skmbz0	},{1, xor		},{1, skmbz2		},{1, xis0		},{1, ld0		},{1, x0		},{1, xds0		},
-	{1, lbi0_9		},{1, lbi0_10	},{1, lbi0_11	},{1, lbi0_12		},{1, lbi0_13	},{1, lbi0_14	},{1, lbi0_15	},{1, lbi0_0	},
-	{0, illegal		},{1, skmbz1	},{0, illegal	},{1, skmbz3		},{1, xis0		},{1, ld1		},{1, x1		},{1, xds1		},
-	{1, lbi1_9		},{1, lbi1_10	},{1, lbi1_11	},{1, lbi1_12		},{1, lbi1_13	},{1, lbi1_14	},{1, lbi1_15	},{1, lbi1_0	},
-	{1, skc			},{1, ske		},{1, sc		},{2, xad			},{1, xis2		},{1, ld2		},{1, x2		},{1, xds2 		},
-	{1,	lbi2_9		},{1, lbi2_10	},{1, lbi2_11	},{1, lbi2_12		},{1, lbi2_13	},{1, lbi2_14	},{1, lbi2_15	},{1, lbi2_0	},
-	{1, asc			},{1, add		},{1, rc		},{2, cop410_op33	},{1, xis3		},{1, ld3		},{1, x3		},{1, xds3		},
-	{1,	lbi3_9		},{1, lbi3_10	},{1, lbi3_11	},{1, lbi3_12		},{1, lbi3_13	},{1, lbi3_14	},{1, lbi3_15	},{1, lbi3_0	},
-	{1, comp		},{0, illegal	},{1, rmb2		},{1, rmb2			},{1, nop		},{1, rmb1		},{1, smb2		},{1, smb1		},
-	{1,	ret			},{1, retsk		},{0, illegal	},{1, smb3			},{1, rmb0		},{1, smb0		},{1, cba		},{1, xas		},
-	{1, cab			},{1, aisc1		},{1, aisc2		},{1, aisc3			},{1, aisc4		},{1, aisc5		},{1, aisc6		},{1, aisc7		},
-	{1, aisc8		},{1, aisc9		},{1, aisc10	},{1, aisc11		},{1, aisc12	},{1, aisc13	},{1, aisc14	},{1, aisc15	},
-	{2, jmp0		},{2, jmp1		},{0, illegal	},{0, illegal		},{0, illegal	},{0, illegal	},{0, illegal	},{0, illegal   },
-	{2, jsr0		},{2, jsr1		},{0, illegal	},{0, illegal		},{0, illegal	},{0, illegal	},{0, illegal	},{0, illegal	},
-	{1, stii0		},{1, stii1		},{1, stii2		},{1, stii3			},{1, stii4		},{1, stii5		},{1, stii6		},{1, stii7		},
-	{1, stii8		},{1, stii9		},{1, stii10	},{1, stii11		},{1, stii12	},{1, stii13	},{1, stii14	},{1, stii15	},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, lqid		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
-	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jid		}
+	{1, illegal 	},{1, skgbz0	},{1, illegal   },{1, skgbz2	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, skgbz1 	},{1, illegal 	},{1, skgbz3 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, skgz 		},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, ing	 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, inl	 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, halt	 	},{1, illegal 	},{1, omg	 	},{1, illegal 	},{1, camq	 	},{1, illegal 	},{1, obd	 	},{1, illegal 	},
+
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, lei 		},{1, lei 		},{1, lei 		},{1, lei 		},{1, lei 		},{1, lei 		},{1, lei 		},{1, lei 		},
+	{1, lei 		},{1, lei 		},{1, lei	 	},{1, lei	 	},{1, lei	 	},{1, lei	 	},{1, lei	 	},{1, lei	 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},
+	{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	},{1, illegal 	}
 };
 
-static ADDRESS_MAP_START( cop410_RAM, ADDRESS_SPACE_DATA, 8 )
-	AM_RANGE(0x00, 0x40) AM_RAM
+static void cop410_op33(cop400_state *cop400, UINT8 opcode)
+{
+	UINT8 opcode33 = ROM(PC++);
+
+	(*(COP410_OPCODE_33_MAP[opcode33].function))(cop400, opcode33);
+}
+
+static const s_opcode COP410_OPCODE_MAP[]=
+{
+	{1, clra		},{1, skmbz0	},{1, xor		},{1, skmbz2		},{1, xis		},{1, ld		},{1, x			},{1, xds		},
+	{1, lbi			},{1, lbi		},{1, lbi		},{1, lbi			},{1, lbi		},{1, lbi		},{1, lbi		},{1, lbi		},
+	{0, illegal		},{1, skmbz1	},{0, illegal	},{1, skmbz3		},{1, xis		},{1, ld		},{1, x			},{1, xds		},
+	{1, lbi			},{1, lbi		},{1, lbi		},{1, lbi			},{1, lbi		},{1, lbi		},{1, lbi		},{1, lbi		},
+	{1, skc			},{1, ske		},{1, sc		},{1, cop410_op23	},{1, xis		},{1, ld		},{1, x			},{1, xds 		},
+	{1, lbi			},{1, lbi		},{1, lbi		},{1, lbi			},{1, lbi		},{1, lbi		},{1, lbi		},{1, lbi		},
+	{1, asc			},{1, add		},{1, rc		},{1, cop410_op33	},{1, xis		},{1, ld		},{1, x			},{1, xds		},
+	{1, lbi			},{1, lbi		},{1, lbi		},{1, lbi			},{1, lbi		},{1, lbi		},{1, lbi		},{1, lbi		},
+
+	{1, comp		},{0, illegal	},{1, rmb2		},{1, rmb3			},{1, nop		},{1, rmb1		},{1, smb2		},{1, smb1		},
+	{1,	ret			},{1, retsk		},{0, illegal	},{1, smb3			},{1, rmb0		},{1, smb0		},{1, cba		},{1, xas		},
+	{1, cab			},{1, aisc		},{1, aisc		},{1, aisc			},{1, aisc		},{1, aisc		},{1, aisc		},{1, aisc		},
+	{1, aisc		},{1, aisc		},{1, aisc		},{1, aisc			},{1, aisc		},{1, aisc		},{1, aisc		},{1, aisc		},
+	{2, jmp			},{2, jmp		},{0, illegal	},{0, illegal		},{0, illegal	},{0, illegal	},{0, illegal	},{0, illegal   },
+	{2, jsr			},{2, jsr		},{0, illegal	},{0, illegal		},{0, illegal	},{0, illegal	},{0, illegal	},{0, illegal	},
+	{1, stii		},{1, stii		},{1, stii		},{1, stii			},{1, stii		},{1, stii		},{1, stii		},{1, stii		},
+	{1, stii		},{1, stii		},{1, stii		},{1, stii			},{1, stii		},{1, stii		},{1, stii		},{1, stii		},
+
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{2, lqid		},
+
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{1, jp		},
+	{1, jp			},{1, jp		},{1, jp		},{1, jp			},{1, jp		},{1, jp		},{1, jp		},{2, jid		}
+};
+
+/* Memory Maps */
+
+static ADDRESS_MAP_START( cop410_internal_rom, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x000, 0x1ff) AM_ROM
+ADDRESS_MAP_END
+
+static ADDRESS_MAP_START( cop410_internal_ram, ADDRESS_SPACE_DATA, 8 )
+	AM_RANGE(0x00, 0x3f) AM_RAM
 ADDRESS_MAP_END
 
 /****************************************************************************
  * Initialize emulation
  ****************************************************************************/
-static void cop410_init(int index, int clock, const void *config, int (*irqcallback)(int))
+static CPU_INIT( cop410 )
 {
+	cop400_state *cop400 = device->token;
 	int i;
 
-	memset(&R, 0, sizeof(R));
-	R.G_mask = 0x0F;
-	R.D_mask = 0x0F;
+	cop400->device = device;
+	cop400->intf = (cop400_interface *) device->static_config;
 
-	for (i=0; i<256; i++) InstLen[i]=1;
+	/* get address spaces */
 
-	InstLen[0x60] = InstLen[0x61] = InstLen[0x68] = InstLen[0x69] = InstLen[0x33] = InstLen[0x23] = 2;
+	cop400->program = memory_find_address_space(device, ADDRESS_SPACE_PROGRAM);
+	cop400->data = memory_find_address_space(device, ADDRESS_SPACE_DATA);
+	cop400->io = memory_find_address_space(device, ADDRESS_SPACE_IO);
 
-	for (i=0; i<256; i++) LBIops[i] = 0;
-	for (i=0x08; i<0x10; i++) LBIops[i] = 1;
-	for (i=0x18; i<0x20; i++) LBIops[i] = 1;
-	for (i=0x28; i<0x30; i++) LBIops[i] = 1;
-	for (i=0x38; i<0x40; i++) LBIops[i] = 1;
+	/* set output pin masks */
 
-	state_save_register_item("cop410", index, PC);
-	state_save_register_item("cop410", index, R.PREVPC);
-	state_save_register_item("cop410", index, A);
-	state_save_register_item("cop410", index, B);
-	state_save_register_item("cop410", index, C);
-	state_save_register_item("cop410", index, EN);
-	state_save_register_item("cop410", index, G);
-	state_save_register_item("cop410", index, Q);
-	state_save_register_item("cop410", index, SA);
-	state_save_register_item("cop410", index, SB);
-	state_save_register_item("cop410", index, SIO);
-	state_save_register_item("cop410", index, SKL);
-	state_save_register_item("cop410", index, skip);
-	state_save_register_item("cop410", index, skipLBI);
-	state_save_register_item("cop410", index, R.G_mask);
-	state_save_register_item("cop410", index, R.D_mask);
+	cop400->g_mask = 0x0f;
+	cop400->d_mask = 0x0f;
+
+	/* set clock divider */
+
+	device_set_info_int(device, CPUINFO_INT_CLOCK_DIVIDER, cop400->intf->cki);
+
+	/* allocate serial timer */
+
+	cop400->serial_timer = timer_alloc(device->machine, cop400_serial_tick, cop400);
+	timer_adjust_periodic(cop400->serial_timer, attotime_zero, 0, ATTOTIME_IN_HZ(device->clock / 16));
+
+	/* initialize instruction length array */
+
+	for (i=0; i<256; i++) cop400->InstLen[i]=1;
+
+	cop400->InstLen[0x60] = cop400->InstLen[0x61] = cop400->InstLen[0x68] = cop400->InstLen[0x69] = cop400->InstLen[0x33] = cop400->InstLen[0x23] = 2;
+
+	/* initialize LBI opcode array */
+
+	for (i=0; i<256; i++) cop400->LBIops[i] = 0;
+	for (i=0x08; i<0x10; i++) cop400->LBIops[i] = 1;
+	for (i=0x18; i<0x20; i++) cop400->LBIops[i] = 1;
+	for (i=0x28; i<0x30; i++) cop400->LBIops[i] = 1;
+	for (i=0x38; i<0x40; i++) cop400->LBIops[i] = 1;
+
+	/* register for state saving */
+
+	state_save_register_device_item(device, 0, cop400->pc);
+	state_save_register_device_item(device, 0, cop400->prevpc);
+	state_save_register_device_item(device, 0, cop400->a);
+	state_save_register_device_item(device, 0, cop400->b);
+	state_save_register_device_item(device, 0, cop400->c);
+	state_save_register_device_item(device, 0, cop400->en);
+	state_save_register_device_item(device, 0, cop400->g);
+	state_save_register_device_item(device, 0, cop400->q);
+	state_save_register_device_item(device, 0, cop400->sa);
+	state_save_register_device_item(device, 0, cop400->sb);
+	state_save_register_device_item(device, 0, cop400->sio);
+	state_save_register_device_item(device, 0, cop400->skl);
+	state_save_register_device_item(device, 0, cop400->skip);
+	state_save_register_device_item(device, 0, cop400->skip_lbi);
+	state_save_register_device_item(device, 0, cop400->g_mask);
+	state_save_register_device_item(device, 0, cop400->d_mask);
+	state_save_register_device_item(device, 0, cop400->si);
+	state_save_register_device_item(device, 0, cop400->microbus_int);
+	state_save_register_device_item(device, 0, cop400->halt);
 }
 
-static void cop411_init(int index, int clock, const void *config, int (*irqcallback)(int))
+static CPU_INIT( cop411 )
 {
-	cop410_init(index, clock, config, irqcallback);
+	cop400_state *cop400 = device->token;
+
+	CPU_INIT_CALL(cop410);
 
 	/* the COP411 is like the COP410, just with less output ports */
-	R.G_mask = 0x07;
-	R.D_mask = 0x03;
+	cop400->g_mask = 0x07;
+	cop400->d_mask = 0x03;
 }
 
 /****************************************************************************
  * Reset registers to their initial values
  ****************************************************************************/
-static void cop410_reset(void)
+static CPU_RESET( cop410 )
 {
+	cop400_state *cop400 = device->token;
+
 	PC = 0;
 	A = 0;
 	B = 0;
 	C = 0;
 	OUT_D(0);
 	EN = 0;
-	WRITE_G(0);
+	WRITE_G(cop400, 0);
+	SKL = 1;
+
+	cop400->halt = 0;
 }
 
 /****************************************************************************
  * Execute cycles CPU cycles. Return number of cycles really executed
  ****************************************************************************/
-static int cop410_execute(int cycles)
+static CPU_EXECUTE( cop410 )
 {
-	unsigned opcode;
+	cop400_state *cop400 = device->token;
 
-	cop410_ICount = cycles;
+	UINT8 opcode;
+
+	cop400->icount = cycles;
 
 	do
 	{
 		prevPC = PC;
 
-		CALL_DEBUGGER(PC);
+		debugger_instruction_hook(device, PC);
+
+		if (cop400->intf->cko == COP400_CKO_HALT_IO_PORT)
+		{
+			cop400->halt = IN_CKO();
+		}
+
+		if (cop400->halt)
+		{
+			cop400->icount -= 1;
+			continue;
+		}
 
 		opcode = ROM(PC);
 
-		if (skipLBI == 1)
+		if (cop400->skip_lbi)
 		{
-			if (LBIops[opcode] == 0)
+			if (cop400->LBIops[opcode])
 			{
-				skipLBI = 0;
-			}
-			else {
-				cop410_ICount -=cop410_opcode_main[opcode].cycles;
+				cop400->icount -= COP410_OPCODE_MAP[opcode].cycles;
 
-				PC += InstLen[opcode];
+				PC += cop400->InstLen[opcode];
+			}
+			else
+			{
+				cop400->skip_lbi = 0;
 			}
 		}
 
-		if (skipLBI == 0)
+		if (!cop400->skip_lbi)
 		{
-			int inst_cycles = cop410_opcode_main[opcode].cycles;
+			int inst_cycles = COP410_OPCODE_MAP[opcode].cycles;
 			PC++;
-			(*(cop410_opcode_main[opcode].function))();
-			cop410_ICount -= inst_cycles;
+			(*(COP410_OPCODE_MAP[opcode].function))(cop400, opcode);
+			cop400->icount -= inst_cycles;
 
-			if (skip == 1) {
-				opcode=ROM(PC);
-				cop410_ICount -=cop410_opcode_main[opcode].cycles;
-				PC += InstLen[opcode];
-				skip = 0;
+			// skip next instruction?
+
+			if (cop400->skip)
+			{
+				void *function = COP410_OPCODE_MAP[ROM(PC)].function;
+
+				opcode = ROM(PC);
+
+				if ((function == lqid) || (function == jid))
+				{
+					cop400->icount -= 1;
+				}
+				else
+				{
+					cop400->icount -= COP410_OPCODE_MAP[opcode].cycles;
+				}
+
+				PC += cop400->InstLen[opcode];
+
+				cop400->skip = 0;
 			}
 		}
-	} while (cop410_ICount>0);
+	} while (cop400->icount > 0);
 
-
-	return cycles - cop410_ICount;
+	return cycles - cop400->icount;
 }
 
-/****************************************************************************
- * Get all registers in given buffer
- ****************************************************************************/
-static void cop410_get_context (void *dst)
+/**************************************************************************
+ * Validity check
+ **************************************************************************/
+static CPU_VALIDITY_CHECK( cop410 )
 {
-	if( dst )
-		*(COP410_Regs*)dst = R;
-}
+	int error = FALSE;
+	const cop400_interface *intf = (const cop400_interface *) config;
 
+	if ((intf == NULL) || (intf->cki <= 0))
+	{
+		mame_printf_error("%s: %s has an invalid CPU configuration\n", driver->source_file, driver->name);
+		error = TRUE;
+	}
 
-/****************************************************************************
- * Set all registers to given values
- ****************************************************************************/
-static void cop410_set_context (void *src)
-{
-	if( src )
-		R = *(COP410_Regs*)src;
+	return error;
 }
 
 /**************************************************************************
  * Generic set_info
  **************************************************************************/
 
-static void cop410_set_info(UINT32 state, cpuinfo *info)
+static CPU_SET_INFO( cop410 )
 {
+	cop400_state *cop400 = device->token;
+
 	switch (state)
 	{
 		/* --- the following bits of info are set as 64-bit signed integers --- */
@@ -300,31 +395,33 @@ static void cop410_set_info(UINT32 state, cpuinfo *info)
  * Generic get_info
  **************************************************************************/
 
-void cop410_get_info(UINT32 state, cpuinfo *info)
+CPU_GET_INFO( cop410 )
 {
+	cop400_state *cop400 = (device != NULL) ? device->token : NULL;
+
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
-		case CPUINFO_INT_CONTEXT_SIZE:					info->i = sizeof(R);					break;
+		case CPUINFO_INT_CONTEXT_SIZE:					info->i = sizeof(cop400_state);			break;
 		case CPUINFO_INT_INPUT_LINES:					info->i = 0;							break;
 		case CPUINFO_INT_DEFAULT_IRQ_VECTOR:			info->i = 0;							break;
-		case CPUINFO_INT_ENDIANNESS:					info->i = CPU_IS_LE;					break;
+		case CPUINFO_INT_ENDIANNESS:					info->i = ENDIANNESS_LITTLE;					break;
 		case CPUINFO_INT_CLOCK_MULTIPLIER:				info->i = 1;							break;
-		case CPUINFO_INT_CLOCK_DIVIDER:					info->i = 4;							break;
+		case CPUINFO_INT_CLOCK_DIVIDER:					info->i = 16;							break;
 		case CPUINFO_INT_MIN_INSTRUCTION_BYTES:			info->i = 1;							break;
 		case CPUINFO_INT_MAX_INSTRUCTION_BYTES:			info->i = 2;							break;
 		case CPUINFO_INT_MIN_CYCLES:					info->i = 1;							break;
 		case CPUINFO_INT_MAX_CYCLES:					info->i = 2;							break;
 
-		case CPUINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_PROGRAM:	info->i = 8;					break;
-		case CPUINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_PROGRAM: info->i = 9;					break;
-		case CPUINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_PROGRAM: info->i = 0;					break;
-		case CPUINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_DATA:	info->i = 8;					break;
-		case CPUINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_DATA: 	info->i = 8;	/* Really 6 */	break;
-		case CPUINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_DATA: 	info->i = 0;					break;
-		case CPUINFO_INT_DATABUS_WIDTH + ADDRESS_SPACE_IO:		info->i = 8;					break;
-		case CPUINFO_INT_ADDRBUS_WIDTH + ADDRESS_SPACE_IO: 		info->i = 9;					break;
-		case CPUINFO_INT_ADDRBUS_SHIFT + ADDRESS_SPACE_IO: 		info->i = 0;					break;
+		case CPUINFO_INT_DATABUS_WIDTH_PROGRAM:	info->i = 8;					break;
+		case CPUINFO_INT_ADDRBUS_WIDTH_PROGRAM: info->i = 9;					break;
+		case CPUINFO_INT_ADDRBUS_SHIFT_PROGRAM: info->i = 0;					break;
+		case CPUINFO_INT_DATABUS_WIDTH_DATA:	info->i = 8;					break;
+		case CPUINFO_INT_ADDRBUS_WIDTH_DATA: 	info->i = 6;					break;
+		case CPUINFO_INT_ADDRBUS_SHIFT_DATA: 	info->i = 0;					break;
+		case CPUINFO_INT_DATABUS_WIDTH_IO:		info->i = 8;					break;
+		case CPUINFO_INT_ADDRBUS_WIDTH_IO: 		info->i = 9;					break;
+		case CPUINFO_INT_ADDRBUS_SHIFT_IO: 		info->i = 0;					break;
 
 		case CPUINFO_INT_INPUT_STATE + 0:				info->i = 0;						    break;
 
@@ -344,23 +441,23 @@ void cop410_get_info(UINT32 state, cpuinfo *info)
 		case CPUINFO_INT_REGISTER + COP400_SKL:			info->i = SKL;							break;
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case CPUINFO_PTR_SET_INFO:						info->setinfo = cop410_set_info;		break;
-		case CPUINFO_PTR_GET_CONTEXT:					info->getcontext = cop410_get_context;	break;
-		case CPUINFO_PTR_SET_CONTEXT:					info->setcontext = cop410_set_context;	break;
-		case CPUINFO_PTR_INIT:							info->init = cop410_init;				break;
-		case CPUINFO_PTR_RESET:							info->reset = cop410_reset;				break;
-		case CPUINFO_PTR_EXECUTE:						info->execute = cop410_execute;			break;
-		case CPUINFO_PTR_BURN:							info->burn = NULL;						break;
-#ifdef ENABLE_DEBUGGER
-		case CPUINFO_PTR_DISASSEMBLE:					info->disassemble = cop410_dasm;		break;
-#endif /* ENABLE_DEBUGGER */
-		case CPUINFO_PTR_INSTRUCTION_COUNTER:			info->icount = &cop410_ICount;			break;
- 		case CPUINFO_PTR_INTERNAL_MEMORY_MAP + ADDRESS_SPACE_DATA:
- 			info->internal_map = construct_map_cop410_RAM;										break;
+		case CPUINFO_FCT_SET_INFO:						info->setinfo = CPU_SET_INFO_NAME(cop410);		break;
+		case CPUINFO_FCT_INIT:							info->init = CPU_INIT_NAME(cop410);				break;
+		case CPUINFO_FCT_RESET:							info->reset = CPU_RESET_NAME(cop410);				break;
+		case CPUINFO_FCT_EXECUTE:						info->execute = CPU_EXECUTE_NAME(cop410);			break;
+		case CPUINFO_FCT_BURN:							info->burn = NULL;						break;
+		case CPUINFO_FCT_DISASSEMBLE:					info->disassemble = CPU_DISASSEMBLE_NAME(cop410);		break;
+		case CPUINFO_PTR_INSTRUCTION_COUNTER:			info->icount = &cop400->icount;			break;
+		case CPUINFO_FCT_VALIDITY_CHECK:				info->validity_check = CPU_VALIDITY_CHECK_NAME(cop410);	break;
+
+		case CPUINFO_PTR_INTERNAL_MEMORY_MAP_PROGRAM:
+			info->internal_map8 = ADDRESS_MAP_NAME(cop410_internal_rom);                              break;
+		case CPUINFO_PTR_INTERNAL_MEMORY_MAP_DATA:
+ 			info->internal_map8 = ADDRESS_MAP_NAME(cop410_internal_ram);								break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
 		case CPUINFO_STR_NAME:							strcpy(info->s, "COP410");				break;
-		case CPUINFO_STR_CORE_FAMILY:					strcpy(info->s, "National Semiconductor COP410"); break;
+		case CPUINFO_STR_CORE_FAMILY:					strcpy(info->s, "National Semiconductor COPS"); break;
 		case CPUINFO_STR_CORE_VERSION:					strcpy(info->s, "1.0");					break;
 		case CPUINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);				break;
 		case CPUINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright MAME Team"); break;
@@ -383,17 +480,35 @@ void cop410_get_info(UINT32 state, cpuinfo *info)
 	}
 }
 
-void cop411_get_info(UINT32 state, cpuinfo *info)
+CPU_GET_INFO( cop411 )
 {
+	// COP411 is a 20-pin package version of the COP410, missing D2/D3/G3/CKO
+
 	switch (state)
 	{
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case CPUINFO_PTR_INIT:							info->init = cop411_init;				break;
+		case CPUINFO_FCT_INIT:							info->init = CPU_INIT_NAME(cop411);				break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
 		case CPUINFO_STR_NAME:							strcpy(info->s, "COP411");				break;
-		case CPUINFO_STR_CORE_FAMILY:					strcpy(info->s, "National Semiconductor COP411"); break;
+		case CPUINFO_STR_CORE_FAMILY:					strcpy(info->s, "National Semiconductor COPS"); break;
 
-		default: cop410_get_info(state, info); break;
+		default: CPU_GET_INFO_CALL(cop410); break;
+	}
+}
+
+CPU_GET_INFO( cop401 )
+{
+	// COP401 is a ROMless version of the COP410
+
+	switch (state)
+	{
+		case CPUINFO_STR_NAME:							strcpy(info->s, "COP401");				break;
+		case CPUINFO_STR_CORE_FAMILY:					strcpy(info->s, "National Semiconductor COPS"); break;
+
+		case CPUINFO_PTR_INTERNAL_MEMORY_MAP_PROGRAM:
+ 			info->internal_map8 = NULL;															break;
+
+		default: CPU_GET_INFO_CALL(cop410); break;
 	}
 }
