@@ -1,443 +1,443 @@
-INLINE void illegal( void );
-INLINE void neg_di( void );
-INLINE void oim_di( void );
-INLINE void aim_di( void );
-INLINE void com_di( void );
-INLINE void lsr_di( void );
-INLINE void eim_di( void );
-INLINE void ror_di( void );
-INLINE void asr_di( void );
-INLINE void asl_di( void );
-INLINE void rol_di( void );
-INLINE void dec_di( void );
-INLINE void tim_di( void );
-INLINE void inc_di( void );
-INLINE void tst_di( void );
-INLINE void jmp_di( void );
-INLINE void clr_di( void );
-INLINE void nop( void );
-INLINE void sync( void );
-INLINE void sexw( void );
-INLINE void lbra( void );
-INLINE void lbsr( void );
-INLINE void daa( void );
-INLINE void daa( void );
-INLINE void orcc( void );
-INLINE void andcc( void );
-INLINE void sex( void );
-INLINE void exg( void );
-INLINE void tfr( void );
-INLINE void bra( void );
-INLINE void brn( void );
-INLINE void lbrn( void );
-INLINE void bhi( void );
-INLINE void lbhi( void );
-INLINE void bls( void );
-INLINE void lbls( void );
-INLINE void bcc( void );
-INLINE void lbcc( void );
-INLINE void bcs( void );
-INLINE void lbcs( void );
-INLINE void bne( void );
-INLINE void lbne( void );
-INLINE void beq( void );
-INLINE void lbeq( void );
-INLINE void bvc( void );
-INLINE void lbvc( void );
-INLINE void bvs( void );
-INLINE void lbvs( void );
-INLINE void bpl( void );
-INLINE void lbpl( void );
-INLINE void bmi( void );
-INLINE void lbmi( void );
-INLINE void bge( void );
-INLINE void lbge( void );
-INLINE void blt( void );
-INLINE void lblt( void );
-INLINE void bgt( void );
-INLINE void lbgt( void );
-INLINE void ble( void );
-INLINE void lble( void );
-INLINE void addr_r( void );
-INLINE void adcr( void );
-INLINE void subr( void );
-INLINE void sbcr( void );
-INLINE void andr( void );
-INLINE void orr( void );
-INLINE void eorr( void );
-INLINE void cmpr( void );
-INLINE void tfmpp( void );
-INLINE void tfmmm( void );
-INLINE void tfmpc( void );
-INLINE void tfmcp( void );
-INLINE void bitmd_im( void );
-INLINE void leax( void );
-INLINE void leay( void );
-INLINE void leas( void );
-INLINE void leau( void );
-INLINE void pshs( void );
-INLINE void ldmd_im( void );
-INLINE void pshsw( void );
-INLINE void pshuw( void );
-INLINE void puls( void );
-INLINE void pulsw( void );
-INLINE void puluw( void );
-INLINE void pshu( void );
-INLINE void pulu( void );
-INLINE void rts( void );
-INLINE void abx( void );
-INLINE void rti( void );
-INLINE void cwai( void );
-INLINE void bitd_di( void );
-INLINE void bitd_ix( void );
-INLINE void bitd_ex( void );
-INLINE void mul( void );
-INLINE void swi( void );
-INLINE void band( void );
-INLINE void bitd_im( void );
-INLINE void biand( void );
-INLINE void bor( void );
-INLINE void bior( void );
-INLINE void beor( void );
-INLINE void bieor( void );
-INLINE void ldbt( void );
-INLINE void stbt( void );
-INLINE void swi2( void );
-INLINE void swi3( void );
-INLINE void nega( void );
-INLINE void coma( void );
-INLINE void lsra( void );
-INLINE void rora( void );
-INLINE void asra( void );
-INLINE void asla( void );
-INLINE void rola( void );
-INLINE void deca( void );
-INLINE void inca( void );
-INLINE void tsta( void );
-INLINE void clra( void );
-INLINE void negb( void );
-INLINE void negd( void );
-INLINE void comb( void );
-INLINE void come( void );
-INLINE void comf( void );
-INLINE void comd( void );
-INLINE void comw( void );
-INLINE void lsrb( void );
-INLINE void lsrd( void );
-INLINE void lsrw( void );
-INLINE void rorb( void );
-INLINE void rord( void );
-INLINE void rorw( void );
-INLINE void asrb( void );
-INLINE void asrd( void );
-INLINE void aslb( void );
-INLINE void asld( void );
-INLINE void rolb( void );
-INLINE void rold( void );
-INLINE void rolw( void );
-INLINE void decb( void );
-INLINE void dece( void );
-INLINE void decf( void );
-INLINE void decd( void );
-INLINE void decw( void );
-INLINE void incb( void );
-INLINE void ince( void );
-INLINE void incf( void );
-INLINE void incd( void );
-INLINE void incw( void );
-INLINE void tstb( void );
-INLINE void tstd( void );
-INLINE void tstw( void );
-INLINE void tste( void );
-INLINE void tstf( void );
-INLINE void clrb( void );
-INLINE void clrd( void );
-INLINE void clre( void );
-INLINE void clrf( void );
-INLINE void clrw( void );
-INLINE void neg_ix( void );
-INLINE void oim_ix( void );
-INLINE void aim_ix( void );
-INLINE void com_ix( void );
-INLINE void lsr_ix( void );
-INLINE void eim_ix( void );
-INLINE void ror_ix( void );
-INLINE void asr_ix( void );
-INLINE void asl_ix( void );
-INLINE void rol_ix( void );
-INLINE void dec_ix( void );
-INLINE void tim_ix( void );
-INLINE void inc_ix( void );
-INLINE void tst_ix( void );
-INLINE void jmp_ix( void );
-INLINE void clr_ix( void );
-INLINE void neg_ex( void );
-INLINE void oim_ex( void );
-INLINE void aim_ex( void );
-INLINE void com_ex( void );
-INLINE void lsr_ex( void );
-INLINE void eim_ex( void );
-INLINE void ror_ex( void );
-INLINE void asr_ex( void );
-INLINE void asl_ex( void );
-INLINE void rol_ex( void );
-INLINE void dec_ex( void );
-INLINE void tim_ex( void );
-INLINE void inc_ex( void );
-INLINE void tst_ex( void );
-INLINE void jmp_ex( void );
-INLINE void clr_ex( void );
-INLINE void suba_im( void );
-INLINE void cmpa_im( void );
-INLINE void sbca_im( void );
-INLINE void subd_im( void );
-INLINE void subw_im( void );
-INLINE void cmpd_im( void );
-INLINE void cmpw_im( void );
-INLINE void cmpu_im( void );
-INLINE void anda_im( void );
-INLINE void bita_im( void );
-INLINE void lda_im( void );
-INLINE void eora_im( void );
-INLINE void adca_im( void );
-INLINE void ora_im( void );
-INLINE void adda_im( void );
-INLINE void cmpx_im( void );
-INLINE void cmpy_im( void );
-INLINE void cmps_im( void );
-INLINE void bsr( void );
-INLINE void ldx_im( void );
-INLINE void ldq_im( void );
-INLINE void ldy_im( void );
-INLINE void suba_di( void );
-INLINE void cmpa_di( void );
-INLINE void sbca_di( void );
-INLINE void subd_di( void );
-INLINE void subw_di( void );
-INLINE void cmpd_di( void );
-INLINE void cmpw_di( void );
-INLINE void cmpu_di( void );
-INLINE void anda_di( void );
-INLINE void bita_di( void );
-INLINE void lda_di( void );
-INLINE void sta_di( void );
-INLINE void eora_di( void );
-INLINE void adca_di( void );
-INLINE void ora_di( void );
-INLINE void adda_di( void );
-INLINE void cmpx_di( void );
-INLINE void cmpy_di( void );
-INLINE void cmps_di( void );
-INLINE void jsr_di( void );
-INLINE void ldx_di( void );
-INLINE void muld_di( void );
-INLINE void divd_im( void );
-INLINE void divq_im( void );
-INLINE void muld_im( void );
-INLINE void divd_di( void );
-INLINE void divq_di( void );
-INLINE void ldq_di( void );
-INLINE void ldy_di( void );
-INLINE void stx_di( void );
-INLINE void stq_di( void );
-INLINE void sty_di( void );
-INLINE void suba_ix( void );
-INLINE void cmpa_ix( void );
-INLINE void sbca_ix( void );
-INLINE void subd_ix( void );
-INLINE void subw_ix( void );
-INLINE void cmpd_ix( void );
-INLINE void cmpw_ix( void );
-INLINE void cmpu_ix( void );
-INLINE void anda_ix( void );
-INLINE void bita_ix( void );
-INLINE void lda_ix( void );
-INLINE void sta_ix( void );
-INLINE void eora_ix( void );
-INLINE void adca_ix( void );
-INLINE void ora_ix( void );
-INLINE void adda_ix( void );
-INLINE void cmpx_ix( void );
-INLINE void cmpy_ix( void );
-INLINE void cmps_ix( void );
-INLINE void jsr_ix( void );
-INLINE void ldx_ix( void );
-INLINE void muld_ix( void );
-INLINE void divd_ix( void );
-INLINE void divq_ix( void );
-INLINE void ldq_ix( void );
-INLINE void ldy_ix( void );
-INLINE void stx_ix( void );
-INLINE void stq_ix( void );
-INLINE void sty_ix( void );
-INLINE void suba_ex( void );
-INLINE void cmpa_ex( void );
-INLINE void sbca_ex( void );
-INLINE void subd_ex( void );
-INLINE void subw_ex( void );
-INLINE void cmpd_ex( void );
-INLINE void cmpw_ex( void );
-INLINE void cmpu_ex( void );
-INLINE void anda_ex( void );
-INLINE void bita_ex( void );
-INLINE void lda_ex( void );
-INLINE void sta_ex( void );
-INLINE void eora_ex( void );
-INLINE void adca_ex( void );
-INLINE void ora_ex( void );
-INLINE void adda_ex( void );
-INLINE void cmpx_ex( void );
-INLINE void cmpy_ex( void );
-INLINE void cmps_ex( void );
-INLINE void jsr_ex( void );
-INLINE void ldx_ex( void );
-INLINE void muld_ex( void );
-INLINE void divd_ex( void );
-INLINE void divq_ex( void );
-INLINE void ldq_ex( void );
-INLINE void ldy_ex( void );
-INLINE void stx_ex( void );
-INLINE void stq_ex( void );
-INLINE void sty_ex( void );
-INLINE void subb_im( void );
-INLINE void sube_im( void );
-INLINE void subf_im( void );
-INLINE void cmpb_im( void );
-INLINE void cmpe_im( void );
-INLINE void cmpf_im( void );
-INLINE void sbcb_im( void );
-INLINE void sbcd_im( void );
-INLINE void addd_im( void );
-INLINE void addw_im( void );
-INLINE void adde_im( void );
-INLINE void addf_im( void );
-INLINE void andb_im( void );
-INLINE void andd_im( void );
-INLINE void bitb_im( void );
-INLINE void ldb_im( void );
-INLINE void lde_im( void );
-INLINE void ldf_im( void );
-INLINE void eorb_im( void );
-INLINE void eord_im( void );
-INLINE void adcb_im( void );
-INLINE void adcd_im( void );
-INLINE void orb_im( void );
-INLINE void ord_im( void );
-INLINE void addb_im( void );
-INLINE void ldd_im( void );
-INLINE void ldw_im( void );
-INLINE void ldu_im( void );
-INLINE void lds_im( void );
-INLINE void subb_di( void );
-INLINE void sube_di( void );
-INLINE void subf_di( void );
-INLINE void cmpb_di( void );
-INLINE void cmpe_di( void );
-INLINE void cmpf_di( void );
-INLINE void sbcb_di( void );
-INLINE void sbcd_di( void );
-INLINE void addd_di( void );
-INLINE void addw_di( void );
-INLINE void adde_di( void );
-INLINE void addf_di( void );
-INLINE void andb_di( void );
-INLINE void andd_di( void );
-INLINE void bitb_di( void );
-INLINE void ldb_di( void );
-INLINE void lde_di( void );
-INLINE void ldf_di( void );
-INLINE void stb_di( void );
-INLINE void ste_di( void );
-INLINE void stf_di( void );
-INLINE void eorb_di( void );
-INLINE void eord_di( void );
-INLINE void adcb_di( void );
-INLINE void adcd_di( void );
-INLINE void orb_di( void );
-INLINE void ord_di( void );
-INLINE void addb_di( void );
-INLINE void ldd_di( void );
-INLINE void ldw_di( void );
-INLINE void std_di( void );
-INLINE void stw_di( void );
-INLINE void ldu_di( void );
-INLINE void lds_di( void );
-INLINE void stu_di( void );
-INLINE void sts_di( void );
-INLINE void subb_ix( void );
-INLINE void sube_ix( void );
-INLINE void subf_ix( void );
-INLINE void cmpb_ix( void );
-INLINE void cmpe_ix( void );
-INLINE void cmpf_ix( void );
-INLINE void sbcb_ix( void );
-INLINE void sbcd_ix( void );
-INLINE void addd_ix( void );
-INLINE void addw_ix( void );
-INLINE void adde_ix( void );
-INLINE void addf_ix( void );
-INLINE void andb_ix( void );
-INLINE void andd_ix( void );
-INLINE void bitb_ix( void );
-INLINE void ldb_ix( void );
-INLINE void lde_ix( void );
-INLINE void ldf_ix( void );
-INLINE void stb_ix( void );
-INLINE void ste_ix( void );
-INLINE void stf_ix( void );
-INLINE void eorb_ix( void );
-INLINE void eord_ix( void );
-INLINE void adcb_ix( void );
-INLINE void adcd_ix( void );
-INLINE void orb_ix( void );
-INLINE void ord_ix( void );
-INLINE void addb_ix( void );
-INLINE void ldd_ix( void );
-INLINE void ldw_ix( void );
-INLINE void std_ix( void );
-INLINE void stw_ix( void );
-INLINE void ldu_ix( void );
-INLINE void lds_ix( void );
-INLINE void stu_ix( void );
-INLINE void sts_ix( void );
-INLINE void subb_ex( void );
-INLINE void sube_ex( void );
-INLINE void subf_ex( void );
-INLINE void cmpb_ex( void );
-INLINE void cmpe_ex( void );
-INLINE void cmpf_ex( void );
-INLINE void sbcb_ex( void );
-INLINE void sbcd_ex( void );
-INLINE void addd_ex( void );
-INLINE void addw_ex( void );
-INLINE void adde_ex( void );
-INLINE void addf_ex( void );
-INLINE void andb_ex( void );
-INLINE void andd_ex( void );
-INLINE void bitb_ex( void );
-INLINE void ldb_ex( void );
-INLINE void lde_ex( void );
-INLINE void ldf_ex( void );
-INLINE void stb_ex( void );
-INLINE void ste_ex( void );
-INLINE void stf_ex( void );
-INLINE void eorb_ex( void );
-INLINE void eord_ex( void );
-INLINE void adcb_ex( void );
-INLINE void adcd_ex( void );
-INLINE void orb_ex( void );
-INLINE void ord_ex( void );
-INLINE void addb_ex( void );
-INLINE void ldd_ex( void );
-INLINE void ldw_ex( void );
-INLINE void std_ex( void );
-INLINE void stw_ex( void );
-INLINE void ldu_ex( void );
-INLINE void lds_ex( void );
-INLINE void stu_ex( void );
-INLINE void sts_ex( void );
-INLINE void pref10( void );
-INLINE void pref11( void );
+INLINE void abx(m68_state_t *m68_state);
+INLINE void adca_di(m68_state_t *m68_state);
+INLINE void adca_ex(m68_state_t *m68_state);
+INLINE void adca_im(m68_state_t *m68_state);
+INLINE void adca_ix(m68_state_t *m68_state);
+INLINE void adcb_di(m68_state_t *m68_state);
+INLINE void adcb_ex(m68_state_t *m68_state);
+INLINE void adcb_im(m68_state_t *m68_state);
+INLINE void adcb_ix(m68_state_t *m68_state);
+INLINE void adcd_di(m68_state_t *m68_state);
+INLINE void adcd_ex(m68_state_t *m68_state);
+INLINE void adcd_im(m68_state_t *m68_state);
+INLINE void adcd_ix(m68_state_t *m68_state);
+INLINE void adcr(m68_state_t *m68_state);
+INLINE void adda_di(m68_state_t *m68_state);
+INLINE void adda_ex(m68_state_t *m68_state);
+INLINE void adda_im(m68_state_t *m68_state);
+INLINE void adda_ix(m68_state_t *m68_state);
+INLINE void addb_di(m68_state_t *m68_state);
+INLINE void addb_ex(m68_state_t *m68_state);
+INLINE void addb_im(m68_state_t *m68_state);
+INLINE void addb_ix(m68_state_t *m68_state);
+INLINE void addd_di(m68_state_t *m68_state);
+INLINE void addd_ex(m68_state_t *m68_state);
+INLINE void addd_im(m68_state_t *m68_state);
+INLINE void addd_ix(m68_state_t *m68_state);
+INLINE void adde_di(m68_state_t *m68_state);
+INLINE void adde_ex(m68_state_t *m68_state);
+INLINE void adde_im(m68_state_t *m68_state);
+INLINE void adde_ix(m68_state_t *m68_state);
+INLINE void addf_di(m68_state_t *m68_state);
+INLINE void addf_ex(m68_state_t *m68_state);
+INLINE void addf_im(m68_state_t *m68_state);
+INLINE void addf_ix(m68_state_t *m68_state);
+INLINE void addr_r(m68_state_t *m68_state);
+INLINE void addw_di(m68_state_t *m68_state);
+INLINE void addw_ex(m68_state_t *m68_state);
+INLINE void addw_im(m68_state_t *m68_state);
+INLINE void addw_ix(m68_state_t *m68_state);
+INLINE void aim_di(m68_state_t *m68_state);
+INLINE void aim_ex(m68_state_t *m68_state);
+INLINE void aim_ix(m68_state_t *m68_state);
+INLINE void anda_di(m68_state_t *m68_state);
+INLINE void anda_ex(m68_state_t *m68_state);
+INLINE void anda_im(m68_state_t *m68_state);
+INLINE void anda_ix(m68_state_t *m68_state);
+INLINE void andb_di(m68_state_t *m68_state);
+INLINE void andb_ex(m68_state_t *m68_state);
+INLINE void andb_im(m68_state_t *m68_state);
+INLINE void andb_ix(m68_state_t *m68_state);
+INLINE void andcc(m68_state_t *m68_state);
+INLINE void andd_di(m68_state_t *m68_state);
+INLINE void andd_ex(m68_state_t *m68_state);
+INLINE void andd_im(m68_state_t *m68_state);
+INLINE void andd_ix(m68_state_t *m68_state);
+INLINE void andr(m68_state_t *m68_state);
+INLINE void asla(m68_state_t *m68_state);
+INLINE void aslb(m68_state_t *m68_state);
+INLINE void asl_di(m68_state_t *m68_state);
+INLINE void asld(m68_state_t *m68_state);
+INLINE void asl_ex(m68_state_t *m68_state);
+INLINE void asl_ix(m68_state_t *m68_state);
+INLINE void asra(m68_state_t *m68_state);
+INLINE void asrb(m68_state_t *m68_state);
+INLINE void asr_di(m68_state_t *m68_state);
+INLINE void asrd(m68_state_t *m68_state);
+INLINE void asr_ex(m68_state_t *m68_state);
+INLINE void asr_ix(m68_state_t *m68_state);
+INLINE void band(m68_state_t *m68_state);
+INLINE void bcc(m68_state_t *m68_state);
+INLINE void bcs(m68_state_t *m68_state);
+INLINE void beor(m68_state_t *m68_state);
+INLINE void beq(m68_state_t *m68_state);
+INLINE void bge(m68_state_t *m68_state);
+INLINE void bgt(m68_state_t *m68_state);
+INLINE void bhi(m68_state_t *m68_state);
+INLINE void biand(m68_state_t *m68_state);
+INLINE void bieor(m68_state_t *m68_state);
+INLINE void bior(m68_state_t *m68_state);
+INLINE void bita_di(m68_state_t *m68_state);
+INLINE void bita_ex(m68_state_t *m68_state);
+INLINE void bita_im(m68_state_t *m68_state);
+INLINE void bita_ix(m68_state_t *m68_state);
+INLINE void bitb_di(m68_state_t *m68_state);
+INLINE void bitb_ex(m68_state_t *m68_state);
+INLINE void bitb_im(m68_state_t *m68_state);
+INLINE void bitb_ix(m68_state_t *m68_state);
+INLINE void bitd_di(m68_state_t *m68_state);
+INLINE void bitd_ex(m68_state_t *m68_state);
+INLINE void bitd_im(m68_state_t *m68_state);
+INLINE void bitd_ix(m68_state_t *m68_state);
+INLINE void bitmd_im(m68_state_t *m68_state);
+INLINE void ble(m68_state_t *m68_state);
+INLINE void bls(m68_state_t *m68_state);
+INLINE void blt(m68_state_t *m68_state);
+INLINE void bmi(m68_state_t *m68_state);
+INLINE void bne(m68_state_t *m68_state);
+INLINE void bor(m68_state_t *m68_state);
+INLINE void bpl(m68_state_t *m68_state);
+INLINE void bra(m68_state_t *m68_state);
+INLINE void brn(m68_state_t *m68_state);
+INLINE void bsr(m68_state_t *m68_state);
+INLINE void bvc(m68_state_t *m68_state);
+INLINE void bvs(m68_state_t *m68_state);
+INLINE void clra(m68_state_t *m68_state);
+INLINE void clrb(m68_state_t *m68_state);
+INLINE void clr_di(m68_state_t *m68_state);
+INLINE void clrd(m68_state_t *m68_state);
+INLINE void clre(m68_state_t *m68_state);
+INLINE void clr_ex(m68_state_t *m68_state);
+INLINE void clrf(m68_state_t *m68_state);
+INLINE void clr_ix(m68_state_t *m68_state);
+INLINE void clrw(m68_state_t *m68_state);
+INLINE void cmpa_di(m68_state_t *m68_state);
+INLINE void cmpa_ex(m68_state_t *m68_state);
+INLINE void cmpa_im(m68_state_t *m68_state);
+INLINE void cmpa_ix(m68_state_t *m68_state);
+INLINE void cmpb_di(m68_state_t *m68_state);
+INLINE void cmpb_ex(m68_state_t *m68_state);
+INLINE void cmpb_im(m68_state_t *m68_state);
+INLINE void cmpb_ix(m68_state_t *m68_state);
+INLINE void cmpd_di(m68_state_t *m68_state);
+INLINE void cmpd_ex(m68_state_t *m68_state);
+INLINE void cmpd_im(m68_state_t *m68_state);
+INLINE void cmpd_ix(m68_state_t *m68_state);
+INLINE void cmpe_di(m68_state_t *m68_state);
+INLINE void cmpe_ex(m68_state_t *m68_state);
+INLINE void cmpe_im(m68_state_t *m68_state);
+INLINE void cmpe_ix(m68_state_t *m68_state);
+INLINE void cmpf_di(m68_state_t *m68_state);
+INLINE void cmpf_ex(m68_state_t *m68_state);
+INLINE void cmpf_im(m68_state_t *m68_state);
+INLINE void cmpf_ix(m68_state_t *m68_state);
+INLINE void cmpr(m68_state_t *m68_state);
+INLINE void cmps_di(m68_state_t *m68_state);
+INLINE void cmps_ex(m68_state_t *m68_state);
+INLINE void cmps_im(m68_state_t *m68_state);
+INLINE void cmps_ix(m68_state_t *m68_state);
+INLINE void cmpu_di(m68_state_t *m68_state);
+INLINE void cmpu_ex(m68_state_t *m68_state);
+INLINE void cmpu_im(m68_state_t *m68_state);
+INLINE void cmpu_ix(m68_state_t *m68_state);
+INLINE void cmpw_di(m68_state_t *m68_state);
+INLINE void cmpw_ex(m68_state_t *m68_state);
+INLINE void cmpw_im(m68_state_t *m68_state);
+INLINE void cmpw_ix(m68_state_t *m68_state);
+INLINE void cmpx_di(m68_state_t *m68_state);
+INLINE void cmpx_ex(m68_state_t *m68_state);
+INLINE void cmpx_im(m68_state_t *m68_state);
+INLINE void cmpx_ix(m68_state_t *m68_state);
+INLINE void cmpy_di(m68_state_t *m68_state);
+INLINE void cmpy_ex(m68_state_t *m68_state);
+INLINE void cmpy_im(m68_state_t *m68_state);
+INLINE void cmpy_ix(m68_state_t *m68_state);
+INLINE void coma(m68_state_t *m68_state);
+INLINE void comb(m68_state_t *m68_state);
+INLINE void com_di(m68_state_t *m68_state);
+INLINE void comd(m68_state_t *m68_state);
+INLINE void come(m68_state_t *m68_state);
+INLINE void com_ex(m68_state_t *m68_state);
+INLINE void comf(m68_state_t *m68_state);
+INLINE void com_ix(m68_state_t *m68_state);
+INLINE void comw(m68_state_t *m68_state);
+INLINE void cwai(m68_state_t *m68_state);
+INLINE void daa(m68_state_t *m68_state);
+INLINE void daa(m68_state_t *m68_state);
+INLINE void deca(m68_state_t *m68_state);
+INLINE void decb(m68_state_t *m68_state);
+INLINE void dec_di(m68_state_t *m68_state);
+INLINE void decd(m68_state_t *m68_state);
+INLINE void dece(m68_state_t *m68_state);
+INLINE void dec_ex(m68_state_t *m68_state);
+INLINE void decf(m68_state_t *m68_state);
+INLINE void dec_ix(m68_state_t *m68_state);
+INLINE void decw(m68_state_t *m68_state);
+INLINE void divd_di(m68_state_t *m68_state);
+INLINE void divd_ex(m68_state_t *m68_state);
+INLINE void divd_im(m68_state_t *m68_state);
+INLINE void divd_ix(m68_state_t *m68_state);
+INLINE void divq_di(m68_state_t *m68_state);
+INLINE void divq_ex(m68_state_t *m68_state);
+INLINE void divq_im(m68_state_t *m68_state);
+INLINE void divq_ix(m68_state_t *m68_state);
+INLINE void eim_di(m68_state_t *m68_state);
+INLINE void eim_ex(m68_state_t *m68_state);
+INLINE void eim_ix(m68_state_t *m68_state);
+INLINE void eora_di(m68_state_t *m68_state);
+INLINE void eora_ex(m68_state_t *m68_state);
+INLINE void eora_im(m68_state_t *m68_state);
+INLINE void eora_ix(m68_state_t *m68_state);
+INLINE void eorb_di(m68_state_t *m68_state);
+INLINE void eorb_ex(m68_state_t *m68_state);
+INLINE void eorb_im(m68_state_t *m68_state);
+INLINE void eorb_ix(m68_state_t *m68_state);
+INLINE void eord_di(m68_state_t *m68_state);
+INLINE void eord_ex(m68_state_t *m68_state);
+INLINE void eord_im(m68_state_t *m68_state);
+INLINE void eord_ix(m68_state_t *m68_state);
+INLINE void eorr(m68_state_t *m68_state);
+INLINE void exg(m68_state_t *m68_state);
+INLINE void illegal(m68_state_t *m68_state);
+INLINE void inca(m68_state_t *m68_state);
+INLINE void incb(m68_state_t *m68_state);
+INLINE void inc_di(m68_state_t *m68_state);
+INLINE void incd(m68_state_t *m68_state);
+INLINE void ince(m68_state_t *m68_state);
+INLINE void inc_ex(m68_state_t *m68_state);
+INLINE void incf(m68_state_t *m68_state);
+INLINE void inc_ix(m68_state_t *m68_state);
+INLINE void incw(m68_state_t *m68_state);
+INLINE void jmp_di(m68_state_t *m68_state);
+INLINE void jmp_ex(m68_state_t *m68_state);
+INLINE void jmp_ix(m68_state_t *m68_state);
+INLINE void jsr_di(m68_state_t *m68_state);
+INLINE void jsr_ex(m68_state_t *m68_state);
+INLINE void jsr_ix(m68_state_t *m68_state);
+INLINE void lbcc(m68_state_t *m68_state);
+INLINE void lbcs(m68_state_t *m68_state);
+INLINE void lbeq(m68_state_t *m68_state);
+INLINE void lbge(m68_state_t *m68_state);
+INLINE void lbgt(m68_state_t *m68_state);
+INLINE void lbhi(m68_state_t *m68_state);
+INLINE void lble(m68_state_t *m68_state);
+INLINE void lbls(m68_state_t *m68_state);
+INLINE void lblt(m68_state_t *m68_state);
+INLINE void lbmi(m68_state_t *m68_state);
+INLINE void lbne(m68_state_t *m68_state);
+INLINE void lbpl(m68_state_t *m68_state);
+INLINE void lbra(m68_state_t *m68_state);
+INLINE void lbrn(m68_state_t *m68_state);
+INLINE void lbsr(m68_state_t *m68_state);
+INLINE void lbvc(m68_state_t *m68_state);
+INLINE void lbvs(m68_state_t *m68_state);
+INLINE void lda_di(m68_state_t *m68_state);
+INLINE void lda_ex(m68_state_t *m68_state);
+INLINE void lda_im(m68_state_t *m68_state);
+INLINE void lda_ix(m68_state_t *m68_state);
+INLINE void ldb_di(m68_state_t *m68_state);
+INLINE void ldb_ex(m68_state_t *m68_state);
+INLINE void ldb_im(m68_state_t *m68_state);
+INLINE void ldb_ix(m68_state_t *m68_state);
+INLINE void ldbt(m68_state_t *m68_state);
+INLINE void ldd_di(m68_state_t *m68_state);
+INLINE void ldd_ex(m68_state_t *m68_state);
+INLINE void ldd_im(m68_state_t *m68_state);
+INLINE void ldd_ix(m68_state_t *m68_state);
+INLINE void lde_di(m68_state_t *m68_state);
+INLINE void lde_ex(m68_state_t *m68_state);
+INLINE void lde_im(m68_state_t *m68_state);
+INLINE void lde_ix(m68_state_t *m68_state);
+INLINE void ldf_di(m68_state_t *m68_state);
+INLINE void ldf_ex(m68_state_t *m68_state);
+INLINE void ldf_im(m68_state_t *m68_state);
+INLINE void ldf_ix(m68_state_t *m68_state);
+INLINE void ldmd_im(m68_state_t *m68_state);
+INLINE void ldq_di(m68_state_t *m68_state);
+INLINE void ldq_ex(m68_state_t *m68_state);
+INLINE void ldq_im(m68_state_t *m68_state);
+INLINE void ldq_ix(m68_state_t *m68_state);
+INLINE void lds_di(m68_state_t *m68_state);
+INLINE void lds_ex(m68_state_t *m68_state);
+INLINE void lds_im(m68_state_t *m68_state);
+INLINE void lds_ix(m68_state_t *m68_state);
+INLINE void ldu_di(m68_state_t *m68_state);
+INLINE void ldu_ex(m68_state_t *m68_state);
+INLINE void ldu_im(m68_state_t *m68_state);
+INLINE void ldu_ix(m68_state_t *m68_state);
+INLINE void ldw_di(m68_state_t *m68_state);
+INLINE void ldw_ex(m68_state_t *m68_state);
+INLINE void ldw_im(m68_state_t *m68_state);
+INLINE void ldw_ix(m68_state_t *m68_state);
+INLINE void ldx_di(m68_state_t *m68_state);
+INLINE void ldx_ex(m68_state_t *m68_state);
+INLINE void ldx_im(m68_state_t *m68_state);
+INLINE void ldx_ix(m68_state_t *m68_state);
+INLINE void ldy_di(m68_state_t *m68_state);
+INLINE void ldy_ex(m68_state_t *m68_state);
+INLINE void ldy_im(m68_state_t *m68_state);
+INLINE void ldy_ix(m68_state_t *m68_state);
+INLINE void leas(m68_state_t *m68_state);
+INLINE void leau(m68_state_t *m68_state);
+INLINE void leax(m68_state_t *m68_state);
+INLINE void leay(m68_state_t *m68_state);
+INLINE void lsra(m68_state_t *m68_state);
+INLINE void lsrb(m68_state_t *m68_state);
+INLINE void lsr_di(m68_state_t *m68_state);
+INLINE void lsrd(m68_state_t *m68_state);
+INLINE void lsr_ex(m68_state_t *m68_state);
+INLINE void lsr_ix(m68_state_t *m68_state);
+INLINE void lsrw(m68_state_t *m68_state);
+INLINE void muld_di(m68_state_t *m68_state);
+INLINE void muld_ex(m68_state_t *m68_state);
+INLINE void muld_im(m68_state_t *m68_state);
+INLINE void muld_ix(m68_state_t *m68_state);
+INLINE void mul(m68_state_t *m68_state);
+INLINE void nega(m68_state_t *m68_state);
+INLINE void negb(m68_state_t *m68_state);
+INLINE void neg_di(m68_state_t *m68_state);
+INLINE void negd(m68_state_t *m68_state);
+INLINE void neg_ex(m68_state_t *m68_state);
+INLINE void neg_ix(m68_state_t *m68_state);
+INLINE void nop(m68_state_t *m68_state);
+INLINE void oim_di(m68_state_t *m68_state);
+INLINE void oim_ex(m68_state_t *m68_state);
+INLINE void oim_ix(m68_state_t *m68_state);
+INLINE void ora_di(m68_state_t *m68_state);
+INLINE void ora_ex(m68_state_t *m68_state);
+INLINE void ora_im(m68_state_t *m68_state);
+INLINE void ora_ix(m68_state_t *m68_state);
+INLINE void orb_di(m68_state_t *m68_state);
+INLINE void orb_ex(m68_state_t *m68_state);
+INLINE void orb_im(m68_state_t *m68_state);
+INLINE void orb_ix(m68_state_t *m68_state);
+INLINE void orcc(m68_state_t *m68_state);
+INLINE void ord_di(m68_state_t *m68_state);
+INLINE void ord_ex(m68_state_t *m68_state);
+INLINE void ord_im(m68_state_t *m68_state);
+INLINE void ord_ix(m68_state_t *m68_state);
+INLINE void orr(m68_state_t *m68_state);
+INLINE void pref10(m68_state_t *m68_state);
+INLINE void pref11(m68_state_t *m68_state);
+INLINE void pshs(m68_state_t *m68_state);
+INLINE void pshsw(m68_state_t *m68_state);
+INLINE void pshu(m68_state_t *m68_state);
+INLINE void pshuw(m68_state_t *m68_state);
+INLINE void puls(m68_state_t *m68_state);
+INLINE void pulsw(m68_state_t *m68_state);
+INLINE void pulu(m68_state_t *m68_state);
+INLINE void puluw(m68_state_t *m68_state);
+INLINE void rola(m68_state_t *m68_state);
+INLINE void rolb(m68_state_t *m68_state);
+INLINE void rol_di(m68_state_t *m68_state);
+INLINE void rold(m68_state_t *m68_state);
+INLINE void rol_ex(m68_state_t *m68_state);
+INLINE void rol_ix(m68_state_t *m68_state);
+INLINE void rolw(m68_state_t *m68_state);
+INLINE void rora(m68_state_t *m68_state);
+INLINE void rorb(m68_state_t *m68_state);
+INLINE void ror_di(m68_state_t *m68_state);
+INLINE void rord(m68_state_t *m68_state);
+INLINE void ror_ex(m68_state_t *m68_state);
+INLINE void ror_ix(m68_state_t *m68_state);
+INLINE void rorw(m68_state_t *m68_state);
+INLINE void rti(m68_state_t *m68_state);
+INLINE void rts(m68_state_t *m68_state);
+INLINE void sbca_di(m68_state_t *m68_state);
+INLINE void sbca_ex(m68_state_t *m68_state);
+INLINE void sbca_im(m68_state_t *m68_state);
+INLINE void sbca_ix(m68_state_t *m68_state);
+INLINE void sbcb_di(m68_state_t *m68_state);
+INLINE void sbcb_ex(m68_state_t *m68_state);
+INLINE void sbcb_im(m68_state_t *m68_state);
+INLINE void sbcb_ix(m68_state_t *m68_state);
+INLINE void sbcd_di(m68_state_t *m68_state);
+INLINE void sbcd_ex(m68_state_t *m68_state);
+INLINE void sbcd_im(m68_state_t *m68_state);
+INLINE void sbcd_ix(m68_state_t *m68_state);
+INLINE void sbcr(m68_state_t *m68_state);
+INLINE void sex(m68_state_t *m68_state);
+INLINE void sexw(m68_state_t *m68_state);
+INLINE void sta_di(m68_state_t *m68_state);
+INLINE void sta_ex(m68_state_t *m68_state);
+INLINE void sta_ix(m68_state_t *m68_state);
+INLINE void stb_di(m68_state_t *m68_state);
+INLINE void stb_ex(m68_state_t *m68_state);
+INLINE void stb_ix(m68_state_t *m68_state);
+INLINE void stbt(m68_state_t *m68_state);
+INLINE void std_di(m68_state_t *m68_state);
+INLINE void std_ex(m68_state_t *m68_state);
+INLINE void std_ix(m68_state_t *m68_state);
+INLINE void ste_di(m68_state_t *m68_state);
+INLINE void ste_ex(m68_state_t *m68_state);
+INLINE void ste_ix(m68_state_t *m68_state);
+INLINE void stf_di(m68_state_t *m68_state);
+INLINE void stf_ex(m68_state_t *m68_state);
+INLINE void stf_ix(m68_state_t *m68_state);
+INLINE void stq_di(m68_state_t *m68_state);
+INLINE void stq_ex(m68_state_t *m68_state);
+INLINE void stq_ix(m68_state_t *m68_state);
+INLINE void sts_di(m68_state_t *m68_state);
+INLINE void sts_ex(m68_state_t *m68_state);
+INLINE void sts_ix(m68_state_t *m68_state);
+INLINE void stu_di(m68_state_t *m68_state);
+INLINE void stu_ex(m68_state_t *m68_state);
+INLINE void stu_ix(m68_state_t *m68_state);
+INLINE void stw_di(m68_state_t *m68_state);
+INLINE void stw_ex(m68_state_t *m68_state);
+INLINE void stw_ix(m68_state_t *m68_state);
+INLINE void stx_di(m68_state_t *m68_state);
+INLINE void stx_ex(m68_state_t *m68_state);
+INLINE void stx_ix(m68_state_t *m68_state);
+INLINE void sty_di(m68_state_t *m68_state);
+INLINE void sty_ex(m68_state_t *m68_state);
+INLINE void sty_ix(m68_state_t *m68_state);
+INLINE void suba_di(m68_state_t *m68_state);
+INLINE void suba_ex(m68_state_t *m68_state);
+INLINE void suba_im(m68_state_t *m68_state);
+INLINE void suba_ix(m68_state_t *m68_state);
+INLINE void subb_di(m68_state_t *m68_state);
+INLINE void subb_ex(m68_state_t *m68_state);
+INLINE void subb_im(m68_state_t *m68_state);
+INLINE void subb_ix(m68_state_t *m68_state);
+INLINE void subd_di(m68_state_t *m68_state);
+INLINE void subd_ex(m68_state_t *m68_state);
+INLINE void subd_im(m68_state_t *m68_state);
+INLINE void subd_ix(m68_state_t *m68_state);
+INLINE void sube_di(m68_state_t *m68_state);
+INLINE void sube_ex(m68_state_t *m68_state);
+INLINE void sube_im(m68_state_t *m68_state);
+INLINE void sube_ix(m68_state_t *m68_state);
+INLINE void subf_di(m68_state_t *m68_state);
+INLINE void subf_ex(m68_state_t *m68_state);
+INLINE void subf_im(m68_state_t *m68_state);
+INLINE void subf_ix(m68_state_t *m68_state);
+INLINE void subr(m68_state_t *m68_state);
+INLINE void subw_di(m68_state_t *m68_state);
+INLINE void subw_ex(m68_state_t *m68_state);
+INLINE void subw_im(m68_state_t *m68_state);
+INLINE void subw_ix(m68_state_t *m68_state);
+INLINE void swi2(m68_state_t *m68_state);
+INLINE void swi3(m68_state_t *m68_state);
+INLINE void swi(m68_state_t *m68_state);
+INLINE void sync(m68_state_t *m68_state);
+INLINE void tfmcp(m68_state_t *m68_state);
+INLINE void tfmmm(m68_state_t *m68_state);
+INLINE void tfmpc(m68_state_t *m68_state);
+INLINE void tfmpp(m68_state_t *m68_state);
+INLINE void tfr(m68_state_t *m68_state);
+INLINE void tim_di(m68_state_t *m68_state);
+INLINE void tim_ex(m68_state_t *m68_state);
+INLINE void tim_ix(m68_state_t *m68_state);
+INLINE void tsta(m68_state_t *m68_state);
+INLINE void tstb(m68_state_t *m68_state);
+INLINE void tst_di(m68_state_t *m68_state);
+INLINE void tstd(m68_state_t *m68_state);
+INLINE void tste(m68_state_t *m68_state);
+INLINE void tst_ex(m68_state_t *m68_state);
+INLINE void tstf(m68_state_t *m68_state);
+INLINE void tst_ix(m68_state_t *m68_state);
+INLINE void tstw(m68_state_t *m68_state);
 
 static const UINT8 flags8i[256]=	 /* increment */
 {
@@ -650,9 +650,9 @@ static const UINT8 ccounts_page11_na[256] =    /* Cycle Counts Page 11, Native 6
 /* 0xFX */      5,    5, IIP1, IIP1, IIP1, IIP1,    5,    5, IIP1, IIP1, IIP1,    5, IIP1, IIP1, IIP1, IIP1
 };
 
-#ifndef BIG_SWITCH
+#if !BIG_SWITCH
 
-static void (*const hd6309_main[0x100])(void) = {
+static void (*const hd6309_main[0x100])(m68_state_t *) = {
 /*          0xX0,   0xX1,     0xX2,    0xX3,    0xX4,    0xX5,    0xX6,    0xX7,
             0xX8,   0xX9,     0xXA,    0xXB,    0xXC,    0xXD,    0xXE,    0xXF   */
 
@@ -705,7 +705,7 @@ static void (*const hd6309_main[0x100])(void) = {
             eorb_ex, adcb_ex, orb_ex,  addb_ex, ldd_ex,  std_ex,  ldu_ex,  stu_ex
 };
 
-static void (*const hd6309_page01[0x100])(void) = {
+static void (*const hd6309_page01[0x100])(m68_state_t *) = {
 /*          0xX0,   0xX1,     0xX2,    0xX3,    0xX4,    0xX5,    0xX6,    0xX7,
             0xX8,   0xX9,     0xXA,    0xXB,    0xXC,    0xXD,    0xXE,    0xXF   */
 
@@ -757,7 +757,7 @@ static void (*const hd6309_page01[0x100])(void) = {
 /* 0xFX */  IIError, IIError, IIError, IIError, IIError, IIError, IIError, IIError,
 			IIError, IIError, IIError, IIError, ldq_ex,  stq_ex,  lds_ex,  sts_ex
 };
-static void (*const hd6309_page11[0x100])(void) = {
+static void (*const hd6309_page11[0x100])(m68_state_t *) = {
 /*          0xX0,   0xX1,     0xX2,    0xX3,    0xX4,    0xX5,    0xX6,    0xX7,
             0xX8,   0xX9,     0xXA,    0xXB,    0xXC,    0xXD,    0xXE,    0xXF   */
 
