@@ -438,8 +438,8 @@ int m7700_disassemble(char* buff, unsigned int pc, unsigned int pb, const UINT8
 		case RELW:
 		case PER :
 			var = read_16(oprom,1);
-			sprintf(ptr, " %06x (%s)", pb | ((pc + 1 + var)&0xffff), int_16_str(var));
 			length += 2;
+			sprintf(ptr, " %06x (%s)", pb | ((pc + length + var)&0xffff), int_16_str(var));
 			break;
 		case IMM :
 			if((opcode->flag == M && !m_flag) || (opcode->flag == X && !x_flag))
