@@ -24,6 +24,8 @@
 /* 4. February 2000 PeT ply inw dew */
 /* 4. February 2000 PeT fixed relative word operand */
 /* 9. May 2000 PeT added m4510 */
+/* 18.April 2008 Roberto Fresca fixed bbr, bbs, rmb & smb displayment,
+   showing the correct bit to operate */
 
 #include "debugger.h"
 #include "m6502.h"
@@ -78,7 +80,7 @@ enum opcodes {
 	bsr,
 /* 6510 + 65c02 mnemonics */
 	anc,  asr, ast,  arr,  asx,  axa,  dcp,  dea,
-	dop,  ina, isc,  lax,  phx,  phy,  plx,  ply,
+	dop,  ina, isb,  lax,  phx,  phy,  plx,  ply,
 	rla,  rra, sax,  slo,  sre,  sah,  say,  ssh,
 	sxh,  syh, top,  oal,  kil,
 /* 65ce02 mnemonics */
@@ -113,7 +115,7 @@ static const char *const token[]=
 	"bsr",
 /* 6510 mnemonics */
 	"anc", "asr", "ast", "arr", "asx", "axa", "dcp", "dea",
-	"dop", "ina", "isc", "lax", "phx", "phy", "plx", "ply",
+	"dop", "ina", "isb", "lax", "phx", "phy", "plx", "ply",
 	"rla", "rra", "sax", "slo", "sre", "sah", "say", "ssh",
 	"sxh", "syh", "top", "oal", "kil",
 /* 65ce02 mnemonics */
@@ -139,43 +141,43 @@ struct op6502_info
 
 static const struct op6502_info op6502[256] = {
 	{m6502_brk,imm},{ora,idx},{kil,non},{slo,idx},/* 00 */
-	{dop,imm},{ora,zpg},{asl,zpg},{slo,zpg},
+	{nop,zpg},{ora,zpg},{asl,zpg},{slo,zpg},
 	{php,imp},{ora,imm},{asl,acc},{anc,imm},
-	{top,iw2},{ora,aba},{asl,aba},{slo,aba},
-	{bpl,rel},{ora,idy},{nop,imp},{slo,idy},/* 10 */
-	{dop,imm},{ora,zpx},{asl,zpx},{slo,zpx},
-	{clc,imp},{ora,aby},{kil,non},{slo,aby},
-	{top,iw2},{ora,abx},{asl,abx},{slo,abx},
+	{nop,aba},{ora,aba},{asl,aba},{slo,aba},
+	{bpl,rel},{ora,idy},{kil,non},{slo,idy},/* 10 */
+	{nop,zpx},{ora,zpx},{asl,zpx},{slo,zpx},
+	{clc,imp},{ora,aby},{nop,imp},{slo,aby},
+	{nop,abx},{ora,abx},{asl,abx},{slo,abx},
 	{jsr,adr},{and,idx},{kil,non},{rla,idx},/* 20 */
 	{bit,zpg},{and,zpg},{rol,zpg},{rla,zpg},
 	{plp,imp},{and,imm},{rol,acc},{anc,imm},
 	{bit,aba},{and,aba},{rol,aba},{rla,aba},
 	{bmi,rel},{and,idy},{kil,non},{rla,idy},/* 30 */
-	{dop,imm},{and,zpx},{rol,zpx},{rla,zpx},
+	{nop,zpx},{and,zpx},{rol,zpx},{rla,zpx},
 	{sec,imp},{and,aby},{nop,imp},{rla,aby},
-	{top,iw2},{and,abx},{rol,abx},{rla,abx},
+	{nop,abx},{and,abx},{rol,abx},{rla,abx},
 	{rti,imp},{eor,idx},{kil,non},{sre,idx},/* 40 */
-	{dop,imm},{eor,zpg},{lsr,zpg},{sre,zpg},
+	{nop,zpg},{eor,zpg},{lsr,zpg},{sre,zpg},
 	{pha,imp},{eor,imm},{lsr,acc},{asr,imm},
 	{jmp,adr},{eor,aba},{lsr,aba},{sre,aba},
 	{bvc,rel},{eor,idy},{kil,non},{sre,idy},/* 50 */
-	{dop,imm},{eor,zpx},{lsr,zpx},{sre,zpx},
+	{nop,zpx},{eor,zpx},{lsr,zpx},{sre,zpx},
 	{cli,imp},{eor,aby},{nop,imp},{sre,aby},
-	{top,iw2},{eor,abx},{lsr,abx},{sre,abx},
+	{nop,abx},{eor,abx},{lsr,abx},{sre,abx},
 	{rts,imp},{adc,idx},{kil,non},{rra,idx},/* 60 */
-	{dop,imm},{adc,zpg},{ror,zpg},{rra,zpg},
+	{nop,zpg},{adc,zpg},{ror,zpg},{rra,zpg},
 	{pla,imp},{adc,imm},{ror,acc},{arr,imm},
 	{jmp,ind},{adc,aba},{ror,aba},{rra,aba},
 	{bvs,rel},{adc,idy},{kil,non},{rra,idy},/* 70 */
-	{dop,imm},{adc,zpx},{ror,zpx},{rra,zpx},
+	{nop,zpx},{adc,zpx},{ror,zpx},{rra,zpx},
 	{sei,imp},{adc,aby},{nop,imp},{rra,aby},
-	{top,iw2},{adc,abx},{ror,abx},{rra,abx},
-	{dop,imm},{sta,idx},{dop,imm},{sax,idx},/* 80 */
+	{nop,abx},{adc,abx},{ror,abx},{rra,abx},
+	{nop,imm},{sta,idx},{nop,imm},{sax,idx},/* 80 */
 	{sty,zpg},{sta,zpg},{stx,zpg},{sax,zpg},
-	{dey,imp},{dop,imm},{txa,imp},{axa,imm},
+	{dey,imp},{nop,imm},{txa,imp},{axa,imm},
 	{sty,aba},{sta,aba},{stx,aba},{sax,aba},
 	{bcc,rel},{sta,idy},{kil,non},{say,idy},/* 90 */
-	{sty,zpx},{sta,zpx},{stx,zpy},{sax,zpx},
+	{sty,zpx},{sta,zpx},{stx,zpy},{sax,zpy},
 	{tya,imp},{sta,aby},{txs,imp},{ssh,aby},
 	{syh,abx},{sta,abx},{sxh,aby},{sah,aby},
 	{ldy,imm},{lda,idx},{ldx,imm},{lax,idx},/* a0 */
@@ -183,25 +185,25 @@ static const struct op6502_info op6502[256] = {
 	{tay,imp},{lda,imm},{tax,imp},{oal,imm},
 	{ldy,aba},{lda,aba},{ldx,aba},{lax,aba},
 	{bcs,rel},{lda,idy},{kil,non},{lax,idy},/* b0 */
-	{ldy,zpx},{lda,zpx},{ldx,zpy},{lax,zpx},
+	{ldy,zpx},{lda,zpx},{ldx,zpy},{lax,zpy},
 	{clv,imp},{lda,aby},{tsx,imp},{ast,aby},
-	{ldy,abx},{lda,abx},{ldx,aby},{lax,abx},
-	{cpy,imm},{cmp,idx},{dop,imm},{dcp,idx},/* c0 */
+	{ldy,abx},{lda,abx},{ldx,aby},{lax,aby},
+	{cpy,imm},{cmp,idx},{nop,imm},{dcp,idx},/* c0 */
 	{cpy,zpg},{cmp,zpg},{dec,zpg},{dcp,zpg},
 	{iny,imp},{cmp,imm},{dex,imp},{asx,imm},
 	{cpy,aba},{cmp,aba},{dec,aba},{dcp,aba},
 	{bne,rel},{cmp,idy},{kil,non},{dcp,idy},/* d0 */
-	{dop,imm},{cmp,zpx},{dec,zpx},{dcp,zpx},
+	{nop,zpx},{cmp,zpx},{dec,zpx},{dcp,zpx},
 	{cld,imp},{cmp,aby},{nop,imp},{dcp,aby},
-	{top,iw2},{cmp,abx},{dec,abx},{dcp,abx},
-	{cpx,imm},{sbc,idx},{dop,imm},{isc,idx},/* e0 */
-	{cpx,zpg},{sbc,zpg},{inc,zpg},{isc,zpg},
+	{nop,abx},{cmp,abx},{dec,abx},{dcp,abx},
+	{cpx,imm},{sbc,idx},{nop,imm},{isb,idx},/* e0 */
+	{cpx,zpg},{sbc,zpg},{inc,zpg},{isb,zpg},
 	{inx,imp},{sbc,imm},{nop,imp},{sbc,imm},
-	{cpx,aba},{sbc,aba},{inc,aba},{isc,aba},
-	{beq,rel},{sbc,idy},{kil,non},{isc,idy},/* f0 */
-	{dop,imm},{sbc,zpx},{inc,zpx},{isc,zpx},
-	{sed,imp},{sbc,aby},{nop,imp},{isc,aby},
-	{top,iw2},{sbc,abx},{inc,abx},{isc,abx}
+	{cpx,aba},{sbc,aba},{inc,aba},{isb,aba},
+	{beq,rel},{sbc,idy},{kil,non},{isb,idy},/* f0 */
+	{nop,zpx},{sbc,zpx},{inc,zpx},{isb,zpx},
+	{sed,imp},{sbc,aby},{nop,imp},{isb,aby},
+	{nop,abx},{sbc,abx},{inc,abx},{isb,abx}
 };
 
 static const struct op6502_info op65c02[256] = {
@@ -589,7 +591,7 @@ static unsigned internal_m6502_dasm(const struct op6502_info *opinfo, char *buff
 
 	dst += sprintf(dst, "%-5s", token[opc]);
 	if( opc == bbr || opc == bbs || opc == rmb || opc == smb )
-		dst += sprintf(dst, "%d,", (op >> 3) & 7);
+		dst += sprintf(dst, "%d,", (op >> 4) & 7);
 
 	switch(arg)
 	{
@@ -740,48 +742,48 @@ static unsigned internal_m6502_dasm(const struct op6502_info *opinfo, char *buff
 	return (pc - PC) | flags;
 }
 
-unsigned m6502_dasm(char *buffer, offs_t pc, const UINT8 *oprom, const UINT8 *opram)
+CPU_DISASSEMBLE( m6502 )
 {
 	return internal_m6502_dasm(op6502, buffer, pc, oprom, opram);
 }
 
 #if (HAS_M65SC02)
-unsigned m65sc02_dasm(char *buffer, offs_t pc, const UINT8 *oprom, const UINT8 *opram)
+CPU_DISASSEMBLE( m65sc02 )
 {
 	return internal_m6502_dasm(op65sc02, buffer, pc, oprom, opram);
 }
 #endif
 
 #if (HAS_M65C02||HAS_M65SC02||HAS_DECO16)
-unsigned m65c02_dasm(char *buffer, offs_t pc, const UINT8 *oprom, const UINT8 *opram)
+CPU_DISASSEMBLE( m65c02 )
 {
 	return internal_m6502_dasm(op65c02, buffer, pc, oprom, opram);
 }
 #endif
 
 #if (HAS_M65CE02)
-unsigned m65ce02_dasm(char *buffer, offs_t pc, const UINT8 *oprom, const UINT8 *opram)
+CPU_DISASSEMBLE( m65ce02 )
 {
 	return internal_m6502_dasm(op65ce02, buffer, pc, oprom, opram);
 }
 #endif
 
 #if (HAS_M6510)
-unsigned m6510_dasm(char *buffer, offs_t pc, const UINT8 *oprom, const UINT8 *opram)
+CPU_DISASSEMBLE( m6510 )
 {
 	return internal_m6502_dasm(op6502, buffer, pc, oprom, opram);
 }
 #endif
 
 #if (HAS_DECO16)
-unsigned deco16_dasm(char *buffer, offs_t pc, const UINT8 *oprom, const UINT8 *opram)
+CPU_DISASSEMBLE( deco16 )
 {
 	return internal_m6502_dasm(opdeco16, buffer, pc, oprom, opram);
 }
 #endif
 
 #if (HAS_M4510)
-unsigned m4510_dasm(char *buffer, offs_t pc, const UINT8 *oprom, const UINT8 *opram)
+CPU_DISASSEMBLE( m4510 )
 {
 	return internal_m6502_dasm(op4510, buffer, pc, oprom, opram);
 }
