@@ -23,7 +23,7 @@
  *****************************************************************************/
 
 #undef	OP
-#define OP(nn) INLINE void m6502_##nn(void)
+#define OP(nn) INLINE void m6502_##nn(m6502_Regs *cpustate)
 
 /*****************************************************************************
  *****************************************************************************
@@ -323,7 +323,7 @@ OP(ff) { int tmp; RD_ABX_NP; WB_EA; ISB; WB_EA; } /* 7 ISB ABX */
 
 /* and here's the array of function pointers */
 
-static void (*const insn6502[0x100])(void) = {
+static void (*const insn6502[0x100])(m6502_Regs *cpustate) = {
 	m6502_00,m6502_01,m6502_02,m6502_03,m6502_04,m6502_05,m6502_06,m6502_07,
 	m6502_08,m6502_09,m6502_0a,m6502_0b,m6502_0c,m6502_0d,m6502_0e,m6502_0f,
 	m6502_10,m6502_11,m6502_12,m6502_13,m6502_14,m6502_15,m6502_16,m6502_17,
