@@ -127,7 +127,8 @@ static const char g_version[] = "3.32";
 /* ============================== PROTOTYPES ============================== */
 /* ======================================================================== */
 
-enum {
+enum
+{
 	CPU_TYPE_000 = 0,
 	CPU_TYPE_010,
 	CPU_TYPE_020,
@@ -780,7 +781,7 @@ void get_base_name(char* base_name, opcode_struct* op)
 /* Write the name of an opcode handler function */
 void write_function_name(FILE* filep, char* base_name)
 {
-	fprintf(filep, "static void %s(void)\n", base_name);
+	fprintf(filep, "static void %s(m68ki_cpu_core *m68k)\n", base_name);
 }
 
 void add_opcode_output_table_entry(opcode_struct* op, char* name)
@@ -869,17 +870,17 @@ void generate_opcode_handler(FILE* filep, body_struct* body, replace_struct* rep
 	/* Add any replace strings needed */
 	if(ea_mode != EA_MODE_NONE)
 	{
-		sprintf(str, "EA_%s_8()", g_ea_info_table[ea_mode].ea_add);
+		sprintf(str, "EA_%s_8(m68k)", g_ea_info_table[ea_mode].ea_add);
 		add_replace_string(replace, ID_OPHANDLER_EA_AY_8, str);
-		sprintf(str, "EA_%s_16()", g_ea_info_table[ea_mode].ea_add);
+		sprintf(str, "EA_%s_16(m68k)", g_ea_info_table[ea_mode].ea_add);
 		add_replace_string(replace, ID_OPHANDLER_EA_AY_16, str);
-		sprintf(str, "EA_%s_32()", g_ea_info_table[ea_mode].ea_add);
+		sprintf(str, "EA_%s_32(m68k)", g_ea_info_table[ea_mode].ea_add);
 		add_replace_string(replace, ID_OPHANDLER_EA_AY_32, str);
-		sprintf(str, "OPER_%s_8()", g_ea_info_table[ea_mode].ea_add);
+		sprintf(str, "OPER_%s_8(m68k)", g_ea_info_table[ea_mode].ea_add);
 		add_replace_string(replace, ID_OPHANDLER_OPER_AY_8, str);
-		sprintf(str, "OPER_%s_16()", g_ea_info_table[ea_mode].ea_add);
+		sprintf(str, "OPER_%s_16(m68k)", g_ea_info_table[ea_mode].ea_add);
 		add_replace_string(replace, ID_OPHANDLER_OPER_AY_16, str);
-		sprintf(str, "OPER_%s_32()", g_ea_info_table[ea_mode].ea_add);
+		sprintf(str, "OPER_%s_32(m68k)", g_ea_info_table[ea_mode].ea_add);
 		add_replace_string(replace, ID_OPHANDLER_OPER_AY_32, str);
 	}
 
@@ -961,8 +962,8 @@ void generate_opcode_cc_variants(FILE* filep, body_struct* body, replace_struct*
 	for(i=2;i<16;i++)
 	{
 		/* Add replace strings for this condition code */
-		sprintf(repl, "COND_%s()", g_cc_table[i][1]);
-		sprintf(replnot, "COND_NOT_%s()", g_cc_table[i][1]);
+		sprintf(repl, "COND_%s(m68k)", g_cc_table[i][1]);
+		sprintf(replnot, "COND_NOT_%s(m68k)", g_cc_table[i][1]);
 
 		add_replace_string(replace, ID_OPHANDLER_CC, repl);
 		add_replace_string(replace, ID_OPHANDLER_NOT_CC, replnot);
