@@ -5,11 +5,13 @@
     Front-end for MIPS3 recompiler
 
     Copyright Aaron Giles
-    Released for general use under the MAME license
+    Released for general non-commercial use under the MAME license
     Visit http://mamedev.org for licensing and usage restrictions.
 
 ***************************************************************************/
 
+#pragma once
+
 #ifndef __MIPS3FE_H__
 #define __MIPS3FE_H__
 
@@ -20,31 +22,23 @@
     CONSTANTS
 ***************************************************************************/
 
-/* register flags */
-#define REGFLAG_R(n)					(((n) == 0) ? 0 : ((UINT64)1 << (n)))
-#define REGFLAG_LO						(REGFLAG_R(REG_LO))
-#define REGFLAG_HI						(REGFLAG_R(REG_HI))
-#define REGFLAG_CPR1(n)					((UINT64)1 << (n))
-#define REGFLAG_FCC						(REGFLAG_CPR1(32))
+/* register flags 0 */
+#define REGFLAG_R(n)					(((n) == 0) ? 0 : (1 << (n)))
 
+/* register flags 1 */
+#define REGFLAG_CPR1(n)					(1 << (n))
 
+/* register flags 2 */
+#define REGFLAG_LO						(1 << 0)
+#define REGFLAG_HI						(1 << 1)
+#define REGFLAG_FCC						(1 << 2)
 
-/***************************************************************************
-    CONSTANTS
-***************************************************************************/
-
-/* this defines a branch targetpc that is dynamic at runtime */
-#define BRANCH_TARGET_DYNAMIC			(~0)
-
-
-/* opcode branch flags */
-#define OPFLAG_IS_UNCONDITIONAL_BRANCH	0x00000001		/* instruction is unconditional branch */
 
 
 /***************************************************************************
     FUNCTION PROTOTYPES
 ***************************************************************************/
 
-int mips3fe_describe(void *param, opcode_desc *desc);
+int mips3fe_describe(void *param, opcode_desc *desc, const opcode_desc *prev);
 
-#endif
+#endif /* __MIPS3FE_H__ */
