@@ -33,24 +33,8 @@
 #include <string.h>
 #include <ctype.h>
 
-#ifdef ENABLE_DEBUGGER					/* Compile interface to MAME */
 #include "tms32025.h"
 #include "debugger.h"
-extern UINT16 *tms32025_pgmmap[0x200];
-//#define READOP16(A)  (cpu_readop16((A)     | (TMS32025_PGM_OFFSET << 1)))
-//#define READARG16(A) (cpu_readop_arg16((A) | (TMS32025_PGM_OFFSET << 1)))
-#define READOP16(A)		((tms32025_pgmmap[(A) >> 7]) ? (tms32025_pgmmap[(A) >> 7][(A) & 0x7f]) : cpu_readop16((A)<<1))
-#define READARG16(A)	((tms32025_pgmmap[(A) >> 7]) ? (tms32025_pgmmap[(A) >> 7][(A) & 0x7f]) : cpu_readop16((A)<<1))
-#else								/* Compile interface for standalone */
-extern unsigned char *Buffer;
-#ifdef MSB_FIRST
-#define READOP16(A)  ( ((Buffer[A+1]<<8) | Buffer[A]) )
-#define READARG16(A) ( ((Buffer[A+1]<<8) | Buffer[A]) )
-#else
-#define READOP16(A)  ( ((Buffer[A]<<8) | Buffer[A+1]) )
-#define READARG16(A) ( ((Buffer[A]<<8) | Buffer[A+1]) )
-#endif
-#endif
 
 
 
@@ -403,7 +387,7 @@ static void InitDasm32025(void)
 	OpInizialized = 1;
 }
 
-offs_t tms32025_dasm(char *str, offs_t pc, const UINT8 *oprom, const UINT8 *opram)
+CPU_DISASSEMBLE( tms32025 )
 {
 	UINT32 flags = 0;
 	int a, b, c, d, k, m, n, p, r, s, t, w, x;	/* these can all be filled in by parsing an instruction */
@@ -412,7 +396,7 @@ offs_t tms32025_dasm(char *str, offs_t pc, const UINT8 *oprom, const UINT8 *opra
 	int cnt = 1;
 	int code;
 	int bit;
-	char *strtmp;
+	char *buffertmp;
 	const char *cp;				/* character pointer in OpFormats */
 
 	if (!OpInizialized) InitDasm32025();
@@ -433,10 +417,10 @@ offs_t tms32025_dasm(char *str, offs_t pc, const UINT8 *oprom, const UINT8 *opra
 	}
 	if (op == -1)
 	{
-		sprintf(str,"???? dw %04Xh",code);
+		sprintf(buffer,"???? dw %04Xh",code);
 		return cnt | DASMFLAG_SUPPORTED;
 	}
-	strtmp = str;
+	buffertmp = buffer;
 	if (Op[op].extcode)
 	{
 		bit = 31;
@@ -510,13 +494,13 @@ offs_t tms32025_dasm(char *str, offs_t pc, const UINT8 *oprom, const UINT8 *opra
 				default:
 					fatalerror("illegal escape character in format '%s'",Op[op].fmt);
 			}
-			q = num; while (*q) *str++ = *q++;
-			*str = '\0';
+			q = num; while (*q) *buffer++ = *q++;
+			*buffer = '\0';
 		}
 		else
 		{
-			*str++ = *cp++;
-			*str = '\0';
+			*buffer++ = *cp++;
+			*buffer = '\0';
 		}
 	}
 	return cnt | flags | DASMFLAG_SUPPORTED;
