@@ -1,9 +1,12 @@
-#ifndef __V60_H
-#define __V60_H
+#pragma once
+
+#ifndef __V60_H__
+#define __V60_H__
 
 #include "cpuintrf.h"
 
-enum {
+enum
+{
 	V60_R0 = 1,
 	V60_R1,
 	V60_R2,
@@ -76,15 +79,16 @@ enum {
 };
 
 extern const char *const v60_reg_names[];
-void v60_stall(void);
+void v60_stall(const device_config *device);
 
 #if HAS_V60
-void v60_get_info(UINT32 state, cpuinfo *info);
-#endif
-
-#endif
+CPU_GET_INFO( v60 );
+#define CPU_V60 CPU_GET_INFO_NAME( v60 )
+#endif /* HAS_V60 */
 
 #if HAS_V70
-void v70_get_info(UINT32 state, cpuinfo *info);
-#endif
+CPU_GET_INFO( v70 );
+#define CPU_V70 CPU_GET_INFO_NAME( v70 )
+#endif /* HAS_V70 */
 
+#endif /* __V60_H__ */
