@@ -22,7 +22,7 @@
 static MACHINE_START( empty )
 {
 	/* force the UI to show the game select screen */
-	ui_menu_force_game_select();
+	ui_menu_force_game_select(machine);
 }
 
 
@@ -38,9 +38,7 @@ static MACHINE_DRIVER_START( empty )
 	MDRV_MACHINE_START(empty)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
-
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_SIZE(640,480)
 	MDRV_SCREEN_VISIBLE_AREA(0,639, 0,479)
@@ -49,17 +47,6 @@ MACHINE_DRIVER_END
 
 
 
-/*************************************
- *
- *  Input ports
- *
- *************************************/
-
-static INPUT_PORTS_START( empty )
-INPUT_PORTS_END
-
-
-
 /*************************************
  *
  *  ROM definitions
@@ -67,7 +54,7 @@ INPUT_PORTS_END
  *************************************/
 
 ROM_START( empty )
-	ROM_REGION( 0x10, REGION_USER1, 0 )
+	ROM_REGION( 0x10, "user1", 0 )
 ROM_END
 
 
@@ -78,4 +65,4 @@ ROM_END
  *
  *************************************/
 
-GAME( 2007, empty, 0, empty, empty, 0, ROT0, "MAME", "No Driver Loaded", 0 )
+GAME( 2007, empty, 0, empty, 0, 0, ROT0, "MAME", "No Driver Loaded", 0 )
