@@ -10,7 +10,6 @@
 ******************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 
 #define VERBOSE 0
 
@@ -75,8 +74,8 @@ struct _colortable_t
     FUNCTION PROTOTYPES
 ***************************************************************************/
 
-static void palette_presave(void);
-static void palette_postload(void);
+static void palette_presave(running_machine *machine, void *param);
+static void palette_postload(running_machine *machine, void *param);
 static void palette_exit(running_machine *machine);
 static void allocate_palette(running_machine *machine, palette_private *palette);
 static void allocate_color_tables(running_machine *machine, palette_private *palette);
@@ -96,7 +95,18 @@ static void configure_rgb_shadows(running_machine *machine, int mode, float fact
 
 void palette_init(running_machine *machine)
 {
+	int format;
 	palette_private *palette = auto_malloc(sizeof(*palette));
+	const device_config *device = video_screen_first(machine->config);
+
+	/* get the format from the first screen, or use BITMAP_FORMAT_INVALID, if screenless */
+	if (device != NULL)
+	{
+		screen_config *config = device->inline_config;
+		format = config->format;
+	}
+	else
+		format = BITMAP_FORMAT_INVALID;
 
 	/* request cleanup */
 	machine->palette_data = palette;
@@ -104,25 +114,20 @@ void palette_init(running_machine *machine)
 
 	/* reset all our data */
 	memset(palette, 0, sizeof(*palette));
-	palette->format = machine->screen[0].format;
+	palette->format = format;
 
 	/* determine the color mode */
-	switch (palette->format)
+	switch (format)
 	{
 		case BITMAP_FORMAT_INDEXED16:
-			/* indexed modes are fine for everything */
-			break;
-
 		case BITMAP_FORMAT_RGB15:
 		case BITMAP_FORMAT_RGB32:
-			/* RGB modes can't use color tables */
-			assert(machine->drv->color_table_len == 0);
+			/* indexed and RGB modes are fine for everything */
 			break;
 
 		case BITMAP_FORMAT_INVALID:
 			/* invalid format means no palette - or at least it should */
-			assert(machine->drv->total_colors == 0);
-			assert(machine->drv->color_table_len == 0);
+			assert(machine->config->total_colors == 0);
 			return;
 
 		default:
@@ -131,7 +136,7 @@ void palette_init(running_machine *machine)
 	}
 
 	/* allocate all the data structures */
-	if (machine->drv->total_colors > 0)
+	if (machine->config->total_colors > 0)
 	{
 		int numcolors;
 
@@ -143,63 +148,14 @@ void palette_init(running_machine *machine)
 		numcolors = palette_get_num_colors(machine->palette);
 		palette->save_pen = auto_malloc(sizeof(*palette->save_pen) * numcolors);
 		palette->save_bright = auto_malloc(sizeof(*palette->save_bright) * numcolors);
-		state_save_register_global_pointer(palette->save_pen, numcolors);
-		state_save_register_global_pointer(palette->save_bright, numcolors);
-		state_save_register_func_presave(palette_presave);
-		state_save_register_func_postload(palette_postload);
+		state_save_register_global_pointer(machine, palette->save_pen, numcolors);
+		state_save_register_global_pointer(machine, palette->save_bright, numcolors);
+		state_save_register_presave(machine, palette_presave, palette);
+		state_save_register_postload(machine, palette_postload, palette);
 	}
 }
 
 
-/*-------------------------------------------------
-    palette_config - palette initialization that
-    takes place after the display is created
--------------------------------------------------*/
-
-void palette_config(running_machine *machine)
-{
-	int total_colors = (machine->palette == NULL) ? 0 : palette_get_num_colors(machine->palette) * palette_get_num_groups(machine->palette);
-	pen_t *remapped_colortable = NULL;
-	UINT16 *colortable = NULL;
-	int i;
-
-	/* allocate memory for the colortables, if needed */
-	if (machine->drv->color_table_len > 0)
-	{
-		/* first for the raw colortable */
-		colortable = auto_malloc(machine->drv->color_table_len * sizeof(colortable[0]));
-		for (i = 0; i < machine->drv->color_table_len; i++)
-			colortable[i] = i % total_colors;
-
-		/* then for the remapped colortable */
-		remapped_colortable = auto_malloc(machine->drv->color_table_len * sizeof(remapped_colortable[0]));
-	}
-
-	/* now let the driver modify the initial palette and colortable */
-	if (machine->drv->init_palette)
-		(*machine->drv->init_palette)(machine, colortable, memory_region(REGION_PROMS));
-
-	/* now compute the remapped_colortable */
-	for (i = 0; i < machine->drv->color_table_len; i++)
-	{
-		pen_t color = colortable[i];
-
-		/* check for invalid colors set by machine->drv->init_palette */
-		assert(color < total_colors);
-		remapped_colortable[i] = machine->pens[color];
-	}
-
-	/* now we can set the final colortables */
-	machine->game_colortable = colortable;
-	machine->remapped_colortable = (remapped_colortable != NULL) ? remapped_colortable : machine->pens;
-
-	/* set the color table base for each graphics element */
-	for (i = 0; i < MAX_GFX_ELEMENTS; i++)
-		if (machine->gfx[i] != NULL)
-			machine->gfx[i]->color_base = machine->drv->gfxdecodeinfo[i].color_codes_start;
-}
-
-
 
 /***************************************************************************
     SHADOW/HIGHLIGHT CONFIGURATION
@@ -369,26 +325,30 @@ colortable_t *colortable_alloc(running_machine *machine, UINT32 palettesize)
 	colortable_t *ctable;
 	UINT32 index;
 
+	assert(machine != NULL);
+	assert(machine->config != NULL);
+	assert(palettesize > 0);
+
 	/* allocate the colortable */
 	ctable = auto_malloc(sizeof(*ctable));
 	memset(ctable, 0, sizeof(*ctable));
 
 	/* fill in the basics */
 	ctable->machine = machine;
-	ctable->entries = machine->drv->total_colors;
+	ctable->entries = machine->config->total_colors;
 	ctable->palentries = palettesize;
 
 	/* allocate the raw colortable */
 	ctable->raw = auto_malloc(ctable->entries * sizeof(*ctable->raw));
 	for (index = 0; index < ctable->entries; index++)
 		ctable->raw[index] = index % ctable->palentries;
-	state_save_register_global_pointer(ctable->raw, ctable->entries);
+	state_save_register_global_pointer(machine, ctable->raw, ctable->entries);
 
 	/* allocate the palette */
 	ctable->palette = auto_malloc(ctable->palentries * sizeof(*ctable->palette));
 	for (index = 0; index < ctable->palentries; index++)
 		ctable->palette[index] = MAKE_ARGB(0x80,0xff,0xff,0xff);
-	state_save_register_global_pointer(ctable->palette, ctable->palentries);
+	state_save_register_global_pointer(machine, ctable->palette, ctable->palentries);
 
 	return ctable;
 }
@@ -402,6 +362,7 @@ colortable_t *colortable_alloc(running_machine *machine, UINT32 palettesize)
 void colortable_entry_set_value(colortable_t *ctable, UINT32 entry, UINT16 value)
 {
 	/* ensure values are within range */
+	assert(ctable != NULL);
 	assert(entry < ctable->entries);
 	assert(value < ctable->palentries);
 
@@ -421,6 +382,7 @@ void colortable_entry_set_value(colortable_t *ctable, UINT32 entry, UINT16 value
 
 UINT16 colortable_entry_get_value(colortable_t *ctable, UINT32 entry)
 {
+	assert(ctable != NULL);
 	assert(entry < ctable->entries);
 	return ctable->raw[entry];
 }
@@ -434,6 +396,7 @@ UINT16 colortable_entry_get_value(colortable_t *ctable, UINT32 entry)
 void colortable_palette_set_color(colortable_t *ctable, UINT32 entry, rgb_t color)
 {
 	/* ensure values are within range */
+	assert(ctable != NULL);
 	assert(entry < ctable->palentries);
 
 	/* alpha doesn't matter */
@@ -461,6 +424,7 @@ void colortable_palette_set_color(colortable_t *ctable, UINT32 entry, rgb_t colo
 
 rgb_t colortable_palette_get_color(colortable_t *ctable, UINT32 entry)
 {
+	assert(ctable != NULL);
 	assert(entry < ctable->palentries);
 	return ctable->palette[entry];
 }
@@ -479,6 +443,7 @@ UINT32 colortable_get_transpen_mask(colortable_t *ctable, const gfx_element *gfx
 	UINT32 count, bit;
 
 	/* make sure we are in range */
+	assert(ctable != NULL);
 	assert(entry < ctable->entries);
 	assert(gfx->color_depth <= 32);
 
@@ -506,6 +471,9 @@ void colortable_configure_tilemap_groups(colortable_t *ctable, tilemap *tmap, co
 {
 	int color;
 
+	assert(ctable != NULL);
+	assert(gfx != NULL);
+	assert(tmap != NULL);
 	assert(gfx->total_colors <= TILEMAP_NUM_GROUPS);
 
 	/* iterate over all colors in the tilemap */
@@ -514,6 +482,18 @@ void colortable_configure_tilemap_groups(colortable_t *ctable, tilemap *tmap, co
 }
 
 
+/*-------------------------------------------------
+    colortable_palette_get_size -
+    return the number of entries in a colortable
+-------------------------------------------------*/
+
+UINT32 colortable_palette_get_size(colortable_t *ctable)
+{
+	assert(ctable != NULL);
+	return ctable->palentries;
+}
+
+
 
 /***************************************************************************
     UTILITIES
@@ -553,17 +533,17 @@ pen_t get_white_pen(running_machine *machine)
     for saving
 -------------------------------------------------*/
 
-static void palette_presave(void)
+static void palette_presave(running_machine *machine, void *param)
 {
-	int numcolors = palette_get_num_colors(Machine->palette);
-	palette_private *palette = Machine->palette_data;
+	int numcolors = palette_get_num_colors(machine->palette);
+	palette_private *palette = param;
 	int index;
 
 	/* fill the save arrays with updated pen and brightness information */
 	for (index = 0; index < numcolors; index++)
 	{
-		palette->save_pen[index] = palette_entry_get_color(Machine->palette, index);
-		palette->save_bright[index] = palette_entry_get_contrast(Machine->palette, index);
+		palette->save_pen[index] = palette_entry_get_color(machine->palette, index);
+		palette->save_bright[index] = palette_entry_get_contrast(machine->palette, index);
 	}
 }
 
@@ -573,17 +553,17 @@ static void palette_presave(void)
     actually update the palette
 -------------------------------------------------*/
 
-static void palette_postload(void)
+static void palette_postload(running_machine *machine, void *param)
 {
-	int numcolors = palette_get_num_colors(Machine->palette);
-	palette_private *palette = Machine->palette_data;
+	int numcolors = palette_get_num_colors(machine->palette);
+	palette_private *palette = param;
 	int index;
 
 	/* reset the pen and brightness for each entry */
 	for (index = 0; index < numcolors; index++)
 	{
-		palette_entry_set_color(Machine->palette, index, palette->save_pen[index]);
-		palette_entry_set_contrast(Machine->palette, index, palette->save_bright[index]);
+		palette_entry_set_color(machine->palette, index, palette->save_pen[index]);
+		palette_entry_set_contrast(machine->palette, index, palette->save_bright[index]);
 	}
 }
 
@@ -611,14 +591,14 @@ static void allocate_palette(running_machine *machine, palette_private *palette)
 
 	/* determine the number of groups we need */
 	numgroups = 1;
-	if (machine->drv->video_attributes & VIDEO_HAS_SHADOWS)
+	if (machine->config->video_attributes & VIDEO_HAS_SHADOWS)
 		palette->shadow_group = numgroups++;
-	if (machine->drv->video_attributes & VIDEO_HAS_HIGHLIGHTS)
+	if (machine->config->video_attributes & VIDEO_HAS_HIGHLIGHTS)
 		palette->hilight_group = numgroups++;
-	assert_always(machine->drv->total_colors * numgroups <= 65536, "Error: palette has more than 65536 colors.");
+	assert_always(machine->config->total_colors * numgroups <= 65536, "Error: palette has more than 65536 colors.");
 
 	/* allocate a palette object containing all the colors and groups */
-	machine->palette = palette_alloc(machine->drv->total_colors, numgroups);
+	machine->palette = palette_alloc(machine->config->total_colors, numgroups);
 	assert_always(machine->palette != NULL, "Failed to allocate system palette");
 
 	/* configure the groups */
@@ -628,7 +608,7 @@ static void allocate_palette(running_machine *machine, palette_private *palette)
 		palette_group_set_contrast(machine->palette, palette->hilight_group, (float)PALETTE_DEFAULT_HIGHLIGHT_FACTOR);
 
 	/* set the initial colors to a standard rainbow */
-	for (index = 0; index < machine->drv->total_colors; index++)
+	for (index = 0; index < machine->config->total_colors; index++)
 		palette_entry_set_color(machine->palette, index, MAKE_RGB(pal1bit(index >> 0), pal1bit(index >> 1), pal1bit(index >> 2)));
 
 	/* switch off the color mode */
@@ -708,7 +688,7 @@ static void allocate_color_tables(running_machine *machine, palette_private *pal
 static void allocate_shadow_tables(running_machine *machine, palette_private *palette)
 {
 	/* if we have shadows, allocate shadow tables */
-	if (machine->drv->video_attributes & VIDEO_HAS_SHADOWS)
+	if (machine->config->video_attributes & VIDEO_HAS_SHADOWS)
 	{
 		pen_t *table = auto_malloc(65536 * sizeof(*table));
 		int i;
@@ -718,7 +698,7 @@ static void allocate_shadow_tables(running_machine *machine, palette_private *pa
 		{
 			palette->shadow_table[0].base = palette->shadow_table[2].base = table;
 			for (i = 0; i < 65536; i++)
-				table[i] = (i < machine->drv->total_colors) ? (i + machine->drv->total_colors) : i;
+				table[i] = (i < machine->config->total_colors) ? (i + machine->config->total_colors) : i;
 		}
 
 		/* RGB mode gets two 32k tables in slots 0 and 2 */
@@ -731,7 +711,7 @@ static void allocate_shadow_tables(running_machine *machine, palette_private *pa
 	}
 
 	/* if we have hilights, allocate shadow tables */
-	if (machine->drv->video_attributes & VIDEO_HAS_HIGHLIGHTS)
+	if (machine->config->video_attributes & VIDEO_HAS_HIGHLIGHTS)
 	{
 		pen_t *table = auto_malloc(65536 * sizeof(*table));
 		int i;
@@ -741,7 +721,7 @@ static void allocate_shadow_tables(running_machine *machine, palette_private *pa
 		{
 			palette->shadow_table[1].base = palette->shadow_table[3].base = table;
 			for (i = 0; i < 65536; i++)
-				table[i] = (i < machine->drv->total_colors) ? (i + 2 * machine->drv->total_colors) : i;
+				table[i] = (i < machine->config->total_colors) ? (i + 2 * machine->config->total_colors) : i;
 		}
 
 		/* RGB mode gets two 32k tables in slots 1 and 3 */
