@@ -44,6 +44,7 @@ struct _mame_file
 #ifdef DEBUG_COOKIE
 	UINT32			debug_cookie;					/* sanity checking for debugging */
 #endif
+	astring *		filename;						/* full filename */
 	core_file *		file;							/* core file pointer */
 	UINT32			openflags;						/* flags we used for the open */
 	char			hash[HASH_BUF_SIZE];			/* hash data for the file */
@@ -214,7 +215,6 @@ static file_error fopen_internal(core_options *opts, const char *searchpath, con
 {
 	file_error filerr = FILERR_NOT_FOUND;
 	path_iterator iterator;
-	astring *fullname;
 
 	/* can either have a hash or open for write, but not both */
 	if ((openflags & OPEN_FLAG_HAS_CRC) && (openflags & OPEN_FLAG_WRITE))
@@ -240,28 +240,27 @@ static file_error fopen_internal(core_options *opts, const char *searchpath, con
 	path_iterator_init(&iterator, opts, searchpath);
 
 	/* loop over paths */
-	fullname = astring_alloc();
-	while (path_iterator_get_next(&iterator, fullname))
+	(*file)->filename = astring_alloc();
+	while (path_iterator_get_next(&iterator, (*file)->filename))
 	{
 		/* compute the full pathname */
-		if (astring_len(fullname) > 0)
-			astring_catc(fullname, PATH_SEPARATOR);
-		astring_catc(fullname, filename);
+		if (astring_len((*file)->filename) > 0)
+			astring_catc((*file)->filename, PATH_SEPARATOR);
+		astring_catc((*file)->filename, filename);
 
 		/* attempt to open the file directly */
-		filerr = core_fopen(astring_c(fullname), openflags, &(*file)->file);
+		filerr = core_fopen(astring_c((*file)->filename), openflags, &(*file)->file);
 		if (filerr == FILERR_NONE)
 			break;
 
 		/* if we're opening for read-only we have other options */
 		if ((openflags & (OPEN_FLAG_READ | OPEN_FLAG_WRITE)) == OPEN_FLAG_READ)
 		{
-			filerr = fopen_attempt_zipped(fullname, crc, openflags, *file);
+			filerr = fopen_attempt_zipped((*file)->filename, crc, openflags, *file);
 			if (filerr == FILERR_NONE)
 				break;
 		}
 	}
-	astring_free(fullname);
 
 	/* handle errors and return */
 	if (filerr != FILERR_NONE)
@@ -379,10 +378,24 @@ void mame_fclose(mame_file *file)
 		core_fclose(file->file);
 	if (file->zipdata != NULL)
 		free(file->zipdata);
+	if (file->filename != NULL)
+		astring_free(file->filename);
 	free(file);
 }
 
 
+/*-------------------------------------------------
+    mame_fcompress - enable/disable streaming file
+    compression via zlib; level is 0 to disable
+    compression, or up to 9 for max compression
+-------------------------------------------------*/
+
+file_error mame_fcompress(mame_file *file, int level)
+{
+	return core_fcompress(file->file, level);
+}
+
+
 
 /***************************************************************************
     FILE POSITIONING
@@ -603,7 +616,6 @@ int CLIB_DECL mame_fprintf(mame_file *file, const char *fmt, ...)
     FILE ENUMERATION
 ***************************************************************************/
 
-
 /*-------------------------------------------------
     mame_openpath - open a search path (multiple
     directories) for iteration
@@ -701,6 +713,20 @@ core_file *mame_core_file(mame_file *file)
 }
 
 
+/*-------------------------------------------------
+    mame_file_full_name - return the full filename
+    for a given mame_file
+-------------------------------------------------*/
+
+const char *mame_file_full_name(mame_file *file)
+{
+	/* return a pointer to the string if we have one; otherwise, return NULL */
+	if (file->filename != NULL)
+		return astring_c(file->filename);
+	return NULL;
+}
+
+
 /*-------------------------------------------------
     mame_fhash - returns the hash for a file
 -------------------------------------------------*/
