@@ -22,7 +22,6 @@
 #include "mame.h"
 #include "emuopts.h"
 #include "profiler.h"
-#include "deprecat.h"
 
 
 
@@ -45,7 +44,6 @@
 #define INVALID_AXIS_VALUE		0x7fffffff
 
 
-
 /***************************************************************************
     TYPE DEFINITIONS
 ***************************************************************************/
@@ -61,7 +59,7 @@ struct _input_device_item
 	void *					internal;				/* internal callback pointer */
 	input_item_class		itemclass;				/* class of the item */
 	input_item_id			itemid;					/* originally specified item id */
-	item_get_state_cb		getstate;				/* get state callback */
+	item_get_state_func		getstate;				/* get state callback */
 	INT32					current;				/* current raw value */
 	INT32					memory;					/* "memory" value, to remember where we started during polling */
 	INT32					oncelatch;				/* latched "once" value, cleared after each read  */
@@ -83,6 +81,7 @@ struct _joystick_map
 /* a single input device */
 struct _input_device
 {
+	running_machine *		machine;				/* machine we are attached to */
 	astring *				name;					/* string name of device */
 	input_device_class		devclass;				/* class of this device */
 	int						devindex;				/* device index of this device */
@@ -316,6 +315,74 @@ static const code_string_table itemid_token_table[] =
 	{ ITEM_ID_START,         "START" },
 	{ ITEM_ID_SELECT,        "SELECT" },
 
+	/* Hats */
+	{ ITEM_ID_HAT1UP,        "HAT1UP" },
+	{ ITEM_ID_HAT1DOWN,      "HAT1DOWN" },
+	{ ITEM_ID_HAT1LEFT,      "HAT1LEFT" },
+	{ ITEM_ID_HAT1RIGHT,     "HAT1RIGHT" },
+	{ ITEM_ID_HAT2UP,        "HAT2UP" },
+	{ ITEM_ID_HAT2DOWN,      "HAT2DOWN" },
+	{ ITEM_ID_HAT2LEFT,      "HAT2LEFT" },
+	{ ITEM_ID_HAT2RIGHT,     "HAT2RIGHT" },
+	{ ITEM_ID_HAT3UP,        "HAT3UP" },
+	{ ITEM_ID_HAT3DOWN,      "HAT3DOWN" },
+	{ ITEM_ID_HAT3LEFT,      "HAT3LEFT" },
+	{ ITEM_ID_HAT3RIGHT,     "HAT3RIGHT" },
+	{ ITEM_ID_HAT4UP,        "HAT4UP" },
+	{ ITEM_ID_HAT4DOWN,      "HAT4DOWN" },
+	{ ITEM_ID_HAT4LEFT,      "HAT4LEFT" },
+	{ ITEM_ID_HAT4RIGHT,     "HAT4RIGHT" },
+
+	/* Additional IDs */
+	{ ITEM_ID_ADD_SWITCH1,   "ADDSW1" },
+	{ ITEM_ID_ADD_SWITCH2,   "ADDSW2" },
+	{ ITEM_ID_ADD_SWITCH3,   "ADDSW3" },
+	{ ITEM_ID_ADD_SWITCH4,	 "ADDSW4" },
+	{ ITEM_ID_ADD_SWITCH5,	 "ADDSW5" },
+	{ ITEM_ID_ADD_SWITCH6,   "ADDSW6" },
+	{ ITEM_ID_ADD_SWITCH7,   "ADDSW7" },
+	{ ITEM_ID_ADD_SWITCH8,   "ADDSW8" },
+	{ ITEM_ID_ADD_SWITCH9,   "ADDSW9" },
+	{ ITEM_ID_ADD_SWITCH10,  "ADDSW10" },
+	{ ITEM_ID_ADD_SWITCH11,  "ADDSW11" },
+	{ ITEM_ID_ADD_SWITCH12,  "ADDSW12" },
+	{ ITEM_ID_ADD_SWITCH13,  "ADDSW13" },
+	{ ITEM_ID_ADD_SWITCH14,  "ADDSW14" },
+	{ ITEM_ID_ADD_SWITCH15,  "ADDSW15" },
+	{ ITEM_ID_ADD_SWITCH16,  "ADDSW16" },
+	{ ITEM_ID_ADD_ABSOLUTE1, "ADDAXIS1" },
+	{ ITEM_ID_ADD_ABSOLUTE2, "ADDAXIS2" },
+	{ ITEM_ID_ADD_ABSOLUTE3, "ADDAXIS3" },
+	{ ITEM_ID_ADD_ABSOLUTE4, "ADDAXIS4" },
+	{ ITEM_ID_ADD_ABSOLUTE5, "ADDAXIS5" },
+	{ ITEM_ID_ADD_ABSOLUTE6, "ADDAXIS6" },
+	{ ITEM_ID_ADD_ABSOLUTE7, "ADDAXIS7" },
+	{ ITEM_ID_ADD_ABSOLUTE8, "ADDAXIS8" },
+	{ ITEM_ID_ADD_ABSOLUTE9, "ADDAXIS9" },
+	{ ITEM_ID_ADD_ABSOLUTE10,"ADDAXIS10" },
+	{ ITEM_ID_ADD_ABSOLUTE11,"ADDAXIS11" },
+	{ ITEM_ID_ADD_ABSOLUTE12,"ADDAXIS12" },
+	{ ITEM_ID_ADD_ABSOLUTE13,"ADDAXIS13" },
+	{ ITEM_ID_ADD_ABSOLUTE14,"ADDAXIS14" },
+	{ ITEM_ID_ADD_ABSOLUTE15,"ADDAXIS15" },
+	{ ITEM_ID_ADD_ABSOLUTE16,"ADDAXIS16" },
+	{ ITEM_ID_ADD_RELATIVE1, "ADDREL1" },
+	{ ITEM_ID_ADD_RELATIVE2, "ADDREL2" },
+	{ ITEM_ID_ADD_RELATIVE3, "ADDREL3" },
+	{ ITEM_ID_ADD_RELATIVE4, "ADDREL4" },
+	{ ITEM_ID_ADD_RELATIVE5, "ADDREL5" },
+	{ ITEM_ID_ADD_RELATIVE6, "ADDREL6" },
+	{ ITEM_ID_ADD_RELATIVE7, "ADDREL7" },
+	{ ITEM_ID_ADD_RELATIVE8, "ADDREL8" },
+	{ ITEM_ID_ADD_RELATIVE9, "ADDREL9" },
+	{ ITEM_ID_ADD_RELATIVE10,"ADDREL10" },
+	{ ITEM_ID_ADD_RELATIVE11,"ADDREL11" },
+	{ ITEM_ID_ADD_RELATIVE12,"ADDREL12" },
+	{ ITEM_ID_ADD_RELATIVE13,"ADDREL13" },
+	{ ITEM_ID_ADD_RELATIVE14,"ADDREL14" },
+	{ ITEM_ID_ADD_RELATIVE15,"ADDREL15" },
+	{ ITEM_ID_ADD_RELATIVE16,"ADDREL16" },
+
 	{ ~0,                    NULL }
 };
 
@@ -409,11 +476,11 @@ INLINE input_code device_item_to_code(input_device *device, input_item_id itemid
 INLINE input_item_class input_item_standard_class(input_device_class devclass, input_item_id itemid)
 {
 	/* most everything standard is a switch, apart from the axes */
-	if (itemid == ITEM_ID_OTHER_SWITCH || itemid < ITEM_ID_XAXIS || itemid > ITEM_ID_SLIDER2)
+	if (itemid == ITEM_ID_OTHER_SWITCH || itemid < ITEM_ID_XAXIS || (itemid > ITEM_ID_SLIDER2 && itemid < ITEM_ID_ADD_ABSOLUTE1))
 		return ITEM_CLASS_SWITCH;
 
 	/* standard mouse axes are relative */
-	else if (devclass == DEVICE_CLASS_MOUSE || itemid == ITEM_ID_OTHER_AXIS_RELATIVE)
+	else if (devclass == DEVICE_CLASS_MOUSE || itemid == ITEM_ID_OTHER_AXIS_RELATIVE || (itemid >= ITEM_ID_ADD_RELATIVE1 && itemid <= ITEM_ID_ADD_RELATIVE16))
 		return ITEM_CLASS_RELATIVE;
 
 	/* all other standard axes are absolute */
@@ -652,12 +719,12 @@ static void input_frame(running_machine *machine)
     input_device_add - add a new input device
 -------------------------------------------------*/
 
-input_device *input_device_add(input_device_class devclass, const char *name, void *internal)
+input_device *input_device_add(running_machine *machine, input_device_class devclass, const char *name, void *internal)
 {
 	input_device_list *devlist = &device_list[devclass];
 	input_device *device;
 
-	assert_always(mame_get_phase(Machine) == MAME_PHASE_INIT, "Can only call input_device_add at init time!");
+	assert_always(mame_get_phase(machine) == MAME_PHASE_INIT, "Can only call input_device_add at init time!");
 	assert(name != NULL);
 	assert(devclass != DEVICE_CLASS_INVALID && devclass < DEVICE_CLASS_MAXIMUM);
 
@@ -667,6 +734,7 @@ input_device *input_device_add(input_device_class devclass, const char *name, vo
 	memset(device, 0, sizeof(*device));
 
 	/* fill in the data */
+	device->machine = machine;
 	device->name = astring_cpyc(auto_astring_alloc(), name);
 	device->devclass = devclass;
 	device->devindex = devlist->count - 1;
@@ -689,11 +757,12 @@ input_device *input_device_add(input_device_class devclass, const char *name, vo
     input device
 -------------------------------------------------*/
 
-void input_device_item_add(input_device *device, const char *name, void *internal, input_item_id itemid, item_get_state_cb getstate)
+void input_device_item_add(input_device *device, const char *name, void *internal, input_item_id itemid, item_get_state_func getstate)
 {
 	input_device_item *item;
+	input_item_id itemid_std = itemid;
 
-	assert_always(mame_get_phase(Machine) == MAME_PHASE_INIT, "Can only call input_device_item_add at init time!");
+	assert_always(mame_get_phase(device->machine) == MAME_PHASE_INIT, "Can only call input_device_item_add at init time!");
 	assert(name != NULL);
 	assert(itemid > ITEM_ID_INVALID && itemid < ITEM_ID_MAXIMUM);
 	assert(getstate != NULL);
@@ -720,7 +789,7 @@ void input_device_item_add(input_device *device, const char *name, void *interna
 	item->name = astring_cpyc(auto_astring_alloc(), name);
 	item->token = NULL;
 	item->internal = internal;
-	item->itemclass = input_item_standard_class(device->devclass, itemid);
+	item->itemclass = input_item_standard_class(device->devclass, itemid_std);
 	item->itemid = itemid;
 	item->getstate = getstate;
 
@@ -868,6 +937,33 @@ int input_code_pressed_once(input_code code)
 }
 
 
+/*-------------------------------------------------
+    input_code_from_input_item_id - translates
+    an input_item_id to an input_code
+-------------------------------------------------*/
+
+input_code input_code_from_input_item_id(input_item_id itemid)
+{
+	input_device_class devclass;
+
+	/* iterate over device classes and devices */
+	for (devclass = DEVICE_CLASS_INVALID + 1; devclass < DEVICE_CLASS_MAXIMUM; devclass++)
+	{
+		input_device_list *devlist = &device_list[devclass];
+		int devnum;
+
+		/* iterate over devices within each class */
+		for (devnum = 0; devnum < devlist->count; devnum++)
+		{
+			input_device *device = &devlist->list[devnum];
+			if (device->item[itemid] != NULL)
+				return device_item_to_code(device, itemid);
+		}
+	}
+	return 0;
+}
+
+
 /*-------------------------------------------------
     input_code_poll_switches - poll for any input
 -------------------------------------------------*/
@@ -1160,7 +1256,7 @@ astring *input_code_to_token(astring *string, input_code code)
 	modifier = code_to_string(modifier_token_table, INPUT_CODE_MODIFIER(code));
 
 	/* determine the itemclass part; if we match the native class, we don't include this */
-	if (item == NULL || item->itemclass == INPUT_CODE_ITEMCLASS(code))
+	if (item != NULL && item->itemclass == INPUT_CODE_ITEMCLASS(code))
 		itemclass = "";
 	else
 		itemclass = code_to_string(itemclass_token_table, INPUT_CODE_ITEMCLASS(code));
@@ -1562,7 +1658,7 @@ static int joystick_map_parse(const char *mapstring, joystick_map *map)
 			for (colnum = 0; colnum < 9; colnum++)
 			{
 				/* if we're at the end of row, copy previous to the middle, then apply left/right symmetry */
-				if (*mapstring == 0 || *mapstring == '.')
+				if (colnum > 0 && (*mapstring == 0 || *mapstring == '.'))
 				{
 					int symmetric = (colnum >= 5);
 					UINT8 val = map->map[rownum][symmetric ? (8 - colnum) : (colnum - 1)];
