@@ -56,6 +56,14 @@
 #define INTERNAL_CODE(x)				(INPUT_CODE_INTERNAL | ((x) & 0xfff))
 #define INPUT_CODE_INVALID				STANDARD_CODE(INVALID, 0, INVALID, NONE, INVALID)
 
+/* maximum number of axis/buttons/hats with ITEM_IDs for use by osd layer */
+#define INPUT_MAX_AXIS					(8)
+#define INPUT_MAX_BUTTONS				(16)
+#define INPUT_MAX_HATS					(4)
+#define INPUT_MAX_ADD_SWITCH			(16)
+#define INPUT_MAX_ADD_ABSOLUTE			(16)
+#define INPUT_MAX_ADD_RELATIVE			(16)
+
 
 
 /***************************************************************************
@@ -246,6 +254,76 @@ enum _input_item_id
 	ITEM_ID_START,
 	ITEM_ID_SELECT,
 
+	/* Hats */
+	ITEM_ID_HAT1UP,
+	ITEM_ID_HAT1DOWN,
+	ITEM_ID_HAT1LEFT,
+	ITEM_ID_HAT1RIGHT,
+	ITEM_ID_HAT2UP,
+	ITEM_ID_HAT2DOWN,
+	ITEM_ID_HAT2LEFT,
+	ITEM_ID_HAT2RIGHT,
+	ITEM_ID_HAT3UP,
+	ITEM_ID_HAT3DOWN,
+	ITEM_ID_HAT3LEFT,
+	ITEM_ID_HAT3RIGHT,
+	ITEM_ID_HAT4UP,
+	ITEM_ID_HAT4DOWN,
+	ITEM_ID_HAT4LEFT,
+	ITEM_ID_HAT4RIGHT,
+
+	/* Additional IDs */
+	ITEM_ID_ADD_SWITCH1,
+	ITEM_ID_ADD_SWITCH2,
+	ITEM_ID_ADD_SWITCH3,
+	ITEM_ID_ADD_SWITCH4,
+	ITEM_ID_ADD_SWITCH5,
+	ITEM_ID_ADD_SWITCH6,
+	ITEM_ID_ADD_SWITCH7,
+	ITEM_ID_ADD_SWITCH8,
+	ITEM_ID_ADD_SWITCH9,
+	ITEM_ID_ADD_SWITCH10,
+	ITEM_ID_ADD_SWITCH11,
+	ITEM_ID_ADD_SWITCH12,
+	ITEM_ID_ADD_SWITCH13,
+	ITEM_ID_ADD_SWITCH14,
+	ITEM_ID_ADD_SWITCH15,
+	ITEM_ID_ADD_SWITCH16,
+
+	ITEM_ID_ADD_ABSOLUTE1,
+	ITEM_ID_ADD_ABSOLUTE2,
+	ITEM_ID_ADD_ABSOLUTE3,
+	ITEM_ID_ADD_ABSOLUTE4,
+	ITEM_ID_ADD_ABSOLUTE5,
+	ITEM_ID_ADD_ABSOLUTE6,
+	ITEM_ID_ADD_ABSOLUTE7,
+	ITEM_ID_ADD_ABSOLUTE8,
+	ITEM_ID_ADD_ABSOLUTE9,
+	ITEM_ID_ADD_ABSOLUTE10,
+	ITEM_ID_ADD_ABSOLUTE11,
+	ITEM_ID_ADD_ABSOLUTE12,
+	ITEM_ID_ADD_ABSOLUTE13,
+	ITEM_ID_ADD_ABSOLUTE14,
+	ITEM_ID_ADD_ABSOLUTE15,
+	ITEM_ID_ADD_ABSOLUTE16,
+
+	ITEM_ID_ADD_RELATIVE1,
+	ITEM_ID_ADD_RELATIVE2,
+	ITEM_ID_ADD_RELATIVE3,
+	ITEM_ID_ADD_RELATIVE4,
+	ITEM_ID_ADD_RELATIVE5,
+	ITEM_ID_ADD_RELATIVE6,
+	ITEM_ID_ADD_RELATIVE7,
+	ITEM_ID_ADD_RELATIVE8,
+	ITEM_ID_ADD_RELATIVE9,
+	ITEM_ID_ADD_RELATIVE10,
+	ITEM_ID_ADD_RELATIVE11,
+	ITEM_ID_ADD_RELATIVE12,
+	ITEM_ID_ADD_RELATIVE13,
+	ITEM_ID_ADD_RELATIVE14,
+	ITEM_ID_ADD_RELATIVE15,
+	ITEM_ID_ADD_RELATIVE16,
+
 	/* generic other IDs */
 	ITEM_ID_OTHER_SWITCH,
 	ITEM_ID_OTHER_AXIS_ABSOLUTE,
@@ -473,7 +551,7 @@ enum
 typedef UINT32 input_code;
 
 /* callback for getting the value of an item on a device */
-typedef INT32 (*item_get_state_cb)(void *device_internal, void *item_internal);
+typedef INT32 (*item_get_state_func)(void *device_internal, void *item_internal);
 
 /* (opaque) input device object */
 typedef struct _input_device input_device;
@@ -514,10 +592,10 @@ int input_device_set_joystick_map(int devindex, const char *mapstring);
 /* ----- OSD configuration and access ----- */
 
 /* add a new input device */
-input_device *input_device_add(input_device_class devclass, const char *name, void *internal);
+input_device *input_device_add(running_machine *machine, input_device_class devclass, const char *name, void *internal);
 
 /* add a new item to an input device */
-void input_device_item_add(input_device *device, const char *name, void *internal, input_item_id itemid, item_get_state_cb getstate);
+void input_device_item_add(input_device *device, const char *name, void *internal, input_item_id itemid, item_get_state_func getstate);
 
 
 
@@ -532,6 +610,9 @@ INT32 input_code_pressed(input_code code);
 /* same as above, but returns TRUE only on the first call after an off->on transition */
 INT32 input_code_pressed_once(input_code code);
 
+/* translates an input_item_id to an input_code */
+input_code input_code_from_input_item_id(input_item_id itemid);
+
 /* poll for any switch input, optionally resetting internal memory */
 input_code input_code_poll_switches(int reset);
 
