@@ -41,16 +41,17 @@ static struct {
 	int halted;
 	int carry;
 	UINT32 (* fetch)(UINT32 dsp);
-	void (* irq_callback)(void);
+	void (* irq_callback)(running_machine *machine);
 	void (* dma_callback)(UINT32, UINT32, int, int);
 } lsi810;
 
-static void (* dma_opcode[256])(void);
+typedef void (*opcode_handler)(running_machine *machine);
+#define OPCODE_HANDLER(name) void name(running_machine *machine)
+static opcode_handler dma_opcode[256];
 
-
-INLINE UINT32 FETCH(void)
+INLINE UINT32 FETCH(running_machine *machine)
 {
-	UINT32 r = intf->fetch(lsi810.dsp);
+	UINT32 r = intf->fetch(machine, lsi810.dsp);
 	lsi810.dsp += 4;
 	return r;
 }
@@ -66,52 +67,52 @@ static UINT32 sign_extend24(UINT32 val)
 }
 #endif
 
-static void dmaop_invalid(void)
+static OPCODE_HANDLER( dmaop_invalid )
 {
 	fatalerror("LSI53C810: Invalid SCRIPTS DMA opcode %08X at %08X", lsi810.dcmd, lsi810.dsp);
 }
 
-static void dmaop_move_memory(void)
+static OPCODE_HANDLER( dmaop_move_memory )
 {
-	UINT32 src = FETCH();
-	UINT32 dst = FETCH();
+	UINT32 src = FETCH(machine);
+	UINT32 dst = FETCH(machine);
 	int count;
 
 	count = lsi810.dcmd & 0xffffff;
 	if(intf->dma_callback != NULL) {
-		intf->dma_callback(src, dst, count, 1);
+		intf->dma_callback(machine, src, dst, count, 1);
 	}
 }
 
-static void dmaop_interrupt(void)
+static OPCODE_HANDLER( dmaop_interrupt )
 {
 	if(lsi810.dcmd & 0x100000) {
 		fatalerror("LSI53C810: INTFLY opcode not implemented");
 	}
-	lsi810.dsps = FETCH();
+	lsi810.dsps = FETCH(machine);
 
 	lsi810.istat |= 0x1;	/* DMA interrupt pending */
 	lsi810.dstat |= 0x4;	/* SIR (SCRIPTS Interrupt Instruction Received) */
 
 	if(intf->irq_callback != NULL) {
-		intf->irq_callback();
+		intf->irq_callback(machine, 1);
 	}
 	lsi810.dma_icount = 0;
 	lsi810.halted = 1;
 }
 
-static void dmaop_block_move(void)
+static OPCODE_HANDLER( dmaop_block_move )
 {
 	UINT32 address;
 	UINT32 count;
 	INT32 dsps;
 
-	address = FETCH();
+	address = FETCH(machine);
 	count = lsi810.dcmd & 0x00ffffff;
 
 	// normal indirect
 	if (lsi810.dcmd & 0x20000000)
-		address = intf->fetch(address);
+		address = intf->fetch(machine, address);
 
 	// table indirect
 	if (lsi810.dcmd & 0x10000000)
@@ -144,11 +145,11 @@ static void dmaop_block_move(void)
 	}
 }
 
-static void dmaop_select(void)
+static OPCODE_HANDLER( dmaop_select )
 {
 	UINT32 operand;
 
-	operand = FETCH();
+	operand = FETCH(machine);
 
 	if (lsi810.scntl0 & 0x01)
 	{
@@ -169,11 +170,11 @@ static void dmaop_select(void)
 	}
 }
 
-static void dmaop_wait_disconnect(void)
+static OPCODE_HANDLER( dmaop_wait_disconnect )
 {
 	UINT32 operand;
 
-	operand = FETCH();
+	operand = FETCH(machine);
 
 	if (lsi810.scntl0 & 0x01)
 	{
@@ -187,11 +188,11 @@ static void dmaop_wait_disconnect(void)
 	}
 }
 
-static void dmaop_wait_reselect(void)
+static OPCODE_HANDLER( dmaop_wait_reselect )
 {
 	UINT32 operand;
 
-	operand = FETCH();
+	operand = FETCH(machine);
 
 	if (lsi810.scntl0 & 0x01)
 	{
@@ -205,11 +206,11 @@ static void dmaop_wait_reselect(void)
 	}
 }
 
-static void dmaop_set(void)
+static OPCODE_HANDLER( dmaop_set )
 {
 	UINT32 operand;
 
-	operand = FETCH();
+	operand = FETCH(machine);
 
 	/* initiator mode */
 	if (lsi810.dcmd & 0x8)
@@ -234,11 +235,11 @@ static void dmaop_set(void)
 	}
 }
 
-static void dmaop_clear(void)
+static OPCODE_HANDLER( dmaop_clear )
 {
 	UINT32 operand;
 
-	operand = FETCH();
+	operand = FETCH(machine);
 
 	/* initiator mode */
 	if (lsi810.dcmd & 0x8)
@@ -263,17 +264,17 @@ static void dmaop_clear(void)
 	}
 }
 
-static void dmaop_move_from_sfbr(void)
+static OPCODE_HANDLER( dmaop_move_from_sfbr )
 {
 	fatalerror("LSI53C810: dmaop_move_from_sfbr not implemented in target mode");
 }
 
-static void dmaop_move_to_sfbr(void)
+static OPCODE_HANDLER( dmaop_move_to_sfbr )
 {
 	fatalerror("LSI53C810: dmaop_move_to_sfbr not implemented");
 }
 
-static void dmaop_read_modify_write(void)
+static OPCODE_HANDLER( dmaop_read_modify_write )
 {
 	fatalerror("LSI53C810: dmaop_read_modify_write not implemented");
 }
@@ -338,12 +339,12 @@ static int scripts_compute_branch(void)
 	return passed;
 }
 
-static UINT32 scripts_get_jump_dest(void)
+static UINT32 scripts_get_jump_dest(running_machine *machine)
 {
 	INT32 dsps;
 	UINT32 dest;
 
-	dsps = FETCH();
+	dsps = FETCH(machine);
 
 	/* relative or absolute addressing? */
 	if (lsi810.dcmd & 0x00800000)
@@ -356,7 +357,7 @@ static UINT32 scripts_get_jump_dest(void)
 
 		logerror("dsps = %x, dsp = %x\n", dsps, lsi810.dsp);
 		dsps += lsi810.dsp;
-}
+	}
 
 	dest = (UINT32)dsps;
 
@@ -365,19 +366,19 @@ static UINT32 scripts_get_jump_dest(void)
 	return dest;
 }
 
-static void dmaop_jump(void)
+static OPCODE_HANDLER( dmaop_jump )
 {
 	if (scripts_compute_branch())
 {
-		lsi810.dsp = scripts_get_jump_dest();
+		lsi810.dsp = scripts_get_jump_dest(machine);
 	}
 	else
 	{
-		FETCH();	// skip operand to continue on
+		FETCH(machine);	// skip operand to continue on
 	}
 }
 
-static void dmaop_call(void)
+static OPCODE_HANDLER( dmaop_call )
 {
 	if (scripts_compute_branch())
 	{
@@ -385,15 +386,15 @@ static void dmaop_call(void)
 		lsi810.temp = lsi810.dsp;
 
 		// and go
-		lsi810.dsp = scripts_get_jump_dest();
+		lsi810.dsp = scripts_get_jump_dest(machine);
 	}
 	else
 	{
-		FETCH();	// skip operand to continue on
+		FETCH(machine);	// skip operand to continue on
 	}
 }
 
-static void dmaop_return(void)
+static OPCODE_HANDLER( dmaop_return )
 {
 	// is this correct?  return only happens if the condition is true?
 	if (scripts_compute_branch())
@@ -403,23 +404,23 @@ static void dmaop_return(void)
 	}
 	else
 	{
-		FETCH();	// skip operand to continue on
+		FETCH(machine);	// skip operand to continue on
 	}
 }
 
-static void dmaop_store(void)
+static OPCODE_HANDLER( dmaop_store )
 {
 	fatalerror("LSI53C810: dmaop_store not implemented");
 }
 
-static void dmaop_load(void)
+static OPCODE_HANDLER( dmaop_load )
 {
 	fatalerror("LSI53C810: dmaop_load not implemented");
 }
 
 
 
-static void dma_exec(void)
+static void dma_exec(running_machine *machine)
 {
 	lsi810.dma_icount = DMA_MAX_ICOUNT;
 
@@ -430,23 +431,23 @@ static void dma_exec(void)
 		if (DASM_OPCODES)
 		{
 			char buf[256];
-			lsi53c810_dasm(buf, lsi810.dsp);
+			lsi53c810_dasm(machine, buf, lsi810.dsp);
 			logerror("0x%08X: %s\n", lsi810.dsp, buf);
 		}
 
-		lsi810.dcmd = FETCH();
+		lsi810.dcmd = FETCH(machine);
 
 		op = (lsi810.dcmd >> 24) & 0xff;
-		dma_opcode[op]();
+		dma_opcode[op](machine);
 
 		lsi810.dma_icount--;
 	}
 }
 
-UINT8 lsi53c810_reg_r(int reg)
+READ8_HANDLER( lsi53c810_reg_r )
 {
-	logerror("53c810: read reg %d:0x%x (PC=%x)\n", reg, reg, activecpu_get_pc());
-	switch(reg)
+	logerror("53c810: read reg %d:0x%x (PC=%x)\n", offset, offset, cpu_get_pc(space->cpu));
+	switch(offset)
 	{
 		case 0x00:		/* SCNTL0 */
 			return lsi810.scntl0;
@@ -477,6 +478,12 @@ UINT8 lsi53c810_reg_r(int reg)
 		case 0x13:		/* DSA [31-24] */
 			return (lsi810.dsa >> 24) & 0xff;
 		case 0x14:		/* ISTAT */
+			// clear the interrupt on service
+			if(intf->irq_callback != NULL)
+			{
+				intf->irq_callback(space->machine, 0);
+			}
+
 			return lsi810.istat;
 		case 0x2c:		/* DSP [7-0] */
 			return lsi810.dsp & 0xff;
@@ -490,7 +497,7 @@ UINT8 lsi53c810_reg_r(int reg)
 		case 0x35:
 		case 0x36:
 		case 0x37:
-			return lsi810.scratch_a[reg % 4];
+			return lsi810.scratch_a[offset % 4];
 		case 0x39:		/* DIEN */
 			return lsi810.dien;
 		case 0x3b:		/* DCNTL */
@@ -509,147 +516,147 @@ UINT8 lsi53c810_reg_r(int reg)
 		case 0x5d:
 		case 0x5e:
 		case 0x5f:
-			return lsi810.scratch_b[reg % 4];
+			return lsi810.scratch_b[offset % 4];
 
 		default:
-			fatalerror("LSI53C810: reg_r: Unknown reg %02X", reg);
+			fatalerror("LSI53C810: reg_r: Unknown reg %02X", offset);
 	}
 
 	return 0;
 }
 
-void lsi53c810_reg_w(int reg, UINT8 value)
+WRITE8_HANDLER( lsi53c810_reg_w )
 {
-	logerror("53c810: %02x to reg %d:0x%x (PC=%x)\n", value, reg, reg, activecpu_get_pc());
-	switch(reg)
+	logerror("53c810: %02x to reg %d:0x%x (PC=%x)\n", data, offset, offset, cpu_get_pc(space->cpu));
+	switch(offset)
 	{
 		case 0x00:		/* SCNTL0 */
-			lsi810.scntl0 = value;
+			lsi810.scntl0 = data;
 			break;
 		case 0x01:		/* SCNTL1 */
-			lsi810.scntl1 = value;
+			lsi810.scntl1 = data;
 			break;
 		case 0x02:		/* SCNTL2 */
-			lsi810.scntl2 = value;
+			lsi810.scntl2 = data;
 			break;
 		case 0x03:		/* SCNTL3 */
-			lsi810.scntl3 = value;
+			lsi810.scntl3 = data;
 			break;
 		case 0x04:		/* SCID */
-			lsi810.scid = value;
+			lsi810.scid = data;
 			break;
 		case 0x09:		/* SOCL */
-			lsi810.socl = value;
+			lsi810.socl = data;
 			break;
 		case 0x0d:		/* SSTAT0 */
-			lsi810.sstat0 = value;
+			lsi810.sstat0 = data;
 			break;
 		case 0x0e:		/* SSTAT1 */
-			lsi810.sstat1 = value;
+			lsi810.sstat1 = data;
 			break;
 		case 0x0f:		/* SSTAT2 */
-			lsi810.sstat2 = value;
+			lsi810.sstat2 = data;
 			break;
 		case 0x10:		/* DSA [7-0] */
 			lsi810.dsa &= 0xffffff00;
-			lsi810.dsa |= value;
+			lsi810.dsa |= data;
 			break;
 		case 0x11:		/* DSA [15-8] */
 			lsi810.dsa &= 0xffff00ff;
-			lsi810.dsa |= value << 8;
+			lsi810.dsa |= data << 8;
 			break;
 		case 0x12:		/* DSA [23-16] */
 			lsi810.dsa &= 0xff00ffff;
-			lsi810.dsa |= value << 16;
+			lsi810.dsa |= data << 16;
 			break;
 		case 0x13:		/* DSA [31-24] */
 			lsi810.dsa &= 0x00ffffff;
-			lsi810.dsa |= value << 24;
+			lsi810.dsa |= data << 24;
 			break;
 		case 0x14:		/* ISTAT */
-			lsi810.istat = value;
+			lsi810.istat = data;
 			break;
 		case 0x2c:		/* DSP [7-0] */
 			lsi810.dsp &= 0xffffff00;
-			lsi810.dsp |= value;
+			lsi810.dsp |= data;
 			break;
 		case 0x2d:		/* DSP [15-8] */
 			lsi810.dsp &= 0xffff00ff;
-			lsi810.dsp |= value << 8;
+			lsi810.dsp |= data << 8;
 			break;
 		case 0x2e:		/* DSP [23-16] */
 			lsi810.dsp &= 0xff00ffff;
-			lsi810.dsp |= value << 16;
+			lsi810.dsp |= data << 16;
 			break;
 		case 0x2f:		/* DSP [31-24] */
 			lsi810.dsp &= 0x00ffffff;
-			lsi810.dsp |= value << 24;
+			lsi810.dsp |= data << 24;
 			lsi810.halted = 0;
 			if((lsi810.dmode & 0x1) == 0 && !lsi810.halted) {
-				dma_exec();
+				dma_exec(space->machine);
 			}
 			break;
 		case 0x34:		/* SCRATCH A */
 		case 0x35:
 		case 0x36:
 		case 0x37:
-			lsi810.scratch_a[reg % 4] = value;
+			lsi810.scratch_a[offset % 4] = data;
 			break;
 		case 0x38:		/* DMODE */
-			lsi810.dmode = value;
+			lsi810.dmode = data;
 			break;
 		case 0x39:		/* DIEN */
-			lsi810.dien = value;
+			lsi810.dien = data;
 			break;
 		case 0x3b:		/* DCNTL */
-			lsi810.dcntl = value;
+			lsi810.dcntl = data;
 
 			if(lsi810.dcntl & 0x14 && !lsi810.halted)		/* single-step & start DMA */
 			{
 				int op;
-				lsi810.dcmd = FETCH();
+				lsi810.dcmd = FETCH(space->machine);
 				op = (lsi810.dcmd >> 24) & 0xff;
-				dma_opcode[op]();
+				dma_opcode[op](space->machine);
 
 				lsi810.istat |= 0x3;	/* DMA interrupt pending */
 				lsi810.dstat |= 0x8;	/* SSI (Single Step Interrupt) */
 				if(intf->irq_callback != NULL) {
-					intf->irq_callback();
+					intf->irq_callback(space->machine, 1);
 				}
 			}
 			else if(lsi810.dcntl & 0x04 && !lsi810.halted)	/* manual start DMA */
 			{
-				dma_exec();
+				dma_exec(space->machine);
 			}
 			break;
 		case 0x40:		/* SIEN0 */
-			lsi810.sien0 = value;
+			lsi810.sien0 = data;
 			break;
 		case 0x41:		/* SIEN1 */
-			lsi810.sien1 = value;
+			lsi810.sien1 = data;
 			break;
 		case 0x48:		/* STIME0 */
-			lsi810.stime0 = value;
+			lsi810.stime0 = data;
 			break;
 		case 0x4a:		/* RESPID */
-			lsi810.respid = value;
+			lsi810.respid = data;
 			break;
 		case 0x4d:		/* STEST1 */
-			lsi810.stest1 = value;
+			lsi810.stest1 = data;
 			break;
 		case 0x5c:		/* SCRATCH B */
 		case 0x5d:
 		case 0x5e:
 		case 0x5f:
-			lsi810.scratch_b[reg % 4] = value;
+			lsi810.scratch_b[offset % 4] = data;
 			break;
 
 		default:
-			fatalerror("LSI53C810: reg_w: Unknown reg %02X, %02X", reg, value);
+			fatalerror("LSI53C810: reg_w: Unknown reg %02X, %02X", offset, data);
 	}
 }
 
-static void add_opcode(UINT8 op, UINT8 mask, void (* handler)(void))
+static void add_opcode(UINT8 op, UINT8 mask, opcode_handler handler)
 {
 	int i;
 	for(i=0; i < 256; i++) {
@@ -659,7 +666,7 @@ static void add_opcode(UINT8 op, UINT8 mask, void (* handler)(void))
 	}
 }
 
-extern void lsi53c810_init(const struct LSI53C810interface *interface)
+void lsi53c810_init(running_machine *machine, const struct LSI53C810interface *interface)
 {
 	int i;
 
@@ -694,11 +701,11 @@ extern void lsi53c810_init(const struct LSI53C810interface *interface)
 	// try to open the devices
 	for (i = 0; i < interface->scsidevs->devs_present; i++)
 	{
-		SCSIAllocInstance( interface->scsidevs->devices[i].scsiClass, &devices[interface->scsidevs->devices[i].scsiID], interface->scsidevs->devices[i].diskID );
+		SCSIAllocInstance( machine, interface->scsidevs->devices[i].scsiClass, &devices[interface->scsidevs->devices[i].scsiID], interface->scsidevs->devices[i].diskregion );
 	}
 }
 
-extern void lsi53c810_exit(const struct LSI53C810interface *interface)
+void lsi53c810_exit(const struct LSI53C810interface *interface)
 {
 	int i;
 
@@ -753,16 +760,16 @@ void *lsi53c810_get_device(int id)
  *
  *************************************/
 
-static UINT32 lsi53c810_dasm_fetch(UINT32 pc)
+static UINT32 lsi53c810_dasm_fetch(running_machine *machine, UINT32 pc)
 {
-	return intf->fetch(pc);
+	return intf->fetch(machine, pc);
 }
 
-unsigned lsi53c810_dasm(char *buf, UINT32 pc)
+unsigned lsi53c810_dasm(running_machine *machine, char *buf, UINT32 pc)
 {
 	unsigned result = 0;
 	const char *op_mnemonic = NULL;
-	UINT32 op = lsi53c810_dasm_fetch(pc);
+	UINT32 op = lsi53c810_dasm_fetch(machine, pc);
 	UINT32 dest;
 	int i;
 
@@ -775,7 +782,7 @@ unsigned lsi53c810_dasm(char *buf, UINT32 pc)
 	if ((op & 0xF8000000) == 0x40000000)
 	{
 		/* SELECT */
-		dest = lsi53c810_dasm_fetch(pc + 4);
+		dest = lsi53c810_dasm_fetch(machine, pc + 4);
 
 		buf += sprintf(buf, "SELECT%s %d, 0x%08X",
 			(op & 0x01000000) ? " ATN" : "",
@@ -834,7 +841,7 @@ unsigned lsi53c810_dasm(char *buf, UINT32 pc)
 			case 0x98000000: op_mnemonic = "INT"; break;
 		}
 
-		dest = lsi53c810_dasm_fetch(pc + 4);
+		dest = lsi53c810_dasm_fetch(machine, pc + 4);
 
 		if (op & 0x00800000)
 		{
@@ -880,7 +887,7 @@ unsigned lsi53c810_dasm(char *buf, UINT32 pc)
 	else if ((op & 0xE0000000) == 0x00000000)
 	{
 		/* MOVE FROM */
-		dest = lsi53c810_dasm_fetch(pc + 4);
+		dest = lsi53c810_dasm_fetch(machine, pc + 4);
 
 		buf += sprintf(buf, "MOVE FROM 0x%08X, WHEN %s",
 			dest, phases[(op >> 24) & 0x07]);
@@ -890,7 +897,7 @@ unsigned lsi53c810_dasm(char *buf, UINT32 pc)
 	else if ((op & 0xE0000000) == 0x20000000)
 	{
 		/* MOVE PTR */
-		dest = lsi53c810_dasm_fetch(pc + 4);
+		dest = lsi53c810_dasm_fetch(machine, pc + 4);
 
 		buf += sprintf(buf, "MOVE 0x%08X, PTR 0x%08X, WHEN %s",
 			(op & 0x00FFFFFF), dest, phases[(op >> 24) & 0x07]);
