@@ -5,7 +5,6 @@
 **********************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "6821pia.h"
 
 
@@ -24,6 +23,7 @@
 typedef struct _pia6821 pia6821;
 struct _pia6821
 {
+	running_machine *machine;
 	const pia6821_interface *intf;
 
 	UINT8 in_a;
@@ -114,51 +114,52 @@ static pia6821 pias[MAX_PIA];
  *
  *************************************/
 
-void pia_config(int which, const pia6821_interface *intf)
+void pia_config(running_machine *machine, int which, const pia6821_interface *intf)
 {
 	pia6821 *p;
 
-	assert_always(mame_get_phase(Machine) == MAME_PHASE_INIT, "Can only call pia_config at init time!");
+	assert_always(mame_get_phase(machine) == MAME_PHASE_INIT, "Can only call pia_config at init time!");
 	assert_always((which >= 0) && (which < MAX_PIA), "pia_config called on an invalid PIA!");
 	assert_always(intf, "pia_config called with an invalid interface!");
 
 	p = &pias[which];
 	memset(p, 0, sizeof(pias[0]));
 
+	p->machine = machine;
 	p->intf = intf;
 
-	state_save_register_item("6821pia", which, p->in_a);
-	state_save_register_item("6821pia", which, p->in_ca1);
-	state_save_register_item("6821pia", which, p->in_ca2);
-	state_save_register_item("6821pia", which, p->out_a);
-	state_save_register_item("6821pia", which, p->out_ca2);
-	state_save_register_item("6821pia", which, p->port_a_z_mask);
-	state_save_register_item("6821pia", which, p->ddr_a);
-	state_save_register_item("6821pia", which, p->ctl_a);
-	state_save_register_item("6821pia", which, p->irq_a1);
-	state_save_register_item("6821pia", which, p->irq_a2);
-	state_save_register_item("6821pia", which, p->irq_a_state);
-	state_save_register_item("6821pia", which, p->in_b);
-	state_save_register_item("6821pia", which, p->in_cb1);
-	state_save_register_item("6821pia", which, p->in_cb2);
-	state_save_register_item("6821pia", which, p->out_b);
-	state_save_register_item("6821pia", which, p->out_cb2);
-	state_save_register_item("6821pia", which, p->last_out_cb2_z);
-	state_save_register_item("6821pia", which, p->ddr_b);
-	state_save_register_item("6821pia", which, p->ctl_b);
-	state_save_register_item("6821pia", which, p->irq_b1);
-	state_save_register_item("6821pia", which, p->irq_b2);
-	state_save_register_item("6821pia", which, p->irq_b_state);
-	state_save_register_item("6821pia", which, p->in_a_pushed);
-	state_save_register_item("6821pia", which, p->out_a_needs_pulled);
-	state_save_register_item("6821pia", which, p->in_ca1_pushed);
-	state_save_register_item("6821pia", which, p->in_ca2_pushed);
-	state_save_register_item("6821pia", which, p->out_ca2_needs_pulled);
-	state_save_register_item("6821pia", which, p->in_b_pushed);
-	state_save_register_item("6821pia", which, p->out_b_needs_pulled);
-	state_save_register_item("6821pia", which, p->in_cb1_pushed);
-	state_save_register_item("6821pia", which, p->in_cb2_pushed);
-	state_save_register_item("6821pia", which, p->out_cb2_needs_pulled);
+	state_save_register_item(machine, "6821pia", NULL, which, p->in_a);
+	state_save_register_item(machine, "6821pia", NULL, which, p->in_ca1);
+	state_save_register_item(machine, "6821pia", NULL, which, p->in_ca2);
+	state_save_register_item(machine, "6821pia", NULL, which, p->out_a);
+	state_save_register_item(machine, "6821pia", NULL, which, p->out_ca2);
+	state_save_register_item(machine, "6821pia", NULL, which, p->port_a_z_mask);
+	state_save_register_item(machine, "6821pia", NULL, which, p->ddr_a);
+	state_save_register_item(machine, "6821pia", NULL, which, p->ctl_a);
+	state_save_register_item(machine, "6821pia", NULL, which, p->irq_a1);
+	state_save_register_item(machine, "6821pia", NULL, which, p->irq_a2);
+	state_save_register_item(machine, "6821pia", NULL, which, p->irq_a_state);
+	state_save_register_item(machine, "6821pia", NULL, which, p->in_b);
+	state_save_register_item(machine, "6821pia", NULL, which, p->in_cb1);
+	state_save_register_item(machine, "6821pia", NULL, which, p->in_cb2);
+	state_save_register_item(machine, "6821pia", NULL, which, p->out_b);
+	state_save_register_item(machine, "6821pia", NULL, which, p->out_cb2);
+	state_save_register_item(machine, "6821pia", NULL, which, p->last_out_cb2_z);
+	state_save_register_item(machine, "6821pia", NULL, which, p->ddr_b);
+	state_save_register_item(machine, "6821pia", NULL, which, p->ctl_b);
+	state_save_register_item(machine, "6821pia", NULL, which, p->irq_b1);
+	state_save_register_item(machine, "6821pia", NULL, which, p->irq_b2);
+	state_save_register_item(machine, "6821pia", NULL, which, p->irq_b_state);
+	state_save_register_item(machine, "6821pia", NULL, which, p->in_a_pushed);
+	state_save_register_item(machine, "6821pia", NULL, which, p->out_a_needs_pulled);
+	state_save_register_item(machine, "6821pia", NULL, which, p->in_ca1_pushed);
+	state_save_register_item(machine, "6821pia", NULL, which, p->in_ca2_pushed);
+	state_save_register_item(machine, "6821pia", NULL, which, p->out_ca2_needs_pulled);
+	state_save_register_item(machine, "6821pia", NULL, which, p->in_b_pushed);
+	state_save_register_item(machine, "6821pia", NULL, which, p->out_b_needs_pulled);
+	state_save_register_item(machine, "6821pia", NULL, which, p->in_cb1_pushed);
+	state_save_register_item(machine, "6821pia", NULL, which, p->in_cb2_pushed);
+	state_save_register_item(machine, "6821pia", NULL, which, p->out_cb2_needs_pulled);
 }
 
 
@@ -176,12 +177,14 @@ void pia_reset(void)
 	/* zap each structure, preserving the interface and swizzle */
 	for (i = 0; i < MAX_PIA; i++)
 	{
+		running_machine *machine = pias[i].machine;
 		const pia6821_interface *intf = pias[i].intf;
 
 		if (intf == NULL)  continue;
 
 		memset(&pias[i], 0, sizeof(pias[i]));
 
+		pias[i].machine = machine;
 		pias[i].intf = intf;
 
 		/*
@@ -195,8 +198,8 @@ void pia_reset(void)
 		pias[i].in_ca2 = TRUE;
 
 		/* clear the IRQs */
-		if (intf->irq_a_func) (*intf->irq_a_func)(FALSE);
-		if (intf->irq_b_func) (*intf->irq_b_func)(FALSE);
+		if (intf->irq_a_func) (*intf->irq_a_func)(machine, FALSE);
+		if (intf->irq_b_func) (*intf->irq_b_func)(machine, FALSE);
 	}
 }
 
@@ -208,7 +211,7 @@ void pia_reset(void)
  *
  *************************************/
 
-static void update_interrupts(pia6821 *p)
+static void update_interrupts(running_machine *machine, pia6821 *p)
 {
 	int new_state;
 
@@ -219,7 +222,7 @@ static void update_interrupts(pia6821 *p)
 	{
 		p->irq_a_state = new_state;
 
-		if (p->intf->irq_a_func) (p->intf->irq_a_func)(p->irq_a_state);
+		if (p->intf->irq_a_func) (p->intf->irq_a_func)(machine, p->irq_a_state);
 	}
 
 	/* then do IRQ B */
@@ -229,7 +232,7 @@ static void update_interrupts(pia6821 *p)
 	{
 		p->irq_b_state = new_state;
 
-		if (p->intf->irq_b_func) (p->intf->irq_b_func)(p->irq_b_state);
+		if (p->intf->irq_b_func) (p->intf->irq_b_func)(machine, p->irq_b_state);
 	}
 }
 
@@ -241,15 +244,17 @@ static void update_interrupts(pia6821 *p)
  *
  *************************************/
 
-static UINT8 get_in_a_value(int which)
+static UINT8 get_in_a_value(running_machine *machine, int which)
 {
+	/* temporary hack until this is converted to a device */
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	pia6821 *p = &pias[which];
 	UINT8 port_a_data = 0;
 	UINT8 ret;
 
 	/* update the input */
 	if (p->intf->in_a_func)
-		port_a_data = p->intf->in_a_func(0);
+		port_a_data = p->intf->in_a_func(space, 0);
 	else
 	{
 		if (p->in_a_pushed)
@@ -261,7 +266,7 @@ static UINT8 get_in_a_value(int which)
 
 			if (!p->logged_port_a_not_connected && (p->ddr_a != 0xff))
 			{
-				logerror("cpu #%d (PC=%08X): PIA #%d: Warning! No port A read handler. Assuming pins 0x%02X not connected\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, p->ddr_a ^ 0xff);
+				logerror("PIA #%d: Warning! No port A read handler. Assuming pins 0x%02X not connected\n", which, p->ddr_a ^ 0xff);
 				p->logged_port_a_not_connected = TRUE;
 			}
 		}
@@ -278,8 +283,10 @@ static UINT8 get_in_a_value(int which)
 }
 
 
-static UINT8 get_in_b_value(int which)
+static UINT8 get_in_b_value(running_machine *machine, int which)
 {
+	/* temporary hack until this is converted to a device */
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	pia6821 *p = &pias[which];
 	UINT8 ret;
 
@@ -292,7 +299,7 @@ static UINT8 get_in_b_value(int which)
 
 		/* update the input */
 		if (p->intf->in_b_func)
-			port_b_data = p->intf->in_b_func(0);
+			port_b_data = p->intf->in_b_func(space, 0);
 		else
 		{
 			if (p->in_b_pushed)
@@ -301,7 +308,7 @@ static UINT8 get_in_b_value(int which)
 			{
 				if (!p->logged_port_b_not_connected && (p->ddr_b != 0xff))
 				{
-					logerror("cpu #%d (PC=%08X): PIA #%d: Error! No port B read handler. Three-state pins 0x%02X are undefined\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, p->ddr_b ^ 0xff);
+					logerror("PIA #%d: Error! No port B read handler. Three-state pins 0x%02X are undefined\n", which, p->ddr_b ^ 0xff);
 					p->logged_port_b_not_connected = TRUE;
 				}
 
@@ -325,7 +332,7 @@ static UINT8 get_in_b_value(int which)
  *
  *************************************/
 
-static UINT8 get_out_a_value(int which)
+static UINT8 get_out_a_value(running_machine *machine, int which)
 {
 	UINT8 ret;
 	pia6821 *p = &pias[which];
@@ -335,7 +342,7 @@ static UINT8 get_out_a_value(int which)
 		ret = p->out_a;
 	else
 		/* input pins don't change */
-		ret = (p->out_a & p->ddr_a) | (get_in_a_value(which) & ~p->ddr_a);
+		ret = (p->out_a & p->ddr_a) | (get_in_a_value(machine, which) & ~p->ddr_a);
 
 	return ret;
 }
@@ -358,8 +365,10 @@ static UINT8 get_out_b_value(int which)
  *
  *************************************/
 
-static void set_out_ca2(int which, int data)
+static void set_out_ca2(running_machine *machine, int which, int data)
 {
+	/* temporary hack until this is converted to a device */
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	pia6821 *p = &pias[which];
 
 	if (data != p->out_ca2)
@@ -368,11 +377,11 @@ static void set_out_ca2(int which, int data)
 
 		/* send to output function */
 		if (p->intf->out_ca2_func)
-			p->intf->out_ca2_func(0, p->out_ca2);
+			p->intf->out_ca2_func(space, 0, p->out_ca2);
 		else
 		{
 			if (p->out_ca2_needs_pulled)
-				logerror("cpu #%d (PC=%08X): PIA #%d: Warning! No port CA2 write handler. Previous value has been lost!\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which);
+				logerror("PIA #%d: Warning! No port CA2 write handler. Previous value has been lost!\n", which);
 
 			p->out_ca2_needs_pulled = TRUE;
 		}
@@ -380,8 +389,10 @@ static void set_out_ca2(int which, int data)
 }
 
 
-static void set_out_cb2(int which, int data)
+static void set_out_cb2(running_machine *machine, int which, int data)
 {
+	/* temporary hack until this is converted to a device */
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	pia6821 *p = &pias[which];
 
 	int z = pia_get_output_cb2_z(which);
@@ -393,11 +404,11 @@ static void set_out_cb2(int which, int data)
 
 		/* send to output function */
 		if (p->intf->out_cb2_func)
-			p->intf->out_cb2_func(0, p->out_cb2);
+			p->intf->out_cb2_func(space, 0, p->out_cb2);
 		else
 		{
 			if (p->out_cb2_needs_pulled)
-				logerror("cpu #%d (PC=%08X): PIA #%d: Warning! No port CB2 write handler. Previous value has been lost!\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which);
+				logerror("PIA #%d: Warning! No port CB2 write handler. Previous value has been lost!\n", which);
 
 			p->out_cb2_needs_pulled = TRUE;
 		}
@@ -412,101 +423,103 @@ static void set_out_cb2(int which, int data)
  *
  *************************************/
 
-static UINT8 port_a_r(int which)
+static UINT8 port_a_r(running_machine *machine, int which)
 {
 	pia6821 *p = &pias[which];
 
-	UINT8 ret = get_in_a_value(which);
+	UINT8 ret = get_in_a_value(machine, which);
 
 	/* IRQ flags implicitly cleared by a read */
 	p->irq_a1 = FALSE;
 	p->irq_a2 = FALSE;
-	update_interrupts(p);
+	update_interrupts(machine, p);
 
 	/* CA2 is configured as output and in read strobe mode */
 	if (C2_OUTPUT(p->ctl_a) && C2_STROBE_MODE(p->ctl_a))
 	{
 		/* this will cause a transition low */
-		set_out_ca2(which, FALSE);
+		set_out_ca2(machine, which, FALSE);
 
 		/* if the CA2 strobe is cleared by the E, reset it right away */
 		if (STROBE_E_RESET(p->ctl_a))
-			set_out_ca2(which, TRUE);
+			set_out_ca2(machine, which, TRUE);
 	}
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: port A read = %02X\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, ret));
+	LOG(("PIA #%d: port A read = %02X\n", which, ret));
 
 	return ret;
 }
 
 
-static UINT8 ddr_a_r(int which)
+static UINT8 ddr_a_r(running_machine *machine, int which)
 {
 	pia6821 *p = &pias[which];
 
 	UINT8 ret = p->ddr_a;
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: DDR A read = %02X\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, ret));
+	LOG(("PIA #%d: DDR A read = %02X\n", which, ret));
 
 	return ret;
 }
 
 
-static UINT8 port_b_r(int which)
+static UINT8 port_b_r(running_machine *machine, int which)
 {
 	pia6821 *p = &pias[which];
 
-	UINT8 ret = get_in_b_value(which);
+	UINT8 ret = get_in_b_value(machine, which);
 
 	/* This read will implicitly clear the IRQ B1 flag.  If CB2 is in write-strobe
        mode with CB1 restore, and a CB1 active transition set the flag,
        clearing it will cause CB2 to go high again.  Note that this is different
        from what happens with port A. */
 	if (p->irq_b1 && C2_STROBE_MODE(p->ctl_b) && STROBE_C1_RESET(p->ctl_b))
-		set_out_cb2(which, TRUE);
+		set_out_cb2(machine, which, TRUE);
 
 	/* IRQ flags implicitly cleared by a read */
 	p->irq_b1 = FALSE;
 	p->irq_b2 = FALSE;
-	update_interrupts(p);
+	update_interrupts(machine, p);
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: port B read = %02X\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, ret));
+	LOG(("PIA #%d: port B read = %02X\n", which, ret));
 
 	return ret;
 }
 
 
-static UINT8 ddr_b_r(int which)
+static UINT8 ddr_b_r(running_machine *machine, int which)
 {
 	pia6821 *p = &pias[which];
 
 	UINT8 ret = p->ddr_b;
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: DDR B read = %02X\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, ret));
+	LOG(("PIA #%d: DDR B read = %02X\n", which, ret));
 
 	return ret;
 }
 
 
-static UINT8 control_a_r(int which)
+static UINT8 control_a_r(running_machine *machine, int which)
 {
+	/* temporary hack until this is converted to a device */
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	pia6821 *p = &pias[which];
 	UINT8 ret;
 
 	/* update CA1 & CA2 if callback exists, these in turn may update IRQ's */
 	if (p->intf->in_ca1_func)
-		pia_set_input_ca1(which, p->intf->in_ca1_func(0));
+		pia_set_input_ca1(which, p->intf->in_ca1_func(space, 0));
 	else if (!p->logged_ca1_not_connected && (!p->in_ca1_pushed))
 	{
-		logerror("cpu #%d (PC=%08X): PIA #%d: Warning! No CA1 read handler. Assuming pin not connected\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which);
+		logerror("PIA #%d: Warning! No CA1 read handler. Assuming pin not connected\n", which);
 		p->logged_ca1_not_connected = TRUE;
 	}
 
 	if (p->intf->in_ca2_func)
-		pia_set_input_ca2(which, p->intf->in_ca2_func(0));
+		pia_set_input_ca2(which, p->intf->in_ca2_func(space, 0));
 	else if ( !p->logged_ca2_not_connected && C2_INPUT(p->ctl_a) && !p->in_ca2_pushed)
 	{
-		logerror("cpu #%d (PC=%08X): PIA #%d: Warning! No CA2 read handler. Assuming pin not connected\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which);
+		logerror("PIA #%d: Warning! No CA2 read handler. Assuming pin not connected\n", which);
 		p->logged_ca2_not_connected = TRUE;
 	}
 
@@ -520,31 +533,33 @@ static UINT8 control_a_r(int which)
 	if (p->irq_a2 && C2_INPUT(p->ctl_a))
 		ret |= PIA_IRQ2;
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: control A read = %02X\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, ret));
+	LOG(("PIA #%d: control A read = %02X\n", which, ret));
 
 	return ret;
 }
 
 
-static UINT8 control_b_r(int which)
+static UINT8 control_b_r(running_machine *machine, int which)
 {
+	/* temporary hack until this is converted to a device */
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	pia6821 *p = &pias[which];
 	UINT8 ret;
 
 	/* update CB1 & CB2 if callback exists, these in turn may update IRQ's */
 	if (p->intf->in_cb1_func)
-		pia_set_input_cb1(which, p->intf->in_cb1_func(0));
+		pia_set_input_cb1(which, p->intf->in_cb1_func(space, 0));
 	else if (!p->logged_cb1_not_connected && !p->in_cb1_pushed)
 	{
-		logerror("cpu #%d (PC=%08X): PIA #%d: Error! no CB1 read handler. Three-state pin is undefined\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which);
+		logerror("PIA #%d: Error! no CB1 read handler. Three-state pin is undefined\n", which);
 		p->logged_cb1_not_connected = TRUE;
 	}
 
 	if (p->intf->in_cb2_func)
-		pia_set_input_cb2(which, p->intf->in_cb2_func(0));
+		pia_set_input_cb2(which, p->intf->in_cb2_func(space, 0));
 	else if (!p->logged_cb2_not_connected && C2_INPUT(p->ctl_b) && !p->in_cb2_pushed)
 	{
-		logerror("cpu #%d (PC=%08X): PIA #%d: Error! No CB2 read handler. Three-state pin is undefined\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which);
+		logerror("PIA #%d: Error! No CB2 read handler. Three-state pin is undefined\n", which);
 		p->logged_cb2_not_connected = TRUE;
 	}
 
@@ -558,7 +573,7 @@ static UINT8 control_b_r(int which)
 	if (p->irq_b2 && C2_INPUT(p->ctl_b))
 		ret |= PIA_IRQ2;
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: control B read = %02X\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, ret));
+	LOG(("PIA #%d: control B read = %02X\n", which, ret));
 
 	return ret;
 }
@@ -574,24 +589,24 @@ UINT8 pia_read(int which, offs_t offset)
 		default: /* impossible */
 		case 0x00:
 			if (OUTPUT_SELECTED(p->ctl_a))
-				ret = port_a_r(which);
+				ret = port_a_r(p->machine, which);
 			else
-				ret = ddr_a_r(which);
+				ret = ddr_a_r(p->machine, which);
 			break;
 
 		case 0x01:
-			ret = control_a_r(which);
+			ret = control_a_r(p->machine, which);
 			break;
 
 		case 0x02:
 			if (OUTPUT_SELECTED(p->ctl_b))
-				ret = port_b_r(which);
+				ret = port_b_r(p->machine, which);
 			else
-				ret = ddr_b_r(which);
+				ret = ddr_b_r(p->machine, which);
 			break;
 
 		case 0x03:
-			ret = control_b_r(which);
+			ret = control_b_r(p->machine, which);
 			break;
 	}
 
@@ -620,131 +635,135 @@ UINT8 pia_get_port_b_z_mask(int which)
  *
  *************************************/
 
-static void send_to_out_a_func(int which, const char* message)
+static void send_to_out_a_func(running_machine *machine, int which, const char* message)
 {
+	/* temporary hack until this is converted to a device */
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	pia6821 *p = &pias[which];
 
 	/* input pins are pulled high */
-	UINT8 data = get_out_a_value(which);
+	UINT8 data = get_out_a_value(machine, which);
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: %s = %02X\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, message, data));
+	LOG(("PIA #%d: %s = %02X\n", which, message, data));
 
 	if (p->intf->out_a_func)
-		p->intf->out_a_func(0, data);
+		p->intf->out_a_func(space, 0, data);
 	else
 	{
 		if (p->out_a_needs_pulled)
-			logerror("cpu #%d (PC=%08X): PIA #%d: Warning! No port A write handler. Previous value has been lost!\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which);
+			logerror("PIA #%d: Warning! No port A write handler. Previous value has been lost!\n", which);
 
 		p->out_a_needs_pulled = TRUE;
 	}
 }
 
 
-static void send_to_out_b_func(int which, const char* message)
+static void send_to_out_b_func(running_machine *machine, int which, const char* message)
 {
+	/* temporary hack until this is converted to a device */
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	pia6821 *p = &pias[which];
 
 	/* input pins are high-impedance - we just send them as zeros for backwards compatibility */
 	UINT8 data = get_out_b_value(which);
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: %s = %02X\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, message, data));
+	LOG(("PIA #%d: %s = %02X\n", which, message, data));
 
 	if (p->intf->out_b_func)
-		p->intf->out_b_func(0, data);
+		p->intf->out_b_func(space, 0, data);
 	else
 	{
 		if (p->out_b_needs_pulled)
-			logerror("cpu #%d (PC=%08X): PIA #%d: Warning! No port B write handler. Previous value has been lost!\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which);
+			logerror("PIA #%d: Warning! No port B write handler. Previous value has been lost!\n", which);
 
 		p->out_b_needs_pulled = TRUE;
 	}
 }
 
 
-static void port_a_w(int which, UINT8 data)
+static void port_a_w(running_machine *machine, int which, UINT8 data)
 {
 	pia6821 *p = &pias[which];
 
 	/* buffer the output value */
 	p->out_a = data;
 
-	send_to_out_a_func(which, "port A write");
+	send_to_out_a_func(machine, which, "port A write");
 }
 
 
-static void ddr_a_w(int which, UINT8 data)
+static void ddr_a_w(running_machine *machine, int which, UINT8 data)
 {
 	pia6821 *p = &pias[which];
 
 	if (data == 0x00)
-		LOG(("cpu #%d (PC=%08X): PIA #%d: DDR A write = %02X (input mode)\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+		LOG(("PIA #%d: DDR A write = %02X (input mode)\n", which, data));
 	else if (data == 0xff)
-		LOG(("cpu #%d (PC=%08X): PIA #%d: DDR A write = %02X (output mode)\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+		LOG(("PIA #%d: DDR A write = %02X (output mode)\n", which, data));
 	else
-		LOG(("cpu #%d (PC=%08X): PIA #%d: DDR A write = %02X (mixed mode)\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+		LOG(("PIA #%d: DDR A write = %02X (mixed mode)\n", which, data));
 
 	if (p->ddr_a != data)
 	{
 		/* DDR changed, call the callback again */
 		p->ddr_a = data;
 		p->logged_port_a_not_connected = FALSE;
-		send_to_out_a_func(which, "port A write due to DDR change");
+		send_to_out_a_func(machine, which, "port A write due to DDR change");
 	}
 }
 
 
-static void port_b_w(int which, UINT8 data)
+static void port_b_w(running_machine *machine, int which, UINT8 data)
 {
 	pia6821 *p = &pias[which];
 
 	/* buffer the output value */
 	p->out_b = data;
 
-	send_to_out_b_func(which, "port B write");
+	send_to_out_b_func(machine, which, "port B write");
 
 	/* CB2 in write strobe mode */
 	if (C2_STROBE_MODE(p->ctl_b))
 	{
 		/* this will cause a transition low */
-		set_out_cb2(which, FALSE);
+		set_out_cb2(machine, which, FALSE);
 
 		/* if the CB2 strobe is cleared by the E, reset it right away */
 		if (STROBE_E_RESET(p->ctl_b))
-			set_out_cb2(which, TRUE);
+			set_out_cb2(machine, which, TRUE);
 	}
 }
 
 
-static void ddr_b_w(int which, UINT8 data)
+static void ddr_b_w(running_machine *machine, int which, UINT8 data)
 {
 	pia6821 *p = &pias[which];
 
 	if (data == 0x00)
-		LOG(("cpu #%d (PC=%08X): PIA #%d: DDR B write = %02X (input mode)\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+		LOG(("PIA #%d: DDR B write = %02X (input mode)\n", which, data));
 	else if (data == 0xff)
-		LOG(("cpu #%d (PC=%08X): PIA #%d: DDR B write = %02X (output mode)\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+		LOG(("PIA #%d: DDR B write = %02X (output mode)\n", which, data));
 	else
-		LOG(("cpu #%d (PC=%08X): PIA #%d: DDR B write = %02X (mixed mode)\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+		LOG(("PIA #%d: DDR B write = %02X (mixed mode)\n", which, data));
 
 	if (p->ddr_b != data)
 	{
 		/* DDR changed, call the callback again */
 		p->ddr_b = data;
 		p->logged_port_b_not_connected = FALSE;
-		send_to_out_b_func(which, "port B write due to DDR change");
+		send_to_out_b_func(machine, which, "port B write due to DDR change");
 	}
 }
 
 
-static void control_a_w(int which, UINT8 data)
+static void control_a_w(running_machine *machine, int which, UINT8 data)
 {
 	pia6821 *p = &pias[which];
 
 	/* bit 7 and 6 are read only */
 	data &= 0x3f;
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: control A write = %02X\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+	LOG(("PIA #%d: control A write = %02X\n", which, data));
 
 	/* update the control register */
 	p->ctl_a = data;
@@ -761,15 +780,15 @@ static void control_a_w(int which, UINT8 data)
 			/* strobe mode - output is always high unless strobed */
 			temp = TRUE;
 
-		set_out_ca2(which, temp);
+		set_out_ca2(machine, which, temp);
 	}
 
 	/* update externals */
-	update_interrupts(p);
+	update_interrupts(machine, p);
 }
 
 
-static void control_b_w(int which, UINT8 data)
+static void control_b_w(running_machine *machine, int which, UINT8 data)
 {
 	pia6821 *p = &pias[which];
 	int temp;
@@ -777,7 +796,7 @@ static void control_b_w(int which, UINT8 data)
 	/* bit 7 and 6 are read only */
 	data &= 0x3f;
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: control B write = %02X\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+	LOG(("PIA #%d: control B write = %02X\n", which, data));
 
 	/* update the control register */
 	p->ctl_b = data;
@@ -789,10 +808,10 @@ static void control_b_w(int which, UINT8 data)
 		/* strobe mode - output is always high unless strobed */
 		temp = TRUE;
 
-	set_out_cb2(which, temp);
+	set_out_cb2(machine, which, temp);
 
 	/* update externals */
-	update_interrupts(p);
+	update_interrupts(machine, p);
 }
 
 
@@ -805,24 +824,24 @@ void pia_write(int which, offs_t offset, UINT8 data)
 		default: /* impossible */
 		case 0x00:
 			if (OUTPUT_SELECTED(p->ctl_a))
-				port_a_w(which, data);
+				port_a_w(p->machine, which, data);
 			else
-				ddr_a_w(which, data);
+				ddr_a_w(p->machine, which, data);
 			break;
 
 		case 0x01:
-			control_a_w(which, data);
+			control_a_w(p->machine, which, data);
 			break;
 
 		case 0x02:
 			if (OUTPUT_SELECTED(p->ctl_b))
-				port_b_w(which, data);
+				port_b_w(p->machine, which, data);
 			else
-				ddr_b_w(which, data);
+				ddr_b_w(p->machine, which, data);
 			break;
 
 		case 0x03:
-			control_b_w(which, data);
+			control_b_w(p->machine, which, data);
 			break;
 	}
 }
@@ -863,7 +882,7 @@ void pia_set_input_a(int which, UINT8 data, UINT8 z_mask)
 
 	assert_always(p->intf->in_a_func == NULL, "pia_set_input_a() called when in_a_func implemented");
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: set input port A = %02X\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+	LOG(("PIA #%d: set input port A = %02X\n", which, data));
 
 	p->in_a = data;
 	p->port_a_z_mask = z_mask;
@@ -877,7 +896,7 @@ UINT8 pia_get_output_a(int which)
 
 	p->out_a_needs_pulled = FALSE;
 
-	return get_out_a_value(which);
+	return get_out_a_value(p->machine, which);
 }
 
 
@@ -903,23 +922,23 @@ void pia_set_input_ca1(int which, int data)
 	/* limit the data to 0 or 1 */
 	data = data ? TRUE : FALSE;
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: set input CA1 = %d\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+	LOG(("PIA #%d: set input CA1 = %d\n", which, data));
 
 	/* the new state has caused a transition */
 	if ((p->in_ca1 != data) &&
 		((data && C1_LOW_TO_HIGH(p->ctl_a)) || (!data && C1_HIGH_TO_LOW(p->ctl_a))))
 	{
-		LOG(("cpu #%d (PC=%08X): PIA #%d: CA1 triggering\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which));
+		LOG(("PIA #%d: CA1 triggering\n", which));
 
 		/* mark the IRQ */
 		p->irq_a1 = TRUE;
 
 		/* update externals */
-		update_interrupts(p);
+		update_interrupts(p->machine, p);
 
 		/* CA2 is configured as output and in read strobe mode and cleared by a CA1 transition */
 		if (C2_OUTPUT(p->ctl_a) && C2_STROBE_MODE(p->ctl_a) && STROBE_C1_RESET(p->ctl_a))
-			set_out_ca2(which, TRUE);
+			set_out_ca2(p->machine, which, TRUE);
 	}
 
 	/* set the new value for CA1 */
@@ -950,20 +969,20 @@ void pia_set_input_ca2(int which, int data)
 	/* limit the data to 0 or 1 */
 	data = data ? 1 : 0;
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: set input CA2 = %d\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+	LOG(("PIA #%d: set input CA2 = %d\n", which, data));
 
 	/* if input mode and the new state has caused a transition */
 	if (C2_INPUT(p->ctl_a) &&
 		(p->in_ca2 != data) &&
 		((data && C2_LOW_TO_HIGH(p->ctl_a)) || (!data && C2_HIGH_TO_LOW(p->ctl_a))))
 	{
-		LOG(("cpu #%d (PC=%08X): PIA #%d: CA2 triggering\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which));
+		LOG(("PIA #%d: CA2 triggering\n", which));
 
 		/* mark the IRQ */
 		p->irq_a2 = TRUE;
 
 		/* update externals */
-		update_interrupts(p);
+		update_interrupts(p->machine, p);
 	}
 
 	/* set the new value for CA2 */
@@ -981,6 +1000,19 @@ int pia_get_output_ca2(int which)
 	return p->out_ca2;
 }
 
+// Version of pia_get_output_ca2, which takes account of internal
+// pullup resistor
+int pia_get_output_ca2_z(int which)
+{
+	pia6821 *p = &pias[which];
+
+	p->out_ca2_needs_pulled = FALSE;
+
+	// If it's an output, output the bit, if it's an input, it's
+	// pulled up
+	return p->out_ca2 |
+	       C2_INPUT(p->ctl_a);
+}
 
 
 /*************************************
@@ -1003,7 +1035,7 @@ void pia_set_input_b(int which, UINT8 data)
 
 	assert_always(p->intf->in_b_func == NULL, "pia_set_input_b() called when in_b_func implemented");
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: set input port B = %02X\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+	LOG(("PIA #%d: set input port B = %02X\n", which, data));
 
 	p->in_b = data;
 	p->in_b_pushed = TRUE;
@@ -1043,19 +1075,19 @@ void pia_set_input_cb1(int which, int data)
 	/* limit the data to 0 or 1 */
 	data = data ? 1 : 0;
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: set input CB1 = %d\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+	LOG(("PIA #%d: set input CB1 = %d\n", which, data));
 
 	/* the new state has caused a transition */
 	if ((p->in_cb1 != data) &&
 		((data && C1_LOW_TO_HIGH(p->ctl_b)) || (!data && C1_HIGH_TO_LOW(p->ctl_b))))
 	{
-		LOG(("cpu #%d (PC=%08X): PIA #%d: CB1 triggering\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which));
+		LOG(("PIA #%d: CB1 triggering\n", which));
 
 		/* mark the IRQ */
 		p->irq_b1 = 1;
 
 		/* update externals */
-		update_interrupts(p);
+		update_interrupts(p->machine, p);
 
 		/* If CB2 is configured as a write-strobe output which is reset by a CB1
            transition, this reset will only happen when a read from port B implicitly
@@ -1091,20 +1123,20 @@ void pia_set_input_cb2(int which, int data)
 	/* limit the data to 0 or 1 */
 	data = data ? 1 : 0;
 
-	LOG(("cpu #%d (PC=%08X): PIA #%d: set input CB2 = %d\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which, data));
+	LOG(("PIA #%d: set input CB2 = %d\n", which, data));
 
 	/* if input mode and the new state has caused a transition */
 	if (C2_INPUT(p->ctl_b) &&
 		(p->in_cb2 != data) &&
 		((data && C2_LOW_TO_HIGH(p->ctl_b)) || (!data && C2_HIGH_TO_LOW(p->ctl_b))))
 	{
-		LOG(("cpu #%d (PC=%08X): PIA #%d: CB2 triggering\n", cpu_getactivecpu(), safe_activecpu_get_pc(), which));
+		LOG(("PIA #%d: CB2 triggering\n", which));
 
 		/* mark the IRQ */
 		p->irq_b2 = 1;
 
 		/* update externals */
-		update_interrupts(p);
+		update_interrupts(p->machine, p);
 	}
 
 	/* set the new value for CA2 */
@@ -1198,82 +1230,6 @@ WRITE8_HANDLER( pia_5_alt_w ) { pia_alt_write(5, offset, data); }
 WRITE8_HANDLER( pia_6_alt_w ) { pia_alt_write(6, offset, data); }
 WRITE8_HANDLER( pia_7_alt_w ) { pia_alt_write(7, offset, data); }
 
-/******************* Standard 16-bit CPU interfaces, D0-D7 *******************/
-
-READ16_HANDLER( pia_0_lsb_r ) { return pia_read(0, offset); }
-READ16_HANDLER( pia_1_lsb_r ) { return pia_read(1, offset); }
-READ16_HANDLER( pia_2_lsb_r ) { return pia_read(2, offset); }
-READ16_HANDLER( pia_3_lsb_r ) { return pia_read(3, offset); }
-READ16_HANDLER( pia_4_lsb_r ) { return pia_read(4, offset); }
-READ16_HANDLER( pia_5_lsb_r ) { return pia_read(5, offset); }
-READ16_HANDLER( pia_6_lsb_r ) { return pia_read(6, offset); }
-READ16_HANDLER( pia_7_lsb_r ) { return pia_read(7, offset); }
-
-WRITE16_HANDLER( pia_0_lsb_w ) { if (ACCESSING_LSB) pia_write(0, offset, data); }
-WRITE16_HANDLER( pia_1_lsb_w ) { if (ACCESSING_LSB) pia_write(1, offset, data); }
-WRITE16_HANDLER( pia_2_lsb_w ) { if (ACCESSING_LSB) pia_write(2, offset, data); }
-WRITE16_HANDLER( pia_3_lsb_w ) { if (ACCESSING_LSB) pia_write(3, offset, data); }
-WRITE16_HANDLER( pia_4_lsb_w ) { if (ACCESSING_LSB) pia_write(4, offset, data); }
-WRITE16_HANDLER( pia_5_lsb_w ) { if (ACCESSING_LSB) pia_write(5, offset, data); }
-WRITE16_HANDLER( pia_6_lsb_w ) { if (ACCESSING_LSB) pia_write(6, offset, data); }
-WRITE16_HANDLER( pia_7_lsb_w ) { if (ACCESSING_LSB) pia_write(7, offset, data); }
-
-READ16_HANDLER( pia_0_lsb_alt_r ) { return pia_alt_read(0, offset); }
-READ16_HANDLER( pia_1_lsb_alt_r ) { return pia_alt_read(1, offset); }
-READ16_HANDLER( pia_2_lsb_alt_r ) { return pia_alt_read(2, offset); }
-READ16_HANDLER( pia_3_lsb_alt_r ) { return pia_alt_read(3, offset); }
-READ16_HANDLER( pia_4_lsb_alt_r ) { return pia_alt_read(4, offset); }
-READ16_HANDLER( pia_5_lsb_alt_r ) { return pia_alt_read(5, offset); }
-READ16_HANDLER( pia_6_lsb_alt_r ) { return pia_alt_read(6, offset); }
-READ16_HANDLER( pia_7_lsb_alt_r ) { return pia_alt_read(7, offset); }
-
-WRITE16_HANDLER( pia_0_lsb_alt_w ) { if (ACCESSING_LSB) pia_alt_write(0, offset, data); }
-WRITE16_HANDLER( pia_1_lsb_alt_w ) { if (ACCESSING_LSB) pia_alt_write(1, offset, data); }
-WRITE16_HANDLER( pia_2_lsb_alt_w ) { if (ACCESSING_LSB) pia_alt_write(2, offset, data); }
-WRITE16_HANDLER( pia_3_lsb_alt_w ) { if (ACCESSING_LSB) pia_alt_write(3, offset, data); }
-WRITE16_HANDLER( pia_4_lsb_alt_w ) { if (ACCESSING_LSB) pia_alt_write(4, offset, data); }
-WRITE16_HANDLER( pia_5_lsb_alt_w ) { if (ACCESSING_LSB) pia_alt_write(5, offset, data); }
-WRITE16_HANDLER( pia_6_lsb_alt_w ) { if (ACCESSING_LSB) pia_alt_write(6, offset, data); }
-WRITE16_HANDLER( pia_7_lsb_alt_w ) { if (ACCESSING_LSB) pia_alt_write(7, offset, data); }
-
-/******************* Standard 16-bit CPU interfaces, D8-D15 *******************/
-
-READ16_HANDLER( pia_0_msb_r ) { return pia_read(0, offset) << 8; }
-READ16_HANDLER( pia_1_msb_r ) { return pia_read(1, offset) << 8; }
-READ16_HANDLER( pia_2_msb_r ) { return pia_read(2, offset) << 8; }
-READ16_HANDLER( pia_3_msb_r ) { return pia_read(3, offset) << 8; }
-READ16_HANDLER( pia_4_msb_r ) { return pia_read(4, offset) << 8; }
-READ16_HANDLER( pia_5_msb_r ) { return pia_read(5, offset) << 8; }
-READ16_HANDLER( pia_6_msb_r ) { return pia_read(6, offset) << 8; }
-READ16_HANDLER( pia_7_msb_r ) { return pia_read(7, offset) << 8; }
-
-WRITE16_HANDLER( pia_0_msb_w ) { if (ACCESSING_MSB) pia_write(0, offset, data >> 8); }
-WRITE16_HANDLER( pia_1_msb_w ) { if (ACCESSING_MSB) pia_write(1, offset, data >> 8); }
-WRITE16_HANDLER( pia_2_msb_w ) { if (ACCESSING_MSB) pia_write(2, offset, data >> 8); }
-WRITE16_HANDLER( pia_3_msb_w ) { if (ACCESSING_MSB) pia_write(3, offset, data >> 8); }
-WRITE16_HANDLER( pia_4_msb_w ) { if (ACCESSING_MSB) pia_write(4, offset, data >> 8); }
-WRITE16_HANDLER( pia_5_msb_w ) { if (ACCESSING_MSB) pia_write(5, offset, data >> 8); }
-WRITE16_HANDLER( pia_6_msb_w ) { if (ACCESSING_MSB) pia_write(6, offset, data >> 8); }
-WRITE16_HANDLER( pia_7_msb_w ) { if (ACCESSING_MSB) pia_write(7, offset, data >> 8); }
-
-READ16_HANDLER( pia_0_msb_alt_r ) { return pia_alt_read(0, offset) << 8; }
-READ16_HANDLER( pia_1_msb_alt_r ) { return pia_alt_read(1, offset) << 8; }
-READ16_HANDLER( pia_2_msb_alt_r ) { return pia_alt_read(2, offset) << 8; }
-READ16_HANDLER( pia_3_msb_alt_r ) { return pia_alt_read(3, offset) << 8; }
-READ16_HANDLER( pia_4_msb_alt_r ) { return pia_alt_read(4, offset) << 8; }
-READ16_HANDLER( pia_5_msb_alt_r ) { return pia_alt_read(5, offset) << 8; }
-READ16_HANDLER( pia_6_msb_alt_r ) { return pia_alt_read(6, offset) << 8; }
-READ16_HANDLER( pia_7_msb_alt_r ) { return pia_alt_read(7, offset) << 8; }
-
-WRITE16_HANDLER( pia_0_msb_alt_w ) { if (ACCESSING_MSB) pia_alt_write(0, offset, data >> 8); }
-WRITE16_HANDLER( pia_1_msb_alt_w ) { if (ACCESSING_MSB) pia_alt_write(1, offset, data >> 8); }
-WRITE16_HANDLER( pia_2_msb_alt_w ) { if (ACCESSING_MSB) pia_alt_write(2, offset, data >> 8); }
-WRITE16_HANDLER( pia_3_msb_alt_w ) { if (ACCESSING_MSB) pia_alt_write(3, offset, data >> 8); }
-WRITE16_HANDLER( pia_4_msb_alt_w ) { if (ACCESSING_MSB) pia_alt_write(4, offset, data >> 8); }
-WRITE16_HANDLER( pia_5_msb_alt_w ) { if (ACCESSING_MSB) pia_alt_write(5, offset, data >> 8); }
-WRITE16_HANDLER( pia_6_msb_alt_w ) { if (ACCESSING_MSB) pia_alt_write(6, offset, data >> 8); }
-WRITE16_HANDLER( pia_7_msb_alt_w ) { if (ACCESSING_MSB) pia_alt_write(7, offset, data >> 8); }
-
 /******************* 8-bit A/B port interfaces *******************/
 
 WRITE8_HANDLER( pia_0_porta_w ) { pia_set_input_a(0, data, 0); }
