@@ -14,7 +14,6 @@
 #include "streams.h"
 #include "config.h"
 #include "profiler.h"
-#include "deprecat.h"
 #include "sound/wavwrite.h"
 
 
@@ -72,6 +71,7 @@ typedef struct _speaker_info speaker_info;
 struct _speaker_info
 {
 	const speaker_config *speaker;			/* pointer to the speaker info */
+	const char *	tag;					/* speaker tag */
 	sound_stream *	mixer_stream;			/* mixing stream */
 	int				inputs;					/* number of input streams */
 	speaker_input *	input;					/* array of input information */
@@ -93,9 +93,6 @@ static emu_timer *sound_update_timer;
 static int totalsnd;
 static sound_info sound[MAX_SOUND];
 
-static int totalspeakers;
-static speaker_info speaker[MAX_SPEAKER];
-
 static INT16 *finalmix;
 static UINT32 finalmix_leftover;
 static INT32 *leftmix, *rightmix;
@@ -116,13 +113,13 @@ static wav_file *wavfile;
 static void sound_reset(running_machine *machine);
 static void sound_exit(running_machine *machine);
 static void sound_pause(running_machine *machine, int pause);
-static void sound_load(int config_type, xml_data_node *parentnode);
-static void sound_save(int config_type, xml_data_node *parentnode);
+static void sound_load(running_machine *machine, int config_type, xml_data_node *parentnode);
+static void sound_save(running_machine *machine, int config_type, xml_data_node *parentnode);
 static TIMER_CALLBACK( sound_update );
-static void start_sound_chips(void);
-static void start_speakers(void);
-static void route_sound(void);
-static void mixer_update(void *param, stream_sample_t **inputs, stream_sample_t **buffer, int length);
+static void start_sound_chips(running_machine *machine);
+static void route_sound(running_machine *machine);
+static STREAM_UPDATE( mixer_update );
+static STATE_POSTLOAD( mixer_postload );
 
 
 
@@ -130,19 +127,29 @@ static void mixer_update(void *param, stream_sample_t **inputs, stream_sample_t
     INLINE FUNCTIONS
 ***************************************************************************/
 
+/*-------------------------------------------------
+    get_safe_token - makes sure that the passed
+    in device is, in fact, a timer
+-------------------------------------------------*/
+
+INLINE speaker_info *get_safe_token(const device_config *device)
+{
+	assert(device != NULL);
+	assert(device->token != NULL);
+	assert(device->type == SPEAKER_OUTPUT);
+
+	return (speaker_info *)device->token;
+}
+
+
 /*-------------------------------------------------
     find_speaker_by_tag - find a tagged speaker
 -------------------------------------------------*/
 
-INLINE speaker_info *find_speaker_by_tag(const char *tag)
+INLINE speaker_info *find_speaker_by_tag(running_machine *machine, const char *tag)
 {
-	int spknum;
-
-	/* attempt to find the speaker in our list */
-	for (spknum = 0; spknum < totalspeakers; spknum++)
-		if (strcmp(speaker[spknum].speaker->tag, tag) == 0)
-			return &speaker[spknum];
-	return NULL;
+	const device_config *speaker = device_list_find_by_tag(machine->config->devicelist, SPEAKER_OUTPUT, tag);
+	return (speaker == NULL) ? NULL : speaker->token;
 }
 
 
@@ -179,20 +186,19 @@ void sound_init(running_machine *machine)
 	/* handle -nosound */
 	nosound_mode = !options_get_bool(mame_options(), OPTION_SOUND);
 	if (nosound_mode)
-		Machine->sample_rate = 11025;
+		machine->sample_rate = 11025;
 
 	/* count the speakers */
-	for (totalspeakers = 0; Machine->drv->speaker[totalspeakers].tag; totalspeakers++) ;
-	VPRINTF(("total speakers = %d\n", totalspeakers));
+	VPRINTF(("total speakers = %d\n", speaker_output_count(machine->config)));
 
 	/* allocate memory for mix buffers */
-	leftmix = auto_malloc(Machine->sample_rate * sizeof(*leftmix));
-	rightmix = auto_malloc(Machine->sample_rate * sizeof(*rightmix));
-	finalmix = auto_malloc(Machine->sample_rate * sizeof(*finalmix));
+	leftmix = auto_malloc(machine->sample_rate * sizeof(*leftmix));
+	rightmix = auto_malloc(machine->sample_rate * sizeof(*rightmix));
+	finalmix = auto_malloc(machine->sample_rate * sizeof(*finalmix));
 
 	/* allocate a global timer for sound timing */
-	sound_update_timer = timer_alloc(sound_update, NULL);
-	timer_adjust(sound_update_timer, update_frequency, 0, update_frequency);
+	sound_update_timer = timer_alloc(machine, sound_update, NULL);
+	timer_adjust_periodic(sound_update_timer, update_frequency, 0, update_frequency);
 
 	/* initialize the streams engine */
 	VPRINTF(("streams_init\n"));
@@ -200,15 +206,11 @@ void sound_init(running_machine *machine)
 
 	/* now start up the sound chips and tag their streams */
 	VPRINTF(("start_sound_chips\n"));
-	start_sound_chips();
-
-	/* then create all the speakers */
-	VPRINTF(("start_speakers\n"));
-	start_speakers();
+	start_sound_chips(machine);
 
 	/* finally, do all the routing */
 	VPRINTF(("route_sound\n"));
-	route_sound();
+	route_sound(machine);
 
 	/* open the output WAV file if specified */
 	filename = options_get_string(mame_options(), OPTION_WAVWRITE);
@@ -221,7 +223,7 @@ void sound_init(running_machine *machine)
 	sound_set_attenuation(options_get_int(mame_options(), OPTION_VOLUME));
 
 	/* register callbacks */
-	config_register("mixer", sound_load, sound_save);
+	config_register(machine, "mixer", sound_load, sound_save);
 	add_pause_callback(machine, sound_pause);
 	add_reset_callback(machine, sound_reset);
 	add_exit_callback(machine, sound_exit);
@@ -240,30 +242,14 @@ static void sound_exit(running_machine *machine)
 	if (wavfile != NULL)
 		wav_close(wavfile);
 
-#ifdef MAME_DEBUG
-{
-	int spknum;
-
-	/* log the maximum sample values for all speakers */
-	for (spknum = 0; spknum < totalspeakers; spknum++)
-		if (speaker[spknum].max_sample > 0)
-		{
-			speaker_info *spk = &speaker[spknum];
-			mame_printf_debug("Speaker \"%s\" - max = %d (gain *= %f) - %d%% samples clipped\n", spk->speaker->tag, spk->max_sample, 32767.0 / (spk->max_sample ? spk->max_sample : 1), (int)((double)spk->clipped_samples * 100.0 / spk->total_samples));
-		}
-}
-#endif /* MAME_DEBUG */
-
 	/* stop all the sound chips */
 	for (sndnum = 0; sndnum < MAX_SOUND; sndnum++)
-		if (Machine->drv->sound[sndnum].type != SOUND_DUMMY)
+		if (machine->config->sound[sndnum].type != SOUND_DUMMY)
 			sndintrf_exit_sound(sndnum);
 
 	/* reset variables */
-	totalspeakers = 0;
 	totalsnd = 0;
-	memset(&speaker, 0, sizeof(speaker));
-	memset(&sound, 0, sizeof(sound));
+	memset(sound, 0, sizeof(sound));
 }
 
 
@@ -277,7 +263,7 @@ static void sound_exit(running_machine *machine)
     and initialize them
 -------------------------------------------------*/
 
-static void start_sound_chips(void)
+static void start_sound_chips(running_machine *machine)
 {
 	int sndnum;
 
@@ -287,7 +273,7 @@ static void start_sound_chips(void)
 	/* start up all the sound chips */
 	for (sndnum = 0; sndnum < MAX_SOUND; sndnum++)
 	{
-		const sound_config *msound = &Machine->drv->sound[sndnum];
+		const sound_config *msound = &machine->config->sound[sndnum];
 		sound_info *info;
 		int num_regs;
 		int index;
@@ -306,25 +292,25 @@ static void start_sound_chips(void)
 
 		/* start the chip, tagging all its streams */
 		VPRINTF(("sndnum = %d -- sound_type = %d\n", sndnum, msound->type));
-		num_regs = state_save_get_reg_count();
-		streams_set_tag(Machine, info);
-		if (sndintrf_init_sound(sndnum, msound->type, msound->clock, msound->config) != 0)
-			fatalerror("Sound chip #%d (%s) failed to initialize!", sndnum, sndnum_name(sndnum));
+		num_regs = state_save_get_reg_count(machine);
+		streams_set_tag(machine, info);
+		if (sndintrf_init_sound(machine, sndnum, msound->tag, msound->type, msound->clock, msound->config) != 0)
+			fatalerror("Sound chip #%d (%s) failed to initialize!", sndnum, sndnum_get_name(sndnum));
 
 		/* if no state registered for saving, we can't save */
-		num_regs = state_save_get_reg_count() - num_regs;
+		num_regs = state_save_get_reg_count(machine) - num_regs;
 		if (num_regs == 0)
 		{
-			logerror("Sound chip #%d (%s) did not register any state to save!\n", sndnum, sndnum_name(sndnum));
-			if (Machine->gamedrv->flags & GAME_SUPPORTS_SAVE)
-				fatalerror("Sound chip #%d (%s) did not register any state to save!", sndnum, sndnum_name(sndnum));
+			logerror("Sound chip #%d (%s) did not register any state to save!\n", sndnum, sndnum_get_name(sndnum));
+			if (machine->gamedrv->flags & GAME_SUPPORTS_SAVE)
+				fatalerror("Sound chip #%d (%s) did not register any state to save!", sndnum, sndnum_get_name(sndnum));
 		}
 
 		/* now count the outputs */
 		VPRINTF(("Counting outputs\n"));
 		for (index = 0; ; index++)
 		{
-			sound_stream *stream = stream_find_by_tag(info, index);
+			sound_stream *stream = stream_find_by_tag(machine, info, index);
 			if (!stream)
 				break;
 			info->outputs += stream_get_outputs(stream);
@@ -342,7 +328,7 @@ static void start_sound_chips(void)
 			info->outputs = 0;
 			for (index = 0; ; index++)
 			{
-				sound_stream *stream = stream_find_by_tag(info, index);
+				sound_stream *stream = stream_find_by_tag(machine, info, index);
 				int outputs, outputnum;
 
 				if (!stream)
@@ -362,46 +348,15 @@ static void start_sound_chips(void)
 }
 
 
-/*-------------------------------------------------
-    start_speakers - loop over all speakers and
-    initialize them
--------------------------------------------------*/
-
-static void start_speakers(void)
-{
-	/* reset the speaker array */
-	memset(speaker, 0, sizeof(speaker));
-
-	/* start up all the speakers */
-	for (totalspeakers = 0; totalspeakers < MAX_SPEAKER; totalspeakers++)
-	{
-		const speaker_config *mspeaker = &Machine->drv->speaker[totalspeakers];
-		speaker_info *info;
-
-		/* stop when we hit an empty entry */
-		if (mspeaker->tag == NULL)
-			break;
-
-		/* zap all the info */
-		info = &speaker[totalspeakers];
-		memset(info, 0, sizeof(*info));
-
-		/* copy in all the relevant info */
-		info->speaker = mspeaker;
-		info->mixer_stream = NULL;
-		info->inputs = 0;
-	}
-}
-
-
 /*-------------------------------------------------
     route_sound - route sound outputs to target
     inputs
 -------------------------------------------------*/
 
-static void route_sound(void)
+static void route_sound(running_machine *machine)
 {
-	int sndnum, spknum, routenum, outputnum;
+	int sndnum, routenum, outputnum;
+	const device_config *curspeak;
 
 	/* iterate over all the sound chips */
 	for (sndnum = 0; sndnum < totalsnd; sndnum++)
@@ -416,7 +371,7 @@ static void route_sound(void)
 			sound_info *sound;
 
 			/* find the target */
-			speaker = find_speaker_by_tag(mroute->target);
+			speaker = find_speaker_by_tag(machine, mroute->target);
 			sound = find_sound_by_tag(mroute->target);
 
 			/* if neither found, it's fatal */
@@ -435,18 +390,19 @@ static void route_sound(void)
 	}
 
 	/* now allocate the mixers and input data */
-	streams_set_tag(Machine, NULL);
-	for (spknum = 0; spknum < totalspeakers; spknum++)
+	streams_set_tag(machine, NULL);
+	for (curspeak = speaker_output_first(machine->config); curspeak != NULL; curspeak = speaker_output_next(curspeak))
 	{
-		speaker_info *info = &speaker[spknum];
+		speaker_info *info = curspeak->token;
 		if (info->inputs != 0)
 		{
-			info->mixer_stream = stream_create(info->inputs, 1, Machine->sample_rate, info, mixer_update);
+			info->mixer_stream = stream_create(curspeak, info->inputs, 1, machine->sample_rate, info, mixer_update);
+			state_save_register_postload(machine, mixer_postload, info->mixer_stream);
 			info->input = auto_malloc(info->inputs * sizeof(*info->input));
 			info->inputs = 0;
 		}
 		else
-			logerror("Warning: speaker \"%s\" has no inputs\n", info->speaker->tag);
+			logerror("Warning: speaker \"%s\" has no inputs\n", info->tag);
 	}
 
 	/* iterate again over all the sound chips */
@@ -462,7 +418,7 @@ static void route_sound(void)
 			sound_info *sound;
 
 			/* find the target */
-			speaker = find_speaker_by_tag(mroute->target);
+			speaker = find_speaker_by_tag(machine, mroute->target);
 			sound = find_sound_by_tag(mroute->target);
 
 			/* if it's a speaker, set the input */
@@ -480,11 +436,11 @@ static void route_sound(void)
                         namebuf[0] = '\0';
 
                         /* speaker name, if more than one speaker */
-						if (totalspeakers > 1)
-							sprintf(namebuf, "%sSpeaker '%s': ", namebuf, speaker->speaker->tag);
+						if (speaker_output_count(machine->config) > 1)
+							sprintf(namebuf, "%sSpeaker '%s': ", namebuf, speaker->tag);
 
                         /* device name */
-						sprintf(namebuf, "%s%s ", namebuf, sndnum_name(sndnum));
+						sprintf(namebuf, "%s%s ", namebuf, sndnum_get_name(sndnum));
 
 						/* device index, if more than one of this type */
 						if (sndtype_count(sndtype) > 1)
@@ -546,7 +502,7 @@ static void sound_reset(running_machine *machine)
 
 	/* reset all the sound chips */
 	for (sndnum = 0; sndnum < MAX_SOUND; sndnum++)
-		if (Machine->drv->sound[sndnum].type != SOUND_DUMMY)
+		if (machine->config->sound[sndnum].type != SOUND_DUMMY)
 			sndnum_reset(sndnum);
 }
 
@@ -622,7 +578,7 @@ void sound_global_enable(int enable)
     configuration file
 -------------------------------------------------*/
 
-static void sound_load(int config_type, xml_data_node *parentnode)
+static void sound_load(running_machine *machine, int config_type, xml_data_node *parentnode)
 {
 	xml_data_node *channelnode;
 	int mixernum;
@@ -643,8 +599,8 @@ static void sound_load(int config_type, xml_data_node *parentnode)
 		{
 			float defvol = xml_get_attribute_float(channelnode, "defvol", -1000.0);
 			float newvol = xml_get_attribute_float(channelnode, "newvol", -1000.0);
-			if (defvol == sound_get_default_gain(mixernum) && newvol != -1000.0)
-				sound_set_user_gain(mixernum, newvol);
+			if (fabs(defvol - sound_get_default_gain(machine, mixernum)) < 1e-6 && newvol != -1000.0)
+				sound_set_user_gain(machine, mixernum, newvol);
 		}
 	}
 }
@@ -655,7 +611,7 @@ static void sound_load(int config_type, xml_data_node *parentnode)
     file
 -------------------------------------------------*/
 
-static void sound_save(int config_type, xml_data_node *parentnode)
+static void sound_save(running_machine *machine, int config_type, xml_data_node *parentnode)
 {
 	int mixernum;
 
@@ -667,8 +623,8 @@ static void sound_save(int config_type, xml_data_node *parentnode)
 	if (parentnode != NULL)
 		for (mixernum = 0; mixernum < MAX_MIXER_CHANNELS; mixernum++)
 		{
-			float defvol = sound_get_default_gain(mixernum);
-			float newvol = sound_get_user_gain(mixernum);
+			float defvol = sound_get_default_gain(machine, mixernum);
+			float newvol = sound_get_user_gain(machine, mixernum);
 
 			if (defvol != newvol)
 			{
@@ -697,17 +653,18 @@ static void sound_save(int config_type, xml_data_node *parentnode)
 static TIMER_CALLBACK( sound_update )
 {
 	UINT32 finalmix_step, finalmix_offset;
+	const device_config *curspeak;
 	int samples_this_update = 0;
-	int sample, spknum;
+	int sample;
 
 	VPRINTF(("sound_update\n"));
 
 	profiler_mark(PROFILER_SOUND);
 
 	/* force all the speaker streams to generate the proper number of samples */
-	for (spknum = 0; spknum < totalspeakers; spknum++)
+	for (curspeak = speaker_output_first(machine->config); curspeak != NULL; curspeak = speaker_output_next(curspeak))
 	{
-		speaker_info *spk = &speaker[spknum];
+		speaker_info *spk = curspeak->token;
 		const stream_sample_t *stream_buf;
 
 		/* get the output buffer */
@@ -796,7 +753,8 @@ static TIMER_CALLBACK( sound_update )
 	/* play the result */
 	if (finalmix_offset > 0)
 	{
-		osd_update_audio_stream(finalmix, finalmix_offset / 2);
+		osd_update_audio_stream(machine, finalmix, finalmix_offset / 2);
+		video_avi_add_sound(machine, finalmix, finalmix_offset / 2);
 		if (wavfile != NULL)
 			wav_add_data_16(wavfile, finalmix, finalmix_offset);
 	}
@@ -812,16 +770,16 @@ static TIMER_CALLBACK( sound_update )
     mixer_update - mix all inputs to one output
 -------------------------------------------------*/
 
-static void mixer_update(void *param, stream_sample_t **inputs, stream_sample_t **buffer, int length)
+static STREAM_UPDATE( mixer_update )
 {
 	speaker_info *speaker = param;
 	int numinputs = speaker->inputs;
 	int pos;
 
-	VPRINTF(("Mixer_update(%d)\n", length));
+	VPRINTF(("Mixer_update(%d)\n", samples));
 
 	/* loop over samples */
-	for (pos = 0; pos < length; pos++)
+	for (pos = 0; pos < samples; pos++)
 	{
 		INT32 sample = inputs[0][pos];
 		int inp;
@@ -829,7 +787,102 @@ static void mixer_update(void *param, stream_sample_t **inputs, stream_sample_t
 		/* add up all the inputs */
 		for (inp = 1; inp < numinputs; inp++)
 			sample += inputs[inp][pos];
-		buffer[0][pos] = sample;
+		outputs[0][pos] = sample;
+	}
+}
+
+
+/*-------------------------------------------------
+    mixer_postload - postload function to reset
+    the mixer stream to the proper sample rate
+-------------------------------------------------*/
+
+static STATE_POSTLOAD( mixer_postload )
+{
+	sound_stream *stream = param;
+	stream_set_sample_rate(stream, machine->sample_rate);
+}
+
+
+
+/***************************************************************************
+    SPEAKER OUTPUT DEVICE INTERFACE
+***************************************************************************/
+
+/*-------------------------------------------------
+    speaker_output_start - device start callback
+    for a speaker
+-------------------------------------------------*/
+
+static DEVICE_START( speaker_output )
+{
+	speaker_info *info = device->token;
+
+	/* copy in all the relevant info */
+	info->speaker = device->inline_config;
+	info->tag = device->tag;
+
+	return DEVICE_START_OK;
+}
+
+
+/*-------------------------------------------------
+    speaker_output_stop - device stop callback
+    for a speaker
+-------------------------------------------------*/
+
+static DEVICE_STOP( speaker_output )
+{
+#ifdef MAME_DEBUG
+	speaker_info *info = device->token;
+
+	/* log the maximum sample values for all speakers */
+	if (info->max_sample > 0)
+		mame_printf_debug("Speaker \"%s\" - max = %d (gain *= %f) - %d%% samples clipped\n", info->tag, info->max_sample, 32767.0 / (info->max_sample ? info->max_sample : 1), (int)((double)info->clipped_samples * 100.0 / info->total_samples));
+#endif /* MAME_DEBUG */
+}
+
+
+/*-------------------------------------------------
+    speaker_output_set_info - device set info
+    callback
+-------------------------------------------------*/
+
+static DEVICE_SET_INFO( speaker_output )
+{
+	switch (state)
+	{
+		/* no parameters to set */
+	}
+}
+
+
+/*-------------------------------------------------
+    speaker_output_get_info - device get info
+    callback
+-------------------------------------------------*/
+
+DEVICE_GET_INFO( speaker_output )
+{
+	switch (state)
+	{
+		/* --- the following bits of info are returned as 64-bit signed integers --- */
+		case DEVINFO_INT_TOKEN_BYTES:					info->i = sizeof(speaker_info);			break;
+		case DEVINFO_INT_INLINE_CONFIG_BYTES:			info->i = sizeof(speaker_config);		break;
+		case DEVINFO_INT_CLASS:							info->i = DEVICE_CLASS_AUDIO;			break;
+
+		/* --- the following bits of info are returned as pointers to data or functions --- */
+		case DEVINFO_FCT_SET_INFO:						info->set_info = DEVICE_SET_INFO_NAME(speaker_output); break;
+		case DEVINFO_FCT_START:							info->start = DEVICE_START_NAME(speaker_output); break;
+		case DEVINFO_FCT_STOP:							info->stop = DEVICE_STOP_NAME(speaker_output); break;
+		case DEVINFO_FCT_RESET:							/* Nothing */							break;
+
+		/* --- the following bits of info are returned as NULL-terminated strings --- */
+		case DEVINFO_STR_NAME:							strcpy(info->s, "Speaker");				break;
+		case DEVINFO_STR_FAMILY:						strcpy(info->s, "Sound");				break;
+		case DEVINFO_STR_VERSION:						strcpy(info->s, "1.0");					break;
+		case DEVINFO_STR_SOURCE_FILE:					strcpy(info->s, __FILE__);				break;
+		case DEVINFO_STR_CREDITS:						strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
@@ -872,19 +925,21 @@ void sndti_set_output_gain(sound_type type, int index, int output, float gain)
     a particular input
 -------------------------------------------------*/
 
-INLINE speaker_info *index_to_input(int index, int *input)
+INLINE speaker_info *index_to_input(running_machine *machine, int index, int *input)
 {
-	int count = 0, speakernum;
+	const device_config *curspeak;
+	int count = 0;
 
 	/* scan through the speakers until we find the indexed input */
-	for (speakernum = 0; speakernum < totalspeakers; speakernum++)
+	for (curspeak = speaker_output_first(machine->config); curspeak != NULL; curspeak = speaker_output_next(curspeak))
 	{
-		if (index < count + speaker[speakernum].inputs)
+		speaker_info *info = curspeak->token;
+		if (index < count + info->inputs)
 		{
 			*input = index - count;
-			return &speaker[speakernum];
+			return info;
 		}
-		count += speaker[speakernum].inputs;
+		count += info->inputs;
 	}
 
 	/* index out of range */
@@ -897,13 +952,17 @@ INLINE speaker_info *index_to_input(int index, int *input)
     of user-controllable gain parameters
 -------------------------------------------------*/
 
-int sound_get_user_gain_count(void)
+int sound_get_user_gain_count(running_machine *machine)
 {
-	int count = 0, speakernum;
+	const device_config *curspeak;
+	int count = 0;
 
 	/* count up the number of speaker inputs */
-	for (speakernum = 0; speakernum < totalspeakers; speakernum++)
-		count += speaker[speakernum].inputs;
+	for (curspeak = speaker_output_first(machine->config); curspeak != NULL; curspeak = speaker_output_next(curspeak))
+	{
+		speaker_info *info = curspeak->token;
+		count += info->inputs;
+	}
 	return count;
 }
 
@@ -913,10 +972,10 @@ int sound_get_user_gain_count(void)
     value
 -------------------------------------------------*/
 
-void sound_set_user_gain(int index, float gain)
+void sound_set_user_gain(running_machine *machine, int index, float gain)
 {
 	int inputnum;
-	speaker_info *spk = index_to_input(index, &inputnum);
+	speaker_info *spk = index_to_input(machine, index, &inputnum);
 
 	if (spk != NULL)
 	{
@@ -931,10 +990,10 @@ void sound_set_user_gain(int index, float gain)
     value
 -------------------------------------------------*/
 
-float sound_get_user_gain(int index)
+float sound_get_user_gain(running_machine *machine, int index)
 {
 	int inputnum;
-	speaker_info *spk = index_to_input(index, &inputnum);
+	speaker_info *spk = index_to_input(machine, index, &inputnum);
 	return (spk != NULL) ? spk->input[inputnum].gain : 0;
 }
 
@@ -944,10 +1003,10 @@ float sound_get_user_gain(int index)
     gain of the nth user value
 -------------------------------------------------*/
 
-float sound_get_default_gain(int index)
+float sound_get_default_gain(running_machine *machine, int index)
 {
 	int inputnum;
-	speaker_info *spk = index_to_input(index, &inputnum);
+	speaker_info *spk = index_to_input(machine, index, &inputnum);
 	return (spk != NULL) ? spk->input[inputnum].default_gain : 0;
 }
 
@@ -957,10 +1016,10 @@ float sound_get_default_gain(int index)
     of the nth user value
 -------------------------------------------------*/
 
-const char *sound_get_user_gain_name(int index)
+const char *sound_get_user_gain_name(running_machine *machine, int index)
 {
 	int inputnum;
-	speaker_info *spk = index_to_input(index, &inputnum);
+	speaker_info *spk = index_to_input(machine, index, &inputnum);
 	return (spk != NULL) ? spk->input[inputnum].name : NULL;
 }
 
