@@ -11,6 +11,7 @@
 #include "sndintrf.h"
 #include "streams.h"
 #include "cpuintrf.h"
+#include "cpuexec.h"
 #include "es5506.h"
 
 
@@ -104,7 +105,7 @@ struct ES5506Chip
 	UINT32 		write_latch;			/* currently accumulated data for write */
 	UINT32 		read_latch;				/* currently accumulated data for read */
 	UINT32 		master_clock;			/* master clock frequency */
-	void 		(*irq_callback)(int);	/* IRQ callback */
+	void 		(*irq_callback)(running_machine *, int);	/* IRQ callback */
 	UINT16		(*port_read)(void);		/* input port read */
 
 	UINT8 		current_page;			/* current register page */
@@ -121,6 +122,7 @@ struct ES5506Chip
 
 	INT16 *		ulaw_lookup;
 	UINT16 *	volume_lookup;
+	const device_config *device;
 
 #if MAKE_WAVS
 	void *		wavraw;					/* raw waveform */
@@ -149,7 +151,7 @@ static void update_irq_state(struct ES5506Chip *chip)
 {
 	/* ES5505/6 irq line has been set high - inform the host */
 	if (chip->irq_callback)
-		(*chip->irq_callback)(1); /* IRQB set high */
+		(*chip->irq_callback)(chip->device->machine, 1); /* IRQB set high */
 }
 
 static void update_internal_irq_state(struct ES5506Chip *chip)
@@ -166,7 +168,7 @@ static void update_internal_irq_state(struct ES5506Chip *chip)
 	chip->irqv=0x80;
 
 	if (chip->irq_callback)
-		(*chip->irq_callback)(0); /* IRQB set low */
+		(*chip->irq_callback)(chip->device->machine, 0); /* IRQB set low */
 }
 
 /**********************************************************************************************
@@ -767,12 +769,12 @@ logerror("IRQ raised on voice %d!!\n",v);
 
 ***********************************************************************************************/
 
-static void es5506_update(void *param, stream_sample_t **inputs, stream_sample_t **buffer, int length)
+static STREAM_UPDATE( es5506_update )
 {
 	struct ES5506Chip *chip = param;
 	INT32 *lsrc = chip->scratch, *rsrc = chip->scratch;
-	stream_sample_t *ldest = buffer[0];
-	stream_sample_t *rdest = buffer[1];
+	stream_sample_t *ldest = outputs[0];
+	stream_sample_t *rdest = outputs[1];
 
 #if MAKE_WAVS
 	/* start the logging once we have a sample rate */
@@ -784,18 +786,18 @@ static void es5506_update(void *param, stream_sample_t **inputs, stream_sample_t
 #endif
 
 	/* loop until all samples are output */
-	while (length)
+	while (samples)
 	{
-		int samples = (length > MAX_SAMPLE_CHUNK) ? MAX_SAMPLE_CHUNK : length;
+		int length = (samples > MAX_SAMPLE_CHUNK) ? MAX_SAMPLE_CHUNK : samples;
 		int samp;
 
 		/* determine left/right source data */
 		lsrc = chip->scratch;
-		rsrc = chip->scratch + samples;
-		generate_samples(chip, lsrc, rsrc, samples);
+		rsrc = chip->scratch + length;
+		generate_samples(chip, lsrc, rsrc, length);
 
 		/* copy the data */
-		for (samp = 0; samp < samples; samp++)
+		for (samp = 0; samp < length; samp++)
 		{
 			*ldest++ = lsrc[samp] >> 4;
 			*rdest++ = rsrc[samp] >> 4;
@@ -804,24 +806,24 @@ static void es5506_update(void *param, stream_sample_t **inputs, stream_sample_t
 #if MAKE_WAVS
 		/* log the raw data */
 		if (chip->wavraw)
-			wav_add_data_32lr(chip->wavraw, lsrc, rsrc, samples, 4);
+			wav_add_data_32lr(chip->wavraw, lsrc, rsrc, length, 4);
 #endif
 
 		/* account for these samples */
-		length -= samples;
+		samples -= length;
 	}
 }
 
 
 /**********************************************************************************************
 
-     ES5506_sh_start -- start emulation of the ES5506
+     SND_START( es5506 ) -- start emulation of the ES5506
 
 ***********************************************************************************************/
 
-static void *es5506_start_common(sound_type sndtype, int sndindex, int clock, const void *config)
+static void *es5506_start_common(const device_config *device, int sndindex, int clock, const void *config, sound_type sndtype)
 {
-	const struct ES5506interface *intf = config;
+	const es5506_interface *intf = config;
 	struct ES5506Chip *chip;
 	int j;
 	UINT32 accum_mask;
@@ -838,15 +840,16 @@ static void *es5506_start_common(sound_type sndtype, int sndindex, int clock, co
 		return NULL;
 
 	/* create the stream */
-	chip->stream = stream_create(0, 2, clock / (16*32), chip, es5506_update);
+	chip->stream = stream_create(device, 0, 2, clock / (16*32), chip, es5506_update);
 
 	/* initialize the regions */
-	chip->region_base[0] = intf->region0 ? (UINT16 *)memory_region(intf->region0) : NULL;
-	chip->region_base[1] = intf->region1 ? (UINT16 *)memory_region(intf->region1) : NULL;
-	chip->region_base[2] = intf->region2 ? (UINT16 *)memory_region(intf->region2) : NULL;
-	chip->region_base[3] = intf->region3 ? (UINT16 *)memory_region(intf->region3) : NULL;
+	chip->region_base[0] = intf->region0 ? (UINT16 *)memory_region(device->machine, intf->region0) : NULL;
+	chip->region_base[1] = intf->region1 ? (UINT16 *)memory_region(device->machine, intf->region1) : NULL;
+	chip->region_base[2] = intf->region2 ? (UINT16 *)memory_region(device->machine, intf->region2) : NULL;
+	chip->region_base[3] = intf->region3 ? (UINT16 *)memory_region(device->machine, intf->region3) : NULL;
 
 	/* initialize the rest of the structure */
+	chip->device = device;
 	chip->master_clock = clock;
 	chip->irq_callback = intf->irq_callback;
 	chip->irqv = 0x80;
@@ -871,20 +874,20 @@ static void *es5506_start_common(sound_type sndtype, int sndindex, int clock, co
 }
 
 
-static void *es5506_start(int sndindex, int clock, const void *config)
+static SND_START( es5506 )
 {
-	return es5506_start_common(SOUND_ES5506, sndindex, clock, config);
+	return es5506_start_common(device, sndindex, clock, config, SOUND_ES5506);
 }
 
 
 
 /**********************************************************************************************
 
-     ES5506_stop -- stop emulation of the ES5506
+     SND_STOP( es5506 ) -- stop emulation of the ES5506
 
 ***********************************************************************************************/
 
-static void es5506_stop(void *chip)
+static SND_STOP( es5506 )
 {
 	/* debugging */
 	if (LOG_COMMANDS && eslog)
@@ -907,7 +910,7 @@ static void es5506_stop(void *chip)
 }
 
 
-static void es5506_reset(void *chip)
+static SND_RESET( es5506 )
 {
 }
 
@@ -1423,26 +1426,26 @@ static UINT8 es5506_reg_read(struct ES5506Chip *chip, offs_t offset)
 
 /**********************************************************************************************
 
-     ES5506_data_0_r/ES5506_data_1_r -- handle a read from the status register
+     es5506_data_0_r/es5506_data_1_r -- handle a read from the status register
 
 **********************************************************************************************/
 
-READ8_HANDLER( ES5506_data_0_r )
+READ8_HANDLER( es5506_data_0_r )
 {
 	return es5506_reg_read(sndti_token(SOUND_ES5506, 0), offset);
 }
 
-READ8_HANDLER( ES5506_data_1_r )
+READ8_HANDLER( es5506_data_1_r )
 {
 	return es5506_reg_read(sndti_token(SOUND_ES5506, 1), offset);
 }
 
-READ16_HANDLER( ES5506_data_0_word_r )
+READ16_HANDLER( es5506_data_0_word_r )
 {
 	return es5506_reg_read(sndti_token(SOUND_ES5506, 0), offset);
 }
 
-READ16_HANDLER( ES5506_data_1_word_r )
+READ16_HANDLER( es5506_data_1_word_r )
 {
 	return es5506_reg_read(sndti_token(SOUND_ES5506, 1), offset);
 }
@@ -1451,41 +1454,41 @@ READ16_HANDLER( ES5506_data_1_word_r )
 
 /**********************************************************************************************
 
-     ES5506_data_0_w/ES5506_data_1_w -- handle a write to the current register
+     es5506_data_0_w/es5506_data_1_w -- handle a write to the current register
 
 ***********************************************************************************************/
 
-WRITE8_HANDLER( ES5506_data_0_w )
+WRITE8_HANDLER( es5506_data_0_w )
 {
 	es5506_reg_write(sndti_token(SOUND_ES5506, 0), offset, data);
 }
 
-WRITE8_HANDLER( ES5506_data_1_w )
+WRITE8_HANDLER( es5506_data_1_w )
 {
 	es5506_reg_write(sndti_token(SOUND_ES5506, 1), offset, data);
 }
 
-WRITE16_HANDLER( ES5506_data_0_word_w )
+WRITE16_HANDLER( es5506_data_0_word_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 		es5506_reg_write(sndti_token(SOUND_ES5506, 0), offset, data);
 }
 
-WRITE16_HANDLER( ES5506_data_1_word_w )
+WRITE16_HANDLER( es5506_data_1_word_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 		es5506_reg_write(sndti_token(SOUND_ES5506, 1), offset, data);
 }
 
 
 
-void ES5506_voice_bank_0_w(int voice, int bank)
+void es5506_voice_bank_0_w(int voice, int bank)
 {
 	struct ES5506Chip *chip = sndti_token(SOUND_ES5506, 0);
 	chip->voice[voice].exbank=bank;
 }
 
-void ES5506_voice_bank_1_w(int voice, int bank)
+void es5506_voice_bank_1_w(int voice, int bank)
 {
 	struct ES5506Chip *chip = sndti_token(SOUND_ES5506, 1);
 	chip->voice[voice].exbank=bank;
@@ -1494,14 +1497,14 @@ void ES5506_voice_bank_1_w(int voice, int bank)
 
 /**********************************************************************************************
 
-     ES5505_start -- start emulation of the ES5505
+     SND_START( es5505 ) -- start emulation of the ES5505
 
 ***********************************************************************************************/
 
-static void *es5505_start(int sndindex, int clock, const void *config)
+static SND_START( es5505 )
 {
-	const struct ES5505interface *intf = config;
-	struct ES5506interface es5506intf;
+	const es5505_interface *intf = config;
+	es5506_interface es5506intf;
 
 	memset(&es5506intf, 0, sizeof(es5506intf));
 
@@ -1510,26 +1513,26 @@ static void *es5505_start(int sndindex, int clock, const void *config)
 	es5506intf.irq_callback = intf->irq_callback;
 	es5506intf.read_port = intf->read_port;
 
-	return es5506_start_common(SOUND_ES5505, sndindex, clock, &es5506intf);
+	return es5506_start_common(device, sndindex, clock, &es5506intf, SOUND_ES5505);
 }
 
 
 
 /**********************************************************************************************
 
-     ES5505_stop -- stop emulation of the ES5506
+     SND_STOP( es5505 ) -- stop emulation of the ES5505
 
 ***********************************************************************************************/
 
-static void es5505_stop(void *chip)
+static SND_STOP( es5505 )
 {
-	es5506_stop(chip);
+	SND_STOP_CALL( es5506 );
 }
 
 
-static void es5505_reset(void *chip)
+static SND_RESET( es5505 )
 {
-	es5506_reset(chip);
+	SND_RESET_CALL( es5506 );
 }
 
 
@@ -1542,10 +1545,12 @@ static void es5505_reset(void *chip)
 
 INLINE void es5505_reg_write_low(struct ES5506Chip *chip, struct ES5506Voice *voice, offs_t offset, UINT16 data, UINT16 mem_mask)
 {
+	running_machine *machine = chip->device->machine;
+
 	switch (offset)
 	{
 		case 0x00:	/* CR */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 			{
 #if RAINE_CHECK
 				voice->control &= ~(CONTROL_STOPMASK | CONTROL_LOOPMASK | CONTROL_DIR);
@@ -1555,7 +1560,7 @@ INLINE void es5505_reg_write_low(struct ES5506Chip *chip, struct ES5506Voice *vo
 				voice->control |= (data & (CONTROL_STOPMASK | CONTROL_LOOPMASK | CONTROL_IRQE | CONTROL_DIR | CONTROL_IRQ)) |
 								  ((data << 12) & CONTROL_BS0);
 			}
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 			{
 				voice->control &= ~(CONTROL_CA0 | CONTROL_CA1 | CONTROL_LPMASK);
 				voice->control |= ((data >> 2) & CONTROL_LPMASK) |
@@ -1563,115 +1568,115 @@ INLINE void es5505_reg_write_low(struct ES5506Chip *chip, struct ES5506Voice *vo
 			}
 
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, control=%04x (raw=%04x & %04x)\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->control, data, mem_mask ^ 0xffff);
+				fprintf(eslog, "%s:voice %d, control=%04x (raw=%04x & %04x)\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->control, data, mem_mask ^ 0xffff);
 			break;
 
 		case 0x01:	/* FC */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->freqcount = (voice->freqcount & ~0x001fe) | ((data & 0x00ff) << 1);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->freqcount = (voice->freqcount & ~0x1fe00) | ((data & 0xff00) << 1);
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, freq count=%08x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->freqcount);
+				fprintf(eslog, "%s:voice %d, freq count=%08x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->freqcount);
 			break;
 
 		case 0x02:	/* STRT (hi) */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->start = (voice->start & ~0x03fc0000) | ((data & 0x00ff) << 18);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->start = (voice->start & ~0x7c000000) | ((data & 0x1f00) << 18);
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, loop start=%08x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->start);
+				fprintf(eslog, "%s:voice %d, loop start=%08x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->start);
 			break;
 
 		case 0x03:	/* STRT (lo) */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->start = (voice->start & ~0x00000380) | ((data & 0x00e0) << 2);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->start = (voice->start & ~0x0003fc00) | ((data & 0xff00) << 2);
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, loop start=%08x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->start);
+				fprintf(eslog, "%s:voice %d, loop start=%08x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->start);
 			break;
 
 		case 0x04:	/* END (hi) */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->end = (voice->end & ~0x03fc0000) | ((data & 0x00ff) << 18);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->end = (voice->end & ~0x7c000000) | ((data & 0x1f00) << 18);
 #if RAINE_CHECK
 			voice->control |= CONTROL_STOP0;
 #endif
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, loop end=%08x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->end);
+				fprintf(eslog, "%s:voice %d, loop end=%08x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->end);
 			break;
 
 		case 0x05:	/* END (lo) */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->end = (voice->end & ~0x00000380) | ((data & 0x00e0) << 2);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->end = (voice->end & ~0x0003fc00) | ((data & 0xff00) << 2);
 #if RAINE_CHECK
 			voice->control |= CONTROL_STOP0;
 #endif
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, loop end=%08x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->end);
+				fprintf(eslog, "%s:voice %d, loop end=%08x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->end);
 			break;
 
 		case 0x06:	/* K2 */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->k2 = (voice->k2 & ~0x00f0) | (data & 0x00f0);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->k2 = (voice->k2 & ~0xff00) | (data & 0xff00);
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, K2=%04x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->k2);
+				fprintf(eslog, "%s:voice %d, K2=%04x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->k2);
 			break;
 
 		case 0x07:	/* K1 */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->k1 = (voice->k1 & ~0x00f0) | (data & 0x00f0);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->k1 = (voice->k1 & ~0xff00) | (data & 0xff00);
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, K1=%04x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->k1);
+				fprintf(eslog, "%s:voice %d, K1=%04x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->k1);
 			break;
 
 		case 0x08:	/* LVOL */
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->lvol = (voice->lvol & ~0xff00) | (data & 0xff00);
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, left vol=%04x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->lvol);
+				fprintf(eslog, "%s:voice %d, left vol=%04x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->lvol);
 			break;
 
 		case 0x09:	/* RVOL */
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->rvol = (voice->rvol & ~0xff00) | (data & 0xff00);
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, right vol=%04x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->rvol);
+				fprintf(eslog, "%s:voice %d, right vol=%04x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->rvol);
 			break;
 
 		case 0x0a:	/* ACC (hi) */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->accum = (voice->accum & ~0x03fc0000) | ((data & 0x00ff) << 18);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->accum = (voice->accum & ~0x7c000000) | ((data & 0x1f00) << 18);
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, accum=%08x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->accum);
+				fprintf(eslog, "%s:voice %d, accum=%08x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->accum);
 			break;
 
 		case 0x0b:	/* ACC (lo) */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->accum = (voice->accum & ~0x000003fc) | ((data & 0x00ff) << 2);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->accum = (voice->accum & ~0x0003fc00) | ((data & 0xff00) << 2);
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, accum=%08x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->accum);
+				fprintf(eslog, "%s:voice %d, accum=%08x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->accum);
 			break;
 
 		case 0x0c:	/* unused */
 			break;
 
 		case 0x0d:	/* ACT */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 			{
 				chip->active_voices = data & 0x1f;
 				chip->sample_rate = chip->master_clock / (16 * (chip->active_voices + 1));
@@ -1686,7 +1691,7 @@ INLINE void es5505_reg_write_low(struct ES5506Chip *chip, struct ES5506Voice *vo
 			break;
 
 		case 0x0f:	/* PAGE */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				chip->current_page = data & 0x7f;
 			break;
 	}
@@ -1695,77 +1700,79 @@ INLINE void es5505_reg_write_low(struct ES5506Chip *chip, struct ES5506Voice *vo
 
 INLINE void es5505_reg_write_high(struct ES5506Chip *chip, struct ES5506Voice *voice, offs_t offset, UINT16 data, UINT16 mem_mask)
 {
+	running_machine *machine = chip->device->machine;
+
 	switch (offset)
 	{
 		case 0x00:	/* CR */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 			{
 				voice->control &= ~(CONTROL_STOPMASK | CONTROL_BS0 | CONTROL_LOOPMASK | CONTROL_IRQE | CONTROL_DIR | CONTROL_IRQ);
 				voice->control |= (data & (CONTROL_STOPMASK | CONTROL_LOOPMASK | CONTROL_IRQE | CONTROL_DIR | CONTROL_IRQ)) |
 								  ((data << 12) & CONTROL_BS0);
 			}
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 			{
 				voice->control &= ~(CONTROL_CA0 | CONTROL_CA1 | CONTROL_LPMASK);
 				voice->control |= ((data >> 2) & CONTROL_LPMASK) |
 								  ((data << 2) & (CONTROL_CA0 | CONTROL_CA1));
 			}
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, control=%04x (raw=%04x & %04x)\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->control, data, mem_mask ^ 0xffff);
+				fprintf(eslog, "%s:voice %d, control=%04x (raw=%04x & %04x)\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->control, data, mem_mask);
 			break;
 
 		case 0x01:	/* O4(n-1) */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->o4n1 = (voice->o4n1 & ~0x00ff) | (data & 0x00ff);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->o4n1 = (INT16)((voice->o4n1 & ~0xff00) | (data & 0xff00));
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, O4(n-1)=%05x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->o4n1 & 0x3ffff);
+				fprintf(eslog, "%s:voice %d, O4(n-1)=%05x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->o4n1 & 0x3ffff);
 			break;
 
 		case 0x02:	/* O3(n-1) */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->o3n1 = (voice->o3n1 & ~0x00ff) | (data & 0x00ff);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->o3n1 = (INT16)((voice->o3n1 & ~0xff00) | (data & 0xff00));
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, O3(n-1)=%05x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->o3n1 & 0x3ffff);
+				fprintf(eslog, "%s:voice %d, O3(n-1)=%05x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->o3n1 & 0x3ffff);
 			break;
 
 		case 0x03:	/* O3(n-2) */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->o3n2 = (voice->o3n2 & ~0x00ff) | (data & 0x00ff);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->o3n2 = (INT16)((voice->o3n2 & ~0xff00) | (data & 0xff00));
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, O3(n-2)=%05x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->o3n2 & 0x3ffff);
+				fprintf(eslog, "%s:voice %d, O3(n-2)=%05x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->o3n2 & 0x3ffff);
 			break;
 
 		case 0x04:	/* O2(n-1) */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->o2n1 = (voice->o2n1 & ~0x00ff) | (data & 0x00ff);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->o2n1 = (INT16)((voice->o2n1 & ~0xff00) | (data & 0xff00));
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, O2(n-1)=%05x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->o2n1 & 0x3ffff);
+				fprintf(eslog, "%s:voice %d, O2(n-1)=%05x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->o2n1 & 0x3ffff);
 			break;
 
 		case 0x05:	/* O2(n-2) */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->o2n2 = (voice->o2n2 & ~0x00ff) | (data & 0x00ff);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->o2n2 = (INT16)((voice->o2n2 & ~0xff00) | (data & 0xff00));
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, O2(n-2)=%05x\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->o2n2 & 0x3ffff);
+				fprintf(eslog, "%s:voice %d, O2(n-2)=%05x\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->o2n2 & 0x3ffff);
 			break;
 
 		case 0x06:	/* O1(n-1) */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				voice->o1n1 = (voice->o1n1 & ~0x00ff) | (data & 0x00ff);
-			if (ACCESSING_MSB)
+			if (ACCESSING_BITS_8_15)
 				voice->o1n1 = (INT16)((voice->o1n1 & ~0xff00) | (data & 0xff00));
 			if (LOG_COMMANDS && eslog)
-				fprintf(eslog, "%06x:voice %d, O1(n-1)=%05x (accum=%08x)\n", activecpu_get_previouspc(), chip->current_page & 0x1f, voice->o2n1 & 0x3ffff, voice->accum);
+				fprintf(eslog, "%s:voice %d, O1(n-1)=%05x (accum=%08x)\n", cpuexec_describe_context(machine), chip->current_page & 0x1f, voice->o2n1 & 0x3ffff, voice->accum);
 			break;
 
 		case 0x07:
@@ -1777,7 +1784,7 @@ INLINE void es5505_reg_write_high(struct ES5506Chip *chip, struct ES5506Voice *v
 			break;
 
 		case 0x0d:	/* ACT */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 			{
 				chip->active_voices = data & 0x1f;
 				chip->sample_rate = chip->master_clock / (16 * (chip->active_voices + 1));
@@ -1792,7 +1799,7 @@ INLINE void es5505_reg_write_high(struct ES5506Chip *chip, struct ES5506Voice *v
 			break;
 
 		case 0x0f:	/* PAGE */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				chip->current_page = data & 0x7f;
 			break;
 	}
@@ -1821,7 +1828,7 @@ INLINE void es5505_reg_write_test(struct ES5506Chip *chip, struct ES5506Voice *v
 			break;
 
 		case 0x0d:	/* ACT */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 			{
 				chip->active_voices = data & 0x1f;
 				chip->sample_rate = chip->master_clock / (16 * (chip->active_voices + 1));
@@ -1836,7 +1843,7 @@ INLINE void es5505_reg_write_test(struct ES5506Chip *chip, struct ES5506Voice *v
 			break;
 
 		case 0x0f:	/* PAGE */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				chip->current_page = data & 0x7f;
 			break;
 	}
@@ -1847,7 +1854,7 @@ static void es5505_reg_write(struct ES5506Chip *chip, offs_t offset, UINT16 data
 {
 	struct ES5506Voice *voice = &chip->voice[chip->current_page & 0x1f];
 
-//  logerror("%04x:ES5505 write %02x/%02x = %04x & %04x\n", activecpu_get_previouspc(), chip->current_page, offset, data, mem_mask ^ 0xffff);
+//  logerror("%s:ES5505 write %02x/%02x = %04x & %04x\n", cpuexec_describe_context(machine), chip->current_page, offset, data, mem_mask);
 
 	/* force an update */
 	stream_update(chip->stream);
@@ -2083,37 +2090,37 @@ static UINT16 es5505_reg_read(struct ES5506Chip *chip, offs_t offset)
 
 /**********************************************************************************************
 
-     ES5505_data_0_r/ES5505_data_1_r -- handle a read from the status register
+     es5505_data_0_r/es5505_data_1_r -- handle a read from the status register
 
 ***********************************************************************************************/
 
-READ16_HANDLER( ES5505_data_0_r )
+READ16_HANDLER( es5505_data_0_r )
 {
 	return es5505_reg_read(sndti_token(SOUND_ES5505, 0), offset);
 }
 
-READ16_HANDLER( ES5505_data_1_r )
+READ16_HANDLER( es5505_data_1_r )
 {
 	return es5505_reg_read(sndti_token(SOUND_ES5505, 1), offset);
 }
 
 /**********************************************************************************************
 
-     ES5505_data_0_w/ES5505_data_1_w -- handle a write to the current register
+     es5505_data_0_w/es5505_data_1_w -- handle a write to the current register
 
 ***********************************************************************************************/
 
-WRITE16_HANDLER( ES5505_data_0_w )
+WRITE16_HANDLER( es5505_data_0_w )
 {
 	es5505_reg_write(sndti_token(SOUND_ES5505, 0), offset, data, mem_mask);
 }
 
-WRITE16_HANDLER( ES5505_data_1_w )
+WRITE16_HANDLER( es5505_data_1_w )
 {
 	es5505_reg_write(sndti_token(SOUND_ES5505, 1), offset, data, mem_mask);
 }
 
-void ES5505_voice_bank_0_w(int voice, int bank)
+void es5505_voice_bank_0_w(int voice, int bank)
 {
 	struct ES5506Chip *chip = sndti_token(SOUND_ES5505, 0);
 #if RAINE_CHECK
@@ -2122,7 +2129,7 @@ void ES5505_voice_bank_0_w(int voice, int bank)
 	chip->voice[voice].exbank=bank;
 }
 
-void ES5505_voice_bank_1_w(int voice, int bank)
+void es5505_voice_bank_1_w(int voice, int bank)
 {
 	struct ES5506Chip *chip = sndti_token(SOUND_ES5505, 1);
 #if RAINE_CHECK
@@ -2138,7 +2145,7 @@ void ES5505_voice_bank_1_w(int voice, int bank)
  * Generic get_info
  **************************************************************************/
 
-static void es5505_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( es5505 )
 {
 	switch (state)
 	{
@@ -2147,24 +2154,24 @@ static void es5505_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void es5505_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( es5505 )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = es5505_set_info;		break;
-		case SNDINFO_PTR_START:							info->start = es5505_start;				break;
-		case SNDINFO_PTR_STOP:							info->stop = es5505_stop;				break;
-		case SNDINFO_PTR_RESET:							info->reset = es5505_reset;				break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( es5505 );		break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( es5505 );				break;
+		case SNDINFO_PTR_STOP:							info->stop = SND_STOP_NAME( es5505 );				break;
+		case SNDINFO_PTR_RESET:							info->reset = SND_RESET_NAME( es5505 );				break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "ES5505";						break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "Ensoniq Wavetable";			break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "1.0";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "ES5505");							break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Ensoniq Wavetable");				break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.0");								break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);							break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
@@ -2173,7 +2180,7 @@ void es5505_get_info(void *token, UINT32 state, sndinfo *info)
  * Generic get_info
  **************************************************************************/
 
-static void es5506_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( es5506 )
 {
 	switch (state)
 	{
@@ -2182,24 +2189,24 @@ static void es5506_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void es5506_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( es5506 )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = es5506_set_info;		break;
-		case SNDINFO_PTR_START:							info->start = es5506_start;				break;
-		case SNDINFO_PTR_STOP:							info->stop = es5506_stop;				break;
-		case SNDINFO_PTR_RESET:							info->reset = es5506_reset;				break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( es5506 );		break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( es5506 );				break;
+		case SNDINFO_PTR_STOP:							info->stop = SND_STOP_NAME( es5506 );				break;
+		case SNDINFO_PTR_RESET:							info->reset = SND_RESET_NAME( es5506 );				break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "ES5506";						break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "Ensoniq Wavetable";			break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "1.0";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "ES5506");							break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Ensoniq Wavetable");				break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.0");								break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);							break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
