@@ -1,7 +1,9 @@
-#ifndef FLT_RC_H
+#pragma once
+
+#ifndef __FLT_RC_H__
 #define FLT_RC_H
 
-#include "rescap.h"
+#include "machine/rescap.h"
 
 #define FLT_RC_LOWPASS		0
 #define FLT_RC_HIGHPASS		1
@@ -33,7 +35,7 @@
  * Same as FLT_RC_HIGHPASS, but with standard frequency of 16 HZ
  * This filter may be setup just with
  *
- * MDRV_SOUND_ADD(FILTER_RC, 0)
+ * MDRV_SOUND_ADD("tag", FILTER_RC, 0)
  * MDRV_SOUND_CONFIG(&flt_rc_ac_default)
  *
  * Default behaviour:
@@ -56,4 +58,6 @@ extern const flt_rc_config flt_rc_ac_default;
 
 void filter_rc_set_RC(int num, int type, double R1, double R2, double R3, double C);
 
-#endif
+SND_GET_INFO( filter_rc );
+
+#endif /* __FLT_RC_H__ */
