@@ -9,6 +9,7 @@
 #include "sndintrf.h"
 #include "streams.h"
 #include "cpuintrf.h"
+#include "cpuexec.h"
 #include "ics2115.h"
 
 #define ICS2115LOGERROR 0
@@ -40,8 +41,10 @@
 
 enum { V_ON = 1, V_DONE = 2 };
 
-struct ics2115{
-	const struct ics2115_interface *intf;
+struct ics2115
+{
+	const ics2115_interface *intf;
+	const device_config *device;
 	int index;
 	UINT8 *rom;
 	INT16 *ulaw;
@@ -65,20 +68,6 @@ struct ics2115{
 	sound_stream * stream;
 };
 
-static int caller_get_pc(void)
-{
-	int pc = activecpu_get_pc();
-#if 0
-	if(pc == 0x14b || pc == 0x26e || pc == 0x284 || pc == 0x28d ||
-	   pc == 0x290 || pc == 0x299 || pc == 0x2a2 || pc == 0x2b3) {
-		int sp = z80_get_reg(Z80_SP);
-		pc = cpu_readmem16(sp)|(cpu_readmem16((UINT16)(sp+1)) << 8);
-	}
-#endif
-
-	return pc;
-}
-
 static void recalc_irq(struct ics2115 *chip)
 {
 	int i;
@@ -91,19 +80,19 @@ static void recalc_irq(struct ics2115 *chip)
 	if(irq != chip->irq_on) {
 		chip->irq_on = irq;
 		if(chip->intf->irq_cb)
-			chip->intf->irq_cb(irq ? ASSERT_LINE : CLEAR_LINE);
+			chip->intf->irq_cb(chip->device->machine, irq ? ASSERT_LINE : CLEAR_LINE);
 	}
 }
 
 
-static void update(void *param, stream_sample_t **inputs, stream_sample_t **buffer, int length)
+static STREAM_UPDATE( update )
 {
 	struct ics2115 *chip = param;
 	int osc, i;
 	int rec_irq = 0;
 
-	memset(buffer[0], 0, length*sizeof(*buffer[0]));
-	memset(buffer[1], 0, length*sizeof(*buffer[0]));
+	memset(outputs[0], 0, samples*sizeof(*outputs[0]));
+	memset(outputs[1], 0, samples*sizeof(*outputs[0]));
 
 	for(osc = 0; osc < 32; osc++)
 		if(chip->voice[osc].state & V_ON) {
@@ -119,7 +108,7 @@ static void update(void *param, stream_sample_t **inputs, stream_sample_t **buff
 			if (ICS2115LOGERROR) logerror("ICS2115: KEYRUN %02d adr=%08x end=%08x delta=%08x\n",
 					 osc, adr, end, delta);
 
-			for(i=0; i<length; i++) {
+			for(i=0; i<samples; i++) {
 				INT32 v = chip->rom[badr|(adr >> 12)];
 				if(conf & 1)
 					v = chip->ulaw[v];
@@ -127,8 +116,8 @@ static void update(void *param, stream_sample_t **inputs, stream_sample_t **buff
 					v = ((INT8)v) << 6;
 
 				v = (v*vol)>>(16+5);
-				buffer[0][i] += v;
-				buffer[1][i] += v;
+				outputs[0][i] += v;
+				outputs[1][i] += v;
 				adr += delta;
 				if(adr >= end) {
 					if (ICS2115LOGERROR) logerror("ICS2115: KEYDONE %2d\n", osc);
@@ -195,21 +184,23 @@ static void recalc_timer(struct ics2115 *chip, int timer)
 	if(chip->timer[timer].period != period) {
 		chip->timer[timer].period = period;
 		if(period)
-			timer_adjust(chip->timer[timer].timer, ATTOTIME_IN_NSEC(period), 0, ATTOTIME_IN_NSEC(period));
+			timer_adjust_periodic(chip->timer[timer].timer, ATTOTIME_IN_NSEC(period), 0, ATTOTIME_IN_NSEC(period));
 		else
-			timer_adjust(chip->timer[timer].timer, attotime_never, 0, attotime_zero);
+			timer_adjust_oneshot(chip->timer[timer].timer, attotime_never, 0);
 	}
 }
 
 
 static void ics2115_reg_w(struct ics2115 *chip, UINT8 reg, UINT8 data, int msb)
 {
+	running_machine *machine = chip->device->machine;
+
 	switch(reg) {
 	case 0x00: // [osc] Oscillator Configuration
 		if(msb) {
 			chip->voice[chip->osc].conf = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: %2d: conf = %02x (%04x)\n", chip->osc,
-					 chip->voice[chip->osc].conf, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: conf = %02x\n", cpuexec_describe_context(machine), chip->osc,
+					 chip->voice[chip->osc].conf);
 		}
 		break;
 
@@ -219,8 +210,8 @@ static void ics2115_reg_w(struct ics2115 *chip, UINT8 reg, UINT8 data, int msb)
 			chip->voice[chip->osc].fc = (chip->voice[chip->osc].fc & 0xff)|(data << 8);
 		else
 			chip->voice[chip->osc].fc = (chip->voice[chip->osc].fc & 0xff00)|data;
-		if (ICS2115LOGERROR) logerror("ICS2115: %2d: fc = %04x (%dHz) (%04x)\n", chip->osc,
-				 chip->voice[chip->osc].fc, chip->voice[chip->osc].fc*33075/1024, caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: fc = %04x (%dHz)\n", cpuexec_describe_context(machine), chip->osc,
+				 chip->voice[chip->osc].fc, chip->voice[chip->osc].fc*33075/1024);
 		break;
 
 	case 0x02: // [osc] Wavesample loop start address 19-4
@@ -228,15 +219,15 @@ static void ics2115_reg_w(struct ics2115 *chip, UINT8 reg, UINT8 data, int msb)
 			chip->voice[chip->osc].strth = (chip->voice[chip->osc].strth & 0xff)|(data << 8);
 		else
 			chip->voice[chip->osc].strth = (chip->voice[chip->osc].strth & 0xff00)|data;
-		if (ICS2115LOGERROR) logerror("ICS2115: %2d: strth = %04x (%04x)\n", chip->osc,
-				 chip->voice[chip->osc].strth, caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: strth = %04x\n", cpuexec_describe_context(machine), chip->osc,
+				 chip->voice[chip->osc].strth);
 		break;
 
 	case 0x03: // [osc] Wavesample loop start address 3-0.3-0
 		if(msb) {
 			chip->voice[chip->osc].strtl = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: %2d: strtl = %02x (%04x)\n", chip->osc,
-					 chip->voice[chip->osc].strtl, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: strtl = %02x\n", cpuexec_describe_context(machine), chip->osc,
+					 chip->voice[chip->osc].strtl);
 		}
 		break;
 
@@ -245,31 +236,31 @@ static void ics2115_reg_w(struct ics2115 *chip, UINT8 reg, UINT8 data, int msb)
 			chip->voice[chip->osc].endh = (chip->voice[chip->osc].endh & 0xff)|(data << 8);
 		else
 			chip->voice[chip->osc].endh = (chip->voice[chip->osc].endh & 0xff00)|data;
-		if (ICS2115LOGERROR) logerror("ICS2115: %2d: endh = %04x (%04x)\n", chip->osc,
-				 chip->voice[chip->osc].endh, caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: endh = %04x\n", cpuexec_describe_context(machine), chip->osc,
+				 chip->voice[chip->osc].endh);
 		break;
 
 	case 0x05: // [osc] Wavesample loop end address 3-0.3-0
 		if(msb) {
 			chip->voice[chip->osc].endl = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: %2d: endl = %02x (%04x)\n", chip->osc,
-					 chip->voice[chip->osc].endl, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: endl = %02x\n", cpuexec_describe_context(machine), chip->osc,
+					 chip->voice[chip->osc].endl);
 		}
 		break;
 
 	case 0x07: // [osc] Volume Start
 		if(msb) {
 			chip->voice[chip->osc].vstart = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: %2d: vstart = %02x (%04x)\n", chip->osc,
-					 chip->voice[chip->osc].vstart, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: vstart = %02x\n", cpuexec_describe_context(machine), chip->osc,
+					 chip->voice[chip->osc].vstart);
 		}
 		break;
 
 	case 0x08: // [osc] Volume End
 		if(msb) {
 			chip->voice[chip->osc].vend = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: %2d: vend = %02x (%04x)\n", chip->osc,
-					 chip->voice[chip->osc].vend, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: vend = %02x\n", cpuexec_describe_context(machine), chip->osc,
+					 chip->voice[chip->osc].vend);
 		}
 		break;
 
@@ -278,8 +269,8 @@ static void ics2115_reg_w(struct ics2115 *chip, UINT8 reg, UINT8 data, int msb)
 			chip->voice[chip->osc].volacc = (chip->voice[chip->osc].volacc & 0xff)|(data << 8);
 		else
 			chip->voice[chip->osc].volacc = (chip->voice[chip->osc].volacc & 0xff00)|data;
-		if (ICS2115LOGERROR) logerror("ICS2115: %2d: volacc = %04x (%04x)\n", chip->osc,
-				 chip->voice[chip->osc].volacc, caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: volacc = %04x\n", cpuexec_describe_context(machine), chip->osc,
+				 chip->voice[chip->osc].volacc);
 		break;
 
 	case 0x0a: // [osc] Wavesample address 19-4
@@ -287,8 +278,8 @@ static void ics2115_reg_w(struct ics2115 *chip, UINT8 reg, UINT8 data, int msb)
 			chip->voice[chip->osc].addrh = (chip->voice[chip->osc].addrh & 0xff)|(data << 8);
 		else
 			chip->voice[chip->osc].addrh = (chip->voice[chip->osc].addrh & 0xff00)|data;
-		if (ICS2115LOGERROR) logerror("ICS2115: %2d: addrh = %04x (%04x)\n", chip->osc,
-				 chip->voice[chip->osc].addrh, caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: addrh = %04x\n", cpuexec_describe_context(machine), chip->osc,
+				 chip->voice[chip->osc].addrh);
 		break;
 
 	case 0x0b: // [osc] Wavesample address 3-0.8-0
@@ -296,32 +287,32 @@ static void ics2115_reg_w(struct ics2115 *chip, UINT8 reg, UINT8 data, int msb)
 			chip->voice[chip->osc].addrl = (chip->voice[chip->osc].addrl & 0xff)|(data << 8);
 		else
 			chip->voice[chip->osc].addrl = (chip->voice[chip->osc].addrl & 0xff00)|data;
-		if (ICS2115LOGERROR) logerror("ICS2115: %2d: addrl = %04x (%04x)\n", chip->osc,
-				 chip->voice[chip->osc].addrl, caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: addrl = %04x\n", cpuexec_describe_context(machine), chip->osc,
+				 chip->voice[chip->osc].addrl);
 		break;
 
 
 	case 0x0c: // [osc] Pan
 		if(msb) {
 			chip->voice[chip->osc].pan = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: %2d: pan = %02x (%04x)\n", chip->osc,
-					 chip->voice[chip->osc].pan, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: pan = %02x\n", cpuexec_describe_context(machine), chip->osc,
+					 chip->voice[chip->osc].pan);
 		}
 		break;
 
 	case 0x0d: // [osc] Volume Enveloppe Control
 		if(msb) {
 			chip->voice[chip->osc].vctl = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: %2d: vctl = %02x (%04x)\n", chip->osc,
-					 chip->voice[chip->osc].vctl, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: vctl = %02x\n", cpuexec_describe_context(machine), chip->osc,
+					 chip->voice[chip->osc].vctl);
 		}
 		break;
 
 	case 0x10: // [osc] Oscillator Control
 		if(msb) {
 			chip->voice[chip->osc].ctl = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: %2d: ctl = %02x (%04x)\n", chip->osc,
-					 chip->voice[chip->osc].ctl, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: ctl = %02x\n", cpuexec_describe_context(machine), chip->osc,
+					 chip->voice[chip->osc].ctl);
 			if(data == 0)
 				keyon(chip, chip->osc);
 		}
@@ -330,15 +321,15 @@ static void ics2115_reg_w(struct ics2115 *chip, UINT8 reg, UINT8 data, int msb)
 	case 0x11: // [osc] Wavesample static address 27-20
 		if(msb) {
 			chip->voice[chip->osc].saddr = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: %2d: saddr = %02x (%04x)\n", chip->osc,
-					 chip->voice[chip->osc].saddr, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: saddr = %02x\n", cpuexec_describe_context(machine), chip->osc,
+					 chip->voice[chip->osc].saddr);
 		}
 		break;
 
 	case 0x40: // Timer 1 Preset
 		if(!msb) {
 			chip->timer[0].preset = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: t1preset = %d (%04x)\n", chip->timer[0].preset, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: t1preset = %d\n", cpuexec_describe_context(machine), chip->timer[0].preset);
 			recalc_timer(chip, 0);
 		}
 		break;
@@ -346,7 +337,7 @@ static void ics2115_reg_w(struct ics2115 *chip, UINT8 reg, UINT8 data, int msb)
 	case 0x41: // Timer 2 Preset
 		if(!msb) {
 			chip->timer[1].preset = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: t2preset = %d (%04x)\n", chip->timer[1].preset, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: t2preset = %d\n", cpuexec_describe_context(machine), chip->timer[1].preset);
 			recalc_timer(chip, 1);
 		}
 		break;
@@ -354,7 +345,7 @@ static void ics2115_reg_w(struct ics2115 *chip, UINT8 reg, UINT8 data, int msb)
 	case 0x42: // Timer 1 Prescaler
 		if(!msb) {
 			chip->timer[0].scale = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: t1scale = %d (%04x)\n", chip->timer[0].scale, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: t1scale = %d\n", cpuexec_describe_context(machine), chip->timer[0].scale);
 			recalc_timer(chip, 0);
 		}
 		break;
@@ -362,7 +353,7 @@ static void ics2115_reg_w(struct ics2115 *chip, UINT8 reg, UINT8 data, int msb)
 	case 0x43: // Timer 2 Prescaler
 		if(!msb) {
 			chip->timer[1].scale = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: t2scale = %d (%04x)\n", chip->timer[1].scale, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: t2scale = %d\n", cpuexec_describe_context(machine), chip->timer[1].scale);
 			recalc_timer(chip, 1);
 		}
 		break;
@@ -370,7 +361,7 @@ static void ics2115_reg_w(struct ics2115 *chip, UINT8 reg, UINT8 data, int msb)
 	case 0x4a: // IRQ Enable
 		if(!msb) {
 			chip->irq_en = data;
-			if (ICS2115LOGERROR) logerror("ICS2115: irq_en = %02x (%04x)\n", chip->irq_en, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: irq_en = %02x\n", cpuexec_describe_context(machine), chip->irq_en);
 			recalc_irq(chip);
 		}
 		break;
@@ -378,20 +369,22 @@ static void ics2115_reg_w(struct ics2115 *chip, UINT8 reg, UINT8 data, int msb)
 	case 0x4f: // Oscillator Address being Programmed
 		if(!msb) {
 			chip->osc = data & 31;
-			if (ICS2115LOGERROR) logerror("ICS2115: oscnumber = %d (%04x)\n", chip->osc, caller_get_pc());
+			if (ICS2115LOGERROR) logerror("%s:ICS2115: oscnumber = %d\n", cpuexec_describe_context(machine), chip->osc);
 		}
 		break;
 
 	default:
-		if (ICS2115LOGERROR) logerror("ICS2115: write %02x, %02x:%d (%04x)\n", reg, data, msb, caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: write %02x, %02x:%d\n", cpuexec_describe_context(machine), reg, data, msb);
 	}
 }
 
 static UINT16 ics2115_reg_r(struct ics2115 *chip, UINT8 reg)
 {
+	running_machine *machine = chip->device->machine;
+
 	switch(reg) {
 	case 0x0d: // [osc] Volume Enveloppe Control
-		if (ICS2115LOGERROR) logerror("ICS2115: %2d: read vctl (%04x)\n", chip->osc, caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: read vctl\n", cpuexec_describe_context(machine), chip->osc);
 		//      res = chip->voice[chip->osc].vctl << 8;
 		// may expect |8 on voice irq with &40 == 0
 		// may expect |8 on reg 0 on voice irq with &80 == 0
@@ -408,46 +401,46 @@ static UINT16 ics2115_reg_r(struct ics2115 *chip, UINT8 reg)
 				res = 0x40 | osc; // 0x40 ? 0x80 ?
 				break;
 			}
-		if (ICS2115LOGERROR) logerror("ICS2115: read irqv %02x (%04x)\n", res, caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: read irqv %02x\n", cpuexec_describe_context(machine), res);
 		return res << 8;
 	}
 
 	case 0x40: // Timer 0 clear irq
-		//      if (ICS2115LOGERROR) logerror("ICS2115: clear timer 0 (%04x)\n", caller_get_pc());
+		//      if (ICS2115LOGERROR) logerror("%s:ICS2115: clear timer 0\n", cpuexec_describe_context(machine));
 		chip->irq_pend &= ~(1<<0);
 		recalc_irq(chip);
 		return chip->timer[0].preset;
 
 	case 0x41: // Timer 1 clear irq
-		if (ICS2115LOGERROR) logerror("ICS2115: clear timer 1 (%04x)\n", caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: clear timer 1\n", cpuexec_describe_context(machine));
 		chip->irq_pend &= ~(1<<1);
 		recalc_irq(chip);
 		return chip->timer[1].preset;
 
 	case 0x43: // Timer status
-		//      if (ICS2115LOGERROR) logerror("ICS2115: read timer status %02x (%04x)\n", chip->irq_pend & 3, caller_get_pc());
+		//      if (ICS2115LOGERROR) logerror("%s:ICS2115: read timer status %02x\n", cpuexec_describe_context(machine), chip->irq_pend & 3);
 		return chip->irq_pend & 3;
 
 	case 0x4a: // IRQ Pending
-		if (ICS2115LOGERROR) logerror("ICS2115: read irq_pend %02x (%04x)\n", chip->irq_pend, caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: read irq_pend %02x\n", cpuexec_describe_context(machine), chip->irq_pend);
 		return chip->irq_pend;
 
 	case 0x4b: // Address of Interrupting Oscillator
-		if (ICS2115LOGERROR) logerror("ICS2115: %2d: read intoscaddr (%04x)\n", chip->osc, caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: %2d: read intoscaddr\n", cpuexec_describe_context(machine), chip->osc);
 		return 0x80;
 
 	case 0x4c: // Chip revision
-		if (ICS2115LOGERROR) logerror("ICS2115: read revision (%04x)\n", caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: read revision\n", cpuexec_describe_context(machine));
 		return 0x01;
 
 	default:
-		if (ICS2115LOGERROR) logerror("ICS2115: read %02x unmapped (%04x)\n", reg, caller_get_pc());
+		if (ICS2115LOGERROR) logerror("%s:ICS2115: read %02x unmapped\n", cpuexec_describe_context(machine), reg);
 		return 0;
 	}
 }
 
 
-static void *ics2115_start(int sndindex, int clock, const void *config)
+static SND_START( ics2115 )
 {
 	struct ics2115 *chip;
 	int i;
@@ -455,13 +448,14 @@ static void *ics2115_start(int sndindex, int clock, const void *config)
 	chip = auto_malloc(sizeof(*chip));
 	memset(chip, 0, sizeof(*chip));
 
+	chip->device = device;
 	chip->intf = config;
 	chip->index = sndindex;
-	chip->rom = memory_region(chip->intf->region);
-	chip->timer[0].timer = timer_alloc(timer_cb_0, chip);
-	chip->timer[1].timer = timer_alloc(timer_cb_1, chip);
+	chip->rom = device->region;
+	chip->timer[0].timer = timer_alloc(device->machine, timer_cb_0, chip);
+	chip->timer[1].timer = timer_alloc(device->machine, timer_cb_1, chip);
 	chip->ulaw = auto_malloc(256*sizeof(INT16));
-	chip->stream = stream_create(0, 2, 33075, chip, update);
+	chip->stream = stream_create(device, 0, 2, 33075, chip, update);
 
 	for(i=0; i<256; i++) {
 		UINT8 c = ~i;
@@ -495,7 +489,7 @@ READ8_HANDLER( ics2115_r )
 					break;
 				}
 		}
-		//      if (ICS2115LOGERROR) logerror("ICS2115: read status %02x (%04x)\n", res, caller_get_pc());
+		//      if (ICS2115LOGERROR) logerror("%s:ICS2115: read status %02x\n", cpuexec_describe_context(space->machine), res);
 
 		return res;
 	}
@@ -523,17 +517,17 @@ WRITE8_HANDLER( ics2115_w )
 		ics2115_reg_w(chip, chip->reg, data, 1);
 		break;
 	}
-	//  if (ICS2115LOGERROR) logerror("ICS2115: wi %d, %02x (%04x)\n", offset, data, caller_get_pc());
+	//  if (ICS2115LOGERROR) logerror("ICS2115: wi %d, %02x\n", cpuexec_describe_context(space->machine), offset, data);
 }
 
-static void ics2115_reset(void *_chip)
+static SND_RESET( ics2115 )
 {
-	struct ics2115 *chip = _chip;
+	struct ics2115 *chip = device->token;
 	chip->irq_en = 0;
 	chip->irq_pend = 0;
 	memset(chip->voice, 0, sizeof(chip->voice));
-	timer_adjust(chip->timer[0].timer, attotime_never, 0, attotime_zero);
-	timer_adjust(chip->timer[1].timer, attotime_never, 0, attotime_zero);
+	timer_adjust_oneshot(chip->timer[0].timer, attotime_never, 0);
+	timer_adjust_oneshot(chip->timer[1].timer, attotime_never, 0);
 	chip->timer[0].period = 0;
 	chip->timer[1].period = 0;
 	recalc_irq(chip);
@@ -546,7 +540,7 @@ static void ics2115_reset(void *_chip)
  * Generic get_info
  **************************************************************************/
 
-static void ics2115_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( ics2115 )
 {
 	switch (state)
 	{
@@ -555,24 +549,24 @@ static void ics2115_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void ics2115_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( ics2115 )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = ics2115_set_info;		break;
-		case SNDINFO_PTR_START:							info->start = ics2115_start;			break;
-		case SNDINFO_PTR_STOP:							/* nothing */							break;
-		case SNDINFO_PTR_RESET:							info->reset = ics2115_reset;			break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( ics2115 );	break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( ics2115 );		break;
+		case SNDINFO_PTR_STOP:							/* nothing */									break;
+		case SNDINFO_PTR_RESET:							info->reset = SND_RESET_NAME( ics2115 );		break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "ICS2115";					break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "ICS";						break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "1.01";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "ICS2115");						break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "ICS");							break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.01");						break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);						break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
