@@ -59,13 +59,13 @@ CHANNEL_DEBUG enables the following keys:
 */
 
 struct k054539_info {
-	const struct K054539interface *intf;
+	const k054539_interface *intf;
 	double voltab[256];
 	double pantab[0xf];
 
-	double K054539_gain[8];
-	UINT8 K054539_posreg_latch[8][3];
-	int K054539_flags;
+	double k054539_gain[8];
+	UINT8 k054539_posreg_latch[8][3];
+	int k054539_flags;
 
 	unsigned char regs[0x230];
 	unsigned char *ram;
@@ -79,7 +79,7 @@ struct k054539_info {
 	UINT32 rom_mask;
 	sound_stream * stream;
 
-	struct K054539_channel {
+	struct k054539_channel {
 		UINT32 pos;
 		UINT32 pfrac;
 		INT32 val;
@@ -89,37 +89,37 @@ struct k054539_info {
 
 //*
 
-void K054539_init_flags(int chip, int flags)
+void k054539_init_flags(int chip, int flags)
 {
 	struct k054539_info *info = sndti_token(SOUND_K054539, chip);
-	info->K054539_flags = flags;
+	info->k054539_flags = flags;
 }
 
-void K054539_set_gain(int chip, int channel, double gain)
+void k054539_set_gain(int chip, int channel, double gain)
 {
 	struct k054539_info *info = sndti_token(SOUND_K054539, chip);
-	if (gain >= 0) info->K054539_gain[channel] = gain;
+	if (gain >= 0) info->k054539_gain[channel] = gain;
 }
 //*
 
-static int K054539_regupdate(struct k054539_info *info)
+static int k054539_regupdate(struct k054539_info *info)
 {
 	return !(info->regs[0x22f] & 0x80);
 }
 
-static void K054539_keyon(struct k054539_info *info, int channel)
+static void k054539_keyon(struct k054539_info *info, int channel)
 {
-	if(K054539_regupdate(info))
+	if(k054539_regupdate(info))
 		info->regs[0x22c] |= 1 << channel;
 }
 
-static void K054539_keyoff(struct k054539_info *info, int channel)
+static void k054539_keyoff(struct k054539_info *info, int channel)
 {
-	if(K054539_regupdate(info))
+	if(k054539_regupdate(info))
 		info->regs[0x22c] &= ~(1 << channel);
 }
 
-static void K054539_update(void *param, stream_sample_t **inputs, stream_sample_t **buffer, int length)
+static STREAM_UPDATE( k054539_update )
 {
 	struct k054539_info *info = param;
 #define VOL_CAP 1.80
@@ -131,11 +131,11 @@ static void K054539_update(void *param, stream_sample_t **inputs, stream_sample_
 
 	int ch, reverb_pos;
 	short *rbase;
-	unsigned char *samples;
+	unsigned char *rom;
 	UINT32 rom_mask;
 
 	unsigned char *base1, *base2;
-	struct K054539_channel *chan;
+	struct k054539_channel *chan;
 	stream_sample_t *bufl, *bufr;
 	int cur_pos, cur_pfrac, cur_val, cur_pval;
 	int delta, rdelta, fdelta, pdelta;
@@ -146,15 +146,15 @@ static void K054539_update(void *param, stream_sample_t **inputs, stream_sample_
 	reverb_pos = info->reverb_pos;
 	rbase = (short *)(info->ram);
 
-	memset(buffer[0], 0, length*sizeof(*buffer[0]));
-	memset(buffer[1], 0, length*sizeof(*buffer[1]));
+	memset(outputs[0], 0, samples*sizeof(*outputs[0]));
+	memset(outputs[1], 0, samples*sizeof(*outputs[1]));
 
-	samples = info->rom;
+	rom = info->rom;
 	rom_mask = info->rom_mask;
 
 	if(!(info->regs[0x22f] & 1)) return;
 
-	info->reverb_pos = (reverb_pos + length) & 0x3fff;
+	info->reverb_pos = (reverb_pos + samples) & 0x3fff;
 
 
 	for(ch=0; ch<8; ch++)
@@ -177,7 +177,7 @@ pan -= 0x81;
 else
 			if (pan >= 0x11 && pan <= 0x1f) pan -= 0x11; else pan = 0x18 - 0x11;
 
-			gain = info->K054539_gain[ch];
+			gain = info->k054539_gain[ch];
 
 			lvol = info->voltab[vol] * info->pantab[pan] * gain;
 			if (lvol > VOL_CAP) lvol = VOL_CAP;
@@ -199,8 +199,8 @@ else
 
 			cur_pos = (base1[0x0c] | (base1[0x0d] << 8) | (base1[0x0e] << 16)) & rom_mask;
 
-			bufl = buffer[0];
-			bufr = buffer[1];
+			bufl = outputs[0];
+			bufr = outputs[1];
 //*
 
 			if(base2[0] & 0x20) {
@@ -233,22 +233,22 @@ else
 
 			switch(base2[0] & 0xc) {
 			case 0x0: { // 8bit pcm
-				for(i=0; i<length; i++) {
+				for(i=0; i<samples; i++) {
 					cur_pfrac += delta;
 					while(cur_pfrac & ~0xffff) {
 						cur_pfrac += fdelta;
 						cur_pos += pdelta;
 
 						cur_pval = cur_val;
-						cur_val = (INT16)(samples[cur_pos] << 8);
+						cur_val = (INT16)(rom[cur_pos] << 8);
 						if(cur_val == (INT16)0x8000) {
 							if(base2[1] & 1) {
 								cur_pos = (base1[0x08] | (base1[0x09] << 8) | (base1[0x0a] << 16)) & rom_mask;
-								cur_val = (INT16)(samples[cur_pos] << 8);
+								cur_val = (INT16)(rom[cur_pos] << 8);
 								if(cur_val != (INT16)0x8000)
 									continue;
 							}
-							K054539_keyoff(info, ch);
+							k054539_keyoff(info, ch);
 							goto end_channel_0;
 						}
 					}
@@ -261,22 +261,22 @@ else
 			case 0x4: { // 16bit pcm lsb first
 				pdelta <<= 1;
 
-				for(i=0; i<length; i++) {
+				for(i=0; i<samples; i++) {
 					cur_pfrac += delta;
 					while(cur_pfrac & ~0xffff) {
 						cur_pfrac += fdelta;
 						cur_pos += pdelta;
 
 						cur_pval = cur_val;
-						cur_val = (INT16)(samples[cur_pos] | samples[cur_pos+1]<<8);
+						cur_val = (INT16)(rom[cur_pos] | rom[cur_pos+1]<<8);
 						if(cur_val == (INT16)0x8000) {
 							if(base2[1] & 1) {
 								cur_pos = (base1[0x08] | (base1[0x09] << 8) | (base1[0x0a] << 16)) & rom_mask;
-								cur_val = (INT16)(samples[cur_pos] | samples[cur_pos+1]<<8);
+								cur_val = (INT16)(rom[cur_pos] | rom[cur_pos+1]<<8);
 								if(cur_val != (INT16)0x8000)
 									continue;
 							}
-							K054539_keyoff(info, ch);
+							k054539_keyoff(info, ch);
 							goto end_channel_4;
 						}
 					}
@@ -294,22 +294,22 @@ else
 					cur_pos |= 1;
 				}
 
-				for(i=0; i<length; i++) {
+				for(i=0; i<samples; i++) {
 					cur_pfrac += delta;
 					while(cur_pfrac & ~0xffff) {
 						cur_pfrac += fdelta;
 						cur_pos += pdelta;
 
 						cur_pval = cur_val;
-						cur_val = samples[cur_pos>>1];
+						cur_val = rom[cur_pos>>1];
 						if(cur_val == 0x88) {
 							if(base2[1] & 1) {
 								cur_pos = ((base1[0x08] | (base1[0x09] << 8) | (base1[0x0a] << 16)) & rom_mask) << 1;
-								cur_val = samples[cur_pos>>1];
+								cur_val = rom[cur_pos>>1];
 								if(cur_val != 0x88)
 									goto next_iter;
 							}
-							K054539_keyoff(info, ch);
+							k054539_keyoff(info, ch);
 							goto end_channel_8;
 						}
 					next_iter:
@@ -341,7 +341,7 @@ else
 			chan->pfrac = cur_pfrac;
 			chan->pval = cur_pval;
 			chan->val = cur_val;
-			if(K054539_regupdate(info)) {
+			if(k054539_regupdate(info)) {
 				base1[0x0c] = cur_pos     & 0xff;
 				base1[0x0d] = cur_pos>> 8 & 0xff;
 				base1[0x0e] = cur_pos>>16 & 0xff;
@@ -349,21 +349,21 @@ else
 		}
 
 	//* drivers should be given the option to disable reverb when things go terribly wrong
-	if(!(info->K054539_flags & K054539_DISABLE_REVERB))
+	if(!(info->k054539_flags & K054539_DISABLE_REVERB))
 	{
-		for(i=0; i<length; i++) {
+		for(i=0; i<samples; i++) {
 			short val = rbase[(i+reverb_pos) & 0x3fff];
-			buffer[0][i] += val;
-			buffer[1][i] += val;
+			outputs[0][i] += val;
+			outputs[1][i] += val;
 		}
 	}
 
-	if(reverb_pos + length > 0x4000) {
+	if(reverb_pos + samples > 0x4000) {
 		i = 0x4000 - reverb_pos;
 		memset(rbase + reverb_pos, 0, i*2);
-		memset(rbase, 0, (length-i)*2);
+		memset(rbase, 0, (samples-i)*2);
 	} else
-		memset(rbase + reverb_pos, 0, length*2);
+		memset(rbase + reverb_pos, 0, samples*2);
 
 	#if CHANNEL_DEBUG
 	{
@@ -391,10 +391,10 @@ else
 			if (gc_j) { gc_i &= 7; gc_pos[gc_chip] = gc_i; }
 
 			if (input_code_pressed_once(KEYCODE_5_PAD))
-				info->K054539_gain[gc_i] = 1.0;
+				info->k054539_gain[gc_i] = 1.0;
 			else
 			{
-				gc_fptr = &info->K054539_gain[gc_i];
+				gc_fptr = &info->k054539_gain[gc_i];
 				gc_f0 = *gc_fptr;
 				gc_j = 0;
 				if (input_code_pressed_once(KEYCODE_2_PAD)) { gc_f0 -= 0.1; gc_j = 1; }
@@ -402,7 +402,7 @@ else
 				if (gc_j) { if (gc_f0 < 0) gc_f0 = 0; *gc_fptr = gc_f0; }
 			}
 
-			gc_fptr = &info->K054539_gain[0] + 8;
+			gc_fptr = &info->k054539_gain[0] + 8;
 			gc_cptr = gc_msg + 7;
 			for (gc_j=-8; gc_j; gc_j++)
 			{
@@ -425,20 +425,20 @@ else
 }
 
 
-static TIMER_CALLBACK( K054539_irq )
+static TIMER_CALLBACK( k054539_irq )
 {
 	struct k054539_info *info = ptr;
 	if(info->regs[0x22f] & 0x20)
-		info->intf->irq ();
+		info->intf->irq(machine);
 }
 
-static void K054539_init_chip(struct k054539_info *info, int clock, int sndindex)
+static void k054539_init_chip(const device_config *device, struct k054539_info *info, int clock)
 {
 	int i;
 
 	memset(info->regs, 0, sizeof(info->regs));
-	memset(info->K054539_posreg_latch, 0, sizeof(info->K054539_posreg_latch)); //*
-	info->K054539_flags |= K054539_UPDATE_AT_KEYON; //* make it default until proven otherwise
+	memset(info->k054539_posreg_latch, 0, sizeof(info->k054539_posreg_latch)); //*
+	info->k054539_flags |= K054539_UPDATE_AT_KEYON; //* make it default until proven otherwise
 
 	// Real size of 0x4000, the addon is to simplify the reverb buffer computations
 	info->ram = auto_malloc(0x4000*2+clock/50*2);
@@ -446,8 +446,13 @@ static void K054539_init_chip(struct k054539_info *info, int clock, int sndindex
 	info->cur_ptr = 0;
 	memset(info->ram, 0, 0x4000*2+clock/50*2);
 
-	info->rom = memory_region(info->intf->region);
-	info->rom_size = memory_region_length(info->intf->region);
+	info->rom = device->region;
+	info->rom_size = device->regionbytes;
+	if (info->intf->rgnoverride != NULL)
+	{
+		info->rom = memory_region(device->machine, info->intf->rgnoverride);
+		info->rom_size = memory_region_length(device->machine, info->intf->rgnoverride);
+	}
 	info->rom_mask = 0xffffffffU;
 	for(i=0; i<32; i++)
 		if((1U<<i) >= info->rom_size) {
@@ -459,16 +464,16 @@ static void K054539_init_chip(struct k054539_info *info, int clock, int sndindex
 		// One or more of the registers must be the timer period
 		// And anyway, this particular frequency is probably wrong
 		// 480 hz is TRUSTED by gokuparo disco stage - the looping sample doesn't line up otherwise
-		timer_pulse(ATTOTIME_IN_HZ(480), info, 0, K054539_irq);
+		timer_pulse(device->machine, ATTOTIME_IN_HZ(480), info, 0, k054539_irq);
 
-	info->stream = stream_create(0, 2, clock, info, K054539_update);
+	info->stream = stream_create(device, 0, 2, clock, info, k054539_update);
 
-	state_save_register_item_array("K054539", sndindex, info->regs);
-	state_save_register_item_pointer("K054539", sndindex, info->ram,  0x4000);
-	state_save_register_item("K054539", sndindex, info->cur_ptr);
+	state_save_register_device_item_array(device, 0, info->regs);
+	state_save_register_device_item_pointer(device, 0, info->ram,  0x4000);
+	state_save_register_device_item(device, 0, info->cur_ptr);
 }
 
-static void K054539_w(int chip, offs_t offset, UINT8 data) //*
+static void k054539_w(int chip, offs_t offset, UINT8 data) //*
 {
 	struct k054539_info *info = sndti_token(SOUND_K054539, chip);
 #if 0
@@ -499,7 +504,7 @@ static void K054539_w(int chip, offs_t offset, UINT8 data) //*
 	UINT8 *regbase, *regptr, *posptr;
 
 	regbase = info->regs;
-	latch = (info->K054539_flags & K054539_UPDATE_AT_KEYON) && (regbase[0x22f] & 1);
+	latch = (info->k054539_flags & K054539_UPDATE_AT_KEYON) && (regbase[0x22f] & 1);
 
 	if (latch && offset < 0x100)
 	{
@@ -509,7 +514,7 @@ static void K054539_w(int chip, offs_t offset, UINT8 data) //*
 		if (offs >= 0 && offs <= 2)
 		{
 			// latch writes to the position index registers
-			info->K054539_posreg_latch[ch][offs] = data;
+			info->k054539_posreg_latch[ch][offs] = data;
 			return;
 		}
 	}
@@ -529,7 +534,7 @@ static void K054539_w(int chip, offs_t offset, UINT8 data) //*
 				{
 					if(data & (1<<ch))
 					{
-						posptr = &info->K054539_posreg_latch[ch][0];
+						posptr = &info->k054539_posreg_latch[ch][0];
 						regptr = regbase + (ch<<5) + 0xc;
 
 						// update the chip at key-on
@@ -537,7 +542,7 @@ static void K054539_w(int chip, offs_t offset, UINT8 data) //*
 						regptr[1] = posptr[1];
 						regptr[2] = posptr[2];
 
-						K054539_keyon(info, ch);
+						k054539_keyon(info, ch);
 					}
 				}
 			}
@@ -545,14 +550,14 @@ static void K054539_w(int chip, offs_t offset, UINT8 data) //*
 			{
 				for(ch=0; ch<8; ch++)
 					if(data & (1<<ch))
-						K054539_keyon(info, ch);
+						k054539_keyon(info, ch);
 			}
 		break;
 
 		case 0x215:
 			for(ch=0; ch<8; ch++)
 				if(data & (1<<ch))
-					K054539_keyoff(info, ch);
+					k054539_keyoff(info, ch);
 		break;
 
 		case 0x22d:
@@ -592,7 +597,7 @@ static void K054539_w(int chip, offs_t offset, UINT8 data) //*
 	regbase[offset] = data;
 }
 
-static void reset_zones(void *param)
+static STATE_POSTLOAD( reset_zones )
 {
 	struct k054539_info *info = param;
 	int data = info->regs[0x22e];
@@ -602,7 +607,7 @@ static void reset_zones(void *param)
 	info->cur_limit = data == 0x80 ? 0x4000 : 0x20000;
 }
 
-static UINT8 K054539_r(int chip, offs_t offset)
+static UINT8 k054539_r(int chip, offs_t offset)
 {
 	struct k054539_info *info = sndti_token(SOUND_K054539, chip);
 	switch(offset) {
@@ -624,8 +629,9 @@ static UINT8 K054539_r(int chip, offs_t offset)
 	return info->regs[offset];
 }
 
-static void *k054539_start(int sndindex, int clock, const void *config)
+static SND_START( k054539 )
 {
+	static const k054539_interface defintrf = { 0 };
 	int i;
 	struct k054539_info *info;
 
@@ -633,10 +639,10 @@ static void *k054539_start(int sndindex, int clock, const void *config)
 	memset(info, 0, sizeof(*info));
 
 	for (i = 0; i < 8; i++)
-		info->K054539_gain[i] = 1.0;
-	info->K054539_flags = K054539_RESET_FLAGS;
+		info->k054539_gain[i] = 1.0;
+	info->k054539_flags = K054539_RESET_FLAGS;
 
-	info->intf = config;
+	info->intf = (config != NULL) ? config : &defintrf;
 
 	/*
         I've tried various equations on volume control but none worked consistently.
@@ -660,30 +666,30 @@ static void *k054539_start(int sndindex, int clock, const void *config)
 	for(i=0; i<0xf; i++)
 		info->pantab[i] = sqrt(i) / sqrt(0xe);
 
-	K054539_init_chip(info, clock, sndindex);
+	k054539_init_chip(device, info, clock);
 
-	state_save_register_func_postload_ptr(reset_zones, info);
+	state_save_register_postload(device->machine, reset_zones, info);
 	return info;
 }
 
-WRITE8_HANDLER( K054539_0_w )
+WRITE8_HANDLER( k054539_0_w )
 {
-	K054539_w(0, offset, data);
+	k054539_w(0, offset, data);
 }
 
-READ8_HANDLER( K054539_0_r )
+READ8_HANDLER( k054539_0_r )
 {
-	return K054539_r(0, offset);
+	return k054539_r(0, offset);
 }
 
-WRITE8_HANDLER( K054539_1_w )
+WRITE8_HANDLER( k054539_1_w )
 {
-	K054539_w(1, offset, data);
+	k054539_w(1, offset, data);
 }
 
-READ8_HANDLER( K054539_1_r )
+READ8_HANDLER( k054539_1_r )
 {
-	return K054539_r(1, offset);
+	return k054539_r(1, offset);
 }
 
 
@@ -693,7 +699,7 @@ READ8_HANDLER( K054539_1_r )
  * Generic get_info
  **************************************************************************/
 
-static void k054539_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( k054539 )
 {
 	switch (state)
 	{
@@ -702,24 +708,24 @@ static void k054539_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void k054539_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( k054539 )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = k054539_set_info;		break;
-		case SNDINFO_PTR_START:							info->start = k054539_start;			break;
-		case SNDINFO_PTR_STOP:							/* nothing */							break;
-		case SNDINFO_PTR_RESET:							/* nothing */							break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( k054539 );	break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( k054539 );		break;
+		case SNDINFO_PTR_STOP:							/* nothing */									break;
+		case SNDINFO_PTR_RESET:							/* nothing */									break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "K054539";					break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "Konami custom";				break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "1.0";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "K054539");						break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Konami custom");				break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.0");							break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);						break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
