@@ -5,6 +5,8 @@
 
 #include "msm5232.h"
 
+#define CLOCK_RATE_DIVIDER 16
+
 /*
     OKI MSM5232RS
     8 channel tone generator
@@ -34,6 +36,8 @@ typedef struct {
 	double	rr_rate;
 
 	int	pitch;			/* current pitch data */
+
+	int GF;
 } VOICE;
 
 
@@ -61,10 +65,13 @@ typedef struct {
 	UINT8   control1;
 	UINT8   control2;
 
+	int		gate;		/* current state of the GATE output */
+
 	int		clock;		/* chip clock in Hz */
 	int		rate;		/* sample rate in Hz */
 
 	double	external_capacity[8]; /* in Farads, eg 0.39e-6 = 0.36 uF (microFarads) */
+	void (*gate_handler)(int state);	/* callback called when the GATE output pin changes state */
 
 } MSM5232;
 
@@ -246,9 +253,20 @@ static void msm5232_init_voice(MSM5232 *chip, int i)
 static void msm5232_write(MSM5232 *chip, int ofst, int data);
 
 
-static void msm5232_reset(void *_chip)
+static void msm5232_gate_update(MSM5232 *chip)
+{
+	int new_state = (chip->control2 & 0x20) ? chip->voi[7].GF : 0;
+
+	if (chip->gate != new_state && chip->gate_handler)
+	{
+		chip->gate = new_state;
+		(*chip->gate_handler)(new_state);
+	}
+}
+
+
+static void msm5232_reset(MSM5232 *chip)
 {
-	MSM5232 *chip = _chip;
 	int i;
 
 	for (i=0; i<8; i++)
@@ -272,9 +290,15 @@ static void msm5232_reset(void *_chip)
 	chip->EN_out4[1]	= 0;
 	chip->EN_out2[1]	= 0;
 
+	msm5232_gate_update(chip);
 }
 
-static void msm5232_init(MSM5232 *chip, const struct MSM5232interface *intf, int clock, int rate)
+static SND_RESET( msm5232 )
+{
+	msm5232_reset(device->token);
+}
+
+static void msm5232_init(MSM5232 *chip, const msm5232_interface *intf, int clock, int rate)
 {
 	int j;
 
@@ -286,6 +310,8 @@ static void msm5232_init(MSM5232 *chip, const struct MSM5232interface *intf, int
 		chip->external_capacity[j] = intf->capacity[j];
 	}
 
+	chip->gate_handler = intf->gate_handler;
+
 	msm5232_init_tables( chip );
 
 	for (j=0; j<8; j++)
@@ -321,6 +347,11 @@ static void msm5232_write(MSM5232 *chip, int ofst, int data)
 	if (ofst < 0x08) /* pitch */
 	{
 		int ch = ofst&7;
+
+		chip->voi[ch].GF = ((data&0x80)>>7);
+		if (ch == 7)
+			msm5232_gate_update(chip);
+
 		if(data&0x80)
 		{
 			if(data >= 0xd8)
@@ -355,7 +386,6 @@ static void msm5232_write(MSM5232 *chip, int ofst, int data)
 
 					n = (n>0)? n-1: 0;
 					chip->voi[ch].TG_out2  = 1<<n;
-
 				}
 				chip->voi[ch].mode = 0;		/* tone mode */
 				chip->voi[ch].eg_sect = 0;	/* Key On */
@@ -363,10 +393,10 @@ static void msm5232_write(MSM5232 *chip, int ofst, int data)
 		}
 		else
 		{
-				if ( !chip->voi[ch].eg_arm )	/* arm = 0 */
-					chip->voi[ch].eg_sect = 2;	/* Key Off -> go to release */
-				else							/* arm = 1 */
-					chip->voi[ch].eg_sect = 1;	/* Key Off -> go to decay */
+			if ( !chip->voi[ch].eg_arm )	/* arm = 0 */
+				chip->voi[ch].eg_sect = 2;	/* Key Off -> go to release */
+			else							/* arm = 1 */
+				chip->voi[ch].eg_sect = 1;	/* Key Off -> go to decay */
 		}
 	}
 	else
@@ -423,6 +453,7 @@ static void msm5232_write(MSM5232 *chip, int ofst, int data)
                 popmessage("msm5232: control2 ctrl=%2x\n", data);*/
 
 			chip->control2 = data;
+			msm5232_gate_update(chip);
 
 			for (i=0; i<4; i++)
 				chip->voi[i+4].eg_arm = data&0x10;
@@ -543,14 +574,14 @@ INLINE void EG_voices_advance(MSM5232 *chip)
 
 }
 
-static int o2,o4,o8,o16;
+static int o2,o4,o8,o16,solo8,solo16;
 
 INLINE void TG_group_advance(MSM5232 *chip, int groupidx)
 {
 	VOICE *voi = &chip->voi[groupidx*4];
 	int i;
 
-	o2 = o4 = o8 = o16 = 0;
+	o2 = o4 = o8 = o16 = solo8 = solo16 = 0;
 
 	i=4;
 	do
@@ -614,6 +645,13 @@ INLINE void TG_group_advance(MSM5232 *chip, int groupidx)
 		o8  += ( (out8 -(1<<(STEP_SH-1))) * voi->egvol) >> STEP_SH;
 		o4  += ( (out4 -(1<<(STEP_SH-1))) * voi->egvol) >> STEP_SH;
 		o2  += ( (out2 -(1<<(STEP_SH-1))) * voi->egvol) >> STEP_SH;
+
+		if (i == 1 && groupidx == 1)
+		{
+			solo16 += ( (out16-(1<<(STEP_SH-1))) << 11) >> STEP_SH;
+			solo8  += ( (out8 -(1<<(STEP_SH-1))) << 11) >> STEP_SH;
+		}
+
 		voi++;
 		i--;
 	}while (i>0);
@@ -665,39 +703,47 @@ INLINE void TG_group_advance(MSM5232 *chip, int groupidx)
 #endif
 
 
-static void MSM5232_update_one(void *param, stream_sample_t **inputs, stream_sample_t** buffer, int samples)
+static STREAM_UPDATE( MSM5232_update_one )
 {
 	MSM5232 * chip = param;
-	stream_sample_t *buf1 = buffer[0];
-	stream_sample_t *buf2 = buffer[1];
+	stream_sample_t *buf1 = outputs[0];
+	stream_sample_t *buf2 = outputs[1];
+	stream_sample_t *buf3 = outputs[2];
+	stream_sample_t *buf4 = outputs[3];
+	stream_sample_t *buf5 = outputs[4];
+	stream_sample_t *buf6 = outputs[5];
+	stream_sample_t *buf7 = outputs[6];
+	stream_sample_t *buf8 = outputs[7];
+	stream_sample_t *bufsolo1 = outputs[8];
+	stream_sample_t *bufsolo2 = outputs[9];
+	stream_sample_t *bufnoise = outputs[10];
 	int i;
 
 	for (i=0; i<samples; i++)
 	{
-		int out;
-
 		/* calculate all voices' envelopes */
 		EG_voices_advance(chip);
 
 		TG_group_advance(chip,0);	/* calculate tones group 1 */
-		out = (o2+o4+o8+o16);
-		if (out>32767)
-			out = 32767;
-		else if (out<-32768)
-			out = -32768;
-		buf1[i] = out;				/* should be 4 separate outputs */
+		buf1[i] = o2;
+		buf2[i] = o4;
+		buf3[i] = o8;
+		buf4[i] = o16;
+
 		SAVE_SINGLE_CHANNEL(0,o2)
 		SAVE_SINGLE_CHANNEL(1,o4)
 		SAVE_SINGLE_CHANNEL(2,o8)
 		SAVE_SINGLE_CHANNEL(3,o16)
 
 		TG_group_advance(chip,1);	/* calculate tones group 2 */
-		out = (o2+o4+o8+o16);
-		if (out>32767)
-			out = 32767;
-		else if (out<-32768)
-			out = -32768;
-		buf2[i] = out;				/* should be 4 separate outputs */
+		buf5[i] = o2;
+		buf6[i] = o4;
+		buf7[i] = o8;
+		buf8[i] = o16;
+
+		bufsolo1[i] = solo8;
+		bufsolo2[i] = solo16;
+
 		SAVE_SINGLE_CHANNEL(4,o2)
 		SAVE_SINGLE_CHANNEL(5,o4)
 		SAVE_SINGLE_CHANNEL(6,o8)
@@ -714,7 +760,7 @@ static void MSM5232_update_one(void *param, stream_sample_t **inputs, stream_sam
 				int tmp = chip->noise_rng & (1<<16);		/* store current level */
 
 				if (chip->noise_rng&1)
-					chip->noise_rng ^= 0x28000;
+					chip->noise_rng ^= 0x24000;
 				chip->noise_rng>>=1;
 
 				if ( (chip->noise_rng & (1<<16)) != tmp )	/* level change detect */
@@ -723,6 +769,8 @@ static void MSM5232_update_one(void *param, stream_sample_t **inputs, stream_sam
 				cnt--;
 			}
 		}
+
+		bufnoise[i] = (chip->noise_rng & (1<<16)) ? 32767 : 0;
 	}
 }
 
@@ -730,10 +778,10 @@ static void MSM5232_update_one(void *param, stream_sample_t **inputs, stream_sam
 
 /* MAME Interface */
 
-static void *msm5232_start(int sndindex, int clock, const void *config)
+static SND_START( msm5232 )
 {
-	const struct MSM5232interface *intf = config;
-	int rate = clock/16;
+	const msm5232_interface *intf = config;
+	int rate = clock/CLOCK_RATE_DIVIDER;
 	MSM5232 *chip;
 
 	chip = auto_malloc(sizeof(*chip));
@@ -741,29 +789,42 @@ static void *msm5232_start(int sndindex, int clock, const void *config)
 
 	msm5232_init(chip, intf, clock, rate);
 
-	chip->stream = stream_create(0,2,rate,chip,MSM5232_update_one);
+	chip->stream = stream_create(device,0,11,rate,chip,MSM5232_update_one);
 	return chip;
 }
 
-static void msm5232_stop (void *chip)
+static SND_STOP( msm5232 )
 {
-	msm5232_shutdown(chip);
+	msm5232_shutdown(device->token);
 }
 
-WRITE8_HANDLER ( MSM5232_0_w )
+WRITE8_HANDLER ( msm5232_0_w )
 {
 	MSM5232 *chip = sndti_token(SOUND_MSM5232, 0);
 	stream_update (chip->stream);
 	msm5232_write(chip, offset, data);
 }
 
-WRITE8_HANDLER ( MSM5232_1_w )
+WRITE8_HANDLER ( msm5232_1_w )
 {
 	MSM5232 *chip = sndti_token(SOUND_MSM5232, 1);
 	stream_update (chip->stream);
 	msm5232_write(chip, offset, data);
 }
 
+void msm5232_set_clock(void *_chip, int clock)
+{
+	MSM5232 *chip = _chip;
+
+	if (chip->clock != clock)
+	{
+		stream_update (chip->stream);
+		chip->clock = clock;
+		chip->rate = clock/CLOCK_RATE_DIVIDER;
+		msm5232_init_tables( chip );
+		stream_set_sample_rate(chip->stream, chip->rate);
+	}
+}
 
 
 
@@ -771,7 +832,7 @@ WRITE8_HANDLER ( MSM5232_1_w )
  * Generic get_info
  **************************************************************************/
 
-static void msm5232_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( msm5232 )
 {
 	switch (state)
 	{
@@ -780,24 +841,24 @@ static void msm5232_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void msm5232_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( msm5232 )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = msm5232_set_info;		break;
-		case SNDINFO_PTR_START:							info->start = msm5232_start;			break;
-		case SNDINFO_PTR_STOP:							info->stop = msm5232_stop;				break;
-		case SNDINFO_PTR_RESET:							info->reset = msm5232_reset;			break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( msm5232 );	break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( msm5232 );		break;
+		case SNDINFO_PTR_STOP:							info->stop = SND_STOP_NAME( msm5232 );			break;
+		case SNDINFO_PTR_RESET:							info->reset = SND_RESET_NAME( msm5232 );			break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "MSM5232";					break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "ADPCM";						break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "1.0";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "MSM5232");						break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Oki Tone");					break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.1");							break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);						break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
