@@ -105,15 +105,18 @@ static void update_namco_waveform(struct namco_sound *chip, int offset, UINT8 da
 
 
 /* build the decoded waveform table */
-static int build_decoded_waveform(struct namco_sound *chip, int region)
+static int build_decoded_waveform(struct namco_sound *chip, UINT8 *rgnbase)
 {
 	INT16 *p;
 	int size;
 	int offset;
 	int v;
 
+	if (rgnbase != NULL)
+		namco_wavedata = rgnbase;
+
 	/* 20pacgal has waves in RAM but old sound system */
-	if (region == -1 && chip->num_voices != 3)
+	if (rgnbase == NULL && chip->num_voices != 3)
 	{
 		chip->wave_size = 1;
 		size = 32 * 16;		/* 32 samples, 16 waveforms */
@@ -132,9 +135,6 @@ static int build_decoded_waveform(struct namco_sound *chip, int region)
 		p += size;
 	}
 
-	if (region != -1)
-		namco_wavedata = memory_region(region);
-
 	/* We need waveform data. It fails if region is not specified. */
 	if (namco_wavedata)
 	{
@@ -160,14 +160,14 @@ INLINE UINT32 namco_update_one(struct namco_sound *chip, stream_sample_t *buffer
 
 
 /* generate sound to the mix buffer in mono */
-static void namco_update_mono(void *param, stream_sample_t **inputs, stream_sample_t **_buffer, int length)
+static STREAM_UPDATE( namco_update_mono )
 {
 	struct namco_sound *chip = param;
-	stream_sample_t *buffer = _buffer[0];
+	stream_sample_t *buffer = outputs[0];
 	sound_channel *voice;
 
 	/* zap the contents of the buffer */
-	memset(buffer, 0, length * sizeof(*buffer));
+	memset(buffer, 0, samples * sizeof(*buffer));
 
 	/* if no sound, we're done */
 	if (chip->sound_enable == 0)
@@ -194,7 +194,7 @@ static void namco_update_mono(void *param, stream_sample_t **inputs, stream_samp
 				int i;
 
 				/* add our contribution */
-				for (i = 0; i < length; i++)
+				for (i = 0; i < samples; i++)
 				{
 					int cnt;
 
@@ -235,7 +235,7 @@ static void namco_update_mono(void *param, stream_sample_t **inputs, stream_samp
 				const INT16 *w = &chip->waveform[v][voice->waveform_select * 32];
 
 				/* generate sound into buffer and update the counter for this voice */
-				voice->counter = namco_update_one(chip, mix, length, w, voice->counter, voice->frequency);
+				voice->counter = namco_update_one(chip, mix, samples, w, voice->counter, voice->frequency);
 			}
 		}
 	}
@@ -243,14 +243,14 @@ static void namco_update_mono(void *param, stream_sample_t **inputs, stream_samp
 
 
 /* generate sound to the mix buffer in stereo */
-static void namco_update_stereo(void *param, stream_sample_t **inputs, stream_sample_t **buffer, int length)
+static STREAM_UPDATE( namco_update_stereo )
 {
 	struct namco_sound *chip = param;
 	sound_channel *voice;
 
 	/* zap the contents of the buffers */
-	memset(buffer[0], 0, length * sizeof(*buffer[0]));
-	memset(buffer[1], 0, length * sizeof(*buffer[1]));
+	memset(outputs[0], 0, samples * sizeof(*outputs[0]));
+	memset(outputs[1], 0, samples * sizeof(*outputs[1]));
 
 	/* if no sound, we're done */
 	if (chip->sound_enable == 0)
@@ -259,8 +259,8 @@ static void namco_update_stereo(void *param, stream_sample_t **inputs, stream_sa
 	/* loop over each voice and add its contribution */
 	for (voice = chip->channel_list; voice < chip->last_channel; voice++)
 	{
-		stream_sample_t *lmix = buffer[0];
-		stream_sample_t *rmix = buffer[1];
+		stream_sample_t *lmix = outputs[0];
+		stream_sample_t *rmix = outputs[1];
 		int lv = voice->volume[0];
 		int rv = voice->volume[1];
 
@@ -280,7 +280,7 @@ static void namco_update_stereo(void *param, stream_sample_t **inputs, stream_sa
 				int i;
 
 				/* add our contribution */
-				for (i = 0; i < length; i++)
+				for (i = 0; i < samples; i++)
 				{
 					int cnt;
 
@@ -333,7 +333,7 @@ static void namco_update_stereo(void *param, stream_sample_t **inputs, stream_sa
 					const INT16 *lw = &chip->waveform[lv][voice->waveform_select * 32];
 
 					/* generate sound into the buffer */
-					c = namco_update_one(chip, lmix, length, lw, voice->counter, voice->frequency);
+					c = namco_update_one(chip, lmix, samples, lw, voice->counter, voice->frequency);
 				}
 
 				/* only update if we have non-zero right volume */
@@ -342,7 +342,7 @@ static void namco_update_stereo(void *param, stream_sample_t **inputs, stream_sa
 					const INT16 *rw = &chip->waveform[rv][voice->waveform_select * 32];
 
 					/* generate sound into the buffer */
-					c = namco_update_one(chip, rmix, length, rw, voice->counter, voice->frequency);
+					c = namco_update_one(chip, rmix, samples, rw, voice->counter, voice->frequency);
 				}
 
 				/* update the counter for this voice */
@@ -353,10 +353,10 @@ static void namco_update_stereo(void *param, stream_sample_t **inputs, stream_sa
 }
 
 
-static void *namco_start(int sndindex, int clock, const void *config)
+static SND_START( namco )
 {
 	sound_channel *voice;
-	const struct namco_interface *intf = config;
+	const namco_interface *intf = config;
 	int clock_multiple;
 	struct namco_sound *chip;
 
@@ -381,28 +381,28 @@ static void *namco_start(int sndindex, int clock, const void *config)
 	logerror("Namco: freq fractional bits = %d: internal freq = %d, output freq = %d\n", chip->f_fracbits, chip->namco_clock, chip->sample_rate);
 
 	/* build the waveform table */
-	if (build_decoded_waveform(chip, intf->region))
+	if (build_decoded_waveform(chip, device->region))
 		return NULL;
 
 	/* get stream channels */
 	if (intf->stereo)
-		chip->stream = stream_create(0, 2, chip->sample_rate, chip, namco_update_stereo);
+		chip->stream = stream_create(device, 0, 2, chip->sample_rate, chip, namco_update_stereo);
 	else
-		chip->stream = stream_create(0, 1, chip->sample_rate, chip, namco_update_mono);
+		chip->stream = stream_create(device, 0, 1, chip->sample_rate, chip, namco_update_mono);
 
 	/* start with sound enabled, many games don't have a sound enable register */
 	chip->sound_enable = 1;
 
 	/* register with the save state system */
-	state_save_register_item("namco", sndindex, chip->num_voices);
-	state_save_register_item("namco", sndindex, chip->sound_enable);
-	state_save_register_item_pointer("namco", sndindex, chip->waveform[0],
+	state_save_register_device_item(device, 0, chip->num_voices);
+	state_save_register_device_item(device, 0, chip->sound_enable);
+	state_save_register_device_item_pointer(device, 0, chip->waveform[0],
 										 MAX_VOLUME * 32 * 8 * (1+chip->wave_size));
 
 	/* reset all the voices */
 	for (voice = chip->channel_list; voice < chip->last_channel; voice++)
 	{
-		int state_index = sndindex * MAX_VOICES + (voice - chip->channel_list);
+		int voicenum = voice - chip->channel_list;
 
 		voice->frequency = 0;
 		voice->volume[0] = voice->volume[1] = 0;
@@ -415,15 +415,15 @@ static void *namco_start(int sndindex, int clock, const void *config)
 		voice->noise_hold = 0;
 
 		/* register with the save state system */
-		state_save_register_item("namco", state_index, voice->frequency);
-		state_save_register_item("namco", state_index, voice->counter);
-		state_save_register_item_array("namco", state_index, voice->volume);
-		state_save_register_item("namco", state_index, voice->noise_sw);
-		state_save_register_item("namco", state_index, voice->noise_state);
-		state_save_register_item("namco", state_index, voice->noise_seed);
-		state_save_register_item("namco", state_index, voice->noise_hold);
-		state_save_register_item("namco", state_index, voice->noise_counter);
-		state_save_register_item("namco", state_index, voice->waveform_select);
+		state_save_register_device_item(device, voicenum, voice->frequency);
+		state_save_register_device_item(device, voicenum, voice->counter);
+		state_save_register_device_item_array(device, voicenum, voice->volume);
+		state_save_register_device_item(device, voicenum, voice->noise_sw);
+		state_save_register_device_item(device, voicenum, voice->noise_state);
+		state_save_register_device_item(device, voicenum, voice->noise_seed);
+		state_save_register_device_item(device, voicenum, voice->noise_hold);
+		state_save_register_device_item(device, voicenum, voice->noise_counter);
+		state_save_register_device_item(device, voicenum, voice->waveform_select);
 	}
 
 	return chip;
@@ -771,7 +771,7 @@ WRITE8_HANDLER( namcos1_cus30_w )
 		}
 	}
 	else if (offset < 0x140)
-		namcos1_sound_w(offset - 0x100,data);
+		namcos1_sound_w(space, offset - 0x100,data);
 	else
 		namco_wavedata[offset] = data;
 }
@@ -797,29 +797,6 @@ WRITE8_HANDLER( _20pacgal_wavedata_w )
 	}
 }
 
-/********************************************************************************/
-
-WRITE8_HANDLER( snkwave_w )
-{
-	struct namco_sound *chip = sndti_token(SOUND_NAMCO, 0);
-	static int freq0 = 0xff;
-	sound_channel *voice = chip->channel_list;
-	if( offset==0 ) freq0 = data;
-	if( offset==1 )
-	{
-		stream_update(chip->stream);
-		if( data==0xff || freq0==0 )
-		{
-			voice->volume[0] = 0x0;
-		}
-		else
-		{
-			voice->volume[0] = 0x8;
-			voice->frequency = (data<<16)/freq0;
-		}
-	}
-}
-
 
 
 
@@ -827,7 +804,7 @@ WRITE8_HANDLER( snkwave_w )
  * Generic get_info
  **************************************************************************/
 
-static void namco_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( namco )
 {
 	switch (state)
 	{
@@ -836,24 +813,24 @@ static void namco_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void namco_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( namco )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = namco_set_info;		break;
-		case SNDINFO_PTR_START:							info->start = namco_start;				break;
-		case SNDINFO_PTR_STOP:							/* Nothing */							break;
-		case SNDINFO_PTR_RESET:							/* Nothing */							break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( namco );	break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( namco );			break;
+		case SNDINFO_PTR_STOP:							/* Nothing */									break;
+		case SNDINFO_PTR_RESET:							/* Nothing */									break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "Namco";						break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "Namco custom";				break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "1.0";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "Namco");						break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Namco custom");				break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.0");							break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);						break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
@@ -861,7 +838,7 @@ void namco_get_info(void *token, UINT32 state, sndinfo *info)
  * Generic get_info
  **************************************************************************/
 
-static void namco_15xx_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( namco_15xx )
 {
 	switch (state)
 	{
@@ -870,24 +847,24 @@ static void namco_15xx_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void namco_15xx_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( namco_15xx )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = namco_15xx_set_info;	break;
-		case SNDINFO_PTR_START:							info->start = namco_start;				break;
-		case SNDINFO_PTR_STOP:							/* Nothing */							break;
-		case SNDINFO_PTR_RESET:							/* Nothing */							break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( namco_15xx );	break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( namco );				break;
+		case SNDINFO_PTR_STOP:							/* Nothing */										break;
+		case SNDINFO_PTR_RESET:							/* Nothing */										break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "Namco 15XX";					break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "Namco custom";				break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "1.0";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "Namco 15XX");						break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Namco custom");					break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.0");								break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);							break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
@@ -895,7 +872,7 @@ void namco_15xx_get_info(void *token, UINT32 state, sndinfo *info)
  * Generic get_info
  **************************************************************************/
 
-static void namco_cus30_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( namco_cus30 )
 {
 	switch (state)
 	{
@@ -904,24 +881,24 @@ static void namco_cus30_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void namco_cus30_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( namco_cus30 )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = namco_cus30_set_info;	break;
-		case SNDINFO_PTR_START:							info->start = namco_start;				break;
-		case SNDINFO_PTR_STOP:							/* Nothing */							break;
-		case SNDINFO_PTR_RESET:							/* Nothing */							break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( namco_cus30 );	break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( namco );				break;
+		case SNDINFO_PTR_STOP:							/* Nothing */										break;
+		case SNDINFO_PTR_RESET:							/* Nothing */										break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "Namco CUS30";				break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "Namco custom";				break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "1.0";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "Namco CUS30");						break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Namco custom");					break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.0");								break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);							break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
