@@ -60,22 +60,37 @@ static const int index_shift[8] = { -1, -1, -1, -1, 2, 4, 6, 8 };
 /* lookup table for the precomputed difference */
 static int diff_lookup[49*16];
 
-/* volume lookup table */
-static UINT32 volume_table[16];
+/* volume lookup table. The manual lists only 9 steps, ~3dB per step. Given the dB values,
+   that seems to map to a 5-bit volume control. What happens for steps after the 9th is not
+    known, we arbitrarily assign a "1" to all those steps. */
+static int volume_table[16] =
+{
+	0x20,	//   0 dB
+	0x16,	//  -3.2 dB
+	0x10,	//  -6.0 dB
+	0x0b,	//  -9.2 dB
+	0x08,	// -12.0 dB
+	0x06,	// -14.5 dB
+	0x04,	// -18.0 dB
+	0x03,	// -20.5 dB
+	0x02,	// -24.0 dB
+	0x01,	// unknown
+	0x01,	// unknown
+	0x01,	// unknown
+	0x01,	// unknown
+	0x01,	// unknown
+	0x01,	// unknown
+	0x01,	// unknown
+};
 
 /* tables computed? */
 static int tables_computed = 0;
 
 /* useful interfaces */
-const struct OKIM6295interface okim6295_interface_region_1_pin7high = { REGION_SOUND1, 1 };
-const struct OKIM6295interface okim6295_interface_region_2_pin7high = { REGION_SOUND2, 1 };
-const struct OKIM6295interface okim6295_interface_region_3_pin7high = { REGION_SOUND3, 1 };
-const struct OKIM6295interface okim6295_interface_region_4_pin7high = { REGION_SOUND4, 1 };
+const okim6295_interface okim6295_interface_pin7high = { 1 };
+const okim6295_interface okim6295_interface_pin7low = { 0 };
+
 
-const struct OKIM6295interface okim6295_interface_region_1_pin7low = { REGION_SOUND1, 0 };
-const struct OKIM6295interface okim6295_interface_region_2_pin7low = { REGION_SOUND2, 0 };
-const struct OKIM6295interface okim6295_interface_region_3_pin7low = { REGION_SOUND3, 0 };
-const struct OKIM6295interface okim6295_interface_region_4_pin7low = { REGION_SOUND4, 0 };
 
 /**********************************************************************************************
 
@@ -113,18 +128,6 @@ static void compute_tables(void)
 		}
 	}
 
-	/* generate the OKI6295 volume table */
-	for (step = 0; step < 16; step++)
-	{
-		double out = 256.0;
-		int vol = step;
-
-		/* 3dB per step */
-		while (vol-- > 0)
-			out /= 1.412537545;	/* = 10 ^ (3/20) = 3dB */
-		volume_table[step] = (UINT32)out;
-	}
-
 	tables_computed = 1;
 }
 
@@ -172,8 +175,8 @@ INT16 clock_adpcm(struct adpcm_state *state, UINT8 nibble)
 	else if (state->step < 0)
 		state->step = 0;
 
-	/* return the signal scaled up to 32767 */
-	return state->signal << 4;
+	/* return the signal */
+	return state->signal;
 }
 
 
@@ -200,7 +203,8 @@ static void generate_adpcm(struct okim6295 *chip, struct ADPCMVoice *voice, INT1
 			int nibble = base[sample / 2] >> (((sample & 1) << 2) ^ 4);
 
 			/* output to the buffer, scaling by the volume */
-			*buffer++ = clock_adpcm(&voice->adpcm, nibble) * voice->volume / 256;
+			/* signal in range -2048..2047, volume in range 2..32 => signal * volume / 2 in range -32768..32767 */
+			*buffer++ = clock_adpcm(&voice->adpcm, nibble) * voice->volume / 2;
 			samples--;
 
 			/* next! */
@@ -247,7 +251,7 @@ static void generate_adpcm(struct okim6295 *chip, struct ADPCMVoice *voice, INT1
 
 ***********************************************************************************************/
 
-static void okim6295_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+static STREAM_UPDATE( okim6295_update )
 {
 	struct okim6295 *chip = param;
 	int i;
@@ -284,45 +288,38 @@ static void okim6295_update(void *param, stream_sample_t **inputs, stream_sample
 
 ***********************************************************************************************/
 
-static void adpcm_state_save_register(struct ADPCMVoice *voice, int i)
+static void adpcm_state_save_register(struct ADPCMVoice *voice, const device_config *device, int index)
 {
-	char buf[20];
-
-	sprintf(buf,"ADPCM");
-
-	state_save_register_item(buf, i, voice->playing);
-	state_save_register_item(buf, i, voice->sample);
-	state_save_register_item(buf, i, voice->count);
-	state_save_register_item(buf, i, voice->adpcm.signal);
-	state_save_register_item(buf, i, voice->adpcm.step);
-	state_save_register_item(buf, i, voice->volume);
-	state_save_register_item(buf, i, voice->base_offset);
+	state_save_register_device_item(device, index, voice->playing);
+	state_save_register_device_item(device, index, voice->sample);
+	state_save_register_device_item(device, index, voice->count);
+	state_save_register_device_item(device, index, voice->adpcm.signal);
+	state_save_register_device_item(device, index, voice->adpcm.step);
+	state_save_register_device_item(device, index, voice->volume);
+	state_save_register_device_item(device, index, voice->base_offset);
 }
 
-static void okim6295_state_save_register(struct okim6295 *info, int sndindex)
+static void okim6295_state_save_register(struct okim6295 *info, const device_config *device)
 {
 	int j;
-	char buf[20];
 
-	sprintf(buf,"OKIM6295");
-
-	state_save_register_item(buf, sndindex, info->command);
-	state_save_register_item(buf, sndindex, info->bank_offset);
+	state_save_register_device_item(device, 0, info->command);
+	state_save_register_device_item(device, 0, info->bank_offset);
 	for (j = 0; j < OKIM6295_VOICES; j++)
-		adpcm_state_save_register(&info->voice[j], sndindex * 4 + j);
+		adpcm_state_save_register(&info->voice[j], device, j);
 }
 
 
 
 /**********************************************************************************************
 
-     OKIM6295_start -- start emulation of an OKIM6295-compatible chip
+     SND_START( okim6295 ) -- start emulation of an OKIM6295-compatible chip
 
 ***********************************************************************************************/
 
-static void *okim6295_start(int sndindex, int clock, const void *config)
+static SND_START( okim6295 )
 {
-	const struct OKIM6295interface *intf = config;
+	const okim6295_interface *intf = config;
 	struct okim6295 *info;
 	int voice;
 	int divisor = intf->pin7 ? 132 : 165;
@@ -334,22 +331,24 @@ static void *okim6295_start(int sndindex, int clock, const void *config)
 
 	info->command = -1;
 	info->bank_offset = 0;
-	info->region_base = memory_region(intf->region);
+	info->region_base = device->region;
+	if (intf->rgnoverride != NULL)
+		info->region_base = memory_region(device->machine, intf->rgnoverride);
 
 	info->master_clock = clock;
 
 	/* generate the name and create the stream */
-	info->stream = stream_create(0, 1, clock/divisor, info, okim6295_update);
+	info->stream = stream_create(device, 0, 1, clock/divisor, info, okim6295_update);
 
 	/* initialize the voices */
 	for (voice = 0; voice < OKIM6295_VOICES; voice++)
 	{
 		/* initialize the rest of the structure */
-		info->voice[voice].volume = 255;
+		info->voice[voice].volume = 0;
 		reset_adpcm(&info->voice[voice].adpcm);
 	}
 
-	okim6295_state_save_register(info, sndindex);
+	okim6295_state_save_register(info, device);
 
 	/* success */
 	return info;
@@ -359,13 +358,13 @@ static void *okim6295_start(int sndindex, int clock, const void *config)
 
 /**********************************************************************************************
 
-     OKIM6295_stop -- stop emulation of an OKIM6295-compatible chip
+     SND_RESET( okim6295 ) -- stop emulation of an OKIM6295-compatible chip
 
 ***********************************************************************************************/
 
-static void okim6295_reset(void *chip)
+static SND_RESET( okim6295 )
 {
-	struct okim6295 *info = chip;
+	struct okim6295 *info = device->token;
 	int i;
 
 	stream_update(info->stream);
@@ -377,11 +376,11 @@ static void okim6295_reset(void *chip)
 
 /**********************************************************************************************
 
-     OKIM6295_set_bank_base -- set the base of the bank for a given voice on a given chip
+     okim6295_set_bank_base -- set the base of the bank for a given voice on a given chip
 
 ***********************************************************************************************/
 
-void OKIM6295_set_bank_base(int which, int base)
+void okim6295_set_bank_base(int which, int base)
 {
 	struct okim6295 *info = sndti_token(SOUND_OKIM6295, which);
 	stream_update(info->stream);
@@ -392,11 +391,11 @@ void OKIM6295_set_bank_base(int which, int base)
 
 /**********************************************************************************************
 
-     OKIM6295_set_pin7 -- adjust pin 7, which controls the internal clock division
+     okim6295_set_pin7 -- adjust pin 7, which controls the internal clock division
 
 ***********************************************************************************************/
 
-void OKIM6295_set_pin7(int which, int pin7)
+void okim6295_set_pin7(int which, int pin7)
 {
 	struct okim6295 *info = sndti_token(SOUND_OKIM6295, which);
 	int divisor = pin7 ? 132 : 165;
@@ -407,11 +406,11 @@ void OKIM6295_set_pin7(int which, int pin7)
 
 /**********************************************************************************************
 
-     OKIM6295_status_r -- read the status port of an OKIM6295-compatible chip
+     okim6295_status_r -- read the status port of an OKIM6295-compatible chip
 
 ***********************************************************************************************/
 
-static int OKIM6295_status_r(int num)
+static int okim6295_status_r(int num)
 {
 	struct okim6295 *info = sndti_token(SOUND_OKIM6295, num);
 	int i, result;
@@ -436,11 +435,11 @@ static int OKIM6295_status_r(int num)
 
 /**********************************************************************************************
 
-     OKIM6295_data_w -- write to the data port of an OKIM6295-compatible chip
+     okim6295_data_w -- write to the data port of an OKIM6295-compatible chip
 
 ***********************************************************************************************/
 
-static void OKIM6295_data_w(int num, int data)
+static void okim6295_data_w(int num, int data)
 {
 	struct okim6295 *info = sndti_token(SOUND_OKIM6295, num);
 
@@ -450,6 +449,11 @@ static void OKIM6295_data_w(int num, int data)
 		int temp = data >> 4, i, start, stop;
 		unsigned char *base;
 
+
+		/* the manual explicitly says that it's not possible to start multiple voices at the same time */
+		if (temp != 0 && temp != 1 && temp != 2 && temp != 4 && temp != 8)
+			popmessage("OKI6295 start %x contact MAMEDEV", temp);
+
 		/* update the stream */
 		stream_update(info->stream);
 
@@ -478,6 +482,10 @@ static void OKIM6295_data_w(int num, int data)
 						/* also reset the ADPCM parameters */
 						reset_adpcm(&voice->adpcm);
 						voice->volume = volume_table[data & 0x0f];
+
+						/* the manual only lists 9 volume steps */
+						if ((data & 0x0f) >= 9)
+							popmessage("OKI6295 volume %x contact MAMEDEV", data & 0x0f);
 					}
 					else
 					{
@@ -528,114 +536,114 @@ static void OKIM6295_data_w(int num, int data)
 
 /**********************************************************************************************
 
-     OKIM6295_status_0_r -- generic status read functions
-     OKIM6295_status_1_r
+     okim6295_status_0_r -- generic status read functions
+     okim6295_status_1_r
 
 ***********************************************************************************************/
 
-READ8_HANDLER( OKIM6295_status_0_r )
+READ8_HANDLER( okim6295_status_0_r )
 {
-	return OKIM6295_status_r(0);
+	return okim6295_status_r(0);
 }
 
-READ8_HANDLER( OKIM6295_status_1_r )
+READ8_HANDLER( okim6295_status_1_r )
 {
-	return OKIM6295_status_r(1);
+	return okim6295_status_r(1);
 }
 
-READ8_HANDLER( OKIM6295_status_2_r )
+READ8_HANDLER( okim6295_status_2_r )
 {
-	return OKIM6295_status_r(2);
+	return okim6295_status_r(2);
 }
 
-READ16_HANDLER( OKIM6295_status_0_lsb_r )
+READ16_HANDLER( okim6295_status_0_lsb_r )
 {
-	return OKIM6295_status_r(0);
+	return okim6295_status_r(0);
 }
 
-READ16_HANDLER( OKIM6295_status_1_lsb_r )
+READ16_HANDLER( okim6295_status_1_lsb_r )
 {
-	return OKIM6295_status_r(1);
+	return okim6295_status_r(1);
 }
 
-READ16_HANDLER( OKIM6295_status_2_lsb_r )
+READ16_HANDLER( okim6295_status_2_lsb_r )
 {
-	return OKIM6295_status_r(2);
+	return okim6295_status_r(2);
 }
 
-READ16_HANDLER( OKIM6295_status_0_msb_r )
+READ16_HANDLER( okim6295_status_0_msb_r )
 {
-	return OKIM6295_status_r(0) << 8;
+	return okim6295_status_r(0) << 8;
 }
 
-READ16_HANDLER( OKIM6295_status_1_msb_r )
+READ16_HANDLER( okim6295_status_1_msb_r )
 {
-	return OKIM6295_status_r(1) << 8;
+	return okim6295_status_r(1) << 8;
 }
 
-READ16_HANDLER( OKIM6295_status_2_msb_r )
+READ16_HANDLER( okim6295_status_2_msb_r )
 {
-	return OKIM6295_status_r(2) << 8;
+	return okim6295_status_r(2) << 8;
 }
 
 
 
 /**********************************************************************************************
 
-     OKIM6295_data_0_w -- generic data write functions
-     OKIM6295_data_1_w
+     okim6295_data_0_w -- generic data write functions
+     okim6295_data_1_w
 
 ***********************************************************************************************/
 
-WRITE8_HANDLER( OKIM6295_data_0_w )
+WRITE8_HANDLER( okim6295_data_0_w )
 {
-	OKIM6295_data_w(0, data);
+	okim6295_data_w(0, data);
 }
 
-WRITE8_HANDLER( OKIM6295_data_1_w )
+WRITE8_HANDLER( okim6295_data_1_w )
 {
-	OKIM6295_data_w(1, data);
+	okim6295_data_w(1, data);
 }
 
-WRITE8_HANDLER( OKIM6295_data_2_w )
+WRITE8_HANDLER( okim6295_data_2_w )
 {
-	OKIM6295_data_w(2, data);
+	okim6295_data_w(2, data);
 }
 
-WRITE16_HANDLER( OKIM6295_data_0_lsb_w )
+WRITE16_HANDLER( okim6295_data_0_lsb_w )
 {
-	if (ACCESSING_LSB)
-		OKIM6295_data_w(0, data & 0xff);
+	if (ACCESSING_BITS_0_7)
+		okim6295_data_w(0, data & 0xff);
 }
 
-WRITE16_HANDLER( OKIM6295_data_1_lsb_w )
+WRITE16_HANDLER( okim6295_data_1_lsb_w )
 {
-	if (ACCESSING_LSB)
-		OKIM6295_data_w(1, data & 0xff);
+	if (ACCESSING_BITS_0_7)
+		okim6295_data_w(1, data & 0xff);
 }
 
-WRITE16_HANDLER( OKIM6295_data_2_lsb_w )
+WRITE16_HANDLER( okim6295_data_2_lsb_w )
 {
-	if (ACCESSING_LSB)
-		OKIM6295_data_w(2, data & 0xff);
+	if (ACCESSING_BITS_0_7)
+		okim6295_data_w(2, data & 0xff);
 }
 
-WRITE16_HANDLER( OKIM6295_data_0_msb_w )
+WRITE16_HANDLER( okim6295_data_0_msb_w )
 {
-	if (ACCESSING_MSB)
-		OKIM6295_data_w(0, data >> 8);
+	if (ACCESSING_BITS_8_15)
+		okim6295_data_w(0, data >> 8);
 }
 
-WRITE16_HANDLER( OKIM6295_data_1_msb_w )
+WRITE16_HANDLER( okim6295_data_1_msb_w )
 {
-	if (ACCESSING_MSB)
-		OKIM6295_data_w(1, data >> 8);
+	if (ACCESSING_BITS_8_15)
+		okim6295_data_w(1, data >> 8);
 }
 
-WRITE16_HANDLER( OKIM6295_data_2_msb_w )
+WRITE16_HANDLER( okim6295_data_2_msb_w )
 {
-	if (ACCESSING_MSB)
-		OKIM6295_data_w(2, data >> 8);
+	if (ACCESSING_BITS_8_15)
+		okim6295_data_w(2, data >> 8);
 }
 
 
@@ -644,7 +652,7 @@ WRITE16_HANDLER( OKIM6295_data_2_msb_w )
  * Generic get_info
  **************************************************************************/
 
-static void okim6295_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( okim6295 )
 {
 	switch (state)
 	{
@@ -653,24 +661,24 @@ static void okim6295_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void okim6295_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( okim6295 )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = okim6295_set_info;		break;
-		case SNDINFO_PTR_START:							info->start = okim6295_start;			break;
-		case SNDINFO_PTR_STOP:							/* nothing */							break;
-		case SNDINFO_PTR_RESET:							info->reset = okim6295_reset;			break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( okim6295 );		break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( okim6295 );			break;
+		case SNDINFO_PTR_STOP:							/* nothing */										break;
+		case SNDINFO_PTR_RESET:							info->reset = SND_RESET_NAME( okim6295 );			break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "OKI6295";					break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "OKI ADPCM";					break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "1.0";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "OKI6295");							break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "OKI ADPCM");						break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.0");								break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);							break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
