@@ -52,6 +52,7 @@
 #include "sndintrf.h"
 #include "streams.h"
 #include "cpuintrf.h"
+#include "cpuexec.h"
 #include "pokey.h"
 
 /*
@@ -167,25 +168,26 @@ struct POKEYregisters
 	UINT32 samplepos_fract; /* sample position fractional part */
 	UINT32 samplepos_whole; /* sample position whole part */
 	UINT32 polyadjust;		/* polynome adjustment */
-    UINT32 p4;              /* poly4 index */
-    UINT32 p5;              /* poly5 index */
-    UINT32 p9;              /* poly9 index */
-    UINT32 p17;             /* poly17 index */
+	UINT32 p4;              /* poly4 index */
+	UINT32 p5;              /* poly5 index */
+	UINT32 p9;              /* poly9 index */
+	UINT32 p17;             /* poly17 index */
 	UINT32 r9;				/* rand9 index */
-    UINT32 r17;             /* rand17 index */
+	UINT32 r17;             /* rand17 index */
 	UINT32 clockmult;		/* clock multiplier */
-    sound_stream * channel; /* streams channel */
+	const device_config *device;
+	sound_stream * channel; /* streams channel */
 	emu_timer *timer[3]; 	/* timers for channel 1,2 and 4 events */
 	attotime timer_period[3];	/* computed periods for these timers */
 	int timer_param[3];		/* computed parameters for these timers */
 	emu_timer *rtimer;     /* timer for calculating the random offset */
 	emu_timer *ptimer[8];	/* pot timers */
-	read8_handler pot_r[8];
-	read8_handler allpot_r;
-	read8_handler serin_r;
-	write8_handler serout_w;
-	void (*interrupt_cb)(int mask);
-    UINT8 AUDF[4];          /* AUDFx (D200, D202, D204, D206) */
+	read8_space_func pot_r[8];
+	read8_space_func allpot_r;
+	read8_space_func serin_r;
+	write8_space_func serout_w;
+	void (*interrupt_cb)(running_machine *machine, int mask);
+	UINT8 AUDF[4];          /* AUDFx (D200, D202, D204, D206) */
 	UINT8 AUDC[4];			/* AUDCx (D201, D203, D205, D207) */
 	UINT8 POTx[8];			/* POTx   (R/D200-D207) */
 	UINT8 AUDCTL;			/* AUDCTL (W/D208) */
@@ -198,7 +200,7 @@ struct POKEYregisters
 	UINT8 IRQEN;			/* IRQEN  (W/D20E) */
 	UINT8 SKSTAT;			/* SKSTAT (R/D20F) */
 	UINT8 SKCTL;			/* SKCTL  (W/D20F) */
-	struct POKEYinterface intf;
+	pokey_interface intf;
 	attotime clock_period;
 	attotime ad_time_fast;
 	attotime ad_time_slow;
@@ -334,7 +336,7 @@ static TIMER_CALLBACK( pokey_pot_trigger );
 	chip->samplepos_whole++;											\
 	/* store sum of output signals into the buffer */					\
 	*buffer++ = (sum > 0x7fff) ? 0x7fff : sum;							\
-	length--
+	samples--
 
 #if HEAVY_MACRO_USAGE
 
@@ -355,7 +357,7 @@ static TIMER_CALLBACK( pokey_pot_trigger );
 		sum += chip->volume[CHAN3];										\
 	if( chip->output[CHAN4] ) 											\
 		sum += chip->volume[CHAN4];										\
-    while( length > 0 )                                                 \
+    while( samples > 0 )                                                 \
 	{																	\
 		if( chip->counter[CHAN1] < chip->samplepos_whole )				\
 		{																\
@@ -466,7 +468,7 @@ static TIMER_CALLBACK( pokey_pot_trigger );
 			PROCESS_SAMPLE(chip);										\
 		}																\
 	}																	\
-	timer_adjust(chip->rtimer, attotime_never, 0, attotime_zero)
+	timer_adjust_oneshot(chip->rtimer, attotime_never, 0)
 
 #else   /* no HEAVY_MACRO_USAGE */
 /*
@@ -483,8 +485,8 @@ static TIMER_CALLBACK( pokey_pot_trigger );
 	if( chip->output[CHAN3] ) 											\
 		sum += chip->volume[CHAN3];										\
 	if( chip->output[CHAN4] ) 											\
-        sum += chip->volume[CHAN4];                               		\
-    while( length > 0 )                                                 \
+        sum += chip->volume[CHAN4];                                     \
+	while( samples > 0 )                                                 \
 	{																	\
 		UINT32 event = chip->samplepos_whole; 							\
 		UINT32 channel = SAMPLE;										\
@@ -517,15 +519,15 @@ static TIMER_CALLBACK( pokey_pot_trigger );
 			PROCESS_CHANNEL(chip,channel);								\
 		}																\
 	}																	\
-	timer_adjust(chip->rtimer, attotime_never, 0, attotime_zero)
+	timer_adjust_oneshot(chip->rtimer, attotime_never, 0)
 
 #endif
 
 
-static void pokey_update(void *param, stream_sample_t **inputs, stream_sample_t **_buffer, int length)
+static STREAM_UPDATE( pokey_update )
 {
 	struct POKEYregisters *chip = param;
-	stream_sample_t *buffer = _buffer[0];
+	stream_sample_t *buffer = outputs[0];
 	PROCESS_POKEY(chip);
 }
 
@@ -565,56 +567,58 @@ static void rand_init(UINT8 *rng, int size, int left, int right, int add)
 }
 
 
-static void register_for_save(struct POKEYregisters *chip, int index)
+static void register_for_save(struct POKEYregisters *chip, const device_config *device)
 {
-	state_save_register_item_array("pokey", index, chip->counter);
-	state_save_register_item_array("pokey", index, chip->divisor);
-	state_save_register_item_array("pokey", index, chip->volume);
-	state_save_register_item_array("pokey", index, chip->output);
-	state_save_register_item_array("pokey", index, chip->audible);
-	state_save_register_item("pokey", index, chip->samplepos_fract);
-	state_save_register_item("pokey", index, chip->samplepos_whole);
-	state_save_register_item("pokey", index, chip->polyadjust);
-	state_save_register_item("pokey", index, chip->p4);
-	state_save_register_item("pokey", index, chip->p5);
-	state_save_register_item("pokey", index, chip->p9);
-	state_save_register_item("pokey", index, chip->p17);
-	state_save_register_item("pokey", index, chip->r9);
-	state_save_register_item("pokey", index, chip->r17);
-	state_save_register_item("pokey", index, chip->clockmult);
-	state_save_register_item("pokey", index, chip->timer_period[0].seconds);
-	state_save_register_item("pokey", index, chip->timer_period[0].attoseconds);
-	state_save_register_item("pokey", index, chip->timer_period[1].seconds);
-	state_save_register_item("pokey", index, chip->timer_period[1].attoseconds);
-	state_save_register_item("pokey", index, chip->timer_period[2].seconds);
-	state_save_register_item("pokey", index, chip->timer_period[2].attoseconds);
-	state_save_register_item_array("pokey", index, chip->timer_param);
-	state_save_register_item_array("pokey", index, chip->AUDF);
-	state_save_register_item_array("pokey", index, chip->AUDC);
-	state_save_register_item_array("pokey", index, chip->POTx);
-	state_save_register_item("pokey", index, chip->AUDCTL);
-	state_save_register_item("pokey", index, chip->ALLPOT);
-	state_save_register_item("pokey", index, chip->KBCODE);
-	state_save_register_item("pokey", index, chip->RANDOM);
-	state_save_register_item("pokey", index, chip->SERIN);
-	state_save_register_item("pokey", index, chip->SEROUT);
-	state_save_register_item("pokey", index, chip->IRQST);
-	state_save_register_item("pokey", index, chip->IRQEN);
-	state_save_register_item("pokey", index, chip->SKSTAT);
-	state_save_register_item("pokey", index, chip->SKCTL);
+	state_save_register_device_item_array(device, 0, chip->counter);
+	state_save_register_device_item_array(device, 0, chip->divisor);
+	state_save_register_device_item_array(device, 0, chip->volume);
+	state_save_register_device_item_array(device, 0, chip->output);
+	state_save_register_device_item_array(device, 0, chip->audible);
+	state_save_register_device_item(device, 0, chip->samplepos_fract);
+	state_save_register_device_item(device, 0, chip->samplepos_whole);
+	state_save_register_device_item(device, 0, chip->polyadjust);
+	state_save_register_device_item(device, 0, chip->p4);
+	state_save_register_device_item(device, 0, chip->p5);
+	state_save_register_device_item(device, 0, chip->p9);
+	state_save_register_device_item(device, 0, chip->p17);
+	state_save_register_device_item(device, 0, chip->r9);
+	state_save_register_device_item(device, 0, chip->r17);
+	state_save_register_device_item(device, 0, chip->clockmult);
+	state_save_register_device_item(device, 0, chip->timer_period[0].seconds);
+	state_save_register_device_item(device, 0, chip->timer_period[0].attoseconds);
+	state_save_register_device_item(device, 0, chip->timer_period[1].seconds);
+	state_save_register_device_item(device, 0, chip->timer_period[1].attoseconds);
+	state_save_register_device_item(device, 0, chip->timer_period[2].seconds);
+	state_save_register_device_item(device, 0, chip->timer_period[2].attoseconds);
+	state_save_register_device_item_array(device, 0, chip->timer_param);
+	state_save_register_device_item_array(device, 0, chip->AUDF);
+	state_save_register_device_item_array(device, 0, chip->AUDC);
+	state_save_register_device_item_array(device, 0, chip->POTx);
+	state_save_register_device_item(device, 0, chip->AUDCTL);
+	state_save_register_device_item(device, 0, chip->ALLPOT);
+	state_save_register_device_item(device, 0, chip->KBCODE);
+	state_save_register_device_item(device, 0, chip->RANDOM);
+	state_save_register_device_item(device, 0, chip->SERIN);
+	state_save_register_device_item(device, 0, chip->SEROUT);
+	state_save_register_device_item(device, 0, chip->IRQST);
+	state_save_register_device_item(device, 0, chip->IRQEN);
+	state_save_register_device_item(device, 0, chip->SKSTAT);
+	state_save_register_device_item(device, 0, chip->SKCTL);
 }
 
 
-static void *pokey_start(int sndindex, int clock, const void *config)
+static SND_START( pokey )
 {
 	struct POKEYregisters *chip;
 	int sample_rate = clock;
+	int i;
 
 	chip = auto_malloc(sizeof(*chip));
 	memset(chip, 0, sizeof(*chip));
 
 	if (config)
-		memcpy(&chip->intf, config, sizeof(struct POKEYinterface));
+		memcpy(&chip->intf, config, sizeof(pokey_interface));
+	chip->device = device;
 	chip->clock_period = ATTOTIME_IN_HZ(clock);
 	chip->index = sndindex;
 
@@ -646,37 +650,25 @@ static void *pokey_start(int sndindex, int clock, const void *config)
 	chip->clockmult = DIV_64;
 	chip->KBCODE = 0x09;		 /* Atari 800 'no key' */
 	chip->SKCTL = SK_RESET;	 /* let the RNG run after reset */
-	chip->rtimer = timer_alloc(NULL, NULL);
+	chip->rtimer = timer_alloc(device->machine,  NULL, NULL);
 
-	chip->timer[0] = timer_alloc(pokey_timer_expire, chip);
-	chip->timer[1] = timer_alloc(pokey_timer_expire, chip);
-	chip->timer[2] = timer_alloc(pokey_timer_expire, chip);
+	chip->timer[0] = timer_alloc(device->machine, pokey_timer_expire, chip);
+	chip->timer[1] = timer_alloc(device->machine, pokey_timer_expire, chip);
+	chip->timer[2] = timer_alloc(device->machine, pokey_timer_expire, chip);
 
-	chip->ptimer[0] = timer_alloc(pokey_pot_trigger, chip);
-	chip->ptimer[1] = timer_alloc(pokey_pot_trigger, chip);
-	chip->ptimer[2] = timer_alloc(pokey_pot_trigger, chip);
-	chip->ptimer[3] = timer_alloc(pokey_pot_trigger, chip);
-	chip->ptimer[4] = timer_alloc(pokey_pot_trigger, chip);
-	chip->ptimer[5] = timer_alloc(pokey_pot_trigger, chip);
-	chip->ptimer[6] = timer_alloc(pokey_pot_trigger, chip);
-	chip->ptimer[7] = timer_alloc(pokey_pot_trigger, chip);
-
-	chip->pot_r[0] = chip->intf.pot_r[0];
-	chip->pot_r[1] = chip->intf.pot_r[1];
-	chip->pot_r[2] = chip->intf.pot_r[2];
-	chip->pot_r[3] = chip->intf.pot_r[3];
-	chip->pot_r[4] = chip->intf.pot_r[4];
-	chip->pot_r[5] = chip->intf.pot_r[5];
-	chip->pot_r[6] = chip->intf.pot_r[6];
-	chip->pot_r[7] = chip->intf.pot_r[7];
+	for (i=0; i<8; i++)
+	{
+		chip->ptimer[i] = timer_alloc(device->machine, pokey_pot_trigger, chip);
+		chip->pot_r[i] = chip->intf.pot_r[i];
+	}
 	chip->allpot_r = chip->intf.allpot_r;
 	chip->serin_r = chip->intf.serin_r;
 	chip->serout_w = chip->intf.serout_w;
 	chip->interrupt_cb = chip->intf.interrupt_cb;
 
-	chip->channel = stream_create(0, 1, sample_rate, chip, pokey_update);
+	chip->channel = stream_create(device, 0, 1, sample_rate, chip, pokey_update);
 
-	register_for_save(chip, sndindex);
+	register_for_save(chip, device);
 
     return chip;
 }
@@ -697,7 +689,7 @@ static TIMER_CALLBACK( pokey_timer_expire )
 		p->IRQST |= timers;
         /* call back an application supplied function to handle the interrupt */
 		if( p->interrupt_cb )
-			(*p->interrupt_cb)(timers);
+			(*p->interrupt_cb)(machine, timers);
     }
 }
 
@@ -760,7 +752,7 @@ static TIMER_CALLBACK( pokey_serin_ready )
 		p->IRQST |= IRQ_SERIN;
 		/* call back an application supplied function to handle the interrupt */
 		if( p->interrupt_cb )
-			(*p->interrupt_cb)(IRQ_SERIN);
+			(*p->interrupt_cb)(machine, IRQ_SERIN);
 	}
 }
 
@@ -771,7 +763,7 @@ static TIMER_CALLBACK( pokey_serout_ready )
 	{
 		p->IRQST |= IRQ_SEROR;
 		if( p->interrupt_cb )
-			(*p->interrupt_cb)(IRQ_SEROR);
+			(*p->interrupt_cb)(machine, IRQ_SEROR);
 	}
 }
 
@@ -782,7 +774,7 @@ static TIMER_CALLBACK( pokey_serout_complete )
 	{
 		p->IRQST |= IRQ_SEROC;
 		if( p->interrupt_cb )
-			(*p->interrupt_cb)(IRQ_SEROC);
+			(*p->interrupt_cb)(machine, IRQ_SEROC);
 	}
 }
 
@@ -796,7 +788,7 @@ static TIMER_CALLBACK( pokey_pot_trigger )
 
 #define AD_TIME  ((p->SKCTL & SK_PADDLE) ? p->ad_time_fast : p->ad_time_slow)
 
-static void pokey_potgo(struct POKEYregisters *p)
+static void pokey_potgo(const address_space *space, struct POKEYregisters *p)
 {
     int pot;
 
@@ -809,7 +801,7 @@ static void pokey_potgo(struct POKEYregisters *p)
 		p->POTx[pot] = 0xff;
 		if( p->pot_r[pot] )
 		{
-			int r = (*p->pot_r[pot])(pot);
+			int r = (*p->pot_r[pot])(space, pot);
 
 			LOG(("POKEY #%d pot_r(%d) returned $%02x\n", p->index, pot, r));
 			if( r != -1 )
@@ -819,7 +811,7 @@ static void pokey_potgo(struct POKEYregisters *p)
 
                 /* final value */
                 p->POTx[pot] = r;
-				timer_adjust(p->ptimer[pot], attotime_mul(AD_TIME, r), pot, attotime_zero);
+				timer_adjust_oneshot(p->ptimer[pot], attotime_mul(AD_TIME, r), pot);
 			}
 		}
 	}
@@ -828,7 +820,9 @@ static void pokey_potgo(struct POKEYregisters *p)
 static int pokey_register_r(int chip, int offs)
 {
 	struct POKEYregisters *p = sndti_token(SOUND_POKEY, chip);
-    int data = 0, pot;
+	/* temporary hack until this is converted to a device */
+	const address_space *space;
+	int data = 0, pot;
 	UINT32 adjust = 0;
 
 #ifdef MAME_DEBUG
@@ -839,7 +833,8 @@ static int pokey_register_r(int chip, int offs)
 	}
 #endif
 
-    switch (offs & 15)
+	space = memory_find_address_space(p->device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	switch (offs & 15)
 	{
 	case POT0_C: case POT1_C: case POT2_C: case POT3_C:
 	case POT4_C: case POT5_C: case POT6_C: case POT7_C:
@@ -863,7 +858,7 @@ static int pokey_register_r(int chip, int offs)
 			}
 		}
 		else
-		logerror("PC %04x: warning - read p[chip] #%d POT%d\n", activecpu_get_pc(), chip, pot);
+			logerror("%s: warning - read p[chip] #%d POT%d\n", cpuexec_describe_context(p->device->machine), chip, pot);
 		break;
 
     case ALLPOT_C:
@@ -871,14 +866,14 @@ static int pokey_register_r(int chip, int offs)
          * If the 2 least significant bits of SKCTL are 0, the ALLPOTs
          * are disabled (SKRESET). Thanks to MikeJ for pointing this out.
          ****************************************************************/
-    	if( (p->SKCTL & SK_RESET) == 0)
-    	{
-    		data = 0;
+		if( (p->SKCTL & SK_RESET) == 0)
+		{
+			data = 0;
 			LOG(("POKEY #%d ALLPOT internal $%02x (reset)\n", chip, data));
 		}
 		else if( p->allpot_r )
 		{
-			data = (*p->allpot_r)(offs);
+			data = (*p->allpot_r)(space, offs);
 			LOG(("POKEY #%d ALLPOT callback $%02x\n", chip, data));
 		}
 		else
@@ -925,13 +920,13 @@ static int pokey_register_r(int chip, int offs)
 			LOG_RAND(("POKEY #%d adjust %u rand17[$%05x]: $%02x\n", chip, adjust, p->r17, p->RANDOM));
 		}
 		if (adjust > 0)
-        	timer_adjust(p->rtimer, attotime_never, 0, attotime_zero);
+			timer_adjust_oneshot(p->rtimer, attotime_never, 0);
 		data = p->RANDOM ^ 0xff;
 		break;
 
 	case SERIN_C:
 		if( p->serin_r )
-			p->SERIN = (*p->serin_r)(offs);
+			p->SERIN = (*p->serin_r)(space, offs);
 		data = p->SERIN;
 		LOG(("POKEY #%d SERIN  $%02x\n", chip, data));
 		break;
@@ -989,6 +984,8 @@ READ8_HANDLER( quad_pokey_r )
 static void pokey_register_w(int chip, int offs, int data)
 {
 	struct POKEYregisters *p = sndti_token(SOUND_POKEY, chip);
+	/* temporary hack until this is converted to a device */
+	const address_space *space = memory_find_address_space(p->device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	int ch_mask = 0, new_val;
 
 #ifdef MAME_DEBUG
@@ -1086,9 +1083,9 @@ static void pokey_register_w(int chip, int offs, int data)
         /* first remove any existing timers */
 		LOG_TIMER(("POKEY #%d STIMER $%02x\n", chip, data));
 
-		timer_adjust(p->timer[TIMER1], attotime_never, p->timer_param[TIMER1], attotime_zero);
-		timer_adjust(p->timer[TIMER2], attotime_never, p->timer_param[TIMER2], attotime_zero);
-		timer_adjust(p->timer[TIMER4], attotime_never, p->timer_param[TIMER4], attotime_zero);
+		timer_adjust_oneshot(p->timer[TIMER1], attotime_never, p->timer_param[TIMER1]);
+		timer_adjust_oneshot(p->timer[TIMER2], attotime_never, p->timer_param[TIMER2]);
+		timer_adjust_oneshot(p->timer[TIMER4], attotime_never, p->timer_param[TIMER4]);
 
         /* reset all counters to zero (side effect) */
 		p->polyadjust = 0;
@@ -1106,7 +1103,7 @@ static void pokey_register_w(int chip, int offs, int data)
 				/* set timer #1 _and_ #2 event after timer_div clocks of joined CHAN1+CHAN2 */
 				p->timer_period[TIMER2] = attotime_mul(p->clock_period, p->divisor[CHAN2]);
 				p->timer_param[TIMER2] = (chip<<3)|IRQ_TIMR2|IRQ_TIMR1;
-				timer_adjust(p->timer[TIMER2], p->timer_period[TIMER2], p->timer_param[TIMER2], p->timer_period[TIMER2]);
+				timer_adjust_periodic(p->timer[TIMER2], p->timer_period[TIMER2], p->timer_param[TIMER2], p->timer_period[TIMER2]);
 			}
         }
         else
@@ -1117,7 +1114,7 @@ static void pokey_register_w(int chip, int offs, int data)
 				/* set timer #1 event after timer_div clocks of CHAN1 */
 				p->timer_period[TIMER1] = attotime_mul(p->clock_period, p->divisor[CHAN1]);
 				p->timer_param[TIMER1] = (chip<<3)|IRQ_TIMR1;
-				timer_adjust(p->timer[TIMER1], p->timer_period[TIMER1], p->timer_param[TIMER1], p->timer_period[TIMER1]);
+				timer_adjust_periodic(p->timer[TIMER1], p->timer_period[TIMER1], p->timer_param[TIMER1], p->timer_period[TIMER1]);
 			}
 
 			if( p->divisor[CHAN2] > 4 )
@@ -1126,7 +1123,7 @@ static void pokey_register_w(int chip, int offs, int data)
 				/* set timer #2 event after timer_div clocks of CHAN2 */
 				p->timer_period[TIMER2] = attotime_mul(p->clock_period, p->divisor[CHAN2]);
 				p->timer_param[TIMER2] = (chip<<3)|IRQ_TIMR2;
-				timer_adjust(p->timer[TIMER2], p->timer_period[TIMER2], p->timer_param[TIMER2], p->timer_period[TIMER2]);
+				timer_adjust_periodic(p->timer[TIMER2], p->timer_period[TIMER2], p->timer_param[TIMER2], p->timer_period[TIMER2]);
 			}
         }
 
@@ -1143,7 +1140,7 @@ static void pokey_register_w(int chip, int offs, int data)
 					/* set timer #4 event after timer_div clocks of CHAN4 */
 					p->timer_period[TIMER4] = attotime_mul(p->clock_period, p->divisor[CHAN4]);
 					p->timer_param[TIMER4] = (chip<<3)|IRQ_TIMR4;
-					timer_adjust(p->timer[TIMER4], p->timer_period[TIMER4], p->timer_param[TIMER4], p->timer_period[TIMER4]);
+					timer_adjust_periodic(p->timer[TIMER4], p->timer_period[TIMER4], p->timer_param[TIMER4], p->timer_period[TIMER4]);
 				}
             }
         }
@@ -1155,7 +1152,7 @@ static void pokey_register_w(int chip, int offs, int data)
 				/* set timer #4 event after timer_div clocks of CHAN4 */
 				p->timer_period[TIMER4] = attotime_mul(p->clock_period, p->divisor[CHAN4]);
 				p->timer_param[TIMER4] = (chip<<3)|IRQ_TIMR4;
-				timer_adjust(p->timer[TIMER4], p->timer_period[TIMER4], p->timer_param[TIMER4], p->timer_period[TIMER4]);
+				timer_adjust_periodic(p->timer[TIMER4], p->timer_period[TIMER4], p->timer_param[TIMER4], p->timer_period[TIMER4]);
 			}
         }
 
@@ -1172,22 +1169,22 @@ static void pokey_register_w(int chip, int offs, int data)
 
     case POTGO_C:
 		LOG(("POKEY #%d POTGO  $%02x\n", chip, data));
-		pokey_potgo(p);
+		pokey_potgo(space, p);
         break;
 
     case SEROUT_C:
 		LOG(("POKEY #%d SEROUT $%02x\n", chip, data));
 		if (p->serout_w)
-			(*p->serout_w)(offs, data);
+			(*p->serout_w)(space, offs, data);
 		p->SKSTAT |= SK_SEROUT;
         /*
          * These are arbitrary values, tested with some custom boot
          * loaders from Ballblazer and Escape from Fractalus
          * The real times are unknown
          */
-        timer_set(ATTOTIME_IN_USEC(200), p, 0, pokey_serout_ready);
+        timer_set(space->machine, ATTOTIME_IN_USEC(200), p, 0, pokey_serout_ready);
         /* 10 bits (assumption 1 start, 8 data and 1 stop bit) take how long? */
-        timer_set(ATTOTIME_IN_USEC(2000), p, 0, pokey_serout_complete);
+        timer_set(space->machine, ATTOTIME_IN_USEC(2000), p, 0, pokey_serout_complete);
         break;
 
     case IRQEN_C:
@@ -1252,7 +1249,7 @@ static void pokey_register_w(int chip, int offs, int data)
 		if( new_val < p->counter[CHAN1] )
 			p->counter[CHAN1] = new_val;
 		if( p->interrupt_cb && p->timer[TIMER1] )
-			timer_adjust(p->timer[TIMER1], attotime_mul(p->clock_period, new_val), p->timer_param[TIMER1], p->timer_period[TIMER1]);
+			timer_adjust_periodic(p->timer[TIMER1], attotime_mul(p->clock_period, new_val), p->timer_param[TIMER1], p->timer_period[TIMER1]);
 		p->audible[CHAN1] = !(
 			(p->AUDC[CHAN1] & VOLUME_ONLY) ||
 			(p->AUDC[CHAN1] & VOLUME_MASK) == 0 ||
@@ -1288,7 +1285,7 @@ static void pokey_register_w(int chip, int offs, int data)
 		if( new_val < p->counter[CHAN2] )
 			p->counter[CHAN2] = new_val;
 		if( p->interrupt_cb && p->timer[TIMER2] )
-			timer_adjust(p->timer[TIMER2], attotime_mul(p->clock_period, new_val), p->timer_param[TIMER2], p->timer_period[TIMER2]);
+			timer_adjust_periodic(p->timer[TIMER2], attotime_mul(p->clock_period, new_val), p->timer_param[TIMER2], p->timer_period[TIMER2]);
 		p->audible[CHAN2] = !(
 			(p->AUDC[CHAN2] & VOLUME_ONLY) ||
 			(p->AUDC[CHAN2] & VOLUME_MASK) == 0 ||
@@ -1353,7 +1350,7 @@ static void pokey_register_w(int chip, int offs, int data)
 		if( new_val < p->counter[CHAN4] )
 			p->counter[CHAN4] = new_val;
 		if( p->interrupt_cb && p->timer[TIMER4] )
-			timer_adjust(p->timer[TIMER4], attotime_mul(p->clock_period, new_val), p->timer_param[TIMER4], p->timer_period[TIMER4]);
+			timer_adjust_periodic(p->timer[TIMER4], attotime_mul(p->clock_period, new_val), p->timer_param[TIMER4], p->timer_period[TIMER4]);
 		p->audible[CHAN4] = !(
 			(p->AUDC[CHAN4] & VOLUME_ONLY) ||
 			(p->AUDC[CHAN4] & VOLUME_MASK) == 0 ||
@@ -1401,31 +1398,31 @@ WRITE8_HANDLER( quad_pokey_w )
 void pokey1_serin_ready(int after)
 {
 	struct POKEYregisters *p = sndti_token(SOUND_POKEY, 0);
-	timer_set(attotime_mul(p->clock_period, after), p, 0, pokey_serin_ready);
+	timer_set(p->device->machine, attotime_mul(p->clock_period, after), p, 0, pokey_serin_ready);
 }
 
 void pokey2_serin_ready(int after)
 {
 	struct POKEYregisters *p = sndti_token(SOUND_POKEY, 1);
-	timer_set(attotime_mul(p->clock_period, after), p, 0, pokey_serin_ready);
+	timer_set(p->device->machine, attotime_mul(p->clock_period, after), p, 0, pokey_serin_ready);
 }
 
 void pokey3_serin_ready(int after)
 {
 	struct POKEYregisters *p = sndti_token(SOUND_POKEY, 2);
-	timer_set(attotime_mul(p->clock_period, after), p, 0, pokey_serin_ready);
+	timer_set(p->device->machine, attotime_mul(p->clock_period, after), p, 0, pokey_serin_ready);
 }
 
 void pokey4_serin_ready(int after)
 {
 	struct POKEYregisters *p = sndti_token(SOUND_POKEY, 3);
-	timer_set(attotime_mul(p->clock_period, after), p, 0, pokey_serin_ready);
+	timer_set(p->device->machine, attotime_mul(p->clock_period, after), p, 0, pokey_serin_ready);
 }
 
 static void pokey_break_w(int chip, int shift)
 {
 	struct POKEYregisters *p = sndti_token(SOUND_POKEY, chip);
-    if( shift )                     /* shift code ? */
+	if( shift )                     /* shift code ? */
 		p->SKSTAT |= SK_SHIFT;
 	else
 		p->SKSTAT &= ~SK_SHIFT;
@@ -1435,8 +1432,8 @@ static void pokey_break_w(int chip, int shift)
 		/* set break IRQ status and call back the interrupt handler */
 		p->IRQST |= IRQ_BREAK;
 		if( p->interrupt_cb )
-			(*p->interrupt_cb)(IRQ_BREAK);
-    }
+			(*p->interrupt_cb)(p->device->machine, IRQ_BREAK);
+	}
 }
 
 void pokey1_break_w(int shift)
@@ -1479,7 +1476,7 @@ static void pokey_kbcode_w(int chip, int kbcode, int make)
 				p->SKSTAT |= SK_KBERR;
 			p->IRQST |= IRQ_KEYBD;
 			if( p->interrupt_cb )
-				(*p->interrupt_cb)(IRQ_KEYBD);
+				(*p->interrupt_cb)(p->device->machine, IRQ_KEYBD);
 		}
 	}
 	else
@@ -1516,7 +1513,7 @@ void pokey4_kbcode_w(int kbcode, int make)
  * Generic get_info
  **************************************************************************/
 
-static void pokey_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( pokey )
 {
 	switch (state)
 	{
@@ -1525,24 +1522,24 @@ static void pokey_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void pokey_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( pokey )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = pokey_set_info;		break;
-		case SNDINFO_PTR_START:							info->start = pokey_start;				break;
-		case SNDINFO_PTR_STOP:							/* Nothing */							break;
-		case SNDINFO_PTR_RESET:							/* Nothing */							break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( pokey );	break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( pokey );			break;
+		case SNDINFO_PTR_STOP:							/* Nothing */									break;
+		case SNDINFO_PTR_RESET:							/* Nothing */									break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "POKEY";						break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "Atari custom";				break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "4.51";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "POKEY");						break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Atari custom");				break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "4.51");						break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);						break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
