@@ -1,8 +1,10 @@
 /*
 
- TSI S14001A emulator v1.11
+ TSI S14001A emulator v1.31c
  By Jonathan Gevaryahu ("Lord Nightmare") with help from Kevin Horton ("kevtris")
  MAME conversion and integration by R. Belmont
+ Clock Frequency control updated by Zsolt Vasvari
+ Other fixes by AtariAce
 
  Copyright Jonathan Gevaryahu.
 
@@ -15,12 +17,103 @@
  1.11 fix signedness of output, pre-multiply, fixes clicking on VSU-1000 volume change - LN (0.111u7)
  1.20 supports setting the clock freq directly - reset is done by external hardware,
       the chip has no reset line ZV (0.122)
+ 1.30 move main dac to 4 bits only with no extension (4->16 bit range extension is now done by output).
+ Added a somewhat better, but still not perfect, filtering system - LN
+ 1.31 fix a minor bug with the dac range. wolfpack clips again, and I'm almost sure its an encoding error on the original speech - LN (0.125u9)
+ 1.31a Add chip pinout and other notes - LN (0.128u4)
+ 1.31b slight update to notes to clarify input bus stuff, mostly finish the state map in the comments - LN
+ 1.31c remove usage of deprecat.h - AtariAce (0.128u5)
 
  TODO:
  * increase accuracy of internal S14001A 'filter' for both driven and undriven cycles (its not terribly inaccurate for undriven cycles, but the dc sliding of driven cycles is not emulated)
- * add option for and attach Frank P.'s emulation of the Analog external filter from the vsu-1000 using the discrete core.
+ * add option for and attach Frank P.'s emulation of the Analog external filter from the vsu-1000 using the discrete core. (with the direction of independent sound core and analog stuff, this should actually be attached in the main berzerk/frenzy driver and not here)
 */
 
+/* Chip Pinout:
+The original datasheet (which is lost as far as I know) clearly called the
+s14001a chip the 'CRC chip', or 'Custom Rom Controller', as it appears with
+this name on the Stern and Canon schematics, as well as on some TSI speech
+print advertisements.
+Labels are not based on the labels used by the Atari wolf pack and Stern
+schematics, as these are inconsistent. Atari calls the word select/speech address
+input pins SAx while Stern calls them Cx. Also Atari and Canon both have the bit
+ordering for the word select/speech address bus backwards, which may indicate it
+was so on the original datasheet. Stern has it correct, and I've used their Cx
+labeling.
+
+                      ______    ______
+                    _|o     \__/      |_
+            +5V -- |_|1             40|_| -> /BUSY*
+                    _|                |_
+          ?TEST ?? |_|2             39|_| <- ROM D7
+                    _|                |_
+ XTAL CLOCK/CKC -> |_|3             38|_| -> ROM A11
+                    _|                |_
+  ROM CLOCK/CKR <- |_|4             37|_| <- ROM D6
+                    _|                |_
+     ?DAC TEST? ?? |_|5             36|_| -> ROM A10
+                    _|                |_
+     ?DAC TEST? ?? |_|6             35|_| -> ROM A9
+                    _|                |_
+     ?DAC TEST? ?? |_|7             34|_| <- ROM D5
+                    _|                |_
+     ?DAC TEST? ?? |_|8             33|_| -> ROM A8
+                    _|                |_
+        ROM /EN <- |_|9             32|_| <- ROM D4
+                    _|       S        |_
+          START -> |_|10 7   1   T  31|_| -> ROM A7
+                    _|   7   4   S    |_
+      AUDIO OUT <- |_|11 3   0   I  30|_| <- ROM D3
+                    _|   7   0        |_
+         ROM A0 <- |_|12     1      29|_| -> ROM A6
+                    _|       A        |_
+SPCH ADR BUS C0 -> |_|13            28|_| <- SPCH ADR BUS C5
+                    _|                |_
+         ROM A1 <- |_|14            27|_| <- ROM D2
+                    _|                |_
+SPCH ADR BUS C1 -> |_|15            26|_| <- SPCH ADR BUS C4
+                    _|                |_
+         ROM A2 <- |_|16            25|_| <- ROM D1
+                    _|                |_
+SPCH ADR BUS C2 -> |_|17            24|_| <- SPCH ADR BUS C3
+                    _|                |_
+         ROM A3 <- |_|18            23|_| <- ROM D0
+                    _|                |_
+         ROM A4 <- |_|19            22|_| -> ROM A5
+                    _|                |_
+            GND -- |_|20            21|_| -- -10V
+                     |________________|
+
+*Note from Kevin Horton when testing the hookup of the S14001A: the /BUSY line
+is not a standard voltage line: when it is in its HIGH state (i.e. not busy) it
+puts out a voltage of -10 volts, so it needs to be dropped back to a sane
+voltage level before it can be passed to any sort of modern IC. The address
+lines for the speech rom (A0-A11) do not have this problem, they output at a
+TTL/CMOS compatible voltage. The AUDIO OUT pin also outputs a voltage below GND,
+and the TEST pins may do so too.
+
+START is pulled high when a word is to be said and the word number is on the
+word select/speech address input lines. The Canon 'Canola' uses a seperate 'rom
+strobe' signal independent of the chip to either enable or clock the speech rom.
+Its likely that they did this to be able to force the speech chip to stop talking,
+which is normally impossible. The later 'version 3' TSI speech board as featured in
+an advertisement in the John Cater book probably also has this feature, in addition
+to external speech rom banking.
+
+Because it requires -10V to operate, the chip manufacturing process must be PMOS.
+
+/-----------\
+> Operation <
+\-----------/
+Put the 6-bit address of the word to be said onto the C0-C5 word select/speech
+address bus lines. Next, clock the START line low-high-low. As long as the START
+line is held high, the first address byte of the first word will be read repeatedly
+every clock, with the rom enable line enabled constantly (i.e. it doesn't toggle on
+and off as it normally does during speech). Once START has gone low-high-low, the
+/BUSY line will go low until 3 clocks after the chip is done speaking.
+*/
+
+
 /* state map:
 
  * state machine 1: odd/even clock state
@@ -106,15 +199,24 @@
  *   Get new OldValHi from bit 9
  *   Get new OldValLo from bit 8
  *   feed current delta (bits 9 and 8) and olddelta (bits 7 and 6) to delta demodulator table, delta demodulator table applies a delta to the accumulator, accumulator goes to enable/disable latch which Silenceflag enables or disables (forces output to 0x8 on disable), then to DAC to output.
- *   Call function: increment address
+ *   if offset < 8, increment offset within 8-byte phone
+ *   if offset = 8: (see PostPhoneme code to understand how this part works, its a bit complicated)
 
  *   next state: depends on playparams:
  *     if we're in mirrored mode, next will be LoadAndPlayBackward1
+ *     if we're in nonmirrored mode, next will be PlayForward1
 
  * state 9(LoadAndPlayBackward1)
+ *   grab byte at (((phoneaddress<<8)+(oddphone*8))+(phonepos>>2)) -> PlayRegister high end, bits F to 8 <- check code on this, I think its backwards here but its correct in the code
+ *   see code for this, its basically the same as state 8 but with the byte grab mentioned above, and the values fed to the delta demod table are switched
  * state 10(PlayBackward2)
+ *   see code for this, its basically the same as state 7 but the values fed to the delta demod table are switched
  * state 11(PlayBackward3)
+ *   see code for this, its basically the same as state 6 but the values fed to the delta demod table are switched
  * state 12(PlayBackward4)
+ *   see code for this, its basically the same as state 5 but with no byte grab, and the values fed to the delta demod table are switched, and a bit below similar to state 5
+ *   if offset > -1, decrement offset within 8-byte phone
+ *   if offset = -1: (see PostPhoneme code to understand how this part works, its a bit complicated)
 */
 
 /* increment address function:
@@ -130,7 +232,6 @@
 
 #include "sndintrf.h"
 #include "streams.h"
-#include "deprecat.h"
 #include "s14001a.h"
 
 typedef struct
@@ -157,13 +258,14 @@ typedef struct
 	UINT8 DACOutput; // 4-bit DAC Accumulator/output
 	UINT8 audioout; // filtered audio output
 	UINT8 *SpeechRom; // array to hold rom contents, mame will not need this, will use a pointer
-	UINT8 filtervals[8];
+	INT16 filtervals[8];
 	UINT8 VSU1000_amp; // amplitude setting on VSU-1000 board
 } S14001AChip;
 
 //#define DEBUGSTATE
 
-#define SILENCE 0x77 // value output when silent
+#define SILENCE 0x7 // value output when silent
+#define ALTFLAG 0xFF // value to tell renderer that this frame's output is the average of the 8 prior frames and not directly used.
 
 #define LASTSYLLABLE ((chip->PlayParams & 0x80)>>7)
 #define MIRRORMODE ((chip->PlayParams & 0x40)>>6)
@@ -174,22 +276,23 @@ typedef struct
 
 static const INT8 DeltaTable[4][4] =
 {
-	{ 0xCD, 0xCD, 0xEF, 0xEF, },
-	{ 0xEF, 0xEF, 0x00, 0x00, },
-	{ 0x00, 0x00, 0x11, 0x11, },
-	{ 0x11, 0x11, 0x33, 0x33  },
+	{ -3, -3, -1, -1, },
+	{ -1, -1,  0,  0, },
+	{  0,  0,  1,  1, },
+	{  1,  1,  3,  3  },
 };
 
-static UINT8 audiofilter(S14001AChip *chip) /* rewrite me to better match the real filter! */
+static INT16 audiofilter(S14001AChip *chip) /* rewrite me to better match the real filter! */
 {
-	UINT16 temp1, temp2 = 0;
-	/* crappy averaging filter! */
+	UINT8 temp1;
+        INT16 temp2 = 0;
+	/* mean averaging filter! 1/n exponential *would* be somewhat better, but I'm lazy... */
 	for (temp1 = 0; temp1 < 8; temp1++) { temp2 += chip->filtervals[temp1]; }
 	temp2 >>= 3;
 	return temp2;
 }
 
-static void shiftIntoFilter(S14001AChip *chip, UINT8 inputvalue)
+static void shiftIntoFilter(S14001AChip *chip, INT16 inputvalue)
 {
 	UINT8 temp1;
 	for (temp1 = 7; temp1 > 0; temp1--)
@@ -293,13 +396,14 @@ static void s14001a_clock(S14001AChip *chip) /* called once per clock */
 {
 	UINT8 CurDelta; // Current delta
 
-	/* on even clocks, audio output is floating, /romen is low so rom data bus is driven, input is latched?
-     * on odd clocks, audio output is driven, /romen is high, state machine 2 is clocked*/
+	/* on even clocks, audio output is floating, /romen is low so rom data bus is driven
+         * on odd clocks, audio output is driven, /romen is high, state machine 2 is clocked
+         */
 	chip->oddeven = !(chip->oddeven); // invert the clock
 	if (chip->oddeven == 0) // even clock
         {
-		chip->audioout = audiofilter(chip); // function to handle output filtering by internal capacitance based on clock speed and such
-		shiftIntoFilter(chip, chip->audioout); // shift over all the filter outputs and stick in audioout
+		chip->audioout = ALTFLAG; // flag to the renderer that this output should be the average of the last 8
+		// DIGITAL INPUT on the test pins occurs on this cycle used for output
 	}
 	else // odd clock
 	{
@@ -310,7 +414,7 @@ static void s14001a_clock(S14001AChip *chip) /* called once per clock */
 			chip->OldDelta = 2;
 		}
 		chip->audioout = (chip->GlobalSilenceState || LOCALSILENCESTATE) ? SILENCE : chip->DACOutput; // when either silence state is 1, output silence.
-		shiftIntoFilter(chip, chip->audioout); // shift over all the filter outputs and stick in audioout
+		// DIGITAL OUTPUT is driven onto the test pins on this cycle
 		switch(chip->machineState) // HUUUUUGE switch statement
 		{
 		case 0: // idle state
@@ -337,7 +441,7 @@ static void s14001a_clock(S14001AChip *chip) /* called once per clock */
 			chip->OutputCounter = 0; // clear output counter and disable mirrored phoneme silence indirectly via LOCALSILENCESTATE
 			chip->PhoneOffset = 0; // set offset within phone to zero
 			chip->OldDelta = 0x2; // set old delta to 2 <- is this right?
-			chip->DACOutput = 0x88; // set DAC output to center/silence position (0x88)
+			chip->DACOutput = SILENCE ; // set DAC output to center/silence position
 			chip->nextstate = 5;
 			break;
 		case 5: // Play phone forward, shift = 0 (also load)
@@ -418,6 +522,9 @@ static void s14001a_clock(S14001AChip *chip) /* called once per clock */
 #endif
 		chip->laststate = chip->machineState;
 		chip->machineState = chip->nextstate;
+
+	        /* the dac is 4 bits wide. if a delta step forced it outside of 4 bits, mask it back over here */
+	        chip->DACOutput &= 0xF;
 	}
 }
 
@@ -425,7 +532,7 @@ static void s14001a_clock(S14001AChip *chip) /* called once per clock */
    MAME glue code
  **************************************************************************/
 
-static void s14001a_pcm_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int length)
+static STREAM_UPDATE( s14001a_pcm_update )
 {
 	INT32 mix[48000];
 	INT32 *mixp;
@@ -435,16 +542,24 @@ static void s14001a_pcm_update(void *param, stream_sample_t **inputs, stream_sam
 	memset(mix, 0, sizeof(mix));
 
 	mixp = &mix[0];
-	for (i = 0; i < length; i++)
+	for (i = 0; i < samples; i++)
 	{
 		s14001a_clock(chip);
-		outputs[0][i] = ((((INT16)chip->audioout)-128)<<6)*chip->VSU1000_amp;
+		if (chip->audioout == ALTFLAG) // input from test pins -> output
+		{
+			shiftIntoFilter(chip, audiofilter(chip)); // shift over the previous outputs and stick in audioout.
+			outputs[0][i] = audiofilter(chip)*chip->VSU1000_amp;
+		}
+		else // normal, dac-driven output
+		{
+			shiftIntoFilter(chip, ((((INT16)chip->audioout)-8)<<9)); // shift over the previous outputs and stick in audioout 4 times. note <<9 instead of <<10, to prevent clipping, and to simulate that the filtered output normally has a somewhat lower amplitude than the driven one.
+			outputs[0][i] = ((((INT16)chip->audioout)-8)<<10)*chip->VSU1000_amp;
+		}
 	}
 }
 
-static void *s14001a_start(int sndindex, int clock, const void *config)
+static SND_START( s14001a )
 {
-	const struct S14001A_interface *intf;
 	S14001AChip *chip;
 	int i;
 
@@ -461,16 +576,14 @@ static void *s14001a_start(int sndindex, int clock, const void *config)
 		chip->filtervals[i] = SILENCE;
 	}
 
-	intf = config;
+	chip->SpeechRom = device->region;
 
-	chip->SpeechRom = memory_region(intf->region);
-
-	chip->stream = stream_create(0, 1, clock ? clock : Machine->sample_rate, chip, s14001a_pcm_update);
+	chip->stream = stream_create(device, 0, 1, clock ? clock : device->machine->sample_rate, chip, s14001a_pcm_update);
 
 	return chip;
 }
 
-static void s14001a_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( s14001a )
 {
 	switch (state)
 	{
@@ -478,7 +591,7 @@ static void s14001a_set_info(void *token, UINT32 state, sndinfo *info)
 	}
 }
 
-int S14001A_bsy_0_r(void)
+int s14001a_bsy_0_r(void)
 {
 	S14001AChip *chip = sndti_token(SOUND_S14001A, 0);
 	stream_update(chip->stream);
@@ -488,14 +601,14 @@ int S14001A_bsy_0_r(void)
 	return (chip->machineState != 0);
 }
 
-void S14001A_reg_0_w(int data)
+void s14001a_reg_0_w(int data)
 {
 	S14001AChip *chip = sndti_token(SOUND_S14001A, 0);
 	stream_update(chip->stream);
 	chip->WordInput = data;
 }
 
-void S14001A_rst_0_w(int data)
+void s14001a_rst_0_w(int data)
 {
 	S14001AChip *chip = sndti_token(SOUND_S14001A, 0);
 	stream_update(chip->stream);
@@ -504,32 +617,32 @@ void S14001A_rst_0_w(int data)
 	chip->machineState = chip->resetState ? 1 : chip->machineState;
 }
 
-void S14001A_set_clock(int clock)
+void s14001a_set_clock(int clock)
 {
 	S14001AChip *chip = sndti_token(SOUND_S14001A, 0);
 	stream_set_sample_rate(chip->stream, clock);
 }
 
-void S14001A_set_volume(int volume)
+void s14001a_set_volume(int volume)
 {
 	S14001AChip *chip = sndti_token(SOUND_S14001A, 0);
 	stream_update(chip->stream);
 	chip->VSU1000_amp = volume;
 }
 
-void s14001a_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( s14001a )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:					info->set_info = s14001a_set_info;	break;
-		case SNDINFO_PTR_START:						info->start = s14001a_start;		break;
+		case SNDINFO_PTR_SET_INFO:					info->set_info = SND_SET_INFO_NAME( s14001a );	break;
+		case SNDINFO_PTR_START:						info->start = SND_START_NAME( s14001a );		break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:						info->s = "S14001A";		break;
-		case SNDINFO_STR_CORE_FAMILY:				info->s = "TSI S14001A";	break;
-		case SNDINFO_STR_CORE_VERSION:				info->s = "1.20";			break;
-		case SNDINFO_STR_CORE_FILE:					info->s = __FILE__;			break;
-		case SNDINFO_STR_CORE_CREDITS:				info->s = "Copyright Jonathan Gevaryahu"; break;
+		case SNDINFO_STR_NAME:						strcpy(info->s, "S14001A");						break;
+		case SNDINFO_STR_CORE_FAMILY:				strcpy(info->s, "TSI S14001A");					break;
+		case SNDINFO_STR_CORE_VERSION:				strcpy(info->s, "1.31");						break;
+		case SNDINFO_STR_CORE_FILE:					strcpy(info->s, __FILE__);						break;
+		case SNDINFO_STR_CORE_CREDITS:				strcpy(info->s, "Copyright Jonathan Gevaryahu"); break;
 	}
 }
