@@ -22,13 +22,13 @@
                              Enabled DSP again.
     * December 16, 2007 (kingshriek) Many EG bug fixes, implemented effects mixer,
                              implemented FM.
-    * January 5, 2007   (kingshriek+RB) Working, good-sounding FM, removed obsolete non-USEDSP code.
+    * January 5, 2008   (kingshriek+RB) Working, good-sounding FM, removed obsolete non-USEDSP code.
 */
 
 #include "sndintrf.h"
 #include "streams.h"
 #include "cpuintrf.h"
-#include "deprecat.h"
+#include "cpuexec.h"
 #include "scsp.h"
 #include "scspdsp.h"
 
@@ -185,7 +185,7 @@ struct _SCSP
 		UINT8 datab[0x30];
 	} udata;
 	struct _SLOT Slots[32];
-	signed short RINGBUF[64];
+	signed short RINGBUF[128];
 	unsigned char BUFPTR;
 #if FM_DELAY
 	signed short DELAYBUF[FM_DELAY];
@@ -194,7 +194,7 @@ struct _SCSP
 	unsigned char *SCSPRAM;
 	UINT32 SCSPRAM_LENGTH;
 	char Master;
-	void (*Int68kCB)(int irq);
+	void (*Int68kCB)(running_machine *machine, int irq);
 	sound_stream * stream;
 
 	INT32 *buffertmpl,*buffertmpr;
@@ -224,9 +224,11 @@ struct _SCSP
 	int ARTABLE[64], DRTABLE[64];
 
 	struct _SCSPDSP DSP;
+
+	const device_config *device;
 };
 
-static void dma_scsp(struct _SCSP *SCSP); 		/*SCSP DMA transfer function*/
+static void dma_scsp(const address_space *space, struct _SCSP *SCSP); 		/*SCSP DMA transfer function*/
 #define	scsp_dgate		scsp_regs[0x16/2] & 0x4000
 #define	scsp_ddir		scsp_regs[0x16/2] & 0x2000
 #define scsp_dexe 		scsp_regs[0x16/2] & 0x1000
@@ -259,6 +261,8 @@ static void CheckPendingIRQ(struct _SCSP *SCSP)
 {
 	UINT32 pend=SCSP->udata.data[0x20/2];
 	UINT32 en=SCSP->udata.data[0x1e/2];
+	running_machine *machine = SCSP->device->machine;
+
 	if(SCSP->MidiW!=SCSP->MidiR)
 	{
 		SCSP->udata.data[0x20/2] |= 8;
@@ -269,47 +273,48 @@ static void CheckPendingIRQ(struct _SCSP *SCSP)
 	if(pend&0x40)
 		if(en&0x40)
 		{
-			SCSP->Int68kCB(SCSP->IrqTimA);
+			SCSP->Int68kCB(machine, SCSP->IrqTimA);
 			return;
 		}
 	if(pend&0x80)
 		if(en&0x80)
 		{
-			SCSP->Int68kCB(SCSP->IrqTimBC);
+			SCSP->Int68kCB(machine, SCSP->IrqTimBC);
 			return;
 		}
 	if(pend&0x100)
 		if(en&0x100)
 		{
-			SCSP->Int68kCB(SCSP->IrqTimBC);
+			SCSP->Int68kCB(machine, SCSP->IrqTimBC);
 			return;
 		}
 	if(pend&8)
 		if (en&8)
 		{
-			SCSP->Int68kCB(SCSP->IrqMidi);
+			SCSP->Int68kCB(machine, SCSP->IrqMidi);
 			SCSP->udata.data[0x20/2] &= ~8;
 			return;
 		}
 
-	SCSP->Int68kCB(0);
+	SCSP->Int68kCB(machine, 0);
 }
 
 static void ResetInterrupts(struct _SCSP *SCSP)
 {
 	UINT32 reset = SCSP->udata.data[0x22/2];
+	running_machine *machine = SCSP->device->machine;
 
 	if (reset & 0x40)
 	{
-		SCSP->Int68kCB(-SCSP->IrqTimA);
+		SCSP->Int68kCB(machine, -SCSP->IrqTimA);
 	}
 	if (reset & 0x180)
 	{
-		SCSP->Int68kCB(-SCSP->IrqTimBC);
+		SCSP->Int68kCB(machine, -SCSP->IrqTimBC);
 	}
 	if (reset & 0x8)
 	{
-		SCSP->Int68kCB(-SCSP->IrqMidi);
+		SCSP->Int68kCB(machine, -SCSP->IrqMidi);
 	}
 
 	CheckPendingIRQ(SCSP);
@@ -419,7 +424,7 @@ static int EG_Update(struct _SLOT *slot)
 			slot->EG.volume-=slot->EG.D1R;
 			if(slot->EG.volume<=0)
 				slot->EG.volume=0;
-			if(slot->EG.volume>>(EG_SHIFT+5)<slot->EG.DL)
+			if(slot->EG.volume>>(EG_SHIFT+5)<=slot->EG.DL)
 				slot->EG.state=DECAY2;
 			break;
 		case DECAY2:
@@ -504,40 +509,39 @@ static void SCSP_StopSlot(struct _SLOT *slot,int keyoff)
 
 #define log_base_2(n) (log((double)(n))/log(2.0))
 
-static void SCSP_Init(struct _SCSP *SCSP, const struct SCSPinterface *intf, int sndindex)
+static void SCSP_Init(const device_config *device, struct _SCSP *SCSP, const scsp_interface *intf, int sndindex)
 {
 	int i;
 
+	memset(SCSP,0,sizeof(*SCSP));
+
+	SCSP->device = device;
 	SCSP->IrqTimA = SCSP->IrqTimBC = SCSP->IrqMidi = 0;
 	SCSP->MidiR=SCSP->MidiW=0;
 	SCSP->MidiOutR=SCSP->MidiOutW=0;
 
 	// get SCSP RAM
+	if (sndindex == 0)
 	{
-		memset(SCSP,0,sizeof(*SCSP));
-
-		if (sndindex == 0)
-		{
-			SCSP->Master=1;
-		}
-		else
-		{
-			SCSP->Master=0;
-		}
-
-		if (intf->region)
-		{
-			SCSP->SCSPRAM = memory_region(intf->region);
-			SCSP->SCSPRAM_LENGTH = memory_region_length(intf->region);
-			SCSP->DSP.SCSPRAM = (UINT16 *)SCSP->SCSPRAM;
-			SCSP->DSP.SCSPRAM_LENGTH =  memory_region_length(intf->region)/2;
-			SCSP->SCSPRAM += intf->roffset;
-		}
+		SCSP->Master=1;
+	}
+	else
+	{
+		SCSP->Master=0;
 	}
 
-	SCSP->timerA = timer_alloc(timerA_cb, SCSP);
-	SCSP->timerB = timer_alloc(timerB_cb, SCSP);
-	SCSP->timerC = timer_alloc(timerC_cb, SCSP);
+	SCSP->SCSPRAM = device->region;
+	if (SCSP->SCSPRAM)
+	{
+		SCSP->SCSPRAM_LENGTH = device->regionbytes;
+		SCSP->DSP.SCSPRAM = (UINT16 *)SCSP->SCSPRAM;
+		SCSP->DSP.SCSPRAM_LENGTH = SCSP->SCSPRAM_LENGTH/2;
+		SCSP->SCSPRAM += intf->roffset;
+	}
+
+	SCSP->timerA = timer_alloc(device->machine, timerA_cb, SCSP);
+	SCSP->timerB = timer_alloc(device->machine, timerB_cb, SCSP);
+	SCSP->timerC = timer_alloc(device->machine, timerC_cb, SCSP);
 
 	for(i=0;i<0x400;++i)
 	{
@@ -634,7 +638,7 @@ static void SCSP_Init(struct _SCSP *SCSP, const struct SCSPinterface *intf, int
 		SCSP->Slots[i].base=NULL;
 	}
 
-	LFO_Init();
+	LFO_Init(device->machine);
 	SCSP->buffertmpl=(signed int*) auto_malloc(44100*sizeof(signed int));
 	SCSP->buffertmpr=(signed int*) auto_malloc(44100*sizeof(signed int));
 	memset(SCSP->buffertmpl,0,44100*sizeof(signed int));
@@ -693,6 +697,8 @@ static void SCSP_UpdateSlotReg(struct _SCSP *SCSP,int s,int r)
 
 static void SCSP_UpdateReg(struct _SCSP *SCSP, int reg)
 {
+	/* temporary hack until this is converted to a device */
+	const address_space *space = memory_find_address_space(SCSP->device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	switch(reg&0x3f)
 	{
 		case 0x2:
@@ -712,7 +718,7 @@ static void SCSP_UpdateReg(struct _SCSP *SCSP, int reg)
 			break;
 		case 0x6:
 		case 0x7:
-			SCSP_MidiIn(0, SCSP->udata.data[0x6/2]&0xff, 0);
+			scsp_midi_in(space, 0, SCSP->udata.data[0x6/2]&0xff, 0);
 			break;
 		case 0x12:
 		case 0x13:
@@ -735,7 +741,7 @@ static void SCSP_UpdateReg(struct _SCSP *SCSP, int reg)
 					time = (44100 / SCSP->TimPris[0]) / (255-(SCSP->udata.data[0x18/2]&0xff));
 					if (time)
 					{
-						timer_adjust(SCSP->timerA, ATTOTIME_IN_HZ(time), 0, attotime_never);
+						timer_adjust_oneshot(SCSP->timerA, ATTOTIME_IN_HZ(time), 0);
 					}
 				}
 			}
@@ -754,7 +760,7 @@ static void SCSP_UpdateReg(struct _SCSP *SCSP, int reg)
 					time = (44100 / SCSP->TimPris[1]) / (255-(SCSP->udata.data[0x1A/2]&0xff));
 					if (time)
 					{
-						timer_adjust(SCSP->timerB, ATTOTIME_IN_HZ(time), 0, attotime_never);
+						timer_adjust_oneshot(SCSP->timerB, ATTOTIME_IN_HZ(time), 0);
 					}
 				}
 			}
@@ -773,7 +779,7 @@ static void SCSP_UpdateReg(struct _SCSP *SCSP, int reg)
 					time = (44100 / SCSP->TimPris[2]) / (255-(SCSP->udata.data[0x1C/2]&0xff));
 					if (time)
 					{
-						timer_adjust(SCSP->timerC, ATTOTIME_IN_HZ(time), 0, attotime_never);
+						timer_adjust_oneshot(SCSP->timerC, ATTOTIME_IN_HZ(time), 0);
 					}
 				}
 			}
@@ -833,7 +839,7 @@ static void SCSP_UpdateRegR(struct _SCSP *SCSP, int reg)
 				unsigned short v=SCSP->udata.data[0x5/2];
 				v&=0xff00;
 				v|=SCSP->MidiStack[SCSP->MidiR];
-				SCSP[0].Int68kCB(-SCSP->IrqMidi);	// cancel the IRQ
+				SCSP[0].Int68kCB(SCSP->device->machine, -SCSP->IrqMidi);	// cancel the IRQ
 				if(SCSP->MidiR!=SCSP->MidiW)
 				{
 					++SCSP->MidiR;
@@ -1147,7 +1153,7 @@ static void SCSP_DoMasterSamples(struct _SCSP *SCSP, int nsamples)
 	}
 }
 
-static void dma_scsp(struct _SCSP *SCSP)
+static void dma_scsp(const address_space *space, struct _SCSP *SCSP)
 {
 	static UINT16 tmp_dma[3], *scsp_regs;
 
@@ -1170,7 +1176,7 @@ static void dma_scsp(struct _SCSP *SCSP)
 	{
 		for(;SCSP->scsp_dtlg > 0;SCSP->scsp_dtlg-=2)
 		{
-			program_write_word(SCSP->scsp_dmea, program_read_word(0x100000|SCSP->scsp_drga));
+			memory_write_word(space,SCSP->scsp_dmea, memory_read_word(space,0x100000|SCSP->scsp_drga));
 			SCSP->scsp_dmea+=2;
 			SCSP->scsp_drga+=2;
 		}
@@ -1179,7 +1185,7 @@ static void dma_scsp(struct _SCSP *SCSP)
 	{
 		for(;SCSP->scsp_dtlg > 0;SCSP->scsp_dtlg-=2)
 		{
-  			program_write_word(0x100000|SCSP->scsp_drga,program_read_word(SCSP->scsp_dmea));
+  			memory_write_word(space,0x100000|SCSP->scsp_drga,memory_read_word(space,SCSP->scsp_dmea));
 			SCSP->scsp_dmea+=2;
 			SCSP->scsp_drga+=2;
 		}
@@ -1195,7 +1201,7 @@ static void dma_scsp(struct _SCSP *SCSP)
 
 	/*Job done,request a dma end irq*/
 	if(scsp_regs[0x1e/2] & 0x10)
-	cpunum_set_input_line(Machine, 2,dma_transfer_end,HOLD_LINE);
+		cpu_set_input_line(space->machine->cpu[2],dma_transfer_end,HOLD_LINE);
 }
 
 #ifdef UNUSED_FUNCTION
@@ -1206,18 +1212,18 @@ int SCSP_IRQCB(void *param)
 }
 #endif
 
-static void SCSP_Update(void *param, stream_sample_t **inputs, stream_sample_t **buf, int samples)
+static STREAM_UPDATE( SCSP_Update )
 {
 	struct _SCSP *SCSP = param;
-	bufferl = buf[0];
-	bufferr = buf[1];
+	bufferl = outputs[0];
+	bufferr = outputs[1];
 	length = samples;
 	SCSP_DoMasterSamples(SCSP, samples);
 }
 
-static void *scsp_start(int sndindex, int clock, const void *config)
+static SND_START( scsp )
 {
-	const struct SCSPinterface *intf;
+	const scsp_interface *intf;
 
 	struct _SCSP *SCSP;
 
@@ -1227,13 +1233,13 @@ static void *scsp_start(int sndindex, int clock, const void *config)
 	intf = config;
 
 	// init the emulation
-	SCSP_Init(SCSP, intf, sndindex);
+	SCSP_Init(device, SCSP, intf, sndindex);
 
 	// set up the IRQ callbacks
 	{
 		SCSP->Int68kCB = intf->irq_callback;
 
-		SCSP->stream = stream_create(0, 2, 44100, SCSP, SCSP_Update);
+		SCSP->stream = stream_create(device, 0, 2, 44100, SCSP, SCSP_Update);
 	}
 
 	return SCSP;
@@ -1247,11 +1253,13 @@ void SCSP_set_ram_base(int which, void *base)
 	{
 		SCSP->SCSPRAM = base;
 		SCSP->DSP.SCSPRAM = base;
+		SCSP->SCSPRAM_LENGTH = 0x80000;
+		SCSP->DSP.SCSPRAM_LENGTH = 0x80000/2;
 	}
 }
 
 
-READ16_HANDLER( SCSP_0_r )
+READ16_HANDLER( scsp_0_r )
 {
 	struct _SCSP *SCSP = sndti_token(SOUND_SCSP, 0);
 
@@ -1262,7 +1270,7 @@ READ16_HANDLER( SCSP_0_r )
 
 UINT32* stv_scu;
 
-WRITE16_HANDLER( SCSP_0_w )
+WRITE16_HANDLER( scsp_0_w )
 {
 	struct _SCSP *SCSP = sndti_token(SOUND_SCSP, 0);
 	UINT16 tmp, *scsp_regs;
@@ -1302,7 +1310,7 @@ WRITE16_HANDLER( SCSP_0_w )
 		SCSP->scsp_dtlg = scsp_regs[0x416/2] & 0x0ffe;
 		if(scsp_dexe)
 		{
-			dma_scsp(SCSP);
+			dma_scsp(space, SCSP);
 			scsp_regs[0x416/2]^=0x1000;//disable starting bit
 		}
 		break;
@@ -1310,7 +1318,7 @@ WRITE16_HANDLER( SCSP_0_w )
 		case 0x42a:
 			if(stv_scu && !(stv_scu[40] & 0x40) /*&& scsp_regs[0x42c/2] & 0x20*/)/*Main CPU allow sound irq*/
 			{
-				cpunum_set_input_line_and_vector(Machine, 0, 9, HOLD_LINE , 0x46);
+				cpu_set_input_line_and_vector(space->machine->cpu[0], 9, HOLD_LINE , 0x46);
 			    logerror("SCSP: Main CPU interrupt\n");
 			}
 		break;
@@ -1321,13 +1329,13 @@ WRITE16_HANDLER( SCSP_0_w )
 	}
 }
 
-READ16_HANDLER( SCSP_1_r )
+READ16_HANDLER( scsp_1_r )
 {
 	struct _SCSP *SCSP = sndti_token(SOUND_SCSP, 1);
 	return SCSP_r16(SCSP, offset*2);
 }
 
-WRITE16_HANDLER( SCSP_1_w )
+WRITE16_HANDLER( scsp_1_w )
 {
 	struct _SCSP *SCSP = sndti_token(SOUND_SCSP, 1);
 	unsigned short tmp;
@@ -1337,7 +1345,7 @@ WRITE16_HANDLER( SCSP_1_w )
 	SCSP_w16(SCSP, offset*2, tmp);
 }
 
-WRITE16_HANDLER( SCSP_MidiIn )
+WRITE16_HANDLER( scsp_midi_in )
 {
 	struct _SCSP *SCSP = sndti_token(SOUND_SCSP, 0);
 
@@ -1347,7 +1355,7 @@ WRITE16_HANDLER( SCSP_MidiIn )
 	CheckPendingIRQ(SCSP);
 }
 
-READ16_HANDLER( SCSP_MidiOutR )
+READ16_HANDLER( scsp_midi_out_r )
 {
 	struct _SCSP *SCSP = sndti_token(SOUND_SCSP, 0);
 	unsigned char val;
@@ -1363,7 +1371,7 @@ READ16_HANDLER( SCSP_MidiOutR )
  * Generic get_info
  **************************************************************************/
 
-static void scsp_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( scsp )
 {
 	switch (state)
 	{
@@ -1372,24 +1380,24 @@ static void scsp_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void scsp_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( scsp )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = scsp_set_info;			break;
-		case SNDINFO_PTR_START:							info->start = scsp_start;				break;
-		case SNDINFO_PTR_STOP:							/* Nothing */							break;
-		case SNDINFO_PTR_RESET:							/* Nothing */							break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( scsp );	break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( scsp );		break;
+		case SNDINFO_PTR_STOP:							/* Nothing */								break;
+		case SNDINFO_PTR_RESET:							/* Nothing */								break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "SCSP";						break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "Sega/Yamaha custom";			break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "2.1.1";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "SCSP");					break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Sega/Yamaha custom");		break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "2.1.1");					break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);					break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
