@@ -30,7 +30,7 @@
 #include <math.h>		/* for pow() */
 #include "sndintrf.h"
 #include "streams.h"
-#include "deprecat.h"
+#include "wavwrite.h"
 #include "sn76477.h"
 
 
@@ -64,7 +64,7 @@
 
 #define LOG_WAV_GAIN_FACTOR		1000
 
-#define LOG_WAV_FILE_NAME		"sn76477_%d.wav"
+#define LOG_WAV_FILE_NAME		"sn76477_%s.wav"
 
 
 #define LOG(n,x) do { if (VERBOSE >= (n)) logerror x; } while (0)
@@ -97,7 +97,7 @@
 #if TEST_MODE
 #include "input.h"
 
-static const struct SN76477interface empty_interface =
+static const sn76477_interface empty_interface =
 {
 	0,			/*  4 noise_clock_res  */
 	0,			/*  5 filter_res       */
@@ -255,12 +255,10 @@ struct SN76477
 
 	/* others */
 	sound_stream *channel;				/* returned by stream_create() */
-	UINT32 index;
 	int sample_rate; 					/* from machine->sample_rate */
+	const device_config *device;
 
-#if LOG_WAV
 	wav_file *file;						/* handle of the wave file to produce */
-#endif
 };
 
 
@@ -644,41 +642,41 @@ static void log_enable_line(struct SN76477 *sn)
 		"Enabled", "Inhibited"
 	};
 
-	LOG(1, ("SN76477 #%d:              Enable line (9): %d [%s]\n", sn->index, sn->enable, desc[sn->enable]));
+	LOG(1, ("SN76477 '%s':              Enable line (9): %d [%s]\n", sn->device->tag, sn->enable, desc[sn->enable]));
 }
 
 
 static void log_mixer_mode(struct SN76477 *sn)
 {
-	const char *desc[] =
+	static const char *const desc[] =
 	{
 		"VCO", "SLF", "Noise", "VCO/Noise",
 		"SLF/Noise", "SLF/VCO/Noise", "SLF/VCO", "Inhibit"
 	};
 
-	LOG(1, ("SN76477 #%d:           Mixer mode (25-27): %d [%s]\n", sn->index, sn->mixer_mode, desc[sn->mixer_mode]));
+	LOG(1, ("SN76477 '%s':           Mixer mode (25-27): %d [%s]\n", sn->device->tag, sn->mixer_mode, desc[sn->mixer_mode]));
 }
 
 
 static void log_envelope_mode(struct SN76477 *sn)
 {
-	const char *desc[] =
+	static const char *const desc[] =
 	{
 		"VCO", "One-Shot", "Mixer Only", "VCO with Alternating Polarity"
 	};
 
-	LOG(1, ("SN76477 #%d:         Envelope mode (1,28): %d [%s]\n", sn->index, sn->envelope_mode, desc[sn->envelope_mode]));
+	LOG(1, ("SN76477 '%s':         Envelope mode (1,28): %d [%s]\n", sn->device->tag, sn->envelope_mode, desc[sn->envelope_mode]));
 }
 
 
 static void log_vco_mode(struct SN76477 *sn)
 {
-	const char *desc[] =
+	static const char *const desc[] =
 	{
 		"External (Pin 16)", "Internal (SLF)"
 	};
 
-	LOG(1, ("SN76477 #%d:                VCO mode (22): %d [%s]\n", sn->index, sn->vco_mode, desc[sn->vco_mode]));
+	LOG(1, ("SN76477 '%s':                VCO mode (22): %d [%s]\n", sn->device->tag, sn->vco_mode, desc[sn->vco_mode]));
 }
 
 
@@ -688,16 +686,16 @@ static void log_one_shot_time(struct SN76477 *sn)
 	{
 		if (compute_one_shot_cap_charging_rate(sn) > 0)
 		{
-			LOG(1, ("SN76477 #%d:        One-shot time (23,24): %.4f sec\n", sn->index, ONE_SHOT_CAP_VOLTAGE_RANGE * (1 / compute_one_shot_cap_charging_rate(sn))));
+			LOG(1, ("SN76477 '%s':        One-shot time (23,24): %.4f sec\n", sn->device->tag, ONE_SHOT_CAP_VOLTAGE_RANGE * (1 / compute_one_shot_cap_charging_rate(sn))));
 		}
 		else
 		{
-			LOG(1, ("SN76477 #%d:        One-shot time (23,24): N/A\n", sn->index));
+			LOG(1, ("SN76477 '%s':        One-shot time (23,24): N/A\n", sn->device->tag));
 		}
 	}
 	else
 	{
-		LOG(1, ("SN76477 #%d:        One-shot time (23,24): External (cap = %.2fV)\n", sn->index, sn->one_shot_cap_voltage));
+		LOG(1, ("SN76477 '%s':        One-shot time (23,24): External (cap = %.2fV)\n", sn->device->tag, sn->one_shot_cap_voltage));
 	}
 }
 
@@ -711,29 +709,29 @@ static void log_slf_freq(struct SN76477 *sn)
 			double charging_time = (1 / compute_slf_cap_charging_rate(sn)) * SLF_CAP_VOLTAGE_RANGE;
 			double discharging_time = (1 / compute_slf_cap_discharging_rate(sn)) * SLF_CAP_VOLTAGE_RANGE;
 
-			LOG(1, ("SN76477 #%d:        SLF frequency (20,21): %.2f Hz\n", sn->index, 1 / (charging_time + discharging_time)));
+			LOG(1, ("SN76477 '%s':        SLF frequency (20,21): %.2f Hz\n", sn->device->tag, 1 / (charging_time + discharging_time)));
 		}
 		else
 		{
-			LOG(1, ("SN76477 #%d:        SLF frequency (20,21): N/A\n", sn->index));
+			LOG(1, ("SN76477 '%s':        SLF frequency (20,21): N/A\n", sn->device->tag));
 		}
 	}
 	else
 	{
-		LOG(1, ("SN76477 #%d:        SLF frequency (20,21): External (cap = %.2fV)\n", sn->index, sn->slf_cap_voltage));
+		LOG(1, ("SN76477 '%s':        SLF frequency (20,21): External (cap = %.2fV)\n", sn->device->tag, sn->slf_cap_voltage));
 	}
 }
 
 
 static void log_vco_pitch_voltage(struct SN76477 *sn)
 {
-	LOG(1, ("SN76477 #%d:       VCO pitch voltage (19): %.2fV\n", sn->index, sn->pitch_voltage));
+	LOG(1, ("SN76477 '%s':       VCO pitch voltage (19): %.2fV\n", sn->device->tag, sn->pitch_voltage));
 }
 
 
 static void log_vco_duty_cycle(struct SN76477 *sn)
 {
-	LOG(1, ("SN76477 #%d:       VCO duty cycle (16,19): %.0f%%\n", sn->index, compute_vco_duty_cycle(sn) * 100.0));
+	LOG(1, ("SN76477 '%s':       VCO duty cycle (16,19): %.0f%%\n", sn->device->tag, compute_vco_duty_cycle(sn) * 100.0));
 }
 
 
@@ -746,16 +744,16 @@ static void log_vco_freq(struct SN76477 *sn)
 			double min_freq = compute_vco_cap_charging_discharging_rate(sn) / (2 * VCO_CAP_VOLTAGE_RANGE);
 			double max_freq = compute_vco_cap_charging_discharging_rate(sn) / (2 * VCO_TO_SLF_VOLTAGE_DIFF);
 
-			LOG(1, ("SN76477 #%d:        VCO frequency (17,18): %.2f Hz - %.1f Hz\n", sn->index, min_freq, max_freq));
+			LOG(1, ("SN76477 '%s':        VCO frequency (17,18): %.2f Hz - %.1f Hz\n", sn->device->tag, min_freq, max_freq));
 		}
 		else
 		{
-			LOG(1, ("SN76477 #%d:        VCO frequency (17,18): N/A\n", sn->index));
+			LOG(1, ("SN76477 '%s':        VCO frequency (17,18): N/A\n", sn->device->tag));
 		}
 	}
 	else
 	{
-		LOG(1, ("SN76477 #%d:        VCO frequency (17,18): External (cap = %.2fV)\n", sn->index, sn->vco_cap_voltage));
+		LOG(1, ("SN76477 '%s':        VCO frequency (17,18): External (cap = %.2fV)\n", sn->device->tag, sn->vco_cap_voltage));
 	}
 }
 
@@ -767,13 +765,13 @@ static void log_vco_ext_voltage(struct SN76477 *sn)
 		double min_freq = compute_vco_cap_charging_discharging_rate(sn) / (2 * VCO_CAP_VOLTAGE_RANGE);
 		double max_freq = compute_vco_cap_charging_discharging_rate(sn) / (2 * VCO_TO_SLF_VOLTAGE_DIFF);
 
-		LOG(1, ("SN76477 #%d:        VCO ext. voltage (16): %.2fV (%.2f Hz)\n", sn->index,
+		LOG(1, ("SN76477 '%s':        VCO ext. voltage (16): %.2fV (%.2f Hz)\n", sn->device->tag,
 				sn->vco_voltage,
 				min_freq + ((max_freq - min_freq) * sn->vco_voltage / VCO_MAX_EXT_VOLTAGE)));
 	}
 	else
 	{
-		LOG(1, ("SN76477 #%d:        VCO ext. voltage (16): %.2fV (saturated, no output)\n", sn->index, sn->vco_voltage));
+		LOG(1, ("SN76477 '%s':        VCO ext. voltage (16): %.2fV (saturated, no output)\n", sn->device->tag, sn->vco_voltage));
 	}
 }
 
@@ -782,17 +780,17 @@ static void log_noise_gen_freq(struct SN76477 *sn)
 {
 	if (sn->noise_clock_ext)
 	{
-		LOG(1, ("SN76477 #%d:      Noise gen frequency (4): External\n", sn->index));
+		LOG(1, ("SN76477 '%s':      Noise gen frequency (4): External\n", sn->device->tag));
 	}
 	else
 	{
 		if (compute_noise_gen_freq(sn) > 0)
 		{
-			LOG(1, ("SN76477 #%d:      Noise gen frequency (4): %d Hz\n", sn->index, compute_noise_gen_freq(sn)));
+			LOG(1, ("SN76477 '%s':      Noise gen frequency (4): %d Hz\n", sn->device->tag, compute_noise_gen_freq(sn)));
 		}
 		else
 		{
-			LOG(1, ("SN76477 #%d:      Noise gen frequency (4): N/A\n", sn->index));
+			LOG(1, ("SN76477 '%s':      Noise gen frequency (4): N/A\n", sn->device->tag));
 		}
 	}
 }
@@ -811,21 +809,21 @@ static void log_noise_filter_freq(struct SN76477 *sn)
 				double charging_time = (1 / charging_rate) * NOISE_CAP_VOLTAGE_RANGE;
 				double discharging_time = (1 / charging_rate) * NOISE_CAP_VOLTAGE_RANGE;
 
-				LOG(1, ("SN76477 #%d: Noise filter frequency (5,6): %.0f Hz\n", sn->index, 1 / (charging_time + discharging_time)));
+				LOG(1, ("SN76477 '%s': Noise filter frequency (5,6): %.0f Hz\n", sn->device->tag, 1 / (charging_time + discharging_time)));
 			}
 			else
 			{
-				LOG(1, ("SN76477 #%d: Noise filter frequency (5,6): Very Large (Filtering Disabled)\n", sn->index));
+				LOG(1, ("SN76477 '%s': Noise filter frequency (5,6): Very Large (Filtering Disabled)\n", sn->device->tag));
 			}
 		}
 		else
 		{
-			LOG(1, ("SN76477 #%d: Noise filter frequency (5,6): N/A\n", sn->index));
+			LOG(1, ("SN76477 '%s': Noise filter frequency (5,6): N/A\n", sn->device->tag));
 		}
 	}
 	else
 	{
-		LOG(1, ("SN76477 #%d: Noise filter frequency (5,6): External (cap = %.2fV)\n", sn->index, sn->noise_filter_cap));
+		LOG(1, ("SN76477 '%s': Noise filter frequency (5,6): External (cap = %.2fV)\n", sn->device->tag, sn->noise_filter_cap));
 	}
 }
 
@@ -836,16 +834,16 @@ static void log_attack_time(struct SN76477 *sn)
 	{
 		if (compute_attack_decay_cap_charging_rate(sn) > 0)
 		{
-			LOG(1, ("SN76477 #%d:           Attack time (8,10): %.4f sec\n", sn->index, AD_CAP_VOLTAGE_RANGE * (1 / compute_attack_decay_cap_charging_rate(sn))));
+			LOG(1, ("SN76477 '%s':           Attack time (8,10): %.4f sec\n", sn->device->tag, AD_CAP_VOLTAGE_RANGE * (1 / compute_attack_decay_cap_charging_rate(sn))));
 		}
 		else
 		{
-			LOG(1, ("SN76477 #%d:           Attack time (8,10): N/A\n", sn->index));
+			LOG(1, ("SN76477 '%s':           Attack time (8,10): N/A\n", sn->device->tag));
 		}
 	}
 	else
 	{
-		LOG(1, ("SN76477 #%d:           Attack time (8,10): External (cap = %.2fV)\n", sn->index, sn->attack_decay_cap_voltage));
+		LOG(1, ("SN76477 '%s':           Attack time (8,10): External (cap = %.2fV)\n", sn->device->tag, sn->attack_decay_cap_voltage));
 	}
 }
 
@@ -856,24 +854,24 @@ static void log_decay_time(struct SN76477 *sn)
 	{
 		if (compute_attack_decay_cap_discharging_rate(sn) > 0)
 		{
-			LOG(1, ("SN76477 #%d:             Decay time (7,8): %.4f sec\n", sn->index, AD_CAP_VOLTAGE_RANGE * (1 / compute_attack_decay_cap_discharging_rate(sn))));
+			LOG(1, ("SN76477 '%s':             Decay time (7,8): %.4f sec\n", sn->device->tag, AD_CAP_VOLTAGE_RANGE * (1 / compute_attack_decay_cap_discharging_rate(sn))));
 		}
 		else
 		{
-			LOG(1, ("SN76477 #%d:            Decay time (8,10): N/A\n", sn->index));
+			LOG(1, ("SN76477 '%s':            Decay time (8,10): N/A\n", sn->device->tag));
 		}
 	}
 	else
 	{
-		LOG(1, ("SN76477 #%d:             Decay time (7, 8): External (cap = %.2fV)\n", sn->index, sn->attack_decay_cap_voltage));
+		LOG(1, ("SN76477 '%s':             Decay time (7, 8): External (cap = %.2fV)\n", sn->device->tag, sn->attack_decay_cap_voltage));
 	}
 }
 
 
 static void log_voltage_out(struct SN76477 *sn)
 {
-	LOG(1, ("SN76477 #%d:    Voltage OUT range (11,12): %.2fV - %.2fV (clips above %.2fV)\n",
-			sn->index,
+	LOG(1, ("SN76477 '%s':    Voltage OUT range (11,12): %.2fV - %.2fV (clips above %.2fV)\n",
+			sn->device->tag,
 			OUT_CENTER_LEVEL_VOLTAGE + compute_center_to_peak_voltage_out(sn) * out_neg_gain[(int)(AD_CAP_VOLTAGE_MAX * 10)],
 			OUT_CENTER_LEVEL_VOLTAGE + compute_center_to_peak_voltage_out(sn) * out_pos_gain[(int)(AD_CAP_VOLTAGE_MAX * 10)],
 			OUT_HIGH_CLIP_THRESHOLD));
@@ -907,19 +905,15 @@ static void log_complete_state(struct SN76477 *sn)
  *
  *****************************************************************************/
 
-#if LOG_WAV
-
-#include "wavwrite.h"
-
 
 static void open_wav_file(struct SN76477 *sn)
 {
 	char wav_file_name[30];
 
-	sprintf(wav_file_name, LOG_WAV_FILE_NAME, sn->index);
+	sprintf(wav_file_name, LOG_WAV_FILE_NAME, sn->device->tag);
 	sn->file = wav_open(wav_file_name, sn->sample_rate, 2);
 
-	LOG(1, ("SN76477 #%d:         Logging output: %s\n", sn->index, wav_file_name));
+	LOG(1, ("SN76477 '%s':         Logging output: %s\n", sn->device->tag, wav_file_name));
 }
 
 
@@ -934,8 +928,6 @@ static void add_wav_data(struct SN76477 *sn, INT16 data_l, INT16 data_r)
 	wav_add_data_16lr(sn->file, &data_l, &data_r, 1);
 }
 
-#endif
-
 
 
 /*****************************************************************************
@@ -1002,7 +994,7 @@ static void SN76477_test_enable_w(struct SN76477 *sn, UINT32 data)
 }
 
 
-void SN76477_enable_w(int chip, UINT32 data)
+void sn76477_enable_w(int chip, UINT32 data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1027,7 +1019,7 @@ static void _SN76477_mixer_a_w(struct SN76477 *sn, UINT32 data)
 }
 
 
-void SN76477_mixer_a_w(int chip, UINT32 data)
+void sn76477_mixer_a_w(int chip, UINT32 data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1052,7 +1044,7 @@ static void _SN76477_mixer_b_w(struct SN76477 *sn, UINT32 data)
 }
 
 
-void SN76477_mixer_b_w(int chip, UINT32 data)
+void sn76477_mixer_b_w(int chip, UINT32 data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1077,7 +1069,7 @@ static void _SN76477_mixer_c_w(struct SN76477 *sn, UINT32 data)
 }
 
 
-void SN76477_mixer_c_w(int chip, UINT32 data)
+void sn76477_mixer_c_w(int chip, UINT32 data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1109,7 +1101,7 @@ static void _SN76477_envelope_1_w(struct SN76477 *sn, UINT32 data)
 }
 
 
-void SN76477_envelope_1_w(int chip, UINT32 data)
+void sn76477_envelope_1_w(int chip, UINT32 data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1134,7 +1126,7 @@ static void _SN76477_envelope_2_w(struct SN76477 *sn, UINT32 data)
 }
 
 
-void SN76477_envelope_2_w(int chip, UINT32 data)
+void sn76477_envelope_2_w(int chip, UINT32 data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1166,7 +1158,7 @@ static void _SN76477_vco_w(struct SN76477 *sn, UINT32 data)
 }
 
 
-void SN76477_vco_w(int chip, UINT32 data)
+void sn76477_vco_w(int chip, UINT32 data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1198,7 +1190,7 @@ static void _SN76477_one_shot_res_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_one_shot_res_w(int chip, double data)
+void sn76477_one_shot_res_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1230,7 +1222,7 @@ static void _SN76477_one_shot_cap_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_one_shot_cap_w(int chip, double data)
+void sn76477_one_shot_cap_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1256,7 +1248,7 @@ void SN76477_one_shot_cap_w(int chip, double data)
  *
  *****************************************************************************/
 
-void SN76477_one_shot_cap_voltage_w(int chip, double data)
+void sn76477_one_shot_cap_voltage_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1305,7 +1297,7 @@ static void _SN76477_slf_res_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_slf_res_w(int chip, double data)
+void sn76477_slf_res_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1337,7 +1329,7 @@ static void _SN76477_slf_cap_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_slf_cap_w(int chip, double data)
+void sn76477_slf_cap_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1365,7 +1357,7 @@ void SN76477_slf_cap_w(int chip, double data)
  *
  *****************************************************************************/
 
-void SN76477_slf_cap_voltage_w(int chip, double data)
+void sn76477_slf_cap_voltage_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1414,7 +1406,7 @@ static void _SN76477_vco_res_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_vco_res_w(int chip, double data)
+void sn76477_vco_res_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1446,7 +1438,7 @@ static void _SN76477_vco_cap_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_vco_cap_w(int chip, double data)
+void sn76477_vco_cap_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1472,7 +1464,7 @@ void SN76477_vco_cap_w(int chip, double data)
  *
  *****************************************************************************/
 
-void SN76477_vco_cap_voltage_w(int chip, double data)
+void sn76477_vco_cap_voltage_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1521,7 +1513,7 @@ static void _SN76477_vco_voltage_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_vco_voltage_w(int chip, double data)
+void sn76477_vco_voltage_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1554,7 +1546,7 @@ static void _SN76477_pitch_voltage_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_pitch_voltage_w(int chip, double data)
+void sn76477_pitch_voltage_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1581,7 +1573,7 @@ void SN76477_pitch_voltage_w(int chip, double data)
  *
  *****************************************************************************/
 
-void SN76477_noise_clock_w(int chip, UINT32 data)
+void sn76477_noise_clock_w(int chip, UINT32 data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1627,7 +1619,7 @@ static void _SN76477_noise_clock_res_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_noise_clock_res_w(int chip, double data)
+void sn76477_noise_clock_res_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1660,7 +1652,7 @@ static void _SN76477_noise_filter_res_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_noise_filter_res_w(int chip, double data)
+void sn76477_noise_filter_res_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1692,7 +1684,7 @@ static void _SN76477_noise_filter_cap_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_noise_filter_cap_w(int chip, double data)
+void sn76477_noise_filter_cap_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1718,7 +1710,7 @@ void SN76477_noise_filter_cap_w(int chip, double data)
  *
  *****************************************************************************/
 
-void SN76477_noise_filter_cap_voltage_w(int chip, double data)
+void sn76477_noise_filter_cap_voltage_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1767,7 +1759,7 @@ static void _SN76477_attack_res_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_attack_res_w(int chip, double data)
+void sn76477_attack_res_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1799,7 +1791,7 @@ static void _SN76477_decay_res_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_decay_res_w(int chip, double data)
+void sn76477_decay_res_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1831,7 +1823,7 @@ static void _SN76477_attack_decay_cap_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_attack_decay_cap_w(int chip, double data)
+void sn76477_attack_decay_cap_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1858,7 +1850,7 @@ void SN76477_attack_decay_cap_w(int chip, double data)
  *
  *****************************************************************************/
 
-void SN76477_attack_decay_cap_voltage_w(int chip, double data)
+void sn76477_attack_decay_cap_voltage_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1909,7 +1901,7 @@ static void _SN76477_amplitude_res_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_amplitude_res_w(int chip, double data)
+void sn76477_amplitude_res_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1941,7 +1933,7 @@ static void _SN76477_feedback_res_w(struct SN76477 *sn, double data)
 }
 
 
-void SN76477_feedback_res_w(int chip, double data)
+void sn76477_feedback_res_w(int chip, double data)
 {
 #if TEST_MODE == 0
 	struct SN76477 *sn = sndti_token(SOUND_SN76477, chip);
@@ -1967,7 +1959,7 @@ void SN76477_feedback_res_w(int chip, double data)
  *
  *****************************************************************************/
 
-static void SN76477_update(void *param, stream_sample_t **inputs, stream_sample_t **_buffer, int length)
+static STREAM_UPDATE( SN76477_update )
 {
 	double one_shot_cap_charging_step;
 	double one_shot_cap_discharging_step;
@@ -1987,7 +1979,7 @@ static void SN76477_update(void *param, stream_sample_t **inputs, stream_sample_
 	double center_to_peak_voltage_out;
 
 	struct SN76477 *sn = param;
-	stream_sample_t *buffer = _buffer[0];
+	stream_sample_t *buffer = outputs[0];
 
 
 #if TEST_MODE
@@ -2025,8 +2017,8 @@ static void SN76477_update(void *param, stream_sample_t **inputs, stream_sample_
 	center_to_peak_voltage_out = compute_center_to_peak_voltage_out(sn);
 
 
-	/* process 'length' number of samples */
-	while (length--)
+	/* process 'samples' number of samples */
+	while (samples--)
 	{
 		/* update the one-shot cap voltage */
 		if (!sn->one_shot_cap_voltage_ext)
@@ -2280,48 +2272,45 @@ static void SN76477_update(void *param, stream_sample_t **inputs, stream_sample_
          */
 		*buffer++ = (((voltage_out - OUT_LOW_CLIP_THRESHOLD) / (OUT_CENTER_LEVEL_VOLTAGE - OUT_LOW_CLIP_THRESHOLD)) - 1) * 32767;
 
-#if LOG_WAV
-#if LOG_WAV_ENABLED_ONLY
-		if (!sn->enable)
-#endif
+		if (LOG_WAV && LOG_WAV_ENABLED_ONLY && !sn->enable)
 		{
 			INT16 log_data_l;
 			INT16 log_data_r;
 
-#if LOG_WAV_VALUE_L == 0
-			log_data_l = LOG_WAV_GAIN_FACTOR * voltage_out;
-#elif LOG_WAV_VALUE_L == 1
-			log_data_l = LOG_WAV_GAIN_FACTOR * sn->enable;
-#elif LOG_WAV_VALUE_L == 2
-			log_data_l = LOG_WAV_GAIN_FACTOR * sn->one_shot_cap_voltage;
-#elif LOG_WAV_VALUE_L == 3
-			log_data_l = LOG_WAV_GAIN_FACTOR * sn->attack_decay_cap_voltage;
-#elif LOG_WAV_VALUE_L == 4
-			log_data_l = LOG_WAV_GAIN_FACTOR * sn->slf_cap_voltage;
-#elif LOG_WAV_VALUE_L == 5
-			log_data_l = LOG_WAV_GAIN_FACTOR * sn->vco_cap_voltage;
-#elif LOG_WAV_VALUE_L == 6
-			log_data_l = LOG_WAV_GAIN_FACTOR * sn->noise_filter_cap_voltage;
-#endif
+			switch (LOG_WAV_VALUE_L)
+			{
+			case 0:
+				log_data_l = LOG_WAV_GAIN_FACTOR * voltage_out;
+				log_data_r = LOG_WAV_GAIN_FACTOR * voltage_out;
+				break;
+			case 1:
+				log_data_l = LOG_WAV_GAIN_FACTOR * sn->enable;
+				log_data_r = LOG_WAV_GAIN_FACTOR * sn->enable;
+				break;
+			case 2:
+				log_data_l = LOG_WAV_GAIN_FACTOR * sn->one_shot_cap_voltage;
+				log_data_r = LOG_WAV_GAIN_FACTOR * sn->one_shot_cap_voltage;
+				break;
+			case 3:
+				log_data_l = LOG_WAV_GAIN_FACTOR * sn->attack_decay_cap_voltage;
+				log_data_r = LOG_WAV_GAIN_FACTOR * sn->attack_decay_cap_voltage;
+				break;
+			case 4:
+				log_data_l = LOG_WAV_GAIN_FACTOR * sn->slf_cap_voltage;
+				log_data_r = LOG_WAV_GAIN_FACTOR * sn->slf_cap_voltage;
+				break;
+			case 5:
+				log_data_l = LOG_WAV_GAIN_FACTOR * sn->vco_cap_voltage;
+				log_data_r = LOG_WAV_GAIN_FACTOR * sn->vco_cap_voltage;
+				break;
+			case 6:
+				log_data_l = LOG_WAV_GAIN_FACTOR * sn->noise_filter_cap_voltage;
+				log_data_r = LOG_WAV_GAIN_FACTOR * sn->noise_filter_cap_voltage;
+				break;
+			}
 
-#if LOG_WAV_VALUE_R == 0
-			log_data_r = LOG_WAV_GAIN_FACTOR * voltage_out;
-#elif LOG_WAV_VALUE_R == 1
-			log_data_r = LOG_WAV_GAIN_FACTOR * sn->enable;
-#elif LOG_WAV_VALUE_R == 2
-			log_data_r = LOG_WAV_GAIN_FACTOR * sn->one_shot_cap_voltage;
-#elif LOG_WAV_VALUE_R == 3
-			log_data_r = LOG_WAV_GAIN_FACTOR * sn->attack_decay_cap_voltage;
-#elif LOG_WAV_VALUE_R == 4
-			log_data_r = LOG_WAV_GAIN_FACTOR * sn->slf_cap_voltage;
-#elif LOG_WAV_VALUE_R == 5
-			log_data_r = LOG_WAV_GAIN_FACTOR * sn->vco_cap_voltage;
-#elif LOG_WAV_VALUE_R == 6
-			log_data_r = LOG_WAV_GAIN_FACTOR * sn->noise_filter_cap_voltage;
-#endif
 			add_wav_data(sn, log_data_l, log_data_r);
 		}
-#endif
 	}
 }
 
@@ -2333,60 +2322,60 @@ static void SN76477_update(void *param, stream_sample_t **inputs, stream_sample_
  *
  *****************************************************************************/
 
-static void state_save_register(struct SN76477 *sn)
+static void state_save_register(const device_config *device, struct SN76477 *sn)
 {
-	state_save_register_item("sn76744", sn->index, sn->enable);
-	state_save_register_item("sn76744", sn->index, sn->envelope_mode);
-	state_save_register_item("sn76744", sn->index, sn->vco_mode);
-	state_save_register_item("sn76744", sn->index, sn->mixer_mode);
+	state_save_register_device_item(device, 0, sn->enable);
+	state_save_register_device_item(device, 0, sn->envelope_mode);
+	state_save_register_device_item(device, 0, sn->vco_mode);
+	state_save_register_device_item(device, 0, sn->mixer_mode);
 
-	state_save_register_item("sn76744", sn->index, sn->one_shot_res);
-	state_save_register_item("sn76744", sn->index, sn->one_shot_cap);
-	state_save_register_item("sn76744", sn->index, sn->one_shot_cap_voltage_ext);
+	state_save_register_device_item(device, 0, sn->one_shot_res);
+	state_save_register_device_item(device, 0, sn->one_shot_cap);
+	state_save_register_device_item(device, 0, sn->one_shot_cap_voltage_ext);
 
-	state_save_register_item("sn76744", sn->index, sn->slf_res);
-	state_save_register_item("sn76744", sn->index, sn->slf_cap);
-	state_save_register_item("sn76744", sn->index, sn->slf_cap_voltage_ext);
+	state_save_register_device_item(device, 0, sn->slf_res);
+	state_save_register_device_item(device, 0, sn->slf_cap);
+	state_save_register_device_item(device, 0, sn->slf_cap_voltage_ext);
 
-	state_save_register_item("sn76744", sn->index, sn->vco_voltage);
-	state_save_register_item("sn76744", sn->index, sn->vco_res);
-	state_save_register_item("sn76744", sn->index, sn->vco_cap);
-	state_save_register_item("sn76744", sn->index, sn->vco_cap_voltage_ext);
+	state_save_register_device_item(device, 0, sn->vco_voltage);
+	state_save_register_device_item(device, 0, sn->vco_res);
+	state_save_register_device_item(device, 0, sn->vco_cap);
+	state_save_register_device_item(device, 0, sn->vco_cap_voltage_ext);
 
-	state_save_register_item("sn76744", sn->index, sn->noise_clock_res);
-	state_save_register_item("sn76744", sn->index, sn->noise_clock_ext);
-	state_save_register_item("sn76744", sn->index, sn->noise_clock);
-	state_save_register_item("sn76744", sn->index, sn->noise_filter_res);
-	state_save_register_item("sn76744", sn->index, sn->noise_filter_cap);
-	state_save_register_item("sn76744", sn->index, sn->noise_filter_cap_voltage_ext);
+	state_save_register_device_item(device, 0, sn->noise_clock_res);
+	state_save_register_device_item(device, 0, sn->noise_clock_ext);
+	state_save_register_device_item(device, 0, sn->noise_clock);
+	state_save_register_device_item(device, 0, sn->noise_filter_res);
+	state_save_register_device_item(device, 0, sn->noise_filter_cap);
+	state_save_register_device_item(device, 0, sn->noise_filter_cap_voltage_ext);
 
-	state_save_register_item("sn76744", sn->index, sn->attack_res);
-	state_save_register_item("sn76744", sn->index, sn->decay_res);
-	state_save_register_item("sn76744", sn->index, sn->attack_decay_cap);
-	state_save_register_item("sn76744", sn->index, sn->attack_decay_cap_voltage_ext);
+	state_save_register_device_item(device, 0, sn->attack_res);
+	state_save_register_device_item(device, 0, sn->decay_res);
+	state_save_register_device_item(device, 0, sn->attack_decay_cap);
+	state_save_register_device_item(device, 0, sn->attack_decay_cap_voltage_ext);
 
-	state_save_register_item("sn76744", sn->index, sn->amplitude_res);
-	state_save_register_item("sn76744", sn->index, sn->feedback_res);
-	state_save_register_item("sn76744", sn->index, sn->pitch_voltage);
+	state_save_register_device_item(device, 0, sn->amplitude_res);
+	state_save_register_device_item(device, 0, sn->feedback_res);
+	state_save_register_device_item(device, 0, sn->pitch_voltage);
 
-	state_save_register_item("sn76744", sn->index, sn->one_shot_cap_voltage);
-	state_save_register_item("sn76744", sn->index, sn->one_shot_running_ff);
+	state_save_register_device_item(device, 0, sn->one_shot_cap_voltage);
+	state_save_register_device_item(device, 0, sn->one_shot_running_ff);
 
-	state_save_register_item("sn76744", sn->index, sn->slf_cap_voltage);
-	state_save_register_item("sn76744", sn->index, sn->slf_out_ff);
+	state_save_register_device_item(device, 0, sn->slf_cap_voltage);
+	state_save_register_device_item(device, 0, sn->slf_out_ff);
 
-	state_save_register_item("sn76744", sn->index, sn->vco_cap_voltage);
-	state_save_register_item("sn76744", sn->index, sn->vco_out_ff);
-	state_save_register_item("sn76744", sn->index, sn->vco_alt_pos_edge_ff);
+	state_save_register_device_item(device, 0, sn->vco_cap_voltage);
+	state_save_register_device_item(device, 0, sn->vco_out_ff);
+	state_save_register_device_item(device, 0, sn->vco_alt_pos_edge_ff);
 
-	state_save_register_item("sn76744", sn->index, sn->noise_filter_cap_voltage);
-	state_save_register_item("sn76744", sn->index, sn->real_noise_bit_ff);
-	state_save_register_item("sn76744", sn->index, sn->filtered_noise_bit_ff);
-	state_save_register_item("sn76744", sn->index, sn->noise_gen_count);
+	state_save_register_device_item(device, 0, sn->noise_filter_cap_voltage);
+	state_save_register_device_item(device, 0, sn->real_noise_bit_ff);
+	state_save_register_device_item(device, 0, sn->filtered_noise_bit_ff);
+	state_save_register_device_item(device, 0, sn->noise_gen_count);
 
-	state_save_register_item("sn76744", sn->index, sn->attack_decay_cap_voltage);
+	state_save_register_device_item(device, 0, sn->attack_decay_cap_voltage);
 
-	state_save_register_item("sn76744", sn->index, sn->rng);
+	state_save_register_device_item(device, 0, sn->rng);
 }
 
 
@@ -2397,14 +2386,14 @@ static void state_save_register(struct SN76477 *sn)
  *
  *****************************************************************************/
 
-static void *sn76477_start(int sndindex, int clock, const void *config)
+static SND_START( sn76477 )
 {
 	struct SN76477 *sn;
-	struct SN76477interface *intf;
+	sn76477_interface *intf;
 
 
 #if TEST_MODE == 0
-	intf = (struct SN76477interface *)config;
+	intf = (sn76477_interface *)config;
 #else
 	intf = &test_interface;
 #endif
@@ -2413,9 +2402,9 @@ static void *sn76477_start(int sndindex, int clock, const void *config)
 	sn = auto_malloc(sizeof(*sn));
 	memset(sn, 0, sizeof(*sn));
 
-	sn->index = sndindex;
+	sn->device = device;
 
-	sn->channel = stream_create(0, 1, Machine->sample_rate, sn, SN76477_update);
+	sn->channel = stream_create(device, 0, 1, device->machine->sample_rate, sn, SN76477_update);
 
 	if (clock > 0)
 	{
@@ -2423,7 +2412,7 @@ static void *sn76477_start(int sndindex, int clock, const void *config)
 	}
 	else
 	{
-		sn->sample_rate = Machine->sample_rate;
+		sn->sample_rate = device->machine->sample_rate;
 	}
 
 	intialize_noise(sn);
@@ -2461,41 +2450,37 @@ static void *sn76477_start(int sndindex, int clock, const void *config)
 	sn->noise_filter_cap_voltage = NOISE_CAP_VOLTAGE_MIN;
 	sn->attack_decay_cap_voltage = AD_CAP_VOLTAGE_MIN;
 
-	state_save_register(sn);
+	state_save_register(device, sn);
 
 	log_complete_state(sn);
 
-#if LOG_WAV
-	open_wav_file(sn);
-#endif
+	if (LOG_WAV)
+		open_wav_file(sn);
 
 	return sn;
 }
 
 
-#if LOG_WAV
-static void sn76477_stop(void *token)
+static SND_STOP( sn76477 )
 {
-	struct SN76477 *sn = (struct SN76477 *)token;
+	struct SN76477 *sn = device->token;
 
-	close_wav_file(sn);
+	if (LOG_WAV)
+		close_wav_file(sn);
 }
-#endif
 
 
-void sn76477_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( sn76477 )
 {
 	switch (state)
 	{
-	case SNDINFO_PTR_START:			info->start = sn76477_start; break;
-#if LOG_WAV
-	case SNDINFO_PTR_STOP:			info->stop = sn76477_stop; break;
-#endif
-	case SNDINFO_STR_NAME:			info->s = "SN76477"; break;
-	case SNDINFO_STR_CORE_FAMILY:	info->s = "Analog"; break;
-	case SNDINFO_STR_CORE_VERSION:	info->s = "2.1"; break;
-	case SNDINFO_STR_CORE_FILE:		info->s = __FILE__; break;
-	case SNDINFO_STR_CORE_CREDITS:	info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+	case SNDINFO_PTR_START:			info->start = SND_START_NAME( sn76477 ); break;
+	case SNDINFO_PTR_STOP:			info->stop = SND_STOP_NAME( sn76477 ); break;
+	case SNDINFO_STR_NAME:			strcpy(info->s, "SN76477"); break;
+	case SNDINFO_STR_CORE_FAMILY:	strcpy(info->s, "Analog"); break;
+	case SNDINFO_STR_CORE_VERSION:	strcpy(info->s, "2.1"); break;
+	case SNDINFO_STR_CORE_FILE:		strcpy(info->s, __FILE__); break;
+	case SNDINFO_STR_CORE_CREDITS:	strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
