@@ -7,6 +7,7 @@
      Additional tweaking by Aaron Giles
      Various fixes by Lord Nightmare
      Additional enhancements by Couriersud
+     Sub-interpolation-cycle parameter updating added by Lord Nightmare
 
      Todo:
         - implement CS
@@ -110,8 +111,9 @@ struct tms5110
 	UINT8  addr_bit;
 
 	/* external callback */
-	int (*M0_callback)(void);
+	int (*M0_callback)(const device_config *);
 	void (*set_load_address)(int);
+	const device_config *device;
 
 	/* these contain data describing the current and previous voice frames */
 	UINT16 old_energy;
@@ -175,54 +177,55 @@ void tms5110_set_variant(void *chip, int variant)
 	tms->variant = variant;
 }
 
-void *tms5110_create(int index, int variant)
+void *tms5110_create(const device_config *device, int variant)
 {
 	struct tms5110 *tms;
 
 	tms = malloc_or_die(sizeof(*tms));
 	memset(tms, 0, sizeof(*tms));
 
+	tms->device = device;
 	tms5110_set_variant(tms, variant);
 
-	state_save_register_item_array("tms5110", index, tms->fifo);
-	state_save_register_item("tms5110", index, tms->fifo_head);
-	state_save_register_item("tms5110", index, tms->fifo_tail);
-	state_save_register_item("tms5110", index, tms->fifo_count);
+	state_save_register_device_item_array(device, 0, tms->fifo);
+	state_save_register_device_item(device, 0, tms->fifo_head);
+	state_save_register_device_item(device, 0, tms->fifo_tail);
+	state_save_register_device_item(device, 0, tms->fifo_count);
 
-	state_save_register_item("tms5110", index, tms->PDC);
-	state_save_register_item("tms5110", index, tms->CTL_pins);
-	state_save_register_item("tms5110", index, tms->speaking_now);
-	state_save_register_item("tms5110", index, tms->speak_delay_frames);
-	state_save_register_item("tms5110", index, tms->talk_status);
+	state_save_register_device_item(device, 0, tms->PDC);
+	state_save_register_device_item(device, 0, tms->CTL_pins);
+	state_save_register_device_item(device, 0, tms->speaking_now);
+	state_save_register_device_item(device, 0, tms->speak_delay_frames);
+	state_save_register_device_item(device, 0, tms->talk_status);
 
-	state_save_register_item("tms5110", index, tms->old_energy);
-	state_save_register_item("tms5110", index, tms->old_pitch);
-	state_save_register_item_array("tms5110", index, tms->old_k);
+	state_save_register_device_item(device, 0, tms->old_energy);
+	state_save_register_device_item(device, 0, tms->old_pitch);
+	state_save_register_device_item_array(device, 0, tms->old_k);
 
-	state_save_register_item("tms5110", index, tms->new_energy);
-	state_save_register_item("tms5110", index, tms->new_pitch);
-	state_save_register_item_array("tms5110", index, tms->new_k);
+	state_save_register_device_item(device, 0, tms->new_energy);
+	state_save_register_device_item(device, 0, tms->new_pitch);
+	state_save_register_device_item_array(device, 0, tms->new_k);
 
-	state_save_register_item("tms5110", index, tms->current_energy);
-	state_save_register_item("tms5110", index, tms->current_pitch);
-	state_save_register_item_array("tms5110", index, tms->current_k);
+	state_save_register_device_item(device, 0, tms->current_energy);
+	state_save_register_device_item(device, 0, tms->current_pitch);
+	state_save_register_device_item_array(device, 0, tms->current_k);
 
-	state_save_register_item("tms5110", index, tms->target_energy);
-	state_save_register_item("tms5110", index, tms->target_pitch);
-	state_save_register_item_array("tms5110", index, tms->target_k);
+	state_save_register_device_item(device, 0, tms->target_energy);
+	state_save_register_device_item(device, 0, tms->target_pitch);
+	state_save_register_device_item_array(device, 0, tms->target_k);
 
-	state_save_register_item("tms5110", index, tms->interp_count);
-	state_save_register_item("tms5110", index, tms->sample_count);
-	state_save_register_item("tms5110", index, tms->pitch_count);
+	state_save_register_device_item(device, 0, tms->interp_count);
+	state_save_register_device_item(device, 0, tms->sample_count);
+	state_save_register_device_item(device, 0, tms->pitch_count);
 
-	state_save_register_item("tms5110", index, tms->next_is_address);
-	state_save_register_item("tms5110", index, tms->address);
-	state_save_register_item("tms5110", index, tms->schedule_dummy_read);
-	state_save_register_item("tms5110", index, tms->addr_bit);
+	state_save_register_device_item(device, 0, tms->next_is_address);
+	state_save_register_device_item(device, 0, tms->address);
+	state_save_register_device_item(device, 0, tms->schedule_dummy_read);
+	state_save_register_device_item(device, 0, tms->addr_bit);
 
-	state_save_register_item_array("tms5110", index, tms->x);
+	state_save_register_device_item_array(device, 0, tms->x);
 
-	state_save_register_item("tms5110", index, tms->RNG);
+	state_save_register_device_item(device, 0, tms->RNG);
 
 	return tms;
 }
@@ -279,7 +282,7 @@ void tms5110_reset_chip(void *chip)
 
 ******************************************************************************************/
 
-void tms5110_set_M0_callback(void *chip, int (*func)(void))
+void tms5110_set_M0_callback(void *chip, int (*func)(const device_config *))
 {
 	struct tms5110 *tms = chip;
 	tms->M0_callback = func;
@@ -346,7 +349,7 @@ int i;
 	{
 		if (tms->M0_callback)
 		{
-			int data = (*tms->M0_callback)();
+			int data = (*tms->M0_callback)(tms->device);
 			FIFO_data_write(tms, data);
 		}
 		else
@@ -360,7 +363,7 @@ static void perform_dummy_read(struct tms5110 *tms)
 	{
 		if (tms->M0_callback)
 		{
-			int data = (*tms->M0_callback)();
+			int data = (*tms->M0_callback)(tms->device);
 				if (DEBUG_5110) logerror("TMS5110 performing dummy read; value read = %1i\n", data&1);
 		}
 			else
@@ -417,7 +420,7 @@ void tms5110_process(void *chip, INT16 *buffer, unsigned int size)
 {
 	struct tms5110 *tms = chip;
 	int buf_count=0;
-	int i, interp_period;
+	int i, interp_period, bitout;
 	INT16 Y11, cliptemp;
 
 	/* if we're not speaking, fill with nothingness */
@@ -542,28 +545,79 @@ void tms5110_process(void *chip, INT16 *buffer, unsigned int size)
 					tms->target_k[i] = tms->new_k[i];
 			}
 		}
-		else if (tms->interp_count == 0)
+		else
 		{
-			/* interpolate (update) values based on step values */
-			/*logerror("\n");*/
-
 			interp_period = tms->sample_count / 25;
-			tms->current_energy += (tms->target_energy - tms->current_energy) / tms->coeff->interp_coeff[interp_period];
-			tms->current_pitch += (tms->target_pitch - tms->current_pitch) / tms->coeff->interp_coeff[interp_period];
-
-			/*logerror("*** Energy = %d\n",current_energy);*/
-
-			for (i = 0; i < tms->coeff->num_k; i++)
+			switch(tms->interp_count)
 			{
-				tms->current_k[i] += (tms->target_k[i] - tms->current_k[i]) / tms->coeff->interp_coeff[interp_period];
+				/*         PC=X  X cycle, rendering change (change for next cycle which chip is actually doing) */
+				case 0: /* PC=0, A cycle, nothing happens (calc energy) */
+				break;
+				case 1: /* PC=0, B cycle, nothing happens (update energy) */
+				break;
+				case 2: /* PC=1, A cycle, update energy (calc pitch) */
+				tms->current_energy += ((tms->target_energy - tms->current_energy) >> tms->coeff->interp_coeff[interp_period]);
+				break;
+				case 3: /* PC=1, B cycle, nothing happens (update pitch) */
+				break;
+				case 4: /* PC=2, A cycle, update pitch (calc K1) */
+				tms->current_pitch += ((tms->target_pitch - tms->current_pitch) >> tms->coeff->interp_coeff[interp_period]);
+				break;
+				case 5: /* PC=2, B cycle, nothing happens (update K1) */
+				break;
+				case 6: /* PC=3, A cycle, update K1 (calc K2) */
+				tms->current_k[0] += ((tms->target_k[0] - tms->current_k[0]) >> tms->coeff->interp_coeff[interp_period]);
+				break;
+				case 7: /* PC=3, B cycle, nothing happens (update K2) */
+				break;
+				case 8: /* PC=4, A cycle, update K2 (calc K3) */
+				tms->current_k[1] += ((tms->target_k[1] - tms->current_k[1]) >> tms->coeff->interp_coeff[interp_period]);
+				break;
+				case 9: /* PC=4, B cycle, nothing happens (update K3) */
+				break;
+				case 10: /* PC=5, A cycle, update K3 (calc K4) */
+				tms->current_k[2] += ((tms->target_k[2] - tms->current_k[2]) >> tms->coeff->interp_coeff[interp_period]);
+				break;
+				case 11: /* PC=5, B cycle, nothing happens (update K4) */
+				break;
+				case 12: /* PC=6, A cycle, update K4 (calc K5) */
+				tms->current_k[3] += ((tms->target_k[3] - tms->current_k[3]) >> tms->coeff->interp_coeff[interp_period]);
+				break;
+				case 13: /* PC=6, B cycle, nothing happens (update K5) */
+				break;
+				case 14: /* PC=7, A cycle, update K5 (calc K6) */
+				tms->current_k[4] += ((tms->target_k[4] - tms->current_k[4]) >> tms->coeff->interp_coeff[interp_period]);
+				break;
+				case 15: /* PC=7, B cycle, nothing happens (update K6) */
+				break;
+				case 16: /* PC=8, A cycle, update K6 (calc K7) */
+				tms->current_k[5] += ((tms->target_k[5] - tms->current_k[5]) >> tms->coeff->interp_coeff[interp_period]);
+				break;
+				case 17: /* PC=8, B cycle, nothing happens (update K7) */
+				break;
+				case 18: /* PC=9, A cycle, update K7 (calc K8) */
+				tms->current_k[6] += ((tms->target_k[6] - tms->current_k[6]) >> tms->coeff->interp_coeff[interp_period]);
+				break;
+				case 19: /* PC=9, B cycle, nothing happens (update K8) */
+				break;
+				case 20: /* PC=10, A cycle, update K8 (calc K9) */
+				tms->current_k[7] += ((tms->target_k[7] - tms->current_k[7]) >> tms->coeff->interp_coeff[interp_period]);
+				break;
+				case 21: /* PC=10, B cycle, nothing happens (update K9) */
+				break;
+				case 22: /* PC=11, A cycle, update K9 (calc K10) */
+				tms->current_k[8] += ((tms->target_k[8] - tms->current_k[8]) >> tms->coeff->interp_coeff[interp_period]);
+				break;
+				case 23: /* PC=11, B cycle, nothing happens (update K10) */
+				break;
+				case 24: /* PC=12, A cycle, update K10 (do nothing) */
+				tms->current_k[9] += ((tms->target_k[9] - tms->current_k[9]) >> tms->coeff->interp_coeff[interp_period]);
+				break;
 			}
 		}
 
 
-
-
-
-	/* calculate the output */
+		/* calculate the output */
 
 		if (tms->current_energy == 0)
 		{
@@ -572,38 +626,42 @@ void tms5110_process(void *chip, INT16 *buffer, unsigned int size)
 		}
 		else if (tms->old_pitch == 0)
 		{
-			int bitout, randbit;
-
 			/* generate unvoiced samples here */
 			if (tms->RNG&1)
-				randbit = -64; /* according to the patent it is (either + or -) half of the maximum value in the chirp table */
+				current_val = -64; /* according to the patent it is (either + or -) half of the maximum value in the chirp table */
 			else
-				randbit = 64;
+				current_val = 64;
 
-			bitout = ((tms->RNG>>12)&1) ^
-					 ((tms->RNG>>10)&1) ^
-					 ((tms->RNG>> 9)&1) ^
-					 ((tms->RNG>> 0)&1);
-			tms->RNG >>= 1;
-			tms->RNG |= (bitout<<12);
-
-			current_val = randbit;
 		}
 		else
 		{
-			/* generate voiced samples here */
-			if (tms->coeff->subtype & (SUBTYPE_TMS5100 | SUBTYPE_M58817))
-			{
-				if (tms->pitch_count > 50)
-					current_val = 0;
-				else
-					current_val = tms->coeff->chirptable[tms->pitch_count];
+	                 /* generate voiced samples here */
+            /* US patent 4331836 Figure 14B shows, and logic would hold, that a pitch based chirp
+             * function has a chirp/peak and then a long chain of zeroes.
+             * The last entry of the chirp rom is at address 0b110011 (50d), the 51st sample,
+             * and if the address reaches that point the ADDRESS incrementer is
+             * disabled, forcing all samples beyond 50d to be == 50d
+             * (address 50d holds zeroes)
+             */
 
-			}
-			else
-				current_val = (tms->coeff->chirptable[tms->pitch_count%sizeof(tms->coeff->chirptable)]);
+	  /*if (tms->coeff->subtype & (SUBTYPE_TMS5100 | SUBTYPE_M58817))*/
+
+		if (tms->pitch_count > 50)
+			current_val = tms->coeff->chirptable[50];
+		else
+			current_val = tms->coeff->chirptable[tms->pitch_count];
 		}
 
+		/* Update LFSR *20* times every sample, like patent shows */
+		for (i=0; i<20; i++)
+		{
+			bitout = ((tms->RNG>>12)&1) ^
+				 ((tms->RNG>>10)&1) ^
+				 ((tms->RNG>> 9)&1) ^
+				 ((tms->RNG>> 0)&1);
+			tms->RNG >>= 1;
+			tms->RNG |= (bitout<<12);
+		}
 
 		/* Lattice filter here */
 
