@@ -1,6 +1,6 @@
 /**********************************************************************************************
 
-     TMS5220 simulator
+     TMS5200/5220 simulator
 
      Written for MAME by Frank Palazzolo
      With help from Neill Corlett
@@ -10,6 +10,33 @@
      Chirp/excitation table fixes by Lord Nightmare
      Various fixes by Lord Nightmare
      Modularization by Lord Nightmare
+     Sub-interpolation-cycle parameter updating added by Lord Nightmare
+
+     Much information regarding these lpc encoding comes from US patent 4,209,844
+     US patent 4,331,836 describes the complete 51xx chip
+     US patent 4,335,277 describes the complete 52xx chip
+     Special Thanks to Larry Brantingham for answering questions regarding the chip details
+
+   TMS5200/TMS5220/TMS5220C:
+
+                 +-----------------+
+        D7(d0)   |  1           28 |  /RS
+        ADD1     |  2           27 |  /WS
+        ROMCLK   |  3           26 |  D6(d1)
+        VDD(-5)  |  4           25 |  ADD2
+        VSS(+5)  |  5           24 |  D5(d2)
+        OSC      |  6           23 |  ADD4
+        T11      |  7           22 |  D4(d3)
+        SPKR     |  8           21 |  ADD8/DATA
+        I/O      |  9           20 |  TEST
+        PROMOUT  | 10           19 |  D3(d4)
+        VREF(GND)| 11           18 |  /READY
+        D2(d5)   | 12           17 |  /INT
+        D1(d6)   | 13           16 |  M1
+        D0(d7)   | 14           15 |  M0
+                 +-----------------+
+Note the standard naming for d* data bits with 7 as MSB and 0 as LSB is in lowercase.
+TI's naming has D7 as LSB and D0 as MSB and is in uppercase
 
 ***********************************************************************************************/
 
@@ -64,7 +91,7 @@ struct tms5220
 	UINT8 buffer_empty;		/* FIFO is empty*/
 	UINT8 irq_pin;			/* state of the IRQ pin (output) */
 
-	void (*irq_func)(int state); /* called when the state of the IRQ pin changes */
+	void (*irq_func)(running_machine *machine, int state); /* called when the state of the IRQ pin changes */
 
 
 	/* these contain data describing the current and previous voice frames */
@@ -88,9 +115,9 @@ struct tms5220
 
 	UINT16 previous_energy;         /* needed for lattice filter to match patent */
 
-	UINT8 interp_count;		/* number of interp periods (0-7) */
-	UINT8 sample_count;		/* sample number within interp (0-24) */
-	UINT16 pitch_count;
+	UINT8 interp_count;		/* number of samples within each sub-interpolation period, ranges from 0-24 */
+	UINT8 sample_count;		/* number of samples within the ENTIRE interpolation period, ranges from 0-199 */
+	UINT16 pitch_count;		/* pitch counter; provides chirp rom address */
 
 	INT32 u[11];
 	INT32 x[10];
@@ -109,27 +136,29 @@ struct tms5220
 	UINT8 RDB_flag;					/* whether we should read data register or status register */
 
 	/* flag for variant tmc0285/tms5200 emulation */
-	/* The TMC0285 AKA TMS5200 is an early variant of the TMS5220 used in
+	/* The TMC0285 AKA TMS5200 is an earlier variant of the TMS5220 used in
        the early releases of the Speech Module for the TI-99/4(a) computer,
        in Zaccaria's 'Money Money', and in a few other places.
-       The TMS5200 has a bug in its state machine PLA which causes it to
-       incorrectly use the LPC K3 parameter table for both K3 and K4.
-       (the chip has the unused K4 parameter in its internal ROM, but it is
-       never accessed due to the PLA bug)
-       The bug was fixed in the quickly-released TMS5220.
-       TI may have sold the remaining stocks of TMS5200s at a discount, and
-       apparently provided a special encoder to work around the bug.
-       Other than the bug, the two chips are identical.
-       Another variant of the TMS5220 is the TMS5220C/TSP5220C, which adds
-       an additional opcode (to select the data rate).
+       The TMS5200 has a different set of LPC coefficients, and a different
+       chirp table than the 5220 (which is not yet dumped)
+       Due to the vast superiority of the quality of the TMS5220, TI may have
+       sold the remaining stocks of TMS5200s at a discount, and provided a
+       special encoder to use the older tables.
+       Other than those differences, the two chips are identical.
+       Another variant of the TMS5220 is the TMS5220C/TSP5220C, which replaces
+       the X0X0 'NOP' opcode with an opcode to select the number of
+       interpolations per frame to either be defined at each frame, or be fixed
+       at either 8, 6, 4, or 2. The TMS5200/5220 is always fixed at 8.
      */
 	tms5220_variant variant;
     /* The TMS52xx has two different ways of providing output data: the
        analog speaker pin (which was usually used) and the Digital I/O pin.
-       The internal DAC used to feed the analog pin is only 8 bits, while the
-       digital pin gives full 12? bit resolution to the output data.
+       The internal DAC used to feed the analog pin is only 8 bits, and has the
+       funny clipping/clamping logic, while the digital pin gives full 12? bit
+       resolution of the output data.
      */
-    UINT8 digital_select;
+	UINT8 digital_select;
+	const device_config *device;
 };
 
 
@@ -146,60 +175,61 @@ static INT16 clip_and_wrap(INT16 cliptemp);
 #define DEBUG_5220	0
 
 
-void *tms5220_create(int index)
+void *tms5220_create(const device_config *device)
 {
 	struct tms5220 *tms;
 
 	tms = malloc_or_die(sizeof(*tms));
 	memset(tms, 0, sizeof(*tms));
 
-	state_save_register_item_array("tms5220", index, tms->fifo);
-	state_save_register_item("tms5220", index, tms->fifo_head);
-	state_save_register_item("tms5220", index, tms->fifo_tail);
-	state_save_register_item("tms5220", index, tms->fifo_count);
-	state_save_register_item("tms5220", index, tms->fifo_bits_taken);
+	tms->device = device;
+	state_save_register_device_item_array(device, 0, tms->fifo);
+	state_save_register_device_item(device, 0, tms->fifo_head);
+	state_save_register_device_item(device, 0, tms->fifo_tail);
+	state_save_register_device_item(device, 0, tms->fifo_count);
+	state_save_register_device_item(device, 0, tms->fifo_bits_taken);
 
-	state_save_register_item("tms5220", index, tms->tms5220_speaking);
-	state_save_register_item("tms5220", index, tms->speak_external);
-	state_save_register_item("tms5220", index, tms->talk_status);
-	state_save_register_item("tms5220", index, tms->first_frame);
-	state_save_register_item("tms5220", index, tms->last_frame);
-	state_save_register_item("tms5220", index, tms->buffer_low);
-	state_save_register_item("tms5220", index, tms->buffer_empty);
-	state_save_register_item("tms5220", index, tms->irq_pin);
+	state_save_register_device_item(device, 0, tms->tms5220_speaking);
+	state_save_register_device_item(device, 0, tms->speak_external);
+	state_save_register_device_item(device, 0, tms->talk_status);
+	state_save_register_device_item(device, 0, tms->first_frame);
+	state_save_register_device_item(device, 0, tms->last_frame);
+	state_save_register_device_item(device, 0, tms->buffer_low);
+	state_save_register_device_item(device, 0, tms->buffer_empty);
+	state_save_register_device_item(device, 0, tms->irq_pin);
 
-	state_save_register_item("tms5220", index, tms->old_energy);
-	state_save_register_item("tms5220", index, tms->old_pitch);
-	state_save_register_item_array("tms5220", index, tms->old_k);
+	state_save_register_device_item(device, 0, tms->old_energy);
+	state_save_register_device_item(device, 0, tms->old_pitch);
+	state_save_register_device_item_array(device, 0, tms->old_k);
 
-	state_save_register_item("tms5220", index, tms->new_energy);
-	state_save_register_item("tms5220", index, tms->new_pitch);
-	state_save_register_item_array("tms5220", index, tms->new_k);
+	state_save_register_device_item(device, 0, tms->new_energy);
+	state_save_register_device_item(device, 0, tms->new_pitch);
+	state_save_register_device_item_array(device, 0, tms->new_k);
 
-	state_save_register_item("tms5220", index, tms->current_energy);
-	state_save_register_item("tms5220", index, tms->current_pitch);
-	state_save_register_item_array("tms5220", index, tms->current_k);
+	state_save_register_device_item(device, 0, tms->current_energy);
+	state_save_register_device_item(device, 0, tms->current_pitch);
+	state_save_register_device_item_array(device, 0, tms->current_k);
 
-	state_save_register_item("tms5220", index, tms->target_energy);
-	state_save_register_item("tms5220", index, tms->target_pitch);
-	state_save_register_item_array("tms5220", index, tms->target_k);
+	state_save_register_device_item(device, 0, tms->target_energy);
+	state_save_register_device_item(device, 0, tms->target_pitch);
+	state_save_register_device_item_array(device, 0, tms->target_k);
 
-	state_save_register_item("tms5220", index, tms->previous_energy);
+	state_save_register_device_item(device, 0, tms->previous_energy);
 
-	state_save_register_item("tms5220", index, tms->interp_count);
-	state_save_register_item("tms5220", index, tms->sample_count);
-	state_save_register_item("tms5220", index, tms->pitch_count);
+	state_save_register_device_item(device, 0, tms->interp_count);
+	state_save_register_device_item(device, 0, tms->sample_count);
+	state_save_register_device_item(device, 0, tms->pitch_count);
 
-	state_save_register_item_array("tms5220", index, tms->u);
-	state_save_register_item_array("tms5220", index, tms->x);
+	state_save_register_device_item_array(device, 0, tms->u);
+	state_save_register_device_item_array(device, 0, tms->x);
 
-	state_save_register_item("tms5220", index, tms->RNG);
-	state_save_register_item("tms5220", index, tms->excitation_data);
+	state_save_register_device_item(device, 0, tms->RNG);
+	state_save_register_device_item(device, 0, tms->excitation_data);
 
-	state_save_register_item("tms5220", index, tms->schedule_dummy_read);
-	state_save_register_item("tms5220", index, tms->data_register);
-	state_save_register_item("tms5220", index, tms->RDB_flag);
-	state_save_register_item("tms5220", index, tms->digital_select);
+	state_save_register_device_item(device, 0, tms->schedule_dummy_read);
+	state_save_register_device_item(device, 0, tms->data_register);
+	state_save_register_device_item(device, 0, tms->RDB_flag);
+	state_save_register_device_item(device, 0, tms->digital_select);
 
 	return tms;
 }
@@ -227,7 +257,7 @@ void tms5220_reset_chip(void *chip)
 	/* initialize the chip state */
 	/* Note that we do not actually clear IRQ on start-up : IRQ is even raised if tms->buffer_empty or tms->buffer_low are 0 */
 	tms->tms5220_speaking = tms->speak_external = tms->talk_status = tms->first_frame = tms->last_frame = tms->irq_pin = 0;
-	if (tms->irq_func) tms->irq_func(0);
+	if (tms->irq_func) tms->irq_func(tms->device->machine, 0);
 	tms->buffer_empty = tms->buffer_low = 1;
 
 	tms->RDB_flag = FALSE;
@@ -260,7 +290,7 @@ void tms5220_reset_chip(void *chip)
 
 ***********************************************************************************************/
 
-void tms5220_set_irq(void *chip, void (*func)(int))
+void tms5220_set_irq(void *chip, void (*func)(running_machine *, int))
 {
 	struct tms5220 *tms = chip;
     tms->irq_func = func;
@@ -361,17 +391,17 @@ void tms5220_data_write(void *chip, int data)
      tms5220_status_read -- read status or data from the TMS5220
 
       From the data sheet:
-        bit 0 = TS - Talk Status is active (high) when the VSP is processing speech data.
+        bit D0(bit 7) = TS - Talk Status is active (high) when the VSP is processing speech data.
                 Talk Status goes active at the initiation of a Speak command or after nine
                 bytes of data are loaded into the FIFO following a Speak External command. It
                 goes inactive (low) when the stop code (Energy=1111) is processed, or
                 immediately by a buffer empty condition or a reset command.
-        bit 1 = BL - Buffer Low is active (high) when the FIFO buffer is more than half empty.
+        bit D1(bit 6) = BL - Buffer Low is active (high) when the FIFO buffer is more than half empty.
                 Buffer Low is set when the "Last-In" byte is shifted down past the half-full
                 boundary of the stack. Buffer Low is cleared when data is loaded to the stack
                 so that the "Last-In" byte lies above the half-full boundary and becomes the
                 ninth data byte of the stack.
-        bit 2 = BE - Buffer Empty is active (high) when the FIFO buffer has run out of data
+        bit D2(bit 5) = BE - Buffer Empty is active (high) when the FIFO buffer has run out of data
                 while executing a Speak External command. Buffer Empty is set when the last bit
                 of the "Last-In" byte is shifted out to the Synthesis Section. This causes
                 Talk Status to be cleared. Speed is terminated at some abnormal point and the
@@ -589,28 +619,83 @@ tryagain:
                 }
             }
         }
-        else if (tms->interp_count == 0)
+        else
         {
-            /* Update values based on step values */
-            /*mame_printf_debug("\n");*/
-
             interp_period = tms->sample_count / 25;
-            tms->current_energy += ((tms->target_energy - tms->current_energy) >> interp_coeff[interp_period]);
-            if (tms->old_pitch != 0)
-                tms->current_pitch += ((tms->target_pitch - tms->current_pitch) >> interp_coeff[interp_period]);
-
-            /*mame_printf_debug("*** Energy = %d\n",tms->current_energy);*/
-
-            for (i = 0; i < 10; i++)
-            {
-                tms->current_k[i] += ((tms->target_k[i] - tms->current_k[i]) >> interp_coeff[interp_period]);
-            }
+	    switch(tms->interp_count)
+	    {
+                /*         PC=X  X cycle, rendering change (change for next cycle which chip is actually doing) */
+		case 0: /* PC=0, A cycle, nothing happens (calc energy) */
+                  break;
+		case 1: /* PC=0, B cycle, nothing happens (update energy) */
+		  break;
+		case 2: /* PC=1, A cycle, update energy (calc pitch) */
+		  tms->current_energy += ((tms->target_energy - tms->current_energy) >> interp_coeff[interp_period]);
+            	  break;
+                case 3: /* PC=1, B cycle, nothing happens (update pitch) */
+		  break;
+                case 4: /* PC=2, A cycle, update pitch (calc K1) */
+            	  if (tms->old_pitch != 0)
+                  tms->current_pitch += ((tms->target_pitch - tms->current_pitch) >> interp_coeff[interp_period]);
+		  break;
+                case 5: /* PC=2, B cycle, nothing happens (update K1) */
+		  break;
+		case 6: /* PC=3, A cycle, update K1 (calc K2) */
+		  tms->current_k[0] += ((tms->target_k[0] - tms->current_k[0]) >> interp_coeff[interp_period]);
+            	  break;
+                case 7: /* PC=3, B cycle, nothing happens (update K2) */
+		  break;
+		case 8: /* PC=4, A cycle, update K2 (calc K3) */
+		  tms->current_k[1] += ((tms->target_k[1] - tms->current_k[1]) >> interp_coeff[interp_period]);
+            	  break;
+                case 9: /* PC=4, B cycle, nothing happens (update K3) */
+		  break;
+		case 10: /* PC=5, A cycle, update K3 (calc K4) */
+		  tms->current_k[2] += ((tms->target_k[2] - tms->current_k[2]) >> interp_coeff[interp_period]);
+            	  break;
+                case 11: /* PC=5, B cycle, nothing happens (update K4) */
+		  break;
+		case 12: /* PC=6, A cycle, update K4 (calc K5) */
+		  tms->current_k[3] += ((tms->target_k[3] - tms->current_k[3]) >> interp_coeff[interp_period]);
+            	  break;
+                case 13: /* PC=6, B cycle, nothing happens (update K5) */
+		  break;
+		case 14: /* PC=7, A cycle, update K5 (calc K6) */
+		  tms->current_k[4] += ((tms->target_k[4] - tms->current_k[4]) >> interp_coeff[interp_period]);
+            	  break;
+                case 15: /* PC=7, B cycle, nothing happens (update K6) */
+		  break;
+		case 16: /* PC=8, A cycle, update K6 (calc K7) */
+		  tms->current_k[5] += ((tms->target_k[5] - tms->current_k[5]) >> interp_coeff[interp_period]);
+            	  break;
+                case 17: /* PC=8, B cycle, nothing happens (update K7) */
+		  break;
+		case 18: /* PC=9, A cycle, update K7 (calc K8) */
+		  tms->current_k[6] += ((tms->target_k[6] - tms->current_k[6]) >> interp_coeff[interp_period]);
+            	  break;
+                case 19: /* PC=9, B cycle, nothing happens (update K8) */
+		  break;
+		case 20: /* PC=10, A cycle, update K8 (calc K9) */
+		  tms->current_k[7] += ((tms->target_k[7] - tms->current_k[7]) >> interp_coeff[interp_period]);
+            	  break;
+                case 21: /* PC=10, B cycle, nothing happens (update K9) */
+		  break;
+		case 22: /* PC=11, A cycle, update K9 (calc K10) */
+		  tms->current_k[8] += ((tms->target_k[8] - tms->current_k[8]) >> interp_coeff[interp_period]);
+            	  break;
+                case 23: /* PC=11, B cycle, nothing happens (update K10) */
+		  break;
+		case 24: /* PC=12, A cycle, update K10 (do nothing) */
+		  tms->current_k[9] += ((tms->target_k[9] - tms->current_k[9]) >> interp_coeff[interp_period]);
+            	  break;
+	    }
         }
 
         if (tms->old_energy == 0)
         {
             /* generate silent samples here */
-			tms->excitation_data = 0x00; /* I'm not sure if this is actually RIGHT, the current_energy may be forced to zero when we've just passed a zero energy frame. However, this does work too. May be removed later. */
+			tms->excitation_data = 0x00; /* This is NOT correct, the current_energy is forced to zero when we                         just passed a zero energy frame because thats what the tables hold for that value.
+                        However, this code does no harm. Will be removed later. */
         }
         else if (tms->old_pitch == 0)
         {
@@ -623,16 +708,29 @@ tryagain:
         else
         {
             /* generate voiced samples here */
-			tms->excitation_data = chirptable[tms->pitch_count%sizeof(chirptable)];
+            /* US patent 4331836 Figure 14B shows, and logic would hold, that a pitch based chirp
+             * function has a chirp/peak and then a long chain of zeroes.
+             * The last entry of the chirp rom is at address 0b110011 (50d), the 51st sample,
+             * and if the address reaches that point the ADDRESS incrementer is
+             * disabled, forcing all samples beyond 50d to be == 50d
+             * (address 50d holds zeroes)
+             */
+          if (tms->pitch_count > 50)
+              tms->excitation_data = chirptable[50];
+          else /*tms->pitch_count <= 50*/
+              tms->excitation_data = chirptable[tms->pitch_count];
         }
 
-        /* Update LFSR every clock, like patent shows */
-        bitout = ((tms->RNG >> 12) & 1) ^
-                 ((tms->RNG >> 10) & 1) ^
-                 ((tms->RNG >>  9) & 1) ^
-                 ((tms->RNG >>  0) & 1);
-        tms->RNG >>= 1;
-        tms->RNG |= bitout << 12;
+        /* Update LFSR *20* times every sample, like patent shows */
+	for (i=0; i<20; i++)
+	{
+            bitout = ((tms->RNG >> 12) & 1) ^
+                     ((tms->RNG >> 10) & 1) ^
+                     ((tms->RNG >>  9) & 1) ^
+                     ((tms->RNG >>  0) & 1);
+            tms->RNG >>= 1;
+            tms->RNG |= bitout << 12;
+	}
 
 		buffer[buf_count] = clip_and_wrap(lattice_filter(tms)); /* execute lattice filter and clipping/wrapping */
 
@@ -1096,6 +1194,6 @@ static void check_buffer_low(struct tms5220 *tms)
 static void set_interrupt_state(struct tms5220 *tms, int state)
 {
     if (tms->irq_func && state != tms->irq_pin)
-    	tms->irq_func(state);
+    	tms->irq_func(tms->device->machine, state);
     tms->irq_pin = state;
 }
