@@ -1,14 +1,17 @@
-#ifndef WAVE_H
-#define WAVE_H
+#pragma once
+
+#ifndef __WAVE_H__
+#define __WAVE_H__
 
 /*****************************************************************************
  *  CassetteWave interface
  *****************************************************************************/
 
+#ifdef MESS
 #include "messdrv.h"
+#endif
+
+SND_GET_INFO( wave );
 
 
-
-#endif /* WAVE_H */
-
-
+#endif /* __WAVE_H__ */
