@@ -21,12 +21,9 @@
 		#undef USE_MAME_TIMERS
 	#endif
 #endif
-#ifdef USE_MAME_TIMERS
-	/*#define LOG_CYM_FILE*/
-	#ifdef LOG_CYM_FILE
-		FILE * cymfile = NULL;
-	#endif
-#endif
+
+#define LOG_CYM_FILE 0
+static FILE * cymfile = NULL;
 
 
 /* struct describing a single operator */
@@ -164,9 +161,10 @@ typedef struct
 
 	UINT32		noise_tab[32];			/* 17bit Noise Generator periods */
 
-	void (*irqhandler)(int irq);		/* IRQ function handler */
-	write8_handler porthandler;		/* port write function handler */
+	void (*irqhandler)(running_machine *machine, int irq);		/* IRQ function handler */
+	write8_space_func porthandler;		/* port write function handler */
 
+	const device_config *device;
 	unsigned int clock;					/* chip clock in Hz (passed from 2151intf.c) */
 	unsigned int sampfreq;				/* sampling frequency in Hz (passed from 2151intf.c) */
 } YM2151;
@@ -790,7 +788,7 @@ static TIMER_CALLBACK( irqAon_callback )
 
 	chip->irqlinestate |= 1;
 
-	if (oldstate == 0 && chip->irqhandler) (*chip->irqhandler)(1);
+	if (oldstate == 0 && chip->irqhandler) (*chip->irqhandler)(machine, 1);
 }
 
 static TIMER_CALLBACK( irqBon_callback )
@@ -800,7 +798,7 @@ static TIMER_CALLBACK( irqBon_callback )
 
 	chip->irqlinestate |= 2;
 
-	if (oldstate == 0 && chip->irqhandler) (*chip->irqhandler)(1);
+	if (oldstate == 0 && chip->irqhandler) (*chip->irqhandler)(machine, 1);
 }
 
 static TIMER_CALLBACK( irqAoff_callback )
@@ -810,7 +808,7 @@ static TIMER_CALLBACK( irqAoff_callback )
 
 	chip->irqlinestate &= ~1;
 
-	if (oldstate == 1 && chip->irqhandler) (*chip->irqhandler)(0);
+	if (oldstate == 1 && chip->irqhandler) (*chip->irqhandler)(machine, 0);
 }
 
 static TIMER_CALLBACK( irqBoff_callback )
@@ -820,18 +818,18 @@ static TIMER_CALLBACK( irqBoff_callback )
 
 	chip->irqlinestate &= ~2;
 
-	if (oldstate == 2 && chip->irqhandler) (*chip->irqhandler)(0);
+	if (oldstate == 2 && chip->irqhandler) (*chip->irqhandler)(machine, 0);
 }
 
 static TIMER_CALLBACK( timer_callback_a )
 {
 	YM2151 *chip = ptr;
-	timer_adjust(chip->timer_A, chip->timer_A_time[ chip->timer_A_index ], 0, attotime_zero);
+	timer_adjust_oneshot(chip->timer_A, chip->timer_A_time[ chip->timer_A_index ], 0);
 	chip->timer_A_index_old = chip->timer_A_index;
 	if (chip->irq_enable & 0x04)
 	{
 		chip->status |= 1;
-		timer_set(attotime_zero,chip,0,irqAon_callback);
+		timer_set(machine, attotime_zero,chip,0,irqAon_callback);
 	}
 	if (chip->irq_enable & 0x80)
 		chip->csm_req = 2;		/* request KEY ON / KEY OFF sequence */
@@ -839,12 +837,12 @@ static TIMER_CALLBACK( timer_callback_a )
 static TIMER_CALLBACK( timer_callback_b )
 {
 	YM2151 *chip = ptr;
-	timer_adjust(chip->timer_B, chip->timer_B_time[ chip->timer_B_index ], 0, attotime_zero);
+	timer_adjust_oneshot(chip->timer_B, chip->timer_B_time[ chip->timer_B_index ], 0);
 	chip->timer_B_index_old = chip->timer_B_index;
 	if (chip->irq_enable & 0x08)
 	{
 		chip->status |= 2;
-		timer_set(attotime_zero,chip,0,irqBon_callback);
+		timer_set(machine, attotime_zero,chip,0,irqBon_callback);
 	}
 }
 #if 0
@@ -1044,9 +1042,11 @@ INLINE void refresh_EG(YM2151Operator * op)
 
 
 /* write a register on YM2151 chip number 'n' */
-void YM2151WriteReg(void *_chip, int r, int v)
+void ym2151_write_reg(void *_chip, int r, int v)
 {
 	YM2151 *chip = _chip;
+	/* temporary hack until this is converted to a device */
+	const address_space *space = memory_find_address_space(chip->device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	YM2151Operator *op = &chip->oper[ (r&0x07)*4+((r&0x18)>>3) ];
 
 	/* adjust bus to 8 bits */
@@ -1060,13 +1060,11 @@ void YM2151WriteReg(void *_chip, int r, int v)
 	chip->status |= 0x80;	/* set busy flag for 64 chip clock cycles */
 #endif
 
-#ifdef LOG_CYM_FILE
-	if ((cymfile) && (r!=0) )
+	if (LOG_CYM_FILE && (cymfile) && (r!=0) )
 	{
 		fputc( (unsigned char)r, cymfile );
 		fputc( (unsigned char)v, cymfile );
 	}
-#endif
 
 
 	switch(r & 0xe0){
@@ -1107,11 +1105,11 @@ void YM2151WriteReg(void *_chip, int r, int v)
 			{
 #ifdef USE_MAME_TIMERS
 				chip->status &= ~1;
-				timer_set(attotime_zero,chip,0,irqAoff_callback);
+				timer_set(chip->device->machine, attotime_zero,chip,0,irqAoff_callback);
 #else
 				int oldstate = chip->status & 3;
 				chip->status &= ~1;
-				if ((oldstate==1) && (chip->irqhandler)) (*chip->irqhandler)(0);
+				if ((oldstate==1) && (chip->irqhandler)) (*chip->irqhandler)(machine, 0);
 #endif
 			}
 
@@ -1119,11 +1117,11 @@ void YM2151WriteReg(void *_chip, int r, int v)
 			{
 #ifdef USE_MAME_TIMERS
 				chip->status &= ~2;
-				timer_set(attotime_zero,chip,0,irqBoff_callback);
+				timer_set(chip->device->machine, attotime_zero,chip,0,irqBoff_callback);
 #else
 				int oldstate = chip->status & 3;
 				chip->status &= ~2;
-				if ((oldstate==2) && (chip->irqhandler)) (*chip->irqhandler)(0);
+				if ((oldstate==2) && (chip->irqhandler)) (*chip->irqhandler)(machine, 0);
 #endif
 			}
 
@@ -1133,7 +1131,7 @@ void YM2151WriteReg(void *_chip, int r, int v)
 				/* start timer _only_ if it wasn't already started (it will reload time value next round) */
 					if (!timer_enable(chip->timer_B, 1))
 					{
-						timer_adjust(chip->timer_B, chip->timer_B_time[ chip->timer_B_index ], 0, attotime_zero);
+						timer_adjust_oneshot(chip->timer_B, chip->timer_B_time[ chip->timer_B_index ], 0);
 						chip->timer_B_index_old = chip->timer_B_index;
 					}
 				#else
@@ -1158,7 +1156,7 @@ void YM2151WriteReg(void *_chip, int r, int v)
 				/* start timer _only_ if it wasn't already started (it will reload time value next round) */
 					if (!timer_enable(chip->timer_A, 1))
 					{
-						timer_adjust(chip->timer_A, chip->timer_A_time[ chip->timer_A_index ], 0, attotime_zero);
+						timer_adjust_oneshot(chip->timer_A, chip->timer_A_time[ chip->timer_A_index ], 0);
 						chip->timer_A_index_old = chip->timer_A_index;
 					}
 				#else
@@ -1195,7 +1193,7 @@ void YM2151WriteReg(void *_chip, int r, int v)
 		case 0x1b:	/* CT2, CT1, LFO waveform */
 			chip->ct = v >> 6;
 			chip->lfo_wsel = v & 3;
-			if (chip->porthandler) (*chip->porthandler)(0 , chip->ct );
+			if (chip->porthandler) (*chip->porthandler)(space, 0 , chip->ct );
 			break;
 
 		default:
@@ -1363,16 +1361,14 @@ void YM2151WriteReg(void *_chip, int r, int v)
 }
 
 
-#ifdef LOG_CYM_FILE
 static TIMER_CALLBACK( cymfile_callback )
 {
 	if (cymfile)
 		fputc( (unsigned char)0, cymfile );
 }
-#endif
 
 
-int YM2151ReadStatus( void *_chip )
+int ym2151_read_status( void *_chip )
 {
 	YM2151 *chip = _chip;
 	return chip->status;
@@ -1385,122 +1381,118 @@ int YM2151ReadStatus( void *_chip )
 /*
 *   state save support for MAME
 */
-void YM2151Postload(void *chip)
+STATE_POSTLOAD( ym2151_postload )
 {
-	YM2151 *YM2151_chip = (YM2151 *)chip;
+	YM2151 *YM2151_chip = (YM2151 *)param;
 	int j;
 
 	for (j=0; j<8; j++)
 		set_connect(&YM2151_chip->oper[j*4], j, YM2151_chip->connect[j]);
 }
 
-static void ym2151_state_save_register( YM2151 *chip, int sndindex )
+static void ym2151_state_save_register( YM2151 *chip, const device_config *device )
 {
 	int j;
-	char buf1[20];
 
 	/* save all 32 operators of chip #i */
 	for (j=0; j<32; j++)
 	{
 		YM2151Operator *op;
 
-		sprintf(buf1,"YM2151.op%02i",j);
 		op = &chip->oper[(j&7)*4+(j>>3)];
 
-		state_save_register_item(buf1, sndindex, op->phase);
-		state_save_register_item(buf1, sndindex, op->freq);
-		state_save_register_item(buf1, sndindex, op->dt1);
-		state_save_register_item(buf1, sndindex, op->mul);
-		state_save_register_item(buf1, sndindex, op->dt1_i);
-		state_save_register_item(buf1, sndindex, op->dt2);
+		state_save_register_device_item(device, j, op->phase);
+		state_save_register_device_item(device, j, op->freq);
+		state_save_register_device_item(device, j, op->dt1);
+		state_save_register_device_item(device, j, op->mul);
+		state_save_register_device_item(device, j, op->dt1_i);
+		state_save_register_device_item(device, j, op->dt2);
 		/* operators connection is saved in chip data block */
-		state_save_register_item(buf1, sndindex, op->mem_value);
+		state_save_register_device_item(device, j, op->mem_value);
 
-		state_save_register_item(buf1, sndindex, op->fb_shift);
-		state_save_register_item(buf1, sndindex, op->fb_out_curr);
-		state_save_register_item(buf1, sndindex, op->fb_out_prev);
-		state_save_register_item(buf1, sndindex, op->kc);
-		state_save_register_item(buf1, sndindex, op->kc_i);
-		state_save_register_item(buf1, sndindex, op->pms);
-		state_save_register_item(buf1, sndindex, op->ams);
-		state_save_register_item(buf1, sndindex, op->AMmask);
+		state_save_register_device_item(device, j, op->fb_shift);
+		state_save_register_device_item(device, j, op->fb_out_curr);
+		state_save_register_device_item(device, j, op->fb_out_prev);
+		state_save_register_device_item(device, j, op->kc);
+		state_save_register_device_item(device, j, op->kc_i);
+		state_save_register_device_item(device, j, op->pms);
+		state_save_register_device_item(device, j, op->ams);
+		state_save_register_device_item(device, j, op->AMmask);
 
-		state_save_register_item(buf1, sndindex, op->state);
-		state_save_register_item(buf1, sndindex, op->eg_sh_ar);
-		state_save_register_item(buf1, sndindex, op->eg_sel_ar);
-		state_save_register_item(buf1, sndindex, op->tl);
-		state_save_register_item(buf1, sndindex, op->volume);
-		state_save_register_item(buf1, sndindex, op->eg_sh_d1r);
-		state_save_register_item(buf1, sndindex, op->eg_sel_d1r);
-		state_save_register_item(buf1, sndindex, op->d1l);
-		state_save_register_item(buf1, sndindex, op->eg_sh_d2r);
-		state_save_register_item(buf1, sndindex, op->eg_sel_d2r);
-		state_save_register_item(buf1, sndindex, op->eg_sh_rr);
-		state_save_register_item(buf1, sndindex, op->eg_sel_rr);
+		state_save_register_device_item(device, j, op->state);
+		state_save_register_device_item(device, j, op->eg_sh_ar);
+		state_save_register_device_item(device, j, op->eg_sel_ar);
+		state_save_register_device_item(device, j, op->tl);
+		state_save_register_device_item(device, j, op->volume);
+		state_save_register_device_item(device, j, op->eg_sh_d1r);
+		state_save_register_device_item(device, j, op->eg_sel_d1r);
+		state_save_register_device_item(device, j, op->d1l);
+		state_save_register_device_item(device, j, op->eg_sh_d2r);
+		state_save_register_device_item(device, j, op->eg_sel_d2r);
+		state_save_register_device_item(device, j, op->eg_sh_rr);
+		state_save_register_device_item(device, j, op->eg_sel_rr);
 
-		state_save_register_item(buf1, sndindex, op->key);
-		state_save_register_item(buf1, sndindex, op->ks);
-		state_save_register_item(buf1, sndindex, op->ar);
-		state_save_register_item(buf1, sndindex, op->d1r);
-		state_save_register_item(buf1, sndindex, op->d2r);
-		state_save_register_item(buf1, sndindex, op->rr);
+		state_save_register_device_item(device, j, op->key);
+		state_save_register_device_item(device, j, op->ks);
+		state_save_register_device_item(device, j, op->ar);
+		state_save_register_device_item(device, j, op->d1r);
+		state_save_register_device_item(device, j, op->d2r);
+		state_save_register_device_item(device, j, op->rr);
 
-		state_save_register_item(buf1, sndindex, op->reserved0);
-		state_save_register_item(buf1, sndindex, op->reserved1);
+		state_save_register_device_item(device, j, op->reserved0);
+		state_save_register_device_item(device, j, op->reserved1);
 	}
 
-	sprintf(buf1,"YM2151.registers");
+	state_save_register_device_item_array(device, 0, chip->pan);
 
-	state_save_register_item_array(buf1, sndindex, chip->pan);
+	state_save_register_device_item(device, 0, chip->eg_cnt);
+	state_save_register_device_item(device, 0, chip->eg_timer);
+	state_save_register_device_item(device, 0, chip->eg_timer_add);
+	state_save_register_device_item(device, 0, chip->eg_timer_overflow);
 
-	state_save_register_item(buf1, sndindex, chip->eg_cnt);
-	state_save_register_item(buf1, sndindex, chip->eg_timer);
-	state_save_register_item(buf1, sndindex, chip->eg_timer_add);
-	state_save_register_item(buf1, sndindex, chip->eg_timer_overflow);
+	state_save_register_device_item(device, 0, chip->lfo_phase);
+	state_save_register_device_item(device, 0, chip->lfo_timer);
+	state_save_register_device_item(device, 0, chip->lfo_timer_add);
+	state_save_register_device_item(device, 0, chip->lfo_overflow);
+	state_save_register_device_item(device, 0, chip->lfo_counter);
+	state_save_register_device_item(device, 0, chip->lfo_counter_add);
+	state_save_register_device_item(device, 0, chip->lfo_wsel);
+	state_save_register_device_item(device, 0, chip->amd);
+	state_save_register_device_item(device, 0, chip->pmd);
+	state_save_register_device_item(device, 0, chip->lfa);
+	state_save_register_device_item(device, 0, chip->lfp);
 
-	state_save_register_item(buf1, sndindex, chip->lfo_phase);
-	state_save_register_item(buf1, sndindex, chip->lfo_timer);
-	state_save_register_item(buf1, sndindex, chip->lfo_timer_add);
-	state_save_register_item(buf1, sndindex, chip->lfo_overflow);
-	state_save_register_item(buf1, sndindex, chip->lfo_counter);
-	state_save_register_item(buf1, sndindex, chip->lfo_counter_add);
-	state_save_register_item(buf1, sndindex, chip->lfo_wsel);
-	state_save_register_item(buf1, sndindex, chip->amd);
-	state_save_register_item(buf1, sndindex, chip->pmd);
-	state_save_register_item(buf1, sndindex, chip->lfa);
-	state_save_register_item(buf1, sndindex, chip->lfp);
+	state_save_register_device_item(device, 0, chip->test);
+	state_save_register_device_item(device, 0, chip->ct);
 
-	state_save_register_item(buf1, sndindex, chip->test);
-	state_save_register_item(buf1, sndindex, chip->ct);
+	state_save_register_device_item(device, 0, chip->noise);
+	state_save_register_device_item(device, 0, chip->noise_rng);
+	state_save_register_device_item(device, 0, chip->noise_p);
+	state_save_register_device_item(device, 0, chip->noise_f);
 
-	state_save_register_item(buf1, sndindex, chip->noise);
-	state_save_register_item(buf1, sndindex, chip->noise_rng);
-	state_save_register_item(buf1, sndindex, chip->noise_p);
-	state_save_register_item(buf1, sndindex, chip->noise_f);
+	state_save_register_device_item(device, 0, chip->csm_req);
+	state_save_register_device_item(device, 0, chip->irq_enable);
+	state_save_register_device_item(device, 0, chip->status);
 
-	state_save_register_item(buf1, sndindex, chip->csm_req);
-	state_save_register_item(buf1, sndindex, chip->irq_enable);
-	state_save_register_item(buf1, sndindex, chip->status);
-
-	state_save_register_item(buf1, sndindex, chip->timer_A_index);
-	state_save_register_item(buf1, sndindex, chip->timer_B_index);
-	state_save_register_item(buf1, sndindex, chip->timer_A_index_old);
-	state_save_register_item(buf1, sndindex, chip->timer_B_index_old);
+	state_save_register_device_item(device, 0, chip->timer_A_index);
+	state_save_register_device_item(device, 0, chip->timer_B_index);
+	state_save_register_device_item(device, 0, chip->timer_A_index_old);
+	state_save_register_device_item(device, 0, chip->timer_B_index_old);
 
 #ifdef USE_MAME_TIMERS
-	state_save_register_item(buf1, sndindex, chip->irqlinestate);
+	state_save_register_device_item(device, 0, chip->irqlinestate);
 #endif
 
-	state_save_register_item_array(buf1, sndindex, chip->connect);
+	state_save_register_device_item_array(device, 0, chip->connect);
 
-	state_save_register_func_postload_ptr(YM2151Postload, chip);
+	state_save_register_postload(device->machine, ym2151_postload, chip);
 }
 #else
-void YM2151Postload(void *chip)
+STATE_POSTLOAD( ym2151_postload )
 {
 }
 
-static void ym2151_state_save_register( YM2151 *chip, int sndindex )
+static void ym2151_state_save_register( YM2151 *chip, const device_config *device )
 {
 }
 #endif
@@ -1513,7 +1505,7 @@ static void ym2151_state_save_register( YM2151 *chip, int sndindex )
 *   'clock' is the chip clock in Hz
 *   'rate' is sampling rate
 */
-void * YM2151Init(int index, int clock, int rate)
+void * ym2151_init(const device_config *device, int clock, int rate)
 {
 	YM2151 *PSG;
 
@@ -1523,10 +1515,11 @@ void * YM2151Init(int index, int clock, int rate)
 
 	memset(PSG, 0, sizeof(YM2151));
 
-	ym2151_state_save_register( PSG, index );
+	ym2151_state_save_register( PSG, device );
 
 	init_tables();
 
+	PSG->device = device;
 	PSG->clock = clock;
 	/*rate = clock/64;*/
 	PSG->sampfreq = rate ? rate : 44100;	/* avoid division by 0 in init_chip_tables() */
@@ -1541,39 +1534,39 @@ void * YM2151Init(int index, int clock, int rate)
 	/*logerror("YM2151[init] eg_timer_add=%8x eg_timer_overflow=%8x\n", PSG->eg_timer_add, PSG->eg_timer_overflow);*/
 
 #ifdef USE_MAME_TIMERS
-/* this must be done _before_ a call to YM2151ResetChip() */
-	PSG->timer_A = timer_alloc(timer_callback_a, PSG);
-	PSG->timer_B = timer_alloc(timer_callback_b, PSG);
+/* this must be done _before_ a call to ym2151_reset_chip() */
+	PSG->timer_A = timer_alloc(device->machine, timer_callback_a, PSG);
+	PSG->timer_B = timer_alloc(device->machine, timer_callback_b, PSG);
 #else
 	PSG->tim_A      = 0;
 	PSG->tim_B      = 0;
 #endif
-	YM2151ResetChip(PSG);
+	ym2151_reset_chip(PSG);
 	/*logerror("YM2151[init] clock=%i sampfreq=%i\n", PSG->clock, PSG->sampfreq);*/
 
-#ifdef LOG_CYM_FILE
-	cymfile = fopen("2151_.cym","wb");
-	if (cymfile)
-		timer_pulse ( ATTOTIME_IN_HZ(110), 0, cymfile_callback); /*110 Hz pulse timer*/
-	else
-		logerror("Could not create file 2151_.cym\n");
-#endif
+	if (LOG_CYM_FILE)
+	{
+		cymfile = fopen("2151_.cym","wb");
+		if (cymfile)
+			timer_pulse ( device->machine, ATTOTIME_IN_HZ(110), NULL, 0, cymfile_callback); /*110 Hz pulse timer*/
+		else
+			logerror("Could not create file 2151_.cym\n");
+	}
 
 	return PSG;
 }
 
 
 
-void YM2151Shutdown(void *_chip)
+void ym2151_shutdown(void *_chip)
 {
 	YM2151 *chip = _chip;
 
 	free (chip);
 
-#ifdef LOG_CYM_FILE
-	fclose (cymfile);
+	if (cymfile)
+		fclose (cymfile);
 	cymfile = NULL;
-#endif
 
 #ifdef SAVE_SAMPLE
 	fclose(sample[8]);
@@ -1595,7 +1588,7 @@ void YM2151Shutdown(void *_chip)
 /*
 *   Reset chip number 'n'.
 */
-void YM2151ResetChip(void *_chip)
+void ym2151_reset_chip(void *_chip)
 {
 	int i;
 	YM2151 *chip = _chip;
@@ -1647,11 +1640,11 @@ void YM2151ResetChip(void *_chip)
 	chip->csm_req	= 0;
 	chip->status    = 0;
 
-	YM2151WriteReg(chip, 0x1b, 0);	/* only because of CT1, CT2 output pins */
-	YM2151WriteReg(chip, 0x18, 0);	/* set LFO frequency */
+	ym2151_write_reg(chip, 0x1b, 0);	/* only because of CT1, CT2 output pins */
+	ym2151_write_reg(chip, 0x18, 0);	/* set LFO frequency */
 	for (i=0x20; i<0x100; i++)		/* set the operators */
 	{
-		YM2151WriteReg(chip, i, 0);
+		ym2151_write_reg(chip, i, 0);
 	}
 }
 
@@ -2378,7 +2371,7 @@ INLINE signed int acc_calc(signed int value)
 *   '**buffers' is table of pointers to the buffers: left and right
 *   'length' is the number of samples that should be generated
 */
-void YM2151UpdateOne(void *chip, SAMP **buffers, int length)
+void ym2151_update_one(void *chip, SAMP **buffers, int length)
 {
 	int i;
 	signed int outl,outr;
@@ -2402,7 +2395,7 @@ void YM2151UpdateOne(void *chip, SAMP **buffers, int length)
 			{
 				int oldstate = PSG->status & 3;
 				PSG->status |= 2;
-				if ((!oldstate) && (PSG->irqhandler)) (*PSG->irqhandler)(1);
+				if ((!oldstate) && (PSG->irqhandler)) (*PSG->irqhandler)(machine, 1);
 			}
 		}
 	}
@@ -2480,7 +2473,7 @@ void YM2151UpdateOne(void *chip, SAMP **buffers, int length)
 				{
 					int oldstate = PSG->status & 3;
 					PSG->status |= 1;
-					if ((!oldstate) && (PSG->irqhandler)) (*PSG->irqhandler)(1);
+					if ((!oldstate) && (PSG->irqhandler)) (*PSG->irqhandler)(machine, 1);
 				}
 				if (PSG->irq_enable & 0x80)
 					PSG->csm_req = 2;	/* request KEY ON / KEY OFF sequence */
@@ -2491,13 +2484,13 @@ void YM2151UpdateOne(void *chip, SAMP **buffers, int length)
 	}
 }
 
-void YM2151SetIrqHandler(void *chip, void(*handler)(int irq))
+void ym2151_set_irq_handler(void *chip, void(*handler)(running_machine *machine, int irq))
 {
 	YM2151 *PSG = chip;
 	PSG->irqhandler = handler;
 }
 
-void YM2151SetPortWriteHandler(void *chip, write8_handler handler)
+void ym2151_set_port_write_handler(void *chip, write8_space_func handler)
 {
 	YM2151 *PSG = chip;
 	PSG->porthandler = handler;
