@@ -14,6 +14,20 @@ Revision History:
  - thanks to Olivier Galibert and Chris Hardy for YMF262 and YAC512 chips
  - thanks to Stiletto for the datasheets
 
+   Features as listed in 4MF262A6 data sheet:
+    1. Registers are compatible with YM3812 (OPL2) FM sound source.
+    2. Up to six sounds can be used as four-operator melody sounds for variety.
+    3. 18 simultaneous melody sounds, or 15 melody sounds with 5 rhythm sounds (with two operators).
+    4. 6 four-operator melody sounds and 6 two-operator melody sounds, or 6 four-operator melody
+       sounds, 3 two-operator melody sounds and 5 rhythm sounds (with four operators).
+    5. 8 selectable waveforms.
+    6. 4-channel sound output.
+    7. YMF262 compabile DAC (YAC512) is available.
+    8. LFO for vibrato and tremolo effedts.
+    9. 2 programable timers.
+   10. Shorter register access time compared with YM3812.
+   11. 5V single supply silicon gate CMOS process.
+   12. 24 Pin SOP Package (YMF262-M), 48 Pin SQFP Package (YMF262-S).
 
 
 differences between OPL2 and OPL3 not documented in Yamaha datahasheets:
@@ -40,8 +54,7 @@ differences between OPL2 and OPL3 shown in datasheets:
 */
 
 #include <math.h>
-
-#include "sndintrf.h"		/* use M.A.M.E. */
+#include "sndintrf.h"
 #include "ymf262.h"
 
 
@@ -119,10 +132,8 @@ static FILE *sample[1];
 	#endif
 #endif
 
-/*#define LOG_CYM_FILE*/
-#ifdef LOG_CYM_FILE
-	FILE * cymfile = NULL;
-#endif
+#define LOG_CYM_FILE 0
+static FILE * cymfile = NULL;
 
 
 
@@ -1609,8 +1620,7 @@ static void OPL3WriteReg(OPL3 *chip, int r, int v)
 
 
 
-#ifdef LOG_CYM_FILE
-	if ((cymfile) && ((r&255)!=0) && (r!=255) )
+	if (LOG_CYM_FILE && (cymfile) && ((r&255)!=0) && (r!=255) )
 	{
 		if (r>0xff)
 			fputc( (unsigned char)0xff, cymfile );/*mark writes to second register set*/
@@ -1618,7 +1628,6 @@ static void OPL3WriteReg(OPL3 *chip, int r, int v)
 		fputc( (unsigned char)r&0xff, cymfile );
 		fputc( (unsigned char)v, cymfile );
 	}
-#endif
 
 	if(r&0x100)
 	{
@@ -2226,7 +2235,6 @@ static void OPL3WriteReg(OPL3 *chip, int r, int v)
 	}
 }
 
-#ifdef LOG_CYM_FILE
 static TIMER_CALLBACK( cymfile_callback )
 {
 	if (cymfile)
@@ -2234,10 +2242,9 @@ static TIMER_CALLBACK( cymfile_callback )
 		fputc( (unsigned char)0, cymfile );
 	}
 }
-#endif
 
 /* lock/unlock for common table */
-static int OPL3_LockTable(void)
+static int OPL3_LockTable(const device_config *device)
 {
 	num_lock++;
 	if(num_lock>1) return 0;
@@ -2252,13 +2259,14 @@ static int OPL3_LockTable(void)
 		return -1;
 	}
 
-#ifdef LOG_CYM_FILE
-	cymfile = fopen("ymf262_.cym","wb");
-	if (cymfile)
-		timer_pulse ( ATTOTIME_IN_HZ(110), 0, cymfile_callback); /*110 Hz pulse timer*/
-	else
-		logerror("Could not create ymf262_.cym file\n");
-#endif
+	if (LOG_CYM_FILE)
+	{
+		cymfile = fopen("ymf262_.cym","wb");
+		if (cymfile)
+			timer_pulse ( device->machine, ATTOTIME_IN_HZ(110), NULL, 0, cymfile_callback); /*110 Hz pulse timer*/
+		else
+			logerror("Could not create ymf262_.cym file\n");
+	}
 
 	return 0;
 }
@@ -2273,11 +2281,9 @@ static void OPL3_UnLockTable(void)
 	cur_chip = NULL;
 	OPLCloseTable();
 
-#ifdef LOG_CYM_FILE
-	fclose (cymfile);
+	if (LOG_CYM_FILE)
+		fclose (cymfile);
 	cymfile = NULL;
-#endif
-
 }
 
 static void OPL3ResetChip(OPL3 *chip)
@@ -2325,11 +2331,11 @@ static void OPL3ResetChip(OPL3 *chip)
 /* Create one of virtual YMF262 */
 /* 'clock' is chip clock in Hz  */
 /* 'rate'  is sampling rate  */
-static OPL3 *OPL3Create(int type, int clock, int rate)
+static OPL3 *OPL3Create(const device_config *device, int clock, int rate, int type)
 {
 	OPL3 *chip;
 
-	if (OPL3_LockTable() ==-1) return NULL;
+	if (OPL3_LockTable(device) == -1) return NULL;
 
 	/* allocate memory block */
 	chip = (OPL3 *)malloc(sizeof(OPL3));
@@ -2457,26 +2463,26 @@ static int OPL3TimerOver(OPL3 *chip,int c)
 
 
 
-void * YMF262Init(int clock, int rate)
+void * ymf262_init(const device_config *device, int clock, int rate)
 {
-	return OPL3Create(OPL3_TYPE_YMF262,clock,rate);
+	return OPL3Create(device,clock,rate,OPL3_TYPE_YMF262);
 }
 
-void YMF262Shutdown(void *chip)
+void ymf262_shutdown(void *chip)
 {
 	OPL3Destroy(chip);
 }
-void YMF262ResetChip(void *chip)
+void ymf262_reset_chip(void *chip)
 {
 	OPL3ResetChip(chip);
 }
 
-int YMF262Write(void *chip, int a, int v)
+int ymf262_write(void *chip, int a, int v)
 {
 	return OPL3Write(chip, a, v);
 }
 
-unsigned char YMF262Read(void *chip, int a)
+unsigned char ymf262_read(void *chip, int a)
 {
 	/* Note on status register: */
 
@@ -2489,20 +2495,20 @@ unsigned char YMF262Read(void *chip, int a)
 
 	return OPL3Read(chip, a);
 }
-int YMF262TimerOver(void *chip, int c)
+int ymf262_timer_over(void *chip, int c)
 {
 	return OPL3TimerOver(chip, c);
 }
 
-void YMF262SetTimerHandler(void *chip, OPL3_TIMERHANDLER timer_handler, void *param)
+void ymf262_set_timer_handler(void *chip, OPL3_TIMERHANDLER timer_handler, void *param)
 {
 	OPL3SetTimerHandler(chip, timer_handler, param);
 }
-void YMF262SetIRQHandler(void *chip,OPL3_IRQHANDLER IRQHandler,void *param)
+void ymf262_set_irq_handler(void *chip,OPL3_IRQHANDLER IRQHandler,void *param)
 {
 	OPL3SetIRQHandler(chip, IRQHandler, param);
 }
-void YMF262SetUpdateHandler(void *chip,OPL3_UPDATEHANDLER UpdateHandler,void *param)
+void ymf262_set_update_handler(void *chip,OPL3_UPDATEHANDLER UpdateHandler,void *param)
 {
 	OPL3SetUpdateHandler(chip, UpdateHandler, param);
 }
@@ -2515,7 +2521,7 @@ void YMF262SetUpdateHandler(void *chip,OPL3_UPDATEHANDLER UpdateHandler,void *pa
 ** '**buffers' is table of 4 pointers to the buffers: CH.A, CH.B, CH.C and CH.D
 ** 'length' is the number of samples that should be generated
 */
-void YMF262UpdateOne(void *_chip, OPL3SAMPLE **buffers, int length)
+void ymf262_update_one(void *_chip, OPL3SAMPLE **buffers, int length)
 {
 	OPL3		*chip  = _chip;
 	UINT8		rhythm = chip->rhythm&0x20;
