@@ -107,13 +107,13 @@ typedef struct
 	UINT8 ext_read;
 
 	const UINT8 *rom;
-	read8_handler ext_mem_read;
-	write8_handler ext_mem_write;
-	void (*irq_callback)(int);
+	read8_space_func ext_mem_read;
+	write8_space_func ext_mem_write;
+	void (*irq_callback)(running_machine *, int);
 
-	int index;
 	UINT32 clock;
 	sound_stream * stream;
+	const device_config *device;
 } YMF271Chip;
 
 // slot mapping assists
@@ -675,14 +675,14 @@ INLINE INT32 calculate_1op_fm_1(YMF271Chip *chip, int slotnum)
 	return slot_output;
 }
 
-static void ymf271_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int length)
+static STREAM_UPDATE( ymf271_update )
 {
 	int i, j;
 	int op;
 	INT32 *mixp;
 	YMF271Chip *chip = param;
 
-	memset(mix, 0, sizeof(mix[0])*length*2);
+	memset(mix, 0, sizeof(mix[0])*samples*2);
 
 	for (j = 0; j < 12; j++)
 	{
@@ -707,7 +707,7 @@ static void ymf271_update(void *param, stream_sample_t **inputs, stream_sample_t
 
 				if (chip->slots[slot1].active)
 				{
-					for (i = 0; i < length; i++)
+					for (i = 0; i < samples; i++)
 					{
 						INT64 output1 = 0, output2 = 0, output3 = 0, output4 = 0, phase_mod1 = 0, phase_mod2 = 0;
 						switch (chip->slots[slot1].algorithm)
@@ -893,7 +893,7 @@ static void ymf271_update(void *param, stream_sample_t **inputs, stream_sample_t
 					mixp = &mix[0];
 					if (chip->slots[slot1].active)
 					{
-						for (i = 0; i < length; i++)
+						for (i = 0; i < samples; i++)
 						{
 							INT64 output1 = 0, output2 = 0, phase_mod = 0;
 							switch (chip->slots[slot1].algorithm & 3)
@@ -946,7 +946,7 @@ static void ymf271_update(void *param, stream_sample_t **inputs, stream_sample_t
 
 				if (chip->slots[slot1].active)
 				{
-					for (i = 0; i < length; i++)
+					for (i = 0; i < samples; i++)
 					{
 						INT64 output1 = 0, output2 = 0, output3 = 0, phase_mod = 0;
 						switch (chip->slots[slot1].algorithm & 7)
@@ -1028,16 +1028,16 @@ static void ymf271_update(void *param, stream_sample_t **inputs, stream_sample_t
 					}
 				}
 
-				update_pcm(chip, j + (3*12), mixp, length);
+				update_pcm(chip, j + (3*12), mixp, samples);
 				break;
 			}
 
 			case 3:		// PCM
 			{
-				update_pcm(chip, j + (0*12), mixp, length);
-				update_pcm(chip, j + (1*12), mixp, length);
-				update_pcm(chip, j + (2*12), mixp, length);
-				update_pcm(chip, j + (3*12), mixp, length);
+				update_pcm(chip, j + (0*12), mixp, samples);
+				update_pcm(chip, j + (1*12), mixp, samples);
+				update_pcm(chip, j + (2*12), mixp, samples);
+				update_pcm(chip, j + (3*12), mixp, samples);
 				break;
 			}
 
@@ -1046,7 +1046,7 @@ static void ymf271_update(void *param, stream_sample_t **inputs, stream_sample_t
 	}
 
 	mixp = &mix[0];
-	for (i = 0; i < length; i++)
+	for (i = 0; i < samples; i++)
 	{
 		outputs[0][i] = (*mixp++)>>2;
 		outputs[1][i] = (*mixp++)>>2;
@@ -1355,7 +1355,7 @@ static TIMER_CALLBACK( ymf271_timer_a_tick )
 	if (chip->enable & 4)
 	{
 		chip->irqstate |= 1;
-		if (chip->irq_callback) chip->irq_callback(1);
+		if (chip->irq_callback) chip->irq_callback(machine, 1);
 	}
 }
 
@@ -1368,14 +1368,16 @@ static TIMER_CALLBACK( ymf271_timer_b_tick )
 	if (chip->enable & 8)
 	{
 		chip->irqstate |= 2;
-		if (chip->irq_callback) chip->irq_callback(1);
+		if (chip->irq_callback) chip->irq_callback(machine, 1);
 	}
 }
 
 static UINT8 ymf271_read_ext_memory(YMF271Chip *chip, UINT32 address)
 {
+	/* temporary hack until this is converted to a device */
+	const address_space *space = memory_find_address_space(chip->device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	if( chip->ext_mem_read ) {
-		return chip->ext_mem_read(address);
+		return chip->ext_mem_read(space,address);
 	} else {
 		if( address < 0x800000)
 			return chip->rom[address];
@@ -1385,8 +1387,10 @@ static UINT8 ymf271_read_ext_memory(YMF271Chip *chip, UINT32 address)
 
 static void ymf271_write_ext_memory(YMF271Chip *chip, UINT32 address, UINT8 data)
 {
+	/* temporary hack until this is converted to a device */
+	const address_space *space = memory_find_address_space(chip->device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	if( chip->ext_mem_write ) {
-		chip->ext_mem_write(address, data);
+		chip->ext_mem_write(space, address, data);
 	}
 }
 
@@ -1395,6 +1399,7 @@ static void ymf271_write_timer(YMF271Chip *chip, int data)
 	int slotnum;
 	YMF271Group *group;
 	attotime period;
+	running_machine *machine = chip->device->machine;
 
 	slotnum = fm_tab[chip->timerreg & 0xf];
 	group = &chip->groups[slotnum];
@@ -1452,23 +1457,23 @@ static void ymf271_write_timer(YMF271Chip *chip, int data)
 					chip->irqstate &= ~1;
 					chip->status &= ~1;
 
-					if (chip->irq_callback) chip->irq_callback(0);
+					if (chip->irq_callback) chip->irq_callback(machine, 0);
 
 					//period = (double)(256.0 - chip->timerAVal ) * ( 384.0 * 4.0 / (double)CLOCK);
 					period = attotime_mul(ATTOTIME_IN_HZ(chip->clock), 384 * (1024 - chip->timerAVal));
 
-					timer_adjust(chip->timA, period, 0, period);
+					timer_adjust_periodic(chip->timA, period, 0, period);
 				}
 				if (data & 0x20)
 				{	// timer B reset
 					chip->irqstate &= ~2;
 					chip->status &= ~2;
 
-					if (chip->irq_callback) chip->irq_callback(0);
+					if (chip->irq_callback) chip->irq_callback(machine, 0);
 
 					period = attotime_mul(ATTOTIME_IN_HZ(chip->clock), 384 * 16 * (256 - chip->timerBVal));
 
-					timer_adjust(chip->timB, period, 0, period);
+					timer_adjust_periodic(chip->timB, period, 0, period);
 				}
 
 				break;
@@ -1647,88 +1652,85 @@ static void init_tables(void)
 	mix = auto_malloc(48000*2*sizeof(*mix));
 }
 
-static void init_state(YMF271Chip *chip)
+static void init_state(YMF271Chip *chip, const device_config *device)
 {
-	int i, instance;
+	int i;
 
-	for (i = 0; i < sizeof(chip->slots) / sizeof(chip->slots[0]); i++)
+	for (i = 0; i < ARRAY_LENGTH(chip->slots); i++)
 	{
-		instance = chip->index * (sizeof(chip->slots) / sizeof(chip->slots[0])) + i;
-
-		state_save_register_item("ymf271", instance, chip->slots[i].extout);
-		state_save_register_item("ymf271", instance, chip->slots[i].lfoFreq);
-		state_save_register_item("ymf271", instance, chip->slots[i].pms);
-		state_save_register_item("ymf271", instance, chip->slots[i].ams);
-		state_save_register_item("ymf271", instance, chip->slots[i].detune);
-		state_save_register_item("ymf271", instance, chip->slots[i].multiple);
-		state_save_register_item("ymf271", instance, chip->slots[i].tl);
-		state_save_register_item("ymf271", instance, chip->slots[i].keyscale);
-		state_save_register_item("ymf271", instance, chip->slots[i].ar);
-		state_save_register_item("ymf271", instance, chip->slots[i].decay1rate);
-		state_save_register_item("ymf271", instance, chip->slots[i].decay2rate);
-		state_save_register_item("ymf271", instance, chip->slots[i].decay1lvl);
-		state_save_register_item("ymf271", instance, chip->slots[i].relrate);
-		state_save_register_item("ymf271", instance, chip->slots[i].fns);
-		state_save_register_item("ymf271", instance, chip->slots[i].block);
-		state_save_register_item("ymf271", instance, chip->slots[i].feedback);
-		state_save_register_item("ymf271", instance, chip->slots[i].waveform);
-		state_save_register_item("ymf271", instance, chip->slots[i].accon);
-		state_save_register_item("ymf271", instance, chip->slots[i].algorithm);
-		state_save_register_item("ymf271", instance, chip->slots[i].ch0_level);
-		state_save_register_item("ymf271", instance, chip->slots[i].ch1_level);
-		state_save_register_item("ymf271", instance, chip->slots[i].ch2_level);
-		state_save_register_item("ymf271", instance, chip->slots[i].ch3_level);
-		state_save_register_item("ymf271", instance, chip->slots[i].startaddr);
-		state_save_register_item("ymf271", instance, chip->slots[i].loopaddr);
-		state_save_register_item("ymf271", instance, chip->slots[i].endaddr);
-		state_save_register_item("ymf271", instance, chip->slots[i].fs);
-		state_save_register_item("ymf271", instance, chip->slots[i].srcnote);
-		state_save_register_item("ymf271", instance, chip->slots[i].srcb);
-		state_save_register_item("ymf271", instance, chip->slots[i].step);
-		state_save_register_item("ymf271", instance, chip->slots[i].stepptr);
-		state_save_register_item("ymf271", instance, chip->slots[i].active);
-		state_save_register_item("ymf271", instance, chip->slots[i].bits);
-		state_save_register_item("ymf271", instance, chip->slots[i].volume);
-		state_save_register_item("ymf271", instance, chip->slots[i].env_state);
-		state_save_register_item("ymf271", instance, chip->slots[i].env_attack_step);
-		state_save_register_item("ymf271", instance, chip->slots[i].env_decay1_step);
-		state_save_register_item("ymf271", instance, chip->slots[i].env_decay2_step);
-		state_save_register_item("ymf271", instance, chip->slots[i].env_release_step);
-		state_save_register_item("ymf271", instance, chip->slots[i].feedback_modulation0);
-		state_save_register_item("ymf271", instance, chip->slots[i].feedback_modulation1);
-		state_save_register_item("ymf271", instance, chip->slots[i].lfo_phase);
-		state_save_register_item("ymf271", instance, chip->slots[i].lfo_step);
-		state_save_register_item("ymf271", instance, chip->slots[i].lfo_amplitude);
+		state_save_register_device_item(device, i, chip->slots[i].extout);
+		state_save_register_device_item(device, i, chip->slots[i].lfoFreq);
+		state_save_register_device_item(device, i, chip->slots[i].pms);
+		state_save_register_device_item(device, i, chip->slots[i].ams);
+		state_save_register_device_item(device, i, chip->slots[i].detune);
+		state_save_register_device_item(device, i, chip->slots[i].multiple);
+		state_save_register_device_item(device, i, chip->slots[i].tl);
+		state_save_register_device_item(device, i, chip->slots[i].keyscale);
+		state_save_register_device_item(device, i, chip->slots[i].ar);
+		state_save_register_device_item(device, i, chip->slots[i].decay1rate);
+		state_save_register_device_item(device, i, chip->slots[i].decay2rate);
+		state_save_register_device_item(device, i, chip->slots[i].decay1lvl);
+		state_save_register_device_item(device, i, chip->slots[i].relrate);
+		state_save_register_device_item(device, i, chip->slots[i].fns);
+		state_save_register_device_item(device, i, chip->slots[i].block);
+		state_save_register_device_item(device, i, chip->slots[i].feedback);
+		state_save_register_device_item(device, i, chip->slots[i].waveform);
+		state_save_register_device_item(device, i, chip->slots[i].accon);
+		state_save_register_device_item(device, i, chip->slots[i].algorithm);
+		state_save_register_device_item(device, i, chip->slots[i].ch0_level);
+		state_save_register_device_item(device, i, chip->slots[i].ch1_level);
+		state_save_register_device_item(device, i, chip->slots[i].ch2_level);
+		state_save_register_device_item(device, i, chip->slots[i].ch3_level);
+		state_save_register_device_item(device, i, chip->slots[i].startaddr);
+		state_save_register_device_item(device, i, chip->slots[i].loopaddr);
+		state_save_register_device_item(device, i, chip->slots[i].endaddr);
+		state_save_register_device_item(device, i, chip->slots[i].fs);
+		state_save_register_device_item(device, i, chip->slots[i].srcnote);
+		state_save_register_device_item(device, i, chip->slots[i].srcb);
+		state_save_register_device_item(device, i, chip->slots[i].step);
+		state_save_register_device_item(device, i, chip->slots[i].stepptr);
+		state_save_register_device_item(device, i, chip->slots[i].active);
+		state_save_register_device_item(device, i, chip->slots[i].bits);
+		state_save_register_device_item(device, i, chip->slots[i].volume);
+		state_save_register_device_item(device, i, chip->slots[i].env_state);
+		state_save_register_device_item(device, i, chip->slots[i].env_attack_step);
+		state_save_register_device_item(device, i, chip->slots[i].env_decay1_step);
+		state_save_register_device_item(device, i, chip->slots[i].env_decay2_step);
+		state_save_register_device_item(device, i, chip->slots[i].env_release_step);
+		state_save_register_device_item(device, i, chip->slots[i].feedback_modulation0);
+		state_save_register_device_item(device, i, chip->slots[i].feedback_modulation1);
+		state_save_register_device_item(device, i, chip->slots[i].lfo_phase);
+		state_save_register_device_item(device, i, chip->slots[i].lfo_step);
+		state_save_register_device_item(device, i, chip->slots[i].lfo_amplitude);
 	}
 
 	for (i = 0; i < sizeof(chip->groups) / sizeof(chip->groups[0]); i++)
 	{
-		instance = chip->index * (sizeof(chip->groups) / sizeof(chip->groups[0])) + i;
-		state_save_register_item("ymf271", instance, chip->groups[i].sync);
-		state_save_register_item("ymf271", instance, chip->groups[i].pfm);
+		state_save_register_device_item(device, i, chip->groups[i].sync);
+		state_save_register_device_item(device, i, chip->groups[i].pfm);
 	}
 
-	state_save_register_item("ymf271", chip->index, chip->timerA);
-	state_save_register_item("ymf271", chip->index, chip->timerB);
-	state_save_register_item("ymf271", chip->index, chip->timerAVal);
-	state_save_register_item("ymf271", chip->index, chip->timerBVal);
-	state_save_register_item("ymf271", chip->index, chip->irqstate);
-	state_save_register_item("ymf271", chip->index, chip->status);
-	state_save_register_item("ymf271", chip->index, chip->enable);
-	state_save_register_item("ymf271", chip->index, chip->reg0);
-	state_save_register_item("ymf271", chip->index, chip->reg1);
-	state_save_register_item("ymf271", chip->index, chip->reg2);
-	state_save_register_item("ymf271", chip->index, chip->reg3);
-	state_save_register_item("ymf271", chip->index, chip->pcmreg);
-	state_save_register_item("ymf271", chip->index, chip->timerreg);
-	state_save_register_item("ymf271", chip->index, chip->ext_address);
-	state_save_register_item("ymf271", chip->index, chip->ext_read);
+	state_save_register_device_item(device, 0, chip->timerA);
+	state_save_register_device_item(device, 0, chip->timerB);
+	state_save_register_device_item(device, 0, chip->timerAVal);
+	state_save_register_device_item(device, 0, chip->timerBVal);
+	state_save_register_device_item(device, 0, chip->irqstate);
+	state_save_register_device_item(device, 0, chip->status);
+	state_save_register_device_item(device, 0, chip->enable);
+	state_save_register_device_item(device, 0, chip->reg0);
+	state_save_register_device_item(device, 0, chip->reg1);
+	state_save_register_device_item(device, 0, chip->reg2);
+	state_save_register_device_item(device, 0, chip->reg3);
+	state_save_register_device_item(device, 0, chip->pcmreg);
+	state_save_register_device_item(device, 0, chip->timerreg);
+	state_save_register_device_item(device, 0, chip->ext_address);
+	state_save_register_device_item(device, 0, chip->ext_read);
 }
 
-static void ymf271_init(YMF271Chip *chip, UINT8 *rom, void (*cb)(int), read8_handler ext_read, write8_handler ext_write)
+static void ymf271_init(const device_config *device, YMF271Chip *chip, UINT8 *rom, void (*cb)(running_machine *,int), read8_space_func ext_read, write8_space_func ext_write)
 {
-	chip->timA = timer_alloc(ymf271_timer_a_tick, chip);
-	chip->timB = timer_alloc(ymf271_timer_b_tick, chip);
+	chip->timA = timer_alloc(device->machine, ymf271_timer_a_tick, chip);
+	chip->timB = timer_alloc(device->machine, ymf271_timer_b_tick, chip);
 
 	chip->rom = rom;
 	chip->irq_callback = cb;
@@ -1737,24 +1739,25 @@ static void ymf271_init(YMF271Chip *chip, UINT8 *rom, void (*cb)(int), read8_han
 	chip->ext_mem_write = ext_write;
 
 	init_tables();
-	init_state(chip);
+	init_state(chip, device);
 }
 
-static void *ymf271_start(int sndindex, int clock, const void *config)
+static SND_START( ymf271 )
 {
-	const struct YMF271interface *intf;
+	static const ymf271_interface defintrf = { 0 };
+	const ymf271_interface *intf;
 	int i;
 	YMF271Chip *chip;
 
 	chip = auto_malloc(sizeof(*chip));
 	memset(chip, 0, sizeof(*chip));
-	chip->index = sndindex;
+	chip->device = device;
 	chip->clock = clock;
 
-	intf = config;
+	intf = (config != NULL) ? config : &defintrf;
 
-	ymf271_init(chip, memory_region(intf->region), intf->irq_callback, intf->ext_read, intf->ext_write);
-	chip->stream = stream_create(0, 2, clock/384, chip, ymf271_update);
+	ymf271_init(device, chip, device->region, intf->irq_callback, intf->ext_read, intf->ext_write);
+	chip->stream = stream_create(device, 0, 2, clock/384, chip, ymf271_update);
 
 	for (i = 0; i < 256; i++)
 	{
@@ -1774,30 +1777,30 @@ static void *ymf271_start(int sndindex, int clock, const void *config)
 	return chip;
 }
 
-READ8_HANDLER( YMF271_0_r )
+READ8_HANDLER( ymf271_0_r )
 {
 	return ymf271_r(0, offset);
 }
 
-WRITE8_HANDLER( YMF271_0_w )
+WRITE8_HANDLER( ymf271_0_w )
 {
 	ymf271_w(0, offset, data);
 }
 
-READ8_HANDLER( YMF271_1_r )
+READ8_HANDLER( ymf271_1_r )
 {
 	return ymf271_r(1, offset);
 }
 
-WRITE8_HANDLER( YMF271_1_w )
+WRITE8_HANDLER( ymf271_1_w )
 {
 	ymf271_w(1, offset, data);
 }
 
-static void ymf271_reset(void *token)
+static SND_RESET( ymf271 )
 {
 	int i;
-	YMF271Chip *chip = (YMF271Chip*)token;
+	YMF271Chip *chip = device->token;
 
 	for (i = 0; i < 48; i++)
 	{
@@ -1810,7 +1813,7 @@ static void ymf271_reset(void *token)
  * Generic get_info
  **************************************************************************/
 
-static void ymf271_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( ymf271 )
 {
 	switch (state)
 	{
@@ -1819,23 +1822,23 @@ static void ymf271_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void ymf271_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( ymf271 )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = ymf271_set_info;		break;
-		case SNDINFO_PTR_START:							info->start = ymf271_start;				break;
-		case SNDINFO_PTR_STOP:							/* Nothing */							break;
-		case SNDINFO_PTR_RESET:							info->reset = ymf271_reset;				break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( ymf271 );	break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( ymf271 );			break;
+		case SNDINFO_PTR_STOP:							/* Nothing */									break;
+		case SNDINFO_PTR_RESET:							info->reset = SND_RESET_NAME( ymf271 );			break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "YMF271";						break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "Yamaha FM";					break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "1.0";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "YMF271");						break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Yamaha FM");					break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.0");							break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);						break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
