@@ -118,7 +118,7 @@ typedef struct
 	int irq_line;
 
 	UINT8 port_A, port_B, port_C;
-	void (*irq_callback)(int);
+	void (*irq_callback)(running_machine *, int);
 
 	const UINT8 *rom;
 	int clock;
@@ -255,7 +255,7 @@ static void ymf278b_envelope_next(YMF278BSlot *slot)
 	}
 }
 
-static void ymf278b_pcm_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int length)
+static STREAM_UPDATE( ymf278b_pcm_update )
 {
 	YMF278BChip *chip = param;
 	int i, j;
@@ -265,7 +265,7 @@ static void ymf278b_pcm_update(void *param, stream_sample_t **inputs, stream_sam
 	INT32 *mixp;
 	INT32 vl, vr;
 
-	memset(mix, 0, sizeof(mix[0])*length*2);
+	memset(mix, 0, sizeof(mix[0])*samples*2);
 
 	rombase = chip->rom;
 
@@ -277,7 +277,7 @@ static void ymf278b_pcm_update(void *param, stream_sample_t **inputs, stream_sam
 		{
 			mixp = mix;
 
-			for (j = 0; j < length; j++)
+			for (j = 0; j < samples; j++)
 			{
 				switch (slot->bits)
 				{
@@ -329,19 +329,19 @@ static void ymf278b_pcm_update(void *param, stream_sample_t **inputs, stream_sam
 	mixp = mix;
 	vl = chip->mix_level[chip->pcm_l];
 	vr = chip->mix_level[chip->pcm_r];
-	for (i = 0; i < length; i++)
+	for (i = 0; i < samples; i++)
 	{
 		outputs[0][i] = (*mixp++ * vl) >> 16;
 		outputs[1][i] = (*mixp++ * vr) >> 16;
 	}
 }
 
-static void ymf278b_irq_check(YMF278BChip *chip)
+static void ymf278b_irq_check(running_machine *machine, YMF278BChip *chip)
 {
 	int prev_line = chip->irq_line;
 	chip->irq_line = chip->current_irq ? ASSERT_LINE : CLEAR_LINE;
 	if(chip->irq_line != prev_line && chip->irq_callback)
-		chip->irq_callback(chip->irq_line);
+		chip->irq_callback(machine, chip->irq_line);
 }
 
 static TIMER_CALLBACK( ymf278b_timer_a_tick )
@@ -350,7 +350,7 @@ static TIMER_CALLBACK( ymf278b_timer_a_tick )
 	if(!(chip->enable & 0x40))
 	{
 		chip->current_irq |= 0x40;
-		ymf278b_irq_check(chip);
+		ymf278b_irq_check(machine, chip);
 	}
 }
 
@@ -360,7 +360,7 @@ static TIMER_CALLBACK( ymf278b_timer_b_tick )
 	if(!(chip->enable & 0x20))
 	{
 		chip->current_irq |= 0x20;
-		ymf278b_irq_check(chip);
+		ymf278b_irq_check(machine, chip);
 	}
 }
 
@@ -373,10 +373,10 @@ static void ymf278b_timer_a_reset(YMF278BChip *chip)
 		if (chip->clock != YMF278B_STD_CLOCK)
 			period = attotime_div(attotime_mul(period, chip->clock), YMF278B_STD_CLOCK);
 
-		timer_adjust(chip->timer_a, period, 0, period);
+		timer_adjust_periodic(chip->timer_a, period, 0, period);
 	}
 	else
-		timer_adjust(chip->timer_a, attotime_never, 0, attotime_zero);
+		timer_adjust_oneshot(chip->timer_a, attotime_never, 0);
 }
 
 static void ymf278b_timer_b_reset(YMF278BChip *chip)
@@ -388,13 +388,13 @@ static void ymf278b_timer_b_reset(YMF278BChip *chip)
 		if (chip->clock != YMF278B_STD_CLOCK)
 			period = attotime_div(attotime_mul(period, chip->clock), YMF278B_STD_CLOCK);
 
-		timer_adjust(chip->timer_a, period, 0, period);
+		timer_adjust_periodic(chip->timer_a, period, 0, period);
 	}
 	else
-		timer_adjust(chip->timer_b, attotime_never, 0, attotime_zero);
+		timer_adjust_oneshot(chip->timer_b, attotime_never, 0);
 }
 
-static void ymf278b_A_w(YMF278BChip *chip, UINT8 reg, UINT8 data)
+static void ymf278b_A_w(running_machine *machine, YMF278BChip *chip, UINT8 reg, UINT8 data)
 {
 	switch(reg)
 	{
@@ -419,7 +419,7 @@ static void ymf278b_A_w(YMF278BChip *chip, UINT8 reg, UINT8 data)
 				if((old_enable ^ data) & 2)
 					ymf278b_timer_b_reset(chip);
 			}
-			ymf278b_irq_check(chip);
+			ymf278b_irq_check(machine, chip);
 			break;
 		default:
 			logerror("YMF278B:  Port A write %02x, %02x\n", reg, data);
@@ -624,10 +624,10 @@ static void ymf278b_control_port_A_w(int num, UINT8 data)
 	chip->port_A = data;
 }
 
-static void ymf278b_data_port_A_w(int num, UINT8 data)
+static void ymf278b_data_port_A_w(running_machine *machine, int num, UINT8 data)
 {
 	YMF278BChip *chip = sndti_token(SOUND_YMF278B, num);
-	ymf278b_A_w(chip, chip->port_A, data);
+	ymf278b_A_w(machine, chip, chip->port_A, data);
 }
 
 static void ymf278b_control_port_B_w(int num, UINT8 data)
@@ -654,21 +654,22 @@ static void ymf278b_data_port_C_w(int num, UINT8 data)
 	ymf278b_C_w(chip, chip->port_C, data);
 }
 
-static void ymf278b_init(YMF278BChip *chip, UINT8 *rom, void (*cb)(int), int clock)
+static void ymf278b_init(running_machine *machine, YMF278BChip *chip, UINT8 *rom, void (*cb)(running_machine *, int), int clock)
 {
 	chip->rom = rom;
 	chip->irq_callback = cb;
-	chip->timer_a = timer_alloc(ymf278b_timer_a_tick, chip);
-	chip->timer_b = timer_alloc(ymf278b_timer_b_tick, chip);
+	chip->timer_a = timer_alloc(machine, ymf278b_timer_a_tick, chip);
+	chip->timer_b = timer_alloc(machine, ymf278b_timer_b_tick, chip);
 	chip->irq_line = CLEAR_LINE;
 	chip->clock = clock;
 
 	mix = auto_malloc(44100*2*sizeof(*mix));
 }
 
-static void *ymf278b_start(int sndindex, int clock, const void *config)
+static SND_START( ymf278b )
 {
-	const struct YMF278B_interface *intf;
+	static const ymf278b_interface defintrf = { 0 };
+	const ymf278b_interface *intf;
 	int i;
 	YMF278BChip *chip;
 
@@ -676,10 +677,10 @@ static void *ymf278b_start(int sndindex, int clock, const void *config)
 	memset(chip, 0, sizeof(*chip));
 	chip->index = sndindex;
 
-	intf = config;
+	intf = (config != NULL) ? config : &defintrf;
 
-	ymf278b_init(chip, memory_region(intf->region), intf->irq_callback, clock);
-	chip->stream = stream_create(0, 2, clock/768, chip, ymf278b_pcm_update);
+	ymf278b_init(device->machine, chip, device->region, intf->irq_callback, clock);
+	chip->stream = stream_create(device, 0, 2, clock/768, chip, ymf278b_pcm_update);
 
 	// Volume table, 1 = -0.375dB, 8 = -3dB, 256 = -96dB
 	for(i = 0; i < 256; i++)
@@ -703,83 +704,83 @@ static void *ymf278b_start(int sndindex, int clock, const void *config)
 }
 
 
-READ8_HANDLER( YMF278B_status_port_0_r )
+READ8_HANDLER( ymf278b_status_port_0_r )
 {
 	return ymf278b_status_port_r(0);
 }
 
-READ8_HANDLER( YMF278B_data_port_0_r )
+READ8_HANDLER( ymf278b_data_port_0_r )
 {
 	return ymf278b_data_port_r(0);
 }
 
-WRITE8_HANDLER( YMF278B_control_port_0_A_w )
+WRITE8_HANDLER( ymf278b_control_port_0_a_w )
 {
 	ymf278b_control_port_A_w(0, data);
 }
 
-WRITE8_HANDLER( YMF278B_data_port_0_A_w )
+WRITE8_HANDLER( ymf278b_data_port_0_a_w )
 {
-	ymf278b_data_port_A_w(0, data);
+	ymf278b_data_port_A_w(space->machine, 0, data);
 }
 
-WRITE8_HANDLER( YMF278B_control_port_0_B_w )
+WRITE8_HANDLER( ymf278b_control_port_0_b_w )
 {
 	ymf278b_control_port_B_w(0, data);
 }
 
-WRITE8_HANDLER( YMF278B_data_port_0_B_w )
+WRITE8_HANDLER( ymf278b_data_port_0_b_w )
 {
 	ymf278b_data_port_B_w(0, data);
 }
 
-WRITE8_HANDLER( YMF278B_control_port_0_C_w )
+WRITE8_HANDLER( ymf278b_control_port_0_c_w )
 {
 	ymf278b_control_port_C_w(0, data);
 }
 
-WRITE8_HANDLER( YMF278B_data_port_0_C_w )
+WRITE8_HANDLER( ymf278b_data_port_0_c_w )
 {
 	ymf278b_data_port_C_w(0, data);
 }
 
 
-READ8_HANDLER( YMF278B_status_port_1_r )
+READ8_HANDLER( ymf278b_status_port_1_r )
 {
 	return ymf278b_status_port_r(1);
 }
 
-READ8_HANDLER( YMF278B_data_port_1_r )
+READ8_HANDLER( ymf278b_data_port_1_r )
 {
 	return ymf278b_data_port_r(1);
 }
 
-WRITE8_HANDLER( YMF278B_control_port_1_A_w )
+WRITE8_HANDLER( ymf278b_control_port_1_a_w )
 {
 	ymf278b_control_port_A_w(1, data);
 }
 
-WRITE8_HANDLER( YMF278B_data_port_1_A_w )
+WRITE8_HANDLER( ymf278b_data_port_1_a_w )
 {
-	ymf278b_data_port_A_w(1, data);
+	ymf278b_data_port_A_w(space->machine, 1, data);
 }
 
-WRITE8_HANDLER( YMF278B_control_port_1_B_w )
+WRITE8_HANDLER( ymf278b_control_port_1_b_w )
 {
 	ymf278b_control_port_B_w(1, data);
 }
 
-WRITE8_HANDLER( YMF278B_data_port_1_B_w )
+WRITE8_HANDLER( ymf278b_data_port_1_b_w )
 {
 	ymf278b_data_port_B_w(1, data);
 }
 
-WRITE8_HANDLER( YMF278B_control_port_1_C_w )
+WRITE8_HANDLER( ymf278b_control_port_1_c_w )
 {
 	ymf278b_control_port_C_w(1, data);
 }
 
-WRITE8_HANDLER( YMF278B_data_port_1_C_w )
+WRITE8_HANDLER( ymf278b_data_port_1_c_w )
 {
 	ymf278b_data_port_C_w(1, data);
 }
@@ -791,7 +792,7 @@ WRITE8_HANDLER( YMF278B_data_port_1_C_w )
  * Generic get_info
  **************************************************************************/
 
-static void ymf278b_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( ymf278b )
 {
 	switch (state)
 	{
@@ -800,24 +801,24 @@ static void ymf278b_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void ymf278b_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( ymf278b )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = ymf278b_set_info;		break;
-		case SNDINFO_PTR_START:							info->start = ymf278b_start;			break;
-		case SNDINFO_PTR_STOP:							/* Nothing */							break;
-		case SNDINFO_PTR_RESET:							/* Nothing */							break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( ymf278b );	break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( ymf278b );		break;
+		case SNDINFO_PTR_STOP:							/* Nothing */									break;
+		case SNDINFO_PTR_RESET:							/* Nothing */									break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "YMF278B";					break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "Yamaha FM";					break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "1.0";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "YMF278B");						break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Yamaha FM");					break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.0");							break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);						break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
