@@ -88,17 +88,18 @@ struct YMZ280BChip
 	UINT8 irq_enable;				/* current IRQ enable */
 	UINT8 keyon_enable;				/* key on enable */
 	double master_clock;			/* master clock frequency */
-	void (*irq_callback)(int);		/* IRQ callback */
+	void (*irq_callback)(running_machine *, int);		/* IRQ callback */
 	struct YMZ280BVoice	voice[8];	/* the 8 voices */
 	UINT32 rom_readback_addr;		/* where the CPU can read the ROM */
-	read8_handler ext_ram_read;		/* external RAM read handler */
-	write8_handler ext_ram_write;	/* external RAM write handler */
+	read8_space_func ext_ram_read;		/* external RAM read handler */
+	write8_space_func ext_ram_write;	/* external RAM write handler */
 
 #if MAKE_WAVS
 	void *		wavresample;			/* resampled waveform */
 #endif
 
 	INT16 *scratch;
+	const device_config *device;
 };
 
 /* step size index shift table */
@@ -117,7 +118,7 @@ static TIMER_CALLBACK( update_irq_state_timer_5 );
 static TIMER_CALLBACK( update_irq_state_timer_6 );
 static TIMER_CALLBACK( update_irq_state_timer_7 );
 
-static const timer_callback update_irq_state_cb[] =
+static const timer_fired_func update_irq_state_cb[] =
 {
 	update_irq_state_timer_0,
 	update_irq_state_timer_1,
@@ -144,14 +145,14 @@ INLINE void update_irq_state(struct YMZ280BChip *chip)
 	{
 		chip->irq_state = 1;
 		if (chip->irq_callback)
-			(*chip->irq_callback)(1);
+			(*chip->irq_callback)(chip->device->machine, 1);
 		else logerror("YMZ280B: IRQ generated, but no callback specified!");
 	}
 	else if (!irq_bits && chip->irq_state)
 	{
 		chip->irq_state = 0;
 		if (chip->irq_callback)
-			(*chip->irq_callback)(0);
+			(*chip->irq_callback)(chip->device->machine, 0);
 		else logerror("YMZ280B: IRQ generated, but no callback specified!");
 	}
 }
@@ -190,7 +191,7 @@ INLINE void update_volumes(struct YMZ280BVoice *voice)
 }
 
 
-static void YMZ280B_state_save_update_step(void *param)
+static STATE_POSTLOAD( YMZ280B_state_save_update_step )
 {
 	struct YMZ280BChip *chip = param;
 	int j;
@@ -199,7 +200,7 @@ static void YMZ280B_state_save_update_step(void *param)
 		struct YMZ280BVoice *voice = &chip->voice[j];
 		update_step(chip, voice);
 		if(voice->irq_schedule)
-			timer_set(attotime_zero, chip, 0, update_irq_state_cb[j]);
+			timer_set(machine, attotime_zero, chip, 0, update_irq_state_cb[j]);
 	}
 }
 
@@ -487,16 +488,16 @@ static int generate_pcm16(struct YMZ280BVoice *voice, UINT8 *base, INT16 *buffer
 
 ***********************************************************************************************/
 
-static void ymz280b_update(void *param, stream_sample_t **inputs, stream_sample_t **buffer, int length)
+static STREAM_UPDATE( ymz280b_update )
 {
 	struct YMZ280BChip *chip = param;
-	stream_sample_t *lacc = buffer[0];
-	stream_sample_t *racc = buffer[1];
+	stream_sample_t *lacc = outputs[0];
+	stream_sample_t *racc = outputs[1];
 	int v;
 
 	/* clear out the accumulator */
-	memset(lacc, 0, length * sizeof(lacc[0]));
-	memset(racc, 0, length * sizeof(racc[0]));
+	memset(lacc, 0, samples * sizeof(lacc[0]));
+	memset(racc, 0, samples * sizeof(racc[0]));
 
 	/* loop over voices */
 	for (v = 0; v < 8; v++)
@@ -509,7 +510,7 @@ static void ymz280b_update(void *param, stream_sample_t **inputs, stream_sample_
 		INT32 *rdest = racc;
 		UINT32 new_samples, samples_left;
 		UINT32 final_pos;
-		int remaining = length;
+		int remaining = samples;
 		int lvol = voice->output_left;
 		int rvol = voice->output_right;
 
@@ -575,7 +576,7 @@ static void ymz280b_update(void *param, stream_sample_t **inputs, stream_sample_
 				voice->playing = 0;
 
 				/* set update_irq_state_timer. IRQ is signaled on next CPU execution. */
-				timer_set(attotime_zero, chip, 0, update_irq_state_cb[v]);
+				timer_set(chip->device->machine, attotime_zero, chip, 0, update_irq_state_cb[v]);
 				voice->irq_schedule = 1;
 			}
 		}
@@ -611,10 +612,10 @@ static void ymz280b_update(void *param, stream_sample_t **inputs, stream_sample_
 		voice->curr_sample = curr;
 	}
 
-	for (v = 0; v < length; v++)
+	for (v = 0; v < samples; v++)
 	{
-		buffer[0][v] /= 256;
-		buffer[1][v] /= 256;
+		outputs[0][v] /= 256;
+		outputs[1][v] /= 256;
 	}
 }
 
@@ -622,18 +623,20 @@ static void ymz280b_update(void *param, stream_sample_t **inputs, stream_sample_
 
 /**********************************************************************************************
 
-     YMZ280B_sh_start -- start emulation of the YMZ280B
+     SND_START( ymz280b ) -- start emulation of the YMZ280B
 
 ***********************************************************************************************/
 
-static void *ymz280b_start(int sndindex, int clock, const void *config)
+static SND_START( ymz280b )
 {
-	const struct YMZ280Binterface *intf = config;
+	static const ymz280b_interface defintrf = { 0 };
+	const ymz280b_interface *intf = (config != NULL) ? config : &defintrf;
 	struct YMZ280BChip *chip;
 
 	chip = auto_malloc(sizeof(*chip));
 	memset(chip, 0, sizeof(*chip));
 
+	chip->device = device;
 	chip->ext_ram_read = intf->ext_read;
 	chip->ext_ram_write = intf->ext_write;
 
@@ -642,11 +645,11 @@ static void *ymz280b_start(int sndindex, int clock, const void *config)
 
 	/* initialize the rest of the structure */
 	chip->master_clock = (double)clock / 384.0;
-	chip->region_base = memory_region(intf->region);
+	chip->region_base = device->region;
 	chip->irq_callback = intf->irq_callback;
 
 	/* create the stream */
-	chip->stream = stream_create(0, 2, INTERNAL_SAMPLE_RATE, chip, ymz280b_update);
+	chip->stream = stream_create(device, 0, 2, INTERNAL_SAMPLE_RATE, chip, ymz280b_update);
 
 	/* allocate memory */
 	chip->scratch = auto_malloc(sizeof(chip->scratch[0]) * MAX_SAMPLE_CHUNK);
@@ -654,42 +657,42 @@ static void *ymz280b_start(int sndindex, int clock, const void *config)
 	/* state save */
 	{
 		int j;
-		state_save_register_item("YMZ280B", sndindex, chip->current_register);
-		state_save_register_item("YMZ280B", sndindex, chip->status_register);
-		state_save_register_item("YMZ280B", sndindex, chip->irq_state);
-		state_save_register_item("YMZ280B", sndindex, chip->irq_mask);
-		state_save_register_item("YMZ280B", sndindex, chip->irq_enable);
-		state_save_register_item("YMZ280B", sndindex, chip->keyon_enable);
-		state_save_register_item("YMZ280B", sndindex, chip->rom_readback_addr);
+		state_save_register_device_item(device, 0, chip->current_register);
+		state_save_register_device_item(device, 0, chip->status_register);
+		state_save_register_device_item(device, 0, chip->irq_state);
+		state_save_register_device_item(device, 0, chip->irq_mask);
+		state_save_register_device_item(device, 0, chip->irq_enable);
+		state_save_register_device_item(device, 0, chip->keyon_enable);
+		state_save_register_device_item(device, 0, chip->rom_readback_addr);
 		for (j = 0; j < 8; j++)
 		{
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].playing);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].keyon);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].looping);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].mode);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].fnum);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].level);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].pan);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].start);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].stop);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].loop_start);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].loop_end);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].position);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].signal);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].step);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].loop_signal);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].loop_step);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].loop_count);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].output_left);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].output_right);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].output_pos);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].last_sample);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].curr_sample);
-			state_save_register_item("YMZ280B.voice", sndindex*8+j, chip->voice[j].irq_schedule);
+			state_save_register_device_item(device, j, chip->voice[j].playing);
+			state_save_register_device_item(device, j, chip->voice[j].keyon);
+			state_save_register_device_item(device, j, chip->voice[j].looping);
+			state_save_register_device_item(device, j, chip->voice[j].mode);
+			state_save_register_device_item(device, j, chip->voice[j].fnum);
+			state_save_register_device_item(device, j, chip->voice[j].level);
+			state_save_register_device_item(device, j, chip->voice[j].pan);
+			state_save_register_device_item(device, j, chip->voice[j].start);
+			state_save_register_device_item(device, j, chip->voice[j].stop);
+			state_save_register_device_item(device, j, chip->voice[j].loop_start);
+			state_save_register_device_item(device, j, chip->voice[j].loop_end);
+			state_save_register_device_item(device, j, chip->voice[j].position);
+			state_save_register_device_item(device, j, chip->voice[j].signal);
+			state_save_register_device_item(device, j, chip->voice[j].step);
+			state_save_register_device_item(device, j, chip->voice[j].loop_signal);
+			state_save_register_device_item(device, j, chip->voice[j].loop_step);
+			state_save_register_device_item(device, j, chip->voice[j].loop_count);
+			state_save_register_device_item(device, j, chip->voice[j].output_left);
+			state_save_register_device_item(device, j, chip->voice[j].output_right);
+			state_save_register_device_item(device, j, chip->voice[j].output_pos);
+			state_save_register_device_item(device, j, chip->voice[j].last_sample);
+			state_save_register_device_item(device, j, chip->voice[j].curr_sample);
+			state_save_register_device_item(device, j, chip->voice[j].irq_schedule);
 		}
 	}
 
-	state_save_register_func_postload_ptr(YMZ280B_state_save_update_step, chip);
+	state_save_register_postload(device->machine, YMZ280B_state_save_update_step, chip);
 
 #if MAKE_WAVS
 	chip->wavresample = wav_open("resamp.wav", INTERNAL_SAMPLE_RATE, 2);
@@ -703,12 +706,12 @@ static void *ymz280b_start(int sndindex, int clock, const void *config)
 
 /**********************************************************************************************
 
-     YMZ280B_sh_stop -- stop emulation of the YMZ280B
+     SND_STOP( YMZ280B_sh ) -- stop emulation of the YMZ280B
 
 ***********************************************************************************************/
 
 #ifdef UNUSED_FUNCTION
-void YMZ280B_sh_stop(void)
+SND_STOP( YMZ280B_sh )
 {
 #if MAKE_WAVS
 {
@@ -864,7 +867,11 @@ static void write_to_register(struct YMZ280BChip *chip, int data)
 
 			case 0x87:		/* RAM write */
 				if (chip->ext_ram_write)
-					chip->ext_ram_write(chip->rom_readback_addr, data);
+				{
+					/* temporary hack until this is converted to a device */
+					const address_space *space = memory_find_address_space(chip->device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+					chip->ext_ram_write(space, chip->rom_readback_addr, data);
+				}
 				else
 					logerror("YMZ280B attempted RAM write to %X\n", chip->rom_readback_addr);
 				break;
@@ -940,41 +947,41 @@ static int compute_status(struct YMZ280BChip *chip)
 
 /**********************************************************************************************
 
-     YMZ280B_status_0_r/YMZ280B_status_1_r -- handle a read from the status register
+     ymz280b_status_0_r/ymz280b_status_1_r -- handle a read from the status register
 
 ***********************************************************************************************/
 
-READ8_HANDLER( YMZ280B_status_0_r )
+READ8_HANDLER( ymz280b_status_0_r )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 0);
 	return compute_status(chip);
 }
 
-READ8_HANDLER( YMZ280B_status_1_r )
+READ8_HANDLER( ymz280b_status_1_r )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 1);
 	return compute_status(chip);
 }
 
-READ16_HANDLER( YMZ280B_status_0_lsb_r )
+READ16_HANDLER( ymz280b_status_0_lsb_r )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 0);
 	return compute_status(chip);
 }
 
-READ16_HANDLER( YMZ280B_status_0_msb_r )
+READ16_HANDLER( ymz280b_status_0_msb_r )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 0);
 	return compute_status(chip) << 8;
 }
 
-READ16_HANDLER( YMZ280B_status_1_lsb_r )
+READ16_HANDLER( ymz280b_status_1_lsb_r )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 1);
 	return compute_status(chip);
 }
 
-READ16_HANDLER( YMZ280B_status_1_msb_r )
+READ16_HANDLER( ymz280b_status_1_msb_r )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 1);
 	return compute_status(chip) << 8;
@@ -982,108 +989,108 @@ READ16_HANDLER( YMZ280B_status_1_msb_r )
 
 /**********************************************************************************************
 
-     YMZ280B_register_0_w/YMZ280B_register_1_w -- handle a write to the register select
+     ymz280b_register_0_w/ymz280b_register_1_w -- handle a write to the register select
 
 ***********************************************************************************************/
 
-WRITE8_HANDLER( YMZ280B_register_0_w )
+WRITE8_HANDLER( ymz280b_register_0_w )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 0);
 	chip->current_register = data;
 }
 
-WRITE8_HANDLER( YMZ280B_register_1_w )
+WRITE8_HANDLER( ymz280b_register_1_w )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 1);
 	chip->current_register = data;
 }
 
-WRITE16_HANDLER( YMZ280B_register_0_lsb_w )
+WRITE16_HANDLER( ymz280b_register_0_lsb_w )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 0);
-	if (ACCESSING_LSB)	chip->current_register = data & 0xff;
+	if (ACCESSING_BITS_0_7)	chip->current_register = data & 0xff;
 }
 
-WRITE16_HANDLER( YMZ280B_register_0_msb_w )
+WRITE16_HANDLER( ymz280b_register_0_msb_w )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 0);
-	if (ACCESSING_MSB)	chip->current_register = (data >> 8) & 0xff;
+	if (ACCESSING_BITS_8_15)	chip->current_register = (data >> 8) & 0xff;
 }
 
-WRITE16_HANDLER( YMZ280B_register_1_lsb_w )
+WRITE16_HANDLER( ymz280b_register_1_lsb_w )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 1);
-	if (ACCESSING_LSB)	chip->current_register = data & 0xff;
+	if (ACCESSING_BITS_0_7)	chip->current_register = data & 0xff;
 }
 
-WRITE16_HANDLER( YMZ280B_register_1_msb_w )
+WRITE16_HANDLER( ymz280b_register_1_msb_w )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 1);
-	if (ACCESSING_MSB)	chip->current_register = (data >> 8) & 0xff;
+	if (ACCESSING_BITS_8_15)	chip->current_register = (data >> 8) & 0xff;
 }
 
 /**********************************************************************************************
 
-     YMZ280B_data_0_w/YMZ280B_data_1_w -- handle a write to the current register
+     ymz280b_data_0_w/ymz280b_data_1_w -- handle a write to the current register
 
 ***********************************************************************************************/
 
-WRITE8_HANDLER( YMZ280B_data_0_w )
+WRITE8_HANDLER( ymz280b_data_0_w )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 0);
 	write_to_register(chip, data);
 }
 
-WRITE8_HANDLER( YMZ280B_data_1_w )
+WRITE8_HANDLER( ymz280b_data_1_w )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 1);
 	write_to_register(chip, data);
 }
 
-WRITE16_HANDLER( YMZ280B_data_0_lsb_w )
+WRITE16_HANDLER( ymz280b_data_0_lsb_w )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 0);
-	if (ACCESSING_LSB)	write_to_register(chip, data & 0xff);
+	if (ACCESSING_BITS_0_7)	write_to_register(chip, data & 0xff);
 }
 
-WRITE16_HANDLER( YMZ280B_data_0_msb_w )
+WRITE16_HANDLER( ymz280b_data_0_msb_w )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 0);
-	if (ACCESSING_MSB)	write_to_register(chip, (data >> 8) & 0xff);
+	if (ACCESSING_BITS_8_15)	write_to_register(chip, (data >> 8) & 0xff);
 }
 
-WRITE16_HANDLER( YMZ280B_data_1_lsb_w )
+WRITE16_HANDLER( ymz280b_data_1_lsb_w )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 1);
-	if (ACCESSING_LSB)	write_to_register(chip, data & 0xff);
+	if (ACCESSING_BITS_0_7)	write_to_register(chip, data & 0xff);
 }
 
-WRITE16_HANDLER( YMZ280B_data_1_msb_w )
+WRITE16_HANDLER( ymz280b_data_1_msb_w )
 {
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 1);
-	if (ACCESSING_MSB)	write_to_register(chip, (data >> 8) & 0xff);
+	if (ACCESSING_BITS_8_15)	write_to_register(chip, (data >> 8) & 0xff);
 }
 
 /**********************************************************************************************
 
-     YMZ280B_data_0_r/YMZ280B_data_1_r -- handle an external RAM read
+     ymz280b_data_0_r/ymz280b_data_1_r -- handle an external RAM read
 
 ***********************************************************************************************/
 
-READ8_HANDLER( YMZ280B_data_0_r )
+READ8_HANDLER( ymz280b_data_0_r )
 {
 	UINT8 data;
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 0);
-	data = chip->ext_ram_read(chip->rom_readback_addr - 1);
+	data = chip->ext_ram_read(space, chip->rom_readback_addr - 1);
 	chip->rom_readback_addr++;
 	return data;
 }
 
-READ8_HANDLER( YMZ280B_data_1_r )
+READ8_HANDLER( ymz280b_data_1_r )
 {
 	UINT8 data;
 	struct YMZ280BChip *chip = sndti_token(SOUND_YMZ280B, 1);
-	data = chip->ext_ram_read(chip->rom_readback_addr - 1);
+	data = chip->ext_ram_read(space, chip->rom_readback_addr - 1);
 	chip->rom_readback_addr++;
 	return data;
 }
@@ -1095,7 +1102,7 @@ READ8_HANDLER( YMZ280B_data_1_r )
  * Generic get_info
  **************************************************************************/
 
-static void ymz280b_set_info(void *token, UINT32 state, sndinfo *info)
+static SND_SET_INFO( ymz280b )
 {
 	switch (state)
 	{
@@ -1104,24 +1111,24 @@ static void ymz280b_set_info(void *token, UINT32 state, sndinfo *info)
 }
 
 
-void ymz280b_get_info(void *token, UINT32 state, sndinfo *info)
+SND_GET_INFO( ymz280b )
 {
 	switch (state)
 	{
 		/* --- the following bits of info are returned as 64-bit signed integers --- */
 
 		/* --- the following bits of info are returned as pointers to data or functions --- */
-		case SNDINFO_PTR_SET_INFO:						info->set_info = ymz280b_set_info;		break;
-		case SNDINFO_PTR_START:							info->start = ymz280b_start;			break;
-		case SNDINFO_PTR_STOP:							/* Nothing */							break;
-		case SNDINFO_PTR_RESET:							/* Nothing */							break;
+		case SNDINFO_PTR_SET_INFO:						info->set_info = SND_SET_INFO_NAME( ymz280b );	break;
+		case SNDINFO_PTR_START:							info->start = SND_START_NAME( ymz280b );		break;
+		case SNDINFO_PTR_STOP:							/* Nothing */									break;
+		case SNDINFO_PTR_RESET:							/* Nothing */									break;
 
 		/* --- the following bits of info are returned as NULL-terminated strings --- */
-		case SNDINFO_STR_NAME:							info->s = "YMZ280B";					break;
-		case SNDINFO_STR_CORE_FAMILY:					info->s = "Yamaha Wavetable";			break;
-		case SNDINFO_STR_CORE_VERSION:					info->s = "1.0";						break;
-		case SNDINFO_STR_CORE_FILE:						info->s = __FILE__;						break;
-		case SNDINFO_STR_CORE_CREDITS:					info->s = "Copyright Nicola Salmoria and the MAME Team"; break;
+		case SNDINFO_STR_NAME:							strcpy(info->s, "YMZ280B");						break;
+		case SNDINFO_STR_CORE_FAMILY:					strcpy(info->s, "Yamaha Wavetable");			break;
+		case SNDINFO_STR_CORE_VERSION:					strcpy(info->s, "1.0");							break;
+		case SNDINFO_STR_CORE_FILE:						strcpy(info->s, __FILE__);						break;
+		case SNDINFO_STR_CORE_CREDITS:					strcpy(info->s, "Copyright Nicola Salmoria and the MAME Team"); break;
 	}
 }
 
