@@ -104,20 +104,6 @@
             column and row to a memory index; several standard mappers
             are provided, with tilemap_scan_rows being the most common
 
-        type = the type of tilemap this is;
-
-            TILEMAP_TYPE_PEN - this is the most common type,
-                and means that transparency is determined by taking the
-                raw pen value and looking it up in a table to determine
-                which layer(s) each pixel belongs to
-
-            TILEMAP_TYPE_COLORTABLE - this is less common and
-                will eventually be deprecated; it means that transparency
-                is determined by taking the raw pen value, looking it up
-                in the machine's colortable, and then looking that value
-                up in a table to determine which layer(s) each pixel
-                belongs to
-
         tilewidth = the width, in pixels, of each individual tile
 
         tileheight = the height, in pixels, of each individual tile
@@ -145,6 +131,9 @@
             * setting a global palette offset via
                 tilemap_set_palette_offset()
 
+            * setting a global pen data offset via
+                tilemap_set_pen_data_offset()
+
     3. In your memory write handlers for the tile memory, anytime tile
         data is modified, you need to mark the tile dirty so that it is
         re-rendered with the new data the next time the tilemap is drawn.
@@ -162,7 +151,7 @@
     6. In your VIDEO_UPDATE callback, render the tiles by calling
         tilemap_draw() or tilemap_draw_roz(). If you need to do custom
         rendering and want access to the raw pixels, call
-        tilemap_get_pixmap() to get a pointer to the updated mame_bitmap
+        tilemap_get_pixmap() to get a pointer to the updated bitmap_t
         containing the tilemap graphics.
 
 ****************************************************************************
@@ -202,10 +191,9 @@
         VIDEO_START( mydriver )
         {
             // first create the tilemap
-            tmap = tilemap_create(
+            tmap = tilemap_create(machine,
                     my_get_info,            // pointer to your get_info
                     tilemap_scan_rows,      // standard row-major mapper
-                    TILEMAP_TYPE_PEN, // transparency from pens
                     8,8,                    // 8x8 tiles
                     64,32);                 // 64 columns, 32 rows
 
@@ -255,17 +243,10 @@
             transparent pen for them; this no longer works.
 
         TILEMAP_TRANSPARENT: This described a tilemap with a single
-            transparent pen. To create the same effect, make a new tilemap
-            of type TILEMAP_TYPE_PEN, and then call
+            transparent pen. To create the same effect, call
             tilemap_set_transparent_pen() to specify which pen is
             transparent; all other pens will map to layer 0.
 
-        TILEMAP_TRANSPARENT_COLOR: This works just like before and
-            even has the same type name. Create a tilemap of type
-            TILEMAP_TYPE_COLORTABLE and call
-            tilemap_set_transparent_pen() to specify which remapped pen
-            is transparent.
-
         TILEMAP_BITMASK: This type is no longer special; with the new
             code, any tile_get_info callback can specify a bitmask which
             will be processed after rendering to make some pixels
@@ -276,8 +257,7 @@
             also allowed for you to choose one of 4 mappings on a per-tile
             basis. All of this functionality is now expanded: you can
             specify one of 3 layers and can choose from one of 256 mappings
-            on a per-tile basis. You just create a tilemap of type
-            TILEMAP_TYPE_PEN and call tilemap_set_transmask(),
+            on a per-tile basis. You just call tilemap_set_transmask(),
             which still exists but maps onto the new behavior. The "front"
             layer is now "layer 0" and the "back" layer is now "layer 1".
 
@@ -344,6 +324,7 @@
 #define TILEMAP_DRAW_LAYER2				0x40		/* draw layer 2 */
 #define TILEMAP_DRAW_OPAQUE				0x80		/* draw everything, even transparent stuff */
 #define TILEMAP_DRAW_ALPHA				0x100		/* draw with alpha blending */
+#define TILEMAP_DRAW_ALL_CATEGORIES		0x200		/* draw all categories */
 
 
 /* per-pixel flags in the transparency_bitmap */
@@ -389,7 +370,6 @@
 /* Macros for setting tile attributes in the TILE_GET_INFO callback: */
 /*   TILE_FLIP_YX assumes that flipy is in bit 1 and flipx is in bit 0 */
 /*   TILE_FLIP_XY assumes that flipy is in bit 0 and flipx is in bit 1 */
-/*   TILE_GROUP shifts a split group number appropriately to OR into the tile flags */
 #define TILE_FLIPYX(YX)					((YX) & 3)
 #define TILE_FLIPXY(XY)					((((XY) & 2) >> 1) | (((XY) & 1) << 1))
 
@@ -406,33 +386,25 @@ typedef UINT32 tilemap_memory_index;
 typedef struct _tilemap tilemap;
 
 
-/* tilemap types */
-enum _tilemap_type
-{
-	TILEMAP_TYPE_PEN,				/* pen-to-layer mapping is determined by pen lookup */
-	TILEMAP_TYPE_COLORTABLE			/* pen-to-layer mapping is determined by colortable[pen] lookup */
-};
-typedef enum _tilemap_type tilemap_type;
-
-
 /* tile_data is filled in by the get_tile_info callback */
 typedef struct _tile_data tile_data;
 struct _tile_data
 {
-	const UINT8 *	pen_data;		/* required */
-	const UINT8 *	mask_data;		/* required for TILEMAP_TYPE_PEN */
+	const UINT8*	pen_data;		/* required */
+	const UINT8*	mask_data;		/* required */
 	pen_t			palette_base;	/* defaults to 0 */
-	UINT8 			category;		/* defaults to 0; range from 0..15 */
+	UINT8			category;		/* defaults to 0; range from 0..15 */
 	UINT8			group;			/* defaults to 0; range from 0..TILEMAP_NUM_GROUPS */
-	UINT8 			flags;			/* defaults to 0; one or more of TILE_* flags above */
+	UINT8			flags;			/* defaults to 0; one or more of TILE_* flags above */
+	UINT8			pen_mask;		/* defaults to 0xff; mask to apply to pen_data while rendering the tile */
 };
 
 
 /* callback function to get info about a tile */
-typedef void (*tile_get_info_callback)(running_machine *machine, tile_data *tileinfo, tilemap_memory_index tile_index, void *param);
+typedef void (*tile_get_info_func)(running_machine *machine, tile_data *tileinfo, tilemap_memory_index tile_index, void *param);
 
 /* callback function to map a column,row pair to a memory index */
-typedef tilemap_memory_index (*tilemap_mapper_callback)(UINT32 col, UINT32 row, UINT32 num_cols, UINT32 num_rows);
+typedef tilemap_memory_index (*tilemap_mapper_func)(UINT32 col, UINT32 row, UINT32 num_cols, UINT32 num_rows);
 
 
 
@@ -440,7 +412,7 @@ typedef tilemap_memory_index (*tilemap_mapper_callback)(UINT32 col, UINT32 row,
     GLOBAL VARIABLES
 ***************************************************************************/
 
-extern mame_bitmap *priority_bitmap;
+extern bitmap_t *priority_bitmap;
 
 
 
@@ -459,14 +431,22 @@ void tilemap_init(running_machine *machine);
 /* ----- tilemap creation and configuration ----- */
 
 /* create a new tilemap; note that tilemaps are tracked by the core so there is no dispose */
-tilemap *tilemap_create(tile_get_info_callback tile_get_info, tilemap_mapper_callback mapper, tilemap_type type, int tilewidth, int tileheight, int cols, int rows);
+tilemap *tilemap_create(running_machine *machine, tile_get_info_func tile_get_info, tilemap_mapper_func mapper, int tilewidth, int tileheight, int cols, int rows);
 
 /* specify a parameter to be passed into the tile_get_info callback */
 void tilemap_set_user_data(tilemap *tmap, void *user_data);
 
-/* specify an offset to be added to each pixel before looking up the palette */
+/* specify an offset to be added to each pixel before looking up the palette.
+ * The offset only applies at final rendering time (e.g., tilemap_draw())
+ * It does not apply to the cached pixmap, which is provided by tilemap_get_pixmap().
+ */
 void tilemap_set_palette_offset(tilemap *tmap, UINT32 offset);
 
+/* specify an offset to be added to pen_data while rendering tiles.
+ * This will automatically mark all tiles dirty if the offset changes.
+ */
+void tilemap_set_pen_data_offset(tilemap *tmap, UINT32 offset);
+
 /* set an enable flag for the tilemap; if 0, requests to draw the tilemap are ignored */
 void tilemap_set_enable(tilemap *tmap, int enable);
 
@@ -527,10 +507,10 @@ int tilemap_get_scrolly(tilemap *tmap, int col);
 /* ----- internal map access ----- */
 
 /* return a pointer to the (updated) internal pixmap for a tilemap */
-mame_bitmap *tilemap_get_pixmap(tilemap *tmap);
+bitmap_t *tilemap_get_pixmap(tilemap *tmap);
 
 /* return a pointer to the (updated) internal flagsmap for a tilemap */
-mame_bitmap *tilemap_get_flagsmap(tilemap *tmap);
+bitmap_t *tilemap_get_flagsmap(tilemap *tmap);
 
 /* return a pointer to the (updated) internal per-tile flags for a tilemap */
 UINT8 *tilemap_get_tile_flags(tilemap *tmap);
@@ -540,11 +520,11 @@ UINT8 *tilemap_get_tile_flags(tilemap *tmap);
 /* ----- tilemap rendering ----- */
 
 /* draw a tilemap to the destination with clipping; pixels apply priority/priority_mask to the priority bitmap */
-void tilemap_draw_primask(mame_bitmap *dest, const rectangle *cliprect, tilemap *tmap, UINT32 flags, UINT8 priority, UINT8 priority_mask);
+void tilemap_draw_primask(bitmap_t *dest, const rectangle *cliprect, tilemap *tmap, UINT32 flags, UINT8 priority, UINT8 priority_mask);
 
 /* draw a tilemap to the destination with clipping and arbitrary rotate/zoom; */
 /* pixels apply priority/priority_mask to the priority bitmap */
-void tilemap_draw_roz_primask(mame_bitmap *dest, const rectangle *cliprect, tilemap *tmap,
+void tilemap_draw_roz_primask(bitmap_t *dest, const rectangle *cliprect, tilemap *tmap,
 		UINT32 startx, UINT32 starty, int incxx, int incxy, int incyx, int incyy,
 		int wraparound, UINT32 flags, UINT8 priority, UINT8 priority_mask);
 
@@ -559,7 +539,7 @@ int tilemap_count(void);
 void tilemap_size_by_index(int number, UINT32 *width, UINT32 *height);
 
 /* render an indexed tilemap with fixed characteristics (no priority) */
-void tilemap_draw_by_index(mame_bitmap *dest, int number, UINT32 scrollx, UINT32 scrolly);
+void tilemap_draw_by_index(bitmap_t *dest, int number, UINT32 scrollx, UINT32 scrolly);
 
 
 
@@ -616,7 +596,7 @@ INLINE void tilemap_map_pen_to_layer(tilemap *tmap, int group, pen_t pen, UINT8
     tilemap_draw_primask
 -------------------------------------------------*/
 
-INLINE void tilemap_draw(mame_bitmap *dest, const rectangle *cliprect, tilemap *tmap, UINT32 flags, UINT8 priority)
+INLINE void tilemap_draw(bitmap_t *dest, const rectangle *cliprect, tilemap *tmap, UINT32 flags, UINT8 priority)
 {
 	tilemap_draw_primask(dest, cliprect, tmap, flags, priority, 0xff);
 }
@@ -627,7 +607,7 @@ INLINE void tilemap_draw(mame_bitmap *dest, const rectangle *cliprect, tilemap *
     tilemap_draw_roz_primask
 -------------------------------------------------*/
 
-INLINE void tilemap_draw_roz(mame_bitmap *dest, const rectangle *cliprect, tilemap *tmap,
+INLINE void tilemap_draw_roz(bitmap_t *dest, const rectangle *cliprect, tilemap *tmap,
 		UINT32 startx, UINT32 starty, int incxx, int incxy, int incyx, int incyy,
 		int wraparound, UINT32 flags, UINT8 priority)
 {
