@@ -10,11 +10,11 @@
 *********************************************************************/
 
 #include "ui.h"
+#include "uiinput.h"
 #include "render.h"
 #include "rendfont.h"
 #include "rendutil.h"
 #include "uigfx.h"
-#include "deprecat.h"
 
 
 
@@ -29,7 +29,7 @@ struct _ui_gfx_state
 
 	/* intermediate bitmaps */
 	UINT8			bitmap_dirty;		/* is the bitmap dirty? */
-	mame_bitmap *	bitmap;				/* bitmap for drawing gfx and tilemaps */
+	bitmap_t *		bitmap;				/* bitmap for drawing gfx and tilemaps */
 	render_texture *texture;			/* texture for rendering the above bitmap */
 
 	/* palette-specific data */
@@ -78,19 +78,19 @@ static ui_gfx_state ui_gfx;
 static void ui_gfx_exit(running_machine *machine);
 
 /* palette handling */
-static void palette_handle_keys(ui_gfx_state *state);
-static void palette_handler(ui_gfx_state *state);
+static void palette_handle_keys(running_machine *machine, ui_gfx_state *state);
+static void palette_handler(running_machine *machine, ui_gfx_state *state);
 
 /* graphics set handling */
-static void gfxset_handle_keys(ui_gfx_state *state, int xcells, int ycells);
-static void gfxset_draw_item(const gfx_element *gfx, int index, mame_bitmap *bitmap, int dstx, int dsty, int color, int rotate);
-static void gfxset_update_bitmap(ui_gfx_state *state, int xcells, int ycells, gfx_element *gfx);
-static void gfxset_handler(ui_gfx_state *state);
+static void gfxset_handle_keys(running_machine *machine, ui_gfx_state *state, int xcells, int ycells);
+static void gfxset_draw_item(running_machine *machine, const gfx_element *gfx, int index, bitmap_t *bitmap, int dstx, int dsty, int color, int rotate);
+static void gfxset_update_bitmap(running_machine *machine, ui_gfx_state *state, int xcells, int ycells, gfx_element *gfx);
+static void gfxset_handler(running_machine *machine, ui_gfx_state *state);
 
 /* tilemap handling */
-static void tilemap_handle_keys(ui_gfx_state *state, int viswidth, int visheight);
-static void tilemap_update_bitmap(ui_gfx_state *state, int width, int height);
-static void tilemap_handler(ui_gfx_state *state);
+static void tilemap_handle_keys(running_machine *machine, ui_gfx_state *state, int viswidth, int visheight);
+static void tilemap_update_bitmap(running_machine *machine, ui_gfx_state *state, int width, int height);
+static void tilemap_handler(running_machine *machine, ui_gfx_state *state);
 
 
 
@@ -119,12 +119,12 @@ void ui_gfx_init(running_machine *machine)
 	/* set up the graphics state */
 	for (gfx = 0; gfx < MAX_GFX_ELEMENTS; gfx++)
 	{
-		state->gfxset.rotate[gfx] = Machine->gamedrv->flags & ORIENTATION_MASK;
+		state->gfxset.rotate[gfx] = machine->gamedrv->flags & ORIENTATION_MASK;
 		state->gfxset.count[gfx] = 16;
 	}
 
 	/* set up the tilemap state */
-	state->tilemap.rotate = Machine->gamedrv->flags & ORIENTATION_MASK;
+	state->tilemap.rotate = machine->gamedrv->flags & ORIENTATION_MASK;
 }
 
 
@@ -155,11 +155,11 @@ UINT32 ui_gfx_ui_handler(running_machine *machine, UINT32 uistate)
 	ui_gfx_state *state = &ui_gfx;
 
 	/* if we have nothing, implicitly cancel */
-	if (Machine->drv->total_colors == 0 && Machine->drv->color_table_len == 0 && Machine->gfx[0] == NULL && tilemap_count() == 0)
+	if (machine->config->total_colors == 0 && machine->colortable == NULL && machine->gfx[0] == NULL && tilemap_count() == 0)
 		goto cancel;
 
 	/* if we're not paused, mark the bitmap dirty */
-	if (!mame_is_paused(Machine))
+	if (!mame_is_paused(machine))
 		state->bitmap_dirty = TRUE;
 
 	/* switch off the state to display something */
@@ -168,9 +168,9 @@ again:
 	{
 		case 0:
 			/* if we have a palette, display it */
-			if (Machine->drv->total_colors > 0)
+			if (machine->config->total_colors > 0)
 			{
-				palette_handler(state);
+				palette_handler(machine, state);
 				break;
 			}
 
@@ -179,9 +179,9 @@ again:
 
 		case 1:
 			/* if we have graphics sets, display them */
-			if (Machine->gfx[0] != NULL)
+			if (machine->gfx[0] != NULL)
 			{
-				gfxset_handler(state);
+				gfxset_handler(machine, state);
 				break;
 			}
 
@@ -192,7 +192,7 @@ again:
 			/* if we have tilemaps, display them */
 			if (tilemap_count() > 0)
 			{
-				tilemap_handler(state);
+				tilemap_handler(machine, state);
 				break;
 			}
 
@@ -201,23 +201,23 @@ again:
 	}
 
 	/* handle keys */
-	if (input_ui_pressed(IPT_UI_SELECT))
+	if (ui_input_pressed(machine, IPT_UI_SELECT))
 	{
 		state->mode = (state->mode + 1) % 3;
 		state->bitmap_dirty = TRUE;
 	}
 
-	if (input_ui_pressed(IPT_UI_PAUSE))
-		mame_pause(Machine, !mame_is_paused(Machine));
+	if (ui_input_pressed(machine, IPT_UI_PAUSE))
+		mame_pause(machine, !mame_is_paused(machine));
 
-	if (input_ui_pressed(IPT_UI_CANCEL) || input_ui_pressed(IPT_UI_SHOW_GFX))
+	if (ui_input_pressed(machine, IPT_UI_CANCEL) || ui_input_pressed(machine, IPT_UI_SHOW_GFX))
 		goto cancel;
 
 	return uistate;
 
 cancel:
 	if (!uistate)
-		mame_pause(Machine, FALSE);
+		mame_pause(machine, FALSE);
 	state->bitmap_dirty = TRUE;
 	return UI_HANDLER_CANCEL;
 }
@@ -233,12 +233,11 @@ cancel:
     viewer
 -------------------------------------------------*/
 
-static void palette_handler(ui_gfx_state *state)
+static void palette_handler(running_machine *machine, ui_gfx_state *state)
 {
-	int total = state->palette.which ? Machine->drv->color_table_len : Machine->drv->total_colors;
-	const UINT16 *pens = state->palette.which ? Machine->game_colortable : NULL;
+	int total = state->palette.which ? colortable_palette_get_size(machine->colortable) : machine->config->total_colors;
 	const char *title = state->palette.which ? "COLORTABLE" : "PALETTE";
-	const rgb_t *raw_color = palette_entry_list_raw(Machine->palette);
+	const rgb_t *raw_color = palette_entry_list_raw(machine->palette);
 	render_font *ui_font = ui_get_font();
 	float cellwidth, cellheight;
 	float chwidth, chheight;
@@ -337,15 +336,15 @@ static void palette_handler(ui_gfx_state *state)
 			int index = state->palette.offset + y * state->palette.count + x;
 			if (index < total)
 			{
-				pen_t pen = (pens != NULL) ? pens[index] : index;
+				pen_t pen = state->palette.which ? colortable_palette_get_color(machine->colortable, index) : raw_color[index];
 				render_ui_add_rect(cellboxbounds.x0 + x * cellwidth, cellboxbounds.y0 + y * cellheight,
 									cellboxbounds.x0 + (x + 1) * cellwidth, cellboxbounds.y0 + (y + 1) * cellheight,
-									0xff000000 | raw_color[pen], PRIMFLAG_BLENDMODE(BLENDMODE_ALPHA));
+									0xff000000 | pen, PRIMFLAG_BLENDMODE(BLENDMODE_ALPHA));
 			}
 		}
 
 	/* handle keys */
-	palette_handle_keys(state);
+	palette_handle_keys(machine, state);
 }
 
 
@@ -354,15 +353,15 @@ static void palette_handler(ui_gfx_state *state)
     palette viewer
 -------------------------------------------------*/
 
-static void palette_handle_keys(ui_gfx_state *state)
+static void palette_handle_keys(running_machine *machine, ui_gfx_state *state)
 {
 	int rowcount, screencount;
 	int total;
 
 	/* handle zoom (minus,plus) */
-	if (input_ui_pressed(IPT_UI_ZOOM_OUT))
+	if (ui_input_pressed(machine, IPT_UI_ZOOM_OUT))
 		state->palette.count /= 2;
-	if (input_ui_pressed(IPT_UI_ZOOM_IN))
+	if (ui_input_pressed(machine, IPT_UI_ZOOM_IN))
 		state->palette.count *= 2;
 
 	/* clamp within range */
@@ -372,36 +371,36 @@ static void palette_handle_keys(ui_gfx_state *state)
 		state->palette.count = 64;
 
 	/* handle colormap selection (open bracket,close bracket) */
-	if (input_ui_pressed(IPT_UI_PREV_GROUP))
+	if (ui_input_pressed(machine, IPT_UI_PREV_GROUP))
 		state->palette.which--;
-	if (input_ui_pressed(IPT_UI_NEXT_GROUP))
+	if (ui_input_pressed(machine, IPT_UI_NEXT_GROUP))
 		state->palette.which++;
 
 	/* clamp within range */
 	if (state->palette.which < 0)
 		state->palette.which = 1;
-	if (state->palette.which > (Machine->drv->color_table_len != 0))
-		state->palette.which = (Machine->drv->color_table_len != 0);
+	if (state->palette.which > (machine->colortable != NULL))
+		state->palette.which = (machine->colortable != NULL);
 
 	/* cache some info in locals */
-	total = state->palette.which ? Machine->drv->color_table_len : Machine->drv->total_colors;
+	total = state->palette.which ? colortable_palette_get_size(machine->colortable) : machine->config->total_colors;
 
 	/* determine number of entries per row and total */
 	rowcount = state->palette.count;
 	screencount = rowcount * rowcount;
 
 	/* handle keyboard navigation */
-	if (input_ui_pressed_repeat(IPT_UI_UP, 4))
+	if (ui_input_pressed_repeat(machine, IPT_UI_UP, 4))
 		state->palette.offset -= rowcount;
-	if (input_ui_pressed_repeat(IPT_UI_DOWN, 4))
+	if (ui_input_pressed_repeat(machine, IPT_UI_DOWN, 4))
 		state->palette.offset += rowcount;
-	if (input_ui_pressed_repeat(IPT_UI_PAGE_UP, 6))
+	if (ui_input_pressed_repeat(machine, IPT_UI_PAGE_UP, 6))
 		state->palette.offset -= screencount;
-	if (input_ui_pressed_repeat(IPT_UI_PAGE_DOWN, 6))
+	if (ui_input_pressed_repeat(machine, IPT_UI_PAGE_DOWN, 6))
 		state->palette.offset += screencount;
-	if (input_ui_pressed_repeat(IPT_UI_HOME, 4))
+	if (ui_input_pressed_repeat(machine, IPT_UI_HOME, 4))
 		state->palette.offset = 0;
-	if (input_ui_pressed_repeat(IPT_UI_END, 4))
+	if (ui_input_pressed_repeat(machine, IPT_UI_END, 4))
 		state->palette.offset = total;
 
 	/* clamp within range */
@@ -422,11 +421,11 @@ static void palette_handle_keys(ui_gfx_state *state)
     viewer
 -------------------------------------------------*/
 
-static void gfxset_handler(ui_gfx_state *state)
+static void gfxset_handler(running_machine *machine, ui_gfx_state *state)
 {
 	render_font *ui_font = ui_get_font();
 	int set = state->gfxset.set;
-	gfx_element *gfx = Machine->gfx[set];
+	gfx_element *gfx = machine->gfx[set];
 	float fullwidth, fullheight;
 	float cellwidth, cellheight;
 	float chwidth, chheight;
@@ -511,7 +510,7 @@ static void gfxset_handler(ui_gfx_state *state)
 	boxbounds.y1 = boxbounds.y0 + fullheight;
 
 	/* figure out the title and expand the outer box to fit */
-	for (x = 0; x < MAX_GFX_ELEMENTS && Machine->gfx[x] != NULL; x++) ;
+	for (x = 0; x < MAX_GFX_ELEMENTS && machine->gfx[x] != NULL; x++) ;
 	sprintf(title, "GFX %d/%d %dx%d COLOR %X", state->gfxset.set, x - 1, gfx->width, gfx->height, state->gfxset.color[set]);
 	titlewidth = render_font_get_string_width(ui_font, chheight, render_get_ui_aspect(), title);
 	x0 = 0.0f;
@@ -570,7 +569,7 @@ static void gfxset_handler(ui_gfx_state *state)
 		}
 
 	/* update the bitmap */
-	gfxset_update_bitmap(state, xcells, ycells, gfx);
+	gfxset_update_bitmap(machine, state, xcells, ycells, gfx);
 
 	/* add the final quad */
 	render_ui_add_quad(boxbounds.x0 + 6.0f * chwidth, boxbounds.y0 + 3.5f * chheight,
@@ -579,34 +578,34 @@ static void gfxset_handler(ui_gfx_state *state)
 						ARGB_WHITE, state->texture, PRIMFLAG_BLENDMODE(BLENDMODE_ALPHA));
 
 	/* handle keyboard navigation before drawing */
-	gfxset_handle_keys(state, xcells, ycells);
+	gfxset_handle_keys(machine, state, xcells, ycells);
 }
 
 
 /*-------------------------------------------------
-    gfxset_handler - handle keys for the graphics
-    viewer
+    gfxset_handle_keys - handle keys for the
+    graphics viewer
 -------------------------------------------------*/
 
-static void gfxset_handle_keys(ui_gfx_state *state, int xcells, int ycells)
+static void gfxset_handle_keys(running_machine *machine, ui_gfx_state *state, int xcells, int ycells)
 {
 	ui_gfx_state oldstate = *state;
 	gfx_element *gfx;
 	int temp, set;
 
 	/* handle gfxset selection (open bracket,close bracket) */
-	if (input_ui_pressed(IPT_UI_PREV_GROUP))
+	if (ui_input_pressed(machine, IPT_UI_PREV_GROUP))
 	{
 		for (temp = state->gfxset.set - 1; temp >= 0; temp--)
-			if (Machine->gfx[temp] != NULL)
+			if (machine->gfx[temp] != NULL)
 				break;
 		if (temp >= 0)
 			state->gfxset.set = temp;
 	}
-	if (input_ui_pressed(IPT_UI_NEXT_GROUP))
+	if (ui_input_pressed(machine, IPT_UI_NEXT_GROUP))
 	{
 		for (temp = state->gfxset.set + 1; temp < MAX_GFX_ELEMENTS; temp++)
-			if (Machine->gfx[temp] != NULL)
+			if (machine->gfx[temp] != NULL)
 				break;
 		if (temp < MAX_GFX_ELEMENTS)
 			state->gfxset.set = temp;
@@ -614,12 +613,12 @@ static void gfxset_handle_keys(ui_gfx_state *state, int xcells, int ycells)
 
 	/* cache some info in locals */
 	set = state->gfxset.set;
-	gfx = Machine->gfx[set];
+	gfx = machine->gfx[set];
 
 	/* handle cells per line (minus,plus) */
-	if (input_ui_pressed(IPT_UI_ZOOM_OUT))
+	if (ui_input_pressed(machine, IPT_UI_ZOOM_OUT))
 		state->gfxset.count[set] = xcells - 1;
-	if (input_ui_pressed(IPT_UI_ZOOM_IN))
+	if (ui_input_pressed(machine, IPT_UI_ZOOM_IN))
 		state->gfxset.count[set] = xcells + 1;
 
 	/* clamp within range */
@@ -629,21 +628,21 @@ static void gfxset_handle_keys(ui_gfx_state *state, int xcells, int ycells)
 		state->gfxset.count[set] = 32;
 
 	/* handle rotation (R) */
-	if (input_ui_pressed(IPT_UI_ROTATE))
+	if (ui_input_pressed(machine, IPT_UI_ROTATE))
 		state->gfxset.rotate[set] = orientation_add(ROT90, state->gfxset.rotate[set]);
 
 	/* handle navigation within the cells (up,down,pgup,pgdown) */
-	if (input_ui_pressed_repeat(IPT_UI_UP, 4))
+	if (ui_input_pressed_repeat(machine, IPT_UI_UP, 4))
 		state->gfxset.offset[set] -= xcells;
-	if (input_ui_pressed_repeat(IPT_UI_DOWN, 4))
+	if (ui_input_pressed_repeat(machine, IPT_UI_DOWN, 4))
 		state->gfxset.offset[set] += xcells;
-	if (input_ui_pressed_repeat(IPT_UI_PAGE_UP, 6))
+	if (ui_input_pressed_repeat(machine, IPT_UI_PAGE_UP, 6))
 		state->gfxset.offset[set] -= xcells * ycells;
-	if (input_ui_pressed_repeat(IPT_UI_PAGE_DOWN, 6))
+	if (ui_input_pressed_repeat(machine, IPT_UI_PAGE_DOWN, 6))
 		state->gfxset.offset[set] += xcells * ycells;
-	if (input_ui_pressed_repeat(IPT_UI_HOME, 4))
+	if (ui_input_pressed_repeat(machine, IPT_UI_HOME, 4))
 		state->gfxset.offset[set] = 0;
-	if (input_ui_pressed_repeat(IPT_UI_END, 4))
+	if (ui_input_pressed_repeat(machine, IPT_UI_END, 4))
 		state->gfxset.offset[set] = gfx->total_elements;
 
 	/* clamp within range */
@@ -653,9 +652,9 @@ static void gfxset_handle_keys(ui_gfx_state *state, int xcells, int ycells)
 		state->gfxset.offset[set] = 0;
 
 	/* handle color selection (left,right) */
-	if (input_ui_pressed_repeat(IPT_UI_LEFT, 4))
+	if (ui_input_pressed_repeat(machine, IPT_UI_LEFT, 4))
 		state->gfxset.color[set] -= 1;
-	if (input_ui_pressed_repeat(IPT_UI_RIGHT, 4))
+	if (ui_input_pressed_repeat(machine, IPT_UI_RIGHT, 4))
 		state->gfxset.color[set] += 1;
 
 	/* clamp within range */
@@ -681,7 +680,7 @@ static void gfxset_handle_keys(ui_gfx_state *state, int xcells, int ycells)
     graphics view bitmap
 -------------------------------------------------*/
 
-static void gfxset_update_bitmap(ui_gfx_state *state, int xcells, int ycells, gfx_element *gfx)
+static void gfxset_update_bitmap(running_machine *machine, ui_gfx_state *state, int xcells, int ycells, gfx_element *gfx)
 {
 	int set = state->gfxset.set;
 	int cellxpix, cellypix;
@@ -703,7 +702,7 @@ static void gfxset_update_bitmap(ui_gfx_state *state, int xcells, int ycells, gf
 		/* allocate new stuff */
 		state->bitmap = bitmap_alloc(cellxpix * xcells, cellypix * ycells, BITMAP_FORMAT_ARGB32);
 		state->texture = render_texture_alloc(NULL, NULL);
-		render_texture_set_bitmap(state->texture, state->bitmap, NULL, 0, TEXFORMAT_ARGB32);
+		render_texture_set_bitmap(state->texture, state->bitmap, NULL, TEXFORMAT_ARGB32, NULL);
 
 		/* force a redraw */
 		state->bitmap_dirty = TRUE;
@@ -737,21 +736,21 @@ static void gfxset_update_bitmap(ui_gfx_state *state, int xcells, int ycells, gf
 
 					/* only render if there is data */
 					if (index < gfx->total_elements)
-						gfxset_draw_item(gfx, index, state->bitmap, cellbounds.min_x, cellbounds.min_y, state->gfxset.color[set], state->gfxset.rotate[set]);
+						gfxset_draw_item(machine, gfx, index, state->bitmap, cellbounds.min_x, cellbounds.min_y, state->gfxset.color[set], state->gfxset.rotate[set]);
 
 					/* otherwise, fill with transparency */
 					else
-						fillbitmap(state->bitmap, 0, &cellbounds);
+						bitmap_fill(state->bitmap, &cellbounds, 0);
 				}
 			}
 
 			/* otherwise, fill with transparency */
 			else
-				fillbitmap(state->bitmap, 0, &cellbounds);
+				bitmap_fill(state->bitmap, &cellbounds, 0);
 		}
 
 		/* reset the texture to force an update */
-		render_texture_set_bitmap(state->texture, state->bitmap, NULL, 0, TEXFORMAT_ARGB32);
+		render_texture_set_bitmap(state->texture, state->bitmap, NULL, TEXFORMAT_ARGB32, NULL);
 		state->bitmap_dirty = FALSE;
 	}
 }
@@ -762,7 +761,7 @@ static void gfxset_update_bitmap(ui_gfx_state *state, int xcells, int ycells, gf
     the view
 -------------------------------------------------*/
 
-static void gfxset_draw_item(const gfx_element *gfx, int index, mame_bitmap *bitmap, int dstx, int dsty, int color, int rotate)
+static void gfxset_draw_item(running_machine *machine, const gfx_element *gfx, int index, bitmap_t *bitmap, int dstx, int dsty, int color, int rotate)
 {
 	static const pen_t default_palette[] =
 	{
@@ -771,16 +770,12 @@ static void gfxset_draw_item(const gfx_element *gfx, int index, mame_bitmap *bit
 	};
 	int width = (rotate & ORIENTATION_SWAP_XY) ? gfx->height : gfx->width;
 	int height = (rotate & ORIENTATION_SWAP_XY) ? gfx->width : gfx->height;
-	const pen_t *palette = (Machine->drv->total_colors != 0) ? palette_entry_list_raw(Machine->palette) : NULL;
+	const rgb_t *palette = (machine->config->total_colors != 0) ? palette_entry_list_raw(machine->palette) : NULL;
 	UINT32 rowpixels = bitmap->rowpixels;
-	const UINT16 *colortable = NULL;
 	UINT32 palette_mask = ~0;
 	int x, y;
 
-	/* select either the raw palette or the colortable */
-	if (Machine->game_colortable != NULL)
-		colortable = &Machine->game_colortable[gfx->color_base + color * gfx->color_granularity];
-	else if (palette != NULL)
+	if (palette != NULL)
 		palette += gfx->color_base + color * gfx->color_granularity;
 	else
 	{
@@ -827,8 +822,6 @@ static void gfxset_draw_item(const gfx_element *gfx, int index, mame_bitmap *bit
 				pixel = (s[effx/2] >> ((effx & 1) * 4)) & 0xf;
 			else
 				pixel = s[effx];
-			if (colortable != NULL)
-				pixel = colortable[pixel];
 			*dest++ = 0xff000000 | palette[pixel & palette_mask];
 		}
 	}
@@ -845,7 +838,7 @@ static void gfxset_draw_item(const gfx_element *gfx, int index, mame_bitmap *bit
     viewer
 -------------------------------------------------*/
 
-static void tilemap_handler(ui_gfx_state *state)
+static void tilemap_handler(running_machine *machine, ui_gfx_state *state)
 {
 	render_font *ui_font = ui_get_font();
 	float chwidth, chheight;
@@ -937,7 +930,7 @@ static void tilemap_handler(ui_gfx_state *state)
 	}
 
 	/* update the bitmap */
-	tilemap_update_bitmap(state, mapboxwidth / pixelscale, mapboxheight / pixelscale);
+	tilemap_update_bitmap(machine, state, mapboxwidth / pixelscale, mapboxheight / pixelscale);
 
 	/* add the final quad */
 	render_ui_add_quad(mapboxbounds.x0, mapboxbounds.y0,
@@ -946,7 +939,7 @@ static void tilemap_handler(ui_gfx_state *state)
 						PRIMFLAG_BLENDMODE(BLENDMODE_ALPHA) | PRIMFLAG_TEXORIENT(state->tilemap.rotate));
 
 	/* handle keyboard input */
-	tilemap_handle_keys(state, mapboxwidth, mapboxheight);
+	tilemap_handle_keys(machine, state, mapboxwidth, mapboxheight);
 }
 
 
@@ -955,16 +948,16 @@ static void tilemap_handler(ui_gfx_state *state)
     tilemap view
 -------------------------------------------------*/
 
-static void tilemap_handle_keys(ui_gfx_state *state, int viswidth, int visheight)
+static void tilemap_handle_keys(running_machine *machine, ui_gfx_state *state, int viswidth, int visheight)
 {
 	ui_gfx_state oldstate = *state;
 	UINT32 mapwidth, mapheight;
 	int step;
 
 	/* handle tilemap selection (open bracket,close bracket) */
-	if (input_ui_pressed(IPT_UI_PREV_GROUP))
+	if (ui_input_pressed(machine, IPT_UI_PREV_GROUP))
 		state->tilemap.which--;
-	if (input_ui_pressed(IPT_UI_NEXT_GROUP))
+	if (ui_input_pressed(machine, IPT_UI_NEXT_GROUP))
 		state->tilemap.which++;
 
 	/* clamp within range */
@@ -977,9 +970,9 @@ static void tilemap_handle_keys(ui_gfx_state *state, int viswidth, int visheight
 	tilemap_size_by_index(state->tilemap.which, &mapwidth, &mapheight);
 
 	/* handle zoom (minus,plus) */
-	if (input_ui_pressed(IPT_UI_ZOOM_OUT))
+	if (ui_input_pressed(machine, IPT_UI_ZOOM_OUT))
 		state->tilemap.zoom--;
-	if (input_ui_pressed(IPT_UI_ZOOM_IN))
+	if (ui_input_pressed(machine, IPT_UI_ZOOM_IN))
 		state->tilemap.zoom++;
 
 	/* clamp within range */
@@ -996,20 +989,20 @@ static void tilemap_handle_keys(ui_gfx_state *state, int viswidth, int visheight
 	}
 
 	/* handle rotation (R) */
-	if (input_ui_pressed(IPT_UI_ROTATE))
+	if (ui_input_pressed(machine, IPT_UI_ROTATE))
 		state->tilemap.rotate = orientation_add(ROT90, state->tilemap.rotate);
 
 	/* handle navigation (up,down,left,right) */
 	step = 8;
 	if (input_code_pressed(KEYCODE_LSHIFT)) step = 1;
 	if (input_code_pressed(KEYCODE_LCONTROL)) step = 64;
-	if (input_ui_pressed_repeat(IPT_UI_UP, 4))
+	if (ui_input_pressed_repeat(machine, IPT_UI_UP, 4))
 		state->tilemap.yoffs -= step;
-	if (input_ui_pressed_repeat(IPT_UI_DOWN, 4))
+	if (ui_input_pressed_repeat(machine, IPT_UI_DOWN, 4))
 		state->tilemap.yoffs += step;
-	if (input_ui_pressed_repeat(IPT_UI_LEFT, 6))
+	if (ui_input_pressed_repeat(machine, IPT_UI_LEFT, 6))
 		state->tilemap.xoffs -= step;
-	if (input_ui_pressed_repeat(IPT_UI_RIGHT, 6))
+	if (ui_input_pressed_repeat(machine, IPT_UI_RIGHT, 6))
 		state->tilemap.xoffs += step;
 
 	/* clamp within range */
@@ -1038,18 +1031,19 @@ static void tilemap_handle_keys(ui_gfx_state *state, int viswidth, int visheight
     for the tilemap view
 -------------------------------------------------*/
 
-static void tilemap_update_bitmap(ui_gfx_state *state, int width, int height)
+static void tilemap_update_bitmap(running_machine *machine, ui_gfx_state *state, int width, int height)
 {
-	bitmap_format screen_format = Machine->screen[0].format;
+	bitmap_format screen_format = video_screen_get_format(machine->primary_screen);
+	palette_t *palette = NULL;
 	int screen_texformat;
 
 	/* convert the screen format to a texture format */
 	switch (screen_format)
 	{
-		case BITMAP_FORMAT_INDEXED16:	screen_texformat = TEXFORMAT_PALETTE16;		break;
-		case BITMAP_FORMAT_RGB15:		screen_texformat = TEXFORMAT_RGB15;			break;
-		case BITMAP_FORMAT_RGB32:		screen_texformat = TEXFORMAT_RGB32;			break;
-		default:						fatalerror("Invalid bitmap format!");		break;
+		case BITMAP_FORMAT_INDEXED16:	screen_texformat = TEXFORMAT_PALETTE16;	palette = machine->palette;	break;
+		case BITMAP_FORMAT_RGB15:		screen_texformat = TEXFORMAT_RGB15;		palette = NULL;				break;
+		case BITMAP_FORMAT_RGB32:		screen_texformat = TEXFORMAT_RGB32;		palette = NULL;				break;
+		default:						fatalerror("Invalid bitmap format!");								break;
 	}
 
 	/* swap the coordinates back if they were talking about a rotated surface */
@@ -1068,7 +1062,7 @@ static void tilemap_update_bitmap(ui_gfx_state *state, int width, int height)
 		/* allocate new stuff */
 		state->bitmap = bitmap_alloc(width, height, screen_format);
 		state->texture = render_texture_alloc(NULL, NULL);
-		render_texture_set_bitmap(state->texture, state->bitmap, NULL, 0, screen_texformat);
+		render_texture_set_bitmap(state->texture, state->bitmap, NULL, screen_texformat, palette);
 
 		/* force a redraw */
 		state->bitmap_dirty = TRUE;
@@ -1080,7 +1074,7 @@ static void tilemap_update_bitmap(ui_gfx_state *state, int width, int height)
 		tilemap_draw_by_index(state->bitmap, state->tilemap.which, state->tilemap.xoffs, state->tilemap.yoffs);
 
 		/* reset the texture to force an update */
-		render_texture_set_bitmap(state->texture, state->bitmap, NULL, 0, screen_texformat);
+		render_texture_set_bitmap(state->texture, state->bitmap, NULL, screen_texformat, palette);
 		state->bitmap_dirty = FALSE;
 	}
 }
