@@ -10,7 +10,6 @@
 *********************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "generic.h"
 
 
@@ -59,8 +58,8 @@ UINT32 *paletteram32;
 UINT8 *paletteram_2;	/* use when palette RAM is split in two parts */
 UINT16 *paletteram16_2;
 
-mame_bitmap *tmpbitmap;
-int flip_screen_x, flip_screen_y;
+bitmap_t *tmpbitmap;
+static int flip_screen_x, flip_screen_y;
 
 
 
@@ -205,9 +204,9 @@ INLINE UINT32 paletteram32_be(offs_t offset)
     shift values
 -------------------------------------------------*/
 
-INLINE void set_color_444(pen_t color, int rshift, int gshift, int bshift, UINT16 data)
+INLINE void set_color_444(running_machine *machine, pen_t color, int rshift, int gshift, int bshift, UINT16 data)
 {
-	palette_set_color_rgb(Machine, color, pal4bit(data >> rshift), pal4bit(data >> gshift), pal4bit(data >> bshift));
+	palette_set_color_rgb(machine, color, pal4bit(data >> rshift), pal4bit(data >> gshift), pal4bit(data >> bshift));
 }
 
 
@@ -217,7 +216,7 @@ INLINE void set_color_444(pen_t color, int rshift, int gshift, int bshift, UINT1
     shift values
 -------------------------------------------------*/
 
-INLINE void set_color_4444(pen_t color, int ishift, int rshift, int gshift, int bshift, UINT16 data)
+INLINE void set_color_4444(running_machine *machine, pen_t color, int ishift, int rshift, int gshift, int bshift, UINT16 data)
 {
 	static const UINT8 ztable[16] =
 		{ 0x0, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8, 0x9, 0xa, 0xb, 0xc, 0xd, 0xe, 0xf, 0x10, 0x11 };
@@ -228,7 +227,7 @@ INLINE void set_color_4444(pen_t color, int ishift, int rshift, int gshift, int
 	g = ((data >> gshift) & 15) * i;
 	b = ((data >> bshift) & 15) * i;
 
-	palette_set_color_rgb(Machine, color, r, g, b);
+	palette_set_color_rgb(machine, color, r, g, b);
 }
 
 
@@ -238,9 +237,9 @@ INLINE void set_color_4444(pen_t color, int ishift, int rshift, int gshift, int
     shift values
 -------------------------------------------------*/
 
-INLINE void set_color_555(pen_t color, int rshift, int gshift, int bshift, UINT16 data)
+INLINE void set_color_555(running_machine *machine, pen_t color, int rshift, int gshift, int bshift, UINT16 data)
 {
-	palette_set_color_rgb(Machine, color, pal5bit(data >> rshift), pal5bit(data >> gshift), pal5bit(data >> bshift));
+	palette_set_color_rgb(machine, color, pal5bit(data >> rshift), pal5bit(data >> gshift), pal5bit(data >> bshift));
 }
 
 
@@ -250,9 +249,9 @@ INLINE void set_color_555(pen_t color, int rshift, int gshift, int bshift, UINT1
     shift values
 -------------------------------------------------*/
 
-INLINE void set_color_888(pen_t color, int rshift, int gshift, int bshift, UINT32 data)
+INLINE void set_color_888(running_machine *machine, pen_t color, int rshift, int gshift, int bshift, UINT32 data)
 {
-	palette_set_color_rgb(Machine, color, (data >> rshift) & 0xff, (data >> gshift) & 0xff, (data >> bshift) & 0xff);
+	palette_set_color_rgb(machine, color, (data >> rshift) & 0xff, (data >> gshift) & 0xff, (data >> bshift) & 0xff);
 }
 
 
@@ -295,6 +294,8 @@ void generic_video_init(running_machine *machine)
 	spriteram_3_size = 0;
 	tmpbitmap = NULL;
 	flip_screen_x = flip_screen_y = 0;
+	state_save_register_item(machine, "video", NULL, 0, flip_screen_x);
+	state_save_register_item(machine, "video", NULL, 0, flip_screen_y);
 }
 
 
@@ -303,17 +304,6 @@ void generic_video_init(running_machine *machine)
     GENERIC VIDEO START/UPDATE
 ***************************************************************************/
 
-/*-------------------------------------------------
-    VIDEO_START( generic ) - general video system
--------------------------------------------------*/
-
-VIDEO_START( generic )
-{
-	/* allocate the temporary bitmap */
-	tmpbitmap = auto_bitmap_alloc(machine->screen[0].width, machine->screen[0].height, machine->screen[0].format);
-}
-
-
 /*-------------------------------------------------
     VIDEO_START( generic_bitmapped ) - general video
     system with a bitmap
@@ -322,10 +312,10 @@ VIDEO_START( generic )
 VIDEO_START( generic_bitmapped )
 {
 	/* allocate the temporary bitmap */
-	tmpbitmap = auto_bitmap_alloc(machine->screen[0].width, machine->screen[0].height, machine->screen[0].format);
+	tmpbitmap = video_screen_auto_bitmap_alloc(machine->primary_screen);
 
 	/* ensure the contents of the bitmap are saved */
-	state_save_register_bitmap("video", 0, "tmpbitmap", tmpbitmap);
+	state_save_register_bitmap(machine, "video", NULL, 0, "tmpbitmap", tmpbitmap);
 }
 
 
@@ -377,7 +367,7 @@ equal to the size of normal spriteram.
 
     Spriteram size _must_ be declared in the memory map:
 
-    { 0x120000, 0x1207ff, MWA8_BANK2, &spriteram, &spriteram_size },
+    { 0x120000, 0x1207ff, SMH_BANK2, &spriteram, &spriteram_size },
 
     Then the video driver must draw the sprites from the buffered_spriteram
 pointer.  The function buffer_spriteram_w() is used to simulate hardware
@@ -457,10 +447,12 @@ void buffer_spriteram_2(UINT8 *ptr, int length)
     updateflip - handle global flipping
 -------------------------------------------------*/
 
-static void updateflip(void)
+static void updateflip(running_machine *machine)
 {
-	screen_state *state = &Machine->screen[0];
-	rectangle visarea = state->visarea;
+	int width = video_screen_get_width(machine->primary_screen);
+	int height = video_screen_get_height(machine->primary_screen);
+	attoseconds_t period = video_screen_get_frame_period(machine->primary_screen).attoseconds;
+	rectangle visarea = *video_screen_get_visible_area(machine->primary_screen);
 
 	tilemap_set_flip(ALL_TILEMAPS,(TILEMAP_FLIPX & flip_screen_x) | (TILEMAP_FLIPY & flip_screen_y));
 
@@ -468,20 +460,20 @@ static void updateflip(void)
 	{
 		int temp;
 
-		temp = state->width - visarea.min_x - 1;
-		visarea.min_x = state->width - visarea.max_x - 1;
+		temp = width - visarea.min_x - 1;
+		visarea.min_x = width - visarea.max_x - 1;
 		visarea.max_x = temp;
 	}
 	if (flip_screen_y)
 	{
 		int temp;
 
-		temp = state->height - visarea.min_y - 1;
-		visarea.min_y = state->height - visarea.max_y - 1;
+		temp = height - visarea.min_y - 1;
+		visarea.min_y = height - visarea.max_y - 1;
 		visarea.max_y = temp;
 	}
 
-	video_screen_configure(0, state->width, state->height, &visarea, state->refresh);
+	video_screen_configure(machine->primary_screen, width, height, &visarea, period);
 }
 
 
@@ -489,10 +481,26 @@ static void updateflip(void)
     flip_screen_set - set global flip
 -------------------------------------------------*/
 
-void flip_screen_set(int on)
+void flip_screen_set(running_machine *machine, int on)
 {
-	flip_screen_x_set(on);
-	flip_screen_y_set(on);
+	flip_screen_x_set(machine, on);
+	flip_screen_y_set(machine, on);
+}
+
+
+/*-------------------------------------------------
+    flip_screen_set_no_update - set global flip
+       do not call update_flip.
+-------------------------------------------------*/
+
+void flip_screen_set_no_update(running_machine *machine, int on)
+{
+	/* flip_screen_y is not updated on purpose
+     * this function is for drivers which
+     * where writing to flip_screen_x to
+     * bypass update_flip
+     */
+	flip_screen_x = on;
 }
 
 
@@ -500,13 +508,13 @@ void flip_screen_set(int on)
     flip_screen_x_set - set global horizontal flip
 -------------------------------------------------*/
 
-void flip_screen_x_set(int on)
+void flip_screen_x_set(running_machine *machine, int on)
 {
 	if (on) on = ~0;
 	if (flip_screen_x != on)
 	{
 		flip_screen_x = on;
-		updateflip();
+		updateflip(machine);
 	}
 }
 
@@ -515,17 +523,48 @@ void flip_screen_x_set(int on)
     flip_screen_y_set - set global vertical flip
 -------------------------------------------------*/
 
-void flip_screen_y_set(int on)
+void flip_screen_y_set(running_machine *machine, int on)
 {
 	if (on) on = ~0;
 	if (flip_screen_y != on)
 	{
 		flip_screen_y = on;
-		updateflip();
+		updateflip(machine);
 	}
 }
 
 
+/*-------------------------------------------------
+    flip_screen_get - get global flip
+-------------------------------------------------*/
+
+int flip_screen_get(running_machine *machine)
+{
+	return flip_screen_x;
+}
+
+
+/*-------------------------------------------------
+    flip_screen_x_get - get global x flip
+-------------------------------------------------*/
+
+int flip_screen_x_get(running_machine *machine)
+{
+	return flip_screen_x;
+}
+
+
+/*-------------------------------------------------
+    flip_screen_get - get global y flip
+-------------------------------------------------*/
+
+int flip_screen_y_get(running_machine *machine)
+{
+	return flip_screen_y;
+}
+
+
+
 /***************************************************************************
     COMMON PALETTE INITIALIZATION
 ***************************************************************************/
@@ -555,7 +594,7 @@ PALETTE_INIT( RRRR_GGGG_BBBB )
 {
 	int i;
 
-	for (i = 0; i < machine->drv->total_colors; i++)
+	for (i = 0; i < machine->config->total_colors; i++)
 	{
 		int bit0,bit1,bit2,bit3,r,g,b;
 
@@ -567,17 +606,17 @@ PALETTE_INIT( RRRR_GGGG_BBBB )
 		r = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 
 		/* green component */
-		bit0 = (color_prom[i + machine->drv->total_colors] >> 0) & 0x01;
-		bit1 = (color_prom[i + machine->drv->total_colors] >> 1) & 0x01;
-		bit2 = (color_prom[i + machine->drv->total_colors] >> 2) & 0x01;
-		bit3 = (color_prom[i + machine->drv->total_colors] >> 3) & 0x01;
+		bit0 = (color_prom[i + machine->config->total_colors] >> 0) & 0x01;
+		bit1 = (color_prom[i + machine->config->total_colors] >> 1) & 0x01;
+		bit2 = (color_prom[i + machine->config->total_colors] >> 2) & 0x01;
+		bit3 = (color_prom[i + machine->config->total_colors] >> 3) & 0x01;
 		g = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 
 		/* blue component */
-		bit0 = (color_prom[i + 2*machine->drv->total_colors] >> 0) & 0x01;
-		bit1 = (color_prom[i + 2*machine->drv->total_colors] >> 1) & 0x01;
-		bit2 = (color_prom[i + 2*machine->drv->total_colors] >> 2) & 0x01;
-		bit3 = (color_prom[i + 2*machine->drv->total_colors] >> 3) & 0x01;
+		bit0 = (color_prom[i + 2*machine->config->total_colors] >> 0) & 0x01;
+		bit1 = (color_prom[i + 2*machine->config->total_colors] >> 1) & 0x01;
+		bit2 = (color_prom[i + 2*machine->config->total_colors] >> 2) & 0x01;
+		bit3 = (color_prom[i + 2*machine->config->total_colors] >> 3) & 0x01;
 		b = 0x0e * bit0 + 0x1f * bit1 + 0x43 * bit2 + 0x8f * bit3;
 
 		palette_set_color(machine,i,MAKE_RGB(r,g,b));
@@ -586,6 +625,47 @@ PALETTE_INIT( RRRR_GGGG_BBBB )
 
 
 
+/*-------------------------------------------------
+    RRRRR_GGGGG_BBBBB/BBBBB_GGGGG_RRRRR -
+    standard 5-5-5 palette for games using a
+    15-bit color space
+-------------------------------------------------*/
+
+PALETTE_INIT( RRRRR_GGGGG_BBBBB )
+{
+	int i;
+
+	for (i = 0; i < 0x8000; i++)
+		palette_set_color(machine, i, MAKE_RGB(pal5bit(i >> 10), pal5bit(i >> 5), pal5bit(i >> 0)));
+}
+
+
+PALETTE_INIT( BBBBB_GGGGG_RRRRR )
+{
+	int i;
+
+	for (i = 0; i < 0x8000; i++)
+		palette_set_color(machine, i, MAKE_RGB(pal5bit(i >> 0), pal5bit(i >> 5), pal5bit(i >> 10)));
+}
+
+
+
+/*-------------------------------------------------
+    RRRRR_GGGGGG_BBBBB -
+    standard 5-6-5 palette for games using a
+    16-bit color space
+-------------------------------------------------*/
+
+PALETTE_INIT( RRRRR_GGGGGG_BBBBB )
+{
+	int i;
+
+	for (i = 0; i < 0x10000; i++)
+		palette_set_color(machine, i, MAKE_RGB(pal5bit(i >> 11), pal6bit(i >> 5), pal5bit(i >> 0)));
+}
+
+
+
 /***************************************************************************
     3-3-2 RGB PALETTE WRITE HANDLERS
 ***************************************************************************/
@@ -597,7 +677,7 @@ PALETTE_INIT( RRRR_GGGG_BBBB )
 WRITE8_HANDLER( paletteram_RRRGGGBB_w )
 {
 	paletteram[offset] = data;
-	palette_set_color_rgb(Machine, offset, pal3bit(data >> 5), pal3bit(data >> 2), pal2bit(data >> 0));
+	palette_set_color_rgb(space->machine, offset, pal3bit(data >> 5), pal3bit(data >> 2), pal2bit(data >> 0));
 }
 
 
@@ -608,7 +688,7 @@ WRITE8_HANDLER( paletteram_RRRGGGBB_w )
 WRITE8_HANDLER( paletteram_BBGGGRRR_w )
 {
 	paletteram[offset] = data;
-	palette_set_color_rgb(Machine, offset, pal3bit(data >> 0), pal3bit(data >> 3), pal2bit(data >> 6));
+	palette_set_color_rgb(space->machine, offset, pal3bit(data >> 0), pal3bit(data >> 3), pal2bit(data >> 6));
 }
 
 
@@ -621,7 +701,7 @@ WRITE8_HANDLER( paletteram_BBGGRRII_w )
 	int i = (data >> 0) & 3;
 
 	paletteram[offset] = data;
-	palette_set_color_rgb(Machine, offset, pal4bit(((data >> 0) & 0x0c) | i),
+	palette_set_color_rgb(space->machine, offset, pal4bit(((data >> 0) & 0x0c) | i),
 	                                   pal4bit(((data >> 2) & 0x0c) | i),
 	                                   pal4bit(((data >> 4) & 0x0c) | i));
 }
@@ -639,31 +719,31 @@ WRITE8_HANDLER( paletteram_BBGGRRII_w )
 WRITE8_HANDLER( paletteram_xxxxBBBBGGGGRRRR_le_w )
 {
 	paletteram[offset] = data;
-	set_color_444(offset / 2, 0, 4, 8, paletteram16_le(offset));
+	set_color_444(space->machine, offset / 2, 0, 4, 8, paletteram16_le(offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxBBBBGGGGRRRR_be_w )
 {
 	paletteram[offset] = data;
-	set_color_444(offset / 2, 0, 4, 8, paletteram16_be(offset));
+	set_color_444(space->machine, offset / 2, 0, 4, 8, paletteram16_be(offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxBBBBGGGGRRRR_split1_w )
 {
 	paletteram[offset] = data;
-	set_color_444(offset, 0, 4, 8, paletteram16_split(offset));
+	set_color_444(space->machine, offset, 0, 4, 8, paletteram16_split(offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxBBBBGGGGRRRR_split2_w )
 {
 	paletteram_2[offset] = data;
-	set_color_444(offset, 0, 4, 8, paletteram16_split(offset));
+	set_color_444(space->machine, offset, 0, 4, 8, paletteram16_split(offset));
 }
 
 WRITE16_HANDLER( paletteram16_xxxxBBBBGGGGRRRR_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	set_color_444(offset, 0, 4, 8, paletteram16[offset]);
+	set_color_444(space->machine, offset, 0, 4, 8, paletteram16[offset]);
 }
 
 
@@ -674,31 +754,31 @@ WRITE16_HANDLER( paletteram16_xxxxBBBBGGGGRRRR_word_w )
 WRITE8_HANDLER( paletteram_xxxxBBBBRRRRGGGG_le_w )
 {
 	paletteram[offset] = data;
-	set_color_444(offset / 2, 4, 0, 8, paletteram16_le(offset));
+	set_color_444(space->machine, offset / 2, 4, 0, 8, paletteram16_le(offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxBBBBRRRRGGGG_be_w )
 {
 	paletteram[offset] = data;
-	set_color_444(offset / 2, 4, 0, 8, paletteram16_be(offset));
+	set_color_444(space->machine, offset / 2, 4, 0, 8, paletteram16_be(offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxBBBBRRRRGGGG_split1_w )
 {
 	paletteram[offset] = data;
-	set_color_444(offset, 4, 0, 8, paletteram16_split(offset));
+	set_color_444(space->machine, offset, 4, 0, 8, paletteram16_split(offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxBBBBRRRRGGGG_split2_w )
 {
 	paletteram_2[offset] = data;
-	set_color_444(offset, 4, 0, 8, paletteram16_split(offset));
+	set_color_444(space->machine, offset, 4, 0, 8, paletteram16_split(offset));
 }
 
 WRITE16_HANDLER( paletteram16_xxxxBBBBRRRRGGGG_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	set_color_444(offset, 4, 0, 8, paletteram16[offset]);
+	set_color_444(space->machine, offset, 4, 0, 8, paletteram16[offset]);
 }
 
 
@@ -709,13 +789,13 @@ WRITE16_HANDLER( paletteram16_xxxxBBBBRRRRGGGG_word_w )
 WRITE8_HANDLER( paletteram_xxxxRRRRBBBBGGGG_split1_w )
 {
 	paletteram[offset] = data;
-	set_color_444(offset, 8, 0, 4, paletteram16_split(offset));
+	set_color_444(space->machine, offset, 8, 0, 4, paletteram16_split(offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxRRRRBBBBGGGG_split2_w )
 {
 	paletteram_2[offset] = data;
-	set_color_444(offset, 8, 0, 4, paletteram16_split(offset));
+	set_color_444(space->machine, offset, 8, 0, 4, paletteram16_split(offset));
 }
 
 
@@ -726,19 +806,19 @@ WRITE8_HANDLER( paletteram_xxxxRRRRBBBBGGGG_split2_w )
 WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_le_w )
 {
 	paletteram[offset] = data;
-	set_color_444(offset / 2, 8, 4, 0, paletteram16_le(offset));
+	set_color_444(space->machine, offset / 2, 8, 4, 0, paletteram16_le(offset));
 }
 
 WRITE8_HANDLER( paletteram_xxxxRRRRGGGGBBBB_be_w )
 {
 	paletteram[offset] = data;
-	set_color_444(offset / 2, 8, 4, 0, paletteram16_be(offset));
+	set_color_444(space->machine, offset / 2, 8, 4, 0, paletteram16_be(offset));
 }
 
 WRITE16_HANDLER( paletteram16_xxxxRRRRGGGGBBBB_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	set_color_444(offset, 8, 4, 0, paletteram16[offset]);
+	set_color_444(space->machine, offset, 8, 4, 0, paletteram16[offset]);
 }
 
 
@@ -749,25 +829,25 @@ WRITE16_HANDLER( paletteram16_xxxxRRRRGGGGBBBB_word_w )
 WRITE8_HANDLER( paletteram_RRRRGGGGBBBBxxxx_be_w )
 {
 	paletteram[offset] = data;
-	set_color_444(offset / 2, 12, 8, 4, paletteram16_be(offset));
+	set_color_444(space->machine, offset / 2, 12, 8, 4, paletteram16_be(offset));
 }
 
 WRITE8_HANDLER( paletteram_RRRRGGGGBBBBxxxx_split1_w )
 {
 	paletteram[offset] = data;
-	set_color_444(offset, 12, 8, 4, paletteram16_split(offset));
+	set_color_444(space->machine, offset, 12, 8, 4, paletteram16_split(offset));
 }
 
 WRITE8_HANDLER( paletteram_RRRRGGGGBBBBxxxx_split2_w )
 {
 	paletteram_2[offset] = data;
-	set_color_444(offset, 12, 8, 4, paletteram16_split(offset));
+	set_color_444(space->machine, offset, 12, 8, 4, paletteram16_split(offset));
 }
 
 WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBxxxx_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	set_color_444(offset, 12, 8, 4, paletteram16[offset]);
+	set_color_444(space->machine, offset, 12, 8, 4, paletteram16[offset]);
 }
 
 
@@ -783,31 +863,31 @@ WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBxxxx_word_w )
 WRITE8_HANDLER( paletteram_xBBBBBGGGGGRRRRR_le_w )
 {
 	paletteram[offset] = data;
-	set_color_555(offset / 2, 0, 5, 10, paletteram16_le(offset));
+	set_color_555(space->machine, offset / 2, 0, 5, 10, paletteram16_le(offset));
 }
 
 WRITE8_HANDLER( paletteram_xBBBBBGGGGGRRRRR_be_w )
 {
 	paletteram[offset] = data;
-	set_color_555(offset / 2, 0, 5, 10, paletteram16_be(offset));
+	set_color_555(space->machine, offset / 2, 0, 5, 10, paletteram16_be(offset));
 }
 
 WRITE8_HANDLER( paletteram_xBBBBBGGGGGRRRRR_split1_w )
 {
 	paletteram[offset] = data;
-	set_color_555(offset, 0, 5, 10, paletteram16_split(offset));
+	set_color_555(space->machine, offset, 0, 5, 10, paletteram16_split(offset));
 }
 
 WRITE8_HANDLER( paletteram_xBBBBBGGGGGRRRRR_split2_w )
 {
 	paletteram_2[offset] = data;
-	set_color_555(offset, 0, 5, 10, paletteram16_split(offset));
+	set_color_555(space->machine, offset, 0, 5, 10, paletteram16_split(offset));
 }
 
 WRITE16_HANDLER( paletteram16_xBBBBBGGGGGRRRRR_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	set_color_555(offset, 0, 5, 10, paletteram16[offset]);
+	set_color_555(space->machine, offset, 0, 5, 10, paletteram16[offset]);
 }
 
 
@@ -818,13 +898,13 @@ WRITE16_HANDLER( paletteram16_xBBBBBGGGGGRRRRR_word_w )
 WRITE8_HANDLER( paletteram_xBBBBBRRRRRGGGGG_split1_w )
 {
 	paletteram[offset] = data;
-	set_color_555(offset, 5, 0, 10, paletteram16_split(offset));
+	set_color_555(space->machine, offset, 5, 0, 10, paletteram16_split(offset));
 }
 
 WRITE8_HANDLER( paletteram_xBBBBBRRRRRGGGGG_split2_w )
 {
 	paletteram_2[offset] = data;
-	set_color_555(offset, 5, 0, 10, paletteram16_split(offset));
+	set_color_555(space->machine, offset, 5, 0, 10, paletteram16_split(offset));
 }
 
 
@@ -835,13 +915,25 @@ WRITE8_HANDLER( paletteram_xBBBBBRRRRRGGGGG_split2_w )
 WRITE8_HANDLER( paletteram_xRRRRRGGGGGBBBBB_le_w )
 {
 	paletteram[offset] = data;
-	set_color_555(offset / 2, 10, 5, 0, paletteram16_le(offset));
+	set_color_555(space->machine, offset / 2, 10, 5, 0, paletteram16_le(offset));
+}
+
+WRITE8_HANDLER( paletteram_xRRRRRGGGGGBBBBB_split1_w )
+{
+	paletteram[offset] = data;
+	set_color_555(space->machine, offset, 10, 5, 0, paletteram16_split(offset));
+}
+
+WRITE8_HANDLER( paletteram_xRRRRRGGGGGBBBBB_split2_w )
+{
+	paletteram_2[offset] = data;
+	set_color_555(space->machine, offset, 10, 5, 0, paletteram16_split(offset));
 }
 
 WRITE16_HANDLER( paletteram16_xRRRRRGGGGGBBBBB_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	set_color_555(offset, 10, 5, 0, paletteram16[offset]);
+	set_color_555(space->machine, offset, 10, 5, 0, paletteram16[offset]);
 }
 
 
@@ -852,7 +944,7 @@ WRITE16_HANDLER( paletteram16_xRRRRRGGGGGBBBBB_word_w )
 WRITE16_HANDLER( paletteram16_xGGGGGRRRRRBBBBB_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	set_color_555(offset, 5, 10, 0, paletteram16[offset]);
+	set_color_555(space->machine, offset, 5, 10, 0, paletteram16[offset]);
 }
 
 
@@ -863,10 +955,20 @@ WRITE16_HANDLER( paletteram16_xGGGGGRRRRRBBBBB_word_w )
 WRITE16_HANDLER( paletteram16_xGGGGGBBBBBRRRRR_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	set_color_555(offset, 0, 10, 5, paletteram16[offset]);
+	set_color_555(space->machine, offset, 0, 10, 5, paletteram16[offset]);
 }
 
 
+/*-------------------------------------------------
+    GGGGG-RRRRR-BBBBB-x writes
+-------------------------------------------------*/
+
+WRITE16_HANDLER( paletteram16_GGGGGRRRRRBBBBBx_word_w )
+{
+	COMBINE_DATA(&paletteram16[offset]);
+	set_color_555(space->machine, offset, 6, 11, 1, paletteram16[offset]);
+}
+
 /*-------------------------------------------------
     RRRRR-GGGGG-BBBBB-x writes
 -------------------------------------------------*/
@@ -874,7 +976,7 @@ WRITE16_HANDLER( paletteram16_xGGGGGBBBBBRRRRR_word_w )
 WRITE16_HANDLER( paletteram16_RRRRRGGGGGBBBBBx_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	set_color_555(offset, 11, 6, 1, paletteram16[offset]);
+	set_color_555(space->machine, offset, 11, 6, 1, paletteram16[offset]);
 }
 
 
@@ -886,7 +988,7 @@ WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBRGBx_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
 	data = paletteram16[offset];
-	palette_set_color_rgb(Machine, offset, pal5bit(((data >> 11) & 0x1e) | ((data >> 3) & 0x01)),
+	palette_set_color_rgb(space->machine, offset, pal5bit(((data >> 11) & 0x1e) | ((data >> 3) & 0x01)),
 	                                       pal5bit(((data >>  7) & 0x1e) | ((data >> 2) & 0x01)),
 	                                       pal5bit(((data >>  3) & 0x1e) | ((data >> 1) & 0x01)));
 }
@@ -904,7 +1006,7 @@ WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBRGBx_word_w )
 WRITE16_HANDLER( paletteram16_IIIIRRRRGGGGBBBB_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	set_color_4444(offset, 12, 8, 4, 0, paletteram16[offset]);
+	set_color_4444(space->machine, offset, 12, 8, 4, 0, paletteram16[offset]);
 }
 
 
@@ -915,7 +1017,7 @@ WRITE16_HANDLER( paletteram16_IIIIRRRRGGGGBBBB_word_w )
 WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBIIII_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	set_color_4444(offset, 0, 12, 8, 4, paletteram16[offset]);
+	set_color_4444(space->machine, offset, 0, 12, 8, 4, paletteram16[offset]);
 }
 
 
@@ -931,7 +1033,7 @@ WRITE16_HANDLER( paletteram16_RRRRGGGGBBBBIIII_word_w )
 WRITE16_HANDLER( paletteram16_xrgb_word_be_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	set_color_888(offset / 2, 16, 8, 0, paletteram32_be(offset));
+	set_color_888(space->machine, offset / 2, 16, 8, 0, paletteram32_be(offset));
 }
 
 
@@ -942,5 +1044,5 @@ WRITE16_HANDLER( paletteram16_xrgb_word_be_w )
 WRITE16_HANDLER( paletteram16_xbgr_word_be_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	set_color_888(offset / 2, 0, 8, 16, paletteram32_be(offset));
+	set_color_888(space->machine, offset / 2, 0, 8, 16, paletteram32_be(offset));
 }
