@@ -100,17 +100,17 @@ static const rgb_t TMS9928A_palette[16] =
 /*
 ** Forward declarations of internal functions.
 */
-static void draw_mode0 (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect);
-static void draw_mode1 (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect);
-static void draw_mode2 (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect);
-static void draw_mode12 (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect);
-static void draw_mode3 (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect);
-static void draw_mode23 (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect);
-static void draw_modebogus (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect);
-static void draw_sprites (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect);
-static void change_register (int reg, UINT8 data);
+static void draw_mode0 (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_mode1 (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_mode2 (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_mode12 (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_mode3 (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_mode23 (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_modebogus (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect);
+static void draw_sprites (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect);
+static void change_register (running_machine *machine, int reg, UINT8 data);
 
-static void (*const ModeHandlers[])(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect) = {
+static void (*const ModeHandlers[])(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect) = {
         draw_mode0, draw_mode1, draw_mode2,  draw_mode12,
         draw_mode3, draw_modebogus, draw_mode23,
         draw_modebogus };
@@ -138,10 +138,10 @@ typedef struct {
     INT32 Addr;
     int colour,pattern,nametbl,spriteattribute,spritepattern;
     int colourmask,patternmask;
-    void (*INTCallback)(int);
+    void (*INTCallback)(running_machine *, int);
     /* memory */
     UINT8 *vMem, *dBackMem;
-    mame_bitmap *tmpbmp;
+    bitmap_t *tmpbmp;
     int vramsize, model;
     /* emulation settings */
     int LimitSprites; /* max 4 sprites on a row, like original TMS9918A */
@@ -194,8 +194,9 @@ static void TMS9928A_start (running_machine *machine, const TMS9928a_interface *
 	tms.visarea.max_y = tms.top_border + 24*8 - 1 + MIN(intf->bordery, tms.bottom_border);
 
 	/* configure the screen if we weren't overridden */
-	if (machine->screen[0].width == LEFT_BORDER+32*8+RIGHT_BORDER && machine->screen[0].height == TOP_BORDER_60HZ+24*8+BOTTOM_BORDER_60HZ)
-		video_screen_configure(0, LEFT_BORDER + 32*8 + RIGHT_BORDER, tms.top_border + 24*8 + tms.bottom_border, &tms.visarea, machine->screen[0].refresh);
+	if (video_screen_get_width(machine->primary_screen) == LEFT_BORDER+32*8+RIGHT_BORDER &&
+	    video_screen_get_height(machine->primary_screen) == TOP_BORDER_60HZ+24*8+BOTTOM_BORDER_60HZ)
+		video_screen_configure(machine->primary_screen, LEFT_BORDER + 32*8 + RIGHT_BORDER, tms.top_border + 24*8 + tms.bottom_border, &tms.visarea, video_screen_get_frame_period(machine->primary_screen).attoseconds);
 
     /* Video RAM */
     tms.vramsize = intf->vram;
@@ -206,26 +207,26 @@ static void TMS9928A_start (running_machine *machine, const TMS9928a_interface *
     tms.dBackMem = (UINT8*)auto_malloc (IMAGE_SIZE);
 
     /* back bitmap */
-    tms.tmpbmp = auto_bitmap_alloc (256, 192, machine->screen[0].format);
+    tms.tmpbmp = auto_bitmap_alloc (256, 192, video_screen_get_format(machine->primary_screen));
 
     TMS9928A_reset ();
     tms.LimitSprites = 1;
 
-	state_save_register_item("tms9928a", 0, tms.Regs[0]);
-	state_save_register_item("tms9928a", 0, tms.Regs[1]);
-	state_save_register_item("tms9928a", 0, tms.Regs[2]);
-	state_save_register_item("tms9928a", 0, tms.Regs[3]);
-	state_save_register_item("tms9928a", 0, tms.Regs[4]);
-	state_save_register_item("tms9928a", 0, tms.Regs[5]);
-	state_save_register_item("tms9928a", 0, tms.Regs[6]);
-	state_save_register_item("tms9928a", 0, tms.Regs[7]);
-	state_save_register_item("tms9928a", 0, tms.StatusReg);
-	state_save_register_item("tms9928a", 0, tms.ReadAhead);
-	state_save_register_item("tms9928a", 0, tms.FirstByte);
-	state_save_register_item("tms9928a", 0, tms.latch);
-	state_save_register_item("tms9928a", 0, tms.Addr);
-	state_save_register_item("tms9928a", 0, tms.INT);
-	state_save_register_item_pointer("tms9928a", 0, tms.vMem, intf->vram);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.Regs[0]);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.Regs[1]);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.Regs[2]);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.Regs[3]);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.Regs[4]);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.Regs[5]);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.Regs[6]);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.Regs[7]);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.StatusReg);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.ReadAhead);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.FirstByte);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.latch);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.Addr);
+	state_save_register_item(machine, "tms9928a", NULL, 0, tms.INT);
+	state_save_register_item_pointer(machine, "tms9928a", NULL, 0, tms.vMem, intf->vram);
 }
 
 const rectangle *TMS9928A_get_visarea (void)
@@ -234,15 +235,15 @@ const rectangle *TMS9928A_get_visarea (void)
 }
 
 
-void TMS9928A_post_load (void) {
+void TMS9928A_post_load (running_machine *machine) {
 	int i;
 
 	/* all registers need to be re-written, so tables are recalculated */
 	for (i=0;i<8;i++)
-		change_register (i, tms.Regs[i]);
+		change_register (machine, i, tms.Regs[i]);
 
 	/* make sure the interrupt request is set properly */
-	if (tms.INTCallback) tms.INTCallback (tms.INT);
+	if (tms.INTCallback) tms.INTCallback (machine, tms.INT);
 }
 
 
@@ -272,7 +273,7 @@ READ8_HANDLER (TMS9928A_register_r) {
     tms.StatusReg = 0x1f;
     if (tms.INT) {
         tms.INT = 0;
-        if (tms.INTCallback) tms.INTCallback (tms.INT);
+        if (tms.INTCallback) tms.INTCallback (space->machine, tms.INT);
     }
     tms.latch = 0;
     return b;
@@ -286,13 +287,13 @@ WRITE8_HANDLER (TMS9928A_register_w) {
             /* register write */
 			reg = data & 7;
 			/*if (tms.FirstByte != tms.Regs[reg])*/ /* Removed to fix ColecoVision MESS Driver*/
-	            change_register (reg, tms.FirstByte);
+	            change_register (space->machine, reg, tms.FirstByte);
         } else {
             /* set read/write address */
             tms.Addr = ((UINT16)data << 8 | tms.FirstByte) & (tms.vramsize - 1);
             if ( !(data & 0x40) ) {
 				/* read ahead */
-				TMS9928A_vram_r	(0);
+				TMS9928A_vram_r	(space,0);
             }
         }
         tms.latch = 0;
@@ -302,7 +303,7 @@ WRITE8_HANDLER (TMS9928A_register_w) {
     }
 }
 
-static void change_register (int reg, UINT8 val) {
+static void change_register (running_machine *machine, int reg, UINT8 val) {
     static const UINT8 Mask[8] =
         { 0x03, 0xfb, 0x0f, 0xff, 0x07, 0x7f, 0x07, 0xff };
     static const char *const modes[] = {
@@ -336,7 +337,7 @@ static void change_register (int reg, UINT8 val) {
         b = (val & 0x20) && (tms.StatusReg & 0x80) ;
         if (b != tms.INT) {
             tms.INT = b;
-            if (tms.INTCallback) tms.INTCallback (tms.INT);
+            if (tms.INTCallback) tms.INTCallback (machine, tms.INT);
         }
         logerror("TMS9928A: %s\n", modes[TMS_MODE]);
         break;
@@ -376,9 +377,11 @@ static void change_register (int reg, UINT8 val) {
 ** Interface functions
 */
 
-/*void TMS9928A_int_callback (void (*callback)(int)) {
+#ifdef UNUSED_FUNCTION
+void TMS9928A_int_callback (void (*callback)(int)) {
     tms.INTCallback = callback;
-}*/
+}
+#endif
 
 void TMS9928A_set_spriteslimit (int limit) {
     tms.LimitSprites = limit;
@@ -389,14 +392,19 @@ void TMS9928A_set_spriteslimit (int limit) {
 */
 VIDEO_UPDATE( tms9928a )
 {
-    INT32 BackColour = tms.Regs[7] & 15; if (!BackColour) BackColour=1;
-    palette_set_color(machine, 0, TMS9928A_palette[BackColour]);
+    INT32 BackColour = tms.Regs[7] & 15;
+    rgb_t oldcolor = palette_get_color(screen->machine, 0);
+
+ 	if (!BackColour) BackColour=1;
+ 	/* note we preserve the alpha here; this is so that it can be controlled independently */
+ 	/* see cliffhgr.c for an example */
+    palette_set_color(screen->machine, 0, (TMS9928A_palette[BackColour] & MAKE_ARGB(0,255,255,255)) | (oldcolor & MAKE_ARGB(255,0,0,0)));
 
 	if (! (tms.Regs[1] & 0x40))
-		fillbitmap(bitmap, machine->pens[BackColour], cliprect);
+		bitmap_fill(bitmap, cliprect, screen->machine->pens[BackColour]);
 	else
 	{
-		(*ModeHandlers[TMS_MODE])(machine, tms.tmpbmp, cliprect);
+		(*ModeHandlers[TMS_MODE])(screen->machine, tms.tmpbmp, cliprect);
 
 		copybitmap(bitmap, tms.tmpbmp, 0, 0, LEFT_BORDER, TOP_BORDER, cliprect);
 		{
@@ -405,24 +413,24 @@ VIDEO_UPDATE( tms9928a )
 			/* set borders */
 			rt.min_x = 0; rt.max_x = LEFT_BORDER+256+RIGHT_BORDER-1;
 			rt.min_y = 0; rt.max_y = TOP_BORDER-1;
-			fillbitmap (bitmap, BackColour, &rt);
+			bitmap_fill (bitmap, &rt, BackColour);
 			rt.min_y = TOP_BORDER+192; rt.max_y = TOP_BORDER+192+BOTTOM_BORDER-1;
-			fillbitmap (bitmap, BackColour, &rt);
+			bitmap_fill (bitmap, &rt, BackColour);
 
 			rt.min_y = TOP_BORDER; rt.max_y = TOP_BORDER+192-1;
 			rt.min_x = 0; rt.max_x = LEFT_BORDER-1;
-			fillbitmap (bitmap, BackColour, &rt);
+			bitmap_fill (bitmap, &rt, BackColour);
 			rt.min_x = LEFT_BORDER+256; rt.max_x = LEFT_BORDER+256+RIGHT_BORDER-1;
-			fillbitmap (bitmap, BackColour, &rt);
+			bitmap_fill (bitmap, &rt, BackColour);
 	    }
 		if (TMS_SPRITES_ENABLED)
-			draw_sprites(machine, bitmap, cliprect);
+			draw_sprites(screen->machine, bitmap, cliprect);
 	}
 
 	return 0;
 }
 
-int TMS9928A_interrupt () {
+int TMS9928A_interrupt(running_machine *machine) {
     int b;
 
     /* when skipping frames, calculate sprite collision */
@@ -436,13 +444,13 @@ int TMS9928A_interrupt () {
     b = (tms.Regs[1] & 0x20) != 0;
     if (b != tms.INT) {
         tms.INT = b;
-        if (tms.INTCallback) tms.INTCallback (tms.INT);
+        if (tms.INTCallback) tms.INTCallback (machine, tms.INT);
     }
 
     return b;
 }
 
-static void draw_mode1 (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect) {
+static void draw_mode1 (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect) {
     int pattern,x,y,yy,xx,name,charcode;
     UINT8 fg,bg,*patternptr;
 	rectangle rt;
@@ -453,10 +461,10 @@ static void draw_mode1 (running_machine *machine, mame_bitmap *bitmap, const rec
 	/* colours at sides must be reset */
 	rt.min_y = 0; rt.max_y = 191;
 	rt.min_x = 0; rt.max_x = 7;
-	fillbitmap (bitmap, bg, &rt);
+	bitmap_fill (bitmap, &rt, bg);
 	rt.min_y = 0; rt.max_y = 191;
 	rt.min_x = 248; rt.max_x = 255;
-	fillbitmap (bitmap, bg, &rt);
+	bitmap_fill (bitmap, &rt, bg);
 
     name = 0;
     for (y=0;y<24;y++) {
@@ -475,7 +483,7 @@ static void draw_mode1 (running_machine *machine, mame_bitmap *bitmap, const rec
     }
 }
 
-static void draw_mode12 (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect) {
+static void draw_mode12 (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect) {
     int pattern,x,y,yy,xx,name,charcode;
     UINT8 fg,bg,*patternptr;
 	rectangle rt;
@@ -486,10 +494,10 @@ static void draw_mode12 (running_machine *machine, mame_bitmap *bitmap, const re
 	/* colours at sides must be reset */
 	rt.min_y = 0; rt.max_y = 191;
 	rt.min_x = 0; rt.max_x = 7;
-	fillbitmap (bitmap, bg, &rt);
+	bitmap_fill (bitmap, &rt, bg);
 	rt.min_y = 0; rt.max_y = 191;
 	rt.min_x = 248; rt.max_x = 255;
-	fillbitmap (bitmap, bg, &rt);
+	bitmap_fill (bitmap, &rt, bg);
 
     name = 0;
     for (y=0;y<24;y++) {
@@ -508,7 +516,7 @@ static void draw_mode12 (running_machine *machine, mame_bitmap *bitmap, const re
     }
 }
 
-static void draw_mode0 (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect) {
+static void draw_mode0 (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect) {
     int pattern,x,y,yy,xx,name,charcode,colour;
     UINT8 fg,bg,*patternptr;
 
@@ -532,7 +540,7 @@ static void draw_mode0 (running_machine *machine, mame_bitmap *bitmap, const rec
     }
 }
 
-static void draw_mode2 (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect) {
+static void draw_mode2 (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect) {
     int colour,name,x,y,yy,pattern,xx,charcode;
     UINT8 fg,bg;
     UINT8 *colourptr,*patternptr;
@@ -560,7 +568,7 @@ static void draw_mode2 (running_machine *machine, mame_bitmap *bitmap, const rec
     }
 }
 
-static void draw_mode3 (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect) {
+static void draw_mode3 (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect) {
     int x,y,yy,yyy,name,charcode;
     UINT8 fg,bg,*patternptr;
 
@@ -588,7 +596,7 @@ static void draw_mode3 (running_machine *machine, mame_bitmap *bitmap, const rec
     }
 }
 
-static void draw_mode23 (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect) {
+static void draw_mode23 (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect) {
     int x,y,yy,yyy,name,charcode;
     UINT8 fg,bg,*patternptr;
 
@@ -617,7 +625,7 @@ static void draw_mode23 (running_machine *machine, mame_bitmap *bitmap, const re
     }
 }
 
-static void draw_modebogus (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect) {
+static void draw_modebogus (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect) {
     UINT8 fg,bg;
     int x,y,n,xx;
 
@@ -644,7 +652,7 @@ static void draw_modebogus (running_machine *machine, mame_bitmap *bitmap, const
 **
 ** This code should be optimized. One day.
 */
-static void draw_sprites (running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect) {
+static void draw_sprites (running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect) {
     UINT8 *attributeptr,*patternptr,c;
     int p,x,y,size,i,j,large,yy,xx,limit[192],
         illegalsprite,illegalspriteline;
@@ -795,7 +803,9 @@ VIDEO_START( tms9928a )
 MACHINE_DRIVER_START( tms9928a )
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK | VIDEO_TYPE_RASTER)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
+
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(LEFT_BORDER+32*8+RIGHT_BORDER, TOP_BORDER_60HZ+24*8+BOTTOM_BORDER_60HZ)
 	MDRV_SCREEN_VISIBLE_AREA(LEFT_BORDER-12, LEFT_BORDER+32*8+12-1, TOP_BORDER_60HZ-9, TOP_BORDER_60HZ+24*8+9-1)
