@@ -290,6 +290,30 @@ astring *astring_substr(astring *str, int start, int count)
 }
 
 
+/*-------------------------------------------------
+    astring_del - delete a substring of
+    ourself, keeping everything else
+-------------------------------------------------*/
+
+astring *astring_del(astring *str, int start, int count)
+{
+	int strlength = strlen(str->text);
+
+	/* ignore attempts to do this on the dummy */
+	if (str == &dummy_astring)
+		return str;
+
+	/* normalize parameters */
+	normalize_substr(&start, &count, strlength);
+
+	/* move the data and NULL-terminate */
+	if (count > 0)
+		memmove(str->text + start, str->text + start + count, strlength - (start + count));
+	str->text[strlength - count] = 0;
+	return str;
+}
+
+
 /*-------------------------------------------------
     astring_printf - printf text into an astring
 -------------------------------------------------*/
@@ -311,6 +335,65 @@ int astring_printf(astring *dst, const char *format, ...)
 }
 
 
+/*-------------------------------------------------
+    astring_vprintf - vprintf text into an astring
+-------------------------------------------------*/
+
+int astring_vprintf(astring *dst, const char *format, va_list args)
+{
+	char tempbuf[4096];
+	int result;
+
+	/* sprintf into the temporary buffer */
+	result = vsprintf(tempbuf, format, args);
+
+	/* set the result */
+	astring_cpyc(dst, tempbuf);
+	return result;
+}
+
+
+/*-------------------------------------------------
+    astring_catprintf - formatted printf to
+    the end of an astring
+-------------------------------------------------*/
+
+int astring_catprintf(astring *dst, const char *format, ...)
+{
+	char tempbuf[4096];
+	va_list args;
+	int result;
+
+	/* sprintf into the temporary buffer */
+	va_start(args, format);
+	result = vsprintf(tempbuf, format, args);
+	va_end(args);
+
+	/* append the result */
+	astring_catc(dst, tempbuf);
+	return result;
+}
+
+
+/*-------------------------------------------------
+    astring_catprintf - formatted vprintf to
+    the end of an astring
+-------------------------------------------------*/
+
+int astring_catvprintf(astring *dst, const char *format, va_list args)
+{
+	char tempbuf[4096];
+	int result;
+
+	/* sprintf into the temporary buffer */
+	result = vsprintf(tempbuf, format, args);
+
+	/* append the result */
+	astring_catc(dst, tempbuf);
+	return result;
+}
+
+
 
 /***************************************************************************
     ASTRING QUERIES
@@ -498,6 +581,41 @@ int astring_findc(const astring *str, int start, const char *search)
 }
 
 
+/*-------------------------------------------------
+    astring_replace - search in an astring for
+    another astring, replacing all instances with
+    a third and returning the number of matches
+-------------------------------------------------*/
+
+int astring_replace(astring *str, int start, const astring *search, const astring *replace)
+{
+	return astring_replacec(str, start, search->text, replace->text);
+}
+
+
+/*-------------------------------------------------
+    astring_replacec - search in an astring for a
+    C string, replacing all instances with another
+    C string and returning the number of matches
+-------------------------------------------------*/
+
+int astring_replacec(astring *str, int start, const char *search, const char *replace)
+{
+	int searchlen = strlen(search);
+	int replacelen = strlen(replace);
+	int matches = 0;
+	int curindex;
+
+	for (curindex = astring_findc(str, start, search); curindex != -1; curindex = astring_findc(str, curindex + replacelen, search))
+	{
+		matches++;
+		astring_del(str, curindex, searchlen);
+		astring_insc(str, curindex, replace);
+	}
+	return matches;
+}
+
+
 
 /***************************************************************************
     ASTRING UTILITIES
@@ -566,7 +684,7 @@ astring *astring_tolower(astring *str)
 {
 	char *text;
 
-	/* just toupper() on all characters */
+	/* just tolower() on all characters */
 	for (text = str->text; *text != 0; text++)
 		*text = tolower(*text);
 
@@ -584,11 +702,11 @@ astring *astring_trimspace(astring *str)
 	char *ptr;
 
 	/* first remove stuff from the end */
-	for (ptr = str->text + strlen(str->text) - 1; ptr >= str->text && isspace(*ptr); ptr--)
+	for (ptr = str->text + strlen(str->text) - 1; ptr >= str->text && (!(*ptr & 0x80) && isspace(*ptr)); ptr--)
 		*ptr = 0;
 
 	/* then count how much to remove from the beginning */
-	for (ptr = str->text; *ptr != 0 && isspace(*ptr); ptr++) ;
+	for (ptr = str->text; *ptr != 0 && (!(*ptr & 0x80) && isspace(*ptr)); ptr++) ;
 	if (ptr > str->text)
 		astring_substr(str, ptr - str->text, -1);
 
