@@ -52,11 +52,6 @@
 #define HANDLER_DIB				AVI_FOURCC('D','I','B',' ')
 #define HANDLER_HFYU			AVI_FOURCC('h','f','y','u')
 
-#define FORMAT_UYVY				AVI_FOURCC('U','Y','V','Y')
-#define FORMAT_VYUY				AVI_FOURCC('V','Y','U','Y')
-#define FORMAT_YUY2				AVI_FOURCC('Y','U','Y','2')
-#define FORMAT_HFYU				AVI_FOURCC('H','F','Y','U')
-
 /* main AVI header files */
 #define AVIF_HASINDEX			0x00000010
 #define AVIF_MUSTUSEINDEX		0x00000020
@@ -224,6 +219,9 @@ static avi_error soundbuf_initialize(avi_file *file);
 static avi_error soundbuf_write_chunk(avi_file *file, UINT32 framenum);
 static avi_error soundbuf_flush(avi_file *file, int only_flush_full);
 
+/* RGB helpers */
+static avi_error rgb32_compress_to_rgb(avi_stream *stream, const bitmap_t *bitmap, UINT8 *data, UINT32 numbytes);
+
 /* YUY helpers */
 static avi_error yuv_decompress_to_yuy16(avi_stream *stream, const UINT8 *data, UINT32 numbytes, bitmap_t *bitmap);
 static avi_error yuy16_compress_to_yuy(avi_stream *stream, const bitmap_t *bitmap, UINT8 *data, UINT32 numbytes);
@@ -645,14 +643,6 @@ avi_error avi_close(avi_file *file)
 		if (avierr == AVIERR_NONE && file->riffbase == 0)
 			avierr = write_idx1_chunk(file);
 
-		/* close the RIFF chunk */
-		if (avierr == AVIERR_NONE)
-			avierr = chunk_close(file);
-
-		/* update the avih chunk */
-		if (avierr == AVIERR_NONE)
-			avierr = write_avih_chunk(file, FALSE);
-
 		/* update the strh and indx chunks for each stream */
 		for (strnum = 0; strnum < file->streams; strnum++)
 		{
@@ -661,6 +651,14 @@ avi_error avi_close(avi_file *file)
 			if (avierr == AVIERR_NONE)
 				avierr = write_indx_chunk(file, &file->stream[strnum], FALSE);
 		}
+
+		/* update the avih chunk */
+		if (avierr == AVIERR_NONE)
+			avierr = write_avih_chunk(file, FALSE);
+
+		/* close the RIFF chunk */
+		if (avierr == AVIERR_NONE)
+			avierr = chunk_close(file);
 	}
 
 	/* close the file */
@@ -865,6 +863,13 @@ avi_error avi_read_sound_samples(avi_file *file, int channel, UINT32 firstsample
 			chunkbase = chunkend;
 		}
 
+		/* if we hit the end, fill the rest with silence */
+		if (chunknum == stream->chunks)
+		{
+			memset(output, 0, numsamples * 2);
+			break;
+		}
+
 		/* expand the tempbuffer to hold the data if necessary */
 		avierr = expand_tempbuffer(file, stream->chunk[chunknum].length);
 		if (avierr != AVIERR_NONE)
@@ -928,6 +933,10 @@ avi_error avi_append_video_frame_yuy16(avi_file *file, const bitmap_t *bitmap)
 	avi_error avierr;
 	UINT32 maxlength;
 
+	/* validate our ability to handle the data */
+	if (stream->format != FORMAT_UYVY && stream->format != FORMAT_VYUY && stream->format != FORMAT_YUY2 && stream->format != FORMAT_HFYU)
+		return AVIERR_UNSUPPORTED_VIDEO_FORMAT;
+
 	/* double check bitmap format */
 	if (bitmap->format != BITMAP_FORMAT_YUY16)
 		return AVIERR_INVALID_BITMAP;
@@ -959,12 +968,62 @@ avi_error avi_append_video_frame_yuy16(avi_file *file, const bitmap_t *bitmap)
 }
 
 
+/*-------------------------------------------------
+    avi_append_video_frame_rgb32 - append a frame
+    of video in RGB32 format
+-------------------------------------------------*/
+
+avi_error avi_append_video_frame_rgb32(avi_file *file, const bitmap_t *bitmap)
+{
+	avi_stream *stream = get_video_stream(file);
+	avi_error avierr;
+	UINT32 maxlength;
+
+	/* validate our ability to handle the data */
+	if (stream->format != 0)
+		return AVIERR_UNSUPPORTED_VIDEO_FORMAT;
+
+	/* depth must be 24 */
+	if (stream->depth != 24)
+		return AVIERR_UNSUPPORTED_VIDEO_FORMAT;
+
+	/* double check bitmap format */
+	if (bitmap->format != BITMAP_FORMAT_RGB32)
+		return AVIERR_INVALID_BITMAP;
+
+	/* write out any sound data first */
+	avierr = soundbuf_write_chunk(file, stream->chunks);
+	if (avierr != AVIERR_NONE)
+		return avierr;
+
+	/* make sure we have enough room */
+	maxlength = 3 * stream->width * stream->height;
+	avierr = expand_tempbuffer(file, maxlength);
+	if (avierr != AVIERR_NONE)
+		return avierr;
+
+	/* copy the RGB data to the destination */
+	avierr = rgb32_compress_to_rgb(stream, bitmap, file->tempbuffer, maxlength);
+	if (avierr != AVIERR_NONE)
+		return avierr;
+
+	/* set the info for this new chunk */
+	avierr = set_stream_chunk_info(stream, stream->chunks, file->writeoffs, maxlength + 8);
+	if (avierr != AVIERR_NONE)
+		return avierr;
+	stream->samples = file->info.video_numsamples = stream->chunks;
+
+	/* write the data */
+	return chunk_write(file, get_chunkid_for_stream(file, stream), file->tempbuffer, maxlength);
+}
+
+
 /*-------------------------------------------------
     avi_append_sound_samples - append sound
     samples
 -------------------------------------------------*/
 
-avi_error avi_append_sound_samples(avi_file *file, int channel, const INT16 *samples, UINT32 numsamples)
+avi_error avi_append_sound_samples(avi_file *file, int channel, const INT16 *samples, UINT32 numsamples, UINT32 sampleskip)
 {
 	UINT32 sampoffset = file->soundbuf_chansamples[channel];
 	UINT32 sampnum;
@@ -977,6 +1036,7 @@ avi_error avi_append_sound_samples(avi_file *file, int channel, const INT16 *sam
 	for (sampnum = 0; sampnum < numsamples; sampnum++)
 	{
 		INT16 data = *samples++;
+		samples += sampleskip;
 		data = LITTLE_ENDIANIZE_INT16(data);
 		file->soundbuf[sampoffset++ * file->info.audio_channels + channel] = data;
 	}
@@ -1656,11 +1716,18 @@ static avi_error chunk_write(avi_file *file, UINT32 type, const void *data, UINT
 {
 	file_error filerr;
 	avi_error avierr;
+	UINT32 idxreserve;
 	UINT32 written;
 
+	/* if we are the first RIFF, we must reserve enough space for the IDX chunk */
+	idxreserve = 0;
+	if (file->riffbase == 0 && type != CHUNKTYPE_IDX1)
+		idxreserve = compute_idx1_size(file);
+
 	/* if we are getting too big, split the RIFF */
-	if ((file->riffbase == 0 && file->writeoffs + length + compute_idx1_size(file) >= MAX_RIFF_SIZE) ||
-		file->writeoffs + length - file->riffbase >= MAX_RIFF_SIZE)
+	/* note that we ignore writes before the current RIFF base, as those are assumed to be
+       overwrites of a chunk from the previous RIFF */
+	if (file->writeoffs >= file->riffbase && file->writeoffs + length + idxreserve - file->riffbase >= MAX_RIFF_SIZE)
 	{
 		/* close the movi list */
 		avierr = chunk_close(file);
@@ -2239,6 +2306,57 @@ static avi_error soundbuf_flush(avi_file *file, int only_flush_full)
 }
 
 
+/*-------------------------------------------------
+    rgb32_compress_to_rgb - "compress" an RGB32
+    bitmap to an RGB encoded frame
+-------------------------------------------------*/
+
+static avi_error rgb32_compress_to_rgb(avi_stream *stream, const bitmap_t *bitmap, UINT8 *data, UINT32 numbytes)
+{
+	int height = MIN(stream->height, bitmap->height);
+	int width = MIN(stream->width, bitmap->width);
+	UINT8 *dataend = data + numbytes;
+	int x, y;
+
+	/* compressed video */
+	for (y = 0; y < height; y++)
+	{
+		const UINT32 *source = (UINT32 *)bitmap->base + y * bitmap->rowpixels;
+		UINT8 *dest = data + (stream->height - 1 - y) * stream->width * 3;
+
+		for (x = 0; x < width && dest < dataend; x++)
+		{
+			UINT32 pix = *source++;
+			*dest++ = RGB_BLUE(pix);
+			*dest++ = RGB_GREEN(pix);
+			*dest++ = RGB_RED(pix);
+		}
+
+		/* fill in any blank space on the right */
+		for ( ; x < stream->width && dest < dataend; x++)
+		{
+			*dest++ = 0;
+			*dest++ = 0;
+			*dest++ = 0;
+		}
+	}
+
+	/* fill in any blank space on the bottom */
+	for ( ; y < stream->height; y++)
+	{
+		UINT8 *dest = data + (stream->height - 1 - y) * stream->width * 3;
+		for (x = 0; x < stream->width && dest < dataend; x++)
+		{
+			*dest++ = 0;
+			*dest++ = 0;
+			*dest++ = 0;
+		}
+	}
+
+	return AVIERR_NONE;
+}
+
+
 /*-------------------------------------------------
     yuv_decompress_to_yuy16 - decompress a YUV
     encoded frame to a YUY16 bitmap
@@ -2475,7 +2593,7 @@ static avi_error huffyuv_decompress_to_yuy16(avi_stream *stream, const UINT8 *da
 	/* compressed video */
 	for (y = 0; y < stream->height; y++)
 	{
-		UINT16 *dest = (UINT16 *)bitmap->base + y * bitmap->rowpixels;
+		UINT16 *dest = BITMAP_ADDR16(bitmap, y, 0);
 
 		/* handle the first four bytes independently */
 		x = 0;
@@ -2560,19 +2678,26 @@ static avi_error huffyuv_decompress_to_yuy16(avi_stream *stream, const UINT8 *da
 	}
 
 	/* apply deltas */
-	lasty = lastcb = lastcr = 0;
 	lastprevy = lastprevcb = lastprevcr = 0;
 	for (y = 0; y < stream->height; y++)
 	{
-		UINT16 *dest = (UINT16 *)bitmap->base + y * bitmap->rowpixels;
-		UINT16 *prevrow = dest - prevlines * bitmap->rowpixels;
+		UINT16 *prevrow = BITMAP_ADDR16(bitmap, y - prevlines, 0);
+		UINT16 *dest = BITMAP_ADDR16(bitmap, y, 0);
+
+		/* handle the first four bytes independently */
+		x = 0;
+		if (y == 0)
+		{
+			/* lasty, lastcr, lastcb are set up previously */
+			x = 2;
+		}
 
 		/* left predict or gradient predict */
 		if ((huffyuv->predictor & ~HUFFYUV_PREDICT_DECORR) == HUFFYUV_PREDICT_LEFT ||
 			((huffyuv->predictor & ~HUFFYUV_PREDICT_DECORR) == HUFFYUV_PREDICT_GRADIENT))
 		{
 			/* first do left deltas */
-			for (x = 0; x < stream->width; x += 2)
+			for ( ; x < stream->width; x += 2)
 			{
 				UINT16 pixel0 = dest[x + 0];
 				UINT16 pixel1 = dest[x + 1];
@@ -2601,7 +2726,7 @@ static avi_error huffyuv_decompress_to_yuy16(avi_stream *stream, const UINT8 *da
 		/* median predict on rows > 0 */
 		else if ((huffyuv->predictor & ~HUFFYUV_PREDICT_DECORR) == HUFFYUV_PREDICT_MEDIAN && y >= prevlines)
 		{
-			for (x = 0; x < stream->width; x += 2)
+			for ( ; x < stream->width; x += 2)
 			{
 				UINT16 prevpixel0 = prevrow[x + 0];
 				UINT16 prevpixel1 = prevrow[x + 1];
