@@ -58,11 +58,12 @@ INLINE UINT8 fetch_8bit(UINT8 *v)
 }
 
 
+#ifdef UNUSED_FUNCTION
 INLINE UINT16 fetch_16bit(UINT8 *v)
 {
 	return BIG_ENDIANIZE_INT16(*(UINT16 *)v);
 }
-
+#endif
 
 INLINE UINT32 fetch_32bit(UINT8 *v)
 {
@@ -76,11 +77,12 @@ INLINE void put_8bit(UINT8 *v, UINT8 data)
 }
 
 
+#ifdef UNUSED_FUNCTION
 INLINE void put_16bit(UINT8 *v, UINT16 data)
 {
 	*(UINT16 *)v = BIG_ENDIANIZE_INT16(data);
 }
-
+#endif
 
 INLINE void put_32bit(UINT8 *v, UINT32 data)
 {
@@ -807,7 +809,7 @@ static png_error write_deflated_chunk(core_file *fp, UINT8 *data, UINT32 type, U
 	memset(&stream, 0, sizeof(stream));
 	stream.next_in = data;
 	stream.avail_in = length;
-    zerr = deflateInit(&stream, Z_DEFAULT_COMPRESSION);
+    zerr = deflateInit(&stream, Z_BEST_COMPRESSION);
     if (zerr != Z_OK)
     	return PNGERR_COMPRESS_ERROR;
 
