@@ -412,9 +412,36 @@ int xml_get_attribute_int(xml_data_node *node, const char *attribute, int defval
 	const char *string = xml_get_attribute_string(node, attribute, NULL);
 	int value;
 
-	if (string == NULL || sscanf(string, "%d", &value) != 1)
+	if (string == NULL)
 		return defvalue;
-	return value;
+	if (string[0] == '$')
+		return (sscanf(&string[1], "%X", &value) == 1) ? value : defvalue;
+	if (string[0] == '0' && string[1] == 'x')
+		return (sscanf(&string[2], "%X", &value) == 1) ? value : defvalue;
+	if (string[0] == '#')
+		return (sscanf(&string[1], "%d", &value) == 1) ? value : defvalue;
+	return (sscanf(&string[0], "%d", &value) == 1) ? value : defvalue;
+}
+
+
+/*-------------------------------------------------
+    xml_get_attribute_int_format - return the
+    format of the given integer attribute
+-------------------------------------------------*/
+
+int xml_get_attribute_int_format(xml_data_node *node, const char *attribute)
+{
+	const char *string = xml_get_attribute_string(node, attribute, NULL);
+
+	if (string == NULL)
+		return XML_INT_FORMAT_DECIMAL;
+	if (string[0] == '$')
+		return XML_INT_FORMAT_HEX_DOLLAR;
+	if (string[0] == '0' && string[1] == 'x')
+		return XML_INT_FORMAT_HEX_C;
+	if (string[0] == '#')
+		return XML_INT_FORMAT_DECIMAL_POUND;
+	return XML_INT_FORMAT_DECIMAL;
 }
 
 
@@ -515,10 +542,7 @@ const char *xml_normalize_string(const char *string)
 				case '<'  : d += sprintf(d, "&lt;"); break;
 				case '>'  : d += sprintf(d, "&gt;"); break;
 				default:
-					if (*string >= ' ' && *string <= '~')
-						*d++ = *string;
-					else
-						d += sprintf(d, "&#%d;", (unsigned)(unsigned char)*string);
+					*d++ = *string;
 			}
 			++string;
 		}
@@ -533,12 +557,37 @@ const char *xml_normalize_string(const char *string)
     EXPAT INTERFACES
 ***************************************************************************/
 
+/*-------------------------------------------------
+    expat_malloc/expat_realloc/expat_free -
+    wrappers for memory allocation functions so
+    that they pass through out memory tracking
+    systems
+-------------------------------------------------*/
+
+static void *expat_malloc(size_t size)
+{
+	return malloc(size);
+}
+
+static void *expat_realloc(void *ptr, size_t size)
+{
+	return realloc(ptr, size);
+}
+
+static void expat_free(void *ptr)
+{
+	free(ptr);
+}
+
+
 /*-------------------------------------------------
     expat_setup_parser - set up expat for parsing
 -------------------------------------------------*/
 
 static int expat_setup_parser(xml_parse_info *parse_info, xml_parse_options *opts)
 {
+	XML_Memory_Handling_Suite memcallbacks;
+
 	/* setup parse_info structure */
 	memset(parse_info, 0, sizeof(*parse_info));
 	if (opts != NULL)
@@ -559,7 +608,10 @@ static int expat_setup_parser(xml_parse_info *parse_info, xml_parse_options *opt
 	parse_info->curnode = parse_info->rootnode;
 
 	/* create the XML parser */
-	parse_info->parser = XML_ParserCreate(NULL);
+	memcallbacks.malloc_fcn = expat_malloc;
+	memcallbacks.realloc_fcn = expat_realloc;
+	memcallbacks.free_fcn = expat_free;
+	parse_info->parser = XML_ParserCreate_MM(NULL, &memcallbacks, NULL);
 	if (parse_info->parser == NULL)
 	{
 		free(parse_info->rootnode);
@@ -595,6 +647,9 @@ static void expat_element_start(void *data, const XML_Char *name, const XML_Char
 	if (newnode == NULL)
 		return;
 
+	/* remember the line number */
+	newnode->line = XML_GetCurrentLineNumber(parse_info->parser);
+
 	/* add all the attributes as well */
 	for (attr = 0; attributes[attr]; attr += 2)
 		add_attribute(newnode, attributes[attr+0], attributes[attr+1]);
