@@ -28,7 +28,7 @@ WRITE8_HANDLER( invadpt2_sh_port_1_w )
 {
 	UINT8 rising_bits = data & ~port_1_last;
 
-	SN76477_enable_w(0, !(data & 0x01));			/* SAUCER SOUND */
+	sn76477_enable_w(0, !(data & 0x01));			/* SAUCER SOUND */
 
 	if (rising_bits & 0x02) sample_start_n(0, 0, 0, 0);		/* MISSLE SOUND */
 	if (rising_bits & 0x04) sample_start_n(0, 1, 1, 0);		/* EXPLOSION */
@@ -60,7 +60,7 @@ WRITE8_HANDLER( invadpt2_sh_port_2_w )
 	if (rising_bits & 0x08) sample_start_n(0, 4, 6, 0);		/* FLEET */
 	if (rising_bits & 0x10) sample_start_n(0, 3, 7, 0);		/* SAUCER HIT */
 
-    c8080bw_flip_screen_w(data & 0x20);
+    c8080bw_flip_screen_w(space, data & 0x20);
 
 	port_2_last = data;
 }
@@ -76,7 +76,7 @@ WRITE8_HANDLER( spcewars_sh_port_w )
 {
 	UINT8 rising_bits = data & ~port_1_last;
 
-	SN76477_enable_w(0, !(data & 0x01));			/* Saucer Sound */
+	sn76477_enable_w(0, !(data & 0x01));			/* Saucer Sound */
 
 	if (rising_bits & 0x02) sample_start(0, 0, 0);		/* Shot Sound */
 	if (rising_bits & 0x04) sample_start(1, 1, 0);		/* Base Hit */
@@ -109,7 +109,7 @@ static const char *const lrescue_sample_names[] =
 	0
 };
 
-const struct Samplesinterface lrescue_samples_interface =
+const samples_interface lrescue_samples_interface =
 {
 	4,	/* 4 channels */
 	lrescue_sample_names
@@ -145,7 +145,7 @@ WRITE8_HANDLER( lrescue_sh_port_2_w )
 	if (rising_bits & 0x10) sample_start(3, 6, 0);		/* Shooting Star and Rescue Ship sounds */
 	if (~data & 0x10 && port_2_last & 0x10) sample_stop (3);	/* This makes the rescue ship sound beep on and off */
 
-	c8080bw_flip_screen_w(data & 0x20);
+	c8080bw_flip_screen_w(space, data & 0x20);
 
 	port_2_last = data;
 }
@@ -160,7 +160,7 @@ WRITE8_HANDLER( lrescue_sh_port_2_w )
 WRITE8_HANDLER( cosmo_sh_port_2_w )
 {
 	/* inverted flip screen bit */
-	invadpt2_sh_port_2_w(offset, data ^ 0x20);
+	invadpt2_sh_port_2_w(space, offset, data ^ 0x20);
 }
 
 
@@ -196,7 +196,7 @@ WRITE8_HANDLER( ballbomb_sh_port_2_w )
 	if (data & 0x04) sample_start(0, 4, 0);		/* Plane is dropping new balloons at start of level */
 	if (rising_bits & 0x10) sample_start(2, 2, 0);		/* Balloon hit and bomb drops */
 
-	c8080bw_flip_screen_w(data & 0x20);
+	c8080bw_flip_screen_w(space, data & 0x20);
 
 	port_2_last = data;
 }
@@ -230,7 +230,7 @@ DISCRETE_SOUND_START(indianbt)
 	DISCRETE_NOTE(NODE_20, 1, INDIANBT_MUSIC_CLK, INDIANBT_MUSIC_DATA, 255, 5, DISC_CLK_IS_FREQ)
 
 	// Convert count to 7492 output
-	DISCRETE_TRANSFORM2(NODE_21, 1, NODE_20, 2, "01>0+")
+	DISCRETE_TRANSFORM2(NODE_21, NODE_20, 2, "01>0+")
 
 	DISCRETE_DAC_R1(NODE_22, 1, NODE_21, DEFAULT_TTL_V_LOGIC_1, &indianbt_music_dac)
 
@@ -277,7 +277,7 @@ WRITE8_HANDLER( indianbt_sh_port_2_w )
 
 WRITE8_HANDLER( indianbt_sh_port_3_w )
 {
-	discrete_sound_w(INDIANBT_MUSIC_DATA, data);
+	discrete_sound_w(space, INDIANBT_MUSIC_DATA, data);
 }
 
 
@@ -429,10 +429,10 @@ DISCRETE_SOUND_START(polaris)
 
 	/* We will cheat and just use the controls to scale the amplitude. */
 	/* It is the same as taking the (0 to 50k)/50k */
-	DISCRETE_ADJUSTMENT_TAG(POLARIS_ADJ_VR1, 1, 0, 1, DISC_LINADJ, "VR1")
-	DISCRETE_ADJUSTMENT_TAG(POLARIS_ADJ_VR2, 1, 0, 1, DISC_LINADJ, "VR2")
+	DISCRETE_ADJUSTMENT_TAG(POLARIS_ADJ_VR1, 0, 1, DISC_LINADJ, "VR1")
+	DISCRETE_ADJUSTMENT_TAG(POLARIS_ADJ_VR2, 0, 1, DISC_LINADJ, "VR2")
 	/* Extra cheating for VR3.  We will include the resistor scaling. */
-	DISCRETE_ADJUSTMENT_TAG(POLARIS_ADJ_VR3, 1, 0, 0.5376, DISC_LINADJ, "VR3")
+	DISCRETE_ADJUSTMENT_TAG(POLARIS_ADJ_VR3, 0, 0.5376, DISC_LINADJ, "VR3")
 
 /******************************************************************************
  *
@@ -473,8 +473,8 @@ DISCRETE_SOUND_START(polaris)
  ******************************************************************************/
 	DISCRETE_SQUAREWFIX(NODE_40, 1, 60.0/16, 1, 50, 1.0/2, 0)	// IC 5L, pin 6
 	DISCRETE_COUNTER(NODE_41, 1, 0, NODE_40, 31, 1, 0, DISC_CLK_ON_F_EDGE)	// IC 5L & 5F
-	DISCRETE_TRANSFORM2(NODE_42, 1, NODE_41, 4, "01&")			// IC 5L, pin 9
-	DISCRETE_TRANSFORM2(NODE_43, 1, NODE_41, 16, "01&!")		// IC 5F, pin 8
+	DISCRETE_TRANSFORM2(NODE_42, NODE_41, 4, "01&")			// IC 5L, pin 9
+	DISCRETE_TRANSFORM2(NODE_43, NODE_41, 16, "01&!")		// IC 5F, pin 8
 	DISCRETE_ONESHOT(NODE_44, NODE_43, 1, 0.0015, DISC_ONESHOT_REDGE | DISC_ONESHOT_NORETRIG | DISC_OUT_ACTIVE_HIGH)
 
 	DISCRETE_LOGIC_OR(NODE_45, 1, NODE_42, POLARIS_SX3_EN)
@@ -595,46 +595,47 @@ DISCRETE_SOUND_END
 
 WRITE8_HANDLER( polaris_sh_port_1_w )
 {
-	discrete_sound_w(POLARIS_MUSIC_DATA, data);
+	discrete_sound_w(space, POLARIS_MUSIC_DATA, data);
 }
 
 WRITE8_HANDLER( polaris_sh_port_2_w )
 {
 	/* 0x01 - SX0 - Shot */
-	discrete_sound_w(POLARIS_SX0_EN, data & 0x01);
+	discrete_sound_w(space, POLARIS_SX0_EN, data & 0x01);
 
 	/* 0x02 - SX1 - Ship Hit (Sub) */
-	discrete_sound_w(POLARIS_SX1_EN, data & 0x02);
+	discrete_sound_w(space, POLARIS_SX1_EN, data & 0x02);
 
 	/* 0x04 - SX2 - Ship */
-	discrete_sound_w(POLARIS_SX2_EN, data & 0x04);
+	discrete_sound_w(space, POLARIS_SX2_EN, data & 0x04);
 
 	/* 0x08 - SX3 - Explosion */
-	discrete_sound_w(POLARIS_SX3_EN, data & 0x08);
+	discrete_sound_w(space, POLARIS_SX3_EN, data & 0x08);
 
 	/* 0x10 - SX4 */
 
 	/* 0x20 - SX5 - Sound Enable */
-	discrete_sound_w(POLARIS_SX5_EN, data & 0x20);
+	discrete_sound_w(space, POLARIS_SX5_EN, data & 0x20);
 }
 
 WRITE8_HANDLER( polaris_sh_port_3_w )
 {
+
 	coin_lockout_global_w(data & 0x04);  /* SX8 */
 
-	c8080bw_flip_screen_w(data & 0x20);  /* SX11 */
+	c8080bw_flip_screen_w(space, data & 0x20);  /* SX11 */
 
 	/* 0x01 - SX6 - Plane Down */
-	discrete_sound_w(POLARIS_SX6_EN, data & 0x01);
+	discrete_sound_w(space, POLARIS_SX6_EN, data & 0x01);
 
 	/* 0x02 - SX7 - Plane Up */
-	discrete_sound_w(POLARIS_SX7_EN, data & 0x02);
+	discrete_sound_w(space, POLARIS_SX7_EN, data & 0x02);
 
 	/* 0x08 - SX9 - Hit */
-	discrete_sound_w(POLARIS_SX9_EN, data & 0x08);
+	discrete_sound_w(space, POLARIS_SX9_EN, data & 0x08);
 
 	/* 0x10 - SX10 - Hit */
-	discrete_sound_w(POLARIS_SX10_EN, data & 0x10);
+	discrete_sound_w(space, POLARIS_SX10_EN, data & 0x10);
 }
 
 
@@ -664,7 +665,7 @@ WRITE8_HANDLER( polaris_sh_port_3_w )
 #define SCHASER_4V		SCHASER_HSYNC /2 /4
 #define SCHASER_8V		SCHASER_HSYNC /2 /8
 
-const struct SN76477interface schaser_sn76477_interface =
+const sn76477_interface schaser_sn76477_interface =
 {
 	RES_K( 47),	/*  4 noise_res         */
 	RES_K(330),	/*  5 filter_res        */
@@ -712,9 +713,8 @@ DISCRETE_SOUND_START(schaser)
 	/************************************************/
 	DISCRETE_INPUT_LOGIC  (SCHASER_DOT_EN)
 	DISCRETE_INPUT_LOGIC  (SCHASER_DOT_SEL)
-//  Change the constant to the stream input when working.
-	DISCRETE_CONSTANT(SCHASER_EXP_STREAM, 0)
-//  DISCRETE_INPUTX_STREAM(SCHASER_EXP_STREAM,   5.0/36764,              0)
+	// scale to 0-3.5V
+	DISCRETE_INPUTX_STREAM(SCHASER_EXP_STREAM, 0, 1.0/14100,             2.323)
 	DISCRETE_INPUTX_LOGIC (SCHASER_MUSIC_BIT,    DEFAULT_TTL_V_LOGIC_1,  0,      0.0)
 	DISCRETE_INPUT_LOGIC  (SCHASER_SND_EN)
 
@@ -723,9 +723,9 @@ DISCRETE_SOUND_START(schaser)
 	/* We will set them to adjust the realitive     */
 	/* gains.                                       */
 	/************************************************/
-	DISCRETE_ADJUSTMENT_TAG(SCHASER_VR1, 1, 0, RES_K(50)/(RES_K(50) + RES_K(470)), DISC_LINADJ, "VR1")
-	DISCRETE_ADJUSTMENT_TAG(SCHASER_VR2, 1, 0, RES_K(50)/(RES_K(50) + 560 + RES_K(6.8) + RES_K(2)), DISC_LINADJ, "VR2")
-	DISCRETE_ADJUSTMENT_TAG(SCHASER_VR3, 1, 0, RES_K(50)/(RES_K(50) + 560 + RES_K(6.8) + RES_K(10)), DISC_LINADJ, "VR3")
+	DISCRETE_ADJUSTMENT_TAG(SCHASER_VR1, 0, RES_K(50)/(RES_K(50) + RES_K(470)), DISC_LINADJ, "VR1")
+	DISCRETE_ADJUSTMENT_TAG(SCHASER_VR2, 0, RES_K(50)/(RES_K(50) + 560 + RES_K(6.8) + RES_K(2)), DISC_LINADJ, "VR2")
+	DISCRETE_ADJUSTMENT_TAG(SCHASER_VR3, 0, RES_K(50)/(RES_K(50) + 560 + RES_K(6.8) + RES_K(10)), DISC_LINADJ, "VR3")
 
 	/************************************************/
 	/* Dot selection just selects between 4V and 8V */
@@ -756,7 +756,7 @@ DISCRETE_SOUND_START(schaser)
 	/************************************************/
 	DISCRETE_ADDER3(NODE_90, SCHASER_SND_EN, SCHASER_DOT_SND, SCHASER_EXP_SND, SCHASER_MUSIC_SND)
 
-	DISCRETE_OUTPUT(NODE_90, 60000)
+	DISCRETE_OUTPUT(NODE_90, 33080)
 DISCRETE_SOUND_END
 
 static const double schaser_effect_rc[8] =
@@ -783,8 +783,8 @@ WRITE8_HANDLER( schaser_sh_port_1_w )
        bit 4 - Effect Sound C (SX4)
        bit 5 - Explosion (SX5) */
 
-	discrete_sound_w(SCHASER_DOT_EN, data & 0x01);
-	discrete_sound_w(SCHASER_DOT_SEL, data & 0x02);
+	discrete_sound_w(space, SCHASER_DOT_EN, data & 0x01);
+	discrete_sound_w(space, SCHASER_DOT_SEL, data & 0x02);
 
 	/* The effect is a variable rate 555 timer.  A diode/resistor array is used to
      * select the frequency.  Because of the diode voltage drop, we can not use the
@@ -800,13 +800,13 @@ WRITE8_HANDLER( schaser_sh_port_1_w )
 			if (attotime_compare(schaser_effect_555_time_remain, attotime_zero) != 0)
 			{
 				/* timer re-enabled, use up remaining 555 high time */
-				timer_adjust(schaser_effect_555_timer, schaser_effect_555_time_remain, effect, attotime_zero);
+				timer_adjust_oneshot(schaser_effect_555_timer, schaser_effect_555_time_remain, effect);
 			}
 			else if (!schaser_effect_555_is_low)
 			{
 				/* set 555 high time */
 				attotime new_time = attotime_make(0, ATTOSECONDS_PER_SECOND * .8873 * schaser_effect_rc[effect]);
-				timer_adjust(schaser_effect_555_timer, new_time, effect, attotime_zero);
+				timer_adjust_oneshot(schaser_effect_555_timer, new_time, effect);
 			}
 		}
 		else
@@ -815,7 +815,7 @@ WRITE8_HANDLER( schaser_sh_port_1_w )
 			if (!schaser_effect_555_is_low)
 			{
 				schaser_effect_555_time_remain = timer_timeleft(schaser_effect_555_timer);
-				timer_adjust(schaser_effect_555_timer, attotime_never, 0, attotime_never);
+				timer_adjust_oneshot(schaser_effect_555_timer, attotime_never, 0);
 			}
 		}
 		last_effect = effect;
@@ -824,15 +824,15 @@ WRITE8_HANDLER( schaser_sh_port_1_w )
 	schaser_explosion = (data >> 5) & 0x01;
 	if (schaser_explosion)
 	{
-		SN76477_amplitude_res_w(0, 1.0 / (1.0/RES_K(200) + 1.0/RES_K(68)));
+		sn76477_amplitude_res_w(0, 1.0 / (1.0/RES_K(200) + 1.0/RES_K(68)));
 	}
 	else
 	{
-		SN76477_amplitude_res_w(0, RES_K(200));
+		sn76477_amplitude_res_w(0, RES_K(200));
 	}
-	SN76477_enable_w(0, !(schaser_effect_555_is_low || schaser_explosion));
-	SN76477_one_shot_cap_voltage_w(0, !(schaser_effect_555_is_low || schaser_explosion) ? 0 : SN76477_EXTERNAL_VOLTAGE_DISCONNECT);
-	SN76477_mixer_b_w(0, schaser_explosion);
+	sn76477_enable_w(0, !(schaser_effect_555_is_low || schaser_explosion));
+	sn76477_one_shot_cap_voltage_w(0, !(schaser_effect_555_is_low || schaser_explosion) ? 0 : SN76477_EXTERNAL_VOLTAGE_DISCONNECT);
+	sn76477_mixer_b_w(0, schaser_explosion);
 }
 
 WRITE8_HANDLER( schaser_sh_port_2_w )
@@ -844,16 +844,16 @@ WRITE8_HANDLER( schaser_sh_port_2_w )
        bit 4 - Field Control B (SX10)
        bit 5 - Flip Screen */
 
-	discrete_sound_w(SCHASER_MUSIC_BIT, data & 0x01);
+	discrete_sound_w(space, SCHASER_MUSIC_BIT, data & 0x01);
 
-	discrete_sound_w(SCHASER_SND_EN, data & 0x02);
+	discrete_sound_w(space, SCHASER_SND_EN, data & 0x02);
 	sound_global_enable(data & 0x02);
 
 	coin_lockout_global_w(data & 0x04);
 
 	schaser_background_control_w(data & 0x18);
 
-	c8080bw_flip_screen_w(data & 0x20);
+	c8080bw_flip_screen_w(space, data & 0x20);
 }
 
 
@@ -874,15 +874,15 @@ static TIMER_CALLBACK( schaser_effect_555_cb )
 		else
 			new_time = attotime_never;
 	}
-	timer_adjust(schaser_effect_555_timer, new_time, effect, attotime_zero);
-	SN76477_enable_w(0, !(schaser_effect_555_is_low || schaser_explosion));
-	SN76477_one_shot_cap_voltage_w(0, !(schaser_effect_555_is_low || schaser_explosion) ? 0 : SN76477_EXTERNAL_VOLTAGE_DISCONNECT);
+	timer_adjust_oneshot(schaser_effect_555_timer, new_time, effect);
+	sn76477_enable_w(0, !(schaser_effect_555_is_low || schaser_explosion));
+	sn76477_one_shot_cap_voltage_w(0, !(schaser_effect_555_is_low || schaser_explosion) ? 0 : SN76477_EXTERNAL_VOLTAGE_DISCONNECT);
 }
 
 
 MACHINE_START( schaser )
 {
-	schaser_effect_555_timer = timer_alloc(schaser_effect_555_cb, NULL);
+	schaser_effect_555_timer = timer_alloc(machine, schaser_effect_555_cb, NULL);
 
 	MACHINE_START_CALL(mw8080bw);
 }
@@ -890,10 +890,11 @@ MACHINE_START( schaser )
 
 MACHINE_RESET( schaser )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	schaser_effect_555_is_low = 0;
-	timer_adjust(schaser_effect_555_timer, attotime_never, 0, attotime_never);
-	schaser_sh_port_1_w(0, 0);
-	schaser_sh_port_2_w(0, 0);
+	timer_adjust_oneshot(schaser_effect_555_timer, attotime_never, 0);
+	schaser_sh_port_1_w(space, 0, 0);
+	schaser_sh_port_2_w(space, 0, 0);
 	schaser_effect_555_time_remain = attotime_zero;
 
 	MACHINE_RESET_CALL(mw8080bw);
@@ -978,7 +979,7 @@ WRITE8_HANDLER( lupin3_sh_port_1_w )
 
 	if (rising_bits & 0x01) sample_start(0, 6, 0);		/* Walking, get money */
 
-	SN76477_enable_w(0, data & 0x02 ? 0:1);			/* Helicopter */
+	sn76477_enable_w(0, data & 0x02 ? 0:1);			/* Helicopter */
 
 	if (rising_bits & 0x04) sample_start(0, 7, 0);		/* Translocate */
 	if (rising_bits & 0x08) sample_start(0, 1, 0);		/* Jail */
@@ -997,7 +998,7 @@ WRITE8_HANDLER( lupin3_sh_port_2_w )
 	if (rising_bits & 0x08) sample_start(3, 0, 0);		/* start intermission, end game */
 	//if (rising_bits & 0x10) sample_start(3, 9, 0);        /* Dog barking */
 
-	c8080bw_flip_screen_w(data & 0x20);
+	c8080bw_flip_screen_w(space, data & 0x20);
 
 	port_2_last = data;
 }
@@ -1029,7 +1030,7 @@ WRITE8_HANDLER( schasrcv_sh_port_2_w )
 
 	sound_global_enable(data & 0x10);
 
-	c8080bw_flip_screen_w(data & 0x20);
+	c8080bw_flip_screen_w(space, data & 0x20);
 }
 
 
@@ -1060,11 +1061,11 @@ WRITE8_HANDLER( yosakdon_sh_port_2_w )
 	if (rising_bits & 0x01) sample_start(1, 6, 0);			/* Ready? , Game Over */
 	if (rising_bits & 0x04) sample_start(3, 7, 0);			/* Big bird dead */
 
-	SN76477_enable_w(0, data & 0x08 ? 0:1);				/* Big bird */
+	sn76477_enable_w(0, data & 0x08 ? 0:1);				/* Big bird */
 
 	if (rising_bits & 0x10) sample_start(2, 7, 0);			/* Game Over */
 
-	c8080bw_flip_screen_w(data & 0x20);
+	c8080bw_flip_screen_w(space, data & 0x20);
 
 	port_2_last = data;
 }
@@ -1084,7 +1085,7 @@ WRITE8_HANDLER( shuttlei_sh_port_1_w )
 	if (rising_bits & 0x01) sample_start(4, 4, 0);			/* Fleet move */
 	if (rising_bits & 0x02) sample_start(5, 8, 0);			/* Extra Tank */
 
-	SN76477_enable_w(0, data & 0x04 ? 0:1);				/* UFO */
+	sn76477_enable_w(0, data & 0x04 ? 0:1);				/* UFO */
 
 	port_1_last = data;
 }
