@@ -31,7 +31,6 @@ Static Program ROM (48K bytes)            4000-FFFF   R    D0-D7
 ****************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "cpu/m6502/m6502.h"
 #include "sound/5220intf.h"
 #include "sound/2151intf.h"
@@ -50,8 +49,8 @@ static UINT8 *bank_source_data;
 static UINT8 speech_data;
 static UINT8 last_ctl;
 
-static int cpu_num;
-static UINT8 test_port;
+static const device_config *jsacpu;
+static const char *test_port;
 static UINT16 test_mask;
 
 static UINT8 has_pokey;
@@ -83,18 +82,18 @@ static WRITE8_HANDLER( jsa3_io_w );
  *
  *************************************/
 
-static void init_save_state(void)
+static void init_save_state(running_machine *machine)
 {
-	state_save_register_global(speech_data);
-	state_save_register_global(last_ctl);
+	state_save_register_global(machine, speech_data);
+	state_save_register_global(machine, last_ctl);
 
-	state_save_register_global(oki6295_bank_base);
+	state_save_register_global(machine, oki6295_bank_base);
 
-	state_save_register_global(overall_volume);
-	state_save_register_global(pokey_volume);
-	state_save_register_global(ym2151_volume);
-	state_save_register_global(tms5220_volume);
-	state_save_register_global(oki6295_volume);
+	state_save_register_global(machine, overall_volume);
+	state_save_register_global(machine, pokey_volume);
+	state_save_register_global(machine, ym2151_volume);
+	state_save_register_global(machine, tms5220_volume);
+	state_save_register_global(machine, oki6295_volume);
 }
 
 
@@ -105,25 +104,27 @@ static void init_save_state(void)
  *
  *************************************/
 
-void atarijsa_init(running_machine *machine, int testport, int testmask)
+void atarijsa_init(running_machine *machine, const char *testport, int testmask)
 {
 	int i;
+	UINT8 *rgn;
 
 	/* copy in the parameters */
-	cpu_num = mame_find_cpu_index(machine, "jsa");
-	assert_always(cpu_num != -1, "Could not find JSA CPU!");
+	jsacpu = cputag_get_cpu(machine, "jsa");
+	assert_always(jsacpu != NULL, "Could not find JSA CPU!");
 	test_port = testport;
 	test_mask = testmask;
 
 	/* predetermine the bank base */
-	bank_base = &memory_region(REGION_CPU1+cpu_num)[0x03000];
-	bank_source_data = &memory_region(REGION_CPU1+cpu_num)[0x10000];
+	rgn = memory_region(machine, "jsa");
+	bank_base = &rgn[0x03000];
+	bank_source_data = &rgn[0x10000];
 
 	/* determine which sound hardware is installed */
 	has_tms5220 = has_oki6295 = has_pokey = has_ym2151 = 0;
 	for (i = 0; i < MAX_SOUND; i++)
 	{
-		switch (Machine->drv->sound[i].type)
+		switch (machine->config->sound[i].type)
 		{
 			case SOUND_TMS5220:
 				has_tms5220 = 1;
@@ -144,36 +145,40 @@ void atarijsa_init(running_machine *machine, int testport, int testmask)
 
 	/* install POKEY memory handlers */
 	if (has_pokey)
-	{
-		memory_install_read8_handler(cpu_num, ADDRESS_SPACE_PROGRAM, 0x2c00, 0x2c0f, 0, 0, pokey1_r);
-		memory_install_write8_handler(cpu_num, ADDRESS_SPACE_PROGRAM, 0x2c00, 0x2c0f, 0, 0, pokey1_w);
-	}
+		memory_install_readwrite8_handler(cpu_get_address_space(jsacpu, ADDRESS_SPACE_PROGRAM), 0x2c00, 0x2c0f, 0, 0, pokey1_r, pokey1_w);
 
-	init_save_state();
+	init_save_state(machine);
 	atarijsa_reset();
-}
 
+	/* initialize JSA III ADPCM */
+	{
+		static const char *const regions[] = { "adpcm", "adcpml", "adpcmr" };
+		int rgn;
 
-void atarijsa3_init_adpcm(int region)
-{
-	UINT8 *base = memory_region(region);
+		/* expand the ADPCM data to avoid lots of memcpy's during gameplay */
+		/* the upper 128k is fixed, the lower 128k is bankswitched */
+		for (rgn = 0; rgn < ARRAY_LENGTH(regions); rgn++)
+		{
+			UINT8 *base = memory_region(machine, regions[rgn]);
+			if (base != NULL && memory_region_length(machine, regions[rgn]) >= 0x100000)
+			{
+				memcpy(&base[0x00000], &base[0x80000], 0x20000);
+				memcpy(&base[0x40000], &base[0x80000], 0x20000);
+				memcpy(&base[0x80000], &base[0xa0000], 0x20000);
 
-	/* expand the ADPCM data to avoid lots of memcpy's during gameplay */
-	/* the upper 128k is fixed, the lower 128k is bankswitched */
-	memcpy(&base[0x00000], &base[0x80000], 0x20000);
-	memcpy(&base[0x40000], &base[0x80000], 0x20000);
-	memcpy(&base[0x80000], &base[0xa0000], 0x20000);
-
-	memcpy(&base[0x20000], &base[0xe0000], 0x20000);
-	memcpy(&base[0x60000], &base[0xe0000], 0x20000);
-	memcpy(&base[0xa0000], &base[0xe0000], 0x20000);
+				memcpy(&base[0x20000], &base[0xe0000], 0x20000);
+				memcpy(&base[0x60000], &base[0xe0000], 0x20000);
+				memcpy(&base[0xa0000], &base[0xe0000], 0x20000);
+			}
+		}
+	}
 }
 
 
 void atarijsa_reset(void)
 {
 	/* reset the sound I/O system */
-	atarigen_sound_io_reset(cpu_num);
+	atarigen_sound_io_reset(jsacpu);
 
 	/* reset the static states */
 	speech_data = 0;
@@ -208,7 +213,7 @@ static READ8_HANDLER( jsa1_io_r )
 			break;
 
 		case 0x002:		/* /RDP */
-			result = atarigen_6502_sound_r(offset);
+			result = atarigen_6502_sound_r(space, offset);
 			break;
 
 		case 0x004:		/* /RDIO */
@@ -222,15 +227,15 @@ static READ8_HANDLER( jsa1_io_r )
                 0x02 = coin 2
                 0x01 = coin 1
             */
-			result = readinputportbytag("JSAI");
-			if (!(readinputport(test_port) & test_mask)) result ^= 0x80;
+			result = input_port_read(space->machine, "JSAI");
+			if (!(input_port_read(space->machine, test_port) & test_mask)) result ^= 0x80;
 			if (atarigen_cpu_to_sound_ready) result ^= 0x40;
 			if (atarigen_sound_to_cpu_ready) result ^= 0x20;
 			if (!has_tms5220 || tms5220_ready_r()) result ^= 0x10;
 			break;
 
 		case 0x006:		/* /IRQACK */
-			atarigen_6502_irq_ack_r(0);
+			atarigen_6502_irq_ack_r(space, 0);
 			break;
 
 		case 0x200:		/* /VOICE */
@@ -256,7 +261,7 @@ static WRITE8_HANDLER( jsa1_io_w )
 			break;
 
 		case 0x006:		/* /IRQACK */
-			atarigen_6502_irq_ack_r(0);
+			atarigen_6502_irq_ack_r(space, 0);
 			break;
 
 		case 0x200:		/* /VOICE */
@@ -264,7 +269,7 @@ static WRITE8_HANDLER( jsa1_io_w )
 			break;
 
 		case 0x202:		/* /WRP */
-			atarigen_6502_sound_w(offset, data);
+			atarigen_6502_sound_w(space, offset, data);
 			break;
 
 		case 0x204:		/* WRIO */
@@ -284,7 +289,7 @@ static WRITE8_HANDLER( jsa1_io_w )
 				int count;
 
 				if (((data ^ last_ctl) & 0x02) && (data & 0x02))
-					tms5220_data_w(0, speech_data);
+					tms5220_data_w(space, 0, speech_data);
 				count = 5 | ((data >> 2) & 2);
 				tms5220_set_frequency(JSA_MASTER_CLOCK*2 / (16 - count));
 			}
@@ -308,7 +313,7 @@ static WRITE8_HANDLER( jsa1_io_w )
 			tms5220_volume = ((data >> 6) & 3) * 100 / 3;
 			pokey_volume = ((data >> 4) & 3) * 100 / 3;
 			ym2151_volume = ((data >> 1) & 7) * 100 / 7;
-			update_all_volumes(Machine);
+			update_all_volumes(space->machine);
 			break;
 	}
 }
@@ -329,13 +334,13 @@ static READ8_HANDLER( jsa2_io_r )
 	{
 		case 0x000:		/* /RDV */
 			if (has_oki6295)
-				result = OKIM6295_status_0_r(offset);
+				result = okim6295_status_0_r(space, offset);
 			else
 				logerror("atarijsa: Unknown read at %04X\n", offset & 0x206);
 			break;
 
 		case 0x002:		/* /RDP */
-			result = atarigen_6502_sound_r(offset);
+			result = atarigen_6502_sound_r(space, offset);
 			break;
 
 		case 0x004:		/* /RDIO */
@@ -349,14 +354,14 @@ static READ8_HANDLER( jsa2_io_r )
                 0x02 = coin 2
                 0x01 = coin 1
             */
-			result = readinputportbytag("JSAII");
-			if (!(readinputport(test_port) & test_mask)) result ^= 0x80;
+			result = input_port_read(space->machine, "JSAII");
+			if (!(input_port_read(space->machine, test_port) & test_mask)) result ^= 0x80;
 			if (atarigen_cpu_to_sound_ready) result ^= 0x40;
 			if (atarigen_sound_to_cpu_ready) result ^= 0x20;
 			break;
 
 		case 0x006:		/* /IRQACK */
-			atarigen_6502_irq_ack_r(0);
+			atarigen_6502_irq_ack_r(space, 0);
 			break;
 
 		case 0x200:		/* /WRV */
@@ -382,18 +387,18 @@ static WRITE8_HANDLER( jsa2_io_w )
 			break;
 
 		case 0x006:		/* /IRQACK */
-			atarigen_6502_irq_ack_r(0);
+			atarigen_6502_irq_ack_r(space, 0);
 			break;
 
 		case 0x200:		/* /WRV */
 			if (has_oki6295)
-				OKIM6295_data_0_w(offset, data);
+				okim6295_data_0_w(space, offset, data);
 			else
 				logerror("atarijsa: Unknown write (%02X) at %04X\n", data & 0xff, offset & 0x206);
 			break;
 
 		case 0x202:		/* /WRP */
-			atarigen_6502_sound_w(offset, data);
+			atarigen_6502_sound_w(space, offset, data);
 			break;
 
 		case 0x204:		/* /WRIO */
@@ -416,7 +421,7 @@ static WRITE8_HANDLER( jsa2_io_w )
 			coin_counter_w(0, (data >> 4) & 1);
 
 			/* update the OKI frequency */
-			if (has_oki6295) OKIM6295_set_pin7(0, data & 8);
+			if (has_oki6295) okim6295_set_pin7(0, data & 8);
 			break;
 
 		case 0x206:		/* /MIX */
@@ -429,7 +434,7 @@ static WRITE8_HANDLER( jsa2_io_w )
             */
 			ym2151_volume = ((data >> 1) & 7) * 100 / 7;
 			oki6295_volume = 50 + (data & 1) * 50;
-			update_all_volumes(Machine);
+			update_all_volumes(space->machine);
 			break;
 	}
 }
@@ -450,11 +455,11 @@ static READ8_HANDLER( jsa3_io_r )
 	{
 		case 0x000:		/* /RDV */
 			if (has_oki6295)
-				result = OKIM6295_status_0_r(offset);
+				result = okim6295_status_0_r(space, offset);
 			break;
 
 		case 0x002:		/* /RDP */
-			result = atarigen_6502_sound_r(offset);
+			result = atarigen_6502_sound_r(space, offset);
 			break;
 
 		case 0x004:		/* /RDIO */
@@ -468,14 +473,14 @@ static READ8_HANDLER( jsa3_io_r )
                 0x02 = coin L (active high)
                 0x01 = coin R (active high)
             */
-			result = readinputportbytag("JSAIII");
-			if (!(readinputport(test_port) & test_mask)) result ^= 0x90;
+			result = input_port_read(space->machine, "JSAIII");
+			if (!(input_port_read(space->machine, test_port) & test_mask)) result ^= 0x90;
 			if (atarigen_cpu_to_sound_ready) result ^= 0x40;
 			if (atarigen_sound_to_cpu_ready) result ^= 0x20;
 			break;
 
 		case 0x006:		/* /IRQACK */
-			atarigen_6502_irq_ack_r(0);
+			atarigen_6502_irq_ack_r(space, 0);
 			break;
 
 		case 0x200:		/* /WRV */
@@ -496,7 +501,7 @@ static WRITE8_HANDLER( jsa3_io_w )
 	{
 		case 0x000:		/* /RDV */
 			overall_volume = data * 100 / 127;
-			update_all_volumes(Machine);
+			update_all_volumes(space->machine);
 			break;
 
 		case 0x002:		/* /RDP */
@@ -505,16 +510,16 @@ static WRITE8_HANDLER( jsa3_io_w )
 			break;
 
 		case 0x006:		/* /IRQACK */
-			atarigen_6502_irq_ack_r(0);
+			atarigen_6502_irq_ack_r(space, 0);
 			break;
 
 		case 0x200:		/* /WRV */
 			if (has_oki6295)
-				OKIM6295_data_0_w(offset, data);
+				okim6295_data_0_w(space, offset, data);
 			break;
 
 		case 0x202:		/* /WRP */
-			atarigen_6502_sound_w(offset, data);
+			atarigen_6502_sound_w(space, offset, data);
 			break;
 
 		case 0x204:		/* /WRIO */
@@ -531,7 +536,7 @@ static WRITE8_HANDLER( jsa3_io_w )
 			/* update the OKI bank */
 
 			oki6295_bank_base = (0x40000 * ((data >> 1) & 1)) | (oki6295_bank_base & 0x80000);
-			if (has_oki6295) OKIM6295_set_bank_base(0, oki6295_bank_base);
+			if (has_oki6295) okim6295_set_bank_base(0, oki6295_bank_base);
 
 			/* update the bank */
 			memcpy(bank_base, &bank_source_data[0x1000 * ((data >> 6) & 3)], 0x1000);
@@ -542,7 +547,7 @@ static WRITE8_HANDLER( jsa3_io_w )
 			coin_counter_w(0, (data >> 4) & 1);
 
 			/* update the OKI frequency */
-			if (has_oki6295) OKIM6295_set_pin7(0, data & 8);
+			if (has_oki6295) okim6295_set_pin7(0, data & 8);
 			break;
 
 		case 0x206:		/* /MIX */
@@ -556,12 +561,12 @@ static WRITE8_HANDLER( jsa3_io_w )
 
 			/* update the OKI bank */
 			oki6295_bank_base = (0x80000 * ((data >> 4) & 1)) | (oki6295_bank_base & 0x40000);
-			if (has_oki6295) OKIM6295_set_bank_base(0, oki6295_bank_base);
+			if (has_oki6295) okim6295_set_bank_base(0, oki6295_bank_base);
 
 			/* update the volumes */
 			ym2151_volume = ((data >> 1) & 7) * 100 / 7;
 			oki6295_volume = 50 + (data & 1) * 50;
-			update_all_volumes(Machine);
+			update_all_volumes(space->machine);
 			break;
 	}
 }
@@ -584,14 +589,14 @@ static READ8_HANDLER( jsa3s_io_r )
 			if (has_oki6295)
 			{
 				if (offset & 1)
-					result = OKIM6295_status_1_r(offset);
+					result = okim6295_status_1_r(space, offset);
 				else
-					result = OKIM6295_status_0_r(offset);
+					result = okim6295_status_0_r(space, offset);
 			}
 			break;
 
 		case 0x002:		/* /RDP */
-			result = atarigen_6502_sound_r(offset);
+			result = atarigen_6502_sound_r(space, offset);
 			break;
 
 		case 0x004:		/* /RDIO */
@@ -605,14 +610,14 @@ static READ8_HANDLER( jsa3s_io_r )
                 0x02 = coin L (active high)
                 0x01 = coin R (active high)
             */
-			result = readinputportbytag("JSAIII");
-			if (!(readinputport(test_port) & test_mask)) result ^= 0x90;
+			result = input_port_read(space->machine, "JSAIII");
+			if (!(input_port_read(space->machine, test_port) & test_mask)) result ^= 0x90;
 			if (atarigen_cpu_to_sound_ready) result ^= 0x40;
 			if (atarigen_sound_to_cpu_ready) result ^= 0x20;
 			break;
 
 		case 0x006:		/* /IRQACK */
-			atarigen_6502_irq_ack_r(0);
+			atarigen_6502_irq_ack_r(space, 0);
 			break;
 
 		case 0x200:		/* /WRV */
@@ -633,7 +638,7 @@ static WRITE8_HANDLER( jsa3s_io_w )
 	{
 		case 0x000:		/* /RDV */
 			overall_volume = data * 100 / 127;
-			update_all_volumes(Machine);
+			update_all_volumes(space->machine);
 			break;
 
 		case 0x002:		/* /RDP */
@@ -642,21 +647,21 @@ static WRITE8_HANDLER( jsa3s_io_w )
 			break;
 
 		case 0x006:		/* /IRQACK */
-			atarigen_6502_irq_ack_r(0);
+			atarigen_6502_irq_ack_r(space, 0);
 			break;
 
 		case 0x200:		/* /WRV */
 			if (has_oki6295)
 			{
 				if (offset & 1)
-					OKIM6295_data_1_w(offset, data);
+					okim6295_data_1_w(space, offset, data);
 				else
-					OKIM6295_data_0_w(offset, data);
+					okim6295_data_0_w(space, offset, data);
 			}
 			break;
 
 		case 0x202:		/* /WRP */
-			atarigen_6502_sound_w(offset, data);
+			atarigen_6502_sound_w(space, offset, data);
 			break;
 
 		case 0x204:		/* /WRIO */
@@ -672,7 +677,7 @@ static WRITE8_HANDLER( jsa3s_io_w )
 
 			/* update the OKI bank */
 			oki6295_bank_base = (0x40000 * ((data >> 1) & 1)) | (oki6295_bank_base & 0x80000);
-			OKIM6295_set_bank_base(0, oki6295_bank_base);
+			okim6295_set_bank_base(0, oki6295_bank_base);
 
 			/* update the bank */
 			memcpy(bank_base, &bank_source_data[0x1000 * ((data >> 6) & 3)], 0x1000);
@@ -683,8 +688,8 @@ static WRITE8_HANDLER( jsa3s_io_w )
 			coin_counter_w(0, (data >> 4) & 1);
 
 			/* update the OKI frequency */
-			OKIM6295_set_pin7(0, data & 8);
-			OKIM6295_set_pin7(1, data & 8);
+			okim6295_set_pin7(0, data & 8);
+			okim6295_set_pin7(1, data & 8);
 			break;
 
 		case 0x206:		/* /MIX */
@@ -698,13 +703,13 @@ static WRITE8_HANDLER( jsa3s_io_w )
 
 			/* update the OKI bank */
 			oki6295_bank_base = (0x80000 * ((data >> 4) & 1)) | (oki6295_bank_base & 0x40000);
-			OKIM6295_set_bank_base(0, oki6295_bank_base);
-			OKIM6295_set_bank_base(1, 0x40000 * (data >> 6));
+			okim6295_set_bank_base(0, oki6295_bank_base);
+			okim6295_set_bank_base(1, 0x40000 * (data >> 6));
 
 			/* update the volumes */
 			ym2151_volume = ((data >> 1) & 7) * 100 / 7;
 			oki6295_volume = 50 + (data & 1) * 50;
-			update_all_volumes(Machine);
+			update_all_volumes(space->machine);
 			break;
 	}
 }
@@ -735,9 +740,9 @@ static void update_all_volumes(running_machine *machine )
 
 static ADDRESS_MAP_START( atarijsa1_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_RAM
-	AM_RANGE(0x2000, 0x2000) AM_WRITE(YM2151_register_port_0_w)
-	AM_RANGE(0x2001, 0x2001) AM_WRITE(YM2151_data_port_0_w)
-	AM_RANGE(0x2000, 0x2001) AM_READ(YM2151_status_port_0_r)
+	AM_RANGE(0x2000, 0x2000) AM_WRITE(ym2151_register_port_0_w)
+	AM_RANGE(0x2001, 0x2001) AM_WRITE(ym2151_data_port_0_w)
+	AM_RANGE(0x2000, 0x2001) AM_READ(ym2151_status_port_0_r)
 	AM_RANGE(0x2800, 0x2bff) AM_READWRITE(jsa1_io_r, jsa1_io_w)
 	AM_RANGE(0x3000, 0xffff) AM_ROM
 ADDRESS_MAP_END
@@ -745,9 +750,9 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( atarijsa2_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_RAM
-	AM_RANGE(0x2000, 0x2000) AM_WRITE(YM2151_register_port_0_w)
-	AM_RANGE(0x2001, 0x2001) AM_WRITE(YM2151_data_port_0_w)
-	AM_RANGE(0x2000, 0x2001) AM_READ(YM2151_status_port_0_r)
+	AM_RANGE(0x2000, 0x2000) AM_WRITE(ym2151_register_port_0_w)
+	AM_RANGE(0x2001, 0x2001) AM_WRITE(ym2151_data_port_0_w)
+	AM_RANGE(0x2000, 0x2001) AM_READ(ym2151_status_port_0_r)
 	AM_RANGE(0x2800, 0x2bff) AM_READWRITE(jsa2_io_r, jsa2_io_w)
 	AM_RANGE(0x3000, 0xffff) AM_ROM
 ADDRESS_MAP_END
@@ -756,9 +761,9 @@ ADDRESS_MAP_END
 /* full map verified from schematics and Batman GALs */
 static ADDRESS_MAP_START( atarijsa3_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_RAM
-	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x07fe) AM_WRITE(YM2151_register_port_0_w)
-	AM_RANGE(0x2001, 0x2001) AM_MIRROR(0x07fe) AM_WRITE(YM2151_data_port_0_w)
-	AM_RANGE(0x2000, 0x2001) AM_MIRROR(0x07fe) AM_READ(YM2151_status_port_0_r)
+	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x07fe) AM_WRITE(ym2151_register_port_0_w)
+	AM_RANGE(0x2001, 0x2001) AM_MIRROR(0x07fe) AM_WRITE(ym2151_data_port_0_w)
+	AM_RANGE(0x2000, 0x2001) AM_MIRROR(0x07fe) AM_READ(ym2151_status_port_0_r)
 	AM_RANGE(0x2800, 0x2fff) AM_READWRITE(jsa3_io_r, jsa3_io_w)
 	AM_RANGE(0x3000, 0xffff) AM_ROM
 ADDRESS_MAP_END
@@ -766,9 +771,9 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( atarijsa3s_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_RAM
-	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x07fe) AM_WRITE(YM2151_register_port_0_w)
-	AM_RANGE(0x2001, 0x2001) AM_MIRROR(0x07fe) AM_WRITE(YM2151_data_port_0_w)
-	AM_RANGE(0x2000, 0x2001) AM_MIRROR(0x07fe) AM_READ(YM2151_status_port_0_r)
+	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x07fe) AM_WRITE(ym2151_register_port_0_w)
+	AM_RANGE(0x2001, 0x2001) AM_MIRROR(0x07fe) AM_WRITE(ym2151_data_port_0_w)
+	AM_RANGE(0x2000, 0x2001) AM_MIRROR(0x07fe) AM_READ(ym2151_status_port_0_r)
 	AM_RANGE(0x2800, 0x2fff) AM_READWRITE(jsa3s_io_r, jsa3s_io_w)
 	AM_RANGE(0x3000, 0xffff) AM_ROM
 ADDRESS_MAP_END
@@ -781,7 +786,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static const struct YM2151interface ym2151_interface =
+static const ym2151_interface ym2151_config =
 {
 	atarigen_ym2151_irq_gen
 };
@@ -798,15 +803,15 @@ static const struct YM2151interface ym2151_interface =
 MACHINE_DRIVER_START( jsa_i_stereo )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("jsa", M6502, JSA_MASTER_CLOCK/2)
+	MDRV_CPU_ADD("jsa", M6502, JSA_MASTER_CLOCK/2)
 	MDRV_CPU_PROGRAM_MAP(atarijsa1_map,0)
 	MDRV_CPU_PERIODIC_INT(atarigen_6502_irq_gen, (double)JSA_MASTER_CLOCK/4/16/16/14)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD_TAG("ym", YM2151, JSA_MASTER_CLOCK)
-	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ADD("ym", YM2151, JSA_MASTER_CLOCK)
+	MDRV_SOUND_CONFIG(ym2151_config)
 	MDRV_SOUND_ROUTE(0, "left", 0.60)
 	MDRV_SOUND_ROUTE(1, "right", 0.60)
 MACHINE_DRIVER_END
@@ -820,7 +825,7 @@ MACHINE_DRIVER_START( jsa_i_stereo_swapped )
 
 	/* sound hardware */
 	MDRV_SOUND_REPLACE("ym", YM2151, JSA_MASTER_CLOCK)
-	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_CONFIG(ym2151_config)
 	MDRV_SOUND_ROUTE(0, "right", 0.60)
 	MDRV_SOUND_ROUTE(1, "left", 0.60)
 MACHINE_DRIVER_END
@@ -833,7 +838,7 @@ MACHINE_DRIVER_START( jsa_i_stereo_pokey )
 	MDRV_IMPORT_FROM(jsa_i_stereo)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(POKEY, JSA_MASTER_CLOCK/2)
+	MDRV_SOUND_ADD("pokey", POKEY, JSA_MASTER_CLOCK/2)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.40)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.40)
 MACHINE_DRIVER_END
@@ -843,19 +848,19 @@ MACHINE_DRIVER_END
 MACHINE_DRIVER_START( jsa_i_mono_speech )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("jsa", M6502, JSA_MASTER_CLOCK/2)
+	MDRV_CPU_ADD("jsa", M6502, JSA_MASTER_CLOCK/2)
 	MDRV_CPU_PROGRAM_MAP(atarijsa1_map,0)
 	MDRV_CPU_PERIODIC_INT(atarigen_6502_irq_gen, (double)JSA_MASTER_CLOCK/4/16/16/14)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD_TAG("ym", YM2151, JSA_MASTER_CLOCK)
-	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ADD("ym", YM2151, JSA_MASTER_CLOCK)
+	MDRV_SOUND_CONFIG(ym2151_config)
 	MDRV_SOUND_ROUTE(0, "mono", 0.60)
 	MDRV_SOUND_ROUTE(1, "mono", 0.60)
 
-	MDRV_SOUND_ADD(TMS5220, JSA_MASTER_CLOCK*2/11) /* potentially JSA_MASTER_CLOCK/9 as well */
+	MDRV_SOUND_ADD("tms", TMS5220, JSA_MASTER_CLOCK*2/11) /* potentially JSA_MASTER_CLOCK/9 as well */
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -864,20 +869,20 @@ MACHINE_DRIVER_END
 MACHINE_DRIVER_START( jsa_ii_mono )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("jsa", M6502, JSA_MASTER_CLOCK/2)
+	MDRV_CPU_ADD("jsa", M6502, JSA_MASTER_CLOCK/2)
 	MDRV_CPU_PROGRAM_MAP(atarijsa2_map,0)
 	MDRV_CPU_PERIODIC_INT(atarigen_6502_irq_gen, (double)JSA_MASTER_CLOCK/4/16/16/14)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD_TAG("ym", YM2151, JSA_MASTER_CLOCK)
-	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ADD("ym", YM2151, JSA_MASTER_CLOCK)
+	MDRV_SOUND_CONFIG(ym2151_config)
 	MDRV_SOUND_ROUTE(0, "mono", 0.60)
 	MDRV_SOUND_ROUTE(1, "mono", 0.60)
 
-	MDRV_SOUND_ADD_TAG("adpcm", OKIM6295, JSA_MASTER_CLOCK/3)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high)
+	MDRV_SOUND_ADD("adpcm", OKIM6295, JSA_MASTER_CLOCK/3)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
 MACHINE_DRIVER_END
 
@@ -907,23 +912,66 @@ MACHINE_DRIVER_END
 MACHINE_DRIVER_START( jsa_iiis_stereo )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("jsa", M6502, JSA_MASTER_CLOCK/2)
+	MDRV_CPU_ADD("jsa", M6502, JSA_MASTER_CLOCK/2)
 	MDRV_CPU_PROGRAM_MAP(atarijsa3s_map,0)
 	MDRV_CPU_PERIODIC_INT(atarigen_6502_irq_gen, (double)JSA_MASTER_CLOCK/4/16/16/14)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD_TAG("ym", YM2151, JSA_MASTER_CLOCK)
-	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ADD("ym", YM2151, JSA_MASTER_CLOCK)
+	MDRV_SOUND_CONFIG(ym2151_config)
 	MDRV_SOUND_ROUTE(0, "left", 0.60)
 	MDRV_SOUND_ROUTE(1, "right", 0.60)
 
-	MDRV_SOUND_ADD(OKIM6295, JSA_MASTER_CLOCK/3)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high)
+	MDRV_SOUND_ADD("adpcml", OKIM6295, JSA_MASTER_CLOCK/3)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.75)
 
-	MDRV_SOUND_ADD(OKIM6295, JSA_MASTER_CLOCK/3)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high)
+	MDRV_SOUND_ADD("adpcmr", OKIM6295, JSA_MASTER_CLOCK/3)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.75)
 MACHINE_DRIVER_END
+
+
+/*************************************
+ *
+ *  Port definitions
+ *
+ *************************************/
+
+INPUT_PORTS_START( atarijsa_i )
+	PORT_START("JSAI")
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 )
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN3 )
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_UNUSED )	/* speech chip ready */
+	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_UNUSED )	/* output buffer full */
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )		/* input buffer full */
+	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )	/* self test */
+INPUT_PORTS_END
+
+INPUT_PORTS_START( atarijsa_ii )
+	PORT_START("JSAII")
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 )
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN3 )
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_UNUSED )	/* output buffer full */
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )		/* input buffer full */
+	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )	/* self test */
+INPUT_PORTS_END
+
+INPUT_PORTS_START( atarijsa_iii )
+	PORT_START("JSAIII")
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN2 )
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN1 )
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_TILT )
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_SERVICE )
+	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_UNUSED )	/* self test */
+	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_UNUSED )	/* output buffer full */
+	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED )	/* input buffer full */
+	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )	/* self test */
+INPUT_PORTS_END
