@@ -9,13 +9,15 @@
     6/27/99 Jim Hernandez -- 1st Attempt at Fixing Drone Star Castle sound and
                              pitch adjustments.
     6/30/99 MLR added Rip Off, Solar Quest, Armor Attack (no samples yet)
+    11/04/08 Jim Hernandez -- Fixed Drone Star Castle sound again. It was
+                              broken for a long time due to some changes.
 
     Bugs: Sometimes the death explosion (small explosion) does not trigger.
 
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
 #include "cpu/ccpu/ccpu.h"
 #include "cpu/z80/z80daisy.h"
 #include "machine/z80ctc.h"
@@ -50,7 +52,7 @@
  *
  *************************************/
 
-static void (*sound_handler)(UINT8 sound_val, UINT8 bits_changed);
+static void (*sound_handler)(running_machine *,UINT8 sound_val, UINT8 bits_changed);
 static UINT8 sound_control;
 
 /* general shift register variables */
@@ -83,7 +85,7 @@ WRITE8_HANDLER( cinemat_sound_control_w )
 
 	/* if something changed, call the sound subroutine */
 	if ((sound_control != oldval) && sound_handler)
-		(*sound_handler)(sound_control, sound_control ^ oldval);
+		(*sound_handler)(space->machine, sound_control, sound_control ^ oldval);
 }
 
 
@@ -94,7 +96,7 @@ WRITE8_HANDLER( cinemat_sound_control_w )
  *
  *************************************/
 
-static void generic_init(running_machine *machine, void (*callback)(UINT8, UINT8))
+static void generic_init(running_machine *machine, void (*callback)(running_machine *,UINT8, UINT8))
 {
 	/* call the standard init */
 	MACHINE_RESET_CALL(cinemat);
@@ -114,19 +116,19 @@ static void generic_init(running_machine *machine, void (*callback)(UINT8, UINT8
     last_frame = 0;
 
 	/* reset Star Castle pitch */
-    current_pitch = 0x20000;
+    current_pitch = 0x10000;
 
     /* register for save states */
-    state_save_register_global(sound_control);
-    state_save_register_global(current_shift);
-    state_save_register_global(last_shift);
-    state_save_register_global(last_shift2);
-    state_save_register_global(current_pitch);
-    state_save_register_global(last_frame);
-    state_save_register_global_array(sound_fifo);
-    state_save_register_global(sound_fifo_in);
-    state_save_register_global(sound_fifo_out);
-    state_save_register_global(last_portb_write);
+    state_save_register_global(machine, sound_control);
+    state_save_register_global(machine, current_shift);
+    state_save_register_global(machine, last_shift);
+    state_save_register_global(machine, last_shift2);
+    state_save_register_global(machine, current_pitch);
+    state_save_register_global(machine, last_frame);
+    state_save_register_global_array(machine, sound_fifo);
+    state_save_register_global(machine, sound_fifo_in);
+    state_save_register_global(machine, sound_fifo_out);
+    state_save_register_global(machine, last_portb_write);
 }
 
 
@@ -151,21 +153,21 @@ static const char *const spacewar_sample_names[] =
     0
 };
 
-static const struct Samplesinterface spacewar_samples_interface =
+static const samples_interface spacewar_samples_interface =
 {
 	8,
 	spacewar_sample_names
 };
 
-static void spacewar_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void spacewar_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
 	/* Explosion - rising edge */
 	if (SOUNDVAL_RISING_EDGE(0x01))
-		sample_start(0, (mame_rand(Machine) & 1) ? 0 : 6, 0);
+		sample_start(0, (mame_rand(machine) & 1) ? 0 : 6, 0);
 
 	/* Fire sound - rising edge */
 	if (SOUNDVAL_RISING_EDGE(0x02))
-		sample_start(1, (mame_rand(Machine) & 1) ? 1 : 7, 0);
+		sample_start(1, (mame_rand(machine) & 1) ? 1 : 7, 0);
 
 	/* Player 1 thrust - 0=on, 1=off */
 	if (SOUNDVAL_FALLING_EDGE(0x04))
@@ -206,7 +208,7 @@ MACHINE_DRIVER_START( spacewar_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(spacewar_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -228,13 +230,13 @@ static const char *const barrier_sample_names[] =
     0
 };
 
-static const struct Samplesinterface barrier_samples_interface =
+static const samples_interface barrier_samples_interface =
 {
 	3,
 	barrier_sample_names
 };
 
-static void barrier_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void barrier_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
 	/* Player die - rising edge */
 	if (SOUNDVAL_RISING_EDGE(0x01))
@@ -259,7 +261,7 @@ MACHINE_DRIVER_START( barrier_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(barrier_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -279,13 +281,13 @@ static const char *const speedfrk_sample_names[] =
     NULL
 };
 
-static const struct Samplesinterface speedfrk_samples_interface =
+static const samples_interface speedfrk_samples_interface =
 {
 	1,
 	speedfrk_sample_names
 };
 
-static void speedfrk_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void speedfrk_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
 	/* on the falling edge of bit 0x08, clock the inverse of bit 0x04 into the top of the shiftreg */
 	if (SOUNDVAL_FALLING_EDGE(0x08))
@@ -317,7 +319,7 @@ MACHINE_DRIVER_START( speedfrk_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(speedfrk_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -342,13 +344,13 @@ static const char *const starhawk_sample_names[] =
     NULL
 };
 
-static const struct Samplesinterface starhawk_samples_interface =
+static const samples_interface starhawk_samples_interface =
 {
 	5,
 	starhawk_sample_names
 };
 
-static void starhawk_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void starhawk_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
 	/* explosion - falling edge */
 	if (SOUNDVAL_FALLING_EDGE(0x01))
@@ -391,7 +393,7 @@ MACHINE_DRIVER_START( starhawk_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(starhawk_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -416,13 +418,13 @@ static const char *const sundance_sample_names[] =
     0
 };
 
-static const struct Samplesinterface sundance_samples_interface =
+static const samples_interface sundance_samples_interface =
 {
 	6,
 	sundance_sample_names
 };
 
-static void sundance_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void sundance_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
 	/* bong - falling edge */
 	if (SOUNDVAL_FALLING_EDGE(0x01))
@@ -459,7 +461,7 @@ MACHINE_DRIVER_START( sundance_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(sundance_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -484,13 +486,13 @@ static const char *const tailg_sample_names[] =
     NULL
 };
 
-static const struct Samplesinterface tailg_samples_interface =
+static const samples_interface tailg_samples_interface =
 {
 	6,
 	tailg_sample_names
 };
 
-static void tailg_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void tailg_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
 	/* the falling edge of bit 0x10 clocks bit 0x08 into the mux selected by bits 0x07 */
 	if (SOUNDVAL_FALLING_EDGE(0x10))
@@ -546,7 +548,7 @@ MACHINE_DRIVER_START( tailg_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(tailg_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -570,13 +572,13 @@ static const char *const warrior_sample_names[] =
     NULL
 };
 
-static const struct Samplesinterface warrior_samples_interface =
+static const samples_interface warrior_samples_interface =
 {
 	5,
 	warrior_sample_names
 };
 
-static void warrior_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void warrior_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
 	/* normal level - 0=on, 1=off */
 	if (SOUNDVAL_FALLING_EDGE(0x01))
@@ -613,7 +615,7 @@ MACHINE_DRIVER_START( warrior_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(warrior_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -639,13 +641,13 @@ static const char *const armora_sample_names[] =
     NULL
 };
 
-static const struct Samplesinterface armora_samples_interface =
+static const samples_interface armora_samples_interface =
 {
 	7,
 	armora_sample_names
 };
 
-static void armora_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void armora_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
 	/* on the rising edge of bit 0x10, clock bit 0x80 into the shift register */
 	if (SOUNDVAL_RISING_EDGE(0x10))
@@ -706,7 +708,7 @@ MACHINE_DRIVER_START( armora_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(armora_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -738,13 +740,13 @@ static const char *const ripoff_sample_names[] =
     NULL
 };
 
-static const struct Samplesinterface ripoff_samples_interface =
+static const samples_interface ripoff_samples_interface =
 {
 	6,
 	ripoff_sample_names
 };
 
-static void ripoff_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void ripoff_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
 	/* on the rising edge of bit 0x02, clock bit 0x01 into the shift register */
 	if (SOUNDVAL_RISING_EDGE(0x02))
@@ -796,7 +798,7 @@ MACHINE_DRIVER_START( ripoff_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(ripoff_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -823,15 +825,15 @@ static const char *const starcas_sample_names[] =
     0
 };
 
-static const struct Samplesinterface starcas_samples_interface =
+static const samples_interface starcas_samples_interface =
 {
 	8,
 	starcas_sample_names
 };
 
-static void starcas_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void starcas_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
-    UINT32 target_pitch;
+	UINT32 target_pitch;
 
 	/* on the rising edge of bit 0x10, clock bit 0x80 into the shift register */
 	if (SOUNDVAL_RISING_EDGE(0x10))
@@ -868,17 +870,17 @@ static void starcas_sound_w(UINT8 sound_val, UINT8 bits_changed)
 
 		/* latch the drone pitch */
 		target_pitch = (current_shift & 7) + ((current_shift & 2) << 2);
-        target_pitch = 0x10000 + (target_pitch << 12);
+        target_pitch = 0x5800 + (target_pitch << 12);
 
         /* once per frame slide the pitch toward the target */
-        if (cpu_getcurrentframe() > last_frame)
+        if (video_screen_get_frame_number(machine->primary_screen) > last_frame)
         {
             if (current_pitch > target_pitch)
-                current_pitch -= 300;
+                current_pitch -= 225;
             if (current_pitch < target_pitch)
-                current_pitch += 200;
+                current_pitch += 150;
             sample_set_freq(4, current_pitch);
-            last_frame = cpu_getcurrentframe();
+            last_frame = video_screen_get_frame_number(machine->primary_screen);
         }
 
 		/* remember the previous value */
@@ -908,7 +910,7 @@ MACHINE_DRIVER_START( starcas_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(starcas_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.5)
 MACHINE_DRIVER_END
@@ -935,15 +937,15 @@ static const char *const solarq_sample_names[] =
     NULL
 };
 
-static const struct Samplesinterface solarq_samples_interface =
+static const samples_interface solarq_samples_interface =
 {
 	8,
 	solarq_sample_names
 };
 
-static void solarq_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void solarq_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
-    static float target_volume, current_volume;
+	static float target_volume, current_volume;
 
 	/* on the rising edge of bit 0x10, clock bit 0x80 into the shift register */
 	if (SOUNDVAL_RISING_EDGE(0x10))
@@ -974,7 +976,7 @@ static void solarq_sound_w(UINT8 sound_val, UINT8 bits_changed)
 			target_volume = 0;
 
 		/* ramp the thrust volume */
-        if (sample_playing(2) && cpu_getcurrentframe() > last_frame)
+        if (sample_playing(2) && video_screen_get_frame_number(machine->primary_screen) > last_frame)
         {
             if (current_volume > target_volume)
                 current_volume -= 0.078f;
@@ -984,7 +986,7 @@ static void solarq_sound_w(UINT8 sound_val, UINT8 bits_changed)
                 sample_set_volume(2, current_volume);
             else
                 sample_stop(2);
-            last_frame = cpu_getcurrentframe();
+            last_frame = video_screen_get_frame_number(machine->primary_screen);
         }
 
 		/* fire - falling edge */
@@ -1043,7 +1045,7 @@ MACHINE_DRIVER_START( solarq_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(solarq_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.5)
 MACHINE_DRIVER_END
@@ -1074,13 +1076,13 @@ static const char *const boxingb_sample_names[] =
     NULL
 };
 
-static const struct Samplesinterface boxingb_samples_interface =
+static const samples_interface boxingb_samples_interface =
 {
 	12,
 	boxingb_sample_names
 };
 
-static void boxingb_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void boxingb_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
 	/* on the rising edge of bit 0x10, clock bit 0x80 into the shift register */
 	if (SOUNDVAL_RISING_EDGE(0x10))
@@ -1176,7 +1178,7 @@ MACHINE_DRIVER_START( boxingb_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(boxingb_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -1203,15 +1205,15 @@ static const char *const wotw_sample_names[] =
     0
 };
 
-static const struct Samplesinterface wotw_samples_interface =
+static const samples_interface wotw_samples_interface =
 {
 	8,
 	wotw_sample_names
 };
 
-static void wotw_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void wotw_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
-    UINT32 target_pitch;
+	UINT32 target_pitch;
 
 	/* on the rising edge of bit 0x10, clock bit 0x80 into the shift register */
 	if (SOUNDVAL_RISING_EDGE(0x10))
@@ -1251,14 +1253,14 @@ static void wotw_sound_w(UINT8 sound_val, UINT8 bits_changed)
         target_pitch = 0x10000 + (target_pitch << 12);
 
         /* once per frame slide the pitch toward the target */
-        if (cpu_getcurrentframe() > last_frame)
+        if (video_screen_get_frame_number(machine->primary_screen) > last_frame)
         {
             if (current_pitch > target_pitch)
                 current_pitch -= 300;
             if (current_pitch < target_pitch)
                 current_pitch += 200;
             sample_set_freq(4, current_pitch);
-            last_frame = cpu_getcurrentframe();
+            last_frame = video_screen_get_frame_number(machine->primary_screen);
         }
 
 		/* remember the previous value */
@@ -1288,7 +1290,7 @@ MACHINE_DRIVER_START( wotw_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(wotw_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -1315,15 +1317,15 @@ static const char *const wotwc_sample_names[] =
     0
 };
 
-static const struct Samplesinterface wotwc_samples_interface =
+static const samples_interface wotwc_samples_interface =
 {
 	8,
 	wotwc_sample_names
 };
 
-static void wotwc_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void wotwc_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
-    UINT32 target_pitch;
+	UINT32 target_pitch;
 
 	/* on the rising edge of bit 0x10, clock bit 0x80 into the shift register */
 	if (SOUNDVAL_RISING_EDGE(0x10))
@@ -1363,14 +1365,14 @@ static void wotwc_sound_w(UINT8 sound_val, UINT8 bits_changed)
         target_pitch = 0x10000 + (target_pitch << 12);
 
         /* once per frame slide the pitch toward the target */
-        if (cpu_getcurrentframe() > last_frame)
+        if (video_screen_get_frame_number(machine->primary_screen) > last_frame)
         {
             if (current_pitch > target_pitch)
                 current_pitch -= 300;
             if (current_pitch < target_pitch)
                 current_pitch += 200;
             sample_set_freq(4, current_pitch);
-            last_frame = cpu_getcurrentframe();
+            last_frame = video_screen_get_frame_number(machine->primary_screen);
         }
 
 		/* remember the previous value */
@@ -1400,7 +1402,7 @@ MACHINE_DRIVER_START( wotwc_sound )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(wotwc_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -1420,14 +1422,14 @@ static TIMER_CALLBACK( synced_sound_w )
 }
 
 
-static void demon_sound_w(UINT8 sound_val, UINT8 bits_changed)
+static void demon_sound_w(running_machine *machine, UINT8 sound_val, UINT8 bits_changed)
 {
 	/* all inputs are inverted */
 	sound_val = ~sound_val;
 
 	/* watch for a 0->1 edge on bit 4 ("shift in") to clock in the new data */
 	if ((bits_changed & 0x10) && (sound_val & 0x10))
-		timer_call_after_resynch(NULL, sound_val & 0x0f, synced_sound_w);
+		timer_call_after_resynch(machine, NULL, sound_val & 0x0f, synced_sound_w);
 }
 
 
@@ -1469,16 +1471,20 @@ static WRITE8_HANDLER( sound_output_w )
 }
 
 
-static const struct AY8910interface demon_ay8910_interface_1 =
+static const ay8910_interface demon_ay8910_interface_1 =
 {
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
 	sound_porta_r,
 	sound_portb_r,
 	0,
 	sound_portb_w
 };
 
-static const struct AY8910interface demon_ay8910_interface_3 =
+static const ay8910_interface demon_ay8910_interface_3 =
 {
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
 	0,
 	0,
 	0,
@@ -1486,15 +1492,14 @@ static const struct AY8910interface demon_ay8910_interface_3 =
 };
 
 
-static void ctc_interrupt(int state)
+static void ctc_interrupt(const device_config *device, int state)
 {
-	cpunum_set_input_line(Machine, 1, 0, state);
+	cpu_set_input_line(device->machine->cpu[1], 0, state);
 }
 
 
 static z80ctc_interface demon_z80ctc_interface =
 {
-	0,               /* clock (filled in from the CPU clock) */
 	0,               /* timer disables */
 	ctc_interrupt,   /* interrupt handler */
 	0,               /* ZC/TO0 callback */
@@ -1508,71 +1513,68 @@ static MACHINE_RESET( demon_sound )
 	/* generic init */
 	generic_init(machine, demon_sound_w);
 
-	/* initialize the CTC interface */
-	demon_z80ctc_interface.baseclock = cpunum_get_clock(1);
-	z80ctc_init(0, &demon_z80ctc_interface);
-
 	/* reset the FIFO */
 	sound_fifo_in = sound_fifo_out = 0;
 	last_portb_write = 0xff;
 
 	/* turn off channel A on AY8910 #0 because it is used as a low-pass filter */
-	AY8910_set_volume(0, 0, 0);
+	ay8910_set_volume(0, 0, 0);
 }
 
 
 static ADDRESS_MAP_START( demon_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM
 	AM_RANGE(0x3000, 0x33ff) AM_RAM
-	AM_RANGE(0x4001, 0x4001) AM_READ(AY8910_read_port_0_r)
-	AM_RANGE(0x4002, 0x4002) AM_WRITE(AY8910_write_port_0_w)
-	AM_RANGE(0x4003, 0x4003) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0x5001, 0x5001) AM_READ(AY8910_read_port_1_r)
-	AM_RANGE(0x5002, 0x5002) AM_WRITE(AY8910_write_port_1_w)
-	AM_RANGE(0x5003, 0x5003) AM_WRITE(AY8910_control_port_1_w)
-	AM_RANGE(0x6001, 0x6001) AM_READ(AY8910_read_port_2_r)
-	AM_RANGE(0x6002, 0x6002) AM_WRITE(AY8910_write_port_2_w)
-	AM_RANGE(0x6003, 0x6003) AM_WRITE(AY8910_control_port_2_w)
-	AM_RANGE(0x7000, 0x7000) AM_WRITE(MWA8_NOP)  /* watchdog? */
+	AM_RANGE(0x4001, 0x4001) AM_READ(ay8910_read_port_0_r)
+	AM_RANGE(0x4002, 0x4002) AM_WRITE(ay8910_write_port_0_w)
+	AM_RANGE(0x4003, 0x4003) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0x5001, 0x5001) AM_READ(ay8910_read_port_1_r)
+	AM_RANGE(0x5002, 0x5002) AM_WRITE(ay8910_write_port_1_w)
+	AM_RANGE(0x5003, 0x5003) AM_WRITE(ay8910_control_port_1_w)
+	AM_RANGE(0x6001, 0x6001) AM_READ(ay8910_read_port_2_r)
+	AM_RANGE(0x6002, 0x6002) AM_WRITE(ay8910_write_port_2_w)
+	AM_RANGE(0x6003, 0x6003) AM_WRITE(ay8910_control_port_2_w)
+	AM_RANGE(0x7000, 0x7000) AM_WRITE(SMH_NOP)  /* watchdog? */
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( demon_sound_ports, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x00, 0x03) AM_WRITE(z80ctc_0_w)
-	AM_RANGE(0x1c, 0x1f) AM_WRITE(z80ctc_0_w)
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x00, 0x03) AM_DEVWRITE(Z80CTC, "ctc", z80ctc_w)
+	AM_RANGE(0x1c, 0x1f) AM_DEVWRITE(Z80CTC, "ctc", z80ctc_w)
 ADDRESS_MAP_END
 
 
-static const struct z80_irq_daisy_chain daisy_chain[] =
+static const z80_daisy_chain daisy_chain[] =
 {
-	{ z80ctc_reset, z80ctc_irq_state, z80ctc_irq_ack, z80ctc_irq_reti, 0 },
-	{ 0,0,0,0,-1 }
+	{ Z80CTC, "ctc" },
+	{ NULL }
 };
 
 
 MACHINE_DRIVER_START( demon_sound )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80, 3579545)
-	/* audio CPU */
+	MDRV_CPU_ADD("audio", Z80, 3579545)
 	MDRV_CPU_CONFIG(daisy_chain)
 	MDRV_CPU_PROGRAM_MAP(demon_sound_map,0)
 	MDRV_CPU_IO_MAP(demon_sound_ports,0)
 
+	MDRV_Z80CTC_ADD("ctc", 3579545 /* same as "audio" */, demon_z80ctc_interface)
+
 	MDRV_MACHINE_RESET(demon_sound)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, 3579545)
+	MDRV_SOUND_ADD("ay1", AY8910, 3579545)
 	MDRV_SOUND_CONFIG(demon_ay8910_interface_1)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD(AY8910, 3579545)
+	MDRV_SOUND_ADD("ay2", AY8910, 3579545)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD(AY8910, 3579545)
+	MDRV_SOUND_ADD("ay3", AY8910, 3579545)
 	MDRV_SOUND_CONFIG(demon_ay8910_interface_3)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
@@ -1587,19 +1589,19 @@ MACHINE_DRIVER_END
 
 static WRITE8_HANDLER( qb3_sound_w )
 {
-	UINT16 rega = cpunum_get_reg(0, CCPU_A);
-	demon_sound_w(0x00 | (~rega & 0x0f), 0x10);
+	UINT16 rega = cpu_get_reg(space->machine->cpu[0], CCPU_A);
+	demon_sound_w(space->machine, 0x00 | (~rega & 0x0f), 0x10);
 }
 
 
 static MACHINE_RESET( qb3_sound )
 {
 	MACHINE_RESET_CALL(demon_sound);
-	memory_install_write8_handler(0, ADDRESS_SPACE_IO, 0x04, 0x04, 0, 0, qb3_sound_w);
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_IO), 0x04, 0x04, 0, 0, qb3_sound_w);
 
 	/* this patch prevents the sound ROM from eating itself when command $0A is sent */
 	/* on a cube rotate */
-	memory_region(REGION_CPU2)[0x11dc] = 0x09;
+	memory_region(machine, "audio")[0x11dc] = 0x09;
 }
 
 
