@@ -5,14 +5,16 @@
 *************************************************************************/
 
 #include "driver.h"
-#include "rescap.h"
+#include "cpu/z80/z80.h"
+#include "machine/rescap.h"
 #include "streams.h"
-#include "deprecat.h"
 #include "cpu/m6502/m6502.h"
 #include "machine/6821pia.h"
+#include "machine/6532riot.h"
 #include "sound/hc55516.h"
 #include "sound/5220intf.h"
 #include "sound/custom.h"
+#include "exidy.h"
 
 
 
@@ -49,16 +51,7 @@ enum
 static UINT8 riot_irq_state;
 
 /* 6532 variables */
-static emu_timer *riot_timer;
-static UINT8 riot_irq_flag;
-static UINT8 riot_timer_irq_enable;
-static UINT8 riot_PA7_irq_enable;
-static UINT8 riot_porta_data;
-static UINT8 riot_porta_ddr;
-static UINT8 riot_portb_data;
-static UINT8 riot_portb_ddr;
-static int riot_clock_divisor;
-static UINT8 riot_state;
+static const device_config *riot;
 
 /* 6840 variables */
 struct sh6840_timer_channel
@@ -82,10 +75,10 @@ static struct sh6840_timer_channel sh6840_timer[3];
 static INT16 sh6840_volume[3];
 static UINT8 sh6840_MSB;
 static UINT8 sh6840_LFSR_oldxor = 0; /* should be saved in savestate */
-static UINT32 sh6840_LFSR_0 = 0xffffffff;/* ditto */
-static UINT32 sh6840_LFSR_1 = 0xffffffff;/* ditto */
-static UINT32 sh6840_LFSR_2 = 0xffffffff;/* ditto */
-static UINT32 sh6840_LFSR_3 = 0xffffffff;/* ditto */
+static UINT32 sh6840_LFSR_0;/* ditto */
+static UINT32 sh6840_LFSR_1;/* ditto */
+static UINT32 sh6840_LFSR_2;/* ditto */
+static UINT32 sh6840_LFSR_3;/* ditto */
 static UINT32 sh6840_clocks_per_sample;
 static UINT32 sh6840_clock_count;
 
@@ -113,25 +106,15 @@ static double freq_to_step;
 
 
 
-/*************************************
- *
- *  Prototypes
- *
- *************************************/
-
-static TIMER_CALLBACK( riot_interrupt );
-
-
-
 /*************************************
  *
  *  Interrupt generation helper
  *
  *************************************/
 
-static void update_irq_state(/* unused */ int state)
+static void update_irq_state(running_machine *machine, /* unused */ int state)
 {
-	cpunum_set_input_line(Machine, 1, M6502_IRQ_LINE, (pia_get_irq_b(1) | riot_irq_state) ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[1], M6502_IRQ_LINE, (pia_get_irq_b(1) | riot_irq_state) ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -233,19 +216,58 @@ INLINE int sh6840_update_noise(int clocks)
 
 
 
+/*************************************
+ *
+ *  6840 state saving
+ *
+ *************************************/
+
+static void sh6840_register_state_globals(running_machine *machine)
+{
+    state_save_register_global_array(machine, sh6840_volume);
+    state_save_register_global(machine, sh6840_MSB);
+    state_save_register_global(machine, sh6840_LFSR_oldxor);
+    state_save_register_global(machine, sh6840_LFSR_0);
+    state_save_register_global(machine, sh6840_LFSR_1);
+    state_save_register_global(machine, sh6840_LFSR_2);
+    state_save_register_global(machine, sh6840_LFSR_3);
+    state_save_register_global(machine, sh6840_clock_count);
+    state_save_register_global(machine, exidy_sfxctrl);
+    state_save_register_global(machine, sh6840_timer[0].cr);
+    state_save_register_global(machine, sh6840_timer[0].state);
+    state_save_register_global(machine, sh6840_timer[0].leftovers);
+    state_save_register_global(machine, sh6840_timer[0].timer);
+    state_save_register_global(machine, sh6840_timer[0].clocks);
+    state_save_register_global(machine, sh6840_timer[0].counter.w);
+    state_save_register_global(machine, sh6840_timer[1].cr);
+    state_save_register_global(machine, sh6840_timer[1].state);
+    state_save_register_global(machine, sh6840_timer[1].leftovers);
+    state_save_register_global(machine, sh6840_timer[1].timer);
+    state_save_register_global(machine, sh6840_timer[1].clocks);
+    state_save_register_global(machine, sh6840_timer[1].counter.w);
+    state_save_register_global(machine, sh6840_timer[2].cr);
+    state_save_register_global(machine, sh6840_timer[2].state);
+    state_save_register_global(machine, sh6840_timer[2].leftovers);
+    state_save_register_global(machine, sh6840_timer[2].timer);
+    state_save_register_global(machine, sh6840_timer[2].clocks);
+    state_save_register_global(machine, sh6840_timer[2].counter.w);
+}
+
+
+
 /*************************************
  *
  *  Core sound generation
  *
  *************************************/
 
-static void exidy_stream_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int length)
+static STREAM_UPDATE( exidy_stream_update )
 {
 	int noisy = ((sh6840_timer[0].cr & sh6840_timer[1].cr & sh6840_timer[2].cr & 0x02) == 0);
 	stream_sample_t *buffer = outputs[0];
 
 	/* loop over samples */
-	while (length--)
+	while (samples--)
 	{
 		struct sh6840_timer_channel *t;
 		struct sh8253_timer_channel *c;
@@ -355,21 +377,28 @@ static void exidy_stream_update(void *param, stream_sample_t **inputs, stream_sa
  *
  *************************************/
 
-void *exidy_sh6840_sh_start(int clock, const struct CustomSound_interface *config)
+static void *common_sh_start(const device_config *device, int clock, const custom_sound_interface *config)
 {
 	int sample_rate = SH8253_CLOCK;
 
 	sh6840_clocks_per_sample = (int)((double)SH6840_CLOCK / (double)sample_rate * (double)(1 << 24));
 
 	/* allocate the stream */
-	exidy_stream = stream_create(0, 1, sample_rate, NULL, exidy_stream_update);
+	exidy_stream = stream_create(device, 0, 1, sample_rate, NULL, exidy_stream_update);
 
+    sh6840_register_state_globals(device->machine);
+
+	return auto_malloc(1);
+}
+
+CUSTOM_START( exidy_sh6840_sh_start )
+{
 	/* indicate no additional hardware */
 	has_sh8253  = FALSE;
 	has_tms5220 = FALSE;
 	has_mc3417 = FALSE;
 
-	return auto_malloc(1);
+	return common_sh_start(device, clock, config);
 }
 
 
@@ -380,7 +409,7 @@ void *exidy_sh6840_sh_start(int clock, const struct CustomSound_interface *confi
  *
  *************************************/
 
-void exidy_sh6840_sh_reset(void *token)
+static void common_sh_reset(void *token)
 {
 	/* 6840 */
 	memset(sh6840_timer, 0, sizeof(sh6840_timer));
@@ -388,6 +417,7 @@ void exidy_sh6840_sh_reset(void *token)
 	sh6840_volume[0] = 0;
 	sh6840_volume[1] = 0;
 	sh6840_volume[2] = 0;
+    sh6840_clock_count = 0;
 	exidy_sfxctrl = 0;
 
 	/* LFSR */
@@ -398,183 +428,102 @@ void exidy_sh6840_sh_reset(void *token)
 	sh6840_LFSR_3 = 0xffffffff;
 }
 
-
-
-/*************************************
- *
- *  6532 RIOT timer callback
- *
- *************************************/
-
-static TIMER_CALLBACK( riot_interrupt )
+CUSTOM_RESET( exidy_sh6840_sh_reset )
 {
-	/* if we're doing the initial interval counting... */
-	if (riot_state == RIOT_COUNT)
-	{
-		/* generate the IRQ */
-		riot_irq_flag |= 0x80;
-		riot_irq_state = riot_timer_irq_enable;
-		update_irq_state(0);
-
-		/* now start counting clock cycles down */
-		riot_state = RIOT_POST_COUNT;
-		timer_adjust(riot_timer, attotime_mul(ATTOTIME_IN_HZ(SH6532_CLOCK), 0xff), 0, attotime_zero);
-	}
-
-	/* if not, we are done counting down */
-	else
-	{
-		riot_state = RIOT_IDLE;
-		timer_adjust(riot_timer, attotime_never, 0, attotime_never);
-	}
+	common_sh_reset(token);
 }
 
 
 
 /*************************************
  *
- *  6532 RIOT write handler
+ *  6532 interface
  *
  *************************************/
 
-static WRITE8_HANDLER( exidy_shriot_w )
+static void r6532_irq(const device_config *device, int state)
 {
-	/* I/O is done if A2 == 0 */
-	if ((offset & 0x04) == 0)
+	riot_irq_state = (state == ASSERT_LINE) ? 1 : 0;
+	update_irq_state(device->machine, 0);
+}
+
+
+static void r6532_porta_w(const device_config *device, UINT8 newdata, UINT8 olddata)
+{
+	if (has_mc3417)
+		cpu_set_input_line(device->machine->cpu[2], INPUT_LINE_RESET, (newdata & 0x10) ? CLEAR_LINE : ASSERT_LINE);
+}
+
+
+static void r6532_portb_w(const device_config *device, UINT8 newdata, UINT8 olddata)
+{
+	const address_space *space = cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	if (has_tms5220)
 	{
-		switch (offset & 0x03)
+		if ((olddata & 0x01) && !(newdata & 0x01))
 		{
-			case 0:	/* port A */
-				if (has_mc3417)
-					cpunum_set_input_line(Machine, 2, INPUT_LINE_RESET, (data & 0x10) ? CLEAR_LINE : ASSERT_LINE);
-				riot_porta_data = (riot_porta_data & ~riot_porta_ddr) | (data & riot_porta_ddr);
-				break;
-
-			case 1:	/* port A DDR */
-				riot_porta_ddr = data;
-				break;
-
-			case 2:	/* port B */
-				if (has_tms5220)
-				{
-					if (!(data & 0x01) && (riot_portb_data & 0x01))
-					{
-						riot_porta_data = tms5220_status_r(0);
-						logerror("(%f)%04X:TMS5220 status read = %02X\n", attotime_to_double(timer_get_time()), activecpu_get_previouspc(), riot_porta_data);
-					}
-					if (!(data & 0x02) && (riot_portb_data & 0x02))
-					{
-						logerror("(%f)%04X:TMS5220 data write = %02X\n", attotime_to_double(timer_get_time()), activecpu_get_previouspc(), riot_porta_data);
-						tms5220_data_w(0, riot_porta_data);
-					}
-				}
-				riot_portb_data = (riot_portb_data & ~riot_portb_ddr) | (data & riot_portb_ddr);
-				break;
-
-			case 3:	/* port B DDR */
-				riot_portb_ddr = data;
-				break;
+			riot6532_porta_in_set(riot, tms5220_status_r(space, 0), 0xff);
+			logerror("(%f)%s:TMS5220 status read = %02X\n", attotime_to_double(timer_get_time(device->machine)), cpuexec_describe_context(device->machine), tms5220_status_r(space, 0));
+		}
+		if ((olddata & 0x02) && !(newdata & 0x02))
+		{
+			logerror("(%f)%s:TMS5220 data write = %02X\n", attotime_to_double(timer_get_time(device->machine)), cpuexec_describe_context(device->machine), riot6532_porta_out_get(riot));
+			tms5220_data_w(space, 0, riot6532_porta_out_get(riot));
 		}
 	}
-
-	/* PA7 edge detect control if A2 == 1 and A4 == 0 */
-	else if ((offset & 0x10) == 0)
-	{
-		riot_PA7_irq_enable = offset & 0x03;
-	}
-
-	/* timer enable if A2 == 1 and A4 == 1 */
-	else
-	{
-		static const int divisors[4] = { 1, 8, 64, 1024 };
-
-		/* make sure the IRQ state is clear */
-		if (riot_state != RIOT_COUNT)
-			riot_irq_flag &= ~0x80;
-		riot_irq_state = 0;
-		update_irq_state(0);
-
-		/* set the enable from the offset */
-		riot_timer_irq_enable = (offset & 0x08) ? 1 : 0;
-
-		/* set a new timer */
-		riot_clock_divisor = divisors[offset & 0x03];
-		timer_adjust(riot_timer, attotime_mul(ATTOTIME_IN_HZ(SH6532_CLOCK), data * riot_clock_divisor), 0, attotime_zero);
-		riot_state = RIOT_COUNT;
-	}
 }
 
 
+static UINT8 r6532_portb_r(const device_config *device, UINT8 olddata)
+{
+	UINT8 newdata = olddata;
+	if (has_tms5220)
+	{
+		newdata &= ~0x0c;
+		if (!tms5220_ready_r()) newdata |= 0x04;
+		if (!tms5220_int_r()) newdata |= 0x08;
+	}
+	return newdata;
+}
+
+
+static const riot6532_interface r6532_interface =
+{
+	NULL,					/* port A read handler */
+	r6532_portb_r,			/* port B read handler */
+	r6532_porta_w,			/* port A write handler */
+	r6532_portb_w,			/* port B write handler */
+	r6532_irq				/* IRQ callback */
+};
+
+
 
 /*************************************
  *
- *  6532 RIOT read handler
+ *  8253 state saving
  *
  *************************************/
 
-static READ8_HANDLER( exidy_shriot_r )
+
+static void sh8253_register_state_globals(running_machine *machine)
 {
-	/* I/O is done if A2 == 0 */
-	if ((offset & 0x04) == 0)
-	{
-		switch (offset & 0x03)
-		{
-			case 0x00:	/* port A */
-				return riot_porta_data;
-
-			case 0x01:	/* port A DDR */
-				return riot_porta_ddr;
-
-			case 0x02:	/* port B */
-				if (has_tms5220)
-				{
-					riot_portb_data &= ~0x0c;
-					if (!tms5220_ready_r()) riot_portb_data |= 0x04;
-					if (!tms5220_int_r()) riot_portb_data |= 0x08;
-				}
-				return riot_portb_data;
-
-			case 0x03:	/* port B DDR */
-				return riot_portb_ddr;
-		}
-	}
-
-	/* interrupt flags are read if A2 == 1 and A0 == 1 */
-	else if (offset & 0x01)
-	{
-		int temp = riot_irq_flag;
-		riot_irq_flag = 0;
-		riot_irq_state = 0;
-		update_irq_state(0);
-		return temp;
-	}
-
-	/* timer count is read if A2 == 1 and A0 == 0 */
-	else
-	{
-		/* set the enable from the offset */
-		riot_timer_irq_enable = offset & 0x08;
-
-		/* compute the timer based on the current state */
-		switch (riot_state)
-		{
-			case RIOT_IDLE:
-				return 0x00;
-
-			case RIOT_COUNT:
-				return attotime_to_double(timer_timeleft(riot_timer)) * SH6532_CLOCK / riot_clock_divisor;
-
-			case RIOT_POST_COUNT:
-				return attotime_to_double(timer_timeleft(riot_timer)) * SH6532_CLOCK;
-		}
-	}
-
-	logerror("Undeclared RIOT read: %x  PC:%x\n",offset,activecpu_get_pc());
-	return 0xff;
+    state_save_register_global(machine, sh8253_timer[0].clstate);
+    state_save_register_global(machine, sh8253_timer[0].enable);
+    state_save_register_global(machine, sh8253_timer[0].count);
+    state_save_register_global(machine, sh8253_timer[0].step);
+    state_save_register_global(machine, sh8253_timer[0].fraction);
+    state_save_register_global(machine, sh8253_timer[1].clstate);
+    state_save_register_global(machine, sh8253_timer[1].enable);
+    state_save_register_global(machine, sh8253_timer[1].count);
+    state_save_register_global(machine, sh8253_timer[1].step);
+    state_save_register_global(machine, sh8253_timer[1].fraction);
+    state_save_register_global(machine, sh8253_timer[2].clstate);
+    state_save_register_global(machine, sh8253_timer[2].enable);
+    state_save_register_global(machine, sh8253_timer[2].count);
+    state_save_register_global(machine, sh8253_timer[2].step);
+    state_save_register_global(machine, sh8253_timer[2].fraction);
 }
 
-
-
 /*************************************
  *
  *  8253 timer handlers
@@ -634,8 +583,7 @@ static READ8_HANDLER( exidy_sh8253_r )
 
 static READ8_HANDLER( exidy_sh6840_r )
 {
-	fatalerror("exidy_sh6840_r - unexpected read");
-
+	logerror("%04X:exidy_sh6840_r - unexpected read", cpu_get_pc(space->cpu));
 	return 0;
 }
 
@@ -726,7 +674,7 @@ WRITE8_HANDLER( exidy_sfxctrl_w )
  *
  *************************************/
 
-WRITE8_HANDLER( exidy_sound_filter_w )
+static WRITE8_HANDLER( exidy_sound_filter_w )
 {
 	logerror("exidy_sound_filter_w = %02X\n", data);
 }
@@ -755,11 +703,14 @@ static const pia6821_interface venture_pia_1_intf =
 };
 
 
-static void *venture_common_sh_start(int clock, const struct CustomSound_interface *config, int _has_tms5220)
+static void *venture_common_sh_start(const device_config *device, int clock, const custom_sound_interface *config, int _has_tms5220)
 {
+	running_machine *machine = device->machine;
 	int i;
 
-	void *ret = exidy_sh6840_sh_start(clock, config);
+	void *ret = common_sh_start(device, clock, config);
+
+	riot = device_list_find_by_tag(machine->config->devicelist, RIOT6532, "riot");
 
 	has_sh8253  = TRUE;
 	has_tms5220 = _has_tms5220;
@@ -768,50 +719,46 @@ static void *venture_common_sh_start(int clock, const struct CustomSound_interfa
 	has_mc3417 = FALSE;
 	for (i = 0; i < MAX_SOUND; i++)
 	{
-		if (Machine->drv->sound[i].type == SOUND_MC3417)
+		if (machine->config->sound[i].type == SOUND_MC3417)
 			has_mc3417 = TRUE;
 	}
 
-	/* 6532 */
-    riot_timer = timer_alloc(riot_interrupt, NULL);
-
 	/* 8253 */
 	freq_to_step = (double)(1 << 24) / (double)SH8253_CLOCK;
 
+    state_save_register_global(machine, riot_irq_state);
+    sh8253_register_state_globals(device->machine);
+
 	return ret;
 }
 
 
-static void *venture_sh_start(int clock, const struct CustomSound_interface *config)
+static CUSTOM_START( venture_sh_start )
 {
-	pia_config(0, &venture_pia_0_intf);
-	pia_config(1, &venture_pia_1_intf);
+	running_machine *machine = device->machine;
+	pia_config(machine, 0, &venture_pia_0_intf);
+	pia_config(machine, 1, &venture_pia_1_intf);
 
-	return venture_common_sh_start(clock, config, FALSE);
+	return venture_common_sh_start(device, clock, config, FALSE);
 }
 
 
-static void venture_sh_reset(void *token)
+static CUSTOM_RESET( venture_sh_reset )
 {
-	exidy_sh6840_sh_reset(token);
+	common_sh_reset(token);
 
 	/* PIA */
 	pia_reset();
 
 	/* 6532 */
-	riot_irq_flag = 0;
-	riot_timer_irq_enable = 0;
-	riot_porta_data = 0xff;
-	riot_portb_data = 0xff;
-	riot_clock_divisor = 1;
-	riot_state = RIOT_IDLE;
+	device_reset(riot);
 
 	/* 8253 */
 	memset(sh8253_timer, 0, sizeof(sh8253_timer));
 }
 
 
-static const struct CustomSound_interface venture_custom_interface =
+static const custom_sound_interface venture_custom_interface =
 {
 	venture_sh_start,
 	0,
@@ -820,9 +767,9 @@ static const struct CustomSound_interface venture_custom_interface =
 
 
 static ADDRESS_MAP_START( venture_audio_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(15) )
+	ADDRESS_MAP_GLOBAL_MASK(0x7fff)
 	AM_RANGE(0x0000, 0x007f) AM_MIRROR(0x0780) AM_RAM
-	AM_RANGE(0x0800, 0x087f) AM_MIRROR(0x0780) AM_READWRITE(exidy_shriot_r, exidy_shriot_w)
+	AM_RANGE(0x0800, 0x087f) AM_MIRROR(0x0780) AM_DEVREADWRITE(RIOT6532, "riot", riot6532_r, riot6532_w)
 	AM_RANGE(0x1000, 0x1003) AM_MIRROR(0x07fc) AM_READWRITE(pia_1_r, pia_1_w)
 	AM_RANGE(0x1800, 0x1803) AM_MIRROR(0x07fc) AM_READWRITE(exidy_sh8253_r, exidy_sh8253_w)
 	AM_RANGE(0x2000, 0x27ff) AM_WRITE(exidy_sound_filter_w)
@@ -834,12 +781,14 @@ ADDRESS_MAP_END
 
 MACHINE_DRIVER_START( venture_audio )
 
-	MDRV_CPU_ADD(M6502, 3579545/4)
+	MDRV_CPU_ADD("audio", M6502, 3579545/4)
 	MDRV_CPU_PROGRAM_MAP(venture_audio_map,0)
 
+	MDRV_RIOT6532_ADD("riot", SH6532_CLOCK, r6532_interface)
+
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(CUSTOM, 0)
+	MDRV_SOUND_ADD("custom", CUSTOM, 0)
 	MDRV_SOUND_CONFIG(venture_custom_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -858,7 +807,7 @@ static WRITE8_HANDLER( mtrap_voiceio_w )
 		hc55516_digit_w(0, data & 1);
 
 	if (!(offset & 0x20))
-		riot_portb_data = data & 1;
+		riot6532_portb_in_set(riot, data & 1, 0xff);
 }
 
 
@@ -866,10 +815,10 @@ static READ8_HANDLER( mtrap_voiceio_r )
 {
 	if (!(offset & 0x80))
 	{
-		int data = (riot_porta_data & 0x06) >> 1;
-		data |= (riot_porta_data & 0x01) << 2;
-		data |= (riot_porta_data & 0x08);
-
+		UINT8 porta = riot6532_porta_out_get(riot);
+		UINT8 data = (porta & 0x06) >> 1;
+		data |= (porta & 0x01) << 2;
+		data |= (porta & 0x08);
 		return data;
 	}
 
@@ -881,25 +830,25 @@ static READ8_HANDLER( mtrap_voiceio_r )
 
 
 static ADDRESS_MAP_START( cvsd_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(14) )
+	ADDRESS_MAP_GLOBAL_MASK(0x3fff)
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( cvsd_iomap, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0xff) AM_READWRITE(mtrap_voiceio_r, mtrap_voiceio_w)
 ADDRESS_MAP_END
 
 
 MACHINE_DRIVER_START( mtrap_cvsd_audio )
 
-	MDRV_CPU_ADD(Z80, CVSD_Z80_CLOCK)
+	MDRV_CPU_ADD("cvsd", Z80, CVSD_Z80_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(cvsd_map,0)
 	MDRV_CPU_IO_MAP(cvsd_iomap,0)
 
 	/* audio hardware */
-	MDRV_SOUND_ADD(MC3417, CVSD_CLOCK)
+	MDRV_SOUND_ADD("cvsd", MC3417, CVSD_CLOCK)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
 MACHINE_DRIVER_END
 
@@ -922,7 +871,7 @@ READ8_HANDLER( victory_sound_response_r )
 {
 	UINT8 ret = pia_get_output_b(1);
 
-	if (VICTORY_LOG_SOUND) logerror("%04X:!!!! Sound response read = %02X\n", activecpu_get_previouspc(), ret);
+	if (VICTORY_LOG_SOUND) logerror("%04X:!!!! Sound response read = %02X\n", cpu_get_previouspc(space->cpu), ret);
 
 	pia_set_input_cb1(1, 0);
 
@@ -934,7 +883,7 @@ READ8_HANDLER( victory_sound_status_r )
 {
 	UINT8 ret = (pia_get_input_ca1(1) << 7) | (pia_get_input_cb1(1) << 6);
 
-	if (VICTORY_LOG_SOUND) logerror("%04X:!!!! Sound status read = %02X\n", activecpu_get_previouspc(), ret);
+	if (VICTORY_LOG_SOUND) logerror("%04X:!!!! Sound status read = %02X\n", cpu_get_previouspc(space->cpu), ret);
 
 	return ret;
 }
@@ -948,15 +897,15 @@ static TIMER_CALLBACK( delayed_command_w )
 
 WRITE8_HANDLER( victory_sound_command_w )
 {
-	if (VICTORY_LOG_SOUND) logerror("%04X:!!!! Sound command = %02X\n", activecpu_get_previouspc(), data);
+	if (VICTORY_LOG_SOUND) logerror("%04X:!!!! Sound command = %02X\n", cpu_get_previouspc(space->cpu), data);
 
-	timer_call_after_resynch(NULL, data, delayed_command_w);
+	timer_call_after_resynch(space->machine, NULL, data, delayed_command_w);
 }
 
 
 static WRITE8_HANDLER( victory_sound_irq_clear_w )
 {
-	if (VICTORY_LOG_SOUND) logerror("%04X:!!!! Sound IRQ clear = %02X\n", activecpu_get_previouspc(), data);
+	if (VICTORY_LOG_SOUND) logerror("%04X:!!!! Sound IRQ clear = %02X\n", cpu_get_previouspc(space->cpu), data);
 
 	if (!data) pia_set_input_ca1(1, 1);
 }
@@ -964,7 +913,7 @@ static WRITE8_HANDLER( victory_sound_irq_clear_w )
 
 static WRITE8_HANDLER( victory_main_ack_w )
 {
-	if (VICTORY_LOG_SOUND) logerror("%04X:!!!! Sound Main ACK W = %02X\n", activecpu_get_previouspc(), data);
+	if (VICTORY_LOG_SOUND) logerror("%04X:!!!! Sound Main ACK W = %02X\n", cpu_get_previouspc(space->cpu), data);
 
 	if (victory_sound_response_ack_clk && !data)
 		pia_set_input_cb1(1, 1);
@@ -981,19 +930,23 @@ static const pia6821_interface victory_pia_e5_intf =
 };
 
 
-static void *victory_sh_start(int clock, const struct CustomSound_interface *config)
+static CUSTOM_START( victory_sh_start )
 {
-	pia_config(1, &victory_pia_e5_intf);
+	running_machine *machine = device->machine;
+	pia_config(machine, 1, &victory_pia_e5_intf);
 
-	state_save_register_global(victory_sound_response_ack_clk);
+	state_save_register_global(machine, victory_sound_response_ack_clk);
 
-	return venture_common_sh_start(clock, config, TRUE);
+	return venture_common_sh_start(device, clock, config, TRUE);
 }
 
 
-static void victory_sh_reset(void *token)
+static CUSTOM_RESET( victory_sh_reset )
 {
-	venture_sh_reset(token);
+	common_sh_reset(token);
+	pia_reset();
+	device_reset(riot);
+	memset(sh8253_timer, 0, sizeof(sh8253_timer));
 
 	/* the flip-flop @ F4 is reset */
 	victory_sound_response_ack_clk = 0;
@@ -1006,7 +959,7 @@ static void victory_sh_reset(void *token)
 }
 
 
-static const struct CustomSound_interface victory_custom_interface =
+static const custom_sound_interface victory_custom_interface =
 {
 	victory_sh_start,
 	0,
@@ -1016,7 +969,7 @@ static const struct CustomSound_interface victory_custom_interface =
 
 static ADDRESS_MAP_START( victory_audio_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x00ff) AM_MIRROR(0x0f00) AM_RAM
-	AM_RANGE(0x1000, 0x107f) AM_MIRROR(0x0f80) AM_READWRITE(exidy_shriot_r, exidy_shriot_w)
+	AM_RANGE(0x1000, 0x107f) AM_MIRROR(0x0f80) AM_DEVREADWRITE(RIOT6532, "riot", riot6532_r, riot6532_w)
 	AM_RANGE(0x2000, 0x2003) AM_MIRROR(0x0ffc) AM_READWRITE(pia_1_r, pia_1_w)
 	AM_RANGE(0x3000, 0x3003) AM_MIRROR(0x0ffc) AM_READWRITE(exidy_sh8253_r, exidy_sh8253_w)
 	AM_RANGE(0x4000, 0x4fff) AM_NOP
@@ -1029,15 +982,17 @@ ADDRESS_MAP_END
 
 MACHINE_DRIVER_START( victory_audio )
 
-	MDRV_CPU_ADD(M6502, VICTORY_AUDIO_CPU_CLOCK)
+	MDRV_CPU_ADD("audio", M6502, VICTORY_AUDIO_CPU_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(victory_audio_map,0)
 
+	MDRV_RIOT6532_ADD("riot", SH6532_CLOCK, r6532_interface)
+
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(CUSTOM, 0)
+	MDRV_SOUND_ADD("custom", CUSTOM, 0)
 	MDRV_SOUND_CONFIG(victory_custom_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_SOUND_ADD(TMS5220, 640000)
+	MDRV_SOUND_ADD("tms", TMS5220, 640000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
