@@ -8,8 +8,8 @@
 ***************************************************************************/
 
 #include "driver.h"
+#include "cpu/m6809/m6809.h"
 #include "streams.h"
-#include "deprecat.h"
 #include "exidy440.h"
 
 
@@ -17,6 +17,10 @@
 #define	FADE_TO_ZERO	1
 
 
+#define EXIDY440_AUDIO_CLOCK	(EXIDY440_MASTER_CLOCK / 4 / 4)
+#define EXIDY440_MC3418_CLOCK	(EXIDY440_AUDIO_CLOCK / 16)
+#define EXIDY440_MC3417_CLOCK	(EXIDY440_AUDIO_CLOCK / 32)
+
 
 /* internal caching */
 #define	MAX_CACHE_ENTRIES		1024				/* maximum separate samples we expect to ever see */
@@ -107,14 +111,14 @@ static const int channel_bits[4] =
 
 
 /* function prototypes */
-static void channel_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int length);
+static STREAM_UPDATE( channel_update );
 static void m6844_finished(int ch);
-static void play_cvsd(int ch);
+static void play_cvsd(running_machine *machine, int ch);
 static void stop_cvsd(int ch);
 
 static void reset_sound_cache(void);
 static INT16 *add_to_sound_cache(UINT8 *input, int address, int length, int bits, int frequency);
-static INT16 *find_or_add_to_sound_cache(int address, int length, int bits, int frequency);
+static INT16 *find_or_add_to_sound_cache(running_machine *machine, int address, int length, int bits, int frequency);
 
 static void decode_and_filter_cvsd(UINT8 *data, int bytes, int maskbits, int frequency, INT16 *dest);
 static void fir_filter(INT32 *input, INT16 *output, int count);
@@ -127,15 +131,16 @@ static void fir_filter(INT32 *input, INT16 *output, int count);
  *
  *************************************/
 
-static void *exidy440_sh_start(int clock, const struct CustomSound_interface *config)
+static CUSTOM_START( exidy440_sh_start )
 {
+	running_machine *machine = device->machine;
 	int i, length;
 
 	/* reset the system */
 	exidy440_sound_command = 0;
 	exidy440_sound_command_ack = 1;
-	state_save_register_global(exidy440_sound_command);
-	state_save_register_global(exidy440_sound_command_ack);
+	state_save_register_global(machine, exidy440_sound_command);
+	state_save_register_global(machine, exidy440_sound_command_ack);
 
 	/* reset the 6844 */
 	for (i = 0; i < 4; i++)
@@ -147,9 +152,9 @@ static void *exidy440_sh_start(int clock, const struct CustomSound_interface *co
 	m6844_interrupt = 0x00;
 	m6844_chain = 0x00;
 
-	state_save_register_global(m6844_priority);
-	state_save_register_global(m6844_interrupt);
-	state_save_register_global(m6844_chain);
+	state_save_register_global(machine, m6844_priority);
+	state_save_register_global(machine, m6844_interrupt);
+	state_save_register_global(machine, m6844_chain);
 
 	channel_frequency[0] = clock;   /* channels 0 and 1 are run by FCLK */
 	channel_frequency[1] = clock;
@@ -157,10 +162,10 @@ static void *exidy440_sh_start(int clock, const struct CustomSound_interface *co
 	channel_frequency[3] = clock/2;
 
 	/* get stream channels */
-	stream = stream_create(0, 2, clock, NULL, channel_update);
+	stream = stream_create(device, 0, 2, clock, NULL, channel_update);
 
 	/* allocate the sample cache */
-	length = memory_region_length(REGION_SOUND1) * 16 + MAX_CACHE_ENTRIES * sizeof(sound_cache_entry);
+	length = memory_region_length(machine, "cvsd") * 16 + MAX_CACHE_ENTRIES * sizeof(sound_cache_entry);
 	sound_cache = auto_malloc(length);
 
 	/* determine the hard end of the cache and reset */
@@ -185,7 +190,7 @@ static void *exidy440_sh_start(int clock, const struct CustomSound_interface *co
  *
  *************************************/
 
-static void exidy440_sh_stop(void *token)
+static CUSTOM_STOP( exidy440_sh_stop )
 {
 	if (SOUND_LOG && debuglog)
 		fclose(debuglog);
@@ -272,19 +277,19 @@ static void mix_to_16(int length, stream_sample_t *dest_left, stream_sample_t *d
  *
  *************************************/
 
-static void channel_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int length)
+static STREAM_UPDATE( channel_update )
 {
 	int ch;
 
 	/* reset the mixer buffers */
-	memset(mixer_buffer_left, 0, length * sizeof(INT32));
-	memset(mixer_buffer_right, 0, length * sizeof(INT32));
+	memset(mixer_buffer_left, 0, samples * sizeof(INT32));
+	memset(mixer_buffer_right, 0, samples * sizeof(INT32));
 
 	/* loop over channels */
 	for (ch = 0; ch < 4; ch++)
 	{
 		sound_channel_data *channel = &sound_channel[ch];
-		int samples, volume, left = length;
+		int length, volume, left = samples;
 		int effective_offset;
 
 		/* if we're not active, bail */
@@ -292,22 +297,22 @@ static void channel_update(void *param, stream_sample_t **inputs, stream_sample_
 			continue;
 
 		/* see how many samples to copy */
-		samples = (left > channel->remaining) ? channel->remaining : left;
+		length = (left > channel->remaining) ? channel->remaining : left;
 
 		/* get a pointer to the sample data and copy to the left */
 		volume = sound_volume[2 * ch + 0];
 		if (volume)
-			add_and_scale_samples(ch, mixer_buffer_left, samples, volume);
+			add_and_scale_samples(ch, mixer_buffer_left, length, volume);
 
 		/* get a pointer to the sample data and copy to the left */
 		volume = sound_volume[2 * ch + 1];
 		if (volume)
-			add_and_scale_samples(ch, mixer_buffer_right, samples, volume);
+			add_and_scale_samples(ch, mixer_buffer_right, length, volume);
 
 		/* update our counters */
-		channel->offset += samples;
-		channel->remaining -= samples;
-		left -= samples;
+		channel->offset += length;
+		channel->remaining -= length;
+		left -= length;
 
 		/* update the MC6844 */
 		effective_offset = (ch & 2) ? channel->offset / 2 : channel->offset;
@@ -322,7 +327,7 @@ static void channel_update(void *param, stream_sample_t **inputs, stream_sample_
 	}
 
 	/* all done, time to mix it */
-	mix_to_16(length, outputs[0], outputs[1]);
+	mix_to_16(samples, outputs[0], outputs[1]);
 }
 
 
@@ -336,7 +341,7 @@ static void channel_update(void *param, stream_sample_t **inputs, stream_sample_
 static READ8_HANDLER( sound_command_r )
 {
 	/* clear the FIRQ that got us here and acknowledge the read to the main CPU */
-	cpunum_set_input_line(Machine, 1, 1, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[1], 1, CLEAR_LINE);
 	exidy440_sound_command_ack = 1;
 
 	return exidy440_sound_command;
@@ -372,7 +377,7 @@ static WRITE8_HANDLER( sound_volume_w )
 
 static WRITE8_HANDLER( sound_interrupt_clear_w )
 {
-	cpunum_set_input_line(Machine, 1, 0, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[1], 0, CLEAR_LINE);
 }
 
 
@@ -383,7 +388,7 @@ static WRITE8_HANDLER( sound_interrupt_clear_w )
  *
  *************************************/
 
-static void exidy440_m6844_update(void)
+static void m6844_update(void)
 {
 	/* update the stream */
 	stream_update(stream);
@@ -419,7 +424,7 @@ static READ8_HANDLER( m6844_r )
 	int result = 0;
 
 	/* first update the current state of the DMA transfers */
-	exidy440_m6844_update();
+	m6844_update();
 
 	/* switch off the offset we were given */
 	switch (offset)
@@ -489,6 +494,9 @@ static READ8_HANDLER( m6844_r )
 		case 0x16:
 			result = m6844_chain;
 			break;
+
+		/* 0x17-0x1f not used */
+		default: break;
 	}
 
 	return result;
@@ -500,7 +508,7 @@ static WRITE8_HANDLER( m6844_w )
 	int i;
 
 	/* first update the current state of the DMA transfers */
-	exidy440_m6844_update();
+	m6844_update();
 
 	/* switch off the offset we were given */
 	switch (offset)
@@ -567,7 +575,7 @@ static WRITE8_HANDLER( m6844_w )
 					m6844_channel[i].start_counter = m6844_channel[i].counter;
 
 					/* generate and play the sample */
-					play_cvsd(i);
+					play_cvsd(space->machine, i);
 				}
 
 				/* if we're going inactive... */
@@ -591,6 +599,9 @@ static WRITE8_HANDLER( m6844_w )
 		case 0x16:
 			m6844_chain = data;
 			break;
+
+		/* 0x17-0x1f not used */
+		default: break;
 	}
 }
 
@@ -635,7 +646,7 @@ static INT16 *add_to_sound_cache(UINT8 *input, int address, int length, int bits
 }
 
 
-static INT16 *find_or_add_to_sound_cache(int address, int length, int bits, int frequency)
+static INT16 *find_or_add_to_sound_cache(running_machine *machine, int address, int length, int bits, int frequency)
 {
 	sound_cache_entry *current;
 
@@ -643,7 +654,7 @@ static INT16 *find_or_add_to_sound_cache(int address, int length, int bits, int
 		if (current->address == address && current->length == length && current->bits == bits && current->frequency == frequency)
 			return current->data;
 
-	return add_to_sound_cache(&memory_region(REGION_SOUND1)[address], address, length, bits, frequency);
+	return add_to_sound_cache(&memory_region(machine, "cvsd")[address], address, length, bits, frequency);
 }
 
 
@@ -654,7 +665,7 @@ static INT16 *find_or_add_to_sound_cache(int address, int length, int bits, int
  *
  *************************************/
 
-static void play_cvsd(int ch)
+static void play_cvsd(running_machine *machine, int ch)
 {
 	sound_channel_data *channel = &sound_channel[ch];
 	int address = m6844_channel[ch].address;
@@ -672,7 +683,7 @@ static void play_cvsd(int ch)
 		address += 0x18000;
 
 	/* compute the base address in the converted samples array */
-	base = find_or_add_to_sound_cache(address, length, channel_bits[ch], channel_frequency[ch]);
+	base = find_or_add_to_sound_cache(machine, address, length, channel_bits[ch], channel_frequency[ch]);
 	if (!base)
 		return;
 
@@ -883,12 +894,16 @@ static void decode_and_filter_cvsd(UINT8 *input, int bytes, int maskbits, int fr
  *************************************/
 
 static ADDRESS_MAP_START( exidy440_audio_map, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x8000, 0x8016) AM_READWRITE(m6844_r, m6844_w) AM_BASE(&m6844_data)
-	AM_RANGE(0x8400, 0x8407) AM_READWRITE(MRA8_RAM, sound_volume_w) AM_BASE(&sound_volume)
-	AM_RANGE(0x8800, 0x8800) AM_READ(sound_command_r)
-	AM_RANGE(0x9400, 0x9403) AM_WRITE(MWA8_RAM) AM_BASE(&sound_banks)
-	AM_RANGE(0x9800, 0x9800) AM_READWRITE(MRA8_NOP, sound_interrupt_clear_w)
+	AM_RANGE(0x0000, 0x7fff) AM_NOP
+	AM_RANGE(0x8000, 0x801f) AM_MIRROR(0x03e0) AM_READWRITE(m6844_r, m6844_w) AM_BASE(&m6844_data)
+	AM_RANGE(0x8400, 0x840f) AM_MIRROR(0x03f0) AM_RAM_WRITE(sound_volume_w) AM_BASE(&sound_volume)
+	AM_RANGE(0x8800, 0x8800) AM_MIRROR(0x03ff) AM_READWRITE(sound_command_r, SMH_NOP)
+	AM_RANGE(0x8c00, 0x93ff) AM_NOP
+	AM_RANGE(0x9400, 0x9403) AM_MIRROR(0x03fc) AM_READWRITE(SMH_NOP, SMH_RAM) AM_BASE(&sound_banks)
+	AM_RANGE(0x9800, 0x9800) AM_MIRROR(0x03ff) AM_READWRITE(SMH_NOP, sound_interrupt_clear_w)
+	AM_RANGE(0x9c00, 0x9fff) AM_NOP
 	AM_RANGE(0xa000, 0xbfff) AM_RAM
+	AM_RANGE(0xc000, 0xdfff) AM_NOP
 	AM_RANGE(0xe000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
@@ -900,7 +915,7 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static const struct CustomSound_interface custom_interface =
+static const custom_sound_interface custom_interface =
 {
 	exidy440_sh_start,
 	exidy440_sh_stop
@@ -916,14 +931,26 @@ static const struct CustomSound_interface custom_interface =
 
 MACHINE_DRIVER_START( exidy440_audio )
 
-	MDRV_CPU_ADD(M6809,EXIDY440_MASTER_CLOCK/4/4)
+	MDRV_CPU_ADD("audio", M6809, EXIDY440_AUDIO_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(exidy440_audio_map,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_assert,1)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_assert)
 
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(CUSTOM, EXIDY440_MASTER_CLOCK/256)
+	MDRV_SOUND_ADD("custom", CUSTOM, EXIDY440_MASTER_CLOCK/256)
 	MDRV_SOUND_CONFIG(custom_interface)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
+
+//  MDRV_SOUND_ADD("cvsd1", MC3418, EXIDY440_MC3418_CLOCK)
+//  MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+
+//  MDRV_SOUND_ADD("cvsd2", MC3418, EXIDY440_MC3418_CLOCK)
+//  MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
+
+//  MDRV_SOUND_ADD("cvsd3", MC3417, EXIDY440_MC3417_CLOCK)
+//  MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
+
+//  MDRV_SOUND_ADD("cvsd4", MC3417, EXIDY440_MC3417_CLOCK)
+//  MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
