@@ -15,13 +15,14 @@ WRITE8_HANDLER( fghtbskt_samples_w )
 		sample_start_raw(0, samplebuf + ((data & 0xf0) << 8), 0x2000, 8000, 0);
 }
 
-void fghtbskt_sh_start(void)
+SAMPLES_START( fghtbskt_sh_start )
 {
-	int i;
-	UINT8 *ROM = memory_region(REGION_SOUND1);
+	running_machine *machine = device->machine;
+	int i, len = memory_region_length(machine, "samples");
+	UINT8 *ROM = memory_region(machine, "samples");
 
-	samplebuf = auto_malloc(memory_region_length(REGION_SOUND1) * 2);
+	samplebuf = auto_malloc(len * 2);
 
-	for(i=0;i<memory_region_length(REGION_SOUND1);i++)
+	for(i=0;i<len;i++)
 		samplebuf[i] = ((INT8)(ROM[i] ^ 0x80)) * 256;
 }
