@@ -11,68 +11,60 @@
 
 WRITE8_HANDLER( firetrk_skid_reset_w )
 {
-	if (GAME_IS_FIRETRUCK || GAME_IS_SUPERBUG)
-	{
-		firetrk_skid[0] = 0;
-		firetrk_skid[1] = 0;
-	}
+	firetrk_skid[0] = 0;
+	firetrk_skid[1] = 0;
 
-	// also SUPERBUG_SKID_EN and MONTECAR_SKID_EN
-	discrete_sound_w(FIRETRUCK_SKID_EN, 1);
+	// also SUPERBUG_SKID_EN
+	discrete_sound_w(space, FIRETRUCK_SKID_EN, 1);
+}
+
+
+WRITE8_HANDLER( montecar_skid_reset_w )
+{
+	discrete_sound_w(space, MONTECAR_SKID_EN, 1);
 }
 
 
 WRITE8_HANDLER( firetrk_crash_snd_w )
 {
 	// also SUPERBUG_CRASH_DATA and MONTECAR_CRASH_DATA
-	discrete_sound_w(FIRETRUCK_CRASH_DATA, data >> 4);
+	discrete_sound_w(space, FIRETRUCK_CRASH_DATA, data >> 4);
 }
 
 
 WRITE8_HANDLER( firetrk_skid_snd_w )
 {
 	// also SUPERBUG_SKID_EN and MONTECAR_SKID_EN
-	discrete_sound_w(FIRETRUCK_SKID_EN, 0);
+	discrete_sound_w(space, FIRETRUCK_SKID_EN, 0);
 }
 
 
 WRITE8_HANDLER( firetrk_motor_snd_w )
 {
-	if (GAME_IS_FIRETRUCK || GAME_IS_MONTECARLO)
-	{
-		// also MONTECAR_DRONE_MOTOR_DATA
-		discrete_sound_w(FIRETRUCK_SIREN_DATA, data >> 4);
-	}
+	// also MONTECAR_DRONE_MOTOR_DATA
+	discrete_sound_w(space, FIRETRUCK_SIREN_DATA, data >> 4);
 
-		// also SUPERBUG_SPEED_DATA and MONTECAR_MOTOR_DATA
-		discrete_sound_w(FIRETRUCK_MOTOR_DATA, data & 0x0f);
+	// also MONTECAR_MOTOR_DATA
+	discrete_sound_w(space, FIRETRUCK_MOTOR_DATA, data & 0x0f);
+}
+
+
+WRITE8_HANDLER( superbug_motor_snd_w )
+{
+	discrete_sound_w(space, SUPERBUG_SPEED_DATA, data & 0x0f);
 }
 
 
 WRITE8_HANDLER( firetrk_xtndply_w )
 {
-	discrete_sound_w(FIRETRUCK_XTNDPLY_EN, data);
+	discrete_sound_w(space, FIRETRUCK_XTNDPLY_EN, data);
 }
 
 
-WRITE8_HANDLER( firetrk_asr_w )
+WRITE8_HANDLER( superbug_asr_w )
 {
-	if (GAME_IS_SUPERBUG)
-	{
-		discrete_sound_w(SUPERBUG_ASR_EN, 1);	/* ASR */
-	}
-}
-
-
-WRITE8_HANDLER( firetrk_out2_w )
-{
-	firetrk_set_flash(data & 0x80);
-
-	if (GAME_IS_MONTECARLO)
-	{
-		discrete_sound_w(MONTECAR_BEEPER_EN, data & 0x10);	/* Beep */
-		discrete_sound_w(MONTECAR_DRONE_LOUD_DATA, data & 0x0f);	/* Drone Motor Volume */
-	}
+popmessage("ASR");
+		discrete_sound_w(space, SUPERBUG_ASR_EN, 1);	/* ASR */
 }
 
 
@@ -118,7 +110,6 @@ static const discrete_555_cc_desc firetrk_motor_vco =
 	DISC_555_OUT_DC | DISC_555_OUT_SQW,
 	5,		// B+ voltage of 555
 	DEFAULT_555_VALUES,
-	5,		// B+ voltage of the Constant Current source
 	0.7		// Q2 junction voltage
 };
 
@@ -215,7 +206,7 @@ DISCRETE_SOUND_START(firetrk)
 	/* drive a modulo 12 counter, with div6 & div12 */
 	/* summed as the output of the circuit.         */
 	/************************************************/
-	DISCRETE_ADJUSTMENT_TAG(NODE_20, 1,
+	DISCRETE_ADJUSTMENT_TAG(NODE_20,
 				RES_K(260),	// R26 + R27 @ max
 				RES_K(10),	// R26 + R27 @ min
 				DISC_LOGADJ, "R27")
@@ -230,12 +221,12 @@ DISCRETE_SOUND_START(firetrk)
 			RES_M(1), 0, 0,		// R28, no rGnd, no rDis
 			&firetrk_motor_vco)
 	DISCRETE_COUNTER_7492(NODE_23, 1, FIRETRUCK_ATTRACT_EN,	// IC A9, QB-QD
-			NODE_22)									// from IC B9, pin 3
-	DISCRETE_TRANSFORM2(NODE_24, 1, NODE_23, 0x04, "01&")	// IC A9, pin 8
+			NODE_22, DISC_CLK_ON_F_EDGE)					// from IC B9, pin 3
+	DISCRETE_TRANSFORM2(NODE_24, NODE_23, 0x04, "01&")	// IC A9, pin 8
 	DISCRETE_COUNTER(NODE_25, 1, FIRETRUCK_ATTRACT_EN,	// IC A9, pin 12
 			NODE_24,									// from IC A9, pin 8
 			1, 1, 0, DISC_CLK_ON_F_EDGE)
-	DISCRETE_TRANSFORM3(NODE_26, 1, NODE_23, 2, NODE_25, "01*2+")	// Mix QA and QB-D together
+	DISCRETE_TRANSFORM3(NODE_26, NODE_23, 2, NODE_25, "01*2+")	// Mix QA and QB-D together
 	DISCRETE_DAC_R1(FIRETRUCK_MOTORSND, 1, NODE_26,
 			DEFAULT_TTL_V_LOGIC_1,
 			&firetrk_motor_out_dac)
@@ -299,11 +290,11 @@ DISCRETE_SOUND_START(firetrk)
 				4.4, 10,		// Q3 instantally charges C42
 				0, RES_K(33),	// discharges thru R66
 				CAP_U(10))		// C42
-	DISCRETE_TRANSFORM2(NODE_71, 1, NODE_70,
+	DISCRETE_TRANSFORM2(NODE_71, NODE_70,
 				5.0 * 680 / (RES_K(10) + 680),	// vRef = 5V * R64 / (R65 + R64)
 				"01<")				// Output is low until vIn drops below vRef
 	DISCRETE_COUNTER(NODE_72, 1, NODE_71, FIRETRUCK_HSYNC, 15, 1, 0, DISC_CLK_IS_FREQ)	// IC B10
-	DISCRETE_TRANSFORM4(FIRETRUCK_BELLSND, 1, NODE_72,
+	DISCRETE_TRANSFORM4(FIRETRUCK_BELLSND, NODE_72,
 				8,	// count 0-7 allow cap voltage to output.  8-15 ground output.
 				NODE_70,	// scale logic to cap voltage
 				RES_K(47) / (RES_K(47) + RES_K(47) + RES_K(47)),	// to drop voltage per divider R72 / (R70+R71+R72)
@@ -345,7 +336,6 @@ static const discrete_555_cc_desc superbug_motor_vco =
 	DISC_555_OUT_DC | DISC_555_OUT_SQW,
 	5,				// B+ voltage of 555
 	DEFAULT_555_VALUES,
-	5,				// B+ voltage of the Constant Current source
 	0.7				// Q1 junction voltage
 };
 
@@ -419,7 +409,7 @@ DISCRETE_SOUND_START(superbug)
 	/* latch (4 bit). This freqency is then used to */
 	/* drive a modulo 12 counter.                   */
 	/************************************************/
-	DISCRETE_ADJUSTMENT_TAG(NODE_20, 1,
+	DISCRETE_ADJUSTMENT_TAG(NODE_20,
 				RES_K(260),	// R12 + R62 @ max
 				RES_K(10),	// R12 + R62 @ min
 				DISC_LOGADJ, "R62")
@@ -434,14 +424,14 @@ DISCRETE_SOUND_START(superbug)
 			RES_M(3.3), 0, 0,	// R11, no rGnd, no rDis
 			&superbug_motor_vco)
 	DISCRETE_COUNTER_7492(NODE_23, 1, SUPERBUG_ATTRACT_EN,	// IC A7, QB-QD
-			NODE_22)										// from IC A6, pin 3
-	DISCRETE_TRANSFORM2(NODE_24, 1, NODE_23, 0x04, "01&")		// IC A7, pin 8-QD
-	DISCRETE_TRANSFORM2(NODE_25, 1, NODE_23, 0x01, "01&")	// IC A7, pin 11-QB
+			NODE_22, DISC_CLK_ON_F_EDGE)					// from IC A6, pin 3
+	DISCRETE_TRANSFORM2(NODE_24, NODE_23, 0x04, "01&")	// IC A7, pin 8-QD
+	DISCRETE_TRANSFORM2(NODE_25, NODE_23, 0x01, "01&")	// IC A7, pin 11-QB
 	DISCRETE_LOGIC_XOR(NODE_26, 1, NODE_24, NODE_25)	// Gate A9, pin 8
 	DISCRETE_COUNTER(NODE_27, 1, SUPERBUG_ATTRACT_EN,	// IC A7, pin 12-QA
 			NODE_26,									// from IC A9, pin 8
 			1, 1, 0, DISC_CLK_ON_F_EDGE)
-	DISCRETE_TRANSFORM3(NODE_28, 1, NODE_23, 2, NODE_27, "01*2+")	// Mix QA and QB-D together
+	DISCRETE_TRANSFORM3(NODE_28, NODE_23, 2, NODE_27, "01*2+")	// Mix QA and QB-D together
 	DISCRETE_DAC_R1(SUPERBUG_MOTORSND, 1, NODE_28,
 			DEFAULT_TTL_V_LOGIC_1,
 			&superbug_motor_out_dac)
@@ -506,7 +496,6 @@ static const discrete_555_cc_desc montecar_motor_vco =
 	DISC_555_OUT_DC | DISC_555_OUT_SQW,
 	5,		// B+ voltage of 555
 	DEFAULT_555_VALUES,
-	5,		// B+ voltage of the Constant Current source
 	0.7		// Q1 junction voltage
 };
 
@@ -604,7 +593,7 @@ DISCRETE_SOUND_START(montecar)
 	/* driver a modulo 12 counter, with div6, 4 & 3 */
 	/* summed as the output of the circuit.         */
 	/************************************************/
-	DISCRETE_ADJUSTMENT_TAG(NODE_20, 1,
+	DISCRETE_ADJUSTMENT_TAG(NODE_20,
 				RES_K(260),	// R87 + R89 @ max
 				RES_K(10),	// R87 + R89 @ min
 				DISC_LOGADJ, "R89")
@@ -619,14 +608,14 @@ DISCRETE_SOUND_START(montecar)
 			RES_M(1), 0, 0,		// R86, no rGnd, no rDis
 			&montecar_motor_vco)
 	DISCRETE_COUNTER_7492(NODE_23, 1, MONTECAR_ATTRACT_EN,	// IC B/C9, QB-QD
-			NODE_22)										// from IC C9, pin 9
-	DISCRETE_TRANSFORM2(NODE_24, 1, NODE_23, 0x04, "01&")	// IC B/C9, pin 8-QD
-	DISCRETE_TRANSFORM2(NODE_25, 1, NODE_23, 0x01, "01&")	// IC B/C9, pin 11-QB
+			NODE_22, DISC_CLK_ON_F_EDGE)						// from IC C9, pin 9
+	DISCRETE_TRANSFORM2(NODE_24, NODE_23, 0x04, "01&")	// IC B/C9, pin 8-QD
+	DISCRETE_TRANSFORM2(NODE_25, NODE_23, 0x01, "01&")	// IC B/C9, pin 11-QB
 	DISCRETE_LOGIC_XOR(NODE_26, 1, NODE_24, NODE_25)	// Gate A9, pin 11
 	DISCRETE_COUNTER(NODE_27, 1, MONTECAR_ATTRACT_EN,	// IC B/C9, pin 12-QA
 			NODE_26,									// from IC A9, pin 11
 			1, 1, 0, DISC_CLK_ON_F_EDGE)
-	DISCRETE_TRANSFORM3(NODE_28, 1, NODE_23, 2, NODE_27, "01*2+")	// Mix QA and QB-D together
+	DISCRETE_TRANSFORM3(NODE_28, NODE_23, 2, NODE_27, "01*2+")	// Mix QA and QB-D together
 	DISCRETE_DAC_R1(MONTECAR_MOTORSND, 1, NODE_28,
 			DEFAULT_TTL_V_LOGIC_1,
 			&montecar_motor_out_dac)
@@ -637,9 +626,9 @@ DISCRETE_SOUND_START(montecar)
 	/* Also I shifted the frequencies up for it to  */
 	/* sound different from the player's car.       */
 	/************************************************/
-	DISCRETE_COMP_ADDER(NODE_30, 1, MONTECAR_DRONE_LOUD_DATA, &montecar_drone_vol_res)	// make sure to change the node value in the mixer table if you change this node number
+	DISCRETE_COMP_ADDER(NODE_30, MONTECAR_DRONE_LOUD_DATA, &montecar_drone_vol_res)	// make sure to change the node value in the mixer table if you change this node number
 
-	DISCRETE_ADJUSTMENT_TAG(NODE_40, 1,
+	DISCRETE_ADJUSTMENT_TAG(NODE_40,
 				RES_K(260),	// R85 + R88 @ max
 				RES_K(10),	// R85 + R88 @ min
 				DISC_LOGADJ, "R88")
@@ -654,14 +643,14 @@ DISCRETE_SOUND_START(montecar)
 			RES_M(1), 0, 0,		// R81, no rGnd, no rDis
 			&montecar_motor_vco)
 	DISCRETE_COUNTER_7492(NODE_43, 1, MONTECAR_ATTRACT_EN,	// IC A/B9, QB-QD
-			NODE_42)										// from IC C9, pin 5
-	DISCRETE_TRANSFORM2(NODE_44, 1, NODE_43, 0x04, "01&")	// IC A/B9, pin 8-QD
-	DISCRETE_TRANSFORM2(NODE_45, 1, NODE_43, 0x01, "01&")	// IC A/B9, pin 11-QB
+			NODE_42, DISC_CLK_ON_F_EDGE)					// from IC C9, pin 5
+	DISCRETE_TRANSFORM2(NODE_44, NODE_43, 0x04, "01&")	// IC A/B9, pin 8-QD
+	DISCRETE_TRANSFORM2(NODE_45, NODE_43, 0x01, "01&")	// IC A/B9, pin 11-QB
 	DISCRETE_LOGIC_XOR(NODE_46, 1, NODE_44, NODE_45)	// Gate A9, pin 6
 	DISCRETE_COUNTER(NODE_47, 1, MONTECAR_ATTRACT_EN,	// IC A/B9, pin 12-QA
 			NODE_46,									// from IC A9, pin 6
 			1, 1, 0, DISC_CLK_ON_F_EDGE)
-	DISCRETE_TRANSFORM3(NODE_48, 1, NODE_43, 2, NODE_47, "01*2+")	// Mix QA and QB-D together
+	DISCRETE_TRANSFORM3(NODE_48, NODE_43, 2, NODE_47, "01*2+")	// Mix QA and QB-D together
 	DISCRETE_DAC_R1(MONTECAR_DRONE_MOTORSND, 1, NODE_48,
 			DEFAULT_TTL_V_LOGIC_1,
 			&montecar_motor_out_dac)
