@@ -4,7 +4,7 @@
 
 ****************************************************************************/
 
-MACHINE_DRIVER_EXTERN( m52_small_audio );
+MACHINE_DRIVER_EXTERN( m52_sound_c_audio );
 MACHINE_DRIVER_EXTERN( m52_large_audio );
 MACHINE_DRIVER_EXTERN( m62_audio );
 
