@@ -143,7 +143,7 @@
 ****************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "memconv.h"
 #include "includes/jaguar.h"
 #include "cpu/jaguar/jaguar.h"
 #include "sound/dac.h"
@@ -189,15 +189,15 @@ static TIMER_CALLBACK( serial_callback );
  *
  *************************************/
 
-void jaguar_dsp_suspend(void)
+void jaguar_dsp_suspend(running_machine *machine)
 {
-	cpunum_suspend(2, SUSPEND_REASON_SPIN, 1);
+	cpu_suspend(machine->cpu[2], SUSPEND_REASON_SPIN, 1);
 }
 
 
-void jaguar_dsp_resume(void)
+void jaguar_dsp_resume(running_machine *machine)
 {
-	cpunum_resume(2, SUSPEND_REASON_SPIN);
+	cpu_resume(machine->cpu[2], SUSPEND_REASON_SPIN);
 }
 
 
@@ -208,25 +208,25 @@ void jaguar_dsp_resume(void)
  *
  *************************************/
 
-static void update_gpu_irq(void)
+static void update_gpu_irq(running_machine *machine)
 {
 	if (gpu_irq_state & dsp_regs[JINTCTRL] & 0x1f)
 	{
-		cpunum_set_input_line(Machine, 1, 1, ASSERT_LINE);
-		jaguar_gpu_resume();
+		cpu_set_input_line(machine->cpu[1], 1, ASSERT_LINE);
+		jaguar_gpu_resume(machine);
 	}
 	else
-		cpunum_set_input_line(Machine, 1, 1, CLEAR_LINE);
+		cpu_set_input_line(machine->cpu[1], 1, CLEAR_LINE);
 }
 
 
-void jaguar_external_int(int state)
+void jaguar_external_int(const device_config *device, int state)
 {
 	if (state != CLEAR_LINE)
 		gpu_irq_state |= 1;
 	else
 		gpu_irq_state &= ~1;
-	update_gpu_irq();
+	update_gpu_irq(device->machine);
 }
 
 
@@ -237,7 +237,7 @@ void jaguar_external_int(int state)
  *
  *************************************/
 
-void cojag_sound_init(void)
+void cojag_sound_init(running_machine *machine)
 {
 	int i;
 
@@ -260,17 +260,17 @@ void cojag_sound_init(void)
 		jaguar_wave_rom[0x200 + i] = (int)(32767. * sin(2.0 * M_PI * (double)i / (double)0x80));
 
 		/* F1DA00 = traingle wave with noise */
-		jaguar_wave_rom[0x280 + i] = jaguar_wave_rom[0x000 + i] * (mame_rand(Machine) % 32768) / 32768;
+		jaguar_wave_rom[0x280 + i] = jaguar_wave_rom[0x000 + i] * (mame_rand(machine) % 32768) / 32768;
 
 		/* F1DC00 = spike */
 		jaguar_wave_rom[0x300 + i] = (i == 0x40) ? 32767 : 0;
 
 		/* F1DE00 = white noise */
-		jaguar_wave_rom[0x380 + i] = mame_rand(Machine) % 32768;
+		jaguar_wave_rom[0x380 + i] = mame_rand(machine) % 32768;
 	}
 
 #if ENABLE_SPEEDUP_HACKS
-	memory_install_write32_handler(2, ADDRESS_SPACE_PROGRAM, 0xf1a100, 0xf1a103, 0, 0, dsp_flags_w);
+	memory_install_write32_handler(cpu_get_address_space(machine->cpu[2], ADDRESS_SPACE_PROGRAM), 0xf1a100, 0xf1a103, 0, 0, dsp_flags_w);
 #endif
 }
 
@@ -282,12 +282,12 @@ void cojag_sound_init(void)
  *
  *************************************/
 
-void cojag_sound_reset(void)
+void cojag_sound_reset(running_machine *machine)
 {
 #if ENABLE_SPEEDUP_HACKS
-	serial_timer = timer_alloc(serial_chunky_callback, NULL);
+	serial_timer = timer_alloc(machine, serial_chunky_callback, NULL);
 #else
-	serial_timer = timer_alloc(serial_callback, NULL);
+	serial_timer = timer_alloc(machine, serial_callback, NULL);
 #endif
 }
 
@@ -302,7 +302,7 @@ void cojag_sound_reset(void)
 READ16_HANDLER( jaguar_jerry_regs_r )
 {
 	if (offset != JINTCTRL && offset != JINTCTRL+2)
-		logerror("%08X:jerry read register @ F10%03X\n", activecpu_get_previouspc(), offset * 2);
+		logerror("%08X:jerry read register @ F10%03X\n", cpu_get_previouspc(space->cpu), offset * 2);
 
 	switch (offset)
 	{
@@ -322,12 +322,12 @@ WRITE16_HANDLER( jaguar_jerry_regs_w )
 	{
 		case JINTCTRL:
 			gpu_irq_state &= ~(dsp_regs[JINTCTRL] >> 8);
-			update_gpu_irq();
+			update_gpu_irq(space->machine);
 			break;
 	}
 
 	if (offset != JINTCTRL && offset != JINTCTRL+2 && offset != ASICTRL)
-		logerror("%08X:jerry write register @ F10%03X = %04X\n", activecpu_get_previouspc(), offset * 2, data);
+		logerror("%08X:jerry write register @ F10%03X = %04X\n", cpu_get_previouspc(space->cpu), offset * 2, data);
 }
 
 
@@ -340,16 +340,13 @@ WRITE16_HANDLER( jaguar_jerry_regs_w )
 
 READ32_HANDLER( jaguar_jerry_regs32_r )
 {
-	return (jaguar_jerry_regs_r(offset * 2, 0) << 16) | jaguar_jerry_regs_r(offset * 2 + 1, 0);
+	return read32be_with_16be_handler(jaguar_jerry_regs_r, space, offset, mem_mask);
 }
 
 
 WRITE32_HANDLER( jaguar_jerry_regs32_w )
 {
-	if (ACCESSING_MSW32)
-		jaguar_jerry_regs_w(offset * 2, data >> 16, mem_mask >> 16);
-	if (ACCESSING_LSW32)
-		jaguar_jerry_regs_w(offset * 2 + 1, data, mem_mask);
+	write32be_with_16be_handler(jaguar_jerry_regs_w, space, offset, data, mem_mask);
 }
 
 
@@ -365,18 +362,18 @@ WRITE32_HANDLER( jaguar_jerry_regs32_w )
 static WRITE32_HANDLER( dsp_flags_w )
 {
 	/* write the data through */
-	jaguardsp_ctrl_w(2, offset, data, mem_mask);
+	jaguardsp_ctrl_w(space->machine->cpu[2], offset, data, mem_mask);
 
 	/* if they were clearing the A2S interrupt, see if we are headed for the spin */
 	/* loop with R22 != 0; if we are, just start spinning again */
-	if (cpu_getactivecpu() == 2 && !(mem_mask & 0x0000ff00) && (data & 0x400))
+	if (space->cpu == space->machine->cpu[2] && ACCESSING_BITS_8_15 && (data & 0x400))
 	{
 		/* see if we're going back to the spin loop */
-		if (!(data & 0x04000) && activecpu_get_reg(JAGUAR_R22) != 0)
+		if (!(data & 0x04000) && cpu_get_reg(space->cpu, JAGUAR_R22) != 0)
 		{
-			UINT32 r30 = activecpu_get_reg(JAGUAR_R30) & 0xffffff;
+			UINT32 r30 = cpu_get_reg(space->cpu, JAGUAR_R30) & 0xffffff;
 			if (r30 >= 0xf1b124 && r30 <= 0xf1b126)
-				jaguar_dsp_suspend();
+				jaguar_dsp_suspend(space->machine);
 		}
 	}
 }
@@ -396,8 +393,8 @@ static WRITE32_HANDLER( dsp_flags_w )
 static TIMER_CALLBACK( serial_chunky_callback )
 {
 	/* assert the A2S IRQ on CPU #2 (DSP) */
-	cpunum_set_input_line(machine, 2, 1, ASSERT_LINE);
-	jaguar_dsp_resume();
+	cpu_set_input_line(machine->cpu[2], 1, ASSERT_LINE);
+	jaguar_dsp_resume(machine);
 
 	/* fix flaky code in interrupt handler which thwarts our speedup */
 	if ((jaguar_dsp_ram[0x3e/4] & 0xffff) == 0xbfbc &&
@@ -415,8 +412,8 @@ static TIMER_CALLBACK( serial_chunky_callback )
 static TIMER_CALLBACK( serial_callback )
 {
 	/* assert the A2S IRQ on CPU #2 (DSP) */
-	cpunum_set_input_line(machine, 2, 1, ASSERT_LINE);
-	jaguar_dsp_resume();
+	cpu_set_input_line(machine->cpu[2], 1, ASSERT_LINE);
+	jaguar_dsp_resume(machine);
 }
 
 #endif
@@ -431,7 +428,7 @@ static TIMER_CALLBACK( serial_callback )
 
 READ32_HANDLER( jaguar_serial_r )
 {
-	logerror("%08X:jaguar_serial_r(%X)\n", activecpu_get_previouspc(), offset);
+	logerror("%08X:jaguar_serial_r(%X)\n", cpu_get_previouspc(space->cpu), offset);
 	return 0;
 }
 
@@ -442,12 +439,12 @@ WRITE32_HANDLER( jaguar_serial_w )
 	{
 		/* right DAC */
 		case 2:
-			DAC_signed_data_16_w(1, (data & 0xffff) ^ 0x8000);
+			dac_signed_data_16_w(1, (data & 0xffff) ^ 0x8000);
 			break;
 
 		/* left DAC */
 		case 3:
-			DAC_signed_data_16_w(0, (data & 0xffff) ^ 0x8000);
+			dac_signed_data_16_w(0, (data & 0xffff) ^ 0x8000);
 			break;
 
 		/* frequency register */
@@ -462,12 +459,12 @@ WRITE32_HANDLER( jaguar_serial_w )
 			if ((data & 0x3f) == 0x15)
 			{
 				attotime rate = attotime_mul(ATTOTIME_IN_HZ(26000000), 32 * 2 * (serial_frequency + 1));
-				timer_adjust(serial_timer, rate, 0, rate);
+				timer_adjust_periodic(serial_timer, rate, 0, rate);
 			}
 			break;
 
 		default:
-			logerror("%08X:jaguar_serial_w(%X,%X)\n", activecpu_get_previouspc(), offset, data);
+			logerror("%08X:jaguar_serial_w(%X,%X)\n", cpu_get_previouspc(space->cpu), offset, data);
 			break;
 	}
 }
