@@ -5,7 +5,7 @@
 ****************************************************************************/
 
 MACHINE_RESET( m72_sound );
-void m72_ym2151_irq_handler(int irq);
+void m72_ym2151_irq_handler(running_machine *machine, int irq);
 WRITE8_HANDLER( m72_sound_command_byte_w );
 WRITE16_HANDLER( m72_sound_command_w );
 WRITE8_HANDLER( m72_sound_irq_ack_w );
