@@ -7,14 +7,14 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
-#include "audio/mcr.h"
-#include "audio/williams.h"
+#include "cpu/z80/z80.h"
+#include "cpu/m68000/m68000.h"
 #include "cpu/m6800/m6800.h"
 #include "cpu/m6809/m6809.h"
 #include "sound/5220intf.h"
 #include "sound/ay8910.h"
 #include "sound/dac.h"
+#include "audio/williams.h"
 #include "includes/mcr.h"
 #include "audio/mcr.h"
 
@@ -63,8 +63,8 @@ static UINT8 ssio_duty_cycle[2][3];
 static UINT8 ssio_ayvolume_lookup[16];
 static UINT8 ssio_custom_input_mask[5];
 static UINT8 ssio_custom_output_mask[2];
-static read8_handler ssio_custom_input[5];
-static write8_handler ssio_custom_output[2];
+static read8_space_func ssio_custom_input[5];
+static write8_space_func ssio_custom_output[2];
 
 /* Chip Squeak Deluxe-specific globals */
 static UINT8 csdeluxe_sound_cpu;
@@ -99,7 +99,7 @@ static const pia6821_interface squawkntalk_pia1_intf;
  *
  *************************************/
 
-static void ssio_compute_ay8910_modulation(void);
+static void ssio_compute_ay8910_modulation(running_machine *machine);
 
 
 
@@ -109,7 +109,7 @@ static void ssio_compute_ay8910_modulation(void);
  *
  *************************************/
 
-void mcr_sound_init(UINT8 config)
+void mcr_sound_init(running_machine *machine, UINT8 config)
 {
 	int sound_cpu = 1;
 	int dac_index = 0;
@@ -120,98 +120,98 @@ void mcr_sound_init(UINT8 config)
 	if (mcr_sound_config & MCR_SSIO)
 	{
 		ssio_sound_cpu = sound_cpu++;
-		ssio_compute_ay8910_modulation();
-		state_save_register_global_array(ssio_data);
-		state_save_register_global(ssio_status);
-		state_save_register_global(ssio_14024_count);
-		state_save_register_global(ssio_mute);
-		state_save_register_global_array(ssio_overall);
-		state_save_register_global_2d_array(ssio_duty_cycle);
+		ssio_compute_ay8910_modulation(machine);
+		state_save_register_global_array(machine, ssio_data);
+		state_save_register_global(machine, ssio_status);
+		state_save_register_global(machine, ssio_14024_count);
+		state_save_register_global(machine, ssio_mute);
+		state_save_register_global_array(machine, ssio_overall);
+		state_save_register_global_2d_array(machine, ssio_duty_cycle);
 	}
 
 	/* Turbo Chip Squeak */
 	if (mcr_sound_config & MCR_TURBO_CHIP_SQUEAK)
 	{
-		pia_config(0, &turbocs_pia_intf);
+		pia_config(machine, 0, &turbocs_pia_intf);
 		turbocs_dac_index = dac_index++;
 		turbocs_sound_cpu = sound_cpu++;
-		state_save_register_global(turbocs_status);
+		state_save_register_global(machine, turbocs_status);
 	}
 
 	/* Chip Squeak Deluxe */
 	if (mcr_sound_config & MCR_CHIP_SQUEAK_DELUXE)
 	{
-		pia_config(0, &csdeluxe_pia_intf);
+		pia_config(machine, 0, &csdeluxe_pia_intf);
 		csdeluxe_dac_index = dac_index++;
 		csdeluxe_sound_cpu = sound_cpu++;
-		state_save_register_global(csdeluxe_status);
+		state_save_register_global(machine, csdeluxe_status);
 	}
 
 	/* Sounds Good */
 	if (mcr_sound_config & MCR_SOUNDS_GOOD)
 	{
 		/* special case: Spy Hunter 2 has both Turbo CS and Sounds Good, so we use PIA slot 1 */
-		pia_config(1, &soundsgood_pia_intf);
+		pia_config(machine, 1, &soundsgood_pia_intf);
 		soundsgood_dac_index = dac_index++;
 		soundsgood_sound_cpu = sound_cpu++;
-		state_save_register_global(soundsgood_status);
+		state_save_register_global(machine, soundsgood_status);
 	}
 
 	/* Squawk n Talk */
 	if (mcr_sound_config & MCR_SQUAWK_N_TALK)
 	{
-		pia_config(0, &squawkntalk_pia0_intf);
-		pia_config(1, &squawkntalk_pia1_intf);
+		pia_config(machine, 0, &squawkntalk_pia0_intf);
+		pia_config(machine, 1, &squawkntalk_pia1_intf);
 		squawkntalk_sound_cpu = sound_cpu++;
-		state_save_register_global(squawkntalk_tms_command);
-		state_save_register_global(squawkntalk_tms_strobes);
+		state_save_register_global(machine, squawkntalk_tms_command);
+		state_save_register_global(machine, squawkntalk_tms_strobes);
 	}
 
 	/* Advanced Audio */
 	if (mcr_sound_config & MCR_WILLIAMS_SOUND)
 	{
-		williams_cvsd_init(0);
+		williams_cvsd_init(machine, 0);
 		sound_cpu++;
 		dac_index++;
 	}
 }
 
 
-void mcr_sound_reset(void)
+void mcr_sound_reset(running_machine *machine)
 {
 	/* SSIO */
 	if (mcr_sound_config & MCR_SSIO)
 	{
-		ssio_reset_w(1);
-		ssio_reset_w(0);
+		ssio_reset_w(machine, 1);
+		ssio_reset_w(machine, 0);
 	}
 
 	/* Turbo Chip Squeak */
 	if (mcr_sound_config & MCR_TURBO_CHIP_SQUEAK)
 	{
-		turbocs_reset_w(1);
-		turbocs_reset_w(0);
+		turbocs_reset_w(machine, 1);
+		turbocs_reset_w(machine, 0);
 	}
 
 	/* Chip Squeak Deluxe */
 	if (mcr_sound_config & MCR_CHIP_SQUEAK_DELUXE)
 	{
-		csdeluxe_reset_w(1);
-		csdeluxe_reset_w(0);
+		csdeluxe_reset_w(machine, 1);
+		csdeluxe_reset_w(machine, 0);
 	}
 
 	/* Sounds Good */
 	if (mcr_sound_config & MCR_SOUNDS_GOOD)
 	{
-		soundsgood_reset_w(1);
-		soundsgood_reset_w(0);
+		soundsgood_reset_w(machine, 1);
+		soundsgood_reset_w(machine, 0);
 	}
 
 	/* Squawk n Talk */
 	if (mcr_sound_config & MCR_SQUAWK_N_TALK)
 	{
-		squawkntalk_reset_w(1);
-		squawkntalk_reset_w(0);
+		squawkntalk_reset_w(machine, 1);
+		squawkntalk_reset_w(machine, 0);
 	}
 
 	/* Advanced Audio */
@@ -267,9 +267,9 @@ void mcr_sound_reset(void)
         frequency of sound output. So we simply apply a volume
         adjustment to each voice according to the duty cycle.
 */
-static void ssio_compute_ay8910_modulation(void)
+static void ssio_compute_ay8910_modulation(running_machine *machine)
 {
-	UINT8 *prom = memory_region(REGION_PROMS);
+	UINT8 *prom = memory_region(machine, "proms");
 	int volval;
 
 	/* loop over all possible values of the duty cycle */
@@ -315,14 +315,14 @@ static INTERRUPT_GEN( ssio_14024_clock )
 
 	/* if the low 5 bits clocked to 0, bit 6 has changed state */
 	if ((ssio_14024_count & 0x3f) == 0)
-		cpunum_set_input_line(machine, ssio_sound_cpu, 0, (ssio_14024_count & 0x40) ? ASSERT_LINE : CLEAR_LINE);
+		cpu_set_input_line(device, 0, (ssio_14024_count & 0x40) ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static READ8_HANDLER( ssio_irq_clear )
 {
 	/* a read here asynchronously resets the 14024 count, clearing /SINT */
 	ssio_14024_count = 0;
-	cpunum_set_input_line(Machine, ssio_sound_cpu, 0, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[ssio_sound_cpu], 0, CLEAR_LINE);
 	return 0xff;
 }
 
@@ -343,12 +343,12 @@ static TIMER_CALLBACK( ssio_delayed_data_w )
 
 static void ssio_update_volumes(void)
 {
-	AY8910_set_volume(0, 0, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[0][0]]);
-	AY8910_set_volume(0, 1, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[0][1]]);
-	AY8910_set_volume(0, 2, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[0][2]]);
-	AY8910_set_volume(1, 0, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[1][0]]);
-	AY8910_set_volume(1, 1, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[1][1]]);
-	AY8910_set_volume(1, 2, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[1][2]]);
+	ay8910_set_volume(0, 0, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[0][0]]);
+	ay8910_set_volume(0, 1, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[0][1]]);
+	ay8910_set_volume(0, 2, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[0][2]]);
+	ay8910_set_volume(1, 0, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[1][0]]);
+	ay8910_set_volume(1, 1, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[1][1]]);
+	ay8910_set_volume(1, 2, ssio_mute ? 0 : ssio_ayvolume_lookup[ssio_duty_cycle[1][2]]);
 }
 
 static WRITE8_HANDLER( ssio_porta0_w )
@@ -383,7 +383,7 @@ static WRITE8_HANDLER( ssio_portb1_w )
 /********* external interfaces ***********/
 WRITE8_HANDLER( ssio_data_w )
 {
-	timer_call_after_resynch(NULL, (offset << 8) | (data & 0xff), ssio_delayed_data_w);
+	timer_call_after_resynch(space->machine, NULL, (offset << 8) | (data & 0xff), ssio_delayed_data_w);
 }
 
 READ8_HANDLER( ssio_status_r )
@@ -391,14 +391,14 @@ READ8_HANDLER( ssio_status_r )
 	return ssio_status;
 }
 
-void ssio_reset_w(int state)
+void ssio_reset_w(running_machine *machine, int state)
 {
 	/* going high halts the CPU */
 	if (state)
 	{
 		int i;
 
-		cpunum_set_input_line(Machine, ssio_sound_cpu, INPUT_LINE_RESET, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[ssio_sound_cpu], INPUT_LINE_RESET, ASSERT_LINE);
 
 		/* latches also get reset */
 		for (i = 0; i < 4; i++)
@@ -408,16 +408,16 @@ void ssio_reset_w(int state)
 	}
 	/* going low resets and reactivates the CPU */
 	else
-		cpunum_set_input_line(Machine, ssio_sound_cpu, INPUT_LINE_RESET, CLEAR_LINE);
+		cpu_set_input_line(machine->cpu[ssio_sound_cpu], INPUT_LINE_RESET, CLEAR_LINE);
 }
 
 READ8_HANDLER( ssio_input_port_r )
 {
 	static const char *const port[] = { "SSIO.IP0", "SSIO.IP1", "SSIO.IP2", "SSIO.IP3", "SSIO.IP4" };
-	UINT8 result = readinputportbytag_safe(port[offset], 0xff);
+	UINT8 result = input_port_read_safe(space->machine, port[offset], 0xff);
 	if (ssio_custom_input[offset])
 		result = (result & ~ssio_custom_input_mask[offset]) |
-		         ((*ssio_custom_input[offset])(offset) & ssio_custom_input_mask[offset]);
+		         ((*ssio_custom_input[offset])(space, offset) & ssio_custom_input_mask[offset]);
 	return result;
 }
 
@@ -425,18 +425,18 @@ WRITE8_HANDLER( ssio_output_port_w )
 {
 	int which = offset >> 2;
 	if (which == 0)
-		mcr_control_port_w(offset, data);
+		mcr_control_port_w(space, offset, data);
 	if (ssio_custom_output[which])
-		(*ssio_custom_output[which])(offset, data & ssio_custom_output_mask[which]);
+		(*ssio_custom_output[which])(space, offset, data & ssio_custom_output_mask[which]);
 }
 
-void ssio_set_custom_input(int which, int mask, read8_handler handler)
+void ssio_set_custom_input(int which, int mask, read8_space_func handler)
 {
 	ssio_custom_input[which] = handler;
 	ssio_custom_input_mask[which] = mask;
 }
 
-void ssio_set_custom_output(int which, int mask, write8_handler handler)
+void ssio_set_custom_output(int which, int mask, write8_space_func handler)
 {
 	ssio_custom_output[which/4] = handler;
 	ssio_custom_output_mask[which/4] = mask;
@@ -444,18 +444,22 @@ void ssio_set_custom_output(int which, int mask, write8_handler handler)
 
 
 /********* sound interfaces ***********/
-static const struct AY8910interface ssio_ay8910_interface_1 =
+static const ay8910_interface ssio_ay8910_interface_1 =
 {
-	0,
-	0,
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
+	NULL,
+	NULL,
 	ssio_porta0_w,
 	ssio_portb0_w
 };
 
-static const struct AY8910interface ssio_ay8910_interface_2 =
+static const ay8910_interface ssio_ay8910_interface_2 =
 {
-	0,
-	0,
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
+	NULL,
+	NULL,
 	ssio_porta1_w,
 	ssio_portb1_w
 };
@@ -465,17 +469,17 @@ static const struct AY8910interface ssio_ay8910_interface_2 =
 
 /* address map verified from schematics */
 static ADDRESS_MAP_START( ssio_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) )
+	ADDRESS_MAP_UNMAP_HIGH
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x8000, 0x83ff) AM_MIRROR(0x0c00) AM_RAM
 	AM_RANGE(0x9000, 0x9003) AM_MIRROR(0x0ffc) AM_READ(ssio_data_r)
-	AM_RANGE(0xa000, 0xa000) AM_MIRROR(0x0ffc) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0xa001, 0xa001) AM_MIRROR(0x0ffc) AM_READ(AY8910_read_port_0_r)
-	AM_RANGE(0xa002, 0xa002) AM_MIRROR(0x0ffc) AM_WRITE(AY8910_write_port_0_w)
-	AM_RANGE(0xb000, 0xb000) AM_MIRROR(0x0ffc) AM_WRITE(AY8910_control_port_1_w)
-	AM_RANGE(0xb001, 0xb001) AM_MIRROR(0x0ffc) AM_READ(AY8910_read_port_1_r)
-	AM_RANGE(0xb002, 0xb002) AM_MIRROR(0x0ffc) AM_WRITE(AY8910_write_port_1_w)
-	AM_RANGE(0xc000, 0xcfff) AM_READWRITE(MRA8_NOP, ssio_status_w)
+	AM_RANGE(0xa000, 0xa000) AM_MIRROR(0x0ffc) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0xa001, 0xa001) AM_MIRROR(0x0ffc) AM_READ(ay8910_read_port_0_r)
+	AM_RANGE(0xa002, 0xa002) AM_MIRROR(0x0ffc) AM_WRITE(ay8910_write_port_0_w)
+	AM_RANGE(0xb000, 0xb000) AM_MIRROR(0x0ffc) AM_WRITE(ay8910_control_port_1_w)
+	AM_RANGE(0xb001, 0xb001) AM_MIRROR(0x0ffc) AM_READ(ay8910_read_port_1_r)
+	AM_RANGE(0xb002, 0xb002) AM_MIRROR(0x0ffc) AM_WRITE(ay8910_write_port_1_w)
+	AM_RANGE(0xc000, 0xcfff) AM_READWRITE(SMH_NOP, ssio_status_w)
 	AM_RANGE(0xd000, 0xdfff) AM_WRITENOP	/* low bit controls yellow LED */
 	AM_RANGE(0xe000, 0xefff) AM_READ(ssio_irq_clear)
 	AM_RANGE(0xf000, 0xffff) AM_READ_PORT("SSIO.DIP")	/* 6 DIP switches */
@@ -484,16 +488,16 @@ ADDRESS_MAP_END
 
 /********* machine driver ***********/
 MACHINE_DRIVER_START(mcr_ssio)
-	MDRV_CPU_ADD_TAG("ssio", Z80, SSIO_CLOCK/2/4)
+	MDRV_CPU_ADD("ssio", Z80, SSIO_CLOCK/2/4)
 	MDRV_CPU_PROGRAM_MAP(ssio_map,0)
 	MDRV_CPU_PERIODIC_INT(ssio_14024_clock, SSIO_CLOCK/2/16/10)
 
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
-	MDRV_SOUND_ADD_TAG("ssio.1", AY8910, SSIO_CLOCK/2/4)
+	MDRV_SOUND_ADD("ssio.1", AY8910, SSIO_CLOCK/2/4)
 	MDRV_SOUND_CONFIG(ssio_ay8910_interface_1)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.33)
 
-	MDRV_SOUND_ADD_TAG("ssio.2", AY8910, SSIO_CLOCK/2/4)
+	MDRV_SOUND_ADD("ssio.2", AY8910, SSIO_CLOCK/2/4)
 	MDRV_SOUND_CONFIG(ssio_ay8910_interface_2)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.33)
 MACHINE_DRIVER_END
@@ -512,7 +516,7 @@ MACHINE_DRIVER_END
 static WRITE8_HANDLER( csdeluxe_porta_w )
 {
 	dacval = (dacval & ~0x3fc) | (data << 2);
-	DAC_signed_data_16_w(csdeluxe_dac_index, dacval << 6);
+	dac_signed_data_16_w(csdeluxe_dac_index, dacval << 6);
 }
 
 static WRITE8_HANDLER( csdeluxe_portb_w )
@@ -520,27 +524,29 @@ static WRITE8_HANDLER( csdeluxe_portb_w )
 	UINT8 z_mask = pia_get_port_b_z_mask(0);
 
 	dacval = (dacval & ~0x003) | (data >> 6);
-	DAC_signed_data_16_w(csdeluxe_dac_index, dacval << 6);
+	dac_signed_data_16_w(csdeluxe_dac_index, dacval << 6);
 
 	if (~z_mask & 0x10)  csdeluxe_status = (csdeluxe_status & ~1) | ((data >> 4) & 1);
 	if (~z_mask & 0x20)  csdeluxe_status = (csdeluxe_status & ~2) | ((data >> 4) & 2);
 }
 
-static void csdeluxe_irq(int state)
+static void csdeluxe_irq(running_machine *machine, int state)
 {
 	int combined_state = pia_get_irq_a(0) | pia_get_irq_b(0);
 
-  	cpunum_set_input_line(Machine, csdeluxe_sound_cpu, 4, combined_state ? ASSERT_LINE : CLEAR_LINE);
+  	cpu_set_input_line(machine->cpu[csdeluxe_sound_cpu], 4, combined_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static TIMER_CALLBACK( csdeluxe_delayed_data_w )
 {
-	pia_0_portb_w(0, param & 0x0f);
-	pia_0_ca1_w(0, ~param & 0x10);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	pia_0_portb_w(space, 0, param & 0x0f);
+	pia_0_ca1_w(space, 0, ~param & 0x10);
 
 	/* oftentimes games will write one nibble at a time; the sync on this is very */
 	/* important, so we boost the interleave briefly while this happens */
-	cpu_boost_interleave(attotime_zero, ATTOTIME_IN_USEC(100));
+	cpuexec_boost_interleave(machine, attotime_zero, ATTOTIME_IN_USEC(100));
 }
 
 static READ16_HANDLER( csdeluxe_pia_r )
@@ -549,25 +555,25 @@ static READ16_HANDLER( csdeluxe_pia_r )
 	/* My guess is that Turbo Tag works through a fluke, whereby the 68000 */
 	/* using the MOVEP instruction outputs the same value on the high and */
 	/* low bytes. */
-	if (ACCESSING_MSB)
-		return pia_0_alt_r(offset) << 8;
+	if (ACCESSING_BITS_8_15)
+		return pia_0_alt_r(space, offset) << 8;
 	else
-		return pia_0_alt_r(offset);
+		return pia_0_alt_r(space, offset);
 }
 
 static WRITE16_HANDLER( csdeluxe_pia_w )
 {
-	if (ACCESSING_MSB)
-		pia_0_alt_w(offset, data >> 8);
+	if (ACCESSING_BITS_8_15)
+		pia_0_alt_w(space, offset, data >> 8);
 	else
-		pia_0_alt_w(offset, data);
+		pia_0_alt_w(space, offset, data);
 }
 
 
 /********* external interfaces ***********/
 WRITE8_HANDLER( csdeluxe_data_w )
 {
-	timer_call_after_resynch(NULL, data, csdeluxe_delayed_data_w);
+	timer_call_after_resynch(space->machine, NULL, data, csdeluxe_delayed_data_w);
 }
 
 READ8_HANDLER( csdeluxe_status_r )
@@ -575,9 +581,9 @@ READ8_HANDLER( csdeluxe_status_r )
 	return csdeluxe_status;
 }
 
-void csdeluxe_reset_w(int state)
+void csdeluxe_reset_w(running_machine *machine, int state)
 {
-	cpunum_set_input_line(Machine, csdeluxe_sound_cpu, INPUT_LINE_RESET, state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[csdeluxe_sound_cpu], INPUT_LINE_RESET, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -585,7 +591,8 @@ void csdeluxe_reset_w(int state)
 
 /* address map determined by PAL; not verified */
 static ADDRESS_MAP_START( csdeluxe_map, ADDRESS_SPACE_PROGRAM, 16 )
-	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) | AMEF_ABITS(17) )
+	ADDRESS_MAP_UNMAP_HIGH
+	ADDRESS_MAP_GLOBAL_MASK(0x1ffff)
 	AM_RANGE(0x000000, 0x007fff) AM_ROM
 	AM_RANGE(0x018000, 0x018007) AM_READWRITE(csdeluxe_pia_r, csdeluxe_pia_w)
 	AM_RANGE(0x01c000, 0x01cfff) AM_RAM
@@ -603,19 +610,19 @@ static const pia6821_interface csdeluxe_pia_intf =
 
 /********* machine driver ***********/
 MACHINE_DRIVER_START(chip_squeak_deluxe)
-	MDRV_CPU_ADD_TAG("csd", M68000, CSDELUXE_CLOCK/2)
+	MDRV_CPU_ADD("csd", M68000, CSDELUXE_CLOCK/2)
 	MDRV_CPU_PROGRAM_MAP(csdeluxe_map,0)
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
-	MDRV_SOUND_ADD_TAG("csd", DAC, 0)
+	MDRV_SOUND_ADD("csd", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 MACHINE_DRIVER_START(chip_squeak_deluxe_stereo)
-	MDRV_CPU_ADD_TAG("csd", M68000, CSDELUXE_CLOCK/2)
+	MDRV_CPU_ADD("csd", M68000, CSDELUXE_CLOCK/2)
 	MDRV_CPU_PROGRAM_MAP(csdeluxe_map,0)
 
-	MDRV_SOUND_ADD_TAG("csd", DAC, 0)
+	MDRV_SOUND_ADD("csd", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
@@ -634,7 +641,7 @@ MACHINE_DRIVER_END
 static WRITE8_HANDLER( soundsgood_porta_w )
 {
 	dacval = (dacval & ~0x3fc) | (data << 2);
-	DAC_signed_data_16_w(soundsgood_dac_index, dacval << 6);
+	dac_signed_data_16_w(soundsgood_dac_index, dacval << 6);
 }
 
 static WRITE8_HANDLER( soundsgood_portb_w )
@@ -642,34 +649,36 @@ static WRITE8_HANDLER( soundsgood_portb_w )
 	UINT8 z_mask = pia_get_port_b_z_mask(1);
 
 	dacval = (dacval & ~0x003) | (data >> 6);
-	DAC_signed_data_16_w(soundsgood_dac_index, dacval << 6);
+	dac_signed_data_16_w(soundsgood_dac_index, dacval << 6);
 
 	if (~z_mask & 0x10)  soundsgood_status = (soundsgood_status & ~1) | ((data >> 4) & 1);
 	if (~z_mask & 0x20)  soundsgood_status = (soundsgood_status & ~2) | ((data >> 4) & 2);
 }
 
-static void soundsgood_irq(int state)
+static void soundsgood_irq(running_machine *machine, int state)
 {
 	int combined_state = pia_get_irq_a(1) | pia_get_irq_b(1);
 
-  	cpunum_set_input_line(Machine, soundsgood_sound_cpu, 4, combined_state ? ASSERT_LINE : CLEAR_LINE);
+  	cpu_set_input_line(machine->cpu[soundsgood_sound_cpu], 4, combined_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static TIMER_CALLBACK( soundsgood_delayed_data_w )
 {
-	pia_1_portb_w(0, (param >> 1) & 0x0f);
-	pia_1_ca1_w(0, ~param & 0x01);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	pia_1_portb_w(space, 0, (param >> 1) & 0x0f);
+	pia_1_ca1_w(space, 0, ~param & 0x01);
 
 	/* oftentimes games will write one nibble at a time; the sync on this is very */
 	/* important, so we boost the interleave briefly while this happens */
-	cpu_boost_interleave(attotime_zero, ATTOTIME_IN_USEC(250));
+	cpuexec_boost_interleave(machine, attotime_zero, ATTOTIME_IN_USEC(250));
 }
 
 
 /********* external interfaces ***********/
 WRITE8_HANDLER( soundsgood_data_w )
 {
-	timer_call_after_resynch(NULL, data, soundsgood_delayed_data_w);
+	timer_call_after_resynch(space->machine, NULL, data, soundsgood_delayed_data_w);
 }
 
 READ8_HANDLER( soundsgood_status_r )
@@ -677,10 +686,10 @@ READ8_HANDLER( soundsgood_status_r )
 	return soundsgood_status;
 }
 
-void soundsgood_reset_w(int state)
+void soundsgood_reset_w(running_machine *machine, int state)
 {
 //if (state) mame_printf_debug("SG Reset\n");
-	cpunum_set_input_line(Machine, soundsgood_sound_cpu, INPUT_LINE_RESET, state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[soundsgood_sound_cpu], INPUT_LINE_RESET, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -688,9 +697,10 @@ void soundsgood_reset_w(int state)
 
 /* address map determined by PAL; not verified */
 static ADDRESS_MAP_START( soundsgood_map, ADDRESS_SPACE_PROGRAM, 16 )
-	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) | AMEF_ABITS(19) )
+	ADDRESS_MAP_UNMAP_HIGH
+	ADDRESS_MAP_GLOBAL_MASK(0x7ffff)
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
-	AM_RANGE(0x060000, 0x060007) AM_READWRITE(pia_1_msb_alt_r, pia_1_msb_alt_w)
+	AM_RANGE(0x060000, 0x060007) AM_READWRITE8(pia_1_alt_r, pia_1_alt_w, 0xff00)
 	AM_RANGE(0x070000, 0x070fff) AM_RAM
 ADDRESS_MAP_END
 
@@ -709,11 +719,11 @@ static const pia6821_interface soundsgood_pia_intf =
 
 /********* machine driver ***********/
 MACHINE_DRIVER_START(sounds_good)
-	MDRV_CPU_ADD_TAG("sg", M68000, SOUNDSGOOD_CLOCK/2)
+	MDRV_CPU_ADD("sg", M68000, SOUNDSGOOD_CLOCK/2)
 	MDRV_CPU_PROGRAM_MAP(soundsgood_map,0)
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
-	MDRV_SOUND_ADD_TAG("sg", DAC, 0)
+	MDRV_SOUND_ADD("sg", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -731,38 +741,40 @@ MACHINE_DRIVER_END
 static WRITE8_HANDLER( turbocs_porta_w )
 {
 	dacval = (dacval & ~0x3fc) | (data << 2);
-	DAC_signed_data_16_w(turbocs_dac_index, dacval << 6);
+	dac_signed_data_16_w(turbocs_dac_index, dacval << 6);
 }
 
 static WRITE8_HANDLER( turbocs_portb_w )
 {
 	dacval = (dacval & ~0x003) | (data >> 6);
-	DAC_signed_data_16_w(turbocs_dac_index, dacval << 6);
+	dac_signed_data_16_w(turbocs_dac_index, dacval << 6);
 	turbocs_status = (data >> 4) & 3;
 }
 
-static void turbocs_irq(int state)
+static void turbocs_irq(running_machine *machine, int state)
 {
 	int combined_state = pia_get_irq_a(0) | pia_get_irq_b(0);
 
-	cpunum_set_input_line(Machine, turbocs_sound_cpu, M6809_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[turbocs_sound_cpu], M6809_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static TIMER_CALLBACK( turbocs_delayed_data_w )
 {
-	pia_0_portb_w(0, (param >> 1) & 0x0f);
-	pia_0_ca1_w(0, ~param & 0x01);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	pia_0_portb_w(space, 0, (param >> 1) & 0x0f);
+	pia_0_ca1_w(space, 0, ~param & 0x01);
 
 	/* oftentimes games will write one nibble at a time; the sync on this is very */
 	/* important, so we boost the interleave briefly while this happens */
-	cpu_boost_interleave(attotime_zero, ATTOTIME_IN_USEC(100));
+	cpuexec_boost_interleave(machine, attotime_zero, ATTOTIME_IN_USEC(100));
 }
 
 
 /********* external interfaces ***********/
 WRITE8_HANDLER( turbocs_data_w )
 {
-	timer_call_after_resynch(NULL, data, turbocs_delayed_data_w);
+	timer_call_after_resynch(space->machine, NULL, data, turbocs_delayed_data_w);
 }
 
 READ8_HANDLER( turbocs_status_r )
@@ -770,9 +782,9 @@ READ8_HANDLER( turbocs_status_r )
 	return turbocs_status;
 }
 
-void turbocs_reset_w(int state)
+void turbocs_reset_w(running_machine *machine, int state)
 {
-	cpunum_set_input_line(Machine, turbocs_sound_cpu, INPUT_LINE_RESET, state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[turbocs_sound_cpu], INPUT_LINE_RESET, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -780,7 +792,7 @@ void turbocs_reset_w(int state)
 
 /* address map verified from schematics */
 static ADDRESS_MAP_START( turbocs_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) )
+	ADDRESS_MAP_UNMAP_HIGH
 	AM_RANGE(0x0000, 0x07ff) AM_MIRROR(0x3800) AM_RAM
 	AM_RANGE(0x4000, 0x4003) AM_MIRROR(0x3ffc) AM_READWRITE(pia_0_alt_r, pia_0_alt_w)
 	AM_RANGE(0x8000, 0xffff) AM_ROM
@@ -798,11 +810,11 @@ static const pia6821_interface turbocs_pia_intf =
 
 /********* machine driver ***********/
 MACHINE_DRIVER_START(turbo_chip_squeak)
-	MDRV_CPU_ADD_TAG("tcs", M6809E, TURBOCS_CLOCK)
+	MDRV_CPU_ADD("tcs", M6809E, TURBOCS_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(turbocs_map,0)
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
-	MDRV_SOUND_ADD_TAG("tcs", DAC, 0)
+	MDRV_SOUND_ADD("tcs", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -813,10 +825,10 @@ MACHINE_DRIVER_START(turbo_chip_squeak_plus_sounds_good)
 	MDRV_IMPORT_FROM(sounds_good)
 
 	MDRV_SOUND_REPLACE("tcs", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
 	MDRV_SOUND_REPLACE("sg", DAC, 0)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 
@@ -853,50 +865,52 @@ static WRITE8_HANDLER( squawkntalk_portb2_w )
 	/* write strobe -- pass the current command to the TMS5200 */
 	if (((data ^ squawkntalk_tms_strobes) & 0x02) && !(data & 0x02))
 	{
-		tms5220_data_w(offset, squawkntalk_tms_command);
+		tms5220_data_w(space, offset, squawkntalk_tms_command);
 
 		/* DoT expects the ready line to transition on a command/write here, so we oblige */
-		pia_1_ca2_w(0, 1);
-		pia_1_ca2_w(0, 0);
+		pia_1_ca2_w(space, 0, 1);
+		pia_1_ca2_w(space, 0, 0);
 	}
 
 	/* read strobe -- read the current status from the TMS5200 */
 	else if (((data ^ squawkntalk_tms_strobes) & 0x01) && !(data & 0x01))
 	{
-		pia_1_porta_w(0, tms5220_status_r(offset));
+		pia_1_porta_w(space, 0, tms5220_status_r(space, offset));
 
 		/* DoT expects the ready line to transition on a command/write here, so we oblige */
-		pia_1_ca2_w(0, 1);
-		pia_1_ca2_w(0, 0);
+		pia_1_ca2_w(space, 0, 1);
+		pia_1_ca2_w(space, 0, 0);
 	}
 
 	/* remember the state */
 	squawkntalk_tms_strobes = data;
 }
 
-static void squawkntalk_irq(int state)
+static void squawkntalk_irq(running_machine *machine, int state)
 {
 	int combined_state = pia_get_irq_a(0) | pia_get_irq_b(0) | pia_get_irq_a(1) | pia_get_irq_b(1);
 
-	cpunum_set_input_line(Machine, squawkntalk_sound_cpu, M6808_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[squawkntalk_sound_cpu], M6800_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static TIMER_CALLBACK( squawkntalk_delayed_data_w )
 {
-	pia_0_porta_w(0, ~param & 0x0f);
-	pia_0_cb1_w(0, ~param & 0x10);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	pia_0_porta_w(space, 0, ~param & 0x0f);
+	pia_0_cb1_w(space, 0, ~param & 0x10);
 }
 
 
 /********* external interfaces ***********/
 WRITE8_HANDLER( squawkntalk_data_w )
 {
-	timer_call_after_resynch(NULL, data, squawkntalk_delayed_data_w);
+	timer_call_after_resynch(space->machine, NULL, data, squawkntalk_delayed_data_w);
 }
 
-void squawkntalk_reset_w(int state)
+void squawkntalk_reset_w(running_machine *machine, int state)
 {
-	cpunum_set_input_line(Machine, squawkntalk_sound_cpu, INPUT_LINE_RESET, state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[squawkntalk_sound_cpu], INPUT_LINE_RESET, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -906,7 +920,7 @@ void squawkntalk_reset_w(int state)
 /* note that jumpers control the ROM sizes; if these are changed, use the alternate */
 /* address map below */
 static ADDRESS_MAP_START( squawkntalk_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) )
+	ADDRESS_MAP_UNMAP_HIGH
 	AM_RANGE(0x0000, 0x007f) AM_RAM		/* internal RAM */
 	AM_RANGE(0x0080, 0x0083) AM_MIRROR(0x4f6c) AM_READWRITE(pia_0_r, pia_0_w)
 	AM_RANGE(0x0090, 0x0093) AM_MIRROR(0x4f6c) AM_READWRITE(pia_1_r, pia_1_w)
@@ -918,7 +932,7 @@ ADDRESS_MAP_END
 /* ROM size of 2k */
 #ifdef UNUSED_FUNCTION
 ADDRESS_MAP_START( squawkntalk_alt_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) )
+	ADDRESS_MAP_UNMAP_HIGH
 	AM_RANGE(0x0000, 0x007f) AM_RAM		/* internal RAM */
 	AM_RANGE(0x0080, 0x0083) AM_MIRROR(0x676c) AM_READWRITE(pia_0_r, pia_0_w)
 	AM_RANGE(0x0090, 0x0093) AM_MIRROR(0x676c) AM_READWRITE(pia_1_r, pia_1_w)
@@ -946,11 +960,11 @@ static const pia6821_interface squawkntalk_pia1_intf =
 
 /********* machine driver ***********/
 MACHINE_DRIVER_START(squawk_n_talk)
-	MDRV_CPU_ADD_TAG("snt", M6802, SQUAWKTALK_CLOCK)
+	MDRV_CPU_ADD("snt", M6802, SQUAWKTALK_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(squawkntalk_map,0)
 
 	/* only used on Discs of Tron, which is stereo */
-	MDRV_SOUND_ADD_TAG("snt", TMS5200, 640000)
+	MDRV_SOUND_ADD("snt", TMS5200, 640000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.60)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.60)
 
