@@ -9,10 +9,10 @@
 
 #include "driver.h"
 #include "streams.h"
-#include "deprecat.h"
-#include "cpu/i8039/i8039.h"
+#include "cpu/mcs48/mcs48.h"
 #include "segag80r.h"
 #include "machine/8255ppi.h"
+#include "machine/i8243.h"
 #include "sound/samples.h"
 #include "sound/tms36xx.h"
 #include "sound/dac.h"
@@ -197,7 +197,7 @@ static const char *const astrob_sample_names[] =
 };
 
 
-static const struct Samplesinterface astrob_samples_interface =
+static const samples_interface astrob_samples_interface =
 {
 	11,
 	astrob_sample_names
@@ -209,7 +209,7 @@ MACHINE_DRIVER_START( astrob_sound_board )
 	MDRV_SOUND_START(astrob)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(astrob_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
@@ -224,8 +224,8 @@ MACHINE_DRIVER_END
 
 static SOUND_START( astrob )
 {
-	state_save_register_global_array(sound_state);
-	state_save_register_global(sound_rate);
+	state_save_register_global_array(machine, sound_state);
+	state_save_register_global(machine, sound_rate);
 }
 
 
@@ -339,9 +339,11 @@ WRITE8_HANDLER( astrob_sound_w )
  *************************************/
 
 static SOUND_START( 005 );
-static void *sega005_custom_start(int clock, const struct CustomSound_interface *config);
-static void sega005_stream_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int samples);
+static CUSTOM_START( sega005_custom_start );
+static STREAM_UPDATE( sega005_stream_update );
 static TIMER_CALLBACK( sega005_auto_timer );
+static WRITE8_DEVICE_HANDLER( sega005_sound_a_w );
+static WRITE8_DEVICE_HANDLER( sega005_sound_b_w );
 
 /*
     005
@@ -412,29 +414,42 @@ static const char *const sega005_sample_names[] =
 };
 
 
-static const struct Samplesinterface sega005_samples_interface =
+static const samples_interface sega005_samples_interface =
 {
 	7,
 	sega005_sample_names
 };
 
 
-static const struct CustomSound_interface sega005_custom_interface =
+static const custom_sound_interface sega005_custom_interface =
 {
 	sega005_custom_start
 };
 
 
+static const ppi8255_interface ppi8255_005_intf =
+{
+	NULL,
+	NULL,
+	NULL,
+	sega005_sound_a_w,
+	sega005_sound_b_w,
+	NULL
+};
+
+
 MACHINE_DRIVER_START( 005_sound_board )
 
+	MDRV_PPI8255_ADD( "ppi8255", ppi8255_005_intf )
+
 	/* sound hardware */
 	MDRV_SOUND_START(005)
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(sega005_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD(CUSTOM, 0)
+	MDRV_SOUND_ADD("005", CUSTOM, 0)
 	MDRV_SOUND_CONFIG(sega005_custom_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
@@ -449,23 +464,11 @@ MACHINE_DRIVER_END
 
 static SOUND_START( 005 )
 {
-	static const ppi8255_interface ppi_intf =
-	{
-		1,
-		{ 0 },
-		{ 0 },
-		{ 0 },
-		{ sega005_sound_a_w },
-		{ sega005_sound_b_w },
-		{ 0 }
-	};
-	ppi8255_init(&ppi_intf);
-
-	state_save_register_global_array(sound_state);
-	state_save_register_global(sound_addr);
-	state_save_register_global(sound_data);
-	state_save_register_global(square_state);
-	state_save_register_global(square_count);
+	state_save_register_global_array(machine, sound_state);
+	state_save_register_global(machine, sound_addr);
+	state_save_register_global(machine, sound_data);
+	state_save_register_global(machine, square_state);
+	state_save_register_global(machine, square_count);
 }
 
 
@@ -476,7 +479,7 @@ static SOUND_START( 005 )
  *
  *************************************/
 
-WRITE8_HANDLER( sega005_sound_a_w )
+static WRITE8_DEVICE_HANDLER( sega005_sound_a_w )
 {
 	UINT8 diff = data ^ sound_state[0];
 	sound_state[0] = data;
@@ -506,9 +509,9 @@ WRITE8_HANDLER( sega005_sound_a_w )
 }
 
 
-INLINE void sega005_update_sound_data(void)
+INLINE void sega005_update_sound_data(running_machine *machine)
 {
-	UINT8 newval = memory_region(REGION_SOUND1)[sound_addr];
+	UINT8 newval = memory_region(machine, "005")[sound_addr];
 	UINT8 diff = newval ^ sound_data;
 
 	//mame_printf_debug("  [%03X] = %02X\n", sound_addr, newval);
@@ -520,19 +523,19 @@ INLINE void sega005_update_sound_data(void)
 	if ((diff & 0x20) && !(newval & 0x20))
 	{
 		//mame_printf_debug("Stopping timer\n");
-		timer_adjust(sega005_sound_timer, attotime_never, 0, attotime_never);
+		timer_adjust_oneshot(sega005_sound_timer, attotime_never, 0);
 	}
 
 	/* if bit 5 goes low, we start the timer again */
 	if ((diff & 0x20) && (newval & 0x20))
 	{
 		//mame_printf_debug("Starting timer\n");
-		timer_adjust(sega005_sound_timer, ATTOTIME_IN_HZ(SEGA005_555_TIMER_FREQ), 0, ATTOTIME_IN_HZ(SEGA005_555_TIMER_FREQ));
+		timer_adjust_periodic(sega005_sound_timer, ATTOTIME_IN_HZ(SEGA005_555_TIMER_FREQ), 0, ATTOTIME_IN_HZ(SEGA005_555_TIMER_FREQ));
 	}
 }
 
 
-WRITE8_HANDLER( sega005_sound_b_w )
+static WRITE8_DEVICE_HANDLER( sega005_sound_b_w )
 {
 	/*
            D6: manual timer clock (0->1)
@@ -563,7 +566,7 @@ WRITE8_HANDLER( sega005_sound_b_w )
 		sound_addr = (sound_addr & 0x780) | ((sound_addr + 1) & 0x07f);
 
 	/* update the sound data */
-	sega005_update_sound_data();
+	sega005_update_sound_data(device->machine);
 }
 
 
@@ -574,25 +577,27 @@ WRITE8_HANDLER( sega005_sound_b_w )
  *
  *************************************/
 
-static void *sega005_custom_start(int clock, const struct CustomSound_interface *config)
+static CUSTOM_START( sega005_custom_start )
 {
+	running_machine *machine = device->machine;
+
 	/* create the stream */
-	sega005_stream = stream_create(0, 1, SEGA005_COUNTER_FREQ, NULL, sega005_stream_update);
+	sega005_stream = stream_create(device, 0, 1, SEGA005_COUNTER_FREQ, NULL, sega005_stream_update);
 
 	/* create a timer for the 555 */
-	sega005_sound_timer = timer_alloc(sega005_auto_timer, NULL);
+	sega005_sound_timer = timer_alloc(machine, sega005_auto_timer, NULL);
 
 	/* set the initial sound data */
 	sound_data = 0x00;
-	sega005_update_sound_data();
+	sega005_update_sound_data(machine);
 
 	return auto_malloc(1);
 }
 
 
-static void sega005_stream_update(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+static STREAM_UPDATE( sega005_stream_update )
 {
-	const UINT8 *sound_prom = memory_region(REGION_PROMS);
+	const UINT8 *sound_prom = memory_region(device->machine, "proms");
 	int i;
 
 	/* no implementation yet */
@@ -619,7 +624,7 @@ static TIMER_CALLBACK( sega005_auto_timer )
 	if ((sound_state[1] & 0x20) && !(sound_state[1] & 0x10))
 	{
 		sound_addr = (sound_addr & 0x780) | ((sound_addr + 1) & 0x07f);
-		sega005_update_sound_data();
+		sega005_update_sound_data(machine);
 	}
 }
 
@@ -651,7 +656,7 @@ static const char *const spaceod_sample_names[] =
 };
 
 
-static const struct Samplesinterface spaceod_samples_interface =
+static const samples_interface spaceod_samples_interface =
 {
 	11,
 	spaceod_sample_names
@@ -663,7 +668,7 @@ MACHINE_DRIVER_START( spaceod_sound_board )
 	/* sound hardware */
 	MDRV_SOUND_START(spaceod)
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(spaceod_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
@@ -678,7 +683,7 @@ MACHINE_DRIVER_END
 
 static SOUND_START( spaceod )
 {
-	state_save_register_global_array(sound_state);
+	state_save_register_global_array(machine, sound_state);
 }
 
 
@@ -745,15 +750,14 @@ WRITE8_HANDLER( spaceod_sound_w )
  *************************************/
 
 static SOUND_START( monsterb );
-static WRITE8_HANDLER( monsterb_sound_a_w );
-static WRITE8_HANDLER( monsterb_sound_b_w );
-static READ8_HANDLER( n7751_status_r );
-static WRITE8_HANDLER( n7751_command_w );
-static WRITE8_HANDLER( n7751_rom_offset_w );
-static WRITE8_HANDLER( n7751_rom_select_w );
+static WRITE8_DEVICE_HANDLER( monsterb_sound_a_w );
+static WRITE8_DEVICE_HANDLER( monsterb_sound_b_w );
+static READ8_DEVICE_HANDLER( n7751_status_r );
+static WRITE8_DEVICE_HANDLER( n7751_command_w );
+static WRITE8_DEVICE_HANDLER( n7751_rom_control_w );
 static READ8_HANDLER( n7751_rom_r );
 static READ8_HANDLER( n7751_command_r );
-static WRITE8_HANDLER( n7751_busy_w );
+static WRITE8_DEVICE_HANDLER( n7751_p2_w );
 static READ8_HANDLER( n7751_t1_r );
 
 /*
@@ -776,14 +780,14 @@ static const char *const monsterb_sample_names[] =
 };
 
 
-static const struct Samplesinterface monsterb_samples_interface =
+static const samples_interface monsterb_samples_interface =
 {
 	2,
 	monsterb_sample_names
 };
 
 
-static const struct TMS36XXinterface monsterb_tms3617_interface =
+static const tms36xx_interface monsterb_tms3617_interface =
 {
 	TMS3617,
 	{0.5,0.5,0.5,0.5,0.5,0.5}  /* decay times of voices */
@@ -797,18 +801,13 @@ static const struct TMS36XXinterface monsterb_tms3617_interface =
  *
  *************************************/
 
-static ADDRESS_MAP_START( monsterb_7751_map, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x03ff) AM_ROM
-ADDRESS_MAP_END
-
 static ADDRESS_MAP_START( monsterb_7751_portmap, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(I8039_t1, I8039_t1) AM_READ(n7751_t1_r)
-	AM_RANGE(I8039_p2, I8039_p2) AM_READ(n7751_command_r)
-	AM_RANGE(I8039_bus, I8039_bus) AM_READ(n7751_rom_r)
-	AM_RANGE(I8039_p1, I8039_p1) AM_WRITE(DAC_0_data_w)
-	AM_RANGE(I8039_p2, I8039_p2) AM_WRITE(n7751_busy_w)
-	AM_RANGE(I8039_p4, I8039_p6) AM_WRITE(n7751_rom_offset_w)
-	AM_RANGE(I8039_p7, I8039_p7) AM_WRITE(n7751_rom_select_w)
+	AM_RANGE(MCS48_PORT_T1,   MCS48_PORT_T1) AM_READ(n7751_t1_r)
+	AM_RANGE(MCS48_PORT_P2,   MCS48_PORT_P2) AM_READ(n7751_command_r)
+	AM_RANGE(MCS48_PORT_BUS,  MCS48_PORT_BUS) AM_READ(n7751_rom_r)
+	AM_RANGE(MCS48_PORT_P1,   MCS48_PORT_P1) AM_WRITE(dac_0_data_w)
+	AM_RANGE(MCS48_PORT_P2,   MCS48_PORT_P2) AM_DEVWRITE(I8243, "audio_8243", n7751_p2_w)
+	AM_RANGE(MCS48_PORT_PROG, MCS48_PORT_PROG) AM_DEVWRITE(I8243, "audio_8243", i8243_prog_w)
 ADDRESS_MAP_END
 
 
@@ -819,25 +818,39 @@ ADDRESS_MAP_END
  *
  *************************************/
 
+static const ppi8255_interface monsterb_ppi_intf =
+{
+	NULL,
+	NULL,
+	n7751_status_r,
+	monsterb_sound_a_w,
+	monsterb_sound_b_w,
+	n7751_command_w
+};
+
+
 MACHINE_DRIVER_START( monsterb_sound_board )
 
+	MDRV_PPI8255_ADD( "ppi8255", monsterb_ppi_intf )
+
 	/* basic machine hardware */
-	MDRV_CPU_ADD(N7751, 6000000)
-	MDRV_CPU_PROGRAM_MAP(monsterb_7751_map,0)
+	MDRV_CPU_ADD("audio", N7751, 6000000)
 	MDRV_CPU_IO_MAP(monsterb_7751_portmap,0)
 
+	MDRV_I8243_ADD("audio_8243", NULL, n7751_rom_control_w)
+
 	/* sound hardware */
 	MDRV_SOUND_START(monsterb)
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(monsterb_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD(TMS36XX, 247)
+	MDRV_SOUND_ADD("music", TMS36XX, 247)
 	MDRV_SOUND_CONFIG(monsterb_tms3617_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ADD("dac", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -851,22 +864,10 @@ MACHINE_DRIVER_END
 
 static SOUND_START( monsterb )
 {
-	static const ppi8255_interface ppi_intf =
-	{
-		1,
-		{ 0 },
-		{ 0 },
-		{ n7751_status_r },
-		{ monsterb_sound_a_w },
-		{ monsterb_sound_b_w },
-		{ n7751_command_w }
-	};
-	ppi8255_init(&ppi_intf);
-
-	state_save_register_global_array(sound_state);
-	state_save_register_global(sound_addr);
-	state_save_register_global(n7751_command);
-	state_save_register_global(n7751_busy);
+	state_save_register_global_array(machine, sound_state);
+	state_save_register_global(machine, sound_addr);
+	state_save_register_global(machine, n7751_command);
+	state_save_register_global(machine, n7751_busy);
 }
 
 
@@ -877,7 +878,7 @@ static SOUND_START( monsterb )
  *
  *************************************/
 
-static WRITE8_HANDLER( monsterb_sound_a_w )
+static WRITE8_DEVICE_HANDLER( monsterb_sound_a_w )
 {
 	int enable_val;
 
@@ -885,7 +886,7 @@ static WRITE8_HANDLER( monsterb_sound_a_w )
 	tms36xx_note_w(0, 0, data & 15);
 
 	/* Top four data lines address an 82S123 ROM that enables/disables voices */
-	enable_val = memory_region(REGION_SOUND2)[(data & 0xF0) >> 4];
+	enable_val = memory_region(device->machine, "prom")[(data & 0xF0) >> 4];
 	tms3617_enable_w(0, enable_val >> 2);
 }
 
@@ -897,7 +898,7 @@ static WRITE8_HANDLER( monsterb_sound_a_w )
  *
  *************************************/
 
-static WRITE8_HANDLER( monsterb_sound_b_w )
+static WRITE8_DEVICE_HANDLER( monsterb_sound_b_w )
 {
 	UINT8 diff = data ^ sound_state[1];
 	sound_state[1] = data;
@@ -919,13 +920,13 @@ static WRITE8_HANDLER( monsterb_sound_b_w )
  *
  *************************************/
 
-static READ8_HANDLER( n7751_status_r )
+static READ8_DEVICE_HANDLER( n7751_status_r )
 {
 	return n7751_busy << 4;
 }
 
 
-static WRITE8_HANDLER( n7751_command_w )
+static WRITE8_DEVICE_HANDLER( n7751_command_w )
 {
 	/*
         Z80 7751 control port
@@ -934,38 +935,49 @@ static WRITE8_HANDLER( n7751_command_w )
         D3    = /INT line
     */
 	n7751_command = data & 0x07;
-	cpunum_set_input_line(Machine, 1, 0, ((data & 0x08) == 0) ? ASSERT_LINE : CLEAR_LINE);
-	cpu_boost_interleave(attotime_zero, ATTOTIME_IN_USEC(100));
+	cpu_set_input_line(device->machine->cpu[1], 0, ((data & 0x08) == 0) ? ASSERT_LINE : CLEAR_LINE);
+	cpuexec_boost_interleave(device->machine, attotime_zero, ATTOTIME_IN_USEC(100));
 }
 
 
-static WRITE8_HANDLER( n7751_rom_offset_w )
+static WRITE8_DEVICE_HANDLER( n7751_rom_control_w )
 {
 	/* P4 - address lines 0-3 */
 	/* P5 - address lines 4-7 */
 	/* P6 - address lines 8-11 */
-	int mask = (0xf << (4 * offset)) & 0x3fff;
-	int newdata = (data << (4 * offset)) & mask;
-	sound_addr = (sound_addr & ~mask) | newdata;
-}
-
-
-static WRITE8_HANDLER( n7751_rom_select_w )
-{
 	/* P7 - ROM selects */
-	int numroms = memory_region_length(REGION_SOUND1) / 0x1000;
-	sound_addr &= 0xfff;
-	if (!(data & 0x01) && numroms >= 1) sound_addr |= 0x0000;
-	if (!(data & 0x02) && numroms >= 2) sound_addr |= 0x1000;
-	if (!(data & 0x04) && numroms >= 3) sound_addr |= 0x2000;
-	if (!(data & 0x08) && numroms >= 4) sound_addr |= 0x3000;
+	switch (offset)
+	{
+		case 0:
+			sound_addr = (sound_addr & ~0x00f) | ((data & 0x0f) << 0);
+			break;
+
+		case 1:
+			sound_addr = (sound_addr & ~0x0f0) | ((data & 0x0f) << 4);
+			break;
+
+		case 2:
+			sound_addr = (sound_addr & ~0xf00) | ((data & 0x0f) << 8);
+			break;
+
+		case 3:
+			sound_addr &= 0xfff;
+			{
+				int numroms = memory_region_length(device->machine, "n7751") / 0x1000;
+				if (!(data & 0x01) && numroms >= 1) sound_addr |= 0x0000;
+				if (!(data & 0x02) && numroms >= 2) sound_addr |= 0x1000;
+				if (!(data & 0x04) && numroms >= 3) sound_addr |= 0x2000;
+				if (!(data & 0x08) && numroms >= 4) sound_addr |= 0x3000;
+			}
+			break;
+	}
 }
 
 
 static READ8_HANDLER( n7751_rom_r )
 {
 	/* read from BUS */
-	return memory_region(REGION_SOUND1)[sound_addr];
+	return memory_region(space->machine, "n7751")[sound_addr];
 }
 
 
@@ -977,9 +989,11 @@ static READ8_HANDLER( n7751_command_r )
 }
 
 
-static WRITE8_HANDLER( n7751_busy_w )
+static WRITE8_DEVICE_HANDLER( n7751_p2_w )
 {
-	/* write to P2 */
+	/* write to P2; low 4 bits go to 8243 */
+	i8243_p2_w(device, offset, data & 0x0f);
+
 	/* output of bit $80 indicates we are ready (1) or busy (0) */
 	/* no other outputs are used */
 	n7751_busy = data >> 7;
