@@ -8,6 +8,7 @@
 
 #include "driver.h"
 #include "sound/samples.h"
+#include "includes/suna8.h"
 
 static INT16 *samplebuf;
 static int sample;
@@ -33,13 +34,14 @@ WRITE8_HANDLER( suna8_samples_number_w )
 	sample = data & 0xf;
 }
 
-void suna8_sh_start(void)
+SAMPLES_START( suna8_sh_start )
 {
-	int i;
-	UINT8 *ROM = memory_region(REGION_SOUND1);
+	running_machine *machine = device->machine;
+	int i, len = memory_region_length(machine, "samples");
+	UINT8 *ROM = memory_region(machine, "samples");
 
-	samplebuf = auto_malloc(memory_region_length(REGION_SOUND1) * sizeof(samplebuf[0]));
+	samplebuf = auto_malloc(len * sizeof(samplebuf[0]));
 
-	for(i=0;i<memory_region_length(REGION_SOUND1);i++)
+	for(i=0;i<len;i++)
 		samplebuf[i] = (INT8)(ROM[i] ^ 0x80) * 256;
 }
