@@ -166,6 +166,7 @@ Notes:
 */
 
 #include "driver.h"
+#include "cpu/rsp/rsp.h"
 #include "cpu/mips/mips3.h"
 #include "streams.h"
 #include "sound/custom.h"
@@ -175,11 +176,11 @@ static READ32_HANDLER( aleck_dips_r )
 {
 	if (offset == 0)
 	{
-		return (readinputport(3));
+		return (input_port_read(space->machine, "IN0"));	/* mtetrisc has regular inputs here */
 	}
 	else if (offset == 1)
 	{
-		return (readinputport(4));
+		return (input_port_read(space->machine, "IN1"));
 	}
 
 	return 0;
@@ -197,11 +198,11 @@ static ADDRESS_MAP_START( n64_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x04600000, 0x046fffff) AM_READWRITE(n64_pi_reg_r, n64_pi_reg_w)	// Peripheral Interface
 	AM_RANGE(0x04700000, 0x047fffff) AM_READWRITE(n64_ri_reg_r, n64_ri_reg_w)	// RDRAM Interface
 	AM_RANGE(0x04800000, 0x048fffff) AM_READWRITE(n64_si_reg_r, n64_si_reg_w)	// Serial Interface
-	AM_RANGE(0x10000000, 0x13ffffff) AM_ROM AM_REGION(REGION_USER2, 0)	// Cartridge
-	AM_RANGE(0x1fc00000, 0x1fc007bf) AM_ROM AM_REGION(REGION_USER1, 0)	// PIF ROM
+	AM_RANGE(0x10000000, 0x13ffffff) AM_ROM AM_REGION("user2", 0)	// Cartridge
+	AM_RANGE(0x1fc00000, 0x1fc007bf) AM_ROM AM_REGION("user1", 0)	// PIF ROM
 	AM_RANGE(0x1fc007c0, 0x1fc007ff) AM_READWRITE(n64_pif_ram_r, n64_pif_ram_w)
 
-	AM_RANGE(0xc0800000, 0xc08fffff) AM_READWRITE(aleck_dips_r, MWA32_NOP)
+	AM_RANGE(0xc0800000, 0xc08fffff) AM_READWRITE(aleck_dips_r, SMH_NOP)
 	AM_RANGE(0xd0000000, 0xd0000fff) AM_RAM
 	AM_RANGE(0xd0010000, 0xd00109ff) AM_RAM
 ADDRESS_MAP_END
@@ -212,7 +213,7 @@ static ADDRESS_MAP_START( rsp_map, ADDRESS_SPACE_PROGRAM, 32 )
 ADDRESS_MAP_END
 
 static INPUT_PORTS_START( aleck64 )
-	PORT_START_TAG("P1")
+	PORT_START("P1")
 		PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(1)			// Button A
 		PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_PLAYER(1)			// Button B
 		PORT_BIT( 0x2000, IP_ACTIVE_HIGH, IPT_BUTTON3 ) PORT_PLAYER(1)			// Button Z
@@ -229,13 +230,13 @@ static INPUT_PORTS_START( aleck64 )
 		PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_BUTTON8 ) PORT_PLAYER(1)			// C Button Left
 		PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_BUTTON9 ) PORT_PLAYER(1)			// C Button Right
 
-	PORT_START_TAG("P1_ANALOG_X")
+	PORT_START("P1_ANALOG_X")
 		PORT_BIT( 0xff, 0x80, IPT_AD_STICK_X ) PORT_SENSITIVITY(30) PORT_KEYDELTA(30) PORT_PLAYER(1)
 
-	PORT_START_TAG("P1_ANALOG_Y")
+	PORT_START("P1_ANALOG_Y")
 		PORT_BIT( 0xff, 0x80, IPT_AD_STICK_Y ) PORT_MINMAX(0xff,0x00) PORT_SENSITIVITY(30) PORT_KEYDELTA(30) PORT_PLAYER(1)
 
-	PORT_START
+	PORT_START("IN0")
 		PORT_DIPNAME( 0x80000000, 0x80000000, "DIPSW1 #8" )
 		PORT_DIPSETTING( 0x80000000, DEF_STR( Off ) )
 		PORT_DIPSETTING( 0x00000000, DEF_STR( On ) )
@@ -286,9 +287,9 @@ static INPUT_PORTS_START( aleck64 )
 		PORT_DIPSETTING( 0x00000000, DEF_STR( On ) )
 		PORT_BIT(0x0000ffff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("IN1")
 		PORT_BIT( 0xff00ffff, IP_ACTIVE_LOW, IPT_UNUSED )
-		PORT_BIT( 0x00200000, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2)
+		PORT_SERVICE_NO_TOGGLE( 0x00200000, IP_ACTIVE_LOW )
 		PORT_BIT( 0x00100000, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME("Service Button") PORT_CODE(KEYCODE_7)
 		PORT_BIT( 0x00080000, IP_ACTIVE_LOW, IPT_COIN2 )
 		PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_COIN1 )
@@ -296,11 +297,11 @@ INPUT_PORTS_END
 
 static INPUT_PORTS_START( mtetrisc )
 	// The basic N64 controls are unused in this game
-	PORT_START_TAG("P1")
-	PORT_START_TAG("P1_ANALOG_X")
-	PORT_START_TAG("P1_ANALOG_Y")
+	PORT_START("P1")
+	PORT_START("P1_ANALOG_X")
+	PORT_START("P1_ANALOG_Y")
 
-	PORT_START
+	PORT_START("IN0")
 		PORT_BIT( 0xffff0000, IP_ACTIVE_LOW, IPT_UNUSED )
 		PORT_BIT( 0x00008000, IP_ACTIVE_LOW, IPT_START2 )
 		PORT_BIT( 0x00004000, IP_ACTIVE_LOW, IPT_UNUSED )
@@ -319,9 +320,9 @@ static INPUT_PORTS_START( mtetrisc )
 		PORT_BIT( 0x00000002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
 		PORT_BIT( 0x00000001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 
-	PORT_START
+	PORT_START("IN1")
 		PORT_BIT( 0xffcc, IP_ACTIVE_LOW, IPT_UNUSED )
-		PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2)
+		PORT_SERVICE_NO_TOGGLE( 0x0020, IP_ACTIVE_LOW )
 		PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME("Service Button") PORT_CODE(KEYCODE_7)
 		PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_COIN2 )
 		PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
@@ -329,7 +330,7 @@ static INPUT_PORTS_START( mtetrisc )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( starsldr )
-	PORT_START_TAG("P1")
+	PORT_START("P1")
 		PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(1)			// Button A
 		PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_PLAYER(1)			// Button B
 		PORT_BIT( 0x2000, IP_ACTIVE_HIGH, IPT_UNUSED )
@@ -346,13 +347,13 @@ static INPUT_PORTS_START( starsldr )
 		PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_UNUSED )
 		PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_BUTTON4 ) PORT_PLAYER(1)			// Button D
 
-	PORT_START_TAG("P1_ANALOG_X")
+	PORT_START("P1_ANALOG_X")
 		PORT_BIT( 0xff, 0x80, IPT_AD_STICK_X ) PORT_SENSITIVITY(30) PORT_KEYDELTA(30) PORT_PLAYER(1)
 
-	PORT_START_TAG("P1_ANALOG_Y")
+	PORT_START("P1_ANALOG_Y")
 		PORT_BIT( 0xff, 0x80, IPT_AD_STICK_Y ) PORT_MINMAX(0xff,0x00) PORT_SENSITIVITY(30) PORT_KEYDELTA(30) PORT_PLAYER(1)
 
-	PORT_START
+	PORT_START("IN0")
 		PORT_DIPNAME( 0x80000000, 0x00000000, DEF_STR(Joystick) )	// DIPSW1 #8
 		PORT_DIPSETTING( 0x00000000, DEF_STR(Joystick) )
 		PORT_DIPSETTING( 0x80000000, "3D" )
@@ -399,16 +400,16 @@ static INPUT_PORTS_START( starsldr )
 		PORT_DIPSETTING( 0x00000000, "Hard2" )
 		PORT_BIT(0x0000ffff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("IN1")
 		PORT_BIT( 0xff00ffff, IP_ACTIVE_LOW, IPT_UNUSED )
-		PORT_BIT( 0x00200000, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2)
+		PORT_SERVICE_NO_TOGGLE( 0x00200000, IP_ACTIVE_LOW )
 		PORT_BIT( 0x00100000, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME("Service Button") PORT_CODE(KEYCODE_7)
 		PORT_BIT( 0x00080000, IP_ACTIVE_LOW, IPT_COIN2 )
 		PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_COIN1 )
 INPUT_PORTS_END
 
 /* ?? */
-static const struct mips3_config config =
+static const mips3_config config =
 {
 	16384,				/* code cache size */
 	8192,				/* data cache size */
@@ -417,31 +418,30 @@ static const struct mips3_config config =
 
 static INTERRUPT_GEN( n64_vblank )
 {
-	signal_rcp_interrupt(VI_INTERRUPT);
+	signal_rcp_interrupt(device->machine, VI_INTERRUPT);
 }
 
 static MACHINE_RESET( aleck64 )
 {
-	n64_machine_reset();
+	n64_machine_reset(machine);
 }
 
 static MACHINE_DRIVER_START( aleck64 )
 	/* basic machine hardware */
-	MDRV_CPU_ADD(R4600BE, 93750000)
+	MDRV_CPU_ADD("main", R4600BE, 93750000)
 	MDRV_CPU_CONFIG(config)
 	MDRV_CPU_PROGRAM_MAP(n64_map, 0)
-	MDRV_CPU_VBLANK_INT( n64_vblank, 1 )
+	MDRV_CPU_VBLANK_INT("main", n64_vblank)
 
-	MDRV_CPU_ADD(RSP, 62500000)
+	MDRV_CPU_ADD("rsp", RSP, 62500000)
 	MDRV_CPU_CONFIG(n64_rsp_config)
 	MDRV_CPU_PROGRAM_MAP(rsp_map, 0)
 
 	MDRV_MACHINE_RESET( aleck64 )
 
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_SIZE(640, 525)
 	MDRV_SCREEN_VISIBLE_AREA(0, 639, 0, 239)
@@ -452,15 +452,15 @@ static MACHINE_DRIVER_START( aleck64 )
 
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(DMADAC, 0)
+	MDRV_SOUND_ADD("dac1", DMADAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
-	MDRV_SOUND_ADD(DMADAC, 0)
+	MDRV_SOUND_ADD("dac2", DMADAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
 
 static DRIVER_INIT( aleck64 )
 {
-	UINT8 *rom = memory_region(REGION_USER2);
+	UINT8 *rom = memory_region(machine, "user2");
 
 	rom[0x67c] = 0;
 	rom[0x67d] = 0;
@@ -471,75 +471,156 @@ static DRIVER_INIT( aleck64 )
 #define PIF_BOOTROM ROM_LOAD( "pifdata.bin", 0x0000, 0x0800, CRC(5ec82be9) SHA1(9174eadc0f0ea2654c95fd941406ab46b9dc9bdd) )
 
 ROM_START( aleck64 )
-	ROM_REGION32_BE( 0x800, REGION_USER1, 0 )
+	ROM_REGION32_BE( 0x800, "user1", 0 )
 	ROM_LOAD( "pifdata.bin", 0x0000, 0x0800, CRC(5ec82be9) SHA1(9174eadc0f0ea2654c95fd941406ab46b9dc9bdd) )
 
-	ROM_REGION32_BE( 0x4000000, REGION_USER2, ROMREGION_ERASE00 )
-	ROM_REGION32_BE( 0x100000, REGION_USER3, ROMREGION_ERASE00 )
-	ROM_REGION32_BE( 0x80, REGION_USER4, ROMREGION_ERASE00 )
+	ROM_REGION32_BE( 0x4000000, "user2", ROMREGION_ERASE00 )
+	ROM_REGION32_BE( 0x100000, "user3", ROMREGION_ERASE00 )
+	ROM_REGION32_BE( 0x80, "user4", ROMREGION_ERASE00 )
 ROM_END
 
 ROM_START( 11beat )
-	ROM_REGION32_BE( 0x800, REGION_USER1, ROMREGION_ERASE00 )
+	ROM_REGION32_BE( 0x800, "user1", ROMREGION_ERASE00 )
 	PIF_BOOTROM
 
-	ROM_REGION32_BE( 0x4000000, REGION_USER2, 0 )
+	ROM_REGION32_BE( 0x4000000, "user2", 0 )
 	ROM_LOAD16_WORD_SWAP( "nus-zhaj.u3", 0x000000, 0x0800000,  CRC(95258ba2) SHA1(0299b8fb9a8b1b24428d0f340f6bf1cfaf99c672) )
 ROM_END
 
 ROM_START( mtetrisc )
-	ROM_REGION32_BE( 0x800, REGION_USER1, ROMREGION_ERASE00 )
+	ROM_REGION32_BE( 0x800, "user1", ROMREGION_ERASE00 )
 	PIF_BOOTROM
 
-	ROM_REGION32_BE( 0x4000000, REGION_USER2, 0 )
+	ROM_REGION32_BE( 0x4000000, "user2", 0 )
 	ROM_LOAD16_WORD_SWAP( "nus-zcaj.u4", 0x000000, 0x1000000,  CRC(ec4563fc) SHA1(4d5a30873a5850cf4cd1c0bdbe24e1934f163cd0) )
 
-	ROM_REGION32_BE( 0x100000, REGION_USER3, 0 )
+	ROM_REGION32_BE( 0x100000, "user3", 0 )
 	ROM_LOAD ( "tet-01m.u5", 0x000000, 0x100000,  CRC(f78f859b) SHA1(b07c85e0453869fe43792f42081f64a5327e58e6) )
 
-	ROM_REGION32_BE( 0x80, REGION_USER4, 0 )
+	ROM_REGION32_BE( 0x80, "user4", 0 )
 	ROM_LOAD ( "at24c01.u34", 0x000000, 0x80,  CRC(ba7e503f) SHA1(454aa4fdde7d8694d1affaf25cd750fa678686bb) )
 ROM_END
 
+
+/*
+Star Soldier Vanishing Earth for Aleck64
+Uses standard PCB '3D ROM PCB-2A' containing... (PCB Labels in brackets)
+1x Macronix MX23C9602CZ 96MBit Serial EEPROM @ U3 (NUS96M)
+1x CIC-NUS-5101 Protection Chip (CIC-NUS)
+1x BK4D-NUS (BU9850)
+*/
+
 ROM_START( starsldr )
-	ROM_REGION32_BE( 0x800, REGION_USER1, ROMREGION_ERASE00 )
+	ROM_REGION32_BE( 0x800, "user1", ROMREGION_ERASE00 )
 	PIF_BOOTROM
 
-	ROM_REGION32_BE( 0x4000000, REGION_USER2, 0 )
+	ROM_REGION32_BE( 0x4000000, "user2", 0 )
 	ROM_LOAD16_WORD_SWAP( "nus-zhbj-0.u3", 0x000000, 0xc00000,  CRC(a4edac93) SHA1(3794606c008fb69f5d16dcccece94d03da23bf8a) )
 
 ROM_END
 
 ROM_START( srmvs )
-	ROM_REGION32_BE( 0x800, REGION_USER1, ROMREGION_ERASE00 )
+	ROM_REGION32_BE( 0x800, "user1", ROMREGION_ERASE00 )
 	PIF_BOOTROM
 
-	ROM_REGION32_BE( 0x4000000, REGION_USER2, 0 )
+	ROM_REGION32_BE( 0x4000000, "user2", 0 )
 	ROM_LOAD16_WORD_SWAP( "nus-zsej-0.u2", 0x000000, 0x2000000,  CRC(44f40102) SHA1(a78de955f2fcd99dda14e782984368b320eb5415) )
 
 ROM_END
 
+
+/*
+Vivid Dolls for Aleck64
+Uses standard PCB '3D ROM PCB-2A' containing... (PCB Labels in brackets)
+1x CIC-NUS-5101 Protection Chip (U1 CIC-NUS)
+1x BK4D-NUS (U2 BU9850)
+1x Macronix MX23C6402CZ 64MBit Serial EEPROM (U3 NUS64M)
+*/
+
 ROM_START( vivdolls )
-	ROM_REGION32_BE( 0x800, REGION_USER1, ROMREGION_ERASE00 )
+	ROM_REGION32_BE( 0x800, "user1", ROMREGION_ERASE00 )
 	PIF_BOOTROM
 
-	ROM_REGION32_BE( 0x4000000, REGION_USER2, 0 )
+	ROM_REGION32_BE( 0x4000000, "user2", 0 )
 	ROM_LOAD16_WORD_SWAP( "nus-zsaj-0.u3", 0x000000, 0x800000,  CRC(f3220e29) SHA1(06d8b808cc19378b046803f4dc75c7d791b7767f) )
 
 ROM_END
 
+
+/*
+Tower And Shaft for Aleck64
+Uses custom PCB 'ALK-ROM01 ARUZE' containing... (PCB Labels in brackets)
+1x Macronix MX23C6402CZ 64MBit Serial EEPROM (U1)  Note - This ROM is mostly empty.
+1x Altera MAX EPM3128ATC144-10 CPLD/FPGA labelled AL01 (U2)
+1x Fujitsu MSP55LV128 128MBit SOP44 FlashROM labelled UA3012-ALL02-U3 (U3)
+1x BK4D-NUS BU9850 (U5)
+1x CIC-NUS-5101 Protection Chip (U6)
+1x 74F245 Logic Chip
+Some transistors
+*/
+
 ROM_START( twrshaft )
-	ROM_REGION32_BE( 0x800, REGION_USER1, ROMREGION_ERASE00 )
+	ROM_REGION32_BE( 0x800, "user1", ROMREGION_ERASE00 )
 	PIF_BOOTROM
 
-	ROM_REGION32_BE( 0x4000000, REGION_USER2, 0 )
+	ROM_REGION32_BE( 0x4000000, "user2", 0 )
 	ROM_LOAD16_WORD_SWAP( "ua3012--all02.u3", 0x000000, 0x1000000,  CRC(904a91a7) SHA1(7dfa3447d2c489c0448c4004dc12d3037c05a0f3) )
 
-	ROM_REGION32_BE( 0x800000, REGION_USER3, 0 )
+	ROM_REGION32_BE( 0x800000, "user3", 0 )
 	ROM_LOAD16_WORD_SWAP( "nus-zsij-0.u1", 0x000000, 0x800000,  CRC(2389576f) SHA1(dc22b2eab4d7a02cb918827a62e6c120b3a84e6c) )
+ROM_END
+
+
+ROM_START( hipai )
+	ROM_REGION32_BE( 0x800, "user1", ROMREGION_ERASE00 )
+	PIF_BOOTROM
+
+	ROM_REGION32_BE( 0x4000000, "user2", 0 )
+	ROM_LOAD16_WORD_SWAP( "ua2011-all02.u3", 0x0000000, 0x1000000,  CRC(eb4b96d0) SHA1(e909ea5b71b81087da07821c4f57244576363678) )
+	ROM_LOAD16_WORD_SWAP( "ua2011-alh02.u4", 0x1000000, 0x1000000,  CRC(b8e35ddf) SHA1(7c3e59f6520dc3f0aa592e682fa82e30ffd1f4d0) )
+
+	ROM_REGION32_BE( 0x800000, "user3", 0 )
+	ROM_LOAD16_WORD_SWAP( "nus-nsij-0.u1", 0x000000, 0x800000,  CRC(94cf9f8d) SHA1(cd624d1f5de2be3bec3ece06556a2e39bef66d77) )
+ROM_END
+
+
+ROM_START( doncdoon )
+	ROM_REGION32_BE( 0x800, "user1", ROMREGION_ERASE00 )
+	PIF_BOOTROM
+
+	ROM_REGION32_BE( 0x4000000, "user2", 0 )
+	ROM_LOAD16_WORD_SWAP( "ua3088-all01.u3", 0x0000000, 0x1000000,  CRC(00db4dbc) SHA1(824fdce01fffdfcbcc9b1fbda4ab389a10b2b418) )
+	ROM_LOAD16_WORD_SWAP( "ua3088-alh04.u4", 0x1000000, 0x1000000,  CRC(c96bc7c0) SHA1(2b6ca1a769dee74e112c2b287dacd0bf46dda091) )
+
+	ROM_REGION32_BE( 0x800000, "user3", 0 )
+	ROM_LOAD16_WORD_SWAP( "nus-zsij-0.u1", 0x000000, 0x800000,   CRC(2389576f) SHA1(dc22b2eab4d7a02cb918827a62e6c120b3a84e6c) ) // same as tower & shaft
+ROM_END
+
+ROM_START( kurufev )
+	ROM_REGION32_BE( 0x800, "user1", ROMREGION_ERASE00 )
+	PIF_BOOTROM
+
+	ROM_REGION32_BE( 0x4000000, "user2", 0 )
+	ROM_LOAD16_WORD_SWAP( "ua3003-all01.u3", 0x0000000, 0x1000000,  CRC(f362fa82) SHA1(4f41ee23edc18110be1218ba333d1c58376ab175) )
+	ROM_LOAD16_WORD_SWAP( "ua3003-alh01.u4", 0x1000000, 0x1000000,  CRC(47c56387) SHA1(c8cc6c0a456b593aef711d0a75b2342ba2f8203f) )
+
+	ROM_REGION32_BE( 0x800000, "user3", 0 )
+	ROM_LOAD16_WORD_SWAP( "nus-zsij-0.u1", 0x000000, 0x800000, CRC(547d8122) SHA1(347f0785767265acb0f0c21646e06cbe6f561821) )
+ROM_END
+
+
+ROM_START( mayjin3 )
+	ROM_REGION32_BE( 0x800, "user1", ROMREGION_ERASE00 )
+	PIF_BOOTROM
+
+	ROM_REGION32_BE( 0x4000000, "user2", 0 )
+	ROM_LOAD16_WORD_SWAP( "nus-zscj.u3", 0x000000, 0x800000,  CRC(8b36eb91) SHA1(179745625c16c6813d5f8d29bfd7628783d55806) )
 
 ROM_END
 
+
+
+
 // BIOS
 GAME( 1998, aleck64,        0,  aleck64, aleck64,  aleck64, ROT0, "Nintendo/Seta", "Aleck64 PIF BIOS", GAME_IS_BIOS_ROOT)
 
@@ -550,3 +631,8 @@ GAME( 1998, starsldr, aleck64,  aleck64, starsldr, aleck64, ROT0, "Hudson/Seta",
 GAME( 1998, vivdolls, aleck64,  aleck64, aleck64,  aleck64, ROT0, "Visco", "Vivid Dolls", GAME_IMPERFECT_GRAPHICS )
 GAME( 1999, srmvs,    aleck64,  aleck64, aleck64,  aleck64, ROT0, "Seta", "Super Real Mahjong VS", GAME_NOT_WORKING|GAME_NO_SOUND )
 GAME( 2003, twrshaft, aleck64,  aleck64, aleck64,  aleck64, ROT0, "Aruze", "Tower & Shaft", GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 200?, hipai,    aleck64,  aleck64, aleck64,  aleck64, ROT0, "Aruze?", "Hi Pai Paradise", GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 200?, doncdoon, aleck64,  aleck64, aleck64,  aleck64, ROT0, "Aruze?", "Donchan no Hanabi de Doon", GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 200?, kurufev,  aleck64,  aleck64, aleck64,  aleck64, ROT0, "Aruze?", "Kurukuru Fever", GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 200?, mayjin3,  aleck64,  aleck64, aleck64,  aleck64, ROT0, "Seta?", "Mayjinsen 3", GAME_NOT_WORKING|GAME_NO_SOUND )
+
