@@ -48,8 +48,10 @@
 ***************************************************************************/
 
 #include "driver.h"
+#include "cpu/m68000/m68000.h"
 #include "sound/custom.h"
 #include "includes/amiga.h"
+#include "machine/6526cia.h"
 
 
 
@@ -71,21 +73,7 @@ static UINT8 coin_counter[2];
 
 static WRITE16_HANDLER( arcadia_multibios_change_game )
 {
-	memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0x800000, 0x97ffff, 0, 0, (data == 0) ? MRA16_BANK2 : MRA16_NOP);
-}
-
-
-
-/*************************************
- *
- *  Special port handlers
- *
- *************************************/
-
-static CUSTOM_INPUT( arcadia_coin_counter_r )
-{
-	/* return coin counter values */
-	return *(UINT8 *)param & 3;
+	memory_install_read16_handler(space, 0x800000, 0x97ffff, 0, 0, (data == 0) ? SMH_BANK2 : SMH_NOP);
 }
 
 
@@ -105,24 +93,24 @@ static CUSTOM_INPUT( arcadia_coin_counter_r )
  *
  *************************************/
 
-static UINT8 arcadia_cia_0_porta_r(void)
+static UINT8 arcadia_cia_0_porta_r(const device_config *device)
 {
-	return readinputportbytag("CIA0PORTA");
+	return input_port_read(device->machine, "CIA0PORTA");
 }
 
-static void arcadia_cia_0_porta_w(UINT8 data)
+static void arcadia_cia_0_porta_w(const device_config *device, UINT8 data)
 {
 	/* switch banks as appropriate */
-	memory_set_bank(1, data & 1);
+	memory_set_bank(device->machine, 1, data & 1);
 
 	/* swap the write handlers between ROM and bank 1 based on the bit */
 	if ((data & 1) == 0)
 		/* overlay disabled, map RAM on 0x000000 */
-		memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0x000000, 0x07ffff, 0, 0, MWA16_BANK1);
+		memory_install_write16_handler(cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x000000, 0x07ffff, 0, 0, SMH_BANK1);
 
 	else
 		/* overlay enabled, map Amiga system ROM on 0x000000 */
-		memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0x000000, 0x07ffff, 0, 0, MWA16_UNMAP);
+		memory_install_write16_handler(cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x000000, 0x07ffff, 0, 0, SMH_UNMAP);
 
 	/* bit 2 = Power Led on Amiga */
 	set_led_status(0, (data & 2) ? 0 : 1);
@@ -145,12 +133,12 @@ static void arcadia_cia_0_porta_w(UINT8 data)
  *
  *************************************/
 
-static UINT8 arcadia_cia_0_portb_r(void)
+static UINT8 arcadia_cia_0_portb_r(const device_config *device)
 {
-	return readinputportbytag("CIA0PORTB");
+	return input_port_read(device->machine, "CIA0PORTB");
 }
 
-static void arcadia_cia_0_portb_w(UINT8 data)
+static void arcadia_cia_0_portb_w(const device_config *device, UINT8 data)
 {
 	/* writing a 0 in the low bit clears one of the coins */
 	if ((data & 1) == 0)
@@ -170,7 +158,14 @@ static void arcadia_cia_0_portb_w(UINT8 data)
  *
  *************************************/
 
-static void coin_changed_callback(void *param, UINT32 oldval, UINT32 newval)
+static CUSTOM_INPUT( coin_counter_r )
+{
+	/* return coin counter values */
+	return *(UINT8 *)param & 3;
+}
+
+
+static INPUT_CHANGED( coin_changed_callback )
 {
 	UINT8 *counter = param;
 
@@ -180,7 +175,7 @@ static void coin_changed_callback(void *param, UINT32 oldval, UINT32 newval)
 }
 
 
-static void arcadia_reset_coins(void)
+static void arcadia_reset_coins(running_machine *machine)
 {
 	/* reset coin counters */
 	coin_counter[0] = coin_counter[1] = 0;
@@ -195,18 +190,18 @@ static void arcadia_reset_coins(void)
  *************************************/
 
 static ADDRESS_MAP_START( amiga_map, ADDRESS_SPACE_PROGRAM, 16 )
-	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) )
+	ADDRESS_MAP_UNMAP_HIGH
 	AM_RANGE(0x000000, 0x07ffff) AM_RAMBANK(1) AM_BASE(&amiga_chip_ram) AM_SIZE(&amiga_chip_ram_size)
 	AM_RANGE(0xbfd000, 0xbfefff) AM_READWRITE(amiga_cia_r, amiga_cia_w)
 	AM_RANGE(0xc00000, 0xdfffff) AM_READWRITE(amiga_custom_r, amiga_custom_w) AM_BASE(&amiga_custom_regs)
 	AM_RANGE(0xe80000, 0xe8ffff) AM_READWRITE(amiga_autoconfig_r, amiga_autoconfig_w)
-	AM_RANGE(0xf80000, 0xffffff) AM_ROM AM_REGION(REGION_USER1, 0)		/* Kickstart BIOS */
+	AM_RANGE(0xf80000, 0xffffff) AM_ROM AM_REGION("user1", 0)		/* Kickstart BIOS */
 
-	AM_RANGE(0x800000, 0x97ffff) AM_ROMBANK(2) AM_REGION(REGION_USER3, 0)
-	AM_RANGE(0x980000, 0x9fbfff) AM_ROM AM_REGION(REGION_USER2, 0)
+	AM_RANGE(0x800000, 0x97ffff) AM_ROMBANK(2) AM_REGION("user3", 0)
+	AM_RANGE(0x980000, 0x9fbfff) AM_ROM AM_REGION("user2", 0)
 	AM_RANGE(0x9fc000, 0x9ffffd) AM_RAM AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)
 	AM_RANGE(0x9ffffe, 0x9fffff) AM_WRITE(arcadia_multibios_change_game)
-	AM_RANGE(0xf00000, 0xf7ffff) AM_ROM AM_REGION(REGION_USER2, 0)
+	AM_RANGE(0xf00000, 0xf7ffff) AM_ROM AM_REGION("user2", 0)
 ADDRESS_MAP_END
 
 
@@ -218,51 +213,51 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( arcadia )
-	PORT_START_TAG("CIA0PORTA")
+	PORT_START("CIA0PORTA")
 	PORT_BIT( 0x3f, IP_ACTIVE_LOW, IPT_SPECIAL )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
 
-	PORT_START_TAG("CIA0PORTB")
+	PORT_START("CIA0PORTB")
 	PORT_DIPNAME( 0x01, 0x01, "DSW1 1" )
 	PORT_DIPSETTING(    0x01, "Reset" )
 	PORT_DIPSETTING(    0x00, "Set" )
 	PORT_SERVICE_NO_TOGGLE( 0x02, IP_ACTIVE_LOW )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT( 0x30, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(arcadia_coin_counter_r, &coin_counter[0])
-	PORT_BIT( 0xc0, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(arcadia_coin_counter_r, &coin_counter[1])
+	PORT_BIT( 0x30, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(coin_counter_r, &coin_counter[0])
+	PORT_BIT( 0xc0, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(coin_counter_r, &coin_counter[1])
 
-	PORT_START_TAG("JOY0DAT")
+	PORT_START("JOY0DAT")
 	PORT_BIT( 0x0303, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(amiga_joystick_convert, "P1JOY")
 	PORT_BIT( 0xfcfc, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START_TAG("JOY1DAT")
+	PORT_START("JOY1DAT")
 	PORT_BIT( 0x0303, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(amiga_joystick_convert, "P2JOY")
 	PORT_BIT( 0xfcfc, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START_TAG("POTGO")
+	PORT_START("POTGO")
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_BUTTON2 )
 	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
 	PORT_BIT( 0xaaff, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START_TAG("P1JOY")
+	PORT_START("P1JOY")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_PLAYER(1)
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(1)
 
-	PORT_START_TAG("P2JOY")
+	PORT_START("P2JOY")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN ) PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_PLAYER(2)
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(2)
 
-	PORT_START_TAG("COINS")
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
-	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 )
+	PORT_START("COINS")
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin_changed_callback, &coin_counter[0])
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_CHANGED(coin_changed_callback, &coin_counter[1])
 INPUT_PORTS_END
 
 
@@ -273,7 +268,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static const struct CustomSound_interface amiga_custom_interface =
+static const custom_sound_interface amiga_custom_interface =
 {
 	amiga_sh_start
 };
@@ -286,21 +281,41 @@ static const struct CustomSound_interface amiga_custom_interface =
  *
  *************************************/
 
+static const cia6526_interface cia_0_intf =
+{
+	amiga_cia_0_irq,										/* irq_func */
+	0,														/* tod_clock */
+	{
+		{ arcadia_cia_0_porta_r, arcadia_cia_0_porta_w },	/* port A */
+		{ arcadia_cia_0_portb_r, arcadia_cia_0_portb_w }	/* port B */
+	}
+};
+
+static const cia6526_interface cia_1_intf =
+{
+	amiga_cia_1_irq,										/* irq_func */
+	0,														/* tod_clock */
+	{
+		{ NULL, NULL },										/* port A */
+		{ NULL, NULL }										/* port B */
+	}
+};
+
 static MACHINE_DRIVER_START( arcadia )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000, AMIGA_68000_NTSC_CLOCK)
+	MDRV_CPU_ADD("main", M68000, AMIGA_68000_NTSC_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(amiga_map,0)
-	MDRV_CPU_VBLANK_INT(amiga_scanline_callback, 262)
-
-	MDRV_SCREEN_REFRESH_RATE(59.997)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 
 	MDRV_MACHINE_RESET(amiga)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_UPDATE_BEFORE_VBLANK)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
+
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(59.997)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(512*2, 262)
 	MDRV_SCREEN_VISIBLE_AREA((129-8)*2, (449+8-1)*2, 44-8, 244+8-1)
@@ -308,17 +323,21 @@ static MACHINE_DRIVER_START( arcadia )
 	MDRV_PALETTE_INIT(amiga)
 
 	MDRV_VIDEO_START(amiga)
-	MDRV_VIDEO_UPDATE(generic_bitmapped)
+	MDRV_VIDEO_UPDATE(amiga)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(CUSTOM, 3579545)
+	MDRV_SOUND_ADD("amiga", CUSTOM, 3579545)
 	MDRV_SOUND_CONFIG(amiga_custom_interface)
 	MDRV_SOUND_ROUTE(0, "left", 0.50)
 	MDRV_SOUND_ROUTE(1, "right", 0.50)
 	MDRV_SOUND_ROUTE(2, "right", 0.50)
 	MDRV_SOUND_ROUTE(3, "left", 0.50)
+
+	/* cia */
+	MDRV_CIA8520_ADD("cia_0", AMIGA_68000_NTSC_CLOCK / 10, cia_0_intf)
+	MDRV_CIA8520_ADD("cia_1", AMIGA_68000_NTSC_CLOCK / 10, cia_1_intf)
 MACHINE_DRIVER_END
 
 
@@ -332,11 +351,11 @@ MACHINE_DRIVER_END
 #define ROM_LOAD16_BYTE_BIOS(bios,name,offset,length,hash)     ROMX_LOAD(name, offset, length, hash, ROM_SKIP(1) | ROM_BIOS(bios+1))
 
 #define ARCADIA_BIOS \
-	ROM_REGION16_BE(0x80000, REGION_USER1, 0 ) \
+	ROM_REGION16_BE(0x80000, "user1", 0 ) \
 	ROM_LOAD16_WORD( "kick12.rom", 0x000000, 0x040000, CRC(a6ce1636) SHA1(11f9e62cf299f72184835b7b2a70a16333fc0d88) ) \
-	ROM_COPY( REGION_USER1, 0x000000, 0x040000, 0x040000 ) \
+	ROM_COPY( "user1", 0x000000, 0x040000, 0x040000 ) \
 	\
-	ROM_REGION16_BE( 0x80000, REGION_USER2, 0 ) \
+	ROM_REGION16_BE( 0x80000, "user2", 0 ) \
 	ROM_SYSTEM_BIOS(0, "onep300", "OnePlay 3.00") \
 	ROM_LOAD16_BYTE_BIOS( 0, "scpav3_0.1h", 0x000000, 0x10000, CRC(2d8e1a06) SHA1(be187f34624aeda110017c4a09242f7c00ef56a4) ) \
 	ROM_LOAD16_BYTE_BIOS( 0, "scpav3_0.1l", 0x000001, 0x10000, CRC(e4f38fab) SHA1(01c2eb5965070893be6734eb1372576727716476) ) \
@@ -356,7 +375,7 @@ MACHINE_DRIVER_END
 ROM_START( ar_bios )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE(0x180000, REGION_USER3, ROMREGION_ERASEFF)
+	ROM_REGION16_BE(0x180000, "user3", ROMREGION_ERASEFF)
 ROM_END
 
 
@@ -370,7 +389,7 @@ ROM_END
 ROM_START( ar_airh )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE( 0x180000, REGION_USER3, ROMREGION_ERASEFF )
+	ROM_REGION16_BE( 0x180000, "user3", ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "airh_1h.bin", 0x00000, 0x10000, CRC(290e8e9e) SHA1(9215e36f02adf4064934aab99accefcb17ea6d3f) )
 	ROM_LOAD16_BYTE( "airh_1l.bin", 0x00001, 0x10000, CRC(155452b6) SHA1(aeaa67ea9cc543c9a43094545450159e4784fb5c) )
 ROM_END
@@ -380,7 +399,7 @@ ROM_END
 ROM_START( ar_bowl )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE( 0x180000, REGION_USER3, ROMREGION_ERASEFF )
+	ROM_REGION16_BE( 0x180000, "user3", ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "bowl_1h.bin", 0x00000, 0x10000, CRC(c0c20422) SHA1(3576df08e7a4cdadaf9dea5da0770efe5f461b07) )
 	ROM_LOAD16_BYTE( "bowl_1l.bin", 0x00001, 0x10000, CRC(1c7fe75c) SHA1(b1830b91b53ec24d4b072898acac02552e2eae97) )
 	ROM_LOAD16_BYTE( "bowl_2h.bin", 0x20000, 0x10000, CRC(a1e497d8) SHA1(4b4885c6937b7cfb24921e84a80d6d4f56844a73) )
@@ -394,7 +413,7 @@ ROM_END
 ROM_START( ar_dart )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE( 0x180000, REGION_USER3, ROMREGION_ERASEFF )
+	ROM_REGION16_BE( 0x180000, "user3", ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "dart_1h.bin", 0x00000, 0x10000, CRC(4d6a33e2) SHA1(1a227b5b0b4aca40d46af62e44deebca60582363) )
 	ROM_LOAD16_BYTE( "dart_1l.bin", 0x00001, 0x10000, CRC(3fa66973) SHA1(66b59870f8ed1bb5b46b2887d99a6a71ff0514ba) )
 	ROM_LOAD16_BYTE( "dart_2h.bin", 0x20000, 0x10000, CRC(3a30426a) SHA1(bf9226d2bfd1fb2d70e55e30aa3dde953baf5792) )
@@ -427,7 +446,7 @@ ROM_END
 ROM_START( ar_fast )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE( 0x180000, REGION_USER3, ROMREGION_ERASEFF )
+	ROM_REGION16_BE( 0x180000, "user3", ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "fastv28.1h", 0x000000, 0x10000, CRC(091e4533) SHA1(61a16deecd32b386d62aab95e8d4a61bddcd8af4) )
 	ROM_LOAD16_BYTE( "fastv28.1l", 0x000001, 0x10000, CRC(8f7685c1) SHA1(b379c1a47618401cfbfcc7bd2d13ae51f5e73e46) )
 	ROM_LOAD16_BYTE( "fastv28.2h", 0x020000, 0x10000, CRC(3a3dd931) SHA1(7be3316e2acf6b14b29ef2e36d8f76999d5d4e94) )
@@ -445,7 +464,7 @@ ROM_START( ar_fast )
 	ROM_LOAD16_BYTE( "fastv28.8h", 0x0e0000, 0x10000, CRC(3650aaf0) SHA1(cc37aa94360159f45076eafaae8140a661bd52f6) )
 	ROM_LOAD16_BYTE( "fastv28.8l", 0x0e0001, 0x10000, CRC(82603f68) SHA1(8affe73e97b966b8e63bff2c7914fb5ead7b60ff) )
 
-	ROM_REGION( 0x0200, REGION_PLDS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0200, "plds", ROMREGION_DISPOSE )
 	ROM_LOAD( "pal16l8-sec-scpa.bin", 0x0000, 0x0104, NO_DUMP ) /* PAL is read protected */
 ROM_END
 
@@ -454,7 +473,7 @@ ROM_END
 ROM_START( ar_ldrb )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE( 0x180000, REGION_USER3, ROMREGION_ERASEFF )
+	ROM_REGION16_BE( 0x180000, "user3", ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "lbg2401h", 0x00000, 0x10000, CRC(fe1287e9) SHA1(34088416d970614b31b25e982ef40fd950080b3e) )
 	ROM_LOAD16_BYTE( "lbg2401l", 0x00001, 0x10000, CRC(7c7bb9ee) SHA1(5c76445732ab139db82fe21c16f49e2609bb03aa) )
 	ROM_LOAD16_BYTE( "lbg2402h", 0x20000, 0x10000, CRC(64e5fbae) SHA1(0dde0d05b05f232aac9ad44398cedd8c7627f146) )
@@ -478,7 +497,7 @@ ROM_END
 ROM_START( ar_ldrba )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE( 0x180000, REGION_USER3, ROMREGION_ERASEFF )
+	ROM_REGION16_BE( 0x180000, "user3", ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "ldrb_1h.bin", 0x00000, 0x10000, CRC(0236511c) SHA1(22b2ee076ed57ba38413c16a52510383d8488e25) )
 	ROM_LOAD16_BYTE( "ldrb_1l.bin", 0x00001, 0x10000, CRC(786d34b9) SHA1(5fd6ef94f65c6fd503d3682154b576d6509a3aa9) )
 	ROM_LOAD16_BYTE( "ldrb_2h.bin", 0x20000, 0x10000, CRC(64e5fbae) SHA1(0dde0d05b05f232aac9ad44398cedd8c7627f146) )
@@ -502,7 +521,7 @@ ROM_END
 ROM_START( ar_ninj )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE(0x200000, REGION_USER3, 0)
+	ROM_REGION16_BE(0x200000, "user3", 0)
 	ROM_LOAD16_BYTE( "ninj_1h.bin", 0x00000, 0x10000, CRC(53b07b4d) SHA1(4852005adf60fe63f2da880dd32740d18fd31169) )
 	ROM_LOAD16_BYTE( "ninj_1l.bin", 0x00001, 0x10000, CRC(3337a6c1) SHA1(be9719f0cd5872b51f4c6d32fcac2638c0dedaf4) )
 	ROM_LOAD16_BYTE( "ninj_2h.bin", 0x20000, 0x10000, CRC(e28a5fa8) SHA1(150e26aea24706b72d2e6612280d5dddc527061b) )
@@ -522,7 +541,7 @@ ROM_END
 ROM_START( ar_rdwr )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE(0x200000, REGION_USER3, 0)
+	ROM_REGION16_BE(0x200000, "user3", 0)
 	ROM_LOAD16_BYTE( "rdwr_1h.bin", 0x00000, 0x10000, CRC(f52cb704) SHA1(cce8c7484ae8c3a3d14b2e79a981780a277c9b1c) )
 	ROM_LOAD16_BYTE( "rdwr_1l.bin", 0x00001, 0x10000, CRC(fde0de6d) SHA1(7f62ce854a040775548c5ba3b05e6a4dcb0d7cfb) )
 	ROM_LOAD16_BYTE( "rdwr_2h.bin", 0x20000, 0x10000, CRC(8f3c1a2c) SHA1(e473e55457c04ebd597375e9936aeb0473507ed7) )
@@ -538,7 +557,7 @@ ROM_END
 ROM_START( ar_sdwr )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE( 0x180000, REGION_USER3, ROMREGION_ERASEFF )
+	ROM_REGION16_BE( 0x180000, "user3", ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "sdwr_1h.bin", 0x00000, 0x10000, CRC(aef3eea8) SHA1(4bf7619f52395fcbde3c8f7af3fd7da4af03c673) )
 	ROM_LOAD16_BYTE( "sdwr_1l.bin", 0x00001, 0x10000, CRC(daed4add) SHA1(a9404a87f1958d7ab829fbb48855d2deb64c5aec) )
 	ROM_LOAD16_BYTE( "sdwr_2h.bin", 0x20000, 0x10000, CRC(d67ba564) SHA1(2afba72a77806e3925c9ca1e13c16c442a6cfc3a) )
@@ -558,7 +577,7 @@ ROM_END
 ROM_START( ar_socc )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE( 0x180000, REGION_USER3, ROMREGION_ERASEFF )
+	ROM_REGION16_BE( 0x180000, "user3", ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "socc30.1hi", 0x00000, 0x10000, CRC(b4df41cf) SHA1(681cecef390f82be420cd9f4d32afddace3da3c8) )
 	ROM_LOAD16_BYTE( "socc30.1lo", 0x00001, 0x10000, CRC(28b5e119) SHA1(3fff3252b855e6ca1aceff89ec0c61688c954d88) )
 	ROM_LOAD16_BYTE( "socc30.2hi", 0x20000, 0x10000, CRC(b3c14026) SHA1(be4e05cbf5b14a1dc77eff70bb44c8cdae57e59a) )
@@ -578,7 +597,7 @@ ROM_END
 ROM_START( ar_spot )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE( 0x180000, REGION_USER3, ROMREGION_ERASEFF )
+	ROM_REGION16_BE( 0x180000, "user3", ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "spotv2.1h", 0x00000, 0x10000, CRC(a8440838) SHA1(8d64ddb603754c85aad47bd079d0a7d80d57b36c) )
 	ROM_LOAD16_BYTE( "spotv2.1l", 0x00001, 0x10000, CRC(2abd2835) SHA1(b419da47c6390334ed8af56bc21430e5b43d6d58) )
 	ROM_LOAD16_BYTE( "spotv2.2h", 0x20000, 0x10000, CRC(f4c95f77) SHA1(46c70755e3c6d06bec4b1bd164a586292a59249d) )
@@ -602,7 +621,7 @@ ROM_END
 ROM_START( ar_sprg )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE( 0x180000, REGION_USER3, ROMREGION_ERASEFF )
+	ROM_REGION16_BE( 0x180000, "user3", ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "sprg_1h.bin", 0x00000, 0x10000, CRC(90b45dc5) SHA1(7cf1fc27e95bf207ed94cc5c20cf0c0ae7799d83) )
 	ROM_LOAD16_BYTE( "sprg_1l.bin", 0x00001, 0x10000, CRC(e5ce68e9) SHA1(dfda2e0bffc499a497865bc214450653880eccf2) )
 	ROM_LOAD16_BYTE( "sprg_2h.bin", 0x20000, 0x10000, CRC(02ef780f) SHA1(d21d6e8a379a2b38de7f3ec0540f67dd6425cbc9) )
@@ -618,7 +637,7 @@ ROM_END
 ROM_START( ar_xeon )
 	ARCADIA_BIOS
 
-	ROM_REGION16_BE( 0x180000, REGION_USER3, ROMREGION_ERASEFF )
+	ROM_REGION16_BE( 0x180000, "user3", ROMREGION_ERASEFF )
 	ROM_LOAD16_BYTE( "xeon_1h.bin", 0x00000, 0x10000, CRC(ca422811) SHA1(fa6f82e1d91b48d58b61f916d5b04dc1a13774fb) )
 	ROM_LOAD16_BYTE( "xeon_1l.bin", 0x00001, 0x10000, CRC(97edf967) SHA1(57fca524e01ba21f7420472f14aaf3fa63a326fa) )
 	ROM_LOAD16_BYTE( "xeon_2h.bin", 0x20000, 0x10000, CRC(8078c10e) SHA1(599995374b23da7187556e2f4f285b60d818f885) )
@@ -637,9 +656,9 @@ ROM_END
  *
  *************************************/
 
-INLINE void generic_decode(int region, int bit7, int bit6, int bit5, int bit4, int bit3, int bit2, int bit1, int bit0)
+INLINE void generic_decode(running_machine *machine, const char *tag, int bit7, int bit6, int bit5, int bit4, int bit3, int bit2, int bit1, int bit0)
 {
-	UINT16 *rom = (UINT16 *)memory_region(region);
+	UINT16 *rom = (UINT16 *)memory_region(machine, tag);
 	int i;
 
 	/* only the low byte of ROMs are encrypted in these games */
@@ -655,15 +674,11 @@ INLINE void generic_decode(int region, int bit7, int bit6, int bit5, int bit4, i
  *
  *************************************/
 
-static void arcadia_init(void)
+static void arcadia_init(running_machine *machine)
 {
 	static const amiga_machine_interface arcadia_intf =
 	{
 		ANGUS_CHIP_RAM_MASK,
-		arcadia_cia_0_porta_r, arcadia_cia_0_portb_r,
-		arcadia_cia_0_porta_w, arcadia_cia_0_portb_w,
-		NULL, NULL,
-		NULL, NULL,
 		NULL, NULL, NULL,
 		NULL, NULL, NULL,
 		NULL,  arcadia_reset_coins,
@@ -673,20 +688,16 @@ static void arcadia_init(void)
 	UINT16 *biosrom;
 
 	/* configure our Amiga setup */
-	amiga_machine_config(&arcadia_intf);
+	amiga_machine_config(machine, &arcadia_intf);
 
 	/* set up memory */
-	memory_configure_bank(1, 0, 1, amiga_chip_ram, 0);
-	memory_configure_bank(1, 1, 1, memory_region(REGION_USER1), 0);
+	memory_configure_bank(machine, 1, 0, 1, amiga_chip_ram, 0);
+	memory_configure_bank(machine, 1, 1, 1, memory_region(machine, "user1"), 0);
 
 	/* OnePlay bios is encrypted, TenPlay is not */
-	biosrom = (UINT16 *)memory_region(REGION_USER2);
+	biosrom = (UINT16 *)memory_region(machine, "user2");
 	if (biosrom[0] != 0x4afc)
-		generic_decode(REGION_USER2, 6, 1, 0, 2, 3, 4, 5, 7);
-
-	/* request notifications when the coins change */
-	input_port_set_changed_callback(port_tag_to_index("COINS"), 0x01, coin_changed_callback, &coin_counter[0]);
-	input_port_set_changed_callback(port_tag_to_index("COINS"), 0x02, coin_changed_callback, &coin_counter[1]);
+		generic_decode(machine, "user2", 6, 1, 0, 2, 3, 4, 5, 7);
 }
 
 
@@ -697,17 +708,17 @@ static void arcadia_init(void)
  *
  *************************************/
 
-static DRIVER_INIT( none )  {                                                arcadia_init(); }
-static DRIVER_INIT( airh )  { generic_decode(REGION_USER3, 5, 0, 2, 4, 7, 6, 1, 3); arcadia_init(); }
-static DRIVER_INIT( bowl )  { generic_decode(REGION_USER3, 7, 6, 0, 1, 2, 3, 4, 5); arcadia_init(); }
-static DRIVER_INIT( dart )  { generic_decode(REGION_USER3, 4, 0, 7, 6, 3, 1, 2, 5); arcadia_init(); }
-static DRIVER_INIT( ldrba ) { generic_decode(REGION_USER3, 2, 3, 4, 1, 0, 7, 5, 6); arcadia_init(); }
-static DRIVER_INIT( ninj )  { generic_decode(REGION_USER3, 1, 6, 5, 7, 4, 2, 0, 3); arcadia_init(); }
-static DRIVER_INIT( rdwr )  { generic_decode(REGION_USER3, 3, 1, 6, 4, 0, 5, 2, 7); arcadia_init(); }
-static DRIVER_INIT( sdwr )  { generic_decode(REGION_USER3, 6, 3, 4, 5, 2, 1, 0, 7); arcadia_init(); }
-static DRIVER_INIT( socc )  { generic_decode(REGION_USER3, 0, 7, 1, 6, 5, 4, 3, 2); arcadia_init(); }
-static DRIVER_INIT( sprg )  { generic_decode(REGION_USER3, 4, 7, 3, 0, 6, 5, 2, 1); arcadia_init(); }
-static DRIVER_INIT( xeon )  { generic_decode(REGION_USER3, 3, 1, 2, 4, 0, 5, 6, 7); arcadia_init(); }
+static DRIVER_INIT( none )  {                                                arcadia_init(machine); }
+static DRIVER_INIT( airh )  { generic_decode(machine, "user3", 5, 0, 2, 4, 7, 6, 1, 3); arcadia_init(machine); }
+static DRIVER_INIT( bowl )  { generic_decode(machine, "user3", 7, 6, 0, 1, 2, 3, 4, 5); arcadia_init(machine); }
+static DRIVER_INIT( dart )  { generic_decode(machine, "user3", 4, 0, 7, 6, 3, 1, 2, 5); arcadia_init(machine); }
+static DRIVER_INIT( ldrba ) { generic_decode(machine, "user3", 2, 3, 4, 1, 0, 7, 5, 6); arcadia_init(machine); }
+static DRIVER_INIT( ninj )  { generic_decode(machine, "user3", 1, 6, 5, 7, 4, 2, 0, 3); arcadia_init(machine); }
+static DRIVER_INIT( rdwr )  { generic_decode(machine, "user3", 3, 1, 6, 4, 0, 5, 2, 7); arcadia_init(machine); }
+static DRIVER_INIT( sdwr )  { generic_decode(machine, "user3", 6, 3, 4, 5, 2, 1, 0, 7); arcadia_init(machine); }
+static DRIVER_INIT( socc )  { generic_decode(machine, "user3", 0, 7, 1, 6, 5, 4, 3, 2); arcadia_init(machine); }
+static DRIVER_INIT( sprg )  { generic_decode(machine, "user3", 4, 7, 3, 0, 6, 5, 2, 1); arcadia_init(machine); }
+static DRIVER_INIT( xeon )  { generic_decode(machine, "user3", 3, 1, 2, 4, 0, 5, 6, 7); arcadia_init(machine); }
 
 
 
