@@ -103,6 +103,8 @@
 ***************************************************************************/
 
 #include "driver.h"
+#include "cpu/m6502/m6502.h"
+#include "deprecat.h"
 #include "atarifb.h"
 #include "sound/discrete.h"
 
@@ -148,19 +150,19 @@ static PALETTE_INIT( atarifb )
  *************************************/
 
 static ADDRESS_MAP_START( atarifb_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(15) )
+	ADDRESS_MAP_GLOBAL_MASK(0x7fff)
 	AM_RANGE(0x0000, 0x01ff) AM_RAM
-	AM_RANGE(0x0200, 0x025f) AM_READWRITE(MRA8_RAM, atarifb_alpha1_videoram_w) AM_BASE(&atarifb_alphap1_videoram)
+	AM_RANGE(0x0200, 0x025f) AM_RAM_WRITE(atarifb_alpha1_videoram_w) AM_BASE(&atarifb_alphap1_videoram)
 	AM_RANGE(0x0260, 0x039f) AM_RAM
-	AM_RANGE(0x03a0, 0x03ff) AM_READWRITE(MRA8_RAM, atarifb_alpha2_videoram_w) AM_BASE(&atarifb_alphap2_videoram)
-	AM_RANGE(0x1000, 0x13bf) AM_READWRITE(MRA8_RAM, atarifb_field_videoram_w) AM_BASE(&atarifb_field_videoram)
+	AM_RANGE(0x03a0, 0x03ff) AM_RAM_WRITE(atarifb_alpha2_videoram_w) AM_BASE(&atarifb_alphap2_videoram)
+	AM_RANGE(0x1000, 0x13bf) AM_RAM_WRITE(atarifb_field_videoram_w) AM_BASE(&atarifb_field_videoram)
 	AM_RANGE(0x13c0, 0x13ff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0x2000, 0x2000) AM_WRITE(MWA8_RAM) AM_BASE(&atarifb_scroll_register) /* OUT 0 */
+	AM_RANGE(0x2000, 0x2000) AM_WRITE(SMH_RAM) AM_BASE(&atarifb_scroll_register) /* OUT 0 */
 	AM_RANGE(0x2001, 0x2001) AM_WRITE(atarifb_out1_w) /* OUT 1 */
 	AM_RANGE(0x2002, 0x2002) AM_WRITE(atarifb_out2_w) /* OUT 2 */
 	AM_RANGE(0x2003, 0x2003) AM_WRITE(atarifb_out3_w) /* OUT 3 */
-	AM_RANGE(0x3000, 0x3000) AM_READ(MRA8_RAM)
-	AM_RANGE(0x3000, 0x3000) AM_WRITE(MWA8_NOP) /* Interrupt Acknowledge */
+	AM_RANGE(0x3000, 0x3000) AM_READ(SMH_RAM)
+	AM_RANGE(0x3000, 0x3000) AM_WRITE(SMH_NOP) /* Interrupt Acknowledge */
 	AM_RANGE(0x4000, 0x4000) AM_READ(atarifb_in0_r)
 	AM_RANGE(0x4002, 0x4002) AM_READ(atarifb_in2_r)
 	AM_RANGE(0x5000, 0x5000) AM_WRITE(watchdog_reset_w)
@@ -169,21 +171,21 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( atarifb4_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(15) )
+	ADDRESS_MAP_GLOBAL_MASK(0x7fff)
 	AM_RANGE(0x0000, 0x01ff) AM_RAM
-	AM_RANGE(0x0200, 0x025f) AM_READWRITE(MRA8_RAM, atarifb_alpha1_videoram_w) AM_BASE(&atarifb_alphap1_videoram)
+	AM_RANGE(0x0200, 0x025f) AM_RAM_WRITE(atarifb_alpha1_videoram_w) AM_BASE(&atarifb_alphap1_videoram)
 	AM_RANGE(0x0260, 0x039f) AM_RAM
-	AM_RANGE(0x03a0, 0x03ff) AM_READWRITE(MRA8_RAM, atarifb_alpha2_videoram_w) AM_BASE(&atarifb_alphap2_videoram)
-	AM_RANGE(0x1000, 0x13bf) AM_READWRITE(MRA8_RAM, atarifb_field_videoram_w) AM_BASE(&atarifb_field_videoram)
+	AM_RANGE(0x03a0, 0x03ff) AM_RAM_WRITE(atarifb_alpha2_videoram_w) AM_BASE(&atarifb_alphap2_videoram)
+	AM_RANGE(0x1000, 0x13bf) AM_RAM_WRITE(atarifb_field_videoram_w) AM_BASE(&atarifb_field_videoram)
 	AM_RANGE(0x13c0, 0x13ff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0x2000, 0x2000) AM_WRITE(MWA8_RAM) AM_BASE(&atarifb_scroll_register) /* OUT 0 */
+	AM_RANGE(0x2000, 0x2000) AM_WRITE(SMH_RAM) AM_BASE(&atarifb_scroll_register) /* OUT 0 */
 	AM_RANGE(0x2001, 0x2001) AM_WRITE(atarifb4_out1_w) /* OUT 1 */
 	AM_RANGE(0x2002, 0x2002) AM_WRITE(atarifb_out2_w) /* OUT 2 */
 	AM_RANGE(0x2003, 0x2003) AM_WRITE(atarifb_out3_w) /* OUT 3 */
-	AM_RANGE(0x3000, 0x3000) AM_READ(MRA8_RAM)
-	AM_RANGE(0x3000, 0x3000) AM_WRITE(MWA8_NOP) /* Interrupt Acknowledge */
+	AM_RANGE(0x3000, 0x3000) AM_READ(SMH_RAM)
+	AM_RANGE(0x3000, 0x3000) AM_WRITE(SMH_NOP) /* Interrupt Acknowledge */
 	AM_RANGE(0x4000, 0x4000) AM_READ(atarifb4_in0_r)
-	AM_RANGE(0x4001, 0x4001) AM_READ(input_port_1_r)
+	AM_RANGE(0x4001, 0x4001) AM_READ_PORT("EXTRA")
 	AM_RANGE(0x4002, 0x4002) AM_READ(atarifb4_in2_r)
 	AM_RANGE(0x5000, 0x5000) AM_WRITE(watchdog_reset_w)
 	AM_RANGE(0x6000, 0x7fff) AM_ROM
@@ -191,19 +193,19 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( abaseb_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(15) )
+	ADDRESS_MAP_GLOBAL_MASK(0x7fff)
 	AM_RANGE(0x0000, 0x01ff) AM_RAM
-	AM_RANGE(0x0200, 0x025f) AM_READWRITE(MRA8_RAM, atarifb_alpha1_videoram_w) AM_BASE(&atarifb_alphap1_videoram)
+	AM_RANGE(0x0200, 0x025f) AM_RAM_WRITE(atarifb_alpha1_videoram_w) AM_BASE(&atarifb_alphap1_videoram)
 	AM_RANGE(0x0260, 0x039f) AM_RAM
-	AM_RANGE(0x03a0, 0x03ff) AM_READWRITE(MRA8_RAM, atarifb_alpha2_videoram_w) AM_BASE(&atarifb_alphap2_videoram)
-	AM_RANGE(0x1000, 0x13bf) AM_READWRITE(MRA8_RAM, atarifb_field_videoram_w) AM_BASE(&atarifb_field_videoram)
+	AM_RANGE(0x03a0, 0x03ff) AM_RAM_WRITE(atarifb_alpha2_videoram_w) AM_BASE(&atarifb_alphap2_videoram)
+	AM_RANGE(0x1000, 0x13bf) AM_RAM_WRITE(atarifb_field_videoram_w) AM_BASE(&atarifb_field_videoram)
 	AM_RANGE(0x13c0, 0x13ff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0x2000, 0x2000) AM_WRITE(MWA8_RAM) AM_BASE(&atarifb_scroll_register) /* OUT 0 */
+	AM_RANGE(0x2000, 0x2000) AM_WRITE(SMH_RAM) AM_BASE(&atarifb_scroll_register) /* OUT 0 */
 	AM_RANGE(0x2001, 0x2001) AM_WRITE(abaseb_out1_w) /* OUT 1 */
 	AM_RANGE(0x2002, 0x2002) AM_WRITE(atarifb_out2_w) /* OUT 2 */
 	AM_RANGE(0x2003, 0x2003) AM_WRITE(atarifb_out3_w) /* OUT 3 */
-	AM_RANGE(0x3000, 0x3000) AM_READ(MRA8_RAM)
-	AM_RANGE(0x3000, 0x3000) AM_WRITE(MWA8_NOP) /* Interrupt Acknowledge */
+	AM_RANGE(0x3000, 0x3000) AM_READ(SMH_RAM)
+	AM_RANGE(0x3000, 0x3000) AM_WRITE(SMH_NOP) /* Interrupt Acknowledge */
 	AM_RANGE(0x4000, 0x4000) AM_READ(atarifb_in0_r)
 	AM_RANGE(0x4002, 0x4002) AM_READ(atarifb_in2_r)
 	AM_RANGE(0x5000, 0x5000) AM_WRITE(watchdog_reset_w)
@@ -212,22 +214,22 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( soccer_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(14) )
+	ADDRESS_MAP_GLOBAL_MASK(0x3fff)
 	AM_RANGE(0x0000, 0x01ff) AM_RAM
-	AM_RANGE(0x0200, 0x025f) AM_READWRITE(MRA8_RAM, atarifb_alpha1_videoram_w) AM_BASE(&atarifb_alphap1_videoram)
+	AM_RANGE(0x0200, 0x025f) AM_RAM_WRITE(atarifb_alpha1_videoram_w) AM_BASE(&atarifb_alphap1_videoram)
 	AM_RANGE(0x0260, 0x039f) AM_RAM
-	AM_RANGE(0x03a0, 0x03ff) AM_READWRITE(MRA8_RAM, atarifb_alpha2_videoram_w) AM_BASE(&atarifb_alphap2_videoram)
-	AM_RANGE(0x0800, 0x0bbf) AM_READWRITE(MRA8_RAM, atarifb_field_videoram_w) AM_BASE(&atarifb_field_videoram)
+	AM_RANGE(0x03a0, 0x03ff) AM_RAM_WRITE(atarifb_alpha2_videoram_w) AM_BASE(&atarifb_alphap2_videoram)
+	AM_RANGE(0x0800, 0x0bbf) AM_RAM_WRITE(atarifb_field_videoram_w) AM_BASE(&atarifb_field_videoram)
 	AM_RANGE(0x0bc0, 0x0bff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0x1000, 0x1000) AM_WRITE(MWA8_RAM) AM_BASE(&atarifb_scroll_register) /* OUT 0 */
+	AM_RANGE(0x1000, 0x1000) AM_WRITE(SMH_RAM) AM_BASE(&atarifb_scroll_register) /* OUT 0 */
 	AM_RANGE(0x1001, 0x1001) AM_WRITE(soccer_out1_w) /* OUT 1 */
 	AM_RANGE(0x1002, 0x1002) AM_WRITE(soccer_out2_w) /* OUT 2 */
-	AM_RANGE(0x1004, 0x1004) AM_WRITE(MWA8_NOP) /* Interrupt Acknowledge */
+	AM_RANGE(0x1004, 0x1004) AM_WRITE(SMH_NOP) /* Interrupt Acknowledge */
 	AM_RANGE(0x1005, 0x1005) AM_WRITE(watchdog_reset_w)
 	AM_RANGE(0x1800, 0x1800) AM_READ(atarifb4_in0_r)
-	AM_RANGE(0x1801, 0x1801) AM_READ(input_port_1_r)
+	AM_RANGE(0x1801, 0x1801) AM_READ_PORT("EXTRA")
 	AM_RANGE(0x1802, 0x1802) AM_READ(atarifb4_in2_r)
-	AM_RANGE(0x1803, 0x1803) AM_READ(input_port_11_r)
+	AM_RANGE(0x1803, 0x1803) AM_READ_PORT("DSW1")
 	AM_RANGE(0x2000, 0x3fff) AM_ROM
 ADDRESS_MAP_END
 
@@ -240,23 +242,21 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( atarifb )
-	PORT_START_TAG("IN0")
-	PORT_BIT ( 0x0F, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+	PORT_START("IN0")
+	PORT_BIT ( 0x0f, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT ( 0x10, IP_ACTIVE_LOW,  IPT_BUTTON1 )
 	PORT_BIT ( 0x20, IP_ACTIVE_LOW,  IPT_TILT )
 	PORT_BIT ( 0x40, IP_ACTIVE_HIGH, IPT_VBLANK )
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW,  IPT_COIN1 )
 
-	PORT_START_TAG("IN1")
-	PORT_DIPNAME( 0x03, 0x00, "Time per coin" )
+	PORT_START("IN1")
+	PORT_DIPNAME( 0x03, 0x00, "Time Per Coin" )		PORT_DIPLOCATION("K10:1,2")
 	PORT_DIPSETTING(	0x00, "1:30" )
 	PORT_DIPSETTING(	0x01, "2:00" )
 	PORT_DIPSETTING(	0x02, "2:30" )
 	PORT_DIPSETTING(	0x03, "3:00" )
-	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(	0x00, DEF_STR( Off ) )
-	PORT_DIPSETTING(	0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x00, "Atari logo" )
+	PORT_DIPUNUSED_DIPLOC( 0x04, 0x04, "K10:3" )	/* Listed as "Unused" */
+	PORT_DIPNAME( 0x08, 0x00, "Atari Logo" )		PORT_DIPLOCATION("K10:4") /* Listed as "Unused" */
 	PORT_DIPSETTING(	0x08, DEF_STR( Off ) )
 	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
 	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
@@ -264,150 +264,86 @@ static INPUT_PORTS_START( atarifb )
 	PORT_SERVICE( 0x40, IP_ACTIVE_LOW )
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )
 
-	PORT_START_TAG("IN2")	/* IN2 - Player 1 trackball, y */
+	PORT_START("IN2")	/* IN2 - Player 1 trackball, y */
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE
 	/* The lower 4 bits are the input */
 
-	PORT_START_TAG("IN3")	/* IN3 - Player 1 trackball, x */
+	PORT_START("IN3")	/* IN3 - Player 1 trackball, x */
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10)
 	/* The lower 4 bits are the input */
 
-	PORT_START_TAG("IN4")	/* IN4 - Player 2 trackball, y */
+	PORT_START("IN4")	/* IN4 - Player 2 trackball, y */
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE PORT_PLAYER(2)
 	/* The lower 4 bits are the input */
 
-	PORT_START_TAG("IN5")	/* IN5 - Player 2 trackball, x */
+	PORT_START("IN5")	/* IN5 - Player 2 trackball, x */
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(2)
 	/* The lower 4 bits are the input */
 INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( atarifb4 )
-	PORT_START_TAG("IN0")
+	PORT_INCLUDE( atarifb )
+
+	PORT_MODIFY("IN0")
 	PORT_BIT ( 0xff, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 
-	PORT_START_TAG("IN1")
+	PORT_MODIFY("IN1")
+	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_TILT )
+	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 )
+
+	PORT_START("IN6")	/* IN6 - Player 3 trackball, y */
+	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE PORT_PLAYER(3)
+	/* The lower 4 bits are the input */
+
+	PORT_START("IN7")	/* IN7 - Player 3 trackball, x */
+	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(3)
+	/* The lower 4 bits are the input */
+
+	PORT_START("IN8")	/* IN8 - Player 4 trackball, y */
+	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE PORT_PLAYER(4)
+	/* The lower 4 bits are the input */
+
+	PORT_START("IN9")	/* IN9 - Player 4 trackball, x */
+	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(4)
+	/* The lower 4 bits are the input */
+
+	PORT_START("EXTRA")
 	PORT_BIT ( 0x01, IP_ACTIVE_LOW,  IPT_COIN1 )
 	PORT_BIT ( 0x02, IP_ACTIVE_LOW,  IPT_COIN2 )
 	PORT_BIT ( 0x04, IP_ACTIVE_LOW,  IPT_COIN3 )
 	PORT_BIT ( 0x38, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_SERVICE( 0x40, IP_ACTIVE_LOW )
 	PORT_BIT ( 0x80, IP_ACTIVE_HIGH, IPT_VBLANK )
-
-	PORT_START_TAG("IN2")
-	PORT_DIPNAME( 0x03, 0x00, "Time per coin" )
-	PORT_DIPSETTING(	0x00, "1:30" )
-	PORT_DIPSETTING(	0x01, "2:00" )
-	PORT_DIPSETTING(	0x02, "2:30" )
-	PORT_DIPSETTING(	0x03, "3:00" )
-	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(	0x00, DEF_STR( Off ) )
-	PORT_DIPSETTING(	0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x00, "Atari logo" )
-	PORT_DIPSETTING(	0x08, DEF_STR( Off ) )
-	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
-	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_TILT )
-	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 )
-
-	PORT_START_TAG("IN3")	/* IN3 - Player 1 trackball, y */
-	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE
-	/* The lower 4 bits are the input */
-
-	PORT_START_TAG("IN4")	/* IN4 - Player 1 trackball, x */
-	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10)
-	/* The lower 4 bits are the input */
-
-	PORT_START_TAG("IN5")	/* IN5 - Player 2 trackball, y */
-	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE PORT_PLAYER(2)
-	/* The lower 4 bits are the input */
-
-	PORT_START_TAG("IN6")	/* IN6 - Player 2 trackball, x */
-	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(2)
-	/* The lower 4 bits are the input */
-
-	PORT_START_TAG("IN7")	/* IN7 - Player 3 trackball, y */
-	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE PORT_PLAYER(3)
-	/* The lower 4 bits are the input */
-
-	PORT_START_TAG("IN8")	/* IN8 - Player 3 trackball, x */
-	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(3)
-	/* The lower 4 bits are the input */
-
-	PORT_START_TAG("IN9")	/* IN9 - Player 4 trackball, y */
-	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE PORT_PLAYER(4)
-	/* The lower 4 bits are the input */
-
-	PORT_START_TAG("IN10")	/* IN10 - Player 4 trackball, x */
-	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(4)
-	/* The lower 4 bits are the input */
 INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( abaseb )
-	PORT_START_TAG("IN0")
-	PORT_BIT ( 0x0F, IP_ACTIVE_HIGH, IPT_UNKNOWN )
-	PORT_BIT ( 0x10, IP_ACTIVE_LOW,  IPT_BUTTON1 )
-	PORT_BIT ( 0x20, IP_ACTIVE_LOW,  IPT_TILT )
-	PORT_BIT ( 0x40, IP_ACTIVE_HIGH, IPT_VBLANK )
-	PORT_BIT ( 0x80, IP_ACTIVE_LOW,  IPT_COIN1 )
+	PORT_INCLUDE( atarifb )
 
-	PORT_START_TAG("IN1")
-	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Difficulty ) )
+	PORT_MODIFY("IN1")
+	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Difficulty ) )	PORT_DIPLOCATION("K10:1,2")
 	PORT_DIPSETTING(	0x00, DEF_STR( Hardest ) )
 	PORT_DIPSETTING(	0x01, DEF_STR( Hard ) )
-	PORT_DIPSETTING(	0x02, "Fair" )
-	PORT_DIPSETTING(	0x03, DEF_STR( Easy ) )
-	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(	0x00, DEF_STR( Off ) )
-	PORT_DIPSETTING(	0x04, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x00, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(	0x00, DEF_STR( Off ) )
-	PORT_DIPSETTING(	0x08, DEF_STR( On ) )
-	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_SERVICE( 0x40, IP_ACTIVE_LOW )
-	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )
-
-	PORT_START_TAG("IN2")	/* IN2 - Player 1 trackball, y */
-	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE
-	/* The lower 4 bits are the input */
-
-	PORT_START_TAG("IN3")	/* IN3 - Player 1 trackball, x */
-	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10)
-	/* The lower 4 bits are the input */
-
-	PORT_START_TAG("IN4")	/* IN4 - Player 2 trackball, y */
-	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE PORT_PLAYER(2)
-	/* The lower 4 bits are the input */
-
-	PORT_START_TAG("IN5")	/* IN5 - Player 2 trackball, x */
-	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(2)
-	/* The lower 4 bits are the input */
+	PORT_DIPSETTING(	0x02, DEF_STR( Easy ) )
+	PORT_DIPSETTING(	0x03, DEF_STR( Easiest ) )
+	PORT_DIPUNUSED_DIPLOC( 0x04, 0x04, "K10:3" )		/* Listed as "Unused" */
+	PORT_DIPUNUSED_DIPLOC( 0x08, 0x08, "K10:4" )		/* Listed as "Unused" */
 INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( soccer )
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT ( 0xff, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 
-	PORT_START_TAG("IN1")
-	PORT_BIT ( 0x01, IP_ACTIVE_LOW,  IPT_UNKNOWN ) /* unused on schematics */
-	PORT_BIT ( 0x02, IP_ACTIVE_LOW,  IPT_COIN1 )
-	PORT_BIT ( 0x04, IP_ACTIVE_LOW,  IPT_COIN2 )
-	PORT_BIT ( 0x08, IP_ACTIVE_LOW,  IPT_COIN3 )
-	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* unused on schematics */
-	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_TILT )
-	PORT_SERVICE( 0x40, IP_ACTIVE_LOW )
-	PORT_BIT ( 0x80, IP_ACTIVE_HIGH, IPT_VBLANK )
-
-	PORT_START_TAG("IN2")
-	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_NAME("2/4 Player Toggle")
-	PORT_DIPNAME( 0x02, 0x00, "Rule Switch" )
+	PORT_START("IN1")
+	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_NAME("2/4 Player Toggle") PORT_DIPLOCATION("SW2:4") /* Listed as "Unused" */
+	PORT_DIPNAME( 0x02, 0x00, "Rule Switch" )		PORT_DIPLOCATION("SW2:3") /* Listed as "Unused" */
 	PORT_DIPSETTING(	0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(	0x02, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0c, 0x00, DEF_STR( Language ) )
+	PORT_DIPNAME( 0x0c, 0x00, DEF_STR( Language ) )	PORT_DIPLOCATION("SW2:1,2")
 	PORT_DIPSETTING(	0x00, DEF_STR( English ) )
 	PORT_DIPSETTING(	0x04, DEF_STR( German ) )
 	PORT_DIPSETTING(	0x08, DEF_STR( French ) )
@@ -417,40 +353,50 @@ static INPUT_PORTS_START( soccer )
 	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(4)
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
 
-	PORT_START_TAG("IN3")	/* IN3 - Player 1 trackball, y */
+	PORT_START("IN2")	/* IN2 - Player 1 trackball, y */
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE
 	/* The lower 4 bits are the input */
 
-	PORT_START_TAG("IN4")	/* IN4 - Player 1 trackball, x */
+	PORT_START("IN3")	/* IN3 - Player 1 trackball, x */
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10)
 	/* The lower 4 bits are the input */
 
-	PORT_START_TAG("IN5")	/* IN5 - Player 2 trackball, y */
+	PORT_START("IN4")	/* IN4 - Player 2 trackball, y */
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE PORT_PLAYER(2)
 	/* The lower 4 bits are the input */
 
-	PORT_START_TAG("IN6")	/* IN6 - Player 2 trackball, x */
+	PORT_START("IN5")	/* IN5 - Player 2 trackball, x */
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(2)
 	/* The lower 4 bits are the input */
 
-	PORT_START_TAG("IN7")	/* IN7 - Player 3 trackball, y */
+	PORT_START("IN6")	/* IN6 - Player 3 trackball, y */
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE PORT_PLAYER(3)
 	/* The lower 4 bits are the input */
 
-	PORT_START_TAG("IN8")	/* IN8 - Player 3 trackball, x */
+	PORT_START("IN7")	/* IN7 - Player 3 trackball, x */
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(3)
 	/* The lower 4 bits are the input */
 
-	PORT_START_TAG("IN9")	/* IN9 - Player 4 trackball, y */
+	PORT_START("IN8")	/* IN8 - Player 4 trackball, y */
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE PORT_PLAYER(4)
 	/* The lower 4 bits are the input */
 
-	PORT_START_TAG("IN10")	/* IN10 - Player 4 trackball, x */
+	PORT_START("IN9")	/* IN9 - Player 4 trackball, x */
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(4)
 	/* The lower 4 bits are the input */
 
-	PORT_START_TAG("IN11")
-	PORT_DIPNAME( 0x07, 0x00, "Time per coin" )
+	PORT_START("EXTRA")
+	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* unused on schematics */
+	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT ( 0x08, IP_ACTIVE_LOW, IPT_COIN3 )
+	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* unused on schematics */
+	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_TILT )
+	PORT_SERVICE( 0x40, IP_ACTIVE_LOW )
+	PORT_BIT ( 0x80, IP_ACTIVE_HIGH, IPT_VBLANK )
+
+	PORT_START("DSW1")
+	PORT_DIPNAME( 0x07, 0x00, "Time per coin" )		PORT_DIPLOCATION("SW1:1,2,3")
 	PORT_DIPSETTING(	0x00, "1:00" )
 	PORT_DIPSETTING(	0x01, "1:20" )
 	PORT_DIPSETTING(	0x02, "1:40" )
@@ -459,18 +405,18 @@ static INPUT_PORTS_START( soccer )
 	PORT_DIPSETTING(	0x05, "3:00" )
 	PORT_DIPSETTING(	0x06, "3:30" )
 	PORT_DIPSETTING(	0x07, "4:00" )
-	PORT_DIPNAME( 0x18, 0x00, DEF_STR( Coin_B ) )
+	PORT_DIPNAME( 0x18, 0x00, DEF_STR( Coin_B ) )	PORT_DIPLOCATION("SW1:4,5")
 	PORT_DIPSETTING(	0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(	0x08, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(	0x10, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(	0x18, DEF_STR( 1C_6C ) )
-	PORT_DIPNAME( 0x20, 0x00, DEF_STR( Coin_A ) )
+	PORT_DIPNAME( 0x20, 0x00, DEF_STR( Coin_A ) )	PORT_DIPLOCATION("SW1:6")
 	PORT_DIPSETTING(	0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(	0x20, DEF_STR( 1C_2C ) )
-	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Coinage ) )
+	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Coinage ) )	PORT_DIPLOCATION("SW1:7")
 	PORT_DIPSETTING(	0x00, "1 Coin Minimum" )
 	PORT_DIPSETTING(	0x40, "2 Coin Minimum" )
-	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* unused on schematics */
+	PORT_DIPUNUSED_DIPLOC( 0x80, 0x80, "SW1:8" )	/* Listed as "Unused" */
 INPUT_PORTS_END
 
 
@@ -544,16 +490,16 @@ static const gfx_layout spritemasklayout =
 
 
 static GFXDECODE_START( atarifb )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, charlayout,  0x00, 0x01 ) /* offset into colors, # of colors */
-	GFXDECODE_ENTRY( REGION_GFX2, 0, fieldlayout, 0x02, 0x01 ) /* offset into colors, # of colors */
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout,  0x00, 0x01 ) /* offset into colors, # of colors */
+	GFXDECODE_ENTRY( "gfx2", 0, fieldlayout, 0x02, 0x01 ) /* offset into colors, # of colors */
 GFXDECODE_END
 
 
 static GFXDECODE_START( soccer )
-	GFXDECODE_ENTRY( REGION_GFX1, 0x0000, charlayout,         0x00, 0x01 ) /* offset into colors, # of colors */
-	GFXDECODE_ENTRY( REGION_GFX3, 0x0400, soccer_fieldlayout, 0x06, 0x01 ) /* offset into colors, # of colors */
-	GFXDECODE_ENTRY( REGION_GFX2, 0x0000, spritelayout,       0x02, 0x02 ) /* offset into colors, # of colors */
-	GFXDECODE_ENTRY( REGION_GFX3, 0x0000, spritemasklayout,   0x06, 0x03 ) /* offset into colors, # of colors */
+	GFXDECODE_ENTRY( "gfx1", 0x0000, charlayout,         0x00, 0x01 ) /* offset into colors, # of colors */
+	GFXDECODE_ENTRY( "gfx3", 0x0400, soccer_fieldlayout, 0x06, 0x01 ) /* offset into colors, # of colors */
+	GFXDECODE_ENTRY( "gfx2", 0x0000, spritelayout,       0x02, 0x02 ) /* offset into colors, # of colors */
+	GFXDECODE_ENTRY( "gfx3", 0x0000, spritemasklayout,   0x06, 0x03 ) /* offset into colors, # of colors */
 GFXDECODE_END
 
 
@@ -567,15 +513,14 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( atarifb )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", M6502, 750000)
+	MDRV_CPU_ADD("main", M6502, 750000)
 	MDRV_CPU_PROGRAM_MAP(atarifb_map,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,4)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2037)	/* 16.3ms * 1/8 = 2037.5. Is it 1/8th or 3/32nds? (1528?) */)
+	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,4)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2037)	/* 16.3ms * 1/8 = 2037.5. Is it 1/8th or 3/32nds? (1528?) */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(38*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 38*8-1, 1*8, 31*8-1)
@@ -589,9 +534,9 @@ static MACHINE_DRIVER_START( atarifb )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD_TAG("discrete", DISCRETE, 0)
+	MDRV_SOUND_ADD("discrete", DISCRETE, 0)
 	MDRV_SOUND_CONFIG_DISCRETE(atarifb)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.18)
 MACHINE_DRIVER_END
 
 
@@ -608,6 +553,7 @@ static MACHINE_DRIVER_START( abaseb )
 
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(atarifb)
+	MDRV_CPU_MODIFY("main")
 	MDRV_CPU_PROGRAM_MAP(abaseb_map,0)
 
 	/* video hardware */
@@ -616,7 +562,7 @@ static MACHINE_DRIVER_START( abaseb )
 	/* sound hardware */
 	MDRV_SOUND_REPLACE("discrete", DISCRETE, 0)
 	MDRV_SOUND_CONFIG_DISCRETE(abaseb)
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.24)
 MACHINE_DRIVER_END
 
 
@@ -628,6 +574,7 @@ static MACHINE_DRIVER_START( soccer )
 	MDRV_CPU_PROGRAM_MAP(soccer_map,0)
 
 	/* video hardware */
+	MDRV_SCREEN_MODIFY("main")
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 38*8-1, 2*8, 32*8-1)
 	MDRV_GFXDECODE(soccer)
 	MDRV_VIDEO_UPDATE(soccer)
@@ -642,37 +589,37 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( atarifb )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "03302602.m1", 0x6800, 0x0800, CRC(352e35db) SHA1(ae3f1bdb274858edf203dbffe4ba2912c065cff2) )
 	ROM_LOAD( "03302801.p1", 0x7000, 0x0800, CRC(a79c79ca) SHA1(7791b431e9aadb09fd286ae56699c4beda54830a) )
 	ROM_LOAD( "03302702.n1", 0x7800, 0x0800, CRC(e7e916ae) SHA1(d3a188809e83c311699cb103040c4525b36a56e3) )
 
-	ROM_REGION( 0x0400, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD_NIB_LOW ( "033029.n7", 0x0000, 0x0400, CRC(12f43dca) SHA1(a463f5068d5522ddf74052429aa6da23e5475844) )
 
-	ROM_REGION( 0x0200, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0200, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD_NIB_LOW ( "033030.c5", 0x0000, 0x0200, CRC(eac9ef90) SHA1(0e6284392852695ab7323be82105d32f57ad00f1) )
 	ROM_LOAD_NIB_HIGH( "033031.d5", 0x0000, 0x0200, CRC(89d619b8) SHA1(0af5d1f4e6f9a377dc2d49a8039866b1857af01f) )
 ROM_END
 
 
 ROM_START( atarifb1 )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "03302601.m1", 0x6800, 0x0800, CRC(f8ce7ed8) SHA1(54520d7d31c6c8f9028b7253a33aba3b2c35ae7c) )
 	ROM_LOAD( "03302801.p1", 0x7000, 0x0800, CRC(a79c79ca) SHA1(7791b431e9aadb09fd286ae56699c4beda54830a) )
 	ROM_LOAD( "03302701.n1", 0x7800, 0x0800, CRC(7740be51) SHA1(3f610061f081eb5589b00a496877bc58f6e0f09f) )
 
-	ROM_REGION( 0x0400, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD_NIB_LOW ( "033029.n7", 0x0000, 0x0400, CRC(12f43dca) SHA1(a463f5068d5522ddf74052429aa6da23e5475844) )
 
-	ROM_REGION( 0x0200, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0200, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD_NIB_LOW ( "033030.c5", 0x0000, 0x0200, CRC(eac9ef90) SHA1(0e6284392852695ab7323be82105d32f57ad00f1) )
 	ROM_LOAD_NIB_HIGH( "033031.d5", 0x0000, 0x0200, CRC(89d619b8) SHA1(0af5d1f4e6f9a377dc2d49a8039866b1857af01f) )
 ROM_END
 
 
 ROM_START( atarifb4 )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 ) /* 64k for code, the ROMs are nibble-wide */
+	ROM_REGION( 0x8000, "main", 0 ) /* 64k for code, the ROMs are nibble-wide */
 	ROM_LOAD_NIB_LOW ( "34889.m1", 0x6000, 0x0400, CRC(5c63974a) SHA1(e91f318be80d985a09ff92f4db5792290a06dc0f) )
 	ROM_LOAD_NIB_HIGH( "34891.m2", 0x6000, 0x0400, CRC(9d03baa1) SHA1(1b57f39fa4d43e3f3d22f2d9a5478b5f5e4d0cb1) )
 	ROM_LOAD_NIB_LOW ( "34890.n1", 0x6400, 0x0400, CRC(2deb5844) SHA1(abc7cc80d5fcac13f50f6cc550ea7a8f322434c9) )
@@ -690,33 +637,33 @@ ROM_START( atarifb4 )
 	ROM_LOAD_NIB_LOW ( "34882.j1", 0x7c00, 0x0400, CRC(060c9cdb) SHA1(3c6d04c535195dfa8f8405ff8e80f4693844d1a1) )
 	ROM_LOAD_NIB_HIGH( "34884.j2", 0x7c00, 0x0400, CRC(aa699a3a) SHA1(2c13eb9cda3fe9cfd348ef5cf309625f77c75056) )
 
-	ROM_REGION( 0x0400, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD_NIB_LOW ( "033029.n7", 0x0000, 0x0400, CRC(12f43dca) SHA1(a463f5068d5522ddf74052429aa6da23e5475844) )
 
-	ROM_REGION( 0x0200, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0200, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD_NIB_LOW ( "033030.c5", 0x0000, 0x0200, CRC(eac9ef90) SHA1(0e6284392852695ab7323be82105d32f57ad00f1) )
 	ROM_LOAD_NIB_HIGH( "033031.d5", 0x0000, 0x0200, CRC(89d619b8) SHA1(0af5d1f4e6f9a377dc2d49a8039866b1857af01f) )
 ROM_END
 
 
 ROM_START( abaseb )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "34738-01.n0", 0x6000, 0x0800, CRC(edcfffe8) SHA1(a445668352da5039ed1a090bcdf2ce092215f165) )
 	ROM_LOAD( "34737-03.m1", 0x6800, 0x0800, CRC(7250863f) SHA1(83ec735a60d74ca9c3e3f5d4b248071f3e3330af) )
 	ROM_LOAD( "34735-01.p1", 0x7000, 0x0800, CRC(54854d7c) SHA1(536d57b00929bf9d1cd1b209b41004cb78e2cd93) )
 	ROM_LOAD( "34736-01.n1", 0x7800, 0x0800, CRC(af444eb0) SHA1(783293426cec6938a2cd9c66c491f073cfb2683f) )
 
-	ROM_REGION( 0x0400, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD_NIB_LOW ( "034710.d5", 0x0000, 0x0400, CRC(31275d86) SHA1(465ff2032e62bcd5a7bb5c947212da4ea4d59353) )
 
-	ROM_REGION( 0x0200, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0200, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD_NIB_LOW ( "034708.n7", 0x0000, 0x0200, CRC(8a0f971b) SHA1(f7de50eeb15c8291f1560e299e3b1b29bba58422) )
 	ROM_LOAD_NIB_HIGH( "034709.c5", 0x0000, 0x0200, CRC(021d1067) SHA1(da0fa8e4f6c0240a4feb41312fa057c65d809e62) )
 ROM_END
 
 
 ROM_START( abaseb2 )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 ) /* 64k for code, the ROMs are nibble-wide */
+	ROM_REGION( 0x8000, "main", 0 ) /* 64k for code, the ROMs are nibble-wide */
 	ROM_LOAD_NIB_LOW ( "034725.c0", 0x6000, 0x0400, CRC(95912c58) SHA1(cb15b60e31ee212e30a81c170611be1e36d2a6dd) )
 	ROM_LOAD_NIB_HIGH( "034723.m0", 0x6000, 0x0400, CRC(5eb1597f) SHA1(78f83d4e79de13d3723732d68738660c3f8d4787) )
 	ROM_LOAD_NIB_LOW ( "034726.b0", 0x6400, 0x0400, CRC(1f8d506c) SHA1(875464ca2ee50b36ceb5989cd40a28c69953c641) )
@@ -734,17 +681,17 @@ ROM_START( abaseb2 )
 	ROM_LOAD_NIB_LOW ( "034720.h0", 0x7c00, 0x0400, CRC(37c5f149) SHA1(89ad4471b949f8318abbdb38c4f373f711130198) )
 	ROM_LOAD_NIB_HIGH( "034714.f0", 0x7c00, 0x0400, CRC(920979ea) SHA1(aba499376c084b8ceb6f0cc6599bd51cec133cc7) )
 
-	ROM_REGION( 0x0400, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD_NIB_LOW ( "034710.d5", 0x0000, 0x0400, CRC(31275d86) SHA1(465ff2032e62bcd5a7bb5c947212da4ea4d59353) )
 
-	ROM_REGION( 0x0200, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0200, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD_NIB_LOW ( "034708.n7", 0x0000, 0x0200, CRC(8a0f971b) SHA1(f7de50eeb15c8291f1560e299e3b1b29bba58422) )
 	ROM_LOAD_NIB_HIGH( "034709.c5", 0x0000, 0x0200, CRC(021d1067) SHA1(da0fa8e4f6c0240a4feb41312fa057c65d809e62) )
 ROM_END
 
 
 ROM_START( soccer )
-	ROM_REGION( 0x4000, REGION_CPU1, 0 ) /* 64k for code, the ROMs are nibble-wide */
+	ROM_REGION( 0x4000, "main", 0 ) /* 64k for code, the ROMs are nibble-wide */
 	ROM_LOAD_NIB_LOW ( "035222.e1", 0x2000, 0x0400, CRC(03ec6bce) SHA1(f81f2ac3bab5f1ae687543427e0187ca51d3be7e) )
 	ROM_LOAD_NIB_HIGH( "035224.e2", 0x2000, 0x0400, CRC(a1aeaa70) SHA1(2018318a0e652b1dbea7696ef3dc2b7f12ebd632) )
 	ROM_LOAD_NIB_LOW ( "035223.f1", 0x2400, 0x0400, CRC(9c600726) SHA1(f652b42b93e43124b0363b52f0f13cb9154987e3) )
@@ -763,14 +710,14 @@ ROM_START( soccer )
 	ROM_LOAD_NIB_LOW ( "035235.n1", 0x3c00, 0x0400, CRC(d6855b0e) SHA1(379d010ebebde6f1b5fec5519a3c0aa4380be28b) )
 	ROM_LOAD_NIB_HIGH( "035237.n2", 0x3c00, 0x0400, CRC(1d01b054) SHA1(7f3dc1130b2aadb13813e223420672c5baf25ad8) )
 
-	ROM_REGION( 0x0400, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD_NIB_LOW ( "035250.r2", 0x0000, 0x0400, CRC(12f43dca) SHA1(a463f5068d5522ddf74052429aa6da23e5475844) ) /* characters */
 
-	ROM_REGION( 0x0800, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0800, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD_NIB_LOW ( "035247.n7", 0x0000, 0x0400, CRC(3adb5f4e) SHA1(859df5dc97b06e0c06e4f71a511313aef1f08d87) ) /* sprites */
 	ROM_LOAD_NIB_HIGH( "035248.m7", 0x0000, 0x0400, CRC(a890cd48) SHA1(34f52bc4b610491d3b81caae25ec3cafbc429373) )
 
-	ROM_REGION( 0x0800, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0800, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "035246.r6", 0x0000, 0x0800, CRC(4a996136) SHA1(535b6d5f70ab5bc2a47263a1c16877ba4c82b3ff) ) /* spritemask - playfield */
 
 	/* ROM_LOAD_NIB_LOW ( "35242-01.r7", 0x0000, 0x0400, CRC(d783e3d3) SHA1(1753b907735ca75c4622e003ec0df5f32e886783) ) */
@@ -778,7 +725,7 @@ ROM_START( soccer )
 	/* ROM_LOAD_NIB_LOW ( "35244-01.p7", 0x0400, 0x0400, CRC(5236ae38) SHA1(472b51635a050ea1913d745fcfc07f30ce9afa09) ) */
 	/* ROM_LOAD_NIB_HIGH( "35245-01.p8", 0x0400, 0x0400, CRC(e4c6fd5c) SHA1(62c80735726c4e11229438c27153203105b9cb66) ) */
 
-	ROM_REGION( 0x0100, REGION_PROMS, 0 )
+	ROM_REGION( 0x0100, "proms", 0 )
 	ROM_LOAD( "34006-01.n4", 0x0000, 0x0100, CRC(0da9918e) SHA1(405ee4396a20d05ecde27388093139d087d81f19) ) /* sync (not used) */
 ROM_END
 
