@@ -19,7 +19,6 @@
 
 
 #include "driver.h"
-#include "deprecat.h"
 #include "machine/atarigen.h"
 #include "video/atarirle.h"
 #include "cpu/m68000/m68000.h"
@@ -42,10 +41,10 @@ UINT8 atarigt_is_primrage;
 
 static UINT32 *	mo_command;
 
-static void (*protection_w)(offs_t offset, UINT16 data);
-static void (*protection_r)(offs_t offset, UINT16 *data);
+static void (*protection_w)(const address_space *space, offs_t offset, UINT16 data);
+static void (*protection_r)(const address_space *space, offs_t offset, UINT16 *data);
 
-static void cage_irq_callback(int reason);
+static void cage_irq_callback(running_machine *machine, int reason);
 
 
 
@@ -57,19 +56,9 @@ static void cage_irq_callback(int reason);
 
 static void update_interrupts(running_machine *machine)
 {
-	int newstate = 0;
-
-	if (atarigen_sound_int_state)
-		newstate = 3;
-	if (atarigen_video_int_state)
-		newstate = 4;
-	if (atarigen_scanline_int_state)
-		newstate = 6;
-
-	if (newstate)
-		cpunum_set_input_line(machine, 0, newstate, ASSERT_LINE);
-	else
-		cpunum_set_input_line(machine, 0, 7, CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], 3, atarigen_sound_int_state    ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], 4, atarigen_video_int_state    ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], 6, atarigen_scanline_int_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -77,7 +66,7 @@ static MACHINE_RESET( atarigt )
 {
 	atarigen_eeprom_reset();
 	atarigen_interrupt_reset(update_interrupts);
-	atarigen_scanline_timer_reset(0, atarigt_scanline_update, 8);
+	atarigen_scanline_timer_reset(machine->primary_screen, atarigt_scanline_update, 8);
 }
 
 
@@ -88,12 +77,14 @@ static MACHINE_RESET( atarigt )
  *
  *************************************/
 
-static void cage_irq_callback(int reason)
+static void cage_irq_callback(running_machine *machine, int reason)
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 	if (reason)
-		atarigen_sound_int_gen(Machine, 0);
+		atarigen_sound_int_gen(machine->cpu[0]);
 	else
-		atarigen_sound_int_ack_w(0,0,0);
+		atarigen_sound_int_ack_w(space,0,0,0xffff);
 }
 
 
@@ -104,15 +95,9 @@ static void cage_irq_callback(int reason)
  *
  *************************************/
 
-static READ32_HANDLER( inputs_01_r )
-{
-	return (readinputportbytag("IN0") << 16) | readinputportbytag("IN1");
-}
-
-
 static READ32_HANDLER( special_port2_r )
 {
-	int temp = readinputportbytag("IN2");
+	int temp = input_port_read(space->machine, "SERVICE");
 	temp ^= 0x0001;		/* /A2DRDY always high for now */
 	temp ^= 0x0008;		/* A2D.EOC always high for now */
 	return (temp << 16) | temp;
@@ -121,7 +106,7 @@ static READ32_HANDLER( special_port2_r )
 
 static READ32_HANDLER( special_port3_r )
 {
-	int temp = readinputportbytag("IN3");
+	int temp = input_port_read(space->machine, "COIN");
 	if (atarigen_video_int_state) temp ^= 0x0001;
 	if (atarigen_scanline_int_state) temp ^= 0x0002;
 	return (temp << 16) | temp;
@@ -131,7 +116,7 @@ static READ32_HANDLER( special_port3_r )
 #if (HACK_TMEK_CONTROLS)
 INLINE void compute_fake_pots(int *pots)
 {
-	int fake = readinputportbytag("FAKE");
+	int fake = input_port_read(machine, "FAKE");
 
 	pots[0] = pots[1] = pots[2] = pots[3] = 0x80;
 
@@ -168,7 +153,7 @@ static READ32_HANDLER( analog_port0_r )
 	compute_fake_pots(pots);
 	return (pots[0] << 24) | (pots[3] << 8);
 #else
-	return (readinputportbytag("IN4") << 24) | (readinputportbytag("IN5") << 8);
+	return (input_port_read(space->machine, "AN1") << 24) | (input_port_read(space->machine, "AN2") << 8);
 #endif
 }
 
@@ -180,7 +165,7 @@ static READ32_HANDLER( analog_port1_r )
 	compute_fake_pots(pots);
 	return (pots[2] << 24) | (pots[1] << 8);
 #else
-	return (readinputportbytag("IN6") << 24) | (readinputportbytag("IN7") << 8);
+	return (input_port_read(space->machine, "AN3") << 24) | (input_port_read(space->machine, "AN4") << 8);
 #endif
 }
 
@@ -206,13 +191,13 @@ static WRITE32_HANDLER( latch_w )
     */
 
 	/* upper byte */
-	if (!(mem_mask & 0xff000000))
+	if (ACCESSING_BITS_24_31)
 	{
 		/* bits 13-11 are the MO control bits */
-		atarirle_control_w(0, (data >> 27) & 7);
+		atarirle_control_w(space->machine, 0, (data >> 27) & 7);
 	}
 
-	if (!(mem_mask & 0x00ff0000))
+	if (ACCESSING_BITS_16_23)
 	{
 //      cage_reset_w(data & 0x00100000);
 		coin_counter_w(0, data & 0x00080000);
@@ -224,14 +209,14 @@ static WRITE32_HANDLER( latch_w )
 static WRITE32_HANDLER( mo_command_w )
 {
 	COMBINE_DATA(mo_command);
-	if (ACCESSING_LSW32)
+	if (ACCESSING_BITS_0_15)
 		atarirle_command_w(0, ((data & 0xffff) == 2) ? ATARIRLE_COMMAND_CHECKSUM : ATARIRLE_COMMAND_DRAW);
 }
 
 
 static WRITE32_HANDLER( led_w )
 {
-//  logerror("LED = %08X & %08X\n", data, ~mem_mask);
+//  logerror("LED = %08X & %08X\n", data, mem_mask);
 }
 
 
@@ -246,19 +231,19 @@ static READ32_HANDLER( sound_data_r )
 {
 	UINT32 result = 0;
 
-	if (ACCESSING_LSW32)
+	if (ACCESSING_BITS_0_15)
 		result |= cage_control_r();
-	if (ACCESSING_MSW32)
-		result |= main_from_cage_r() << 16;
+	if (ACCESSING_BITS_16_31)
+		result |= main_from_cage_r(space) << 16;
 	return result;
 }
 
 
 static WRITE32_HANDLER( sound_data_w )
 {
-	if (ACCESSING_LSW32)
-		cage_control_w(data);
-	if (ACCESSING_MSW32)
+	if (ACCESSING_BITS_0_15)
+		cage_control_w(space->machine, data);
+	if (ACCESSING_BITS_16_31)
 		main_to_cage_w(data >> 16);
 }
 
@@ -291,11 +276,9 @@ static void tmek_update_mode(offs_t offset)
 }
 
 
-static void tmek_protection_w(offs_t offset, UINT16 data)
+static void tmek_protection_w(const address_space *space, offs_t offset, UINT16 data)
 {
-#if LOG_PROTECTION
-	logerror("%06X:Protection W@%06X = %04X\n", activecpu_get_previouspc(), offset, data);
-#endif
+	if (LOG_PROTECTION) logerror("%06X:Protection W@%06X = %04X\n", cpu_get_previouspc(space->cpu), offset, data);
 
 	/* track accesses */
 	tmek_update_mode(offset);
@@ -308,11 +291,9 @@ static void tmek_protection_w(offs_t offset, UINT16 data)
 	}
 }
 
-static void tmek_protection_r(offs_t offset, UINT16 *data)
+static void tmek_protection_r(const address_space *space, offs_t offset, UINT16 *data)
 {
-#if LOG_PROTECTION
-	logerror("%06X:Protection R@%06X\n", activecpu_get_previouspc(), offset);
-#endif
+	if (LOG_PROTECTION) logerror("%06X:Protection R@%06X\n", cpu_get_previouspc(space->cpu), offset);
 
 	/* track accesses */
 	tmek_update_mode(offset);
@@ -354,21 +335,21 @@ static void primage_update_mode(offs_t offset)
 		/* this is from the code at $20f90 */
 		if (protaddr[1] == 0xdcc7c4 && protaddr[2] == 0xdcc7c4 && protaddr[3] == 0xdc4010)
 		{
-//          logerror("prot:Entering mode 1\n");
+			if (LOG_PROTECTION) logerror("prot:Entering mode 1\n");
 			protmode = 1;
 		}
 
 		/* this is from the code at $27592 */
 		if (protaddr[0] == 0xdcc7ca && protaddr[1] == 0xdcc7ca && protaddr[2] == 0xdcc7c6 && protaddr[3] == 0xdc4022)
 		{
-//          logerror("prot:Entering mode 2\n");
+			if (LOG_PROTECTION) logerror("prot:Entering mode 2\n");
 			protmode = 2;
 		}
 
 		/* this is from the code at $3d8dc */
 		if (protaddr[0] == 0xdcc7c0 && protaddr[1] == 0xdcc7c0 && protaddr[2] == 0xdc80f2 && protaddr[3] == 0xdc7af2)
 		{
-//          logerror("prot:Entering mode 3\n");
+			if (LOG_PROTECTION) logerror("prot:Entering mode 3\n");
 			protmode = 3;
 		}
 	}
@@ -376,11 +357,11 @@ static void primage_update_mode(offs_t offset)
 
 
 
-static void primrage_protection_w(offs_t offset, UINT16 data)
+static void primrage_protection_w(const address_space *space, offs_t offset, UINT16 data)
 {
-#if LOG_PROTECTION
-{
-	UINT32 pc = activecpu_get_previouspc();
+	if (LOG_PROTECTION)
+	{
+	UINT32 pc = cpu_get_previouspc(space->cpu);
 	switch (pc)
 	{
 		/* protection code from 20f90 - 21000 */
@@ -413,11 +394,10 @@ static void primrage_protection_w(offs_t offset, UINT16 data)
 
 		/* catch anything else */
 		default:
-			logerror("%06X:Unknown protection W@%06X = %04X\n", activecpu_get_previouspc(), offset, data);
+			logerror("%06X:Unknown protection W@%06X = %04X\n", cpu_get_previouspc(space->cpu), offset, data);
 			break;
 	}
-}
-#endif
+	}
 
 /* mask = 0x78fff */
 
@@ -431,7 +411,7 @@ static void primrage_protection_w(offs_t offset, UINT16 data)
 	if (protmode == 2)
 	{
 		int temp = (offset - 0xdc7800) / 2;
-//      logerror("prot:mode 2 param = %04X\n", temp);
+		if (LOG_PROTECTION) logerror("prot:mode 2 param = %04X\n", temp);
 		protresult = temp * 0x6915 + 0x6915;
 	}
 
@@ -439,7 +419,7 @@ static void primrage_protection_w(offs_t offset, UINT16 data)
 	{
 		if (offset == 0xdc4700)
 		{
-//          logerror("prot:Clearing mode 3\n");
+			if (LOG_PROTECTION) logerror("prot:Clearing mode 3\n");
 			protmode = 0;
 		}
 	}
@@ -447,14 +427,14 @@ static void primrage_protection_w(offs_t offset, UINT16 data)
 
 
 
-static void primrage_protection_r(offs_t offset, UINT16 *data)
+static void primrage_protection_r(const address_space *space, offs_t offset, UINT16 *data)
 {
 	/* track accesses */
 	primage_update_mode(offset);
 
-#if LOG_PROTECTION
+if (LOG_PROTECTION)
 {
-	UINT32 pc = activecpu_get_previouspc();
+	UINT32 pc = cpu_get_previouspc(space->cpu);
 	UINT32 p1, p2, a6;
 	switch (pc)
 	{
@@ -474,9 +454,9 @@ static void primrage_protection_r(offs_t offset, UINT16 *data)
 		case 0x275bc:
 			break;
 		case 0x275cc:
-			a6 = activecpu_get_reg(M68K_A6);
-			p1 = (cpu_readmem24bedw_word(a6+8) << 16) | cpu_readmem24bedw_word(a6+10);
-			p2 = (cpu_readmem24bedw_word(a6+12) << 16) | cpu_readmem24bedw_word(a6+14);
+			a6 = cpu_get_reg(space->cpu, M68K_A6);
+			p1 = (memory_read_word(space, a6+8) << 16) | memory_read_word(space, a6+10);
+			p2 = (memory_read_word(space, a6+12) << 16) | memory_read_word(space, a6+14);
 			logerror("Known Protection @ 275BC(%08X, %08X): R@%06X ", p1, p2, offset);
 			break;
 		case 0x275d2:
@@ -492,8 +472,8 @@ static void primrage_protection_r(offs_t offset, UINT16 *data)
 
 		/* protection code from 3d8dc - 3d95a */
 		case 0x3d8f4:
-			a6 = activecpu_get_reg(M68K_A6);
-			p1 = (cpu_readmem24bedw_word(a6+12) << 16) | cpu_readmem24bedw_word(a6+14);
+			a6 = cpu_get_reg(space->cpu, M68K_A6);
+			p1 = (memory_read_word(space, a6+12) << 16) | memory_read_word(space, a6+14);
 			logerror("Known Protection @ 3D8F4(%08X): R@%06X ", p1, offset);
 			break;
 		case 0x3d8fa:
@@ -503,8 +483,8 @@ static void primrage_protection_r(offs_t offset, UINT16 *data)
 
 		/* protection code from 437fa - 43860 */
 		case 0x43814:
-			a6 = activecpu_get_reg(M68K_A6);
-			p1 = cpu_readmem24bedw(a6+15);
+			a6 = cpu_get_reg(space->cpu, M68K_A6);
+			p1 = memory_read_dword(space, a6+14) & 0xffffff;
 			logerror("Known Protection @ 43814(%08X): R@%06X ", p1, offset);
 			break;
 		case 0x4381c:
@@ -517,11 +497,10 @@ static void primrage_protection_r(offs_t offset, UINT16 *data)
 
 		/* catch anything else */
 		default:
-			logerror("%06X:Unknown protection R@%06X\n", activecpu_get_previouspc(), offset);
+			logerror("%06X:Unknown protection R@%06X\n", cpu_get_previouspc(space->cpu), offset);
 			break;
 	}
 }
-#endif
 
 	/* handle specific reads */
 	switch (offset)
@@ -540,7 +519,7 @@ static void primrage_protection_r(offs_t offset, UINT16 *data)
 			{
 				*data = protresult;
 				protmode = 0;
-//              logerror("prot:Clearing mode 2\n");
+			if (LOG_PROTECTION) logerror("prot:Clearing mode 2\n");
 			}
 			break;
 
@@ -548,7 +527,7 @@ static void primrage_protection_r(offs_t offset, UINT16 *data)
 			if (protmode == 1)
 			{
 				protmode = 0;
-//              logerror("prot:Clearing mode 1\n");
+			if (LOG_PROTECTION) logerror("prot:Clearing mode 1\n");
 			}
 			break;
 	}
@@ -568,16 +547,16 @@ static READ32_HANDLER( colorram_protection_r )
 	UINT32 result32 = 0;
 	UINT16 result;
 
-	if ((mem_mask & 0xffff0000) != 0xffff0000)
+	if (ACCESSING_BITS_16_31)
 	{
 		result = atarigt_colorram_r(address);
-		(*protection_r)(address, &result);
+		(*protection_r)(space, address, &result);
 		result32 |= result << 16;
 	}
-	if ((mem_mask & 0x0000ffff) != 0x0000ffff)
+	if (ACCESSING_BITS_0_15)
 	{
 		result = atarigt_colorram_r(address + 2);
-		(*protection_r)(address + 2, &result);
+		(*protection_r)(space, address + 2, &result);
 		result32 |= result;
 	}
 
@@ -589,17 +568,17 @@ static WRITE32_HANDLER( colorram_protection_w )
 {
 	offs_t address = 0xd80000 + offset * 4;
 
-	if ((mem_mask & 0xffff0000) != 0xffff0000)
+	if (ACCESSING_BITS_16_31)
 	{
 		if (!ignore_writes)
 			atarigt_colorram_w(address, data >> 16, mem_mask >> 16);
-		(*protection_w)(address, data >> 16);
+		(*protection_w)(space, address, data >> 16);
 	}
-	if ((mem_mask & 0x0000ffff) != 0x0000ffff)
+	if (ACCESSING_BITS_0_15)
 	{
 		if (!ignore_writes)
 			atarigt_colorram_w(address + 2, data, mem_mask);
-		(*protection_w)(address + 2, data);
+		(*protection_w)(space, address + 2, data);
 	}
 }
 
@@ -628,8 +607,8 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0xe08000, 0xe08003) AM_WRITE(latch_w)
 	AM_RANGE(0xe0a000, 0xe0a003) AM_WRITE(atarigen_scanline_int_ack32_w)
 	AM_RANGE(0xe0c000, 0xe0c003) AM_WRITE(atarigen_video_int_ack32_w)
-	AM_RANGE(0xe0e000, 0xe0e003) AM_WRITE(MWA32_NOP)//watchdog_reset_w },
-	AM_RANGE(0xe80000, 0xe80003) AM_READ(inputs_01_r)
+	AM_RANGE(0xe0e000, 0xe0e003) AM_WRITE(SMH_NOP)//watchdog_reset_w },
+	AM_RANGE(0xe80000, 0xe80003) AM_READ_PORT("P1_P2")
 	AM_RANGE(0xe82000, 0xe82003) AM_READ(special_port2_r)
 	AM_RANGE(0xe82004, 0xe82007) AM_READ(special_port3_r)
 	AM_RANGE(0xf80000, 0xffffff) AM_RAM
@@ -643,104 +622,99 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-#define COMMON_IN0\
-	PORT_START_TAG("IN0")\
-	PORT_BIT( 0x00ff, IP_ACTIVE_LOW, IPT_UNUSED )\
-	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_START1 )\
-	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)\
-	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)\
-	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)\
-	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(1)\
-	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(1)\
-	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)\
-	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
+static INPUT_PORTS_START( common )
+	PORT_START("P1_P2")				/* 68.SW (A1=0, A1=1) */
+	PORT_BIT( 0x000000ff, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00000100, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0x00000200, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT( 0x00000400, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
+	PORT_BIT( 0x00000800, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
+	PORT_BIT( 0x00001000, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(2)
+	PORT_BIT( 0x00002000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(2)
+	PORT_BIT( 0x00004000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(2)
+	PORT_BIT( 0x00008000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(2)
+	PORT_BIT( 0x00ff0000, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x01000000, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x02000000, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
+	PORT_BIT( 0x04000000, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
+	PORT_BIT( 0x08000000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
+	PORT_BIT( 0x10000000, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(1)
+	PORT_BIT( 0x20000000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(1)
+	PORT_BIT( 0x40000000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
+	PORT_BIT( 0x80000000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 
-#define COMMON_IN1\
-	PORT_START_TAG("IN1")\
-	PORT_BIT( 0x00ff, IP_ACTIVE_LOW, IPT_UNUSED )\
-	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_START2 )\
-	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)\
-	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)\
-	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)\
-	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(2)\
-	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(2)\
-	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(2)\
-	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(2)
-
-#define COMMON_IN2\
-	PORT_START_TAG("IN2")      /* 68.STATUS (A2=0) */ \
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /A2DRDY */ \
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_TILT )		/* TILT */ \
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /XIRQ23 */ \
-	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_SPECIAL )	/* A2D.EOC */ \
-	PORT_BIT( 0x0030, IP_ACTIVE_LOW, IPT_UNUSED )	/* NC */ \
-	PORT_SERVICE( 0x0040, IP_ACTIVE_LOW )			/* SELFTEST */ \
-	PORT_BIT( 0x0080, IP_ACTIVE_HIGH, IPT_VBLANK )	/* VBLANK */ \
+	PORT_START("SERVICE")		/* 68.STATUS (A2=0) */
+	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /A2DRDY */
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_TILT )		/* TILT */
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /XIRQ23 */
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_SPECIAL )	/* A2D.EOC */
+	PORT_BIT( 0x0030, IP_ACTIVE_LOW, IPT_UNUSED )	/* NC */
+	PORT_SERVICE( 0x0040, IP_ACTIVE_LOW )			/* SELFTEST */
+	PORT_BIT( 0x0080, IP_ACTIVE_HIGH, IPT_VBLANK )	/* VBLANK */
 	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNUSED )
 
-#define COMMON_IN3\
-	PORT_START_TAG("IN3")      /* 68.STATUS (A2=1) */ \
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /VBIRQ */ \
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /4MSIRQ */ \
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /XIRQ0 */ \
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /XIRQ1 */ \
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /SERVICER */ \
-	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /SER.L */ \
-	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_COIN2 )	/* COINR */ \
-	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_COIN1 )	/* COINL */ \
+	PORT_START("COIN")			/* 68.STATUS (A2=1) */
+	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /VBIRQ */
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /4MSIRQ */
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /XIRQ0 */
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /XIRQ1 */
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /SERVICER */
+	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_SPECIAL )	/* /SER.L */
+	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_COIN2 )	/* COINR */
+	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_COIN1 )	/* COINL */
 	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNUSED )
+INPUT_PORTS_END
 
 static INPUT_PORTS_START( tmek )
-	COMMON_IN0		/* 68.SW (A1=0) */
-
-	COMMON_IN1		/* 68.SW (A1=1) */
-
-	COMMON_IN2
-
-	COMMON_IN3
+	PORT_INCLUDE( common )
 
 #if (HACK_TMEK_CONTROLS)
-	PORT_START_TAG("FAKE")		/* single digital joystick */
+	PORT_START("FAKE")		/* single digital joystick */
 	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
 #else
-	PORT_START_TAG("IN4")
+
+	PORT_START("AN1")
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(2)
 
-	PORT_START_TAG("IN5")
+	PORT_START("AN2")
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(1)
 
-	PORT_START_TAG("IN6")
+	PORT_START("AN3")
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(1)
 
-	PORT_START_TAG("IN7")
+	PORT_START("AN4")
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_PLAYER(2)
 #endif
-
 INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( primrage )
-	COMMON_IN0		/* 68.SW (A1=0) */
+	PORT_INCLUDE( common )
 
-	COMMON_IN1		/* 68.SW (A1=1) bit 0x0008 does something */
+	/* primrage uses one of the 4 action buttons as start */
+	PORT_MODIFY( "P1_P2" )
+	PORT_BIT( 0x00000100, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT( 0x00000200, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
+	PORT_BIT( 0x00000400, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
+	PORT_BIT( 0x00000800, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(2)
+	PORT_BIT( 0x01000000, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
+	PORT_BIT( 0x02000000, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
+	PORT_BIT( 0x04000000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
+	PORT_BIT( 0x08000000, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(1)
 
-	COMMON_IN2      /* 68.STATUS (A2=0) */
-
-	COMMON_IN3      /* 68.STATUS (A2=1) */
-
-	PORT_START_TAG("IN4")
+	PORT_START("AN1")
 	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("IN5")
+	PORT_START("AN2")
 	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("IN6")
+	PORT_START("AN3")
 	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("IN7")
+	PORT_START("AN4")
 	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
@@ -789,9 +763,9 @@ static const gfx_layout anlayout =
 
 
 static GFXDECODE_START( atarigt )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, pflayout, 0x000, 64 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0, anlayout, 0x000, 16 )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, pftoplayout, 0x000, 64 )
+	GFXDECODE_ENTRY( "gfx1", 0, pflayout, 0x000, 64 )
+	GFXDECODE_ENTRY( "gfx2", 0, anlayout, 0x000, 16 )
+	GFXDECODE_ENTRY( "gfx1", 0, pftoplayout, 0x000, 64 )
 GFXDECODE_END
 
 
@@ -805,20 +779,20 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( atarigt )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68EC020, ATARI_CLOCK_50MHz/2)
+	MDRV_CPU_ADD("main", M68EC020, ATARI_CLOCK_50MHz/2)
 	MDRV_CPU_PROGRAM_MAP(main_map,0)
-	MDRV_CPU_VBLANK_INT(atarigen_video_int_gen,1)
+	MDRV_CPU_VBLANK_INT("main", atarigen_video_int_gen)
 	MDRV_CPU_PERIODIC_INT(atarigen_scanline_int_gen, 250)
 
 	MDRV_MACHINE_RESET(atarigt)
 	MDRV_NVRAM_HANDLER(atarigen)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_UPDATE_BEFORE_VBLANK)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
 	MDRV_GFXDECODE(atarigt)
 	MDRV_PALETTE_LENGTH(32768)
 
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	/* note: these parameters are from published specs, not derived */
 	/* the board uses a pair of GALs to determine H and V parameters */
@@ -841,16 +815,16 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( tmek )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 )	/* 8*64k for 68000 code */
+	ROM_REGION( 0x200000, "main", 0 )	/* 8*64k for 68000 code */
 	ROM_LOAD32_BYTE( "0044d", 0x00000, 0x20000, CRC(1cd62725) SHA1(7685794d9fbe3fe7a9978d12e489447b4fba5282) )
 	ROM_LOAD32_BYTE( "0043d", 0x00001, 0x20000, CRC(82185051) SHA1(a21aad4f6ec948d9cd47efb89e7811c5c2e4850b) )
 	ROM_LOAD32_BYTE( "0042d", 0x00002, 0x20000, CRC(ef9feda4) SHA1(9fb6e91d4c22e28ced61d0d1f28f5e43191c8762) )
 	ROM_LOAD32_BYTE( "0041d", 0x00003, 0x20000, CRC(179da056) SHA1(5f7ddf44aab55beaf2c377b0c93279acb6273255) )
 
-	ROM_REGION32_LE( 0x200000, REGION_USER1, 0 )	/* TMS320C31 boot ROM */
+	ROM_REGION32_LE( 0x200000, "cageboot", 0 )	/* TMS320C31 boot ROM */
 	ROM_LOAD32_BYTE( "0078c", 0x000000, 0x080000, CRC(ff5b979a) SHA1(deb8ee454b6b7c7bddb2ba0c808869e45b19e55f) )
 
-	ROM_REGION32_LE( 0x1000000, REGION_USER2, 0 )	/* TMS320C31 sound ROMs */
+	ROM_REGION32_LE( 0x1000000, "cage", 0 )	/* TMS320C31 sound ROMs */
 	ROM_LOAD32_WORD( "0077",  0x400000, 0x200000, CRC(8f650f8b) SHA1(e3b48ff4e2093d709134b6bf62cecd101ab5cef4) )
 	ROM_LOAD32_BYTE( "2501a", 0x400002, 0x080000, CRC(98e51103) SHA1(420d0aac6b1de1bd990b9e4219041192400299f8) )
 	ROM_LOAD32_BYTE( "2500a", 0x400003, 0x080000, CRC(49c0136c) SHA1(1ad463b1e50df9843abb8c645cbe8a79e42cbb87) )
@@ -859,7 +833,7 @@ ROM_START( tmek )
 	ROM_LOAD32_WORD( "0076",  0x800000, 0x200000, CRC(74dffe2d) SHA1(9436f69827050ad2f3be58f1cb57d7a06b75ab61) )
 	ROM_LOAD32_WORD( "0074",  0x800002, 0x200000, CRC(8dfc6ce0) SHA1(5b0d4dd4cb7934f542e67217a2542a3c69558cea) )
 
-	ROM_REGION( 0x300000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x300000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "0250",  0x000000, 0x80000, CRC(56bd9f25) SHA1(a8161aeee274f28c41f82b6b3f63570970ee281d) ) /* playfield, planes 0-1 */
 	ROM_LOAD( "0253a", 0x080000, 0x80000, CRC(23e2f83d) SHA1(804a17ce8768bd48cda853e55fc1f54ed7475968) )
 	ROM_LOAD( "0251",  0x100000, 0x80000, CRC(0d3b08f7) SHA1(72ec2383011ef20e9054594279cc85fa55c3a9b2) ) /* playfield, planes 2-3 */
@@ -867,10 +841,10 @@ ROM_START( tmek )
 	ROM_LOAD( "0252",  0x200000, 0x80000, CRC(95a1c23b) SHA1(74eb69dcaebd7a7a03d8f7c9bf6183ece695e91d) ) /* playfield, planes 4-5 */
 	ROM_LOAD( "0255a", 0x280000, 0x80000, CRC(f0fbb700) SHA1(3f0355b137f6426a07abab77f25e718c6102a16f) )
 
-	ROM_REGION( 0x020000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x020000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "0045a", 0x000000, 0x20000, CRC(057a5304) SHA1(d44c0cf885a1324888b7e8118f124c0dae616859) ) /* alphanumerics */
 
-	ROM_REGION16_BE( 0x1000000, REGION_GFX3, 0 )
+	ROM_REGION16_BE( 0x1000000, "gfx3", 0 )
 	ROM_LOAD16_BYTE( "0300", 0x000001, 0x100000, CRC(8367ddac) SHA1(9ca77962259284cef8a261b652ab1327817ee8d0) )
 	ROM_LOAD16_BYTE( "0301", 0x000000, 0x100000, CRC(94524b5b) SHA1(db401fd7ba56658fcb614406672c02569d845930) )
 	ROM_LOAD16_BYTE( "0302", 0x200001, 0x100000, CRC(c03f1aa7) SHA1(c68b52280d0695629c843b9c90f7a39713e063b0) )
@@ -888,7 +862,7 @@ ROM_START( tmek )
 	ROM_LOAD16_BYTE( "0314", 0xe00001, 0x100000, CRC(4f01db8d) SHA1(c18c72f1ccbe6ff18576592548c960f9ce357016) )
 	ROM_LOAD16_BYTE( "0315", 0xe00000, 0x100000, CRC(28e97d06) SHA1(ef115f393c568822cb2cb3cca92c7656e1ee07f9) )
 
-	ROM_REGION( 0x0600, REGION_PROMS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0600, "proms", ROMREGION_DISPOSE )
 	ROM_LOAD( "0001a",  0x0000, 0x0200, CRC(a70ade3f) SHA1(f4a558b17767eed2683c768d1b441e75edcff967) )	/* microcode for growth renderer */
 	ROM_LOAD( "0001b",  0x0200, 0x0200, CRC(f4768b4d) SHA1(a506fa5386ab0ea2851ff1f8474d4bfc66deaa70) )
 	ROM_LOAD( "0001c",  0x0400, 0x0200, CRC(22a76ad4) SHA1(ce840c283bbd3a5f19dc8d91b19d1571eff51ff4) )
@@ -896,16 +870,16 @@ ROM_END
 
 
 ROM_START( tmekprot )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 )	/* 8*64k for 68000 code */
+	ROM_REGION( 0x200000, "main", 0 )	/* 8*64k for 68000 code */
 	ROM_LOAD32_BYTE( "pgm0", 0x00000, 0x20000, CRC(f5f7f7be) SHA1(66be472e7c0ef26e2ce2b45488a8e4cfc1b0f80a) )
 	ROM_LOAD32_BYTE( "pgm1", 0x00001, 0x20000, CRC(284f7971) SHA1(5327f6368abd2ab9740a5150a8660c420f750476) )
 	ROM_LOAD32_BYTE( "pgm2", 0x00002, 0x20000, CRC(ce9a77d4) SHA1(025143b59d85180286086940b05c8e5ea0b4a7fe) )
 	ROM_LOAD32_BYTE( "pgm3", 0x00003, 0x20000, CRC(28b0e210) SHA1(7567671beecc7d30e9d4b61cf7d3448bb1dbb072) )
 
-	ROM_REGION32_LE( 0x200000, REGION_USER1, 0 )	/* TMS320C31 boot ROM */
+	ROM_REGION32_LE( 0x200000, "cageboot", 0 )	/* TMS320C31 boot ROM */
 	ROM_LOAD32_BYTE( "0078c", 0x000000, 0x080000, NO_DUMP CRC(ff5b979a) SHA1(deb8ee454b6b7c7bddb2ba0c808869e45b19e55f) )
 
-	ROM_REGION32_LE( 0x1000000, REGION_USER2, 0 )	/* TMS320C31 sound ROMs */
+	ROM_REGION32_LE( 0x1000000, "cage", 0 )	/* TMS320C31 sound ROMs */
 	ROM_LOAD32_WORD( "0077",  0x400000, 0x200000, CRC(8f650f8b) SHA1(e3b48ff4e2093d709134b6bf62cecd101ab5cef4) )
 	ROM_LOAD32_BYTE( "2501a", 0x400002, 0x080000, CRC(98e51103) SHA1(420d0aac6b1de1bd990b9e4219041192400299f8) )
 	ROM_LOAD32_BYTE( "2500a", 0x400003, 0x080000, CRC(49c0136c) SHA1(1ad463b1e50df9843abb8c645cbe8a79e42cbb87) )
@@ -914,7 +888,7 @@ ROM_START( tmekprot )
 	ROM_LOAD32_WORD( "0076",  0x800000, 0x200000, CRC(74dffe2d) SHA1(9436f69827050ad2f3be58f1cb57d7a06b75ab61) )
 	ROM_LOAD32_WORD( "0074",  0x800002, 0x200000, CRC(8dfc6ce0) SHA1(5b0d4dd4cb7934f542e67217a2542a3c69558cea) )
 
-	ROM_REGION( 0x300000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x300000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "0250",  0x000000, 0x80000, CRC(56bd9f25) SHA1(a8161aeee274f28c41f82b6b3f63570970ee281d) ) /* playfield, planes 0-1 */
 	ROM_LOAD( "0253a", 0x080000, 0x80000, CRC(23e2f83d) SHA1(804a17ce8768bd48cda853e55fc1f54ed7475968) )
 	ROM_LOAD( "0251",  0x100000, 0x80000, CRC(0d3b08f7) SHA1(72ec2383011ef20e9054594279cc85fa55c3a9b2) ) /* playfield, planes 2-3 */
@@ -922,10 +896,10 @@ ROM_START( tmekprot )
 	ROM_LOAD( "0252",  0x200000, 0x80000, CRC(95a1c23b) SHA1(74eb69dcaebd7a7a03d8f7c9bf6183ece695e91d) ) /* playfield, planes 4-5 */
 	ROM_LOAD( "0255a", 0x280000, 0x80000, CRC(f0fbb700) SHA1(3f0355b137f6426a07abab77f25e718c6102a16f) )
 
-	ROM_REGION( 0x020000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x020000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "alpha", 0x000000, 0x20000, CRC(8f57a604) SHA1(f076636430ff73ea11e4687ef7b21a7bac1d8e34) ) /* alphanumerics */
 
-	ROM_REGION16_BE( 0x1000000, REGION_GFX3, 0 )
+	ROM_REGION16_BE( 0x1000000, "gfx3", 0 )
 	ROM_LOAD16_BYTE( "0300", 0x000001, 0x100000, CRC(8367ddac) SHA1(9ca77962259284cef8a261b652ab1327817ee8d0) )
 	ROM_LOAD16_BYTE( "0301", 0x000000, 0x100000, CRC(94524b5b) SHA1(db401fd7ba56658fcb614406672c02569d845930) )
 	ROM_LOAD16_BYTE( "0302", 0x200001, 0x100000, CRC(c03f1aa7) SHA1(c68b52280d0695629c843b9c90f7a39713e063b0) )
@@ -943,7 +917,7 @@ ROM_START( tmekprot )
 	ROM_LOAD16_BYTE( "0314", 0xe00001, 0x100000, CRC(4f01db8d) SHA1(c18c72f1ccbe6ff18576592548c960f9ce357016) )
 	ROM_LOAD16_BYTE( "0315", 0xe00000, 0x100000, CRC(28e97d06) SHA1(ef115f393c568822cb2cb3cca92c7656e1ee07f9) )
 
-	ROM_REGION( 0x0600, REGION_PROMS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0600, "proms", ROMREGION_DISPOSE )
 	ROM_LOAD( "0001a",  0x0000, 0x0200, CRC(a70ade3f) SHA1(f4a558b17767eed2683c768d1b441e75edcff967) )	/* microcode for growth renderer */
 	ROM_LOAD( "0001b",  0x0200, 0x0200, CRC(f4768b4d) SHA1(a506fa5386ab0ea2851ff1f8474d4bfc66deaa70) )
 	ROM_LOAD( "0001c",  0x0400, 0x0200, CRC(22a76ad4) SHA1(ce840c283bbd3a5f19dc8d91b19d1571eff51ff4) )
@@ -951,28 +925,28 @@ ROM_END
 
 
 ROM_START( primrage )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 )	/* 8*64k for 68000 code */
+	ROM_REGION( 0x200000, "main", 0 )	/* 8*64k for 68000 code */
 	ROM_LOAD32_BYTE( "1044b", 0x000000, 0x80000, CRC(35c9c34b) SHA1(4bd1d35cc7c68574819afd648405eedb8db25b4c) )
 	ROM_LOAD32_BYTE( "1043b", 0x000001, 0x80000, CRC(86322829) SHA1(e0e72888def0931d078921f099bae6788738a291) )
 	ROM_LOAD32_BYTE( "1042b", 0x000002, 0x80000, CRC(750e8095) SHA1(4660637136b1a25169d8c43646c8b87081763987) )
 	ROM_LOAD32_BYTE( "1041b", 0x000003, 0x80000, CRC(6a90d283) SHA1(7c18c97cb5e5cdd26a52cd6bc099fbce87055311) )
 
-	ROM_REGION32_LE( 0x200000, REGION_USER1, 0 )	/* TMS320C31 boot ROM */
+	ROM_REGION32_LE( 0x200000, "cageboot", 0 )	/* TMS320C31 boot ROM */
 	ROM_LOAD32_BYTE( "1078a", 0x000000, 0x080000, CRC(0656435f) SHA1(f8e498171e754eb8703dad6b2351509bbb27e06b) )
 
-	ROM_REGION32_LE( 0x1000000, REGION_USER2, 0 )	/* TMS320C31 sound ROMs */
+	ROM_REGION32_LE( 0x1000000, "cage", 0 )	/* TMS320C31 sound ROMs */
 	ROM_LOAD32_WORD( "0075",  0x400000, 0x200000, CRC(b685a88e) SHA1(998b8fe54971f6cd96e4c22b19e3831f29d8172d) )
 	ROM_LOAD32_WORD( "0077",  0x400002, 0x200000, CRC(3283cea8) SHA1(fb7333ca951053a56c501f2ce0eb197c8fcafaf7) )
 
-	ROM_REGION( 0x300000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x300000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "0050a",  0x000000, 0x80000, CRC(66896e8f) SHA1(7675b24c15ca0608f11f2a7b8d70717adb10924c) ) /* playfield, planes 0-1 */
 	ROM_LOAD( "0051a",  0x100000, 0x80000, CRC(fb5b3e7b) SHA1(f43fe4b5c4bbea10da46b60c644f586fb391355d) ) /* playfield, planes 2-3 */
 	ROM_LOAD( "0052a",  0x200000, 0x80000, CRC(cbe38670) SHA1(0780e599007851f6d37cdd8c701d01cb1ae48b9d) ) /* playfield, planes 4-5 */
 
-	ROM_REGION( 0x020000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x020000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "1045b", 0x000000, 0x20000, CRC(1d3260bf) SHA1(85d9db8499cbe180c8d52710f3cfe64453a530ff) ) /* alphanumerics */
 
-	ROM_REGION16_BE( 0x2000000, REGION_GFX3, 0 )
+	ROM_REGION16_BE( 0x2000000, "gfx3", 0 )
 	ROM_LOAD16_BYTE( "1100a", 0x0000001, 0x080000, CRC(6e9c80b5) SHA1(ec724011527dd8707c733211b1a6c51b22f580c7) )
 	ROM_LOAD16_BYTE( "1101a", 0x0000000, 0x080000, CRC(bb7ee624) SHA1(0de6385aee7d25b41fd5bf232e44e5da536504ac) )
 	ROM_LOAD16_BYTE( "0332",  0x0800001, 0x100000, CRC(610cfcb4) SHA1(bed1bd0d11c0a7cc48d020fc0acec34daf48c5ac) )
@@ -1000,7 +974,7 @@ ROM_START( primrage )
 	ROM_LOAD16_BYTE( "0330",  0x1e00001, 0x100000, CRC(7bf6bb8f) SHA1(f34bd8a9c7f95436a1c816badc59673cd2a6969a) )
 	ROM_LOAD16_BYTE( "0331",  0x1e00000, 0x100000, CRC(c6a64dad) SHA1(ee54514463ab61cbaef70da064cf5de591e5861f) )
 
-	ROM_REGION( 0x0600, REGION_PROMS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0600, "proms", ROMREGION_DISPOSE )
 	ROM_LOAD( "0001a",  0x0000, 0x0200, CRC(a70ade3f) SHA1(f4a558b17767eed2683c768d1b441e75edcff967) )	/* microcode for growth renderer */
 	ROM_LOAD( "0001b",  0x0200, 0x0200, CRC(f4768b4d) SHA1(a506fa5386ab0ea2851ff1f8474d4bfc66deaa70) )
 	ROM_LOAD( "0001c",  0x0400, 0x0200, CRC(22a76ad4) SHA1(ce840c283bbd3a5f19dc8d91b19d1571eff51ff4) )
@@ -1008,28 +982,28 @@ ROM_END
 
 
 ROM_START( primraga )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 )	/* 8*64k for 68000 code */
+	ROM_REGION( 0x200000, "main", 0 )	/* 8*64k for 68000 code */
 	ROM_LOAD32_BYTE( "0044b", 0x000000, 0x80000, CRC(26139575) SHA1(22e59ab621d58e56969b64701fc59aec085193dd) )
 	ROM_LOAD32_BYTE( "0043b", 0x000001, 0x80000, CRC(928d2447) SHA1(9bbbdbf056a7b986d985d79be889b9876a710631) )
 	ROM_LOAD32_BYTE( "0042b", 0x000002, 0x80000, CRC(cd6062b9) SHA1(2973fb561ab68cd48ec132b6720c04d10bedfd19) )
 	ROM_LOAD32_BYTE( "0041b", 0x000003, 0x80000, CRC(3008f6f0) SHA1(45aac457b4584ee3bd3561e3b2e34e49aa61fbc5) )
 
-	ROM_REGION32_LE( 0x200000, REGION_USER1, 0 )	/* TMS320C31 boot ROM */
+	ROM_REGION32_LE( 0x200000, "cageboot", 0 )	/* TMS320C31 boot ROM */
 	ROM_LOAD32_BYTE( "0078a", 0x000000, 0x080000, CRC(91df8d8f) SHA1(6d361f88de604b8f11dd9bfe85ff18bcd322862d) )
 
-	ROM_REGION32_LE( 0x1000000, REGION_USER2, 0 )	/* TMS320C31 sound ROMs */
+	ROM_REGION32_LE( 0x1000000, "cage", 0 )	/* TMS320C31 sound ROMs */
 	ROM_LOAD32_WORD( "0075",  0x400000, 0x200000, CRC(b685a88e) SHA1(998b8fe54971f6cd96e4c22b19e3831f29d8172d) )
 	ROM_LOAD32_WORD( "0077",  0x400002, 0x200000, CRC(3283cea8) SHA1(fb7333ca951053a56c501f2ce0eb197c8fcafaf7) )
 
-	ROM_REGION( 0x300000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x300000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "0050a",  0x000000, 0x80000, CRC(66896e8f) SHA1(7675b24c15ca0608f11f2a7b8d70717adb10924c) ) /* playfield, planes 0-1 */
 	ROM_LOAD( "0051a",  0x100000, 0x80000, CRC(fb5b3e7b) SHA1(f43fe4b5c4bbea10da46b60c644f586fb391355d) ) /* playfield, planes 2-3 */
 	ROM_LOAD( "0052a",  0x200000, 0x80000, CRC(cbe38670) SHA1(0780e599007851f6d37cdd8c701d01cb1ae48b9d) ) /* playfield, planes 4-5 */
 
-	ROM_REGION( 0x020000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x020000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "0045a", 0x000000, 0x20000, CRC(c8b39b1c) SHA1(836c0ccf96b2beccacf6d8ac23981fc2d1f09803) ) /* alphanumerics */
 
-	ROM_REGION16_BE( 0x2000000, REGION_GFX3, 0 )
+	ROM_REGION16_BE( 0x2000000, "gfx3", 0 )
 	ROM_LOAD16_BYTE( "0100a", 0x0000001, 0x080000, CRC(5299fb2a) SHA1(791378215ab6ffff3ab2ae7192ce9f88dae4090d) )
 	ROM_LOAD16_BYTE( "0101a", 0x0000000, 0x080000, CRC(3e234711) SHA1(6a9f19db2b4c8c34d3d7b4984206e3d5c4398d7f) )
 	ROM_LOAD16_BYTE( "0332",  0x0800001, 0x100000, CRC(610cfcb4) SHA1(bed1bd0d11c0a7cc48d020fc0acec34daf48c5ac) )
@@ -1057,7 +1031,7 @@ ROM_START( primraga )
 	ROM_LOAD16_BYTE( "0330",  0x1e00001, 0x100000, CRC(7bf6bb8f) SHA1(f34bd8a9c7f95436a1c816badc59673cd2a6969a) )
 	ROM_LOAD16_BYTE( "0331",  0x1e00000, 0x100000, CRC(c6a64dad) SHA1(ee54514463ab61cbaef70da064cf5de591e5861f) )
 
-	ROM_REGION( 0x0600, REGION_PROMS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0600, "proms", ROMREGION_DISPOSE )
 	ROM_LOAD( "0001a",  0x0000, 0x0200, CRC(a70ade3f) SHA1(f4a558b17767eed2683c768d1b441e75edcff967) )	/* microcode for growth renderer */
 	ROM_LOAD( "0001b",  0x0200, 0x0200, CRC(f4768b4d) SHA1(a506fa5386ab0ea2851ff1f8474d4bfc66deaa70) )
 	ROM_LOAD( "0001c",  0x0400, 0x0200, CRC(22a76ad4) SHA1(ce840c283bbd3a5f19dc8d91b19d1571eff51ff4) )
@@ -1073,21 +1047,21 @@ ROM_END
 
 static WRITE32_HANDLER( tmek_pf_w )
 {
-	offs_t pc = activecpu_get_pc();
+	offs_t pc = cpu_get_pc(space->cpu);
 
 	/* protected version */
 	if (pc == 0x2EB3C || pc == 0x2EB48)
 	{
-		logerror("%06X:PFW@%06X = %08X & %08X (src=%06X)\n", activecpu_get_pc(), 0xd72000 + offset*4, data, ~mem_mask, (UINT32)activecpu_get_reg(M68K_A4) - 2);
+		logerror("%06X:PFW@%06X = %08X & %08X (src=%06X)\n", cpu_get_pc(space->cpu), 0xd72000 + offset*4, data, mem_mask, (UINT32)cpu_get_reg(space->cpu, M68K_A4) - 2);
 		/* skip these writes to make more stuff visible */
 		return;
 	}
 
 	/* unprotected version */
 	if (pc == 0x25834 || pc == 0x25860)
-		logerror("%06X:PFW@%06X = %08X & %08X (src=%06X)\n", activecpu_get_pc(), 0xd72000 + offset*4, data, ~mem_mask, (UINT32)activecpu_get_reg(M68K_A3) - 2);
+		logerror("%06X:PFW@%06X = %08X & %08X (src=%06X)\n", cpu_get_pc(space->cpu), 0xd72000 + offset*4, data, mem_mask, (UINT32)cpu_get_reg(space->cpu, M68K_A3) - 2);
 
-	atarigen_playfield32_w(offset, data, mem_mask);
+	atarigen_playfield32_w(space, offset, data, mem_mask);
 }
 
 static DRIVER_INIT( tmek )
@@ -1095,7 +1069,7 @@ static DRIVER_INIT( tmek )
 	atarigen_eeprom_default = NULL;
 	atarigt_is_primrage = 0;
 
-	cage_init(REGION_USER1, 0x4fad);
+	cage_init(machine, 0x4fad);
 	cage_set_irq_handler(cage_irq_callback);
 
 	/* setup protection */
@@ -1103,16 +1077,16 @@ static DRIVER_INIT( tmek )
 	protection_w = tmek_protection_w;
 
 	/* temp hack */
-	memory_install_write32_handler(0, ADDRESS_SPACE_PROGRAM, 0xd72000, 0xd75fff, 0, 0, tmek_pf_w);
+	memory_install_write32_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xd72000, 0xd75fff, 0, 0, tmek_pf_w);
 }
 
 
-static void primrage_init_common(offs_t cage_speedup)
+static void primrage_init_common(running_machine *machine, offs_t cage_speedup)
 {
 	atarigen_eeprom_default = NULL;
 	atarigt_is_primrage = 1;
 
-	cage_init(REGION_USER1, cage_speedup);
+	cage_init(machine, cage_speedup);
 	cage_set_irq_handler(cage_irq_callback);
 
 	/* install protection */
@@ -1120,8 +1094,8 @@ static void primrage_init_common(offs_t cage_speedup)
 	protection_w = primrage_protection_w;
 }
 
-static DRIVER_INIT( primrage ) { primrage_init_common(0x42f2); }
-static DRIVER_INIT( primraga ) { primrage_init_common(0x48a4); }
+static DRIVER_INIT( primrage ) { primrage_init_common(machine, 0x42f2); }
+static DRIVER_INIT( primraga ) { primrage_init_common(machine, 0x48a4); }
 
 
 
