@@ -11,10 +11,7 @@
 */
 
 #define DE156CPU ARM
-extern void decrypt156(void);
-
 #include "driver.h"
-#include "deprecat.h"
 #include "decocrpt.h"
 #include "deco32.h"
 #include "machine/eeprom.h"
@@ -27,8 +24,8 @@ extern void decrypt156(void);
 static UINT32 *backfire_spriteram32_1;
 static UINT32 *backfire_spriteram32_2;
 static UINT32 *backfire_mainram;
-static mame_bitmap * backfire_left;
-static mame_bitmap * backfire_right;
+static bitmap_t *backfire_left;
+static bitmap_t *backfire_right;
 
 //UINT32 *backfire_180010, *backfire_188010;
 static UINT32 *backfire_left_priority, *backfire_right_priority;
@@ -63,18 +60,18 @@ static VIDEO_START(backfire)
 	deco16_pf34_control = auto_malloc(0x10);
 
 	/* and register the allocated ram so that save states still work */
-	state_save_register_global_pointer(deco16_pf1_data, 0x2000/2);
-	state_save_register_global_pointer(deco16_pf2_data, 0x2000/2);
-	state_save_register_global_pointer(deco16_pf3_data, 0x2000/2);
-	state_save_register_global_pointer(deco16_pf4_data, 0x2000/2);
-	state_save_register_global_pointer(deco16_pf1_rowscroll, 0x800/2);
-	state_save_register_global_pointer(deco16_pf2_rowscroll, 0x800/2);
-	state_save_register_global_pointer(deco16_pf3_rowscroll, 0x800/2);
-	state_save_register_global_pointer(deco16_pf4_rowscroll, 0x800/2);
-	state_save_register_global_pointer(deco16_pf12_control, 0x10/2);
-	state_save_register_global_pointer(deco16_pf34_control, 0x10/2);
+	state_save_register_global_pointer(machine, deco16_pf1_data, 0x2000/2);
+	state_save_register_global_pointer(machine, deco16_pf2_data, 0x2000/2);
+	state_save_register_global_pointer(machine, deco16_pf3_data, 0x2000/2);
+	state_save_register_global_pointer(machine, deco16_pf4_data, 0x2000/2);
+	state_save_register_global_pointer(machine, deco16_pf1_rowscroll, 0x800/2);
+	state_save_register_global_pointer(machine, deco16_pf2_rowscroll, 0x800/2);
+	state_save_register_global_pointer(machine, deco16_pf3_rowscroll, 0x800/2);
+	state_save_register_global_pointer(machine, deco16_pf4_rowscroll, 0x800/2);
+	state_save_register_global_pointer(machine, deco16_pf12_control, 0x10/2);
+	state_save_register_global_pointer(machine, deco16_pf34_control, 0x10/2);
 
-	deco16_2_video_init(0);
+	deco16_2_video_init(machine, 0);
 
 	deco16_pf1_colour_bank = 0x00;
 	deco16_pf2_colour_bank = 0x40;
@@ -90,11 +87,11 @@ static VIDEO_START(backfire)
 	backfire_right = auto_bitmap_alloc(80*8, 32*8, BITMAP_FORMAT_INDEXED16);
 }
 
-static void draw_sprites(running_machine *machine,mame_bitmap *bitmap,const rectangle *cliprect, UINT32 *backfire_spriteram32, int region)
+static void draw_sprites(running_machine *machine,bitmap_t *bitmap,const rectangle *cliprect, UINT32 *backfire_spriteram32, int region)
 {
 	int offs;
 
-	flip_screen = 1;
+	flip_screen_set_no_update(machine, 1);
 
 	for (offs = (0x1400/4)-4;offs >= 0;offs -= 4) // 0x1400 for charlien
 	{
@@ -104,7 +101,7 @@ static void draw_sprites(running_machine *machine,mame_bitmap *bitmap,const rect
 
 		y = backfire_spriteram32[offs]&0xffff;
 		flash=y&0x1000;
-		if (flash && (cpu_getcurrentframe() & 1)) continue;
+		if (flash && (video_screen_get_frame_number(machine->primary_screen) & 1)) continue;
 
 		x = backfire_spriteram32[offs+2]&0xffff;
 		colour = (x >>9) & 0x1f;
@@ -144,7 +141,7 @@ static void draw_sprites(running_machine *machine,mame_bitmap *bitmap,const rect
 			inc = 1;
 		}
 
-		if (flip_screen)
+		if (flip_screen_x_get(machine))
 		{
 			y=240-y;
 			x=304-x;
@@ -172,56 +169,55 @@ static void draw_sprites(running_machine *machine,mame_bitmap *bitmap,const rect
 
 static VIDEO_UPDATE(backfire)
 {
+	const device_config *left_screen = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "left");
+	const device_config *right_screen = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "right");
+
 	/* screen 1 uses pf1 as the forground and pf3 as the background */
 	/* screen 2 uses pf2 as the foreground and pf4 as the background */
 
 	deco16_pf12_update(deco16_pf1_rowscroll,deco16_pf2_rowscroll);
 	deco16_pf34_update(deco16_pf3_rowscroll,deco16_pf4_rowscroll);
 
-	if (screen==0)
+	if (screen == left_screen)
 	{
 
-		fillbitmap(priority_bitmap,0,NULL);
-		fillbitmap(bitmap,machine->pens[0x100],cliprect);
+		bitmap_fill(priority_bitmap,NULL,0);
+		bitmap_fill(bitmap,cliprect,0x100);
 
 		if (backfire_left_priority[0] == 0)
 		{
-			deco16_tilemap_3_draw(bitmap,cliprect,0,1);
-			deco16_tilemap_1_draw(bitmap,cliprect,0,2);
-			draw_sprites(machine,bitmap,cliprect,backfire_spriteram32_1,3);
+			deco16_tilemap_3_draw(screen,bitmap,cliprect,0,1);
+			deco16_tilemap_1_draw(screen,bitmap,cliprect,0,2);
+			draw_sprites(screen->machine,bitmap,cliprect,backfire_spriteram32_1,3);
 		}
 		else if (backfire_left_priority[0] == 2)
 		{
-			deco16_tilemap_1_draw(bitmap,cliprect,0,2);
-			deco16_tilemap_3_draw(bitmap,cliprect,0,4);
-			draw_sprites(machine,bitmap,cliprect,backfire_spriteram32_1,3);
+			deco16_tilemap_1_draw(screen,bitmap,cliprect,0,2);
+			deco16_tilemap_3_draw(screen,bitmap,cliprect,0,4);
+			draw_sprites(screen->machine,bitmap,cliprect,backfire_spriteram32_1,3);
 		}
 		else
-		{
 			popmessage( "unknown left priority %08x", backfire_left_priority[0] );
-		}
 	}
-	else if (screen==1)
+	else if (screen == right_screen)
 	{
-		fillbitmap(priority_bitmap,0,NULL);
-		fillbitmap(bitmap,machine->pens[0x500],cliprect);
+		bitmap_fill(priority_bitmap,NULL,0);
+		bitmap_fill(bitmap,cliprect,0x500);
 
 		if (backfire_right_priority[0] == 0)
 		{
-			deco16_tilemap_4_draw(bitmap,cliprect,0,1);
-			deco16_tilemap_2_draw(bitmap,cliprect,0,2);
-			draw_sprites(machine,bitmap,cliprect,backfire_spriteram32_2,4);
+			deco16_tilemap_4_draw(screen,bitmap,cliprect,0,1);
+			deco16_tilemap_2_draw(screen,bitmap,cliprect,0,2);
+			draw_sprites(screen->machine,bitmap,cliprect,backfire_spriteram32_2,4);
 		}
 		else if (backfire_right_priority[0] == 2)
 		{
-			deco16_tilemap_2_draw(bitmap,cliprect,0,2);
-			deco16_tilemap_4_draw(bitmap,cliprect,0,4);
-			draw_sprites(machine,bitmap,cliprect,backfire_spriteram32_2,4);
+			deco16_tilemap_2_draw(screen,bitmap,cliprect,0,2);
+			deco16_tilemap_4_draw(screen,bitmap,cliprect,0,4);
+			draw_sprites(screen->machine,bitmap,cliprect,backfire_spriteram32_2,4);
 		}
 		else
-		{
 			popmessage( "unknown right priority %08x", backfire_right_priority[0] );
-		}
 	}
 	return 0;
 }
@@ -231,32 +227,34 @@ static VIDEO_UPDATE(backfire)
 static READ32_HANDLER(backfire_eeprom_r)
 {
 	/* some kind of screen indicator?  checked by backfira set before it will boot */
-	int backfire_screen = mame_rand(Machine)&1;
-	return ((EEPROM_read_bit()<<24) | readinputport(0) | (readinputport(3)<<16)) ^  (backfire_screen << 26) ;
+	int backfire_screen = mame_rand(space->machine)&1;
+	return ((eeprom_read_bit()<<24) | input_port_read(space->machine, "IN0")
+			| ((input_port_read(space->machine, "IN2") & ~0x40) <<16)
+			| ((input_port_read(space->machine, "IN3") &  0x40) <<16)) ^  (backfire_screen << 26) ;
 }
 
 static READ32_HANDLER(backfire_control2_r)
 {
-//  logerror("%08x:Read eprom %08x (%08x)\n",activecpu_get_pc(),offset<<1,mem_mask);
-	return (EEPROM_read_bit()<<24) | readinputport(1) | (readinputport(1)<<16);
+//  logerror("%08x:Read eprom %08x (%08x)\n",cpu_get_pc(space->cpu),offset<<1,mem_mask);
+	return (eeprom_read_bit()<<24) | input_port_read(space->machine, "IN1") | (input_port_read(space->machine, "IN1")<<16);
 }
 
 #ifdef UNUSED_FUNCTION
 static READ32_HANDLER(backfire_control3_r)
 {
-//  logerror("%08x:Read eprom %08x (%08x)\n",activecpu_get_pc(),offset<<1,mem_mask);
-	return (EEPROM_read_bit()<<24) | readinputport(2) | (readinputport(2)<<16);
+//  logerror("%08x:Read eprom %08x (%08x)\n",cpu_get_pc(space->cpu),offset<<1,mem_mask);
+	return (eeprom_read_bit()<<24) | input_port_read(space->machine, "IN2") | (input_port_read(space->machine, "IN2")<<16);
 }
 #endif
 
 
 static WRITE32_HANDLER(backfire_eeprom_w)
 {
-	logerror("%08x:write eprom %08x (%08x) %08x\n",activecpu_get_pc(),offset<<1,mem_mask,data);
-	if (ACCESSING_LSB32) {
-		EEPROM_set_clock_line((data & 0x2) ? ASSERT_LINE : CLEAR_LINE);
-		EEPROM_write_bit(data & 0x1);
-		EEPROM_set_cs_line((data & 0x4) ? CLEAR_LINE : ASSERT_LINE);
+	logerror("%08x:write eprom %08x (%08x) %08x\n",cpu_get_pc(space->cpu),offset<<1,mem_mask,data);
+	if (ACCESSING_BITS_0_7) {
+		eeprom_set_clock_line((data & 0x2) ? ASSERT_LINE : CLEAR_LINE);
+		eeprom_write_bit(data & 0x1);
+		eeprom_set_cs_line((data & 0x4) ? CLEAR_LINE : ASSERT_LINE);
 	}
 }
 
@@ -264,21 +262,21 @@ static WRITE32_HANDLER(backfire_eeprom_w)
 static WRITE32_HANDLER(wcvol95_nonbuffered_palette_w)
 {
 	COMBINE_DATA(&paletteram32[offset]);
-	palette_set_color_rgb(Machine,offset,pal5bit(paletteram32[offset] >> 0),pal5bit(paletteram32[offset] >> 5),pal5bit(paletteram32[offset] >> 10));
+	palette_set_color_rgb(space->machine,offset,pal5bit(paletteram32[offset] >> 0),pal5bit(paletteram32[offset] >> 5),pal5bit(paletteram32[offset] >> 10));
 }
 
 
 static READ32_HANDLER( deco156_snd_r )
 {
-	return YMZ280B_status_0_r(0);
+	return ymz280b_status_0_r(space, 0);
 }
 
 static WRITE32_HANDLER( deco156_snd_w )
 {
 	if (offset)
-		YMZ280B_data_0_w(0, data);
+		ymz280b_data_0_w(space, 0, data);
 	else
-		YMZ280B_register_0_w(0, data);
+		ymz280b_register_0_w(space, 0, data);
 }
 
 /* map 32-bit writes to 16-bit */
@@ -299,25 +297,25 @@ static READ32_HANDLER( backfire_pf1_data_r ) {	return deco16_pf1_data[offset]^0x
 static READ32_HANDLER( backfire_pf2_data_r ) {	return deco16_pf2_data[offset]^0xffff0000; }
 static READ32_HANDLER( backfire_pf3_data_r ) {	return deco16_pf3_data[offset]^0xffff0000; }
 static READ32_HANDLER( backfire_pf4_data_r ) {	return deco16_pf4_data[offset]^0xffff0000; }
-static WRITE32_HANDLER( backfire_pf1_data_w ) { data &=0x0000ffff; mem_mask &=0x0000ffff; deco16_pf1_data_w(offset,data,mem_mask); }
-static WRITE32_HANDLER( backfire_pf2_data_w ) { data &=0x0000ffff; mem_mask &=0x0000ffff; deco16_pf2_data_w(offset,data,mem_mask); }
-static WRITE32_HANDLER( backfire_pf3_data_w ) { data &=0x0000ffff; mem_mask &=0x0000ffff; deco16_pf3_data_w(offset,data,mem_mask); }
-static WRITE32_HANDLER( backfire_pf4_data_w ) { data &=0x0000ffff; mem_mask &=0x0000ffff; deco16_pf4_data_w(offset,data,mem_mask); }
+static WRITE32_HANDLER( backfire_pf1_data_w ) { data &=0x0000ffff; mem_mask &=0x0000ffff; deco16_pf1_data_w(space,offset,data,mem_mask); }
+static WRITE32_HANDLER( backfire_pf2_data_w ) { data &=0x0000ffff; mem_mask &=0x0000ffff; deco16_pf2_data_w(space,offset,data,mem_mask); }
+static WRITE32_HANDLER( backfire_pf3_data_w ) { data &=0x0000ffff; mem_mask &=0x0000ffff; deco16_pf3_data_w(space,offset,data,mem_mask); }
+static WRITE32_HANDLER( backfire_pf4_data_w ) { data &=0x0000ffff; mem_mask &=0x0000ffff; deco16_pf4_data_w(space,offset,data,mem_mask); }
 
 #ifdef UNUSED_FUNCTION
 READ32_HANDLER( backfire_unknown_wheel_r )
 {
-	return readinputport(4);
+	return input_port_read(space->machine, "PADDLE0");
 }
 
 READ32_HANDLER( backfire_wheel1_r )
 {
-	return mame_rand(Machine);
+	return mame_rand(space->machine);
 }
 
 READ32_HANDLER( backfire_wheel2_r )
 {
-	return mame_rand(Machine);
+	return mame_rand(space->machine);
 }
 #endif
 
@@ -348,7 +346,7 @@ static ADDRESS_MAP_START( backfire_map, ADDRESS_SPACE_PROGRAM, 32 )
 
 	AM_RANGE(0x1a8000, 0x1a8003) AM_RAM AM_BASE(&backfire_left_priority)
 	AM_RANGE(0x1ac000, 0x1ac003) AM_RAM AM_BASE(&backfire_right_priority)
-//  AM_RANGE(0x1b0000, 0x1b0003) AM_WRITE(MWA32_NOP) // always 1b0000
+//  AM_RANGE(0x1b0000, 0x1b0003) AM_WRITE(SMH_NOP) // always 1b0000
 
 	/* when set to pentometer in test mode */
 //  AM_RANGE(0x1e4000, 0x1e4003) AM_READ(backfire_unknown_wheel_r)
@@ -360,7 +358,7 @@ ADDRESS_MAP_END
 
 
 static INPUT_PORTS_START( backfire )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
@@ -370,7 +368,7 @@ static INPUT_PORTS_START( backfire )
 	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_START1 )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
@@ -380,11 +378,11 @@ static INPUT_PORTS_START( backfire )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2)
+	PORT_SERVICE_NO_TOGGLE( 0x0008, IP_ACTIVE_LOW )
 	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, IPT_VBLANK )
 	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_UNUSED ) /* 'soundmask' */
 	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_UNUSED )
@@ -398,23 +396,18 @@ static INPUT_PORTS_START( backfire )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_BUTTON6 ) PORT_PLAYER(2)
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2)
-	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, IPT_VBLANK )
-	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_UNUSED ) /* 'soundmask' */
+	PORT_START("IN3")
+	PORT_BIT( 0x003f, IP_ACTIVE_LOW, IPT_UNUSED ) /* all other bits like low IN2 */
 	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_VBLANK )
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("PADDLE0")
 	PORT_BIT ( 0x00ff, 0x0080, IPT_PADDLE ) PORT_SENSITIVITY(30) PORT_KEYDELTA(1)
 
-	PORT_START
+	PORT_START("PADDLE1")
 	PORT_BIT ( 0x00ff, 0x0080, IPT_PADDLE ) PORT_SENSITIVITY(30) PORT_KEYDELTA(1)
 
-	PORT_START
+	PORT_START("UNK")
 	/* ?? */
 INPUT_PORTS_END
 
@@ -458,28 +451,27 @@ static const gfx_layout tilelayout =
 
 
 static GFXDECODE_START( backfire )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, charlayout,      0, 128 )	/* Characters 8x8 */
-	GFXDECODE_ENTRY( REGION_GFX1, 0, tilelayout,      0, 128 )	/* Tiles 16x16 */
-	GFXDECODE_ENTRY( REGION_GFX2, 0, tilelayout,      0, 128 )	/* Tiles 16x16 */
-	GFXDECODE_ENTRY( REGION_GFX3, 0, spritelayout,    0x200, 32 )	/* Sprites 16x16 (screen 1) */
-	GFXDECODE_ENTRY( REGION_GFX4, 0, spritelayout,    0x600, 32 )	/* Sprites 16x16 (screen 2) */
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout,      0, 128 )	/* Characters 8x8 */
+	GFXDECODE_ENTRY( "gfx1", 0, tilelayout,      0, 128 )	/* Tiles 16x16 */
+	GFXDECODE_ENTRY( "gfx2", 0, tilelayout,      0, 128 )	/* Tiles 16x16 */
+	GFXDECODE_ENTRY( "gfx3", 0, spritelayout,    0x200, 32 )	/* Sprites 16x16 (screen 1) */
+	GFXDECODE_ENTRY( "gfx4", 0, spritelayout,    0x600, 32 )	/* Sprites 16x16 (screen 2) */
 GFXDECODE_END
 
 
-static void sound_irq_gen(int state)
+static void sound_irq_gen(running_machine *machine, int state)
 {
 	logerror("sound irq\n");
 }
 
-static const struct YMZ280Binterface ymz280b_intf =
+static const ymz280b_interface ymz280b_intf =
 {
-	REGION_SOUND1,
 	sound_irq_gen
 };
 
 static INTERRUPT_GEN( deco32_vbl_interrupt )
 {
-	cpunum_set_input_line(machine, 0, ARM_IRQ_LINE, HOLD_LINE);
+	cpu_set_input_line(device, ARM_IRQ_LINE, HOLD_LINE);
 }
 
 
@@ -487,31 +479,28 @@ static INTERRUPT_GEN( deco32_vbl_interrupt )
 static MACHINE_DRIVER_START( backfire )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(ARM, 28000000/4) /* Unconfirmed */
+	MDRV_CPU_ADD("main", ARM, 28000000/4) /* Unconfirmed */
 	MDRV_CPU_PROGRAM_MAP(backfire_map,0)
-	MDRV_CPU_VBLANK_INT(deco32_vbl_interrupt,1)
+	MDRV_CPU_VBLANK_INT("left", deco32_vbl_interrupt)	/* or is it "right?" */
 
-	MDRV_SCREEN_REFRESH_RATE(58)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(529))
 	MDRV_NVRAM_HANDLER(93C46)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_PALETTE_LENGTH(2048)
 	MDRV_GFXDECODE(backfire)
 	MDRV_DEFAULT_LAYOUT(layout_dualhsxs)
 
-	MDRV_SCREEN_ADD("left", 0x000)
+	MDRV_SCREEN_ADD("left", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_SIZE(40*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
 
-	MDRV_SCREEN_ADD("right", 0x000)
+	MDRV_SCREEN_ADD("right", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_SIZE(40*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 1*8, 31*8-1)
 
@@ -521,7 +510,7 @@ static MACHINE_DRIVER_START( backfire )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(YMZ280B, 28000000 / 2)
+	MDRV_SOUND_ADD("ymz", YMZ280B, 28000000 / 2)
 	MDRV_SOUND_CONFIG(ymz280b_intf)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
@@ -583,11 +572,11 @@ TSW1: Push Button TEST switch to access options menu (coins/lives etc).
 */
 
 ROM_START( backfire )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* DE156 code (encrypted) */
+	ROM_REGION( 0x100000, "main", 0 ) /* DE156 code (encrypted) */
 	ROM_LOAD32_WORD( "ra00-0.2j",    0x000002, 0x080000, CRC(790da069) SHA1(84fd90fb1833b97459cb337fdb92f7b6e93b5936) )
 	ROM_LOAD32_WORD( "ra01-0.3j",    0x000000, 0x080000, CRC(447cb57b) SHA1(1d503b9cf1cadd3fdd7c9d6d59d4c40a59fa25ab))
 
-	ROM_REGION( 0x400000, REGION_GFX1, ROMREGION_DISPOSE ) /* Tiles 1 */
+	ROM_REGION( 0x400000, "gfx1", ROMREGION_DISPOSE ) /* Tiles 1 */
 	ROM_LOAD( "mbz-00.9a",    0x000000, 0x080000, CRC(1098d504) SHA1(1fecd26b92faffce0b59a8a9646bfd457c17c87c) )
 	ROM_CONTINUE( 0x200000, 0x080000)
 	ROM_CONTINUE( 0x100000, 0x080000)
@@ -597,33 +586,33 @@ ROM_START( backfire )
 	ROM_CONTINUE( 0x180000, 0x080000)
 	ROM_CONTINUE( 0x380000, 0x080000)
 
-	ROM_REGION( 0x100000, REGION_GFX2, ROMREGION_DISPOSE ) /* Tiles 2 */
+	ROM_REGION( 0x100000, "gfx2", ROMREGION_DISPOSE ) /* Tiles 2 */
 	ROM_LOAD( "mbz-02.12a",    0x000000, 0x100000, CRC(2bd2b0a1) SHA1(8fcb37728f3248ad55e48f2d398b014b36c9ec05) )
 
-	ROM_REGION( 0x400000, REGION_GFX3, ROMREGION_DISPOSE ) /* Sprites 1 */
+	ROM_REGION( 0x400000, "gfx3", ROMREGION_DISPOSE ) /* Sprites 1 */
 	ROM_LOAD16_BYTE( "mbz-03.15a",    0x000001, 0x200000, CRC(2e818569) SHA1(457c1cad25d9b21459262be8b5788969f566a996) )
 	ROM_LOAD16_BYTE( "mbz-04.16a",    0x000000, 0x200000, CRC(67bdafb1) SHA1(9729c18f3153e4bba703a6f46ad0b886c52d84e2) )
 
-	ROM_REGION( 0x400000, REGION_GFX4, ROMREGION_DISPOSE ) /* Sprites 2 */
+	ROM_REGION( 0x400000, "gfx4", ROMREGION_DISPOSE ) /* Sprites 2 */
 	ROM_LOAD16_BYTE( "mbz-03.18a",    0x000001, 0x200000, CRC(2e818569) SHA1(457c1cad25d9b21459262be8b5788969f566a996) )
 	ROM_LOAD16_BYTE( "mbz-04.19a",    0x000000, 0x200000, CRC(67bdafb1) SHA1(9729c18f3153e4bba703a6f46ad0b886c52d84e2) )
 
-	ROM_REGION( 0x400000, REGION_SOUND1, ROMREGION_ERASEFF ) /* samples */
+	ROM_REGION( 0x400000, "ymz", ROMREGION_ERASEFF ) /* samples */
 	ROM_LOAD( "mbz-05.17l",    0x000000, 0x200000,  CRC(947c1da6) SHA1(ac36006e04dc5e3990f76539763cc76facd08376) )
 	ROM_LOAD( "mbz-06.19l",    0x200000, 0x080000,  CRC(4a38c635) SHA1(7f0fb6a7a4aa6774c04fa38e53ceff8744fe1e9f) )
 
-	ROM_REGION( 0x0600, REGION_PLDS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0600, "plds", ROMREGION_DISPOSE )
 	ROM_LOAD( "gal16v8b.6b",  0x0000, 0x0117, NO_DUMP ) /* PAL is read protected */
 	ROM_LOAD( "gal16v8b.6d",  0x0200, 0x0117, NO_DUMP ) /* PAL is read protected */
 	ROM_LOAD( "gal16v8b.12n", 0x0400, 0x0117, NO_DUMP ) /* PAL is read protected */
 ROM_END
 
 ROM_START( backfira )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* DE156 code (encrypted) */
+	ROM_REGION( 0x100000, "main", 0 ) /* DE156 code (encrypted) */
 	ROM_LOAD32_WORD( "rb-00h.h2",    0x000002, 0x080000, CRC(60973046) SHA1(e70d9be9cb172920da2a2ac9d317768b1438c59d) )
 	ROM_LOAD32_WORD( "rb-01l.h3",    0x000000, 0x080000, CRC(27472f60) SHA1(d73b1e68dc51e28b1148db39ce22bd2e93f6fd0a) )
 
-	ROM_REGION( 0x400000, REGION_GFX1, ROMREGION_DISPOSE ) /* Tiles 1 */
+	ROM_REGION( 0x400000, "gfx1", ROMREGION_DISPOSE ) /* Tiles 1 */
 	ROM_LOAD( "mbz-00.9a",    0x000000, 0x080000, CRC(1098d504) SHA1(1fecd26b92faffce0b59a8a9646bfd457c17c87c) )
 	ROM_CONTINUE( 0x200000, 0x080000)
 	ROM_CONTINUE( 0x100000, 0x080000)
@@ -633,25 +622,25 @@ ROM_START( backfira )
 	ROM_CONTINUE( 0x180000, 0x080000)
 	ROM_CONTINUE( 0x380000, 0x080000)
 
-	ROM_REGION( 0x100000, REGION_GFX2, ROMREGION_DISPOSE ) /* Tiles 2 */
+	ROM_REGION( 0x100000, "gfx2", ROMREGION_DISPOSE ) /* Tiles 2 */
 	ROM_LOAD( "mbz-02.12a",    0x000000, 0x100000, CRC(2bd2b0a1) SHA1(8fcb37728f3248ad55e48f2d398b014b36c9ec05) )
 
-	ROM_REGION( 0x400000, REGION_GFX3, ROMREGION_DISPOSE ) /* Sprites 1 */
+	ROM_REGION( 0x400000, "gfx3", ROMREGION_DISPOSE ) /* Sprites 1 */
 	ROM_LOAD16_BYTE( "mbz-03.15a",    0x000001, 0x200000, CRC(2e818569) SHA1(457c1cad25d9b21459262be8b5788969f566a996) )
 	ROM_LOAD16_BYTE( "mbz-04.16a",    0x000000, 0x200000, CRC(67bdafb1) SHA1(9729c18f3153e4bba703a6f46ad0b886c52d84e2) )
 
-	ROM_REGION( 0x400000, REGION_GFX4, ROMREGION_DISPOSE ) /* Sprites 2 */
+	ROM_REGION( 0x400000, "gfx4", ROMREGION_DISPOSE ) /* Sprites 2 */
 	ROM_LOAD16_BYTE( "mbz-03.18a",    0x000001, 0x200000, CRC(2e818569) SHA1(457c1cad25d9b21459262be8b5788969f566a996) )
 	ROM_LOAD16_BYTE( "mbz-04.19a",    0x000000, 0x200000, CRC(67bdafb1) SHA1(9729c18f3153e4bba703a6f46ad0b886c52d84e2) )
 
-	ROM_REGION( 0x400000, REGION_SOUND1, ROMREGION_ERASEFF ) /* samples */
+	ROM_REGION( 0x400000, "ymz", ROMREGION_ERASEFF ) /* samples */
 	ROM_LOAD( "mbz-05.17l",    0x000000, 0x200000,  CRC(947c1da6) SHA1(ac36006e04dc5e3990f76539763cc76facd08376) )
 	ROM_LOAD( "mbz-06.19l",    0x200000, 0x080000,  CRC(4a38c635) SHA1(7f0fb6a7a4aa6774c04fa38e53ceff8744fe1e9f) )
 ROM_END
 
-static void descramble_sound( void )
+static void descramble_sound( running_machine *machine )
 {
-	UINT8 *rom = memory_region(REGION_SOUND1);
+	UINT8 *rom = memory_region(machine, "ymz");
 	int length = 0x200000; // only the first rom is swapped on backfire!
 	UINT8 *buf1 = malloc_or_die(length);
 	UINT32 x;
@@ -677,10 +666,10 @@ static void descramble_sound( void )
 
 static READ32_HANDLER( backfire_speedup_r )
 {
-//  mame_printf_debug( "%08x\n",activecpu_get_pc());
+//  mame_printf_debug( "%08x\n",cpu_get_pc(space->cpu));
 
-	if (activecpu_get_pc()==0xce44)  cpu_spinuntil_time(ATTOTIME_IN_USEC(400)); // backfire
-	if (activecpu_get_pc()==0xcee4)  cpu_spinuntil_time(ATTOTIME_IN_USEC(400)); // backfira
+	if (cpu_get_pc(space->cpu)==0xce44)  cpu_spinuntil_time(space->cpu, ATTOTIME_IN_USEC(400)); // backfire
+	if (cpu_get_pc(space->cpu)==0xcee4)  cpu_spinuntil_time(space->cpu, ATTOTIME_IN_USEC(400)); // backfira
 
 	return backfire_mainram[0x18/4];
 }
@@ -688,12 +677,12 @@ static READ32_HANDLER( backfire_speedup_r )
 
 static DRIVER_INIT( backfire )
 {
-	deco56_decrypt(REGION_GFX1); /* 141 */
-	deco56_decrypt(REGION_GFX2); /* 141 */
-	decrypt156();
-	cpunum_set_clockscale(machine, 0, 4.0f); /* core timings aren't accurate */
-	descramble_sound();
-	memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0x0170018, 0x017001b, 0, 0, backfire_speedup_r );
+	deco56_decrypt_gfx(machine, "gfx1"); /* 141 */
+	deco56_decrypt_gfx(machine, "gfx2"); /* 141 */
+	deco156_decrypt(machine);
+	cpu_set_clockscale(machine->cpu[0], 4.0f); /* core timings aren't accurate */
+	descramble_sound(machine);
+	memory_install_read32_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x0170018, 0x017001b, 0, 0, backfire_speedup_r );
 }
 
 GAME( 1995, backfire, 0,        backfire,      backfire, backfire, ROT0, "Data East Corporation", "Backfire! (set 1)", 0 )
