@@ -24,7 +24,7 @@ Check game speed, it depends on a bit we toggle..
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/m68000/m68000.h"
 #include "sound/okim6295.h"
 
 /* Variables defined in video: */
@@ -55,9 +55,9 @@ VIDEO_UPDATE( blmbycar );
 
 static WRITE16_HANDLER( blmbycar_okibank_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
-		UINT8 *RAM = memory_region(REGION_SOUND1);
+		UINT8 *RAM = memory_region(space->machine, "oki");
 		memcpy(&RAM[0x30000],&RAM[0x40000 + 0x10000*(data & 0xf)],0x10000);
 	}
 }
@@ -76,13 +76,13 @@ static UINT8 pot_wheel = 0;
 
 static WRITE16_HANDLER( blmbycar_pot_wheel_reset_w )
 {
-	if (ACCESSING_LSB)
-		pot_wheel = ~readinputport(2) & 0xff;
+	if (ACCESSING_BITS_0_7)
+		pot_wheel = ~input_port_read(space->machine, "WHEEL") & 0xff;
 }
 
 static WRITE16_HANDLER( blmbycar_pot_wheel_shift_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		static int old;
 		if ( ((old & 0xff) == 0xff) && ((data & 0xff) == 0) )
@@ -94,7 +94,7 @@ static WRITE16_HANDLER( blmbycar_pot_wheel_shift_w )
 static READ16_HANDLER( blmbycar_pot_wheel_r )
 {
 	return	((pot_wheel & 0x80) ? 0x04 : 0) |
-			(mame_rand(Machine) & 0x08);
+			(mame_rand(space->machine) & 0x08);
 }
 
 
@@ -102,7 +102,7 @@ static READ16_HANDLER( blmbycar_pot_wheel_r )
 
 static READ16_HANDLER( blmbycar_opt_wheel_r )
 {
-	return	(~readinputport(2) & 0xff) << 8;
+	return	(~input_port_read(space->machine, "WHEEL") & 0xff) << 8;
 }
 
 
@@ -114,45 +114,31 @@ static READ16_HANDLER( blmbycar_opt_wheel_r )
 
 ***************************************************************************/
 
-static ADDRESS_MAP_START( blmbycar_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(MRA16_ROM					)	// ROM
-	AM_RANGE(0xfec000, 0xfeffff) AM_READ(MRA16_RAM					)	// RAM
-	AM_RANGE(0x200000, 0x2005ff) AM_READ(MRA16_RAM					)	// Palette
-	AM_RANGE(0x200600, 0x203fff) AM_READ(MRA16_RAM					)	//
-	AM_RANGE(0x204000, 0x2045ff) AM_READ(MRA16_RAM					)	// Palette
-	AM_RANGE(0x204600, 0x207fff) AM_READ(MRA16_RAM					)	//
-	AM_RANGE(0x104000, 0x105fff) AM_READ(MRA16_RAM					)	// Layer 1
-	AM_RANGE(0x106000, 0x107fff) AM_READ(MRA16_RAM					)	// Layer 0
-	AM_RANGE(0x440000, 0x441fff) AM_READ(MRA16_RAM					)	//
-	AM_RANGE(0x444000, 0x445fff) AM_READ(MRA16_RAM					)	// Sprites (size?)
-	AM_RANGE(0x700000, 0x700001) AM_READ(input_port_0_word_r		)	// 2 x DSW0
-	AM_RANGE(0x700002, 0x700003) AM_READ(input_port_1_word_r		)	// Joystick + Buttons
-	AM_RANGE(0x700004, 0x700005) AM_READ(blmbycar_opt_wheel_r		)	// Wheel (optical)
-	AM_RANGE(0x700006, 0x700007) AM_READ(input_port_3_word_r		)	//
-	AM_RANGE(0x700008, 0x700009) AM_READ(blmbycar_pot_wheel_r		)	// Wheel (potentiometer)
-	AM_RANGE(0x70000e, 0x70000f) AM_READ(OKIM6295_status_0_lsb_r	)	// Sound
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( blmbycar_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(MWA16_ROM								)	// ROM
-	AM_RANGE(0xfec000, 0xfeffff) AM_WRITE(MWA16_RAM								)	// RAM
-	AM_RANGE(0x100000, 0x103fff) AM_WRITE(MWA16_RAM								)	//
-	AM_RANGE(0x104000, 0x105fff) AM_WRITE(blmbycar_vram_1_w) AM_BASE(&blmbycar_vram_1	)	// Layer 1
-	AM_RANGE(0x106000, 0x107fff) AM_WRITE(blmbycar_vram_0_w) AM_BASE(&blmbycar_vram_0	)	// Layer 0
-	AM_RANGE(0x108000, 0x10bfff) AM_WRITE(MWA16_RAM								)	//
-	AM_RANGE(0x10c000, 0x10c003) AM_WRITE(MWA16_RAM) AM_BASE(&blmbycar_scroll_1			)	// Scroll 1
-	AM_RANGE(0x10c004, 0x10c007) AM_WRITE(MWA16_RAM) AM_BASE(&blmbycar_scroll_0			)	// Scroll 0
-	AM_RANGE(0x200000, 0x2005ff) AM_WRITE(blmbycar_palette_w					)	// Palette
-	AM_RANGE(0x200600, 0x203fff) AM_WRITE(MWA16_RAM								)	//
-	AM_RANGE(0x204000, 0x2045ff) AM_WRITE(blmbycar_palette_w) AM_BASE(&paletteram16		)	// Palette
-	AM_RANGE(0x204600, 0x207fff) AM_WRITE(MWA16_RAM								)	//
-	AM_RANGE(0x440000, 0x441fff) AM_WRITE(MWA16_RAM								)	//
-	AM_RANGE(0x444000, 0x445fff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size	)	// Sprites (size?)
-	AM_RANGE(0x70000a, 0x70000b) AM_WRITE(MWA16_NOP								)	// ? Wheel
-	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(blmbycar_okibank_w					)	// Sound
-	AM_RANGE(0x70000e, 0x70000f) AM_WRITE(OKIM6295_data_0_lsb_w					)	//
-	AM_RANGE(0x70006a, 0x70006b) AM_WRITE(blmbycar_pot_wheel_reset_w			)	// Wheel (potentiometer)
-	AM_RANGE(0x70007a, 0x70007b) AM_WRITE(blmbycar_pot_wheel_shift_w			)	//
+static ADDRESS_MAP_START( blmbycar_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM
+	AM_RANGE(0xfec000, 0xfeffff) AM_RAM
+	AM_RANGE(0x100000, 0x103fff) AM_WRITE(SMH_RAM											)	//
+	AM_RANGE(0x104000, 0x105fff) AM_RAM_WRITE(blmbycar_vram_1_w) AM_BASE(&blmbycar_vram_1	)	// Layer 1
+	AM_RANGE(0x106000, 0x107fff) AM_RAM_WRITE(blmbycar_vram_0_w) AM_BASE(&blmbycar_vram_0	)	// Layer 0
+	AM_RANGE(0x108000, 0x10bfff) AM_WRITE(SMH_RAM											)	//
+	AM_RANGE(0x10c000, 0x10c003) AM_WRITE(SMH_RAM) AM_BASE(&blmbycar_scroll_1				)	// Scroll 1
+	AM_RANGE(0x10c004, 0x10c007) AM_WRITE(SMH_RAM) AM_BASE(&blmbycar_scroll_0				)	// Scroll 0
+	AM_RANGE(0x200000, 0x2005ff) AM_RAM_WRITE(blmbycar_palette_w							)	// Palette
+	AM_RANGE(0x200600, 0x203fff) AM_RAM
+	AM_RANGE(0x204000, 0x2045ff) AM_RAM_WRITE(blmbycar_palette_w) AM_BASE(&paletteram16		)	// Palette
+	AM_RANGE(0x204600, 0x207fff) AM_RAM
+	AM_RANGE(0x440000, 0x441fff) AM_RAM
+	AM_RANGE(0x444000, 0x445fff) AM_RAM_WRITE(SMH_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size	)	// Sprites (size?)
+	AM_RANGE(0x700000, 0x700001) AM_READ_PORT("DSW"											)
+	AM_RANGE(0x700002, 0x700003) AM_READ_PORT("P1_P2"										)
+	AM_RANGE(0x700004, 0x700005) AM_READ(blmbycar_opt_wheel_r								)	// Wheel (optical)
+	AM_RANGE(0x700006, 0x700007) AM_READ_PORT("UNK"											)
+	AM_RANGE(0x700008, 0x700009) AM_READ(blmbycar_pot_wheel_r								)	// Wheel (potentiometer)
+	AM_RANGE(0x70000a, 0x70000b) AM_WRITE(SMH_NOP											)	// ? Wheel
+	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(blmbycar_okibank_w								)	// Sound
+	AM_RANGE(0x70000e, 0x70000f) AM_READWRITE(okim6295_status_0_lsb_r, okim6295_data_0_lsb_w)	// Sound
+	AM_RANGE(0x70006a, 0x70006b) AM_WRITE(blmbycar_pot_wheel_reset_w						)	// Wheel (potentiometer)
+	AM_RANGE(0x70007a, 0x70007b) AM_WRITE(blmbycar_pot_wheel_shift_w						)	//
 ADDRESS_MAP_END
 
 static READ16_HANDLER( waterball_unk_r )
@@ -164,42 +150,28 @@ static READ16_HANDLER( waterball_unk_r )
 	return retvalue;
 }
 
-static ADDRESS_MAP_START( watrball_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(MRA16_ROM					)	// ROM
-	AM_RANGE(0xfec000, 0xfeffff) AM_READ(MRA16_RAM					)	// RAM
-	AM_RANGE(0x200000, 0x2005ff) AM_READ(MRA16_RAM					)	// Palette
-	AM_RANGE(0x200600, 0x203fff) AM_READ(MRA16_RAM					)	//
-	AM_RANGE(0x204000, 0x2045ff) AM_READ(MRA16_RAM					)	// Palette
-	AM_RANGE(0x204600, 0x207fff) AM_READ(MRA16_RAM					)	//
-	AM_RANGE(0x104000, 0x105fff) AM_READ(MRA16_RAM					)	// Layer 1
-	AM_RANGE(0x106000, 0x107fff) AM_READ(MRA16_RAM					)	// Layer 0
-	AM_RANGE(0x440000, 0x441fff) AM_READ(MRA16_RAM					)	//
-	AM_RANGE(0x444000, 0x445fff) AM_READ(MRA16_RAM					)	// Sprites (size?)
-	AM_RANGE(0x700000, 0x700001) AM_READ(input_port_0_word_r		)
-	AM_RANGE(0x700002, 0x700003) AM_READ(input_port_1_word_r		)
-	AM_RANGE(0x700006, 0x700007) AM_READ(MRA16_NOP	            	)   // read
-	AM_RANGE(0x700008, 0x700009) AM_READ(waterball_unk_r	     	)   // 0x0008 must toggle
-	AM_RANGE(0x70000e, 0x70000f) AM_READ(OKIM6295_status_0_lsb_r	)	// Sound
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( watrball_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(MWA16_ROM								)	// ROM
-	AM_RANGE(0xfec000, 0xfeffff) AM_WRITE(MWA16_RAM								)	// RAM
-	AM_RANGE(0x100000, 0x103fff) AM_WRITE(MWA16_RAM								)	//
-	AM_RANGE(0x104000, 0x105fff) AM_WRITE(blmbycar_vram_1_w) AM_BASE(&blmbycar_vram_1	)	// Layer 1
-	AM_RANGE(0x106000, 0x107fff) AM_WRITE(blmbycar_vram_0_w) AM_BASE(&blmbycar_vram_0	)	// Layer 0
-	AM_RANGE(0x108000, 0x10bfff) AM_WRITE(MWA16_RAM								)	//
-	AM_RANGE(0x10c000, 0x10c003) AM_WRITE(MWA16_RAM) AM_BASE(&blmbycar_scroll_1			)	// Scroll 1
-	AM_RANGE(0x10c004, 0x10c007) AM_WRITE(MWA16_RAM) AM_BASE(&blmbycar_scroll_0			)	// Scroll 0
-	AM_RANGE(0x200000, 0x2005ff) AM_WRITE(blmbycar_palette_w					)	// Palette
-	AM_RANGE(0x200600, 0x203fff) AM_WRITE(MWA16_RAM								)	//
-	AM_RANGE(0x204000, 0x2045ff) AM_WRITE(blmbycar_palette_w) AM_BASE(&paletteram16		)	// Palette
-	AM_RANGE(0x204600, 0x207fff) AM_WRITE(MWA16_RAM								)	//
-	AM_RANGE(0x440000, 0x441fff) AM_WRITE(MWA16_RAM								)	//
-	AM_RANGE(0x444000, 0x445fff) AM_WRITE(MWA16_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size	)	// Sprites (size?)
-	AM_RANGE(0x70000a, 0x70000b) AM_WRITE(MWA16_NOP								)	// ?? busy
-	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(blmbycar_okibank_w					)	// Sound
-	AM_RANGE(0x70000e, 0x70000f) AM_WRITE(OKIM6295_data_0_lsb_w					)	//
+static ADDRESS_MAP_START( watrball_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM
+	AM_RANGE(0xfec000, 0xfeffff) AM_RAM
+	AM_RANGE(0x100000, 0x103fff) AM_WRITE(SMH_RAM											)	//
+	AM_RANGE(0x104000, 0x105fff) AM_RAM_WRITE(blmbycar_vram_1_w) AM_BASE(&blmbycar_vram_1	)	// Layer 1
+	AM_RANGE(0x106000, 0x107fff) AM_RAM_WRITE(blmbycar_vram_0_w) AM_BASE(&blmbycar_vram_0	)	// Layer 0
+	AM_RANGE(0x108000, 0x10bfff) AM_WRITE(SMH_RAM											)	//
+	AM_RANGE(0x10c000, 0x10c003) AM_WRITE(SMH_RAM) AM_BASE(&blmbycar_scroll_1				)	// Scroll 1
+	AM_RANGE(0x10c004, 0x10c007) AM_WRITE(SMH_RAM) AM_BASE(&blmbycar_scroll_0				)	// Scroll 0
+	AM_RANGE(0x200000, 0x2005ff) AM_RAM_WRITE(blmbycar_palette_w							)	// Palette
+	AM_RANGE(0x200600, 0x203fff) AM_RAM
+	AM_RANGE(0x204000, 0x2045ff) AM_RAM_WRITE(blmbycar_palette_w) AM_BASE(&paletteram16		)	// Palette
+	AM_RANGE(0x204600, 0x207fff) AM_RAM
+	AM_RANGE(0x440000, 0x441fff) AM_RAM
+	AM_RANGE(0x444000, 0x445fff) AM_RAM_WRITE(SMH_RAM) AM_BASE(&spriteram16) AM_SIZE(&spriteram_size	)	// Sprites (size?)
+	AM_RANGE(0x700000, 0x700001) AM_READ_PORT("DSW"											)
+	AM_RANGE(0x700002, 0x700003) AM_READ_PORT("P1_P2"										)
+	AM_RANGE(0x700006, 0x700007) AM_READ(SMH_NOP	            							)   // read
+	AM_RANGE(0x700008, 0x700009) AM_READ(waterball_unk_r	     							)   // 0x0008 must toggle
+	AM_RANGE(0x70000a, 0x70000b) AM_WRITE(SMH_NOP											)	// ?? busy
+	AM_RANGE(0x70000c, 0x70000d) AM_WRITE(blmbycar_okibank_w								)	// Sound
+	AM_RANGE(0x70000e, 0x70000f) AM_READWRITE(okim6295_status_0_lsb_r, okim6295_data_0_lsb_w)	//
 ADDRESS_MAP_END
 
 /***************************************************************************
@@ -212,7 +184,7 @@ ADDRESS_MAP_END
 
 static INPUT_PORTS_START( blmbycar )
 
-	PORT_START	// IN0 - $700000.w
+	PORT_START("DSW")	// IN0 - $700000.w
 	PORT_DIPNAME( 0x0003, 0x0003, DEF_STR( Difficulty ) ) PORT_DIPLOCATION("SW1:8,7")
 	PORT_DIPSETTING(      0x0002, DEF_STR( Easy )    )
 	PORT_DIPSETTING(      0x0003, DEF_STR( Normal )  )
@@ -259,7 +231,7 @@ static INPUT_PORTS_START( blmbycar )
 	PORT_DIPSETTING(      0x8000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 
-	PORT_START	// IN1 - $700002.w
+	PORT_START("P1_P2")	// IN1 - $700002.w
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN	 ) PORT_PLAYER(1)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(1)
@@ -278,17 +250,17 @@ static INPUT_PORTS_START( blmbycar )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_START1  )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_START2  )
 
-	PORT_START	// IN2 - $700004.w
+	PORT_START("WHEEL")	// IN2 - $700004.w
 	PORT_BIT ( 0x00ff, 0x0080, IPT_AD_STICK_X ) PORT_SENSITIVITY(30) PORT_KEYDELTA(1)
 
-	PORT_START	// IN3 - $700006.w
+	PORT_START("UNK")	// IN3 - $700006.w
 	PORT_BIT( 0xffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( watrball )
-	PORT_START	/* dips */
+	PORT_START("DSW")	/* dips */
 	PORT_DIPNAME( 0x0003, 0x0003, DEF_STR( Difficulty ) ) PORT_DIPLOCATION("SW1:8,7") /* Affects timer */
 	PORT_DIPSETTING(      0x0002, DEF_STR( Easy )    )    /* 180 Seconds */
 	PORT_DIPSETTING(      0x0003, DEF_STR( Normal )  )    /* 150 Seconds */
@@ -326,7 +298,7 @@ static INPUT_PORTS_START( watrball )
 	PORT_DIPUNUSED_DIPLOC( 0x4000, 0x4000, "SW2:2" )
 	PORT_DIPUNUSED_DIPLOC( 0x8000, 0x8000, "SW2:1" )
 
-	PORT_START	/* 16bit */
+	PORT_START("P1_P2")	/* 16bit */
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN	 ) PORT_PLAYER(1)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(1)
@@ -368,7 +340,7 @@ static const gfx_layout layout_16x16x4 =
 
 /* Layers both use the first $20 color codes. Sprites the next $10 */
 static GFXDECODE_START( blmbycar )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, layout_16x16x4, 0x0, 0x30 ) // [0] Layers + Sprites
+	GFXDECODE_ENTRY( "sprites", 0, layout_16x16x4, 0x0, 0x30 ) // [0] Layers + Sprites
 GFXDECODE_END
 
 
@@ -384,18 +356,18 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( blmbycar )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000, 10000000)	/* ? */
-	MDRV_CPU_PROGRAM_MAP(blmbycar_readmem,blmbycar_writemem)
-	MDRV_CPU_VBLANK_INT(irq1_line_hold,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_ADD("main", M68000, 10000000)	/* ? */
+	MDRV_CPU_PROGRAM_MAP(blmbycar_map,0)
+	MDRV_CPU_VBLANK_INT("main", irq1_line_hold)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(0x180, 0x100)
 	MDRV_SCREEN_VISIBLE_AREA(0, 0x180-1, 0, 0x100-1)
+
 	MDRV_GFXDECODE(blmbycar)
 	MDRV_PALETTE_LENGTH(0x300)
 
@@ -405,8 +377,8 @@ static MACHINE_DRIVER_START( blmbycar )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(OKIM6295, 1056000)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high) // clock frequency & pin 7 not verified
+	MDRV_SOUND_ADD("oki", OKIM6295, 1056000)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // clock frequency & pin 7 not verified
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
@@ -414,18 +386,18 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( watrball )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000, 10000000)	/* ? */
-	MDRV_CPU_PROGRAM_MAP(watrball_readmem,watrball_writemem)
-	MDRV_CPU_VBLANK_INT(irq1_line_hold,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_CPU_ADD("main", M68000, 10000000)	/* ? */
+	MDRV_CPU_PROGRAM_MAP(watrball_map,0)
+	MDRV_CPU_VBLANK_INT("main", irq1_line_hold)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(0x180, 0x100)
 	MDRV_SCREEN_VISIBLE_AREA(0, 0x180-1, 16, 0x100-1)
+
 	MDRV_GFXDECODE(blmbycar)
 	MDRV_PALETTE_LENGTH(0x300)
 
@@ -435,8 +407,8 @@ static MACHINE_DRIVER_START( watrball )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(OKIM6295, 1056000)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high) // clock frequency & pin 7 not verified
+	MDRV_SOUND_ADD("oki", OKIM6295, 1056000)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // clock frequency & pin 7 not verified
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
@@ -464,37 +436,37 @@ GFX : TI TPC1020AFN-084
 ***************************************************************************/
 
 ROM_START( blmbycar )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )		/* 68000 Code */
+	ROM_REGION( 0x100000, "main", 0 )		/* 68000 Code */
 	ROM_LOAD16_BYTE( "bcrom4.bin", 0x000000, 0x080000, CRC(06d490ba) SHA1(6d113561b474bf613c6b91c9525a52025ae65ab7) )
 	ROM_LOAD16_BYTE( "bcrom6.bin", 0x000001, 0x080000, CRC(33aca664) SHA1(04fff492654d3edac62e9d35808e5946bcc78cbb) )
 
-	ROM_REGION( 0x200000, REGION_GFX1, ROMREGION_DISPOSE )	/* Sprites */
+	ROM_REGION( 0x200000, "sprites", ROMREGION_DISPOSE )	/* Sprites */
 	ROM_LOAD( "bc_rom7",   0x000000, 0x080000, CRC(e55ca79b) SHA1(4453a6ae0518832f437ab701c28cb2f32920f8ba) )
 	ROM_LOAD( "bc_rom8",   0x080000, 0x080000, CRC(cdf38c96) SHA1(3273c29b6a01a7296d06fc653120f8c615195d2c) )
 	ROM_LOAD( "bc_rom9",   0x100000, 0x080000, CRC(0337ab3d) SHA1(18c72cd640c7b599390dffaeb670f5832202bf06) )
 	ROM_LOAD( "bc_rom10",  0x180000, 0x080000, CRC(5458917e) SHA1(c8dd5a391cc20a573e27a140b185893a8c04859e) )
 
-	ROM_REGION( 0x140000, REGION_SOUND1, 0 )	/* 8 bit adpcm (banked) */
+	ROM_REGION( 0x140000, "oki", 0 )	/* 8 bit adpcm (banked) */
 	ROM_LOAD( "bc_rom1",     0x040000, 0x080000, CRC(ac6f8ba1) SHA1(69d2d47cdd331bde5a8973d29659b3f8520452e7) )
 	ROM_LOAD( "bc_rom2",     0x0c0000, 0x080000, CRC(a4bc31bf) SHA1(f3d60141a91449a73f6cec9f4bc5d95ca7911e19) )
-	ROM_COPY( REGION_SOUND1, 0x040000, 0x000000,   0x040000 )
+	ROM_COPY( "oki", 0x040000, 0x000000,   0x040000 )
 ROM_END
 
 ROM_START( blmbycau )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )		/* 68000 Code */
+	ROM_REGION( 0x100000, "main", 0 )		/* 68000 Code */
 	ROM_LOAD16_BYTE( "bc_rom4", 0x000000, 0x080000, CRC(76f054a2) SHA1(198efd152b13033e5249119ca48b9e0f6351b0b9) )
 	ROM_LOAD16_BYTE( "bc_rom6", 0x000001, 0x080000, CRC(2570b4c5) SHA1(706465950023a6ef7c85ceb9c76246d7556b3859) )
 
-	ROM_REGION( 0x200000, REGION_GFX1, ROMREGION_DISPOSE )	/* Sprites */
+	ROM_REGION( 0x200000, "sprites", ROMREGION_DISPOSE )	/* Sprites */
 	ROM_LOAD( "bc_rom7",   0x000000, 0x080000, CRC(e55ca79b) SHA1(4453a6ae0518832f437ab701c28cb2f32920f8ba) )
 	ROM_LOAD( "bc_rom8",   0x080000, 0x080000, CRC(cdf38c96) SHA1(3273c29b6a01a7296d06fc653120f8c615195d2c) )
 	ROM_LOAD( "bc_rom9",   0x100000, 0x080000, CRC(0337ab3d) SHA1(18c72cd640c7b599390dffaeb670f5832202bf06) )
 	ROM_LOAD( "bc_rom10",  0x180000, 0x080000, CRC(5458917e) SHA1(c8dd5a391cc20a573e27a140b185893a8c04859e) )
 
-	ROM_REGION( 0x140000, REGION_SOUND1, 0 )	/* 8 bit adpcm (banked) */
+	ROM_REGION( 0x140000, "oki", 0 )	/* 8 bit adpcm (banked) */
 	ROM_LOAD( "bc_rom1",     0x040000, 0x080000, CRC(ac6f8ba1) SHA1(69d2d47cdd331bde5a8973d29659b3f8520452e7) )
 	ROM_LOAD( "bc_rom2",     0x0c0000, 0x080000, CRC(a4bc31bf) SHA1(f3d60141a91449a73f6cec9f4bc5d95ca7911e19) )
-	ROM_COPY( REGION_SOUND1, 0x040000, 0x000000,   0x040000 )
+	ROM_COPY( "oki", 0x040000, 0x000000,   0x040000 )
 ROM_END
 
 /*
@@ -514,27 +486,27 @@ The game has fonts identical to World rally and obiviously Blomby car ;)
 */
 
 ROM_START( watrball )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )		/* 68000 Code */
+	ROM_REGION( 0x100000, "main", 0 )		/* 68000 Code */
 	ROM_LOAD16_BYTE( "rom4.bin", 0x000000, 0x020000, CRC(bfbfa720) SHA1(d6d14c0ba545eb7adee7190da2d3db1c6dd00d75) )
 	ROM_LOAD16_BYTE( "rom6.bin", 0x000001, 0x020000, CRC(acff9b01) SHA1(b85671bcc4f03fdf05eb1c9b5d4143e33ec1d7db) )
 
-	ROM_REGION( 0x200000, REGION_GFX1, ROMREGION_DISPOSE )	/* Sprites */
+	ROM_REGION( 0x200000, "sprites", ROMREGION_DISPOSE )	/* Sprites */
 	ROM_LOAD( "rom7.bin",   0x000000, 0x080000, CRC(e7e5c311) SHA1(5af1a666bf23c5505d120d81fb942f5c49341861) )
 	ROM_LOAD( "rom8.bin",   0x080000, 0x080000, CRC(fd27ce6e) SHA1(a472a8cc25818427d2870518649780146e51835b) )
 	ROM_LOAD( "rom9.bin",   0x100000, 0x080000, CRC(122cc0ad) SHA1(27cdb19fa082089e47c5cdb44742cfd93aa23a00) )
 	ROM_LOAD( "rom10.bin",  0x180000, 0x080000, CRC(22a2a706) SHA1(c7350a94a857e0007d7fc0076b44a3d62693cb6c) )
 
-	ROM_REGION( 0x140000, REGION_SOUND1, 0 )	/* 8 bit adpcm (banked) */
+	ROM_REGION( 0x140000, "oki", 0 )	/* 8 bit adpcm (banked) */
 	ROM_LOAD( "rom1.bin",     0x040000, 0x080000, CRC(7f88dee7) SHA1(d493b961fa4631185a33faee7f61786430707209))
 //  ROM_LOAD( "rom2.bin",     0x0c0000, 0x080000, /* not populated for this game */ )
-	ROM_COPY( REGION_SOUND1, 0x040000, 0x000000,   0x040000 )
+	ROM_COPY( "oki", 0x040000, 0x000000,   0x040000 )
 ROM_END
 
 
 static DRIVER_INIT( blmbycar )
 {
-	UINT16 *RAM  = (UINT16 *) memory_region(REGION_CPU1);
-	size_t    size = memory_region_length(REGION_CPU1) / 2;
+	UINT16 *RAM  = (UINT16 *) memory_region(machine, "main");
+	size_t    size = memory_region_length(machine, "main") / 2;
 	int i;
 
 	for (i = 0; i < size; i++)
