@@ -132,7 +132,7 @@ static VIDEO_UPDATE( bmcbowl )
 */
 
 	int x,y,z,pixdat;
-	fillbitmap(bitmap,get_black_pen(machine),cliprect);
+	bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
 
 	z=0;
 	for (y=0;y<230;y++)
@@ -175,15 +175,15 @@ static VIDEO_UPDATE( bmcbowl )
 
 static READ16_HANDLER( bmc_random_read )
 {
-	return mame_rand(Machine);
+	return mame_rand(space->machine);
 }
 
 static READ16_HANDLER( bmc_protection_r )
 {
-	switch(activecpu_get_previouspc())
+	switch(cpu_get_previouspc(space->cpu))
 	{
 		case 0xca68:
-			switch(activecpu_get_reg(M68K_D2))
+			switch(cpu_get_reg(space->cpu, M68K_D2))
 			{
 				case 0: 		 return 0x37<<8;
 				case 0x1013: return 0;
@@ -191,8 +191,8 @@ static READ16_HANDLER( bmc_protection_r )
 			}
 			break;
 	}
-	logerror("Protection read @ %X\n",activecpu_get_previouspc());
-	return mame_rand(Machine);
+	logerror("Protection read @ %X\n",cpu_get_previouspc(space->cpu));
+	return mame_rand(space->machine);
 }
 
 static WRITE16_HANDLER( bmc_RAMDAC_offset_w )
@@ -203,7 +203,7 @@ static WRITE16_HANDLER( bmc_RAMDAC_offset_w )
 static WRITE16_HANDLER( bmc_RAMDAC_color_w )
 {
 		colorram[clr_offset]=data;
-		palette_set_color_rgb(Machine,clr_offset/3,pal6bit(colorram[(clr_offset/3)*3]),pal6bit(colorram[(clr_offset/3)*3+1]),pal6bit(colorram[(clr_offset/3)*3+2]));
+		palette_set_color_rgb(space->machine,clr_offset/3,pal6bit(colorram[(clr_offset/3)*3]),pal6bit(colorram[(clr_offset/3)*3+1]),pal6bit(colorram[(clr_offset/3)*3+2]));
 		clr_offset=(clr_offset+1)%768;
 }
 
@@ -213,39 +213,41 @@ static WRITE16_HANDLER( scroll_w )
 }
 
 
-static READ16_HANDLER(via_r)
+static READ16_HANDLER(bmcbowl_via_r)
 {
-	return via_0_r(offset);
+	const device_config *via_0 = device_list_find_by_tag(space->machine->config->devicelist, VIA6522, "via6522_0");
+	return via_r(via_0, offset);
 }
 
-static WRITE16_HANDLER(via_w)
+static WRITE16_HANDLER(bmcbowl_via_w)
 {
-	via_0_w(offset,data);
+	const device_config *via_0 = device_list_find_by_tag(space->machine->config->devicelist, VIA6522, "via6522_0");
+	via_w(via_0, offset, data);
 }
 
-static READ8_HANDLER(via_b_in)
+static READ8_DEVICE_HANDLER(via_b_in)
 {
-	return input_port_3_r(0);
+	return input_port_read(device->machine, "IN3");
 }
 
 
-static WRITE8_HANDLER(via_a_out)
+static WRITE8_DEVICE_HANDLER(via_a_out)
 {
 	// related to video hw ? BG scroll ?
 }
 
-static WRITE8_HANDLER(via_b_out)
+static WRITE8_DEVICE_HANDLER(via_b_out)
 {
 	//used
 }
 
-static WRITE8_HANDLER(via_ca2_out)
+static WRITE8_DEVICE_HANDLER(via_ca2_out)
 {
 	//used
 }
 
 
-static void via_irq(int state)
+static void via_irq(const device_config *device, int state)
 {
 	//used
 }
@@ -327,40 +329,40 @@ static ADDRESS_MAP_START( bmcbowl_mem, ADDRESS_SPACE_PROGRAM, 16 )
 
 	AM_RANGE(0x090000, 0x090001) AM_WRITE(bmc_RAMDAC_offset_w)
 	AM_RANGE(0x090002, 0x090003) AM_WRITE(bmc_RAMDAC_color_w)
-	AM_RANGE(0x090004, 0x090005) AM_WRITE(MWA16_NOP)//RAMDAC
+	AM_RANGE(0x090004, 0x090005) AM_WRITE(SMH_NOP)//RAMDAC
 
-	AM_RANGE(0x090800, 0x090803) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x091000, 0x091001) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0x090800, 0x090803) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x091000, 0x091001) AM_WRITE(SMH_NOP)
 	AM_RANGE(0x091800, 0x091801) AM_WRITE(scroll_w)
 
-	AM_RANGE(0x092000, 0x09201f) AM_READWRITE(via_r,via_w)
+	AM_RANGE(0x092000, 0x09201f) AM_READWRITE(bmcbowl_via_r, bmcbowl_via_w)
 
-	AM_RANGE(0x093000, 0x093003) AM_WRITE(MWA16_NOP)  // related to music
-	AM_RANGE(0x092800, 0x092801) AM_WRITE(AY8910_write_port_0_msb_w		)
-	AM_RANGE(0x092802, 0x092803) AM_READ(AY8910_read_port_0_msb_r) AM_WRITE(AY8910_control_port_0_msb_w	)
-	AM_RANGE(0x093802, 0x093803) AM_READ(input_port_0_word_r)
+	AM_RANGE(0x093000, 0x093003) AM_WRITE(SMH_NOP)  // related to music
+	AM_RANGE(0x092800, 0x092801) AM_WRITE(ay8910_write_port_0_msb_w		)
+	AM_RANGE(0x092802, 0x092803) AM_READ(ay8910_read_port_0_msb_r) AM_WRITE(ay8910_control_port_0_msb_w	)
+	AM_RANGE(0x093802, 0x093803) AM_READ_PORT("IN0")
 	AM_RANGE(0x095000, 0x095fff) AM_RAM AM_BASE((UINT16 **)&stats_ram) AM_SIZE(&stats_ram_size) /* 8 bit */
-	AM_RANGE(0x097000, 0x097001) AM_READ(MRA16_NOP)
+	AM_RANGE(0x097000, 0x097001) AM_READ(SMH_NOP)
 	AM_RANGE(0x140000, 0x1bffff) AM_ROM
 	AM_RANGE(0x1c0000, 0x1effff) AM_RAM AM_BASE(&bmcbowl_vid1)
 	AM_RANGE(0x1f0000, 0x1fffff) AM_RAM
 	AM_RANGE(0x200000, 0x21ffff) AM_RAM AM_BASE(&bmcbowl_vid2)
 
-	AM_RANGE(0x28c000, 0x28c001) AM_READWRITE(OKIM6295_status_0_msb_r,OKIM6295_data_0_msb_w)
+	AM_RANGE(0x28c000, 0x28c001) AM_READWRITE(okim6295_status_0_msb_r,okim6295_data_0_msb_w)
 
 	/* protection device*/
-	AM_RANGE(0x30c000, 0x30c001) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x30c040, 0x30c041) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x30c080, 0x30c081) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x30c0c0, 0x30c0c1) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0x30c000, 0x30c001) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x30c040, 0x30c041) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x30c080, 0x30c081) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x30c0c0, 0x30c0c1) AM_WRITE(SMH_NOP)
 	AM_RANGE(0x30c100, 0x30c101) AM_READ(bmc_protection_r)
-	AM_RANGE(0x30c140, 0x30c141) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x30ca00, 0x30ca01) AM_READ(bmc_random_read) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0x30c140, 0x30c141) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x30ca00, 0x30ca01) AM_READ(bmc_random_read) AM_WRITE(SMH_NOP)
 ADDRESS_MAP_END
 
 
 static INPUT_PORTS_START( bmcbowl )
-	PORT_START	/* DSW 1 */
+	PORT_START("IN0")	/* DSW 1 */
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_SERVICE1 )	PORT_NAME("Note")
 	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_SERVICE2 )	PORT_NAME("Analizer")
 
@@ -373,7 +375,6 @@ static INPUT_PORTS_START( bmcbowl )
 	PORT_BIT(0x0400, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Confirm") PORT_CODE(KEYCODE_N)
 
 
-	PORT_BIT(0x0040, IP_ACTIVE_LOW, IPT_START1 ) PORT_NAME("Start")
 	PORT_BIT(0x0040, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_NAME("Start")
 	PORT_BIT(0x0080, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Take") PORT_CODE(KEYCODE_A)
 	PORT_BIT(0x0200, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("HP") PORT_CODE(KEYCODE_S)
@@ -382,10 +383,10 @@ static INPUT_PORTS_START( bmcbowl )
 	PORT_BIT(0x4000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Big") PORT_CODE(KEYCODE_G)
 	PORT_BIT(0x8000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Double") PORT_CODE(KEYCODE_H)
 
-	PORT_START	/* DSW 2 */
+	PORT_START("IN1")	/* DSW 2 */
 	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Coinage ) )
-	PORT_DIPSETTING(    0x20, "1 COIN 10 CREDITS")
-	PORT_DIPSETTING(    0x00, "2 COINS 10 CREDITS")
+	PORT_DIPSETTING(    0x20, "1 COIN 10 CREDITS" )
+	PORT_DIPSETTING(    0x00, "2 COINS 10 CREDITS" )
 
 	PORT_DIPNAME( 0x01, 0x00, "DSW2 8" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
@@ -410,7 +411,7 @@ static INPUT_PORTS_START( bmcbowl )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START	/* DSW 4 */
+	PORT_START("IN2")	/* DSW 4 */
 	PORT_DIPNAME( 0x01, 0x00, "DSW4 8" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -436,10 +437,10 @@ static INPUT_PORTS_START( bmcbowl )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_IMPULSE(1)
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(1)
-	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_VBLANK )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_VBLANK )
 
 INPUT_PORTS_END
 
@@ -447,10 +448,10 @@ static READ8_HANDLER(dips1_r)
 {
 	switch(bmc_input)
 	{
-			case 0x00:	return  input_port_1_r(0);
-			case 0x40:	return  input_port_2_r(0);
+			case 0x00:	return  input_port_read(space->machine, "IN1");
+			case 0x40:	return  input_port_read(space->machine, "IN2");
 	}
-	logerror("unknown input - %X (PC=%X)\n",bmc_input,activecpu_get_previouspc());
+	logerror("unknown input - %X (PC=%X)\n",bmc_input,cpu_get_previouspc(space->cpu));
 	return 0xff;
 }
 
@@ -461,16 +462,18 @@ static WRITE8_HANDLER(input_mux_w)
 }
 
 
-static const struct AY8910interface ay8910_interface =
+static const ay8910_interface ay8910_config =
 {
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
 	dips1_r,
-	0,
-	0,
+	NULL,
+	NULL,
 	input_mux_w
 };
 
 
-static const struct via6522_interface via_interface =
+static const via6522_interface via_interface =
 {
 	/*inputs : A/B         */ 0, via_b_in,
 	/*inputs : CA/B1,CA/B2 */ 0, 0, 0, 0,
@@ -481,28 +484,29 @@ static const struct via6522_interface via_interface =
 
 static MACHINE_RESET( bmcbowl )
 {
-	via_reset();
 }
 
 static INTERRUPT_GEN( bmc_interrupt )
 {
-	if (cpu_getiloops())
-		cpunum_set_input_line(machine, 0, 4, HOLD_LINE);
+	if (cpu_getiloops(device))
+		cpu_set_input_line(device, 4, HOLD_LINE);
 	else
-		cpunum_set_input_line(machine, 0, 2, HOLD_LINE);
+		cpu_set_input_line(device, 2, HOLD_LINE);
 }
 
 static MACHINE_DRIVER_START( bmcbowl )
-	MDRV_CPU_ADD_TAG("main", M68000, 21477270/2 )
+	MDRV_CPU_ADD("main", M68000, 21477270/2 )
 	MDRV_CPU_PROGRAM_MAP(bmcbowl_mem,0)
-	MDRV_CPU_VBLANK_INT(bmc_interrupt,2)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT_HACK(bmc_interrupt,2)
 
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(35*8, 30*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 35*8-1, 0*8, 29*8-1)
+
 	MDRV_PALETTE_LENGTH(256)
 
 	MDRV_VIDEO_START(bmcbowl)
@@ -513,19 +517,22 @@ static MACHINE_DRIVER_START( bmcbowl )
 
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(AY8910, 3579545/2)
-	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ADD("ay", AY8910, 3579545/2)
+	MDRV_SOUND_CONFIG(ay8910_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
 
-	MDRV_SOUND_ADD(OKIM6295, 1122000)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high) // clock frequency & pin 7 not verified
+	MDRV_SOUND_ADD("oki", OKIM6295, 1122000)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // clock frequency & pin 7 not verified
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
+
+	/* via */
+	MDRV_VIA6522_ADD("via6522_0", 1000000, via_interface)
 MACHINE_DRIVER_END
 
 ROM_START( bmcbowl )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_REGION( 0x200000, "main", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "bmc_8ex.bin", 0x000000, 0x10000, CRC(8b1aa5db) SHA1(879df950bedf2c163ba89d983ca4a0691b01c46e) )
 	ROM_LOAD16_BYTE( "bmc_7ex.bin", 0x000001, 0x10000, CRC(7726d47a) SHA1(8438c3345847c2913c640a29145ec8502f6b01e7) )
 
@@ -537,15 +544,13 @@ ROM_START( bmcbowl )
 	ROM_LOAD16_BYTE( "bmc_6.bin", 0x180000, 0x20000, CRC(7b9e0d77) SHA1(1ec1c92c6d4c512f7292b77e9663518085684ba9) )
 	ROM_LOAD16_BYTE( "bmc_5.bin", 0x180001, 0x20000, CRC(708b6f8b) SHA1(4a910126d87c11fed99f44b61d51849067eddc02) )
 
-	ROM_REGION( 0x040000, REGION_SOUND1, 0 ) /* Samples */
+	ROM_REGION( 0x040000, "oki", 0 ) /* Samples */
 	ROM_LOAD( "bmc_10.bin", 0x00000, 0x20000,  CRC(f840c17f) SHA1(82891a85c8dc60f727b5a8c8e8ab09e8e4bd8af4) )
 
 ROM_END
 
 static DRIVER_INIT(bmcbowl)
 {
-	via_config(0, &via_interface);
-	via_set_clock(0, 1000000);//1 MHz ?
 	colorram=auto_malloc(768);
 }
 
