@@ -87,14 +87,15 @@ ROMs    : MR96004-10.1  [125661cd] (IC5 - Samples)
 */
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
+#include "cpu/v60/v60.h"
 #include "deprecat.h"
 #include "sound/ymf271.h"
 #include "rendlay.h"
+#include "includes/ms32.h"
 
-/* drivers/ms32/c */
-extern void ms32_rearrange_sprites(int region);
-extern void decrypt_ms32_tx(int addr_xor,int data_xor, int region);
-extern void decrypt_ms32_bg(int addr_xor,int data_xor, int region);
+#define ms32_roz_ctrl bnstars_roz_ctrl
+#define ms32_spram bnstars_spram
 
 static tilemap *ms32_tx_tilemap[2];
 static tilemap *ms32_bg_tilemap[2];
@@ -181,7 +182,7 @@ static WRITE32_HANDLER( ms32_bg1_ram_w )
 
 /* ROZ Layers */
 
-static void draw_roz(mame_bitmap *bitmap, const rectangle *cliprect,int priority, int chip)
+static void draw_roz(bitmap_t *bitmap, const rectangle *cliprect,int priority, int chip)
 {
 	/* TODO: registers 0x40/4 / 0x44/4 and 0x50/4 / 0x54/4 are used, meaning unknown */
 
@@ -299,7 +300,7 @@ static WRITE32_HANDLER( ms32_roz1_ram_w )
 }
 
 
-static void update_color(int color, int screen)
+static void update_color(running_machine *machine, int color, int screen)
 {
 	int r,g,b;
 
@@ -307,26 +308,26 @@ static void update_color(int color, int screen)
 	g = ((ms32_pal_ram[screen][color*2] & 0x00ff) >>0 );
 	b = ((ms32_pal_ram[screen][color*2+1] & 0x00ff) >>0 );
 
-	palette_set_color(Machine,color+screen*0x8000,MAKE_RGB(r,g,b));
+	palette_set_color(machine,color+screen*0x8000,MAKE_RGB(r,g,b));
 }
 
 static WRITE32_HANDLER( ms32_pal0_ram_w )
 {
 	COMBINE_DATA(&ms32_pal_ram[0][offset]);
-	update_color(offset/2, 0);
+	update_color(space->machine, offset/2, 0);
 }
 
 static WRITE32_HANDLER( ms32_pal1_ram_w )
 {
 	COMBINE_DATA(&ms32_pal_ram[1][offset]);
-	update_color(offset/2, 1);
+	update_color(space->machine, offset/2, 1);
 }
 
 static int ms32_reverse_sprite_order = 0;
 static int flipscreen = 0;
 
 /* SPRITES based on tetrisp2 for now, readd priority bits later */
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, UINT32 *sprram_top, size_t sprram_size, int region)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, UINT32 *sprram_top, size_t sprram_size, int region)
 {
 /***************************************************************************
 
@@ -467,18 +468,18 @@ static WRITE32_HANDLER( ms32_spramx_w )
 
 static VIDEO_START(bnstars)
 {
-	ms32_tx_tilemap[0] = tilemap_create(get_ms32_tx0_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN, 8, 8,64,64);
-	ms32_tx_tilemap[1] = tilemap_create(get_ms32_tx1_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN, 8, 8,64,64);
+	ms32_tx_tilemap[0] = tilemap_create(machine, get_ms32_tx0_tile_info,tilemap_scan_rows, 8, 8,64,64);
+	ms32_tx_tilemap[1] = tilemap_create(machine, get_ms32_tx1_tile_info,tilemap_scan_rows, 8, 8,64,64);
 	tilemap_set_transparent_pen(ms32_tx_tilemap[0],0);
 	tilemap_set_transparent_pen(ms32_tx_tilemap[1],0);
 
-	ms32_bg_tilemap[0] = tilemap_create(get_ms32_bg0_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,64,64);
-	ms32_bg_tilemap[1] = tilemap_create(get_ms32_bg1_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,64,64);
+	ms32_bg_tilemap[0] = tilemap_create(machine, get_ms32_bg0_tile_info,tilemap_scan_rows,16,16,64,64);
+	ms32_bg_tilemap[1] = tilemap_create(machine, get_ms32_bg1_tile_info,tilemap_scan_rows,16,16,64,64);
 	tilemap_set_transparent_pen(ms32_bg_tilemap[0],0);
 	tilemap_set_transparent_pen(ms32_bg_tilemap[1],0);
 
-	ms32_roz_tilemap[0] = tilemap_create(get_ms32_roz0_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,128,128);
-	ms32_roz_tilemap[1] = tilemap_create(get_ms32_roz1_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,128,128);
+	ms32_roz_tilemap[0] = tilemap_create(machine, get_ms32_roz0_tile_info,tilemap_scan_rows,16,16,128,128);
+	ms32_roz_tilemap[1] = tilemap_create(machine, get_ms32_roz1_tile_info,tilemap_scan_rows,16,16,128,128);
 	tilemap_set_transparent_pen(ms32_roz_tilemap[0],0);
 	tilemap_set_transparent_pen(ms32_roz_tilemap[1],0);
 
@@ -491,12 +492,14 @@ static VIDEO_START(bnstars)
 
 static VIDEO_UPDATE(bnstars)
 {
+	const device_config *left_screen  = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "left");
+	const device_config *right_screen = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "right");
 
-	fillbitmap(priority_bitmap,0,cliprect);
+	bitmap_fill(priority_bitmap,cliprect,0);
 
-	if (screen==0)
+	if (screen==left_screen)
 	{
-		fillbitmap(bitmap,machine->pens[0],cliprect);	/* bg color */
+		bitmap_fill(bitmap,cliprect,0);	/* bg color */
 
 
 		tilemap_set_scrollx(ms32_bg_tilemap[0], 0, ms32_bg0_scroll[0x00/4] + ms32_bg0_scroll[0x08/4] + 0x10 );
@@ -510,11 +513,11 @@ static VIDEO_UPDATE(bnstars)
 		tilemap_draw(bitmap,cliprect,ms32_tx_tilemap[0],0,4);
 
 
-		draw_sprites(machine,bitmap,cliprect, ms32_spram, 0x20000, 0);
+		draw_sprites(screen->machine,bitmap,cliprect, ms32_spram, 0x20000, 0);
 	}
-	else
+	else if (screen == right_screen)
 	{
-		fillbitmap(bitmap,machine->pens[0x8000+0],cliprect);	/* bg color */
+		bitmap_fill(bitmap,cliprect,0x8000+0);	/* bg color */
 
 
 		tilemap_set_scrollx(ms32_bg_tilemap[1], 0, ms32_bg1_scroll[0x00/4] + ms32_bg1_scroll[0x08/4] + 0x10 );
@@ -527,14 +530,14 @@ static VIDEO_UPDATE(bnstars)
 		tilemap_set_scrolly(ms32_tx_tilemap[1], 0, ms32_tx1_scroll[0x0c/4] + ms32_tx1_scroll[0x14/4]);
 		tilemap_draw(bitmap,cliprect,ms32_tx_tilemap[1],0,4);
 
-		draw_sprites(machine,bitmap,cliprect, ms32_spram+(0x20000/4), 0x20000, 4);
+		draw_sprites(screen->machine,bitmap,cliprect, ms32_spram+(0x20000/4), 0x20000, 4);
 	}
 
 	return 0;
 }
 
 static INPUT_PORTS_START( bnstars )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x00000001, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_A )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_E )
@@ -616,7 +619,7 @@ static INPUT_PORTS_START( bnstars )
 	PORT_DIPSETTING(  0x80000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(  0x00000000, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_DIPNAME(     0x00000001, 0x00000001, "MAH2" )
 	PORT_DIPSETTING(  0x00000001, DEF_STR( Off ) )
 	PORT_DIPSETTING(  0x00000000, DEF_STR( On ) )
@@ -704,7 +707,7 @@ static INPUT_PORTS_START( bnstars )
 	PORT_DIPSETTING(  0x80000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(  0x00000000, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_DIPNAME(     0x00000001, 0x00000001, "MAH4" )
 	PORT_DIPSETTING(  0x00000001, DEF_STR( Off ) )
 	PORT_DIPSETTING(  0x00000000, DEF_STR( On ) )
@@ -792,7 +795,7 @@ static INPUT_PORTS_START( bnstars )
 	PORT_DIPSETTING(  0x80000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(  0x00000000, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_DIPNAME(     0x00000001, 0x00000001, "MAH6" )
 	PORT_DIPSETTING(  0x00000001, DEF_STR( Off ) )
 	PORT_DIPSETTING(  0x00000000, DEF_STR( On ) )
@@ -882,7 +885,7 @@ static INPUT_PORTS_START( bnstars )
 	PORT_DIPSETTING(  0x80000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(  0x00000000, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN4")
 	PORT_BIT( 0x00000001, IP_ACTIVE_LOW, IPT_START2 )
 	/* The follow 4 bits active 4 button each one for the second player */
 	PORT_DIPNAME(     0x00000002, 0x00000002, "P2: A,B,C,D" )
@@ -975,7 +978,7 @@ static INPUT_PORTS_START( bnstars )
 	PORT_DIPSETTING(  0x80000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(  0x00000000, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN5")
 	PORT_DIPNAME(     0x00000001, 0x00000001, "Test Mode" ) PORT_DIPLOCATION("SW1:8")
 	PORT_DIPSETTING(  0x00000001, DEF_STR( Off ) )
 	PORT_DIPSETTING(  0x00000000, DEF_STR( On ) )
@@ -1074,7 +1077,7 @@ static INPUT_PORTS_START( bnstars )
 	PORT_DIPSETTING(  0x80000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(  0x00000000, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN6")
 	PORT_DIPNAME(     0x00000001, 0x00000001, "4" )
 	PORT_DIPSETTING(  0x00000001, DEF_STR( Off ) )
 	PORT_DIPSETTING(  0x00000000, DEF_STR( On ) )
@@ -1181,15 +1184,15 @@ static GFXLAYOUT_RAW( bglayout, 8, 16, 16, 16*8, 16*16*8 )
 static GFXLAYOUT_RAW( txlayout, 8, 8, 8, 8*8, 8*8*8 )
 
 static GFXDECODE_START( bnstars )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, spritelayout, 0x0000, 0x10 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0, bglayout,     0x5000, 0x10 ) /* Roz scr1 */
-	GFXDECODE_ENTRY( REGION_GFX4, 0, bglayout,     0x1000, 0x10 ) /* Bg scr1 */
-	GFXDECODE_ENTRY( REGION_GFX5, 0, txlayout,     0x6000, 0x10 ) /* Tx scr1 */
+	GFXDECODE_ENTRY( "gfx1", 0, spritelayout, 0x0000, 0x10 )
+	GFXDECODE_ENTRY( "gfx2", 0, bglayout,     0x5000, 0x10 ) /* Roz scr1 */
+	GFXDECODE_ENTRY( "gfx4", 0, bglayout,     0x1000, 0x10 ) /* Bg scr1 */
+	GFXDECODE_ENTRY( "gfx5", 0, txlayout,     0x6000, 0x10 ) /* Tx scr1 */
 
-	GFXDECODE_ENTRY( REGION_GFX1, 0, spritelayout, 0x8000+0x0000, 0x10 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0, bglayout,     0x8000+0x5000, 0x10 ) /* Roz scr2 */
-	GFXDECODE_ENTRY( REGION_GFX6, 0, bglayout,     0x8000+0x1000, 0x10 ) /* Bg scr2 */
-	GFXDECODE_ENTRY( REGION_GFX7, 0, txlayout,     0x8000+0x6000, 0x10 ) /* Tx scr2 */
+	GFXDECODE_ENTRY( "gfx1", 0, spritelayout, 0x8000+0x0000, 0x10 )
+	GFXDECODE_ENTRY( "gfx3", 0, bglayout,     0x8000+0x5000, 0x10 ) /* Roz scr2 */
+	GFXDECODE_ENTRY( "gfx6", 0, bglayout,     0x8000+0x1000, 0x10 ) /* Bg scr2 */
+	GFXDECODE_ENTRY( "gfx7", 0, txlayout,     0x8000+0x6000, 0x10 ) /* Tx scr2 */
 
 GFXDECODE_END
 
@@ -1202,28 +1205,28 @@ static READ32_HANDLER( bnstars1_r )
 			return 0xffffffff;
 
 		case 0x0000:
-			return readinputport(0);
+			return input_port_read(space->machine, "IN0");
 
 		case 0x0080:
-			return readinputport(1);
+			return input_port_read(space->machine, "IN1");
 
 		case 0x2000:
-			return readinputport(2);
+			return input_port_read(space->machine, "IN2");
 
 		case 0x2080:
-			return readinputport(3);
+			return input_port_read(space->machine, "IN3");
 
 	}
 }
 
 static READ32_HANDLER( bnstars2_r )
 {
-	return readinputport(4);
+	return input_port_read(space->machine, "IN4");
 }
 
 static READ32_HANDLER( bnstars3_r )
 {
-	return readinputport(5);
+	return input_port_read(space->machine, "IN5");
 }
 
 static WRITE32_HANDLER( bnstars1_mahjong_select_w )
@@ -1239,36 +1242,36 @@ static ADDRESS_MAP_START( bnstars_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0xfcc00008, 0xfcc0000b) AM_READ( bnstars2_r )
 	AM_RANGE(0xfcc00010, 0xfcc00013) AM_READ( bnstars3_r )
 
-	AM_RANGE(0xfce00034, 0xfce00037) AM_WRITE(MWA32_NOP)
+	AM_RANGE(0xfce00034, 0xfce00037) AM_WRITE(SMH_NOP)
 
-	AM_RANGE(0xfce00050, 0xfce00053) AM_WRITE(MWA32_NOP)
-	AM_RANGE(0xfce00058, 0xfce0005b) AM_WRITE(MWA32_NOP)
-	AM_RANGE(0xfce0005c, 0xfce0005f) AM_WRITE(MWA32_NOP)
+	AM_RANGE(0xfce00050, 0xfce00053) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xfce00058, 0xfce0005b) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xfce0005c, 0xfce0005f) AM_WRITE(SMH_NOP)
 
-	AM_RANGE(0xfce00400, 0xfce0045f) AM_WRITE(MWA32_RAM) AM_BASE(&ms32_roz_ctrl[0])
-	AM_RANGE(0xfce00700, 0xfce0075f) AM_WRITE(MWA32_RAM) AM_BASE(&ms32_roz_ctrl[1]) // guess
-	AM_RANGE(0xfce00a00, 0xfce00a17) AM_WRITE(MWA32_RAM) AM_BASE(&ms32_tx0_scroll)
-	AM_RANGE(0xfce00a20, 0xfce00a37) AM_WRITE(MWA32_RAM) AM_BASE(&ms32_bg0_scroll)
-	AM_RANGE(0xfce00c00, 0xfce00c17) AM_WRITE(MWA32_RAM) AM_BASE(&ms32_tx1_scroll)
-	AM_RANGE(0xfce00c20, 0xfce00c37) AM_WRITE(MWA32_RAM) AM_BASE(&ms32_bg1_scroll)
+	AM_RANGE(0xfce00400, 0xfce0045f) AM_WRITE(SMH_RAM) AM_BASE(&ms32_roz_ctrl[0])
+	AM_RANGE(0xfce00700, 0xfce0075f) AM_WRITE(SMH_RAM) AM_BASE(&ms32_roz_ctrl[1]) // guess
+	AM_RANGE(0xfce00a00, 0xfce00a17) AM_WRITE(SMH_RAM) AM_BASE(&ms32_tx0_scroll)
+	AM_RANGE(0xfce00a20, 0xfce00a37) AM_WRITE(SMH_RAM) AM_BASE(&ms32_bg0_scroll)
+	AM_RANGE(0xfce00c00, 0xfce00c17) AM_WRITE(SMH_RAM) AM_BASE(&ms32_tx1_scroll)
+	AM_RANGE(0xfce00c20, 0xfce00c37) AM_WRITE(SMH_RAM) AM_BASE(&ms32_bg1_scroll)
 
 	AM_RANGE(0xfce00e00, 0xfce00e03) AM_WRITE(bnstars1_mahjong_select_w) // ?
 
 	/* wrote together */
 	AM_RANGE(0xfd040000, 0xfd047fff) AM_RAM // priority ram
 	AM_RANGE(0xfd080000, 0xfd087fff) AM_RAM
-	AM_RANGE(0xfd200000, 0xfd237fff) AM_RAM AM_WRITE(ms32_pal1_ram_w) AM_BASE(&ms32_pal_ram[1])
-	AM_RANGE(0xfd400000, 0xfd437fff) AM_RAM AM_WRITE(ms32_pal0_ram_w) AM_BASE(&ms32_pal_ram[0])
-	AM_RANGE(0xfe000000, 0xfe01ffff) AM_RAM AM_WRITE(ms32_roz1_ram_w) AM_BASE(&ms32_roz1_ram)
-	AM_RANGE(0xfe400000, 0xfe41ffff) AM_RAM AM_WRITE(ms32_roz0_ram_w) AM_BASE(&ms32_roz0_ram)
-	AM_RANGE(0xfe800000, 0xfe83ffff) AM_RAM AM_WRITE(ms32_spramx_w) AM_BASE(&ms32_spram)
-	AM_RANGE(0xfea00000, 0xfea07fff) AM_RAM AM_WRITE(ms32_tx1_ram_w) AM_BASE(&ms32_tx1_ram)
-	AM_RANGE(0xfea08000, 0xfea0ffff) AM_RAM AM_WRITE(ms32_bg1_ram_w) AM_BASE(&ms32_bg1_ram)
- 	AM_RANGE(0xfec00000, 0xfec07fff) AM_RAM AM_WRITE(ms32_tx0_ram_w) AM_BASE(&ms32_tx0_ram)
-	AM_RANGE(0xfec08000, 0xfec0ffff) AM_RAM AM_WRITE(ms32_bg0_ram_w) AM_BASE(&ms32_bg0_ram)
+	AM_RANGE(0xfd200000, 0xfd237fff) AM_RAM_WRITE(ms32_pal1_ram_w) AM_BASE(&ms32_pal_ram[1])
+	AM_RANGE(0xfd400000, 0xfd437fff) AM_RAM_WRITE(ms32_pal0_ram_w) AM_BASE(&ms32_pal_ram[0])
+	AM_RANGE(0xfe000000, 0xfe01ffff) AM_RAM_WRITE(ms32_roz1_ram_w) AM_BASE(&ms32_roz1_ram)
+	AM_RANGE(0xfe400000, 0xfe41ffff) AM_RAM_WRITE(ms32_roz0_ram_w) AM_BASE(&ms32_roz0_ram)
+	AM_RANGE(0xfe800000, 0xfe83ffff) AM_RAM_WRITE(ms32_spramx_w) AM_BASE(&ms32_spram)
+	AM_RANGE(0xfea00000, 0xfea07fff) AM_RAM_WRITE(ms32_tx1_ram_w) AM_BASE(&ms32_tx1_ram)
+	AM_RANGE(0xfea08000, 0xfea0ffff) AM_RAM_WRITE(ms32_bg1_ram_w) AM_BASE(&ms32_bg1_ram)
+ 	AM_RANGE(0xfec00000, 0xfec07fff) AM_RAM_WRITE(ms32_tx0_ram_w) AM_BASE(&ms32_tx0_ram)
+	AM_RANGE(0xfec08000, 0xfec0ffff) AM_RAM_WRITE(ms32_bg0_ram_w) AM_BASE(&ms32_bg0_ram)
 
 	AM_RANGE(0xfee00000, 0xfee1ffff) AM_RAM
-	AM_RANGE(0xffe00000, 0xffffffff) AM_READWRITE(MRA32_BANK1, MWA32_ROM)
+	AM_RANGE(0xffe00000, 0xffffffff) AM_READWRITE(SMH_BANK1, SMH_ROM)
 ADDRESS_MAP_END
 
 #if 0
@@ -1277,46 +1280,36 @@ static ADDRESS_MAP_START( bnstars_z80_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 #endif
 
-static const struct YMF271interface ymf271_interface1 =
-{
-	REGION_SOUND1
-};
-
-static const struct YMF271interface ymf271_interface2 =
-{
-	REGION_SOUND2
-};
-
 static UINT16 irqreq;
 
-static int irq_callback(int irqline)
+static IRQ_CALLBACK(irq_callback)
 {
 	int i;
 	for(i=15; i>=0 && !(irqreq & (1<<i)); i--);
 	irqreq &= ~(1<<i);
 	if(!irqreq)
-		cpunum_set_input_line(Machine, 0, 0, CLEAR_LINE);
+		cpu_set_input_line(device, 0, CLEAR_LINE);
 	return i;
 }
 
-static void irq_init(void)
+static void irq_init(running_machine *machine)
 {
 	irqreq = 0;
-	cpunum_set_input_line(Machine, 0, 0, CLEAR_LINE);
-	cpunum_set_irq_callback(0, irq_callback);
+	cpu_set_input_line(machine->cpu[0], 0, CLEAR_LINE);
+	cpu_set_irq_callback(machine->cpu[0], irq_callback);
 }
 
-static void irq_raise(int level)
+static void irq_raise(running_machine *machine, int level)
 {
 	irqreq |= (1<<level);
-	cpunum_set_input_line(Machine, 0, 0, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[0], 0, ASSERT_LINE);
 }
 
 
 static INTERRUPT_GEN(ms32_interrupt)
 {
-	if( cpu_getiloops() == 0 ) irq_raise(10);
-	if( cpu_getiloops() == 1 ) irq_raise(9);
+	if( cpu_getiloops(device) == 0 ) irq_raise(device->machine, 10);
+	if( cpu_getiloops(device) == 1 ) irq_raise(device->machine, 9);
 	/* hayaosi1 needs at least 12 IRQ 0 per frame to work (see code at FFE02289)
        kirarast needs it too, at least 8 per frame, but waits for a variable amount
        47pi2 needs ?? per frame (otherwise it hangs when you lose)
@@ -1325,46 +1318,45 @@ static INTERRUPT_GEN(ms32_interrupt)
        desertwr
        p47aces
        */
-	if( cpu_getiloops() >= 3 && cpu_getiloops() <= 32 ) irq_raise(0);
+	if( cpu_getiloops(device) >= 3 && cpu_getiloops(device) <= 32 ) irq_raise(device->machine, 0);
 }
 
 static MACHINE_RESET( ms32 )
 {
-	irq_init();
+	irq_init(machine);
 }
 
 
 static MACHINE_DRIVER_START( bnstars )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(V70, 20000000) // 20MHz
+	MDRV_CPU_ADD("main", V70, 20000000) // 20MHz
 	MDRV_CPU_PROGRAM_MAP(bnstars_map,0)
-	MDRV_CPU_VBLANK_INT(ms32_interrupt,32)
+	MDRV_CPU_VBLANK_INT_HACK(ms32_interrupt,32)
 
-//  MDRV_CPU_ADD(Z80, 4000000) /* audio CPU */
+//  MDRV_CPU_ADD("audio", Z80, 4000000)
 //  MDRV_CPU_PROGRAM_MAP(bnstars_z80_map, 0)
 
-	MDRV_INTERLEAVE(1000)
+	MDRV_QUANTUM_TIME(HZ(60000))
 
 	MDRV_MACHINE_RESET(ms32)
 
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_GFXDECODE(bnstars)
 	MDRV_PALETTE_LENGTH(0x8000*2)
 
 	MDRV_DEFAULT_LAYOUT(layout_dualhsxs)
 
-	MDRV_SCREEN_ADD("left", 0x000)
+	MDRV_SCREEN_ADD("left", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_SIZE(40*8, 28*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 28*8-1)
 
-	MDRV_SCREEN_ADD("right", 0x000)
+	MDRV_SCREEN_ADD("right", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_SIZE(40*8, 28*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 28*8-1)
 
@@ -1374,13 +1366,11 @@ static MACHINE_DRIVER_START( bnstars )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(YMF271, 16934400)
-	MDRV_SOUND_CONFIG(ymf271_interface1)
+	MDRV_SOUND_ADD("ymf1", YMF271, 16934400)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 
-	MDRV_SOUND_ADD(YMF271, 16934400)
-	MDRV_SOUND_CONFIG(ymf271_interface2)
+	MDRV_SOUND_ADD("ymf2", YMF271, 16934400)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 
@@ -1388,14 +1378,14 @@ MACHINE_DRIVER_END
 
 
 ROM_START( bnstars1 )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 ) /* V70 code */
+	ROM_REGION( 0x200000, "main", 0 ) /* V70 code */
 	ROM_LOAD32_BYTE( "mb-93142.36", 0x000003, 0x80000, CRC(2eb6a503) SHA1(27c02ab1b4321924fd4499844467ea4dc97de25d) )
 	ROM_LOAD32_BYTE( "mb-93142.37", 0x000002, 0x80000, CRC(49f60882) SHA1(2ff5b0989aaf970103304a453773e0b9517ebb8d) )
 	ROM_LOAD32_BYTE( "mb-93142.38", 0x000001, 0x80000, CRC(6e1312cd) SHA1(4c22f8f9f1574eefd96147453cf240f50c17f5dc) )
 	ROM_LOAD32_BYTE( "mb-93142.39", 0x000000, 0x80000, CRC(56b98539) SHA1(5eb0e77729b31e6a100c1b43813a39fea57bedee) )
 
 	/* Sprites - shared by both screens? */
-	ROM_REGION( 0x1000000, REGION_GFX1, 0 ) /* sprites, don't dispose since we use GFX_RAW */
+	ROM_REGION( 0x1000000, "gfx1", 0 ) /* sprites, don't dispose since we use GFX_RAW */
 	ROM_LOAD32_WORD( "mr96004-01.20",   0x0000000, 0x200000, CRC(3366d104) SHA1(2de0cabe2ead777b5b02cade7f2003ef7f90b75b) )
 	ROM_LOAD32_WORD( "mr96004-02.28",   0x0000002, 0x200000, CRC(ad556664) SHA1(4b36f8d8d9efa37cf515af41d14433e7eafa27a2) )
 	ROM_LOAD32_WORD( "mr96004-03.21",   0x0400000, 0x200000, CRC(b399e2b1) SHA1(9b6a00a219db8d66dcf592160b7b5f7a86b8f0c9) )
@@ -1406,40 +1396,40 @@ ROM_START( bnstars1 )
 	ROM_LOAD32_WORD( "mr96004-08.31",   0x0c00002, 0x200000, CRC(f6df27b2) SHA1(60590976020d86bdccd4eaf57b349ea31bec6830) )
 
 	/* Roz Tiles #1 (Screen 1) */
-	ROM_REGION( 0x400000, REGION_GFX2, 0 ) /* roz tiles, don't dispose since we use GFX_RAW */
+	ROM_REGION( 0x400000, "gfx2", 0 ) /* roz tiles, don't dispose since we use GFX_RAW */
 	ROM_LOAD( "mr96004-09.1", 0x000000, 0x400000, CRC(7f8ea9f0) SHA1(f1fe682dcb884f1aa4a5536e17ab94157a99f519) )
 
 	/* Roz Tiles #2 (Screen 2) */
-	ROM_REGION( 0x400000, REGION_GFX3, 0 ) /* roz tiles, don't dispose since we use GFX_RAW */
+	ROM_REGION( 0x400000, "gfx3", 0 ) /* roz tiles, don't dispose since we use GFX_RAW */
 	ROM_LOAD( "mr96004-09.7", 0x000000, 0x400000, CRC(7f8ea9f0) SHA1(f1fe682dcb884f1aa4a5536e17ab94157a99f519) )
 
 	/* BG Tiles #1 (Screen 1?) */
-	ROM_REGION( 0x200000, REGION_GFX4, 0 ) /* bg tiles, don't dispose since we use GFX_RAW */
+	ROM_REGION( 0x200000, "gfx4", 0 ) /* bg tiles, don't dispose since we use GFX_RAW */
 	ROM_LOAD( "mr96004-11.11", 0x000000, 0x200000,  CRC(e6da552c) SHA1(69a5af3015883793c7d1343243ccae23db9ef77c) )
 
 	/* TX Tiles #1 (Screen 1?) */
-	ROM_REGION( 0x080000, REGION_GFX5, 0 ) /* tx tiles, don't dispose since we use GFX_RAW */
+	ROM_REGION( 0x080000, "gfx5", 0 ) /* tx tiles, don't dispose since we use GFX_RAW */
 	ROM_LOAD( "vsjanshi6.5", 0x000000, 0x080000, CRC(fdbbac21) SHA1(c77d852e53126cc8ebfe1e79d1134e42b54d1aab) )
 
 	/* BG Tiles #2 (Screen 2?) */
-	ROM_REGION( 0x200000, REGION_GFX6, 0 ) /* bg tiles, don't dispose since we use GFX_RAW */
+	ROM_REGION( 0x200000, "gfx6", 0 ) /* bg tiles, don't dispose since we use GFX_RAW */
 	ROM_LOAD( "mr96004-11.13", 0x000000, 0x200000, CRC(e6da552c) SHA1(69a5af3015883793c7d1343243ccae23db9ef77c) )
 
 	/* TX Tiles #2 (Screen 2?) */
-	ROM_REGION( 0x080000, REGION_GFX7, 0 ) /* tx tiles, don't dispose since we use GFX_RAW */
+	ROM_REGION( 0x080000, "gfx7", 0 ) /* tx tiles, don't dispose since we use GFX_RAW */
 	ROM_LOAD( "vsjanshi5.6", 0x000000, 0x080000, CRC(fdbbac21) SHA1(c77d852e53126cc8ebfe1e79d1134e42b54d1aab) )
 
 	/* Sound Program (one, driving both screen sound) */
-	ROM_REGION( 0x50000, REGION_CPU2, 0 ) /* z80 program */
+	ROM_REGION( 0x50000, "cpu1", 0 ) /* z80 program */
 	ROM_LOAD( "sb93145.5",  0x000000, 0x040000, CRC(0424e899) SHA1(fbcdebfa3d5f52b10cf30f7e416f5f53994e4d55) )
 	ROM_RELOAD(              0x010000, 0x40000 )
 
 	/* Samples #1 (Screen 1?) */
-	ROM_REGION( 0x400000, REGION_SOUND1, 0 ) /* samples - 8-bit signed PCM */
+	ROM_REGION( 0x400000, "ymf1", 0 ) /* samples - 8-bit signed PCM */
 	ROM_LOAD( "mr96004-10.1",  0x000000, 0x400000, CRC(83f4303a) SHA1(90ee010591afe1d35744925ef0e8d9a7e2ef3378) )
 
 	/* Samples #2 (Screen 2?) */
-	ROM_REGION( 0x400000, REGION_SOUND2, 0 ) /* samples - 8-bit signed PCM */
+	ROM_REGION( 0x400000, "ymf2", 0 ) /* samples - 8-bit signed PCM */
 	ROM_LOAD( "mr96004-10.1",  0x000000, 0x400000, CRC(83f4303a) SHA1(90ee010591afe1d35744925ef0e8d9a7e2ef3378) )
 ROM_END
 
@@ -1447,14 +1437,14 @@ ROM_END
 /* SS92046_01: bbbxing, f1superb, tetrisp, hayaosi1 */
 static DRIVER_INIT (bnstars)
 {
-	ms32_rearrange_sprites(REGION_GFX1);
+	ms32_rearrange_sprites(machine, "gfx1");
 
-	decrypt_ms32_tx(0x00020,0x7e, REGION_GFX5);
-	decrypt_ms32_bg(0x00001,0x9b, REGION_GFX4);
-	decrypt_ms32_tx(0x00020,0x7e, REGION_GFX7);
-	decrypt_ms32_bg(0x00001,0x9b, REGION_GFX6);
+	decrypt_ms32_tx(machine, 0x00020,0x7e, "gfx5");
+	decrypt_ms32_bg(machine, 0x00001,0x9b, "gfx4");
+	decrypt_ms32_tx(machine, 0x00020,0x7e, "gfx7");
+	decrypt_ms32_bg(machine, 0x00001,0x9b, "gfx6");
 
-	memory_set_bankptr(1, memory_region(REGION_CPU1));
+	memory_set_bankptr(machine, 1, memory_region(machine, "main"));
 }
 
 GAME( 1997, bnstars1, 0,        bnstars, bnstars, bnstars, ROT0,   "Jaleco", "Vs. Janshi Brandnew Stars", GAME_NO_SOUND )
