@@ -78,6 +78,7 @@ Notes:
 */
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
 #include "machine/segacrpt.h"
 #include "sound/ay8910.h"
 
@@ -89,7 +90,7 @@ static tilemap *bg_tilemap,*fg_tilemap;
 
 static TILE_GET_INFO( get_bg_tile_info )
 {
-	UINT8 *src = memory_region(REGION_USER1);
+	UINT8 *src = memory_region(machine, "user1");
 	int bg_base = (calorie_bg & 0x0f) * 0x200;
 	int code  = src[bg_base + tile_index] | (((src[bg_base + tile_index + 0x100]) & 0x10) << 4);
 	int color = src[bg_base + tile_index + 0x100] & 0x0f;
@@ -109,8 +110,8 @@ static TILE_GET_INFO( get_fg_tile_info )
 
 static VIDEO_START( calorie )
 {
-	bg_tilemap = tilemap_create(get_bg_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,     16,16,16,16);
-	fg_tilemap = tilemap_create(get_fg_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN, 8, 8,32,32);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info,tilemap_scan_rows,16,16,16,16);
+	fg_tilemap = tilemap_create(machine, get_fg_tile_info,tilemap_scan_rows,8, 8,32,32);
 
 	tilemap_set_transparent_pen(fg_tilemap,0);
 }
@@ -141,7 +142,7 @@ static VIDEO_UPDATE( calorie )
 		ypos = 0xff - calorie_sprites[x+2];
 		xpos = calorie_sprites[x+3];
 
-		if(flip_screen)
+		if(flip_screen_get(screen->machine))
 		{
 			if( calorie_sprites[x+1] & 0x10 )
 				ypos = 0xff - ypos + 32;
@@ -156,12 +157,12 @@ static VIDEO_UPDATE( calorie )
 		if( calorie_sprites[x+1] & 0x10 )
 		{
 			 /* 32x32 sprites */
-			drawgfx(bitmap,machine->gfx[3],tileno | 0x40,color,flipx,flipy,xpos,ypos - 31,cliprect,TRANSPARENCY_PEN,0);
+			drawgfx(bitmap,screen->machine->gfx[3],tileno | 0x40,color,flipx,flipy,xpos,ypos - 31,cliprect,TRANSPARENCY_PEN,0);
 		}
 		else
 		{
 			/* 16x16 sprites */
-			drawgfx(bitmap,machine->gfx[2],tileno,color,flipx,flipy,xpos,ypos - 15,cliprect,TRANSPARENCY_PEN,0);
+			drawgfx(bitmap,screen->machine->gfx[2],tileno,color,flipx,flipy,xpos,ypos - 15,cliprect,TRANSPARENCY_PEN,0);
 		}
 	}
 	return 0;
@@ -185,13 +186,13 @@ static WRITE8_HANDLER( calorie_bg_w )
 
 static WRITE8_HANDLER( calorie_flipscreen_w )
 {
-	flip_screen_set(data & 1);
+	flip_screen_set(space->machine, data & 1);
 }
 
 static READ8_HANDLER( calorie_soundlatch_r )
 {
-	UINT8 latch = soundlatch_r(0);
-	soundlatch_clear_w(0,0);
+	UINT8 latch = soundlatch_r(space,0);
+	soundlatch_clear_w(space,0,0);
 	return latch;
 }
 
@@ -204,15 +205,15 @@ static ADDRESS_MAP_START( calorie_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0x8000, 0xbfff) AM_ROM
 	AM_RANGE(0xc000, 0xcfff) AM_RAM
-	AM_RANGE(0xd000, 0xd7ff) AM_RAM AM_WRITE(calorie_fg_w) AM_BASE(&calorie_fg)
+	AM_RANGE(0xd000, 0xd7ff) AM_RAM_WRITE(calorie_fg_w) AM_BASE(&calorie_fg)
 	AM_RANGE(0xd800, 0xdbff) AM_RAM AM_BASE(&calorie_sprites)
-	AM_RANGE(0xdc00, 0xdcff) AM_RAM AM_WRITE(paletteram_xxxxBBBBGGGGRRRR_le_w) AM_BASE(&paletteram)
+	AM_RANGE(0xdc00, 0xdcff) AM_RAM_WRITE(paletteram_xxxxBBBBGGGGRRRR_le_w) AM_BASE(&paletteram)
 	AM_RANGE(0xde00, 0xde00) AM_WRITE(calorie_bg_w)
-	AM_RANGE(0xf000, 0xf000) AM_READ(input_port_0_r)
-	AM_RANGE(0xf001, 0xf001) AM_READ(input_port_1_r)
-	AM_RANGE(0xf002, 0xf002) AM_READ(input_port_2_r)
-	AM_RANGE(0xf004, 0xf004) AM_READ(input_port_3_r) AM_WRITE(calorie_flipscreen_w)
-	AM_RANGE(0xf005, 0xf005) AM_READ(input_port_4_r)
+	AM_RANGE(0xf000, 0xf000) AM_READ_PORT("P1")
+	AM_RANGE(0xf001, 0xf001) AM_READ_PORT("P2")
+	AM_RANGE(0xf002, 0xf002) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0xf004, 0xf004) AM_READ_PORT("DSW1") AM_WRITE(calorie_flipscreen_w)
+	AM_RANGE(0xf005, 0xf005) AM_READ_PORT("DSW2")
 	AM_RANGE(0xf800, 0xf800) AM_WRITE(soundlatch_w)
 ADDRESS_MAP_END
 
@@ -224,37 +225,37 @@ static ADDRESS_MAP_START( calorie_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( calorie_sound_io_map, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0x01, 0x01) AM_READWRITE(AY8910_read_port_0_r, AY8910_write_port_0_w)
-	AM_RANGE(0x10, 0x10) AM_WRITE(AY8910_control_port_1_w)
-	AM_RANGE(0x11, 0x11) AM_READWRITE(AY8910_read_port_1_r, AY8910_write_port_1_w)
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x00, 0x00) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0x01, 0x01) AM_READWRITE(ay8910_read_port_0_r, ay8910_write_port_0_w)
+	AM_RANGE(0x10, 0x10) AM_WRITE(ay8910_control_port_1_w)
+	AM_RANGE(0x11, 0x11) AM_READWRITE(ay8910_read_port_1_r, ay8910_write_port_1_w)
 	// 3rd ?
 	AM_RANGE(0x00, 0xff) AM_WRITE(bogus_w)
 ADDRESS_MAP_END
 
 static INPUT_PORTS_START( calorie )
-	PORT_START
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP )    PORT_PLAYER(1) PORT_4WAY
-	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN )  PORT_PLAYER(1) PORT_4WAY
-	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT )  PORT_PLAYER(1) PORT_4WAY
+	PORT_START("P1")
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_PLAYER(1) PORT_4WAY
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1) PORT_4WAY
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_PLAYER(1) PORT_4WAY
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(1) PORT_4WAY
 	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(1)
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_PLAYER(1)
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 
-	PORT_START
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP )    PORT_COCKTAIL PORT_4WAY
-	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN )  PORT_COCKTAIL PORT_4WAY
-	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT )  PORT_COCKTAIL PORT_4WAY
+	PORT_START("P2")
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_COCKTAIL PORT_4WAY
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN ) PORT_COCKTAIL PORT_4WAY
+	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_COCKTAIL PORT_4WAY
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_COCKTAIL PORT_4WAY
 	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_COCKTAIL
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_COCKTAIL
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("SYSTEM")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_START1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_START2 )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN1 )
@@ -264,7 +265,7 @@ static INPUT_PORTS_START( calorie )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("DSW1")
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Coin_A ) ) PORT_DIPLOCATION("SW1:1,2")
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( 1C_2C ) )
@@ -287,7 +288,7 @@ static INPUT_PORTS_START( calorie )
 	PORT_DIPSETTING(    0x40, "4" )
 	PORT_DIPSETTING(    0x80, "5" )
 
-	PORT_START
+	PORT_START("DSW2")
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Bonus_Life ) ) PORT_DIPLOCATION("SW2:1,2")
 	PORT_DIPSETTING(    0x00, DEF_STR( None ) )
 	PORT_DIPSETTING(    0x01, "20,000 Only" )
@@ -352,31 +353,31 @@ static const gfx_layout tiles32x32_layout =
 };
 
 static GFXDECODE_START( calorie )
-	GFXDECODE_ENTRY( REGION_GFX2, 0, tiles8x8_layout,   0, 16 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0, tiles16x16_layout, 0, 16 )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, tiles16x16_layout, 0, 16 )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, tiles32x32_layout, 0, 16 )
+	GFXDECODE_ENTRY( "gfx2", 0, tiles8x8_layout,   0, 16 )
+	GFXDECODE_ENTRY( "gfx3", 0, tiles16x16_layout, 0, 16 )
+	GFXDECODE_ENTRY( "gfx1", 0, tiles16x16_layout, 0, 16 )
+	GFXDECODE_ENTRY( "gfx1", 0, tiles32x32_layout, 0, 16 )
 GFXDECODE_END
 
 static MACHINE_DRIVER_START( calorie )
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80,4000000)		 /* 4 MHz */
+	MDRV_CPU_ADD("main", Z80,4000000)		 /* 4 MHz */
 	MDRV_CPU_PROGRAM_MAP(calorie_map,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
-	MDRV_CPU_ADD(Z80,3000000)		 /* 3 MHz */
+	MDRV_CPU_ADD("audio", Z80,3000000)		 /* 3 MHz */
 	MDRV_CPU_PROGRAM_MAP(calorie_sound_map,0)
 	MDRV_CPU_IO_MAP(calorie_sound_io_map,0)
 	MDRV_CPU_PERIODIC_INT(irq0_line_hold, 64)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 256)
 	MDRV_SCREEN_VISIBLE_AREA(0, 256-1, 16, 256-16-1)
+
 	MDRV_GFXDECODE(calorie)
 	MDRV_PALETTE_LENGTH(0x100)
 
@@ -386,70 +387,70 @@ static MACHINE_DRIVER_START( calorie )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ADD("ay1", AY8910, 1500000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.8)  /* YM2149 really */
 
-	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ADD("ay2", AY8910, 1500000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.8)  /* YM2149 really */
 
-	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ADD("ay3", AY8910, 1500000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.8)  /* YM2149 really */
 MACHINE_DRIVER_END
 
 
 ROM_START( calorie )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "epr10072.1j", 0x00000, 0x4000, CRC(ade792c1) SHA1(6ea5afb00a87037d502c17adda7e4060d12680d7) )
 	ROM_LOAD( "epr10073.1k", 0x04000, 0x4000, CRC(b53e109f) SHA1(a41c5affe917232e7adf40d7c15cff778b197e90) )
 	ROM_LOAD( "epr10074.1m", 0x08000, 0x4000, CRC(a08da685) SHA1(69f9cfebc771312dbb1726350c2d9e9e8c46353f) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "epr10075.4d", 0x0000, 0x4000, CRC(ca547036) SHA1(584a65482f2b92a4c08c37560450d6db68a56c7b) )
 
-	ROM_REGION( 0x2000, REGION_USER1, 0 ) /* background tilemaps */
+	ROM_REGION( 0x2000, "user1", 0 ) /* background tilemaps */
 	ROM_LOAD( "epr10079.8d", 0x0000, 0x2000, CRC(3c61a42c) SHA1(68ea6b5d2f3c6a9e5308c08dde20424f20021a73) )
 
-	ROM_REGION( 0xc000, REGION_GFX1, ROMREGION_DISPOSE ) /* sprites */
+	ROM_REGION( 0xc000, "gfx1", ROMREGION_DISPOSE ) /* sprites */
 	ROM_LOAD( "epr10071.7m", 0x0000, 0x4000, CRC(5f55527a) SHA1(ec1ba8f95ac47a0c783e117ef4af6fe0ab5925b5) )
 	ROM_LOAD( "epr10070.7k", 0x4000, 0x4000, CRC(97f35a23) SHA1(869553a334e1b3ba900a8b9c9eaf25fbc6ab31dd) )
 	ROM_LOAD( "epr10069.7j", 0x8000, 0x4000, CRC(c0c3deaf) SHA1(8bf2e2146b794a330a079dd080f0586500964b1a) )
 
-	ROM_REGION( 0x6000, REGION_GFX2, ROMREGION_DISPOSE ) /* tiles  */
+	ROM_REGION( 0x6000, "gfx2", ROMREGION_DISPOSE ) /* tiles  */
 	ROM_LOAD( "epr10082.5r", 0x0000, 0x2000, CRC(5984ea44) SHA1(010011b5b8dfa593c6fc7d2366f8cf82fcc8c978) )
 	ROM_LOAD( "epr10081.4r", 0x2000, 0x2000, CRC(e2d45dd8) SHA1(5e11089680b574ea4cbf64510e51b0a945f79174) )
 	ROM_LOAD( "epr10080.3r", 0x4000, 0x2000, CRC(42edfcfe) SHA1(feba7b1daffcad24d4c24f55ab5466f8cebf31ad) )
 
-	ROM_REGION( 0xc000, REGION_GFX3, ROMREGION_DISPOSE ) /* tiles */
+	ROM_REGION( 0xc000, "gfx3", ROMREGION_DISPOSE ) /* tiles */
 	ROM_LOAD( "epr10078.7d", 0x0000, 0x4000, CRC(5b8eecce) SHA1(e7eee82081939b361edcbb9587b072b4b9a162f9) )
 	ROM_LOAD( "epr10077.6d", 0x4000, 0x4000, CRC(01bcb609) SHA1(5d01fa75f214d34483284aaaef985ab92a606505) )
 	ROM_LOAD( "epr10076.5d", 0x8000, 0x4000, CRC(b1529782) SHA1(8e0e92aae4c8dd8720414372aa767054cc316a0f) )
 ROM_END
 
 ROM_START( calorieb )
-	ROM_REGION( 0x1c000, REGION_CPU1, 0 )
+	ROM_REGION( 0x1c000, "main", 0 )
 	ROM_LOAD( "12.bin",      0x10000, 0x4000, CRC(cf5fa69e) SHA1(520d5652e93a672a1fc147295fbd63b873967885) )
 	ROM_CONTINUE(            0x00000, 0x4000 )
 	ROM_LOAD( "13.bin",      0x14000, 0x4000, CRC(52e7263f) SHA1(4d684c9e3f08ddb18b0b3b982aba82d3c809a633) )
 	ROM_CONTINUE(            0x04000, 0x4000 )
 	ROM_LOAD( "epr10074.1m", 0x08000, 0x4000, CRC(a08da685) SHA1(69f9cfebc771312dbb1726350c2d9e9e8c46353f) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "epr10075.4d", 0x0000, 0x4000, CRC(ca547036) SHA1(584a65482f2b92a4c08c37560450d6db68a56c7b) )
 
-	ROM_REGION( 0x2000, REGION_USER1, 0 ) /* background tilemaps */
+	ROM_REGION( 0x2000, "user1", 0 ) /* background tilemaps */
 	ROM_LOAD( "epr10079.8d", 0x0000, 0x2000, CRC(3c61a42c) SHA1(68ea6b5d2f3c6a9e5308c08dde20424f20021a73) )
 
-	ROM_REGION( 0xc000, REGION_GFX1, ROMREGION_DISPOSE ) /* sprites */
+	ROM_REGION( 0xc000, "gfx1", ROMREGION_DISPOSE ) /* sprites */
 	ROM_LOAD( "epr10071.7m", 0x0000, 0x4000, CRC(5f55527a) SHA1(ec1ba8f95ac47a0c783e117ef4af6fe0ab5925b5) )
 	ROM_LOAD( "epr10070.7k", 0x4000, 0x4000, CRC(97f35a23) SHA1(869553a334e1b3ba900a8b9c9eaf25fbc6ab31dd) )
 	ROM_LOAD( "epr10069.7j", 0x8000, 0x4000, CRC(c0c3deaf) SHA1(8bf2e2146b794a330a079dd080f0586500964b1a) )
 
-	ROM_REGION( 0x6000, REGION_GFX2, ROMREGION_DISPOSE ) /* tiles  */
+	ROM_REGION( 0x6000, "gfx2", ROMREGION_DISPOSE ) /* tiles  */
 	ROM_LOAD( "epr10082.5r", 0x0000, 0x2000, CRC(5984ea44) SHA1(010011b5b8dfa593c6fc7d2366f8cf82fcc8c978) )
 	ROM_LOAD( "epr10081.4r", 0x2000, 0x2000, CRC(e2d45dd8) SHA1(5e11089680b574ea4cbf64510e51b0a945f79174) )
 	ROM_LOAD( "epr10080.3r", 0x4000, 0x2000, CRC(42edfcfe) SHA1(feba7b1daffcad24d4c24f55ab5466f8cebf31ad) )
 
-	ROM_REGION( 0xc000, REGION_GFX3, ROMREGION_DISPOSE ) /* tiles */
+	ROM_REGION( 0xc000, "gfx3", ROMREGION_DISPOSE ) /* tiles */
 	ROM_LOAD( "epr10078.7d", 0x0000, 0x4000, CRC(5b8eecce) SHA1(e7eee82081939b361edcbb9587b072b4b9a162f9) )
 	ROM_LOAD( "epr10077.6d", 0x4000, 0x4000, CRC(01bcb609) SHA1(5d01fa75f214d34483284aaaef985ab92a606505) )
 	ROM_LOAD( "epr10076.5d", 0x8000, 0x4000, CRC(b1529782) SHA1(8e0e92aae4c8dd8720414372aa767054cc316a0f) )
@@ -458,12 +459,13 @@ ROM_END
 
 static DRIVER_INIT( calorie )
 {
-	calorie_decode();
+	calorie_decode(machine, "main");
 }
 
 static DRIVER_INIT( calorieb )
 {
-	memory_set_decrypted_region(0, 0x0000, 0x7fff, memory_region(REGION_CPU1) + 0x10000);
+	const address_space *space = cputag_get_address_space(machine, "main", ADDRESS_SPACE_PROGRAM);
+	memory_set_decrypted_region(space, 0x0000, 0x7fff, memory_region(machine, "main") + 0x10000);
 }
 
 
