@@ -74,8 +74,8 @@ Side 2 = 0x8F7DDD (or 0x880000 | ( 0x77 << 12 ) | 0x0DDD)
 *********************************************************/
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
 #include "render.h"
-#include "deprecat.h"
 #include "machine/laserdsc.h"
 #include "video/tms9928a.h"
 #include "sound/discrete.h"
@@ -83,70 +83,15 @@ Side 2 = 0x8F7DDD (or 0x880000 | ( 0x77 << 12 ) | 0x0DDD)
 #define CLIFF_ENABLE_SND_1	NODE_01
 #define CLIFF_ENABLE_SND_2	NODE_02
 
-static laserdisc_info *discinfo = NULL;
+static const device_config *laserdisc;
 
 static int port_bank = 0;
 static int phillips_code = 0;
 
-static render_texture *video_texture;
-static render_texture *overlay_texture;
-static mame_bitmap *last_video_bitmap;
-
 static emu_timer *irq_timer;
 
 /********************************************************/
 
-static void video_cleanup(running_machine *machine)
-{
-	if (video_texture != NULL)
-		render_texture_free(video_texture);
-	if (overlay_texture != NULL)
-		render_texture_free(overlay_texture);
-	laserdisc_exit(discinfo);
-}
-
-static VIDEO_UPDATE( cliff )
-{
-	/* update the TMS9928A video */
-	VIDEO_UPDATE_CALL(tms9928a);
-
-	if (discinfo != NULL)
-	{
-		mame_bitmap *vidbitmap;
-		rectangle fixedvis = *TMS9928A_get_visarea();
-		fixedvis.max_x++;
-		fixedvis.max_y++;
-
-		laserdisc_get_video(discinfo, &vidbitmap);
-
-		/* first lay down the video data */
-		if (video_texture == NULL)
-			video_texture = render_texture_alloc(NULL, NULL);
-		if (vidbitmap != last_video_bitmap)
-			render_texture_set_bitmap(video_texture, vidbitmap, NULL, 0, TEXFORMAT_YUY16);
-
-		last_video_bitmap = vidbitmap;
-
-		/* then overlay the TMS9928A video */
-		if (overlay_texture == NULL)
-			overlay_texture = render_texture_alloc(NULL, NULL);
-		render_texture_set_bitmap(overlay_texture, bitmap, &fixedvis, 0, TEXFORMAT_PALETTEA16);
-
-		/* add both quads to the screen */
-		render_container_empty(render_container_get_screen(screen));
-		render_screen_add_quad(screen, 0.0f, 0.0f, 1.0f, 1.0f, MAKE_ARGB(0xff,0xff,0xff,0xff), video_texture, PRIMFLAG_BLENDMODE(BLENDMODE_NONE) | PRIMFLAG_SCREENTEX(1));
-		render_screen_add_quad(screen, 0.0f, 0.0f, 1.0f, 1.0f, MAKE_ARGB(0xff,0xff,0xff,0xff), overlay_texture, PRIMFLAG_BLENDMODE(BLENDMODE_ALPHA) | PRIMFLAG_SCREENTEX(1));
-	}
-
-	/* display disc information */
-	if (discinfo != NULL)
-		popmessage("%s", laserdisc_describe_state(discinfo));
-
-	return 0;
-}
-
-/********************************************************/
-
 static WRITE8_HANDLER( cliff_test_led_w )
 {
 	set_led_status( 0, offset ^ 1 );
@@ -163,9 +108,11 @@ static WRITE8_HANDLER( cliff_port_bank_w )
 
 static READ8_HANDLER( cliff_port_r )
 {
+	static const char *const banknames[] = { "BANK0", "BANK1", "BANK2", "BANK3", "BANK4", "BANK5", "BANK6" };
+
 	if ( port_bank < 7 )
 	{
-		return readinputport( port_bank );
+		return input_port_read(space->machine,  banknames[port_bank]);
 	}
 
 	/* output is pulled up for non-mapped ports */
@@ -174,7 +121,7 @@ static READ8_HANDLER( cliff_port_r )
 
 static READ8_HANDLER( cliff_phillips_code_r )
 {
-	if ( discinfo != NULL )
+	if ( laserdisc != NULL )
 	{
 		return ( phillips_code >> (8*offset) ) & 0xff;
 	}
@@ -190,7 +137,7 @@ static WRITE8_HANDLER( cliff_coin_counter_w )
 static READ8_HANDLER( cliff_irq_ack_r )
 {
 	/* deassert IRQ on the CPU */
-	cpunum_set_input_line(Machine, 0, 0, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[0], 0, CLEAR_LINE);
 
 	return 0x00;
 }
@@ -201,24 +148,25 @@ static WRITE8_HANDLER( cliff_sound_overlay_w )
 	int overlay = ( data & 0x10 ) ? 1 : 0;
 
 	/* configure pen 0 and 1 as transparent in the renderer and use it as the compositing color */
-	render_container_set_palette_alpha(render_container_get_screen(0), 0, overlay ? 0x00 : 0xff );
-	render_container_set_palette_alpha(render_container_get_screen(0), 1, overlay ? 0x00 : 0xff );
+	if (overlay)
+	{
+		palette_set_color(space->machine, 0, palette_get_color(space->machine, 0) & MAKE_ARGB(0,255,255,255));
+		palette_set_color(space->machine, 1, palette_get_color(space->machine, 1) & MAKE_ARGB(0,255,255,255));
+	}
+	else
+	{
+		palette_set_color(space->machine, 0, palette_get_color(space->machine, 0) | MAKE_ARGB(255,0,0,0));
+		palette_set_color(space->machine, 1, palette_get_color(space->machine, 1) | MAKE_ARGB(255,0,0,0));
+	}
 
 	/* audio */
-	discrete_sound_w(CLIFF_ENABLE_SND_1, sound&1);
-	discrete_sound_w(CLIFF_ENABLE_SND_2, (sound>>1)&1);
+	discrete_sound_w(space, CLIFF_ENABLE_SND_1, sound&1);
+	discrete_sound_w(space, CLIFF_ENABLE_SND_2, (sound>>1)&1);
 }
 
-#ifdef UNUSED_FUNCTION
-static WRITE8_HANDLER( cliff_irqack_w )
-{
-	phillips_code = 0;
-}
-#endif
-
 static WRITE8_HANDLER( cliff_ldwire_w )
 {
-	laserdisc_line_w(discinfo,LASERDISC_LINE_CONTROL,(data&1) ? ASSERT_LINE : CLEAR_LINE );
+	laserdisc_line_w(laserdisc,LASERDISC_LINE_CONTROL,(data&1) ? ASSERT_LINE : CLEAR_LINE );
 }
 
 
@@ -226,9 +174,8 @@ static WRITE8_HANDLER( cliff_ldwire_w )
 
 static INTERRUPT_GEN( cliff_vsync )
 {
-	/* clock the laserdisc and video chip every 60Hz */
-	laserdisc_vsync(discinfo);
-	TMS9928A_interrupt();
+	/* clock the video chip every 60Hz */
+	TMS9928A_interrupt(device->machine);
 }
 
 static TIMER_CALLBACK( cliff_irq_callback )
@@ -238,41 +185,41 @@ static TIMER_CALLBACK( cliff_irq_callback )
 	switch (param)
 	{
 		case 17:
-			phillips_code = laserdisc_get_field_code(discinfo, LASERDISC_CODE_LINE17);
+			phillips_code = laserdisc_get_field_code(laserdisc, LASERDISC_CODE_LINE17);
 			param = 18;
 			break;
 
 		case 18:
-			phillips_code = laserdisc_get_field_code(discinfo, LASERDISC_CODE_LINE18);
+			phillips_code = laserdisc_get_field_code(laserdisc, LASERDISC_CODE_LINE18);
 			param = 17;
 			break;
 	}
 
 	/* if we have a valid code, trigger an IRQ */
 	if ( phillips_code & 0x800000 )
-		cpunum_set_input_line(machine, 0, 0, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[0], 0, ASSERT_LINE);
 
-	timer_adjust(irq_timer, video_screen_get_time_until_pos(0, param, 0), param, attotime_zero);
+	timer_adjust_oneshot(irq_timer, video_screen_get_time_until_pos(machine->primary_screen, param, 0), param);
 }
 
-static void vdp_interrupt (int state)
+static void vdp_interrupt (running_machine *machine, int state)
 {
-	cpunum_set_input_line(Machine, 0, INPUT_LINE_NMI, state ? ASSERT_LINE : CLEAR_LINE );
+	cpu_set_input_line(machine->cpu[0], INPUT_LINE_NMI, state ? ASSERT_LINE : CLEAR_LINE );
 }
 
 
 
 static MACHINE_START( cliffhgr )
 {
-	discinfo = laserdisc_init(LASERDISC_TYPE_PR8210, get_disk_handle(0), 0);
-	irq_timer = timer_alloc(cliff_irq_callback, NULL);
+	laserdisc = device_list_find_by_tag(machine->config->devicelist, LASERDISC, "laserdisc");
+	irq_timer = timer_alloc(machine, cliff_irq_callback, NULL);
 }
 
 static MACHINE_RESET( cliffhgr )
 {
 	port_bank = 0;
 	phillips_code = 0;
-	timer_adjust(irq_timer, video_screen_get_time_until_pos(0, 17, 0), 17, attotime_zero);
+	timer_adjust_oneshot(irq_timer, video_screen_get_time_until_pos(machine->primary_screen, 17, 0), 17);
 }
 
 /********************************************************/
@@ -284,7 +231,7 @@ static ADDRESS_MAP_START( mainmem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( mainport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x44, 0x44) AM_WRITE(TMS9928A_vram_w)
 	AM_RANGE(0x45, 0x45) AM_READ(TMS9928A_vram_r)
 	AM_RANGE(0x46, 0x46) AM_WRITE(cliff_sound_overlay_w)
@@ -310,12 +257,12 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( cliffhgr )
-	PORT_START_TAG("BANK0")
+	PORT_START("BANK0")
 	PORT_BIT ( 0x3F, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_SERVICE2 )	/* SW2 on CPU PCB */
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_SERVICE1 )	/* SW1 on CPU PCB */
 
-	PORT_START_TAG("BANK1")
+	PORT_START("BANK1")
 	PORT_DIPNAME( 0xc0, 0xc0, "Should Have Hint" )		PORT_DIPLOCATION("E11:7,8")
 	PORT_DIPSETTING(    0xc0, "Never" )
 	PORT_DIPSETTING(    0x80, "After 1st Player Mistake" )
@@ -339,7 +286,7 @@ static INPUT_PORTS_START( cliffhgr )
 	PORT_DIPSETTING(    0x01, "5" )
 	PORT_DIPSETTING(    0x00, "6" )
 
-	PORT_START_TAG("BANK2")
+	PORT_START("BANK2")
 	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )		PORT_DIPLOCATION("F11:8")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -364,7 +311,7 @@ static INPUT_PORTS_START( cliffhgr )
 	PORT_DIPSETTING(    0x02, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) )
 
-	PORT_START_TAG("BANK3")
+	PORT_START("BANK3")
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Allow_Continue ) )	PORT_DIPLOCATION("G11:8")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -390,7 +337,7 @@ static INPUT_PORTS_START( cliffhgr )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START_TAG("BANK4")
+	PORT_START("BANK4")
 	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )		PORT_DIPLOCATION("H11:8")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -421,7 +368,7 @@ static INPUT_PORTS_START( cliffhgr )
 	PORT_DIPSETTING(    0x01, "14" )
 	PORT_DIPSETTING(    0x00, "15 (Hardest)" )
 
-	PORT_START_TAG("BANK5")
+	PORT_START("BANK5")
 	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
@@ -431,7 +378,7 @@ static INPUT_PORTS_START( cliffhgr )
 	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_TILT )
 
-	PORT_START_TAG("BANK6")
+	PORT_START("BANK6")
 	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )
 	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT )
 	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )
@@ -440,12 +387,12 @@ static INPUT_PORTS_START( cliffhgr )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( cliffhga )
-	PORT_START_TAG("BANK0")
+	PORT_START("BANK0")
 	PORT_BIT ( 0x3F, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_SERVICE2 )	/* SW2 on CPU PCB */
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_SERVICE1 )	/* SW1 on CPU PCB */
 
-	PORT_START_TAG("BANK1")
+	PORT_START("BANK1")
 	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )		PORT_DIPLOCATION("E11:8")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -470,7 +417,7 @@ static INPUT_PORTS_START( cliffhga )
 	PORT_DIPSETTING(    0x01, "5" )
 	PORT_DIPSETTING(    0x00, "6" )
 
-	PORT_START_TAG("BANK2")
+	PORT_START("BANK2")
 	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )		PORT_DIPLOCATION("F11:8")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -495,7 +442,7 @@ static INPUT_PORTS_START( cliffhga )
 //  PORT_DIPSETTING(    0x02, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( 2C_1C ) )
 
-	PORT_START_TAG("BANK3")
+	PORT_START("BANK3")
 	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )		PORT_DIPLOCATION("G11:8")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -521,7 +468,7 @@ static INPUT_PORTS_START( cliffhga )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START_TAG("BANK4")
+	PORT_START("BANK4")
 	PORT_DIPNAME( 0xf0, 0xf0, "Hint Difficulty" )		PORT_DIPLOCATION("H11:5,6,7,8")
 	PORT_DIPSETTING(    0xf0, "0 (Most Hints)" )
 	PORT_DIPSETTING(    0xe0, "1" )
@@ -557,7 +504,7 @@ static INPUT_PORTS_START( cliffhga )
 	PORT_DIPSETTING(    0x01, "14" )
 	PORT_DIPSETTING(    0x00, "15 (Hardest)" )
 
-	PORT_START_TAG("BANK5")
+	PORT_START("BANK5")
 	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
@@ -567,7 +514,7 @@ static INPUT_PORTS_START( cliffhga )
 	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_TILT )
 
-	PORT_START_TAG("BANK6")
+	PORT_START("BANK6")
 	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )
 	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT )
 	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )
@@ -576,12 +523,12 @@ static INPUT_PORTS_START( cliffhga )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( goaltogo )
-	PORT_START_TAG("BANK0")
+	PORT_START("BANK0")
 	PORT_BIT ( 0x3F, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_SERVICE2 )	/* SW2 on CPU PCB */
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_SERVICE1 )	/* SW1 on CPU PCB */
 
-	PORT_START_TAG("BANK1")
+	PORT_START("BANK1")
 	PORT_DIPNAME( 0x80, 0x80, "Should Have Hint" )		PORT_DIPLOCATION("E11:8")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -607,7 +554,7 @@ static INPUT_PORTS_START( goaltogo )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START_TAG("BANK2")
+	PORT_START("BANK2")
 	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )		PORT_DIPLOCATION("F11:8")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -632,7 +579,7 @@ static INPUT_PORTS_START( goaltogo )
 	PORT_DIPSETTING(    0x02, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) )
 
-	PORT_START_TAG("BANK3")
+	PORT_START("BANK3")
 	PORT_DIPNAME( 0x80, 0x00, "Display Diagram Before Play" )	PORT_DIPLOCATION("G11:8")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -658,7 +605,7 @@ static INPUT_PORTS_START( goaltogo )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START_TAG("BANK4")
+	PORT_START("BANK4")
 	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )		PORT_DIPLOCATION("H11:8")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -689,7 +636,7 @@ static INPUT_PORTS_START( goaltogo )
 	PORT_DIPSETTING(    0x01, "14" )
 	PORT_DIPSETTING(    0x00, "15 (Hardest)" )
 
-	PORT_START_TAG("BANK5")
+	PORT_START("BANK5")
 	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
@@ -699,7 +646,7 @@ static INPUT_PORTS_START( goaltogo )
 	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_TILT )
 
-	PORT_START_TAG("BANK6")
+	PORT_START("BANK6")
 	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )
 	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT )
 	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )
@@ -723,7 +670,7 @@ static const TMS9928a_interface tms9928a_interface =
 	vdp_interrupt
 };
 
-extern const discrete_sound_block cliffhgr_discrete_interface[];
+DISCRETE_SOUND_EXTERN( cliffhgr );
 
 
 
@@ -735,35 +682,36 @@ extern const discrete_sound_block cliffhgr_discrete_interface[];
 
 static MACHINE_DRIVER_START( cliffhgr )
 
-	MDRV_CPU_ADD(Z80, 4000000)       /* 4MHz */
+	MDRV_CPU_ADD("main", Z80, 4000000)       /* 4MHz */
 	MDRV_CPU_PROGRAM_MAP(mainmem,0)
 	MDRV_CPU_IO_MAP(mainport,0)
-	MDRV_CPU_VBLANK_INT(cliff_vsync,1)
+	MDRV_CPU_VBLANK_INT("main", cliff_vsync)
 
 	MDRV_MACHINE_START(cliffhgr)
 	MDRV_MACHINE_RESET(cliffhgr)
 
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
+	MDRV_LASERDISC_ADD("laserdisc", PIONEER_PR8210, "main", "ldsound")
+	MDRV_LASERDISC_OVERLAY(tms9928a, 15+32*8+15, 27+24*8+24, BITMAP_FORMAT_INDEXED16)
+	MDRV_LASERDISC_OVERLAY_CLIP(15-12, 15+32*8+12-1, 27-9, 27+24*8+9-1)
+
 	/* start with the TMS9928a video configuration */
 	MDRV_IMPORT_FROM(tms9928a)
 
 	/* override video rendering and raw screen info */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_SELF_RENDER)
-	MDRV_VIDEO_UPDATE(cliff)
-	MDRV_SCREEN_RAW_PARAMS(13500000, 858, 0, 720, 262.5, 21, 262.5)
+	MDRV_SCREEN_REMOVE("main")
+	MDRV_LASERDISC_SCREEN_ADD_NTSC("main", BITMAP_FORMAT_INDEXED16)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	/* laserdisc audio */
-	MDRV_SOUND_ADD(CUSTOM, 0)
+	MDRV_SOUND_ADD("ldsound", CUSTOM, 0)
 	MDRV_SOUND_CONFIG(laserdisc_custom_interface)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 
-	/* discrete sounds */
-	MDRV_SOUND_ADD_TAG("discrete", DISCRETE, 0)
+	MDRV_SOUND_ADD("discrete", DISCRETE, 0)
 	MDRV_SOUND_CONFIG_DISCRETE(cliffhgr)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
 MACHINE_DRIVER_END
@@ -777,37 +725,37 @@ MACHINE_DRIVER_END
 *************************************/
 
 ROM_START( cliffhgr )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "cliff_u1.bin",	0x0000, 0x2000, CRC(a86ec38f) SHA1(bfca1b1c084f5b7b1e0ccb2f3616ecea1340f04c) )
 	ROM_LOAD( "cliff_u2.bin",	0x2000, 0x2000, CRC(b8d33b6b) SHA1(02778f87a78199129c758a8fb0629b9ba74cab99) )
 	ROM_LOAD( "cliff_u3.bin",	0x4000, 0x2000, CRC(75a64cd2) SHA1(18fe4d8885b59ec8b8c28b5d7141a27164c982ac) )
 	ROM_LOAD( "cliff_u4.bin",	0x6000, 0x2000, CRC(906b2af1) SHA1(65fadd2fec90f47c91ac4928f342c79ab8bc6ef0) )
 	ROM_LOAD( "cliff_u5.bin",	0x8000, 0x2000, CRC(5922e710) SHA1(10637baba4d16dc333aeb0ab88ee251f44e1a115) )
 
-	DISK_REGION( REGION_DISKS )
+	DISK_REGION( "laserdisc" )
 	DISK_IMAGE_READONLY( "cliffhgr", 0, NO_DUMP )
 ROM_END
 
 ROM_START( cliffhga )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "cliff_alt_0.bin",	0x0000, 0x2000, CRC(27caa67c) SHA1(70d8270766b8712d4250b1a23489007d59eb262f) )
 	ROM_LOAD( "cliff_alt_1.bin",	0x2000, 0x2000, CRC(6e5f1515) SHA1(1c4116f4f5910857408826d73c630abbf1434119) )
 	ROM_LOAD( "cliff_alt_2.bin",	0x4000, 0x2000, CRC(045f895d) SHA1(364e259a9630d87ca917c7a9dc1a94d6f0d0eba5) )
 	ROM_LOAD( "cliff_alt_3.bin",	0x6000, 0x2000, CRC(54cdb4a1) SHA1(6b1d73aec029af4a88ca2f883b4ed706d153592d) )
 
-	DISK_REGION( REGION_DISKS )
+	DISK_REGION( "laserdisc" )
 	DISK_IMAGE_READONLY( "cliffhgr", 0, NO_DUMP )
 ROM_END
 
 ROM_START( goaltogo )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "gtg.rm0",	0x0000, 0x2000, CRC(d8efddea) SHA1(69a076fed60ebabad3032d8c10804f57a0904327) )
 	ROM_LOAD( "gtg.rm1",	0x2000, 0x2000, CRC(69953d38) SHA1(2a51aa785a4576db8b046e128bbfc1b3949d7bf7) )
 	ROM_LOAD( "gtg.rm2",	0x4000, 0x2000, CRC(b043e205) SHA1(8992c0e294f59bd9331fb3a50a0dfd8d5c194fa3) )
 	ROM_LOAD( "gtg.rm3",	0x6000, 0x2000, CRC(ec305f5e) SHA1(e205fac699db4ca28a87f56f89cc6cf185ad540d) )
 	ROM_LOAD( "gtg.rm4",	0x8000, 0x2000, CRC(9e4c8aa2) SHA1(002c0940d3890141f85f98f854fd30cc1e340d45) )
 
-	DISK_REGION( REGION_DISKS )
+	DISK_REGION( "laserdisc" )
 	DISK_IMAGE_READONLY( "goaltog1", 0, NO_DUMP )
 ROM_END
 
@@ -821,13 +769,7 @@ ROM_END
 
 static DRIVER_INIT( cliff )
 {
-	video_texture = NULL;
-	overlay_texture = NULL;
-	last_video_bitmap = NULL;
-
 	TMS9928A_configure(&tms9928a_interface);
-
-	add_exit_callback(machine, video_cleanup);
 }
 
 
