@@ -94,6 +94,10 @@
     Motion object ROM: 136023.307,136023.308
     Playfield ROM: 136023.306,136023.305
 
+
+    2008-07
+    Dip locations and suggested settings verified with manual.
+
 ****************************************************************************/
 
 /*
@@ -108,22 +112,13 @@
 */
 
 #include "driver.h"
+#include "cpu/m6502/m6502.h"
 #include "deprecat.h"
 #include "sound/pokey.h"
+#include "includes/cloak.h"
 
 static int cloak_nvram_enabled;
 
-extern WRITE8_HANDLER( cloak_videoram_w );
-extern WRITE8_HANDLER( cloak_paletteram_w );
-extern WRITE8_HANDLER( cloak_clearbmp_w );
-extern WRITE8_HANDLER( graph_processor_w );
-extern WRITE8_HANDLER( cloak_flipscreen_w );
-extern READ8_HANDLER( graph_processor_r );
-
-extern VIDEO_START( cloak );
-extern VIDEO_UPDATE( cloak );
-
-
 /*************************************
  *
  *  Output ports
@@ -146,12 +141,12 @@ static WRITE8_HANDLER( cloak_custom_w )
 
 static WRITE8_HANDLER( cloak_irq_reset_0_w )
 {
-	cpunum_set_input_line(Machine, 0, 0, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[0], 0, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( cloak_irq_reset_1_w )
 {
-	cpunum_set_input_line(Machine, 1, 0, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[1], 0, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( cloak_nvram_enable_w )
@@ -169,16 +164,16 @@ static WRITE8_HANDLER( cloak_nvram_enable_w )
 
 static ADDRESS_MAP_START( master_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x03ff) AM_RAM
-	AM_RANGE(0x0400, 0x07ff) AM_READWRITE(MRA8_RAM, cloak_videoram_w) AM_BASE(&videoram)
+	AM_RANGE(0x0400, 0x07ff) AM_RAM_WRITE(cloak_videoram_w) AM_BASE(&videoram)
 	AM_RANGE(0x0800, 0x0fff) AM_RAM AM_SHARE(1)
 	AM_RANGE(0x1000, 0x100f) AM_READWRITE(pokey1_r, pokey1_w)		/* DSW0 also */
-//  AM_RANGE(0x1008, 0x1008) AM_READ(MRA8_RAM)
 	AM_RANGE(0x1800, 0x180f) AM_READWRITE(pokey2_r, pokey2_w)		/* DSW1 also */
-	AM_RANGE(0x2000, 0x2000) AM_READ(input_port_0_r)	/* IN0 */
-	AM_RANGE(0x2200, 0x2200) AM_READ(input_port_1_r)	/* IN1 */
-	AM_RANGE(0x2400, 0x2400) AM_READ(input_port_2_r)	/* IN2 */
+	AM_RANGE(0x2000, 0x2000) AM_READ_PORT("P1")
+	AM_RANGE(0x2200, 0x2200) AM_READ_PORT("P2")
+	AM_RANGE(0x2400, 0x2400) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x2600, 0x2600) AM_WRITE(cloak_custom_w)
 	AM_RANGE(0x2800, 0x29ff) AM_RAM AM_BASE(&generic_nvram) AM_SIZE(&generic_nvram_size)
+	AM_RANGE(0x2f00, 0x2fff) AM_NOP
 	AM_RANGE(0x3000, 0x30ff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
 	AM_RANGE(0x3200, 0x327f) AM_WRITE(cloak_paletteram_w)
 	AM_RANGE(0x3800, 0x3801) AM_WRITE(cloak_coin_counter_w)
@@ -218,7 +213,7 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( cloak )
-	PORT_START	/* IN0 */
+	PORT_START("P1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICKRIGHT_DOWN ) PORT_8WAY
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICKRIGHT_UP ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICKRIGHT_RIGHT ) PORT_8WAY
@@ -228,10 +223,10 @@ static INPUT_PORTS_START( cloak )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICKLEFT_RIGHT ) PORT_8WAY
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICKLEFT_LEFT ) PORT_8WAY
 
-	PORT_START	/* IN1 */
+	PORT_START("P2")
 	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNUSED )		// player 2 controls, not used
 
-	PORT_START	/* IN2 */
+	PORT_START("SYSTEM")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_VBLANK )
 	PORT_SERVICE( 0x02, IP_ACTIVE_LOW )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN2 )
@@ -241,31 +236,31 @@ static INPUT_PORTS_START( cloak )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )		// player 2 button 1, not used
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 )
 
-	PORT_START	/* IN3 */
-	PORT_BIT( 0x2f, IP_ACTIVE_LOW, IPT_UNUSED )		// not connected
+	PORT_START("START")
+	PORT_BIT( 0x0f, IP_ACTIVE_LOW, IPT_UNUSED )		// not connected
 	PORT_BIT( 0x30, IP_ACTIVE_HIGH, IPT_UNUSED )	// pulled high
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_START2 )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_START1 )
 
-	PORT_START      /* DSW0 */
-	PORT_DIPNAME( 0x03, 0x02, "Credits" )
+	PORT_START("DSW")
+	PORT_DIPNAME( 0x03, 0x02, "Credits" ) PORT_DIPLOCATION("5A:!7,!8")
 	PORT_DIPSETTING(    0x02, "1 Credit/1 Game" )
 	PORT_DIPSETTING(    0x01, "1 Credit/2 Games" )
 	PORT_DIPSETTING(    0x03, "2 Credits/1 Game" )
 	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
-	PORT_DIPNAME( 0x0c, 0x00, DEF_STR( Coin_B ) )
+	PORT_DIPNAME( 0x0c, 0x00, DEF_STR( Coin_B ) ) PORT_DIPLOCATION("5A:!5,!6")
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_6C ) )
-	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Coin_A ) )
+	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Coin_A ) ) PORT_DIPLOCATION("5A:!4")
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( 1C_2C ) )
-	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_DIPNAME( 0x40, 0x00, "Demo Freeze Mode" )	// when active, press button 1 to freeze
+	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_UNUSED )	// "5A:!3" - it must be OFF according to manual.
+	PORT_DIPNAME( 0x40, 0x00, "Demo Freeze Mode" ) PORT_DIPLOCATION("5A:!2")	// when active, press button 1 to freeze
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x40, DEF_STR( On ) )
-	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )	// "5A:!1" - Not Used according to manual.
 INPUT_PORTS_END
 
 
@@ -300,8 +295,8 @@ static const gfx_layout spritelayout =
 };
 
 static GFXDECODE_START( cloak )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, charlayout,     0,  1 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0, spritelayout,  32,  1 )
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout,     0,  1 )
+	GFXDECODE_ENTRY( "gfx2", 0, spritelayout,  32,  1 )
 GFXDECODE_END
 
 
@@ -312,13 +307,13 @@ GFXDECODE_END
  *
  *************************************/
 
-static const struct POKEYinterface pokey_interface_1 =
+static const pokey_interface pokey_interface_1 =
 {
 	{ 0 },
 	input_port_3_r
 };
 
-static const struct POKEYinterface pokey_interface_2 =
+static const pokey_interface pokey_interface_2 =
 {
 	{ 0 },
 	input_port_4_r
@@ -335,25 +330,26 @@ static const struct POKEYinterface pokey_interface_2 =
 static MACHINE_DRIVER_START( cloak )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M6502,1000000)		/* 1 MHz ???? */
+	MDRV_CPU_ADD("main", M6502,1000000)		/* 1 MHz ???? */
 	MDRV_CPU_PROGRAM_MAP(master_map,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,4)
+	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,4)
 
-	MDRV_CPU_ADD(M6502,1250000)		/* 1.25 MHz ???? */
+	MDRV_CPU_ADD("slave", M6502,1250000)		/* 1.25 MHz ???? */
 	MDRV_CPU_PROGRAM_MAP(slave_map,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,2)
+	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,2)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(5)
+	MDRV_QUANTUM_TIME(HZ(300))
 
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(32*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 3*8, 32*8-1)
+
 	MDRV_GFXDECODE(cloak)
 	MDRV_PALETTE_LENGTH(64)
 
@@ -363,11 +359,11 @@ static MACHINE_DRIVER_START( cloak )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(POKEY, 1500000)
+	MDRV_SOUND_ADD("pokey1", POKEY, 1500000)
 	MDRV_SOUND_CONFIG(pokey_interface_1)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD(POKEY, 1500000)
+	MDRV_SOUND_ADD("pokey2", POKEY, 1500000)
 	MDRV_SOUND_CONFIG(pokey_interface_2)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
@@ -381,13 +377,13 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( cloak )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "136023-501.bin",      0x4000, 0x2000, CRC(c2dbef1b) SHA1(3bab091afb846ea5f09200e3b44dc8dd430993fe) )
 	ROM_LOAD( "136023-502.bin",      0x6000, 0x2000, CRC(316d0c7b) SHA1(58e50661c077415d9465d85c015b8238b4552304) )
 	ROM_LOAD( "136023-503.bin",      0x8000, 0x4000, CRC(b9c291a6) SHA1(b3e310110c6d76fa11c44561eb8281aec5f2d1ae) )
 	ROM_LOAD( "136023-504.bin",      0xc000, 0x4000, CRC(d014a1c0) SHA1(76c375ccbd0956779942a72ad2e3c3b8c6203ab3) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "slave", 0 )
 	ROM_LOAD( "136023-509.bin",      0x2000, 0x2000, CRC(46c021a4) SHA1(8ed7efca766611d433a4fec16ae9c05131a157f4) )
 	ROM_LOAD( "136023-510.bin",      0x4000, 0x2000, CRC(8c9cf017) SHA1(19e404354418f95ed7079420fe51110f30e349ed) )
 	ROM_LOAD( "136023-511.bin",      0x6000, 0x2000, CRC(66fd8a34) SHA1(9597a02a20113baea656ad5d581311abc2865fb1) )
@@ -396,24 +392,27 @@ ROM_START( cloak )
 	ROM_LOAD( "136023-514.bin",      0xc000, 0x2000, CRC(6f8c7991) SHA1(bd6f838b224abed78fbdb7da17baa892289fc2f2) )
 	ROM_LOAD( "136023-515.bin",      0xe000, 0x2000, CRC(835438a0) SHA1(27f320b74e7bdb29d4bc505432c96284f482cacc) )
 
-	ROM_REGION( 0x2000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "136023-105.bin",      0x0000, 0x1000, CRC(ee443909) SHA1(802c5839be9e9e33c75ca7318043ecdb7b82f721) )
 	ROM_LOAD( "136023-106.bin",      0x1000, 0x1000, CRC(d708b132) SHA1(d57acdcfb7b3de65f0162bdc041efff4c7eeff18) )
 
-	ROM_REGION( 0x2000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "136023-107.bin",      0x0000, 0x1000, CRC(c42c84a4) SHA1(6f241e772f8b46c8d3acad2e967f1ab530886b11) )
 	ROM_LOAD( "136023-108.bin",      0x1000, 0x1000, CRC(4fe13d58) SHA1(b21a32b2ff5363ab35fd1438344a04deb4077dbc) )
+
+	ROM_REGION( 0x100, "proms", 0 )
+	ROM_LOAD( "136023-116.3n",  0x000, 0x100, CRC(ef2668e5) SHA1(442df346a40b1e20d599ed9877c699e00ab518ba) ) /* 82S129 Vertical timing PROM */
 ROM_END
 
 
 ROM_START( cloaksp )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "136023-501.bin",      0x4000, 0x2000, CRC(c2dbef1b) SHA1(3bab091afb846ea5f09200e3b44dc8dd430993fe) )
 	ROM_LOAD( "136023-502.bin",      0x6000, 0x2000, CRC(316d0c7b) SHA1(58e50661c077415d9465d85c015b8238b4552304) )
 	ROM_LOAD( "136023-503.bin",      0x8000, 0x4000, CRC(b9c291a6) SHA1(b3e310110c6d76fa11c44561eb8281aec5f2d1ae) )
 	ROM_LOAD( "136023-804.bin",      0xc000, 0x4000, CRC(994899c7) SHA1(3835777ce3f3aaff2ce3520c71d16d4c86743a20) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "slave", 0 )
 	ROM_LOAD( "136023-509.bin",      0x2000, 0x2000, CRC(46c021a4) SHA1(8ed7efca766611d433a4fec16ae9c05131a157f4) )
 	ROM_LOAD( "136023-510.bin",      0x4000, 0x2000, CRC(8c9cf017) SHA1(19e404354418f95ed7079420fe51110f30e349ed) )
 	ROM_LOAD( "136023-511.bin",      0x6000, 0x2000, CRC(66fd8a34) SHA1(9597a02a20113baea656ad5d581311abc2865fb1) )
@@ -422,24 +421,27 @@ ROM_START( cloaksp )
 	ROM_LOAD( "136023-514.bin",      0xc000, 0x2000, CRC(6f8c7991) SHA1(bd6f838b224abed78fbdb7da17baa892289fc2f2) )
 	ROM_LOAD( "136023-515.bin",      0xe000, 0x2000, CRC(835438a0) SHA1(27f320b74e7bdb29d4bc505432c96284f482cacc) )
 
-	ROM_REGION( 0x2000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "136023-105.bin",      0x0000, 0x1000, CRC(ee443909) SHA1(802c5839be9e9e33c75ca7318043ecdb7b82f721) )
 	ROM_LOAD( "136023-106.bin",      0x1000, 0x1000, CRC(d708b132) SHA1(d57acdcfb7b3de65f0162bdc041efff4c7eeff18) )
 
-	ROM_REGION( 0x2000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "136023-107.bin",      0x0000, 0x1000, CRC(c42c84a4) SHA1(6f241e772f8b46c8d3acad2e967f1ab530886b11) )
 	ROM_LOAD( "136023-108.bin",      0x1000, 0x1000, CRC(4fe13d58) SHA1(b21a32b2ff5363ab35fd1438344a04deb4077dbc) )
+
+	ROM_REGION( 0x100, "proms", 0 )
+	ROM_LOAD( "136023-116.3n",  0x000, 0x100, CRC(ef2668e5) SHA1(442df346a40b1e20d599ed9877c699e00ab518ba) ) /* 82S129 Vertical timing PROM */
 ROM_END
 
 
 ROM_START( cloakfr )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "136023-501.bin",      0x4000, 0x2000, CRC(c2dbef1b) SHA1(3bab091afb846ea5f09200e3b44dc8dd430993fe) )
 	ROM_LOAD( "136023-502.bin",      0x6000, 0x2000, CRC(316d0c7b) SHA1(58e50661c077415d9465d85c015b8238b4552304) )
 	ROM_LOAD( "136023-503.bin",      0x8000, 0x4000, CRC(b9c291a6) SHA1(b3e310110c6d76fa11c44561eb8281aec5f2d1ae) )
 	ROM_LOAD( "136023-704.bin",      0xc000, 0x4000, CRC(bf225ea0) SHA1(d1e45d6071eb819e6a5075b61014e24a451fb443) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "slave", 0 )
 	ROM_LOAD( "136023-509.bin",      0x2000, 0x2000, CRC(46c021a4) SHA1(8ed7efca766611d433a4fec16ae9c05131a157f4) )
 	ROM_LOAD( "136023-510.bin",      0x4000, 0x2000, CRC(8c9cf017) SHA1(19e404354418f95ed7079420fe51110f30e349ed) )
 	ROM_LOAD( "136023-511.bin",      0x6000, 0x2000, CRC(66fd8a34) SHA1(9597a02a20113baea656ad5d581311abc2865fb1) )
@@ -448,24 +450,27 @@ ROM_START( cloakfr )
 	ROM_LOAD( "136023-514.bin",      0xc000, 0x2000, CRC(6f8c7991) SHA1(bd6f838b224abed78fbdb7da17baa892289fc2f2) )
 	ROM_LOAD( "136023-515.bin",      0xe000, 0x2000, CRC(835438a0) SHA1(27f320b74e7bdb29d4bc505432c96284f482cacc) )
 
-	ROM_REGION( 0x2000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "136023-105.bin",      0x0000, 0x1000, CRC(ee443909) SHA1(802c5839be9e9e33c75ca7318043ecdb7b82f721) )
 	ROM_LOAD( "136023-106.bin",      0x1000, 0x1000, CRC(d708b132) SHA1(d57acdcfb7b3de65f0162bdc041efff4c7eeff18) )
 
-	ROM_REGION( 0x2000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "136023-107.bin",      0x0000, 0x1000, CRC(c42c84a4) SHA1(6f241e772f8b46c8d3acad2e967f1ab530886b11) )
 	ROM_LOAD( "136023-108.bin",      0x1000, 0x1000, CRC(4fe13d58) SHA1(b21a32b2ff5363ab35fd1438344a04deb4077dbc) )
+
+	ROM_REGION( 0x100, "proms", 0 )
+	ROM_LOAD( "136023-116.3n",  0x000, 0x100, CRC(ef2668e5) SHA1(442df346a40b1e20d599ed9877c699e00ab518ba) ) /* 82S129 Vertical timing PROM */
 ROM_END
 
 
 ROM_START( cloakgr )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "136023-501.bin",      0x4000, 0x2000, CRC(c2dbef1b) SHA1(3bab091afb846ea5f09200e3b44dc8dd430993fe) )
 	ROM_LOAD( "136023-502.bin",      0x6000, 0x2000, CRC(316d0c7b) SHA1(58e50661c077415d9465d85c015b8238b4552304) )
 	ROM_LOAD( "136023-503.bin",      0x8000, 0x4000, CRC(b9c291a6) SHA1(b3e310110c6d76fa11c44561eb8281aec5f2d1ae) )
 	ROM_LOAD( "136023-604.bin",      0xc000, 0x4000, CRC(7ac66aea) SHA1(fbeb3bb2756275aabb5fee1aa44c6f32da159bb6) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "slave", 0 )
 	ROM_LOAD( "136023-509.bin",      0x2000, 0x2000, CRC(46c021a4) SHA1(8ed7efca766611d433a4fec16ae9c05131a157f4) )
 	ROM_LOAD( "136023-510.bin",      0x4000, 0x2000, CRC(8c9cf017) SHA1(19e404354418f95ed7079420fe51110f30e349ed) )
 	ROM_LOAD( "136023-511.bin",      0x6000, 0x2000, CRC(66fd8a34) SHA1(9597a02a20113baea656ad5d581311abc2865fb1) )
@@ -474,24 +479,27 @@ ROM_START( cloakgr )
 	ROM_LOAD( "136023-514.bin",      0xc000, 0x2000, CRC(6f8c7991) SHA1(bd6f838b224abed78fbdb7da17baa892289fc2f2) )
 	ROM_LOAD( "136023-515.bin",      0xe000, 0x2000, CRC(835438a0) SHA1(27f320b74e7bdb29d4bc505432c96284f482cacc) )
 
-	ROM_REGION( 0x2000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "136023-105.bin",      0x0000, 0x1000, CRC(ee443909) SHA1(802c5839be9e9e33c75ca7318043ecdb7b82f721) )
 	ROM_LOAD( "136023-106.bin",      0x1000, 0x1000, CRC(d708b132) SHA1(d57acdcfb7b3de65f0162bdc041efff4c7eeff18) )
 
-	ROM_REGION( 0x2000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "136023-107.bin",      0x0000, 0x1000, CRC(c42c84a4) SHA1(6f241e772f8b46c8d3acad2e967f1ab530886b11) )
 	ROM_LOAD( "136023-108.bin",      0x1000, 0x1000, CRC(4fe13d58) SHA1(b21a32b2ff5363ab35fd1438344a04deb4077dbc) )
+
+	ROM_REGION( 0x100, "proms", 0 )
+	ROM_LOAD( "136023-116.3n",  0x000, 0x100, CRC(ef2668e5) SHA1(442df346a40b1e20d599ed9877c699e00ab518ba) ) /* 82S129 Vertical timing PROM */
 ROM_END
 
 
 ROM_START( agentx4 )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "136401-023.bin",      0x4000, 0x2000, CRC(f7edac86) SHA1(80e8738460d408343cbae2a99bcdfd92664d13bb) )
 	ROM_LOAD( "136402-023.bin",      0x6000, 0x2000, CRC(db5e2382) SHA1(15196a588cb676254ed19fe019e4bab3708d5636) )
 	ROM_LOAD( "136403-023.bin",      0x8000, 0x4000, CRC(87de01b4) SHA1(5c79edc132a3b460a636e223387a8bbde54833dc) )
 	ROM_LOAD( "136404-023.bin",      0xc000, 0x4000, CRC(b97219dc) SHA1(39d1fcc76e112840f20443e2125478a33a102afc) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "slave", 0 )
 	ROM_LOAD( "136409-023.bin",      0x2000, 0x2000, CRC(add4a749) SHA1(885a7175179d3e4201af24217d27f100479edc1b) )
 	ROM_LOAD( "136410-023.bin",      0x4000, 0x2000, CRC(b1e1c074) SHA1(ac0b39887c4e21db06160e0d097d17e00c47c784) )
 	ROM_LOAD( "136411-023.bin",      0x6000, 0x2000, CRC(6d0c1ee5) SHA1(62c7214df7cd4f5426d7fa2b28243acc31b356f2) )
@@ -500,24 +508,27 @@ ROM_START( agentx4 )
 	ROM_LOAD( "136414-023.bin",      0xc000, 0x2000, CRC(cadf9ab0) SHA1(d5c4c86124033f21e065e5cd9cf7a1b31d3c11a6) )
 	ROM_LOAD( "136415-023.bin",      0xe000, 0x2000, CRC(f5024961) SHA1(99a8b02932b497588a011fe051465407531f8a0f) )
 
-	ROM_REGION( 0x2000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "136105-023.bin",      0x0000, 0x1000, CRC(ee443909) SHA1(802c5839be9e9e33c75ca7318043ecdb7b82f721) )
 	ROM_LOAD( "136106-023.bin",      0x1000, 0x1000, CRC(d708b132) SHA1(d57acdcfb7b3de65f0162bdc041efff4c7eeff18) )
 
-	ROM_REGION( 0x2000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "136107-023.bin",      0x0000, 0x1000, CRC(c42c84a4) SHA1(6f241e772f8b46c8d3acad2e967f1ab530886b11) )
 	ROM_LOAD( "136108-023.bin",      0x1000, 0x1000, CRC(4fe13d58) SHA1(b21a32b2ff5363ab35fd1438344a04deb4077dbc) )
+
+	ROM_REGION( 0x100, "proms", 0 )
+	ROM_LOAD( "136023-116.3n",  0x000, 0x100, CRC(ef2668e5) SHA1(442df346a40b1e20d599ed9877c699e00ab518ba) ) /* 82S129 Vertical timing PROM */
 ROM_END
 
 
 ROM_START( agentx3 )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "136301-023.bin",      0x4000, 0x2000, CRC(fba1d9de) SHA1(e8a72531f912a6ff1cd1c67a5c3fd0d18ede54f6) )
 	ROM_LOAD( "136302-023.bin",      0x6000, 0x2000, CRC(e5694c72) SHA1(45e143048f2bbfcb1a71eab63ccd61e2a227066c) )
 	ROM_LOAD( "136303-023.bin",      0x8000, 0x4000, CRC(70ef51c5) SHA1(4a2a15dc05eaf8481dfdb18e1aea81efb8f7e1d6) )
 	ROM_LOAD( "136304-023.bin",      0xc000, 0x4000, CRC(f4a86cda) SHA1(438c60e91948468f4ce3bafd471bc68b1a728c3b) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "slave", 0 )
 	ROM_LOAD( "136309-023.bin",      0x2000, 0x2000, CRC(1c04282d) SHA1(ec50645220dae7f65aa2c0252088cb53de2e4610) )
 	ROM_LOAD( "136310-023.bin",      0x4000, 0x2000, CRC(a61eaa88) SHA1(6f00d5d8338a311b33a8ff748c13d25fa01feba7) )
 	ROM_LOAD( "136311-023.bin",      0x6000, 0x2000, CRC(a670f4b4) SHA1(235828c34710c901bffef85f208bc0c5abfd527a) )
@@ -526,24 +537,27 @@ ROM_START( agentx3 )
 	ROM_LOAD( "136314-023.bin",      0xc000, 0x2000, CRC(3138a3b2) SHA1(553f247a72fce176d80db7e4c7624cdb73c8c078) )
 	ROM_LOAD( "136315-023.bin",      0xe000, 0x2000, CRC(d12f5523) SHA1(53a7e4e360bd8c21c0e9bf408b6dd231f4fe025c) )
 
-	ROM_REGION( 0x2000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "136105-023.bin",      0x0000, 0x1000, CRC(ee443909) SHA1(802c5839be9e9e33c75ca7318043ecdb7b82f721) )
 	ROM_LOAD( "136106-023.bin",      0x1000, 0x1000, CRC(d708b132) SHA1(d57acdcfb7b3de65f0162bdc041efff4c7eeff18) )
 
-	ROM_REGION( 0x2000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "136107-023.bin",      0x0000, 0x1000, CRC(c42c84a4) SHA1(6f241e772f8b46c8d3acad2e967f1ab530886b11) )
 	ROM_LOAD( "136108-023.bin",      0x1000, 0x1000, CRC(4fe13d58) SHA1(b21a32b2ff5363ab35fd1438344a04deb4077dbc) )
+
+	ROM_REGION( 0x100, "proms", 0 )
+	ROM_LOAD( "136023-116.3n",  0x000, 0x100, CRC(ef2668e5) SHA1(442df346a40b1e20d599ed9877c699e00ab518ba) ) /* 82S129 Vertical timing PROM */
 ROM_END
 
 
 ROM_START( agentx2 )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "136201-023.bin",      0x4000, 0x2000, CRC(e6c7041f) SHA1(dd253b2a1417498b16c2986f7e2d885cfc11f8e9) )
 	ROM_LOAD( "136202-023.bin",      0x6000, 0x2000, CRC(4c94929e) SHA1(b67640cfdb7ccda80b8569d2c8607d0f0103226e) )
 	ROM_LOAD( "136203-023.bin",      0x8000, 0x4000, CRC(c7a59697) SHA1(a1735873290956c50fea34787003fe2ef9e23b6e) )
 	ROM_LOAD( "136204-023.bin",      0xc000, 0x4000, CRC(e6e06a9c) SHA1(91976a73742d5cb61f59e28917f5eb923c9ee8f5) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "slave", 0 )
 	ROM_LOAD( "136209-023.bin",      0x2000, 0x2000, CRC(319772d8) SHA1(ef4cdb5f7d100410bc406b61857083c12cde21f6) )
 	ROM_LOAD( "136210-023.bin",      0x4000, 0x2000, CRC(6e95f628) SHA1(987a76447b6bda00223a8c94bdb741dce944c61f) )
 	ROM_LOAD( "136211-023.bin",      0x6000, 0x2000, CRC(8d936132) SHA1(461e1924e4fce337889377912311291947c432be) )
@@ -552,24 +566,27 @@ ROM_START( agentx2 )
 	ROM_LOAD( "136214-023.bin",      0xc000, 0x2000, CRC(dba311ec) SHA1(a825f013211e6eaac4c18a589b38a416dc633954) )
 	ROM_LOAD( "136215-023.bin",      0xe000, 0x2000, CRC(dc20c185) SHA1(5a1d3e65e543fe295c2f179f8b5c2193065af581) )
 
-	ROM_REGION( 0x2000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "136105-023.bin",      0x0000, 0x1000, CRC(ee443909) SHA1(802c5839be9e9e33c75ca7318043ecdb7b82f721) )
 	ROM_LOAD( "136106-023.bin",      0x1000, 0x1000, CRC(d708b132) SHA1(d57acdcfb7b3de65f0162bdc041efff4c7eeff18) )
 
-	ROM_REGION( 0x2000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "136107-023.bin",      0x0000, 0x1000, CRC(c42c84a4) SHA1(6f241e772f8b46c8d3acad2e967f1ab530886b11) )
 	ROM_LOAD( "136108-023.bin",      0x1000, 0x1000, CRC(4fe13d58) SHA1(b21a32b2ff5363ab35fd1438344a04deb4077dbc) )
+
+	ROM_REGION( 0x100, "proms", 0 )
+	ROM_LOAD( "136023-116.3n",  0x000, 0x100, CRC(ef2668e5) SHA1(442df346a40b1e20d599ed9877c699e00ab518ba) ) /* 82S129 Vertical timing PROM */
 ROM_END
 
 
 ROM_START( agentx1 )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "136101-023.bin",      0x4000, 0x2000, CRC(a12b9c22) SHA1(40fef20782bdb05ef5ef81327e69286abab6449c) )
 	ROM_LOAD( "136102-023.bin",      0x6000, 0x2000, CRC(e65d30df) SHA1(bad65c2bb434c43bd72a0b7f88adea4150e3cd66) )
 	ROM_LOAD( "136103-023.bin",      0x8000, 0x4000, CRC(c6f8a128) SHA1(feaf860b2226796643c107ac5821b0a9988d3367) )
 	ROM_LOAD( "136104-023.bin",      0xc000, 0x4000, CRC(db002945) SHA1(52c0d0e94e718e51cd744d3ceb10e1443f41a3d5) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "slave", 0 )
 	ROM_LOAD( "136109-023.bin",      0x2000, 0x2000, CRC(31487f5d) SHA1(86d519fb7f352101780c2ed1a87cbabb2ff0dcd4) )
 	ROM_LOAD( "136110-023.bin",      0x4000, 0x2000, CRC(1ee38ecb) SHA1(44d3d7c0cffbdeb57231037cfbf7e4054dfc9349) )
 	ROM_LOAD( "136111-023.bin",      0x6000, 0x2000, CRC(ca6a6b0c) SHA1(3d8b62a6a7480032bce74d3a5dbdaa52fc8b33c0) )
@@ -578,13 +595,16 @@ ROM_START( agentx1 )
 	ROM_LOAD( "136114-023.bin",      0xc000, 0x2000, CRC(7c7c905d) SHA1(eb417c5e80f1a3169c1385d7c843a3defa584b6e) )
 	ROM_LOAD( "136115-023.bin",      0xe000, 0x2000, CRC(7f36710c) SHA1(6d412f22e723999c641dde18a47c8d90d2ed07a3) )
 
-	ROM_REGION( 0x2000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "136105-023.bin",      0x0000, 0x1000, CRC(ee443909) SHA1(802c5839be9e9e33c75ca7318043ecdb7b82f721) )
 	ROM_LOAD( "136106-023.bin",      0x1000, 0x1000, CRC(d708b132) SHA1(d57acdcfb7b3de65f0162bdc041efff4c7eeff18) )
 
-	ROM_REGION( 0x2000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "136107-023.bin",      0x0000, 0x1000, CRC(c42c84a4) SHA1(6f241e772f8b46c8d3acad2e967f1ab530886b11) )
 	ROM_LOAD( "136108-023.bin",      0x1000, 0x1000, CRC(4fe13d58) SHA1(b21a32b2ff5363ab35fd1438344a04deb4077dbc) )
+
+	ROM_REGION( 0x100, "proms", 0 )
+	ROM_LOAD( "136023-116.3n",  0x000, 0x100, CRC(ef2668e5) SHA1(442df346a40b1e20d599ed9877c699e00ab518ba) ) /* 82S129 Vertical timing PROM */
 ROM_END
 
 
