@@ -23,8 +23,9 @@
 
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
 #include "machine/6821pia.h"
-#include "video/crtc6845.h"
+#include "video/mc6845.h"
 #include "sound/ay8910.h"
 
 
@@ -60,7 +61,7 @@ static WRITE8_HANDLER( quizmstr_attr2_w )
 static READ8_HANDLER( question_r )
 {
 	int address;
-	UINT8 *questions = memory_region(REGION_USER1);
+	UINT8 *questions = memory_region(space->machine, "user1");
 
 	switch(question_adr[2])
 	{
@@ -120,38 +121,39 @@ static WRITE8_HANDLER( question_w )
 static ADDRESS_MAP_START( coinmstr_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_ROM
 	AM_RANGE(0xc000, 0xdfff) AM_RAM // supnudg2 writes here...
-	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_WRITE(quizmstr_bg_w) AM_BASE(&videoram)
-	AM_RANGE(0xe800, 0xefff) AM_RAM AM_WRITE(quizmstr_attr1_w) AM_BASE(&attr_ram1)
-	AM_RANGE(0xf000, 0xf7ff) AM_RAM AM_WRITE(quizmstr_attr2_w) AM_BASE(&attr_ram2)
+	AM_RANGE(0xe000, 0xe7ff) AM_RAM_WRITE(quizmstr_bg_w) AM_BASE(&videoram)
+	AM_RANGE(0xe800, 0xefff) AM_RAM_WRITE(quizmstr_attr1_w) AM_BASE(&attr_ram1)
+	AM_RANGE(0xf000, 0xf7ff) AM_RAM_WRITE(quizmstr_attr2_w) AM_BASE(&attr_ram2)
 	AM_RANGE(0xf800, 0xffff) AM_RAM // supnudg2 writes here...
 ADDRESS_MAP_END
 
 // Different I/O mappping for every game
 
 static ADDRESS_MAP_START( quizmstr_io_map, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) | AMEF_UNMAP(1) )
+	ADDRESS_MAP_UNMAP_HIGH
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(question_r)
 	AM_RANGE(0x00, 0x03) AM_WRITE(question_w)
-	AM_RANGE(0x40, 0x40) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0x41, 0x41) AM_READWRITE(AY8910_read_port_0_r, AY8910_write_port_0_w)
+	AM_RANGE(0x40, 0x40) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0x41, 0x41) AM_READWRITE(ay8910_read_port_0_r, ay8910_write_port_0_w)
 	AM_RANGE(0x48, 0x4b) AM_READWRITE(pia_0_r, pia_0_w)
 	AM_RANGE(0x50, 0x53) AM_READNOP
 	AM_RANGE(0x50, 0x53) AM_WRITENOP
 	AM_RANGE(0x58, 0x5b) AM_READWRITE(pia_2_r, pia_2_w)
-	AM_RANGE(0x70, 0x70) AM_WRITE(crtc6845_address_w)
-	AM_RANGE(0x71, 0x71) AM_WRITE(crtc6845_register_w)
+	AM_RANGE(0x70, 0x70) AM_DEVWRITE(H46505, "crtc", mc6845_address_w)
+	AM_RANGE(0x71, 0x71) AM_DEVWRITE(H46505, "crtc", mc6845_register_w)
 	AM_RANGE(0xc0, 0xc3) AM_READNOP
 	AM_RANGE(0xc0, 0xc3) AM_WRITENOP
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( trailblz_io_map, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(question_r)
 	AM_RANGE(0x00, 0x03) AM_WRITE(question_w)
-	AM_RANGE(0x40, 0x40) AM_WRITE(crtc6845_address_w)
-	AM_RANGE(0x41, 0x41) AM_WRITE(crtc6845_register_w)
-	AM_RANGE(0x48, 0x48) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0x49, 0x49) AM_READWRITE(AY8910_read_port_0_r, AY8910_write_port_0_w)
+	AM_RANGE(0x40, 0x40) AM_DEVWRITE(H46505, "crtc", mc6845_address_w)
+	AM_RANGE(0x41, 0x41) AM_DEVWRITE(H46505, "crtc", mc6845_register_w)
+	AM_RANGE(0x48, 0x48) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0x49, 0x49) AM_READWRITE(ay8910_read_port_0_r, ay8910_write_port_0_w)
 	AM_RANGE(0x50, 0x53) AM_READWRITE(pia_0_r, pia_0_w) //?
 	AM_RANGE(0x60, 0x63) AM_READWRITE(pia_1_r, pia_1_w)
 	AM_RANGE(0x70, 0x73) AM_READWRITE(pia_2_r, pia_2_w)
@@ -159,50 +161,51 @@ static ADDRESS_MAP_START( trailblz_io_map, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( supnudg2_io_map, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) | AMEF_UNMAP(1) )
+	ADDRESS_MAP_UNMAP_HIGH
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(question_r)
 	AM_RANGE(0x00, 0x03) AM_WRITE(question_w)
 	AM_RANGE(0x40, 0x41) AM_READNOP
 	AM_RANGE(0x40, 0x43) AM_WRITENOP
 	AM_RANGE(0x43, 0x43) AM_READNOP
-	AM_RANGE(0x48, 0x48) AM_WRITE(crtc6845_address_w)
-	AM_RANGE(0x49, 0x49) AM_WRITE(crtc6845_register_w)
+	AM_RANGE(0x48, 0x48) AM_DEVWRITE(H46505, "crtc", mc6845_address_w)
+	AM_RANGE(0x49, 0x49) AM_DEVWRITE(H46505, "crtc", mc6845_register_w)
 	AM_RANGE(0x50, 0x51) AM_READNOP
 	AM_RANGE(0x50, 0x53) AM_WRITENOP
 	AM_RANGE(0x53, 0x53) AM_READNOP
 	AM_RANGE(0x68, 0x69) AM_READNOP
 	AM_RANGE(0x68, 0x6b) AM_WRITENOP
 	AM_RANGE(0x6b, 0x6b) AM_READNOP
-	AM_RANGE(0x78, 0x78) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0x79, 0x79) AM_READWRITE(AY8910_read_port_0_r, AY8910_write_port_0_w)
+	AM_RANGE(0x78, 0x78) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0x79, 0x79) AM_READWRITE(ay8910_read_port_0_r, ay8910_write_port_0_w)
 	AM_RANGE(0xc0, 0xc1) AM_READNOP
 	AM_RANGE(0xc0, 0xc3) AM_WRITENOP
 ADDRESS_MAP_END
 
 static INPUT_PORTS_START( quizmstr )
-	PORT_START
-	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
- 	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_SERVICE1) PORT_NAME("Bookkeeping") PORT_TOGGLE /* Button 2 for second page, Button 3 erases data */
-	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_COIN3 )
-	PORT_BIT ( 0x08, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_COIN2 )
- 	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_SERVICE) PORT_TOGGLE
-	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 )
-	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_BUTTON3 )
+	PORT_START("IN0")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
+ 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SERVICE1) PORT_NAME("Bookkeeping") PORT_TOGGLE /* Button 2 for second page, Button 3 erases data */
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_COIN2 )
+ 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_SERVICE) PORT_TOGGLE
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON3 )
 
-	PORT_START
-	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_BUTTON4 )
-	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_BUTTON5 )
-	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_BUTTON6 )
-	PORT_BIT ( 0x08, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_START2 )
-	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 )
- /* If 0x40 is HIGH the DIP Test Mode does work but bookkeeping shows always 0's */
- /* If 0x40 is LOW Bookkeeping does work, but the second page (selected categories) is missing */
- 	PORT_BIT ( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
- 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_START("IN1")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON4 )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON5 )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON6 )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 )
+	/* If 0x40 is HIGH the DIP Test Mode does work but bookkeeping shows always 0's */
+	/* If 0x40 is LOW Bookkeeping does work, but the second page (selected categories) is missing */
+ 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
+ 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_DIPNAME( 0x01, 0x01, "2-01" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -228,7 +231,7 @@ static INPUT_PORTS_START( quizmstr )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_DIPNAME( 0x01, 0x01, "3-01" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -254,7 +257,7 @@ static INPUT_PORTS_START( quizmstr )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN4")
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) )
@@ -282,7 +285,7 @@ static INPUT_PORTS_START( quizmstr )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( trailblz )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 )
@@ -296,7 +299,7 @@ static INPUT_PORTS_START( trailblz )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_SERVICE( 0x80, IP_ACTIVE_LOW )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_DIPNAME( 0x02, 0x02, "1" )
 	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
@@ -314,7 +317,7 @@ static INPUT_PORTS_START( trailblz )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_DIPNAME( 0x01, 0x01, "2" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -340,7 +343,7 @@ static INPUT_PORTS_START( trailblz )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_DIPNAME( 0x01, 0x01, "3" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -366,7 +369,7 @@ static INPUT_PORTS_START( trailblz )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN4")
 	PORT_DIPNAME( 0x01, 0x01, "4" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -394,7 +397,7 @@ static INPUT_PORTS_START( trailblz )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( supnudg2 )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 )
@@ -408,7 +411,7 @@ static INPUT_PORTS_START( supnudg2 )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_SERVICE( 0x80, IP_ACTIVE_HIGH )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_DIPNAME( 0x02, 0x02, "1" )
 	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
@@ -426,7 +429,7 @@ static INPUT_PORTS_START( supnudg2 )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_DIPNAME( 0x01, 0x01, "2" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -452,7 +455,7 @@ static INPUT_PORTS_START( supnudg2 )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_DIPNAME( 0x01, 0x01, "3" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -478,7 +481,7 @@ static INPUT_PORTS_START( supnudg2 )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN4")
 	PORT_DIPNAME( 0x01, 0x01, "4" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -517,7 +520,7 @@ static const gfx_layout charlayout =
 };
 
 static GFXDECODE_START( coinmstr )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, charlayout, 0, 32 )
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout, 0, 32 )
 GFXDECODE_END
 
 static TILE_GET_INFO( get_bg_tile_info )
@@ -533,7 +536,7 @@ static TILE_GET_INFO( get_bg_tile_info )
 
 static VIDEO_START( coinmstr )
 {
-	bg_tilemap = tilemap_create(get_bg_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN, 8, 8, 46, 64);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info,tilemap_scan_rows, 8, 8, 46, 64);
 }
 
 static VIDEO_UPDATE( coinmstr )
@@ -595,9 +598,9 @@ static const pia6821_interface trailblz_pia_2_intf =
 
 static MACHINE_START( quizmstr )
 {
-	pia_config(0, &quizmstr_pia_0_intf);
-	pia_config(1, &quizmstr_pia_1_intf);
-	pia_config(2, &quizmstr_pia_2_intf);
+	pia_config(machine, 0, &quizmstr_pia_0_intf);
+	pia_config(machine, 1, &quizmstr_pia_1_intf);
+	pia_config(machine, 2, &quizmstr_pia_2_intf);
 }
 
 static MACHINE_RESET( quizmstr )
@@ -607,9 +610,9 @@ static MACHINE_RESET( quizmstr )
 
 static MACHINE_START( trailblz )
 {
-	pia_config(0, &trailblz_pia_0_intf);
-	pia_config(1, &trailblz_pia_1_intf);
-	pia_config(2, &trailblz_pia_2_intf);
+	pia_config(machine, 0, &trailblz_pia_0_intf);
+	pia_config(machine, 1, &trailblz_pia_1_intf);
+	pia_config(machine, 2, &trailblz_pia_2_intf);
 }
 
 static MACHINE_RESET( trailblz )
@@ -617,34 +620,54 @@ static MACHINE_RESET( trailblz )
 	pia_reset();
 }
 
-static const struct AY8910interface ay8912_interface =
+static const ay8910_interface ay8912_interface =
 {
-	input_port_4_r
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
+	input_port_4_r,
+	NULL,
+	NULL,
+	NULL
 };
 
-static MACHINE_DRIVER_START( coinmstr )
-	MDRV_CPU_ADD_TAG("cpu",Z80,8000000) // ?
-	MDRV_CPU_PROGRAM_MAP(coinmstr_map,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+static const mc6845_interface h46505_intf =
+{
+	"main",		/* screen we are acting on */
+	8,			/* number of pixels per video memory address */
+	NULL,		/* before pixel update callback */
+	NULL,		/* row update callback */
+	NULL,		/* after pixel update callback */
+	NULL,		/* callback for display state changes */
+	NULL,		/* HSYNC callback */
+	NULL		/* VSYNC callback */
+};
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+
+static MACHINE_DRIVER_START( coinmstr )
+	MDRV_CPU_ADD("cpu",Z80,8000000) // ?
+	MDRV_CPU_PROGRAM_MAP(coinmstr_map,0)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*8, 64*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 46*8-1, 0*8, 32*8-1)
+
 	MDRV_GFXDECODE(coinmstr)
 	MDRV_PALETTE_LENGTH(256)
 
 	MDRV_VIDEO_START(coinmstr)
 	MDRV_VIDEO_UPDATE(coinmstr)
 
+	MDRV_MC6845_ADD("crtc", H46505, 14000000 / 16, h46505_intf)
+
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, 1500000)
+	MDRV_SOUND_ADD("ay", AY8910, 1500000)
 	MDRV_SOUND_CONFIG(ay8912_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
@@ -719,16 +742,16 @@ CN1/2 is connector for top ROM board                    * - unpopulated socket
 */
 
 ROM_START( quizmstr )
-	ROM_REGION( 0x10000, REGION_CPU1, ROMREGION_ERASEFF )
+	ROM_REGION( 0x10000, "cpu", ROMREGION_ERASEFF )
 	ROM_LOAD( "nm_qm4_11.ic9", 0x0000, 0x4000, CRC(3a233bf0) SHA1(7b91b6f19093e67dd5513a000138421d4ef6f0af) )
 	ROM_LOAD( "np_qm4_21.ic6", 0x4000, 0x4000, CRC(a1cd39e4) SHA1(420b0726577471c762ae470bc2138c035f295ad9) )
 	/* 0x8000 - 0xbfff empty */
 
-	ROM_REGION( 0x4000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x4000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "npc_qm4_11.ic45", 0x0000, 0x2000, CRC(ed48582a) SHA1(0aa2434a43af2990b8ad1cd3fc9f2e5e962f99c7) )
 	ROM_LOAD( "npc_qm4_21.ic41", 0x2000, 0x2000, CRC(b67b0183) SHA1(018cabace593e795edfe914cdaedb9ebdf158567) )
 
-	ROM_REGION( 0xa0000, REGION_USER1, ROMREGION_ERASEFF ) /* Question roms */
+	ROM_REGION( 0xa0000, "user1", ROMREGION_ERASEFF ) /* Question roms */
 	/* empty ic1 */
 	ROM_LOAD( "allgeme3.ic2",   0x08000, 0x8000, CRC(e9ead7f0) SHA1(c0b8e4e7905f31b74c8d217f0afc91f73d52927b) )
 	ROM_LOAD( "allgeme2.ic3",   0x10000, 0x8000, CRC(ac4d2ee8) SHA1(3a64fba8a24ae2e8bfd9d1c27804342e1779bcf6) )
@@ -753,30 +776,30 @@ ROM_END
 
 
 ROM_START( trailblz )
-	ROM_REGION( 0x10000, REGION_CPU1, ROMREGION_ERASEFF )
+	ROM_REGION( 0x10000, "cpu", ROMREGION_ERASEFF )
 	ROM_LOAD( "1-4.09",       0x0000, 0x4000, CRC(7c34749c) SHA1(3847188a734b32979f376f51f74dff050b610dfb) )
 	ROM_LOAD( "2-4.06",       0x4000, 0x4000, CRC(81a9809b) SHA1(4d2bfd5223713a9e2e15130a3176118d400ee63e) )
 	/* 0x8000 - 0xbfff empty */
 
-	ROM_REGION( 0x4000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x4000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "1-2.45",       0x0000, 0x2000, CRC(b4a807b1) SHA1(f00a4790adb0c25917a0dc8c98c9b65526304fd3) )
 	ROM_LOAD( "2-2.41",       0x2000, 0x2000, CRC(756dd230) SHA1(6d6f440bf1f48cc33d5e46cfc645809d5f8b1f3a) )
 
-	ROM_REGION( 0xa0000, REGION_USER1, ROMREGION_ERASEFF ) /* Question roms */
+	ROM_REGION( 0xa0000, "user1", ROMREGION_ERASEFF ) /* Question roms */
 	ROM_LOAD( "questions.bin", 0x00000, 0xa0000, NO_DUMP )
 ROM_END
 
 
 ROM_START( supnudg2 )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "cpu", 0 )
 	ROM_LOAD( "u3.bin",       0x0000, 0x8000, CRC(ed04e2cc) SHA1(7d90a588cca2d113487710e897771f9d99e37e62) )
 	ROM_LOAD( "u4.bin",       0x8000, 0x8000, CRC(0551e859) SHA1(b71640097cc75b78f3013f0e77de328bf1a205b1) )
 
-	ROM_REGION( 0x10000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x10000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "u23.bin",      0x0000, 0x8000, CRC(726a48ac) SHA1(cd17840067294812edf5bfa88d71fc967388df8e) )
 	ROM_LOAD( "u25.bin",      0x8000, 0x8000, CRC(1f7cef5e) SHA1(3abc31d400a0f5dc29c70d8aac42fd6302290cc9) )
 
-	ROM_REGION( 0xa0000, REGION_USER1, 0 ) /* Question roms */
+	ROM_REGION( 0xa0000, "user1", 0 ) /* Question roms */
 	ROM_LOAD( "q1.bin",       0x00000, 0x8000, CRC(245d679a) SHA1(2d3fbed8c1b3d0bffe7f3bd9088e0a5d207654c7) )
 	ROM_LOAD( "q2.bin",       0x08000, 0x8000, CRC(e41ae8fb) SHA1(526c7b60e6ee4dfe05bbabf0e1e986e04ac2f544) )
 	ROM_LOAD( "q3.bin",       0x10000, 0x8000, CRC(692218a2) SHA1(b9548dd835d9f3fb3e09bd018c7f9cbecafaee28) )
@@ -801,8 +824,8 @@ ROM_END
 
 static DRIVER_INIT( coinmstr )
 {
-	UINT8 *rom = memory_region(REGION_USER1);
-	int length = memory_region_length(REGION_USER1);
+	UINT8 *rom = memory_region(machine, "user1");
+	int length = memory_region_length(machine, "user1");
 	UINT8 *buf = malloc_or_die(length);
 	int i;
 
