@@ -25,9 +25,8 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/tms32010/tms32010.h"
 #include "cpu/tms34010/tms34010.h"
-#include "cpu/tms34010/34010ops.h"
 #include "cpu/tms32025/tms32025.h"
 #include "video/tlc34076.h"
 #include "sound/dac.h"
@@ -76,7 +75,7 @@ static TIMER_CALLBACK( nvram_write_timeout );
  *
  *************************************/
 
-static void amerdart_scanline(running_machine *machine, int screen, mame_bitmap *bitmap, int scanline, const tms34010_display_params *params)
+static void amerdart_scanline(const device_config *screen, bitmap_t *bitmap, int scanline, const tms34010_display_params *params)
 {
 	UINT16 *vram = &vram_base[(params->rowaddr << 8) & 0xff00];
 	UINT32 *dest = BITMAP_ADDR32(bitmap, scanline, 0);
@@ -103,7 +102,7 @@ static void amerdart_scanline(running_machine *machine, int screen, mame_bitmap
 }
 
 
-static void coolpool_scanline(running_machine *machine, int screen, mame_bitmap *bitmap, int scanline, const tms34010_display_params *params)
+static void coolpool_scanline(const device_config *screen, bitmap_t *bitmap, int scanline, const tms34010_display_params *params)
 {
 	UINT16 *vram = &vram_base[(params->rowaddr << 8) & 0x1ff00];
 	UINT32 *dest = BITMAP_ADDR32(bitmap, scanline, 0);
@@ -127,13 +126,13 @@ static void coolpool_scanline(running_machine *machine, int screen, mame_bitmap
  *
  *************************************/
 
-static void coolpool_to_shiftreg(UINT32 address, UINT16 *shiftreg)
+static void coolpool_to_shiftreg(const address_space *space, UINT32 address, UINT16 *shiftreg)
 {
 	memcpy(shiftreg, &vram_base[TOWORD(address) & ~TOWORD(0xfff)], TOBYTE(0x1000));
 }
 
 
-static void coolpool_from_shiftreg(UINT32 address, UINT16 *shiftreg)
+static void coolpool_from_shiftreg(const address_space *space, UINT32 address, UINT16 *shiftreg)
 {
 	memcpy(&vram_base[TOWORD(address) & ~TOWORD(0xfff)], shiftreg, TOBYTE(0x1000));
 }
@@ -149,7 +148,7 @@ static void coolpool_from_shiftreg(UINT32 address, UINT16 *shiftreg)
 static MACHINE_RESET( amerdart )
 {
 	nvram_write_enable = 0;
-	nvram_write_timer = timer_alloc(nvram_write_timeout, NULL);
+	nvram_write_timer = timer_alloc(machine, nvram_write_timeout, NULL);
 }
 
 
@@ -157,7 +156,7 @@ static MACHINE_RESET( coolpool )
 {
 	tlc34076_reset(6);
 	nvram_write_enable = 0;
-	nvram_write_timer = timer_alloc(nvram_write_timeout, NULL);
+	nvram_write_timer = timer_alloc(machine, nvram_write_timeout, NULL);
 }
 
 
@@ -184,7 +183,7 @@ static WRITE16_HANDLER( nvram_thrash_w )
 	if (!memcmp(nvram_unlock_seq, nvram_write_seq, sizeof(nvram_unlock_seq)))
 	{
 		nvram_write_enable = 1;
-		timer_adjust(nvram_write_timer, ATTOTIME_IN_MSEC(1000), 0, attotime_zero);
+		timer_adjust_oneshot(nvram_write_timer, ATTOTIME_IN_MSEC(1000), 0);
 	}
 }
 
@@ -192,7 +191,7 @@ static WRITE16_HANDLER( nvram_thrash_w )
 static WRITE16_HANDLER( nvram_data_w )
 {
 	/* only the low 8 bits matter */
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		if (nvram_write_enable)
 			generic_nvram16[offset] = data & 0xff;
@@ -202,8 +201,8 @@ static WRITE16_HANDLER( nvram_data_w )
 
 static WRITE16_HANDLER( nvram_thrash_data_w )
 {
-	nvram_data_w(offset, data, mem_mask);
-	nvram_thrash_w(offset, data, mem_mask);
+	nvram_data_w(space, offset, data, mem_mask);
+	nvram_thrash_w(space, offset, data, mem_mask);
 }
 
 
@@ -216,12 +215,12 @@ static WRITE16_HANDLER( nvram_thrash_data_w )
 
 static WRITE16_HANDLER( amerdart_misc_w )
 {
-	logerror("%08x:IOP_reset_w %04x\n",activecpu_get_pc(),data);
+	logerror("%08x:IOP_reset_w %04x\n",cpu_get_pc(space->cpu),data);
 
 	coin_counter_w(0, ~data & 0x0001);
 	coin_counter_w(1, ~data & 0x0002);
 
-	cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, (data & 0x0400) ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, (data & 0x0400) ? ASSERT_LINE : CLEAR_LINE);
 
 	/* bits 10-15 are counted down over time */
 	if (data & 0x0400) amerdart_iop_echo = 1;
@@ -234,7 +233,7 @@ static TIMER_CALLBACK( amerdart_iop_response )
 	iop_answer = iop_cmd;
 	if (amerdart_iop_echo && iop_cmd != 0x19)
 	{
-		cpunum_set_input_line(machine, 0, 1, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[0], 1, ASSERT_LINE);
 		return;
 	}
 	amerdart_iop_echo = 0;
@@ -255,32 +254,32 @@ static TIMER_CALLBACK( amerdart_iop_response )
 			break;
 
 		case 0x100:
-			iop_answer = (INT8)(-readinputportbytag("YAXIS2") - readinputportbytag("XAXIS2")) << 6;
+			iop_answer = (INT8)(-input_port_read(machine, "YAXIS2") - input_port_read(machine, "XAXIS2")) << 6;
 			break;
 		case 0x101:
-			iop_answer = (INT8)(-readinputportbytag("YAXIS2") + readinputportbytag("XAXIS2")) << 6;
+			iop_answer = (INT8)(-input_port_read(machine, "YAXIS2") + input_port_read(machine, "XAXIS2")) << 6;
 			break;
 		case 0x102:
-			iop_answer = (INT8)(-readinputportbytag("YAXIS1") - readinputportbytag("XAXIS1")) << 6;
+			iop_answer = (INT8)(-input_port_read(machine, "YAXIS1") - input_port_read(machine, "XAXIS1")) << 6;
 			break;
 		case 0x103:
-			iop_answer = (INT8)(-readinputportbytag("YAXIS1") + readinputportbytag("XAXIS1")) << 6;
+			iop_answer = (INT8)(-input_port_read(machine, "YAXIS1") + input_port_read(machine, "XAXIS1")) << 6;
 			break;
 
 		case 0x500:
-			iop_answer = readinputport(0);
+			iop_answer = input_port_read(machine, "IN1");
 			break;
 	}
 
-	cpunum_set_input_line(machine, 0, 1, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[0], 1, ASSERT_LINE);
 }
 
 
 static WRITE16_HANDLER( amerdart_iop_w )
 {
-	logerror("%08x:IOP write %04x\n", activecpu_get_pc(), data);
+	logerror("%08x:IOP write %04x\n", cpu_get_pc(space->cpu), data);
 	COMBINE_DATA(&iop_cmd);
-	timer_set(ATTOTIME_IN_USEC(100), NULL, 0, amerdart_iop_response);
+	timer_set(space->machine, ATTOTIME_IN_USEC(100), NULL, 0, amerdart_iop_response);
 }
 
 
@@ -293,12 +292,12 @@ static WRITE16_HANDLER( amerdart_iop_w )
 
 static WRITE16_HANDLER( coolpool_misc_w )
 {
-	logerror("%08x:IOP_reset_w %04x\n",activecpu_get_pc(),data);
+	logerror("%08x:IOP_reset_w %04x\n",cpu_get_pc(space->cpu),data);
 
 	coin_counter_w(0, ~data & 0x0001);
 	coin_counter_w(1, ~data & 0x0002);
 
-	cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, (data & 0x0400) ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, (data & 0x0400) ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -314,24 +313,24 @@ static TIMER_CALLBACK( deferred_iop_w )
 {
 	iop_cmd = param;
 	cmd_pending = 1;
-	cpunum_set_input_line(machine, 1, 0, HOLD_LINE);	/* ???  I have no idea who should generate this! */
+	cpu_set_input_line(machine->cpu[1], 0, HOLD_LINE);	/* ???  I have no idea who should generate this! */
 										/* the DSP polls the status bit so it isn't strictly */
 										/* necessary to also have an IRQ */
-	cpu_boost_interleave(attotime_zero, ATTOTIME_IN_USEC(50));
+	cpuexec_boost_interleave(machine, attotime_zero, ATTOTIME_IN_USEC(50));
 }
 
 
 static WRITE16_HANDLER( coolpool_iop_w )
 {
-	logerror("%08x:IOP write %04x\n", activecpu_get_pc(), data);
-	timer_call_after_resynch(NULL, data, deferred_iop_w);
+	logerror("%08x:IOP write %04x\n", cpu_get_pc(space->cpu), data);
+	timer_call_after_resynch(space->machine, NULL, data, deferred_iop_w);
 }
 
 
 static READ16_HANDLER( coolpool_iop_r )
 {
-	logerror("%08x:IOP read %04x\n",activecpu_get_pc(),iop_answer);
-	cpunum_set_input_line(Machine, 0, 1, CLEAR_LINE);
+	logerror("%08x:IOP read %04x\n",cpu_get_pc(space->cpu),iop_answer);
+	cpu_set_input_line(space->machine->cpu[0], 1, CLEAR_LINE);
 
 	return iop_answer;
 }
@@ -348,16 +347,16 @@ static READ16_HANDLER( coolpool_iop_r )
 static READ16_HANDLER( dsp_cmd_r )
 {
 	cmd_pending = 0;
-	logerror("%08x:IOP cmd_r %04x\n",activecpu_get_pc(),iop_cmd);
+	logerror("%08x:IOP cmd_r %04x\n",cpu_get_pc(space->cpu),iop_cmd);
 	return iop_cmd;
 }
 
 
 static WRITE16_HANDLER( dsp_answer_w )
 {
-	logerror("%08x:IOP answer %04x\n",activecpu_get_pc(),data);
+	logerror("%08x:IOP answer %04x\n",cpu_get_pc(space->cpu),data);
 	iop_answer = data;
-	cpunum_set_input_line(Machine, 0, 1, ASSERT_LINE);
+	cpu_set_input_line(space->machine->cpu[0], 1, ASSERT_LINE);
 }
 
 
@@ -382,8 +381,8 @@ static READ16_HANDLER( dsp_hold_line_r )
 
 static READ16_HANDLER( dsp_rom_r )
 {
-	UINT8 *rom = memory_region(REGION_USER2);
-	return rom[iop_romaddr & (memory_region_length(REGION_USER2) - 1)];
+	UINT8 *rom = memory_region(space->machine, "user2");
+	return rom[iop_romaddr & (memory_region_length(space->machine, "user2") - 1)];
 }
 
 
@@ -404,7 +403,7 @@ static WRITE16_HANDLER( dsp_romaddr_w )
 
 static WRITE16_HANDLER( dsp_dac_w )
 {
-	DAC_signed_data_16_w(0, (INT16)(data << 4) + 0x8000);
+	dac_signed_data_16_w(0, (INT16)(data << 4) + 0x8000);
 }
 
 
@@ -420,9 +419,9 @@ static READ16_HANDLER( coolpool_input_r )
 	static UINT8 oldx, oldy;
 	static UINT16 lastresult;
 
-	int result = (readinputportbytag("IN1") & 0x00ff) | (lastresult & 0xff00);
-	UINT8 newx = readinputportbytag("XAXIS");
-	UINT8 newy = readinputportbytag("YAXIS");
+	int result = (input_port_read(space->machine, "IN1") & 0x00ff) | (lastresult & 0xff00);
+	UINT8 newx = input_port_read(space->machine, "XAXIS");
+	UINT8 newy = input_port_read(space->machine, "YAXIS");
 	int dx = (INT8)(newx - oldx);
 	int dy = (INT8)(newy - oldy);
 
@@ -472,7 +471,7 @@ static READ16_HANDLER( coolpool_input_r )
 		}
 	}
 
-//  logerror("%08X:read port 7 (X=%02X Y=%02X oldX=%02X oldY=%02X res=%04X)\n", activecpu_get_pc(),
+//  logerror("%08X:read port 7 (X=%02X Y=%02X oldX=%02X oldY=%02X res=%04X)\n", cpu_get_pc(space->cpu),
 //      newx, newy, oldx, oldy, result);
 	lastresult = result;
 	return result;
@@ -490,9 +489,9 @@ static ADDRESS_MAP_START( amerdart_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x00000000, 0x000fffff) AM_RAM AM_BASE(&vram_base)
 	AM_RANGE(0x04000000, 0x0400000f) AM_WRITE(amerdart_misc_w)
 	AM_RANGE(0x05000000, 0x0500000f) AM_READWRITE(coolpool_iop_r, amerdart_iop_w)
-	AM_RANGE(0x06000000, 0x06007fff) AM_READWRITE(MRA16_RAM, nvram_thrash_data_w) AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)
+	AM_RANGE(0x06000000, 0x06007fff) AM_RAM_WRITE(nvram_thrash_data_w) AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)
 	AM_RANGE(0xc0000000, 0xc00001ff) AM_READWRITE(tms34010_io_register_r, tms34010_io_register_w)
-	AM_RANGE(0xffb00000, 0xffffffff) AM_ROM AM_REGION(REGION_USER1, 0)
+	AM_RANGE(0xffb00000, 0xffffffff) AM_ROM AM_REGION("user1", 0)
 ADDRESS_MAP_END
 
 
@@ -501,10 +500,10 @@ static ADDRESS_MAP_START( coolpool_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x01000000, 0x010000ff) AM_READWRITE(tlc34076_lsb_r, tlc34076_lsb_w)	// IMSG176P-40
 	AM_RANGE(0x02000000, 0x020000ff) AM_READWRITE(coolpool_iop_r, coolpool_iop_w)
 	AM_RANGE(0x03000000, 0x0300000f) AM_WRITE(coolpool_misc_w)
-	AM_RANGE(0x03000000, 0x03ffffff) AM_ROM AM_REGION(REGION_GFX1, 0)
-	AM_RANGE(0x06000000, 0x06007fff) AM_READWRITE(MRA16_RAM, nvram_thrash_data_w) AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)
+	AM_RANGE(0x03000000, 0x03ffffff) AM_ROM AM_REGION("gfx1", 0)
+	AM_RANGE(0x06000000, 0x06007fff) AM_RAM_WRITE(nvram_thrash_data_w) AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)
 	AM_RANGE(0xc0000000, 0xc00001ff) AM_READWRITE(tms34010_io_register_r, tms34010_io_register_w)
-	AM_RANGE(0xffe00000, 0xffffffff) AM_ROM AM_REGION(REGION_USER1, 0)
+	AM_RANGE(0xffe00000, 0xffffffff) AM_ROM AM_REGION("user1", 0)
 ADDRESS_MAP_END
 
 
@@ -513,10 +512,10 @@ static ADDRESS_MAP_START( nballsht_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x02000000, 0x020000ff) AM_READWRITE(coolpool_iop_r, coolpool_iop_w)
 	AM_RANGE(0x03000000, 0x0300000f) AM_WRITE(coolpool_misc_w)
 	AM_RANGE(0x04000000, 0x040000ff) AM_READWRITE(tlc34076_lsb_r, tlc34076_lsb_w)	// IMSG176P-40
-	AM_RANGE(0x06000000, 0x0601ffff) AM_MIRROR(0x00020000) AM_READWRITE(MRA16_RAM, nvram_thrash_data_w) AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)
+	AM_RANGE(0x06000000, 0x0601ffff) AM_MIRROR(0x00020000) AM_RAM_WRITE(nvram_thrash_data_w) AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)
 	AM_RANGE(0xc0000000, 0xc00001ff) AM_READWRITE(tms34010_io_register_r, tms34010_io_register_w)
-	AM_RANGE(0xff000000, 0xff7fffff) AM_ROM AM_REGION(REGION_GFX1, 0)
-	AM_RANGE(0xffc00000, 0xffffffff) AM_ROM AM_REGION(REGION_USER1, 0)
+	AM_RANGE(0xff000000, 0xff7fffff) AM_ROM AM_REGION("gfx1", 0)
+	AM_RANGE(0xffc00000, 0xffffffff) AM_ROM AM_REGION("user1", 0)
 ADDRESS_MAP_END
 
 
@@ -543,8 +542,8 @@ static ADDRESS_MAP_START( dsp_io_map, ADDRESS_SPACE_IO, 16 )
 	AM_RANGE(0x02, 0x02) AM_READWRITE(dsp_cmd_r, dsp_answer_w)
 	AM_RANGE(0x03, 0x03) AM_WRITE(dsp_dac_w)
 	AM_RANGE(0x04, 0x04) AM_READ(dsp_rom_r)
-	AM_RANGE(0x05, 0x05) AM_READ(input_port_0_word_r)
-	AM_RANGE(0x07, 0x07) AM_READ(input_port_1_word_r)
+	AM_RANGE(0x05, 0x05) AM_READ_PORT("IN0")
+	AM_RANGE(0x07, 0x07) AM_READ_PORT("IN1")
 	AM_RANGE(TMS32025_BIO, TMS32025_BIO) AM_READ(dsp_bio_line_r)
 	AM_RANGE(TMS32025_HOLD, TMS32025_HOLD) AM_READ(dsp_hold_line_r)
 //  AM_RANGE(TMS32025_HOLDA, TMS32025_HOLDA) AM_WRITE(dsp_HOLDA_signal_w)
@@ -559,7 +558,7 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( amerdart )
-	PORT_START_TAG("IN1")
+	PORT_START("IN1")
 	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_BUTTON1 )	PORT_PLAYER(1)
 	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_UNKNOWN )
@@ -570,22 +569,22 @@ static INPUT_PORTS_START( amerdart )
 	PORT_BIT( 0x0080, IP_ACTIVE_HIGH, IPT_SERVICE1 )
 	PORT_BIT( 0xff00, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 
-	PORT_START_TAG("XAXIS1")
+	PORT_START("XAXIS1")
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_RESET PORT_PLAYER(1)
 
-	PORT_START_TAG("YAXIS1")
+	PORT_START("YAXIS1")
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_RESET PORT_PLAYER(1)
 
-	PORT_START_TAG("XAXIS2")
+	PORT_START("XAXIS2")
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_RESET PORT_PLAYER(2)
 
-	PORT_START_TAG("YAXIS2")
+	PORT_START("YAXIS2")
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_RESET PORT_PLAYER(2)
 INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( 9ballsht )
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT( 0x00ff, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x0300, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
@@ -595,7 +594,7 @@ static INPUT_PORTS_START( 9ballsht )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
 
-	PORT_START_TAG("IN1")
+	PORT_START("IN1")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -616,14 +615,14 @@ INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( coolpool )
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT( 0x00ff, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x0f00, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
 	PORT_BIT( 0xc000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("IN1")
+	PORT_START("IN1")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -634,10 +633,10 @@ static INPUT_PORTS_START( coolpool )
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_SPECIAL )
 
-	PORT_START_TAG("XAXIS")
+	PORT_START("XAXIS")
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10)
 
-	PORT_START_TAG("YAXIS")
+	PORT_START("YAXIS")
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_REVERSE
 INPUT_PORTS_END
 
@@ -652,7 +651,7 @@ INPUT_PORTS_END
 static const tms34010_config tms_config_amerdart =
 {
 	FALSE,							/* halt on reset */
-	0,								/* the screen operated on */
+	"main",							/* the screen operated on */
 	40000000/12,					/* pixel clock */
 	2,								/* pixels per clock */
 	amerdart_scanline,				/* scanline callback */
@@ -665,7 +664,7 @@ static const tms34010_config tms_config_amerdart =
 static const tms34010_config tms_config_coolpool =
 {
 	FALSE,							/* halt on reset */
-	0,								/* the screen operated on */
+	"main",							/* the screen operated on */
 	40000000/6,						/* pixel clock */
 	1,								/* pixels per clock */
 	coolpool_scanline,				/* scanline callback */
@@ -685,11 +684,11 @@ static const tms34010_config tms_config_coolpool =
 static MACHINE_DRIVER_START( amerdart )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(TMS34010, 40000000)
+	MDRV_CPU_ADD("main", TMS34010, 40000000)
 	MDRV_CPU_CONFIG(tms_config_amerdart)
 	MDRV_CPU_PROGRAM_MAP(amerdart_map,0)
 
-	MDRV_CPU_ADD(TMS32010, 15000000/2)
+	MDRV_CPU_ADD("dsp", TMS32010, 15000000/2)
 	MDRV_CPU_FLAGS(CPU_DISABLE)
 	MDRV_CPU_PROGRAM_MAP(amerdart_dsp_map,0)
 
@@ -697,17 +696,16 @@ static MACHINE_DRIVER_START( amerdart )
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_VIDEO_UPDATE(tms340x0)
 
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_RAW_PARAMS(40000000/6, 212*2, 0, 161*2, 262, 0, 241)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ADD("dac", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -715,11 +713,11 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( coolpool )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", TMS34010, 40000000)
+	MDRV_CPU_ADD("main", TMS34010, 40000000)
 	MDRV_CPU_CONFIG(tms_config_coolpool)
 	MDRV_CPU_PROGRAM_MAP(coolpool_map,0)
 
-	MDRV_CPU_ADD(TMS32026,40000000)
+	MDRV_CPU_ADD("dsp", TMS32026,40000000)
 	MDRV_CPU_PROGRAM_MAP(dsp_program_map,0)
 	MDRV_CPU_IO_MAP(dsp_io_map,0)
 
@@ -727,17 +725,16 @@ static MACHINE_DRIVER_START( coolpool )
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_VIDEO_UPDATE(tms340x0)
 
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_RAW_PARAMS(40000000/6, 424, 0, 320, 262, 0, 240)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ADD("dac", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -758,7 +755,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( amerdart )
-	ROM_REGION16_LE( 0x0a0000, REGION_USER1, 0 )	/* 34010 code */
+	ROM_REGION16_LE( 0x0a0000, "user1", 0 )	/* 34010 code */
 	ROM_LOAD16_BYTE( "u31",  0x000001, 0x10000, CRC(9628c422) SHA1(46b71acc746760962e34e9d7876f9499ea7d5c7c) )
 	ROM_LOAD16_BYTE( "u32",  0x000000, 0x10000, CRC(2d651ed0) SHA1(e2da2c3d8f25c17e26fd435c75983b2db8691993) )
 	ROM_LOAD16_BYTE( "u38",  0x020001, 0x10000, CRC(1eb8c887) SHA1(220f566043535c54ad1cf2216966c7f42099e50b) )
@@ -770,11 +767,11 @@ ROM_START( amerdart )
 	ROM_LOAD16_BYTE( "u57",  0x080001, 0x10000, CRC(f620f935) SHA1(bf891fce1f04f3ad5b8b72d43d041ceacb0b65bc) )
 	ROM_LOAD16_BYTE( "u58",  0x080000, 0x10000, CRC(f1b3d7c4) SHA1(7b897230d110be7a5eb05eda927d00561ebb9ce3) )
 
-	ROM_REGION( 0x18000, REGION_CPU2, 0 )	/* 32015 code (missing) */
+	ROM_REGION( 0x18000, "dsp", 0 )	/* 32015 code (missing) */
 	ROM_LOAD16_BYTE( "dspl",         0x00000, 0x08000, NO_DUMP )
 	ROM_LOAD16_BYTE( "dsph",         0x00001, 0x08000, NO_DUMP )
 
-	ROM_REGION( 0x100000, REGION_USER2, 0 )				/* 32015 data? (incl. samples?) */
+	ROM_REGION( 0x100000, "user2", 0 )				/* 32015 data? (incl. samples?) */
 	ROM_LOAD16_WORD( "u1",   0x000000, 0x10000, CRC(3f459482) SHA1(d9d489efd0d9217fceb3bf1a3b37a78d6823b4d9) )
 	ROM_LOAD16_WORD( "u2",   0x010000, 0x10000, CRC(a587fffd) SHA1(f33f511d1bf1d6eb3c42535593a9718571174c4b) )
 	ROM_LOAD16_WORD( "u3",   0x020000, 0x10000, CRC(984d343a) SHA1(ee214830de4cb22d2d8e9d3ca335eff05af4abb6) )
@@ -794,7 +791,7 @@ ROM_START( amerdart )
 ROM_END
 
 ROM_START( amerdar2 )
-	ROM_REGION16_LE( 0x0a0000, REGION_USER1, 0 )	/* 34010 code */
+	ROM_REGION16_LE( 0x0a0000, "user1", 0 )	/* 34010 code */
 	ROM_LOAD16_BYTE( "u31",     0x000001, 0x10000, CRC(9628c422) SHA1(46b71acc746760962e34e9d7876f9499ea7d5c7c) )
 	ROM_LOAD16_BYTE( "u32",     0x000000, 0x10000, CRC(2d651ed0) SHA1(e2da2c3d8f25c17e26fd435c75983b2db8691993) )
 	ROM_LOAD16_BYTE( "u38",     0x020001, 0x10000, CRC(1eb8c887) SHA1(220f566043535c54ad1cf2216966c7f42099e50b) )
@@ -806,11 +803,11 @@ ROM_START( amerdar2 )
 	ROM_LOAD16_BYTE( "u57.bin", 0x080001, 0x10000, CRC(8a70f849) SHA1(dfd4cf90de2ab8cbeff458f0fd20110c1ed009e9) )
 	ROM_LOAD16_BYTE( "u58.bin", 0x080000, 0x10000, CRC(8bb81975) SHA1(b7666572ab543991c7deaa0ebefb8b4526a7e386) )
 
-	ROM_REGION( 0x18000, REGION_CPU2, 0 )	/* 32015 code (missing) */
+	ROM_REGION( 0x18000, "dsp", 0 )	/* 32015 code (missing) */
 	ROM_LOAD16_BYTE( "dspl",         0x00000, 0x08000, NO_DUMP )
 	ROM_LOAD16_BYTE( "dsph",         0x00001, 0x08000, NO_DUMP )
 
-	ROM_REGION( 0x100000, REGION_USER2, 0 )				/* 32015 data? (incl. samples?) */
+	ROM_REGION( 0x100000, "user2", 0 )				/* 32015 data? (incl. samples?) */
 	ROM_LOAD16_WORD( "u1.bin",   0x000000, 0x10000, CRC(e2bb7f54) SHA1(39eeb61a852b93331f445cc1c993727e52959660) )
 	ROM_LOAD16_WORD( "u2",      0x010000, 0x10000, CRC(a587fffd) SHA1(f33f511d1bf1d6eb3c42535593a9718571174c4b) )
 	ROM_LOAD16_WORD( "u3",      0x020000, 0x10000, CRC(984d343a) SHA1(ee214830de4cb22d2d8e9d3ca335eff05af4abb6) )
@@ -831,11 +828,11 @@ ROM_END
 
 
 ROM_START( coolpool )
-	ROM_REGION16_LE( 0x40000, REGION_USER1, 0 )	/* 34010 code */
+	ROM_REGION16_LE( 0x40000, "user1", 0 )	/* 34010 code */
 	ROM_LOAD16_BYTE( "u112b",        0x00000, 0x20000, CRC(aa227769) SHA1(488e357a7aad07369cade3110cde14ba8562c66c) )
 	ROM_LOAD16_BYTE( "u113b",        0x00001, 0x20000, CRC(5b5f82f1) SHA1(82afb6a8d94cf09960b962d5208aab451b56feae) )
 
-	ROM_REGION16_LE( 0x200000, REGION_GFX1, 0 )	/* gfx data read by main CPU */
+	ROM_REGION16_LE( 0x200000, "gfx1", 0 )	/* gfx data read by main CPU */
 	ROM_LOAD16_BYTE( "u04",          0x000000, 0x20000, CRC(66a9940e) SHA1(7fa587280ecfad6b06194868de09cbdd57cf517f) )
 	ROM_CONTINUE(                    0x100000, 0x20000 )
 	ROM_LOAD16_BYTE( "u08",          0x000001, 0x20000, CRC(56789cf4) SHA1(5ad867d5029fdac9dccd01a6979171aa30d9a6eb) )
@@ -853,11 +850,11 @@ ROM_START( coolpool )
 	ROM_LOAD16_BYTE( "u05",          0x0c0001, 0x20000, CRC(616965e2) SHA1(588ea3c5c7838c50b2157ff1074f629d9d85791c) )
 	ROM_CONTINUE(                    0x1c0001, 0x20000 )
 
-	ROM_REGION( 0x40000, REGION_CPU2, 0 )	/* TMS320C26 */
+	ROM_REGION( 0x40000, "dsp", 0 )	/* TMS320C26 */
 	ROM_LOAD16_BYTE( "u34",          0x00000, 0x08000, CRC(dc1df70b) SHA1(e42fa7e34e50e0bd2aaeea5c55d750ed3286610d) )
 	ROM_LOAD16_BYTE( "u35",          0x00001, 0x08000, CRC(ac999431) SHA1(7e4c2dcaedcb7e7c67072a179e4b8488d2bbdac7) )
 
-	ROM_REGION( 0x200000, REGION_USER2, 0 )	/* TMS32026 data */
+	ROM_REGION( 0x200000, "user2", 0 )	/* TMS32026 data */
 	ROM_LOAD( "u17c",         0x000000, 0x40000, CRC(ea3cc41d) SHA1(e703e789dfbcfaec878a990031ce839164c51253) )
 	ROM_LOAD( "u16c",         0x040000, 0x40000, CRC(2e6680ea) SHA1(cb30dc789039aab491428d075fee9e0bc04fd2ce) )
 	ROM_LOAD( "u15c",         0x080000, 0x40000, CRC(8e5f248e) SHA1(a954d3c20dc0b70f83c4c238db30a33285fcb353) )
@@ -870,19 +867,19 @@ ROM_END
 
 
 ROM_START( 9ballsht )
-	ROM_REGION16_LE( 0x80000, REGION_USER1, 0 )	/* 34010 code */
+	ROM_REGION16_LE( 0x80000, "user1", 0 )	/* 34010 code */
 	ROM_LOAD16_BYTE( "u112",         0x00000, 0x40000, CRC(b3855e59) SHA1(c3175df24b85897783169bcaccd61630e512f7f6) )
 	ROM_LOAD16_BYTE( "u113",         0x00001, 0x40000, CRC(30cbf462) SHA1(64b2e2d40c2a92c4f4823dc866e5464792954ac3) )
 
-	ROM_REGION16_LE( 0x100000, REGION_GFX1, 0 )	/* gfx data read by main CPU */
+	ROM_REGION16_LE( 0x100000, "gfx1", 0 )	/* gfx data read by main CPU */
 	ROM_LOAD16_BYTE( "u110",         0x00000, 0x80000, CRC(890ed5c0) SHA1(eaf06ee5b6c5ed0103b535396b4517012818a416) )
 	ROM_LOAD16_BYTE( "u111",         0x00001, 0x80000, CRC(1a9f1145) SHA1(ba52a6d1aca26484c320518f69c66ce3ceb4adcf) )
 
-	ROM_REGION( 0x40000, REGION_CPU2, 0 )	/* TMS320C26 */
+	ROM_REGION( 0x40000, "dsp", 0 )	/* TMS320C26 */
 	ROM_LOAD16_BYTE( "u34",          0x00000, 0x08000, CRC(dc1df70b) SHA1(e42fa7e34e50e0bd2aaeea5c55d750ed3286610d) )
 	ROM_LOAD16_BYTE( "u35",          0x00001, 0x08000, CRC(ac999431) SHA1(7e4c2dcaedcb7e7c67072a179e4b8488d2bbdac7) )
 
-	ROM_REGION( 0x100000, REGION_USER2, 0 )	/* TMS32026 data */
+	ROM_REGION( 0x100000, "user2", 0 )	/* TMS32026 data */
 	ROM_LOAD( "u54",          0x00000, 0x80000, CRC(1be5819c) SHA1(308b5b1fe05634419d03956ae1b2e5a61206900f) )
 	ROM_LOAD( "u53",          0x80000, 0x80000, CRC(d401805d) SHA1(f4bcb2bdc45c3bc5ca423e518cdea8b3a7e8d60e) )
 ROM_END
@@ -892,41 +889,62 @@ ROM_END
   I assume the others are the same.
  */
 ROM_START( 9ballsh2 )
-	ROM_REGION16_LE( 0x80000, REGION_USER1, 0 )	/* 34010 code */
+	ROM_REGION16_LE( 0x80000, "user1", 0 )	/* 34010 code */
 	ROM_LOAD16_BYTE( "e-scape.112",  0x00000, 0x40000, CRC(aee8114f) SHA1(a0d0e9e3a879393585b85ac6d04e31a7d4221179) )
 	ROM_LOAD16_BYTE( "e-scape.113",  0x00001, 0x40000, CRC(ccd472a7) SHA1(d074080e987c233b26b3c72248411c575f7a2293) )
 
-	ROM_REGION16_LE( 0x100000, REGION_GFX1, 0 )	/* gfx data read by main CPU */
+	ROM_REGION16_LE( 0x100000, "gfx1", 0 )	/* gfx data read by main CPU */
 	ROM_LOAD16_BYTE( "u110",         0x00000, 0x80000, CRC(890ed5c0) SHA1(eaf06ee5b6c5ed0103b535396b4517012818a416) )
 	ROM_LOAD16_BYTE( "u111",         0x00001, 0x80000, CRC(1a9f1145) SHA1(ba52a6d1aca26484c320518f69c66ce3ceb4adcf) )
 
-	ROM_REGION( 0x40000, REGION_CPU2, 0 )	/* TMS320C26 */
+	ROM_REGION( 0x40000, "dsp", 0 )	/* TMS320C26 */
 	ROM_LOAD16_BYTE( "u34",          0x00000, 0x08000, CRC(dc1df70b) SHA1(e42fa7e34e50e0bd2aaeea5c55d750ed3286610d) )
 	ROM_LOAD16_BYTE( "u35",          0x00001, 0x08000, CRC(ac999431) SHA1(7e4c2dcaedcb7e7c67072a179e4b8488d2bbdac7) )
 
-	ROM_REGION( 0x100000, REGION_USER2, 0 )	/* TMS32026 data */
+	ROM_REGION( 0x100000, "user2", 0 )	/* TMS32026 data */
 	ROM_LOAD( "u54",          0x00000, 0x80000, CRC(1be5819c) SHA1(308b5b1fe05634419d03956ae1b2e5a61206900f) )
 	ROM_LOAD( "u53",          0x80000, 0x80000, CRC(d401805d) SHA1(f4bcb2bdc45c3bc5ca423e518cdea8b3a7e8d60e) )
 ROM_END
 
 ROM_START( 9ballsh3 )
-	ROM_REGION16_LE( 0x80000, REGION_USER1, 0 )	/* 34010 code */
+	ROM_REGION16_LE( 0x80000, "user1", 0 )	/* 34010 code */
 	ROM_LOAD16_BYTE( "8e_1826.112",  0x00000, 0x40000, CRC(486f7a8b) SHA1(635e3b1e7a21a86dd3d0ea994e9b923b06df587e) )
 	ROM_LOAD16_BYTE( "8e_6166.113",  0x00001, 0x40000, CRC(c41db70a) SHA1(162112f9f5bb6345920a45c41da6a249796bd21f) )
 
-	ROM_REGION16_LE( 0x100000, REGION_GFX1, 0 )	/* gfx data read by main CPU */
+	ROM_REGION16_LE( 0x100000, "gfx1", 0 )	/* gfx data read by main CPU */
 	ROM_LOAD16_BYTE( "u110",         0x00000, 0x80000, CRC(890ed5c0) SHA1(eaf06ee5b6c5ed0103b535396b4517012818a416) )
 	ROM_LOAD16_BYTE( "u111",         0x00001, 0x80000, CRC(1a9f1145) SHA1(ba52a6d1aca26484c320518f69c66ce3ceb4adcf) )
 
-	ROM_REGION( 0x40000, REGION_CPU2, 0 )	/* TMS320C26 */
+	ROM_REGION( 0x40000, "dsp", 0 )	/* TMS320C26 */
 	ROM_LOAD16_BYTE( "u34",          0x00000, 0x08000, CRC(dc1df70b) SHA1(e42fa7e34e50e0bd2aaeea5c55d750ed3286610d) )
 	ROM_LOAD16_BYTE( "u35",          0x00001, 0x08000, CRC(ac999431) SHA1(7e4c2dcaedcb7e7c67072a179e4b8488d2bbdac7) )
 
-	ROM_REGION( 0x100000, REGION_USER2, 0 )	/* TMS32026 data */
+	ROM_REGION( 0x100000, "user2", 0 )	/* TMS32026 data */
 	ROM_LOAD( "u54",          0x00000, 0x80000, CRC(1be5819c) SHA1(308b5b1fe05634419d03956ae1b2e5a61206900f) )
 	ROM_LOAD( "u53",          0x80000, 0x80000, CRC(d401805d) SHA1(f4bcb2bdc45c3bc5ca423e518cdea8b3a7e8d60e) )
 ROM_END
 
+/* If you use the roms from the other set this will boot as 9 Ball Shootout Championship, it looks however like the TMS32026 data
+   should differ at least (the correct data in the bad dump is very different to the other dumps) */
+ROM_START( 9ballshc )
+	ROM_REGION16_LE( 0x80000, "user1", 0 )	/* 34010 code */
+	ROM_LOAD16_BYTE( "escape.112",  0x00000, 0x40000, CRC(7ba2749a) SHA1(e2ddc2600234dbebbb423f201cc4061fd0b9911a) )
+	ROM_LOAD16_BYTE( "escape.113",  0x00001, 0x40000, CRC(1e0f3c62) SHA1(3c24a38dcb553fd84b0b44a5a8d93a14435e22b0) )
+
+	ROM_REGION16_LE( 0x100000, "gfx1", 0 )	/* gfx data read by main CPU */
+	ROM_LOAD16_BYTE( "escape.110",  0x00000, 0x80000, BAD_DUMP CRC(1da8da18) SHA1(63455a7cccb21dc5afeb860e17527cd443f542eb) ) // xx1xxxxxxxxxxxxxxxx = 0x00
+	ROM_LOAD16_BYTE( "escape.111",  0x00001, 0x80000, BAD_DUMP CRC(65dea5e8) SHA1(291232dd19240b150e54a4ed300bcfd40bf5d1f2) ) // xx1xxxxxxxxxxxxxxxx = 0x00
+
+	ROM_REGION( 0x40000, "dsp", 0 )	/* TMS320C26 */
+	ROM_LOAD16_BYTE( "u34",          0x00000, 0x08000, CRC(dc1df70b) SHA1(e42fa7e34e50e0bd2aaeea5c55d750ed3286610d) )
+	ROM_LOAD16_BYTE( "u35",          0x00001, 0x08000, CRC(ac999431) SHA1(7e4c2dcaedcb7e7c67072a179e4b8488d2bbdac7) )
+
+	ROM_REGION( 0x100000, "user2", 0 )	/* TMS32026 data */
+	ROM_LOAD( "escape.54",          0x00000, 0x80000, BAD_DUMP CRC(28b4dec6) SHA1(10e47105abb48b572da38709128cba961299d88e) ) // xx1xxxxxxxxxxxxxxxx = 0x00
+	ROM_LOAD( "escape.53",          0x80000, 0x80000, CRC(28f4dd51) SHA1(67ea5bf3dacc17ef4fcc999e4ae0857759fac838) )
+ROM_END
+
+
 
 
 /*************************************
@@ -937,18 +955,19 @@ ROM_END
 
 static DRIVER_INIT( coolpool )
 {
-	memory_install_read16_handler(1, ADDRESS_SPACE_IO, 0x07, 0x07, 0, 0, coolpool_input_r);
+	memory_install_read16_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_IO), 0x07, 0x07, 0, 0, coolpool_input_r);
 }
 
 
 static DRIVER_INIT( 9ballsht )
 {
-	int a;
+	int a, len;
 	UINT16 *rom;
 
 	/* decrypt the main program ROMs */
-	rom = (UINT16 *)memory_region(REGION_USER1);
-	for (a = 0;a < memory_region_length(REGION_USER1)/2;a++)
+	rom = (UINT16 *)memory_region(machine, "user1");
+	len = memory_region_length(machine, "user1");
+	for (a = 0;a < len/2;a++)
 	{
 		int hi,lo,nhi,nlo;
 
@@ -970,8 +989,9 @@ static DRIVER_INIT( 9ballsht )
 	}
 
 	/* decrypt the sub data ROMs */
-	rom = (UINT16 *)memory_region(REGION_USER2);
-	for (a = 1;a < memory_region_length(REGION_USER2)/2;a+=4)
+	rom = (UINT16 *)memory_region(machine, "user2");
+	len = memory_region_length(machine, "user2");
+	for (a = 1;a < len/2;a+=4)
 	{
 		/* just swap bits 1 and 2 of the address */
 		UINT16 tmp = rom[a];
@@ -994,3 +1014,4 @@ GAME( 1992, coolpool, 0,        coolpool, coolpool, coolpool, ROT0, "Catalina",
 GAME( 1993, 9ballsht, 0,        9ballsht, 9ballsht, 9ballsht, ROT0, "E-Scape EnterMedia (Bundra license)", "9-Ball Shootout (set 1)", 0 )
 GAME( 1993, 9ballsh2, 9ballsht, 9ballsht, 9ballsht, 9ballsht, ROT0, "E-Scape EnterMedia (Bundra license)", "9-Ball Shootout (set 2)", 0 )
 GAME( 1993, 9ballsh3, 9ballsht, 9ballsht, 9ballsht, 9ballsht, ROT0, "E-Scape EnterMedia (Bundra license)", "9-Ball Shootout (set 3)", 0 )
+GAME( 1993, 9ballshc, 9ballsht, 9ballsht, 9ballsht, 9ballsht, ROT0, "E-Scape EnterMedia (Bundra license)", "9-Ball Shootout Championship", GAME_NOT_WORKING )
