@@ -117,7 +117,6 @@ Notes:
 */
 
 #include "driver.h"
-#include "deprecat.h"
 #include "cpu/se3208/se3208.h"
 #include "video/vrender0.h"
 #include "machine/ds1302.h"
@@ -133,43 +132,44 @@ static UINT32 *workram,*textureram,*frameram;
 static UINT32 *sysregs,*vidregs;
 static UINT32 Bank;
 static UINT8 FlipCount,IntHigh;
-static UINT32 Timer0ctrl,Timer1ctrl,Timer2ctrl,Timer3ctrl;
-static void *Timer0,*Timer1,*Timer2,*Timer3;
+static UINT32 Timerctrl[4];
+static emu_timer *Timer[4];
 static UINT32 FlashCmd,PIO;
-static UINT32 DMA0ctrl,DMA1ctrl;
+static UINT32 DMActrl[2];
 static UINT8 OldPort4;
 static UINT32 *ResetPatch;
 
-static void IntReq(int num)
+static void IntReq(running_machine *machine, int num)
 {
-	UINT32 IntEn=program_read_dword_32le(0x01800c08);
-	UINT32 IntPend=program_read_dword_32le(0x01800c0c);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	UINT32 IntEn=memory_read_dword(space, 0x01800c08);
+	UINT32 IntPend=memory_read_dword(space, 0x01800c0c);
 	if(IntEn&(1<<num))
 	{
 		IntPend|=(1<<num);
-		program_write_dword_32le(0x01800c0c,IntPend);
-		cpunum_set_input_line(Machine, 0,SE3208_INT,ASSERT_LINE);
+		memory_write_dword(space,0x01800c0c,IntPend);
+		cpu_set_input_line(machine->cpu[0],SE3208_INT,ASSERT_LINE);
 	}
 #ifdef IDLE_LOOP_SPEEDUP
 	FlipCntRead=0;
-	cpunum_resume(0,SUSPEND_REASON_SPIN);
+	cpu_resume(machine->cpu[0],SUSPEND_REASON_SPIN);
 #endif
 }
 
 static READ32_HANDLER(FlipCount_r)
 {
 #ifdef IDLE_LOOP_SPEEDUP
-	UINT32 IntPend=program_read_dword_32le(0x01800c0c);
+	UINT32 IntPend=memory_read_dword(space, 0x01800c0c);
 	FlipCntRead++;
 	if(FlipCntRead>=16 && !IntPend && FlipCount!=0)
-		cpunum_suspend(0,SUSPEND_REASON_SPIN,1);
+		cpu_suspend(space->machine->cpu[0],SUSPEND_REASON_SPIN,1);
 #endif
 	return ((UINT32) FlipCount)<<16;
 }
 
 static WRITE32_HANDLER(FlipCount_w)
 {
-	if((~mem_mask)&0x00ff0000)
+	if(mem_mask&0x00ff0000)
 	{
 		int fc=(data>>16)&0xff;
 		if(fc==1)
@@ -181,48 +181,48 @@ static WRITE32_HANDLER(FlipCount_w)
 
 static READ32_HANDLER(Input_r)
 {
-	if(offset==0)
-		return readinputport(0)|(readinputport(1)<<16);
-	else if(offset==1)
-		return readinputport(2)|(readinputport(3)<<16);
-	else if(offset==2)
+	if(offset == 0)
+		return input_port_read(space->machine, "P1_P2");
+	else if(offset == 1)
+		return input_port_read(space->machine, "P3_P4");
+	else if(offset == 2)
 	{
-		UINT8 Port4=readinputport(4);
-		if(!(Port4&0x10) && ((OldPort4^Port4)&0x10))	//coin buttons trigger IRQs
-			IntReq(12);
-		if(!(Port4&0x20) && ((OldPort4^Port4)&0x20))
-			IntReq(19);
-		OldPort4=Port4;
-		return /*dips*/readinputport(5)|(Port4<<16);
+		UINT8 Port4 = input_port_read(space->machine, "SYSTEM");
+		if(!(Port4 & 0x10) && ((OldPort4^Port4) & 0x10))	//coin buttons trigger IRQs
+			IntReq(space->machine, 12);
+		if(!(Port4 & 0x20) && ((OldPort4^Port4) & 0x20))
+			IntReq(space->machine, 19);
+		OldPort4 = Port4;
+		return /*dips*/input_port_read(space->machine, "DSW")|(Port4<<16);
 	}
 	return 0;
 }
 
 static WRITE32_HANDLER(IntAck_w)
 {
-	UINT32 IntPend=program_read_dword_32le(0x01800c0c);
-	if((~mem_mask)&0xff)
+	UINT32 IntPend=memory_read_dword(space, 0x01800c0c);
+	if(mem_mask&0xff)
 	{
 		IntPend&=~(1<<(data&0x1f));
-		program_write_dword_32le(0x01800c0c,IntPend);
+		memory_write_dword(space, 0x01800c0c,IntPend);
 		if(!IntPend)
-			cpunum_set_input_line(Machine, 0,SE3208_INT,CLEAR_LINE);
+			cpu_set_input_line(space->machine->cpu[0],SE3208_INT,CLEAR_LINE);
 	}
-	if((~mem_mask)&0xff00)
+	if(mem_mask&0xff00)
 		IntHigh=(data>>8)&7;
 }
 
-static int icallback(int line)
+static IRQ_CALLBACK(icallback)
 {
+	const address_space *space = cpu_get_address_space(device, ADDRESS_SPACE_PROGRAM);
+	UINT32 IntPend=memory_read_dword(space, 0x01800c0c);
 	int i;
-	UINT32 IntPend=program_read_dword_32le(0x01800c0c);
 
 	for(i=0;i<32;++i)
 	{
 		if(IntPend&(1<<i))
 		{
 			return (IntHigh<<5)|i;
-			break;
 		}
 	}
 	return 0;		//This should never happen
@@ -232,121 +232,75 @@ static WRITE32_HANDLER(Banksw_w)
 {
 	Bank=(data>>1)&7;
 	if(Bank<=2)
-		memory_set_bankptr(1,memory_region(REGION_USER1)+Bank*0x1000000);
+		memory_set_bankptr(space->machine, 1,memory_region(space->machine, "user1")+Bank*0x1000000);
 	else
-		memory_set_bankptr(1,memory_region(REGION_USER2));
+		memory_set_bankptr(space->machine, 1,memory_region(space->machine, "user2"));
 }
 
-static TIMER_CALLBACK( Timer0cb )
+static TIMER_CALLBACK( Timercb )
 {
-	if(!(Timer0ctrl&2))
-		Timer0ctrl&=~1;
-	IntReq(0);
+	int which = (int)(FPTR)ptr;
+	static const int num[] = { 0, 1, 9, 10 };
+
+	if(!(Timerctrl[which]&2))
+		Timerctrl[which]&=~1;
+	IntReq(machine, num[which]);
+}
+
+INLINE void Timer_w(const address_space *space, int which, UINT32 data, UINT32 mem_mask)
+{
+	if(((data^Timerctrl[which])&1) && (data&1))	//Timer activate
+	{
+		int PD=(data>>8)&0xff;
+		int TCV=memory_read_dword(space, 0x01801404+which*8);
+		attotime period = attotime_mul(ATTOTIME_IN_HZ(43000000), (PD + 1) * (TCV + 1));
+
+		if(Timerctrl[which]&2)
+			timer_adjust_periodic(Timer[which],period,0,period);
+		else
+			timer_adjust_oneshot(Timer[which],period,0);
+	}
+	COMBINE_DATA(&Timerctrl[which]);
 }
 
 static WRITE32_HANDLER(Timer0_w)
 {
-	if(((data^Timer0ctrl)&1) && (data&1))	//Timer activate
-	{
-		int PD=(data>>8)&0xff;
-		int TCV=program_read_dword_32le(0x01801404);
-		attotime period = attotime_mul(ATTOTIME_IN_HZ(43000000), (PD + 1) * (TCV + 1));
-
-		if(Timer0ctrl&2)
-			timer_adjust(Timer0,period,0,period);
-		else
-			timer_adjust(Timer0,period,0,attotime_zero);
-	}
-	COMBINE_DATA(&Timer0ctrl);
+	Timer_w(space, 0, data, mem_mask);
 }
 
 static READ32_HANDLER(Timer0_r)
 {
-	return Timer0ctrl;
-}
-
-static TIMER_CALLBACK( Timer1cb )
-{
-	if(!(Timer1ctrl&2))
-		Timer1ctrl&=~1;
-	IntReq(1);
+	return Timerctrl[0];
 }
 
 static WRITE32_HANDLER(Timer1_w)
 {
-	if(((data^Timer1ctrl)&1) && (data&1))	//Timer activate
-	{
-		int PD=(data>>8)&0xff;
-		int TCV=program_read_dword_32le(0x0180140C);
-		attotime period = attotime_mul(ATTOTIME_IN_HZ(43000000), (PD + 1) * (TCV + 1));
-
-		if(Timer1ctrl&2)
-			timer_adjust(Timer1,period,0,period);
-		else
-			timer_adjust(Timer1,period,0,attotime_zero);
-	}
-	COMBINE_DATA(&Timer1ctrl);
+	Timer_w(space, 1, data, mem_mask);
 }
 
 static READ32_HANDLER(Timer1_r)
 {
-	return Timer1ctrl;
-}
-
-static TIMER_CALLBACK( Timer2cb )
-{
-	if(!(Timer2ctrl&2))
-		Timer2ctrl&=~1;
-	IntReq(9);
+	return Timerctrl[1];
 }
 
 static WRITE32_HANDLER(Timer2_w)
 {
-	if(((data^Timer2ctrl)&1) && (data&1))	//Timer activate
-	{
-		int PD=(data>>8)&0xff;
-		int TCV=program_read_dword_32le(0x01801414);
-		attotime period = attotime_mul(ATTOTIME_IN_HZ(43000000), (PD + 1) * (TCV + 1));
-
-		if(Timer2ctrl&2)
-			timer_adjust(Timer2,period,0,period);
-		else
-			timer_adjust(Timer2,period,0,attotime_zero);
-	}
-	COMBINE_DATA(&Timer2ctrl);
+	Timer_w(space, 2, data, mem_mask);
 }
 
 static READ32_HANDLER(Timer2_r)
 {
-	return Timer2ctrl;
-}
-
-static TIMER_CALLBACK( Timer3cb )
-{
-	if(!(Timer3ctrl&2))
-		Timer3ctrl&=~1;
-	IntReq(10);
+	return Timerctrl[2];
 }
 
 static WRITE32_HANDLER(Timer3_w)
 {
-	if(((data^Timer3ctrl)&1) && (data&1))	//Timer activate
-	{
-		int PD=(data>>8)&0xff;
-		int TCV=program_read_dword_32le(0x0180141C);
-		attotime period = attotime_mul(ATTOTIME_IN_HZ(43000000), (PD + 1) * (TCV + 1));
-
-		if(Timer3ctrl&2)
-			timer_adjust(Timer3,period,0,period);
-		else
-			timer_adjust(Timer3,period,0,attotime_zero);
-	}
-	COMBINE_DATA(&Timer3ctrl);
+	Timer_w(space, 3, data, mem_mask);
 }
 
 static READ32_HANDLER(Timer3_r)
 {
-	return Timer3ctrl;
+	return Timerctrl[3];
 }
 
 static READ32_HANDLER(FlashCmd_r)
@@ -355,7 +309,7 @@ static READ32_HANDLER(FlashCmd_r)
 	{
 		if(Bank<=2)
 		{
-			UINT32 *ptr=(UINT32*)(memory_region(REGION_USER1)+Bank*0x1000000);
+			UINT32 *ptr=(UINT32*)(memory_region(space->machine, "user1")+Bank*0x1000000);
 			return ptr[0];
 		}
 		else
@@ -389,106 +343,75 @@ static WRITE32_HANDLER(PIO_w)
 
 	DS1302_RST(RST?1:0);
 	DS1302_DAT(DAT?1:0);
-	DS1302_CLK(CLK?1:0);
+	DS1302_CLK(space->machine, CLK?1:0);
 
 	if(DS1302_RD())
-		program_write_dword_32le(0x01802008,program_read_dword_32le(0x01802008)|0x10000000);
+		memory_write_dword(space,0x01802008,memory_read_dword(space,0x01802008)|0x10000000);
 	else
-		program_write_dword_32le(0x01802008,program_read_dword_32le(0x01802008)&(~0x10000000));
+		memory_write_dword(space,0x01802008,memory_read_dword(space,0x01802008)&(~0x10000000));
 
 	COMBINE_DATA(&PIO);
 }
 
+INLINE void DMA_w(const address_space *space, int which, UINT32 data, UINT32 mem_mask)
+{
+	if(((data^DMActrl[which])&(1<<10)) && (data&(1<<10)))	//DMAOn
+	{
+		UINT32 CTR=data;
+		UINT32 SRC=memory_read_dword(space,0x01800804+which*0x10);
+		UINT32 DST=memory_read_dword(space,0x01800808+which*0x10);
+		UINT32 CNT=memory_read_dword(space,0x0180080C+which*0x10);
+		int i;
+
+		if(CTR&0x2)	//32 bits
+		{
+			for(i=0;i<CNT;++i)
+			{
+				UINT32 v=memory_read_dword(space,SRC+i*4);
+				memory_write_dword(space,DST+i*4,v);
+			}
+		}
+		else if(CTR&0x1)	//16 bits
+		{
+			for(i=0;i<CNT;++i)
+			{
+				UINT16 v=memory_read_word(space,SRC+i*2);
+				memory_write_word(space,DST+i*2,v);
+			}
+		}
+		else	//8 bits
+		{
+			for(i=0;i<CNT;++i)
+			{
+				UINT8 v=memory_read_byte(space,SRC+i);
+				memory_write_byte(space,DST+i,v);
+			}
+		}
+		data&=~(1<<10);
+		memory_write_dword(space,0x0180080C+which*0x10,0);
+		IntReq(space->machine, 7+which);
+	}
+	COMBINE_DATA(&DMActrl[which]);
+}
+
 static READ32_HANDLER(DMA0_r)
 {
-	return DMA0ctrl;
+	return DMActrl[0];
 }
 
 static WRITE32_HANDLER(DMA0_w)
 {
-	if(((data^DMA0ctrl)&(1<<10)) && (data&(1<<10)))	//DMAOn
-	{
-		UINT32 CTR=data;
-		UINT32 SRC=program_read_dword_32le(0x01800804);
-		UINT32 DST=program_read_dword_32le(0x01800808);
-		UINT32 CNT=program_read_dword_32le(0x0180080C);
-		int i;
-
-		if(CTR&0x2)	//32 bits
-		{
-			for(i=0;i<CNT;++i)
-			{
-				UINT32 v=program_read_dword_32le(SRC+i*4);
-				program_write_dword_32le(DST+i*4,v);
-			}
-		}
-		else if(CTR&0x1)	//16 bits
-		{
-			for(i=0;i<CNT;++i)
-			{
-				UINT16 v=program_read_word_32le(SRC+i*2);
-				program_write_word_32le(DST+i*2,v);
-			}
-		}
-		else	//8 bits
-		{
-			for(i=0;i<CNT;++i)
-			{
-				UINT8 v=program_read_byte_32le(SRC+i);
-				program_write_byte_32le(DST+i,v);
-			}
-		}
-		data&=~(1<<10);
-		program_write_dword_32le(0x0180080C,0);
-		IntReq(7);
-	}
-	COMBINE_DATA(&DMA0ctrl);
+	DMA_w(space, 0, data, mem_mask);
 }
 
 static READ32_HANDLER(DMA1_r)
 {
-	return DMA1ctrl;
+	return DMActrl[1];
 }
 
 static WRITE32_HANDLER(DMA1_w)
 {
-	if(((data^DMA1ctrl)&(1<<10)) && (data&(1<<10)))	//DMAOn
-	{
-		UINT32 CTR=data;
-		UINT32 SRC=program_read_dword_32le(0x01800814);
-		UINT32 DST=program_read_dword_32le(0x01800818);
-		UINT32 CNT=program_read_dword_32le(0x0180081C);
-		int i;
-
-		if(CTR&0x2)	//32 bits
-		{
-			for(i=0;i<CNT;++i)
-			{
-				UINT32 v=program_read_dword_32le(SRC+i*4);
-				program_write_dword_32le(DST+i*4,v);
-			}
-		}
-		else if(CTR&0x1)	//16 bits
-		{
-			for(i=0;i<CNT;++i)
-			{
-				UINT16 v=program_read_word_32le(SRC+i*2);
-				program_write_word_32le(DST+i*2,v);
-			}
-		}
-		else	//8 bits
-		{
-			for(i=0;i<CNT;++i)
-			{
-				UINT8 v=program_read_byte_32le(SRC+i);
-				program_write_byte_32le(DST+i,v);
-			}
-		}
-		data&=~(1<<10);
-		program_write_dword_32le(0x0180081C,0);
-		IntReq(8);
-	}
-	COMBINE_DATA(&DMA1ctrl);
+	DMA_w(space, 1, data, mem_mask);
 }
 
 
@@ -517,10 +440,10 @@ static ADDRESS_MAP_START( crystal_mem, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x03000000, 0x0300ffff) AM_RAM AM_BASE(&vidregs)
 	AM_RANGE(0x03800000, 0x03ffffff) AM_RAM AM_BASE(&textureram)
 	AM_RANGE(0x04000000, 0x047fffff) AM_RAM AM_BASE(&frameram)
-	AM_RANGE(0x04800000, 0x04800fff) AM_READ(VR0_Snd_Read) AM_WRITE(VR0_Snd_Write)
+	AM_RANGE(0x04800000, 0x04800fff) AM_READ(vr0_snd_read) AM_WRITE(vr0_snd_write)
 
 	AM_RANGE(0x05000000, 0x05000003) AM_READ(FlashCmd_r) AM_WRITE(FlashCmd_w)
-	AM_RANGE(0x05000000, 0x05ffffff) AM_READ(MRA32_BANK1)
+	AM_RANGE(0x05000000, 0x05ffffff) AM_READ(SMH_BANK1)
 
 	AM_RANGE(0x44414F4C, 0x44414F7F) AM_RAM AM_BASE(&ResetPatch)
 
@@ -574,39 +497,41 @@ loop:
 #endif
 }
 
+static MACHINE_START(crystal)
+{
+	int i;
+
+	cpu_set_irq_callback(machine->cpu[0],icallback);
+	for (i=0; i<4; i++)
+		Timer[i] = timer_alloc(machine, Timercb, (void*)(FPTR)i);
+
+	PatchReset();
+}
+
 static MACHINE_RESET(crystal)
 {
+	int i;
+
 	memset(sysregs,0,0x10000);
 	memset(vidregs,0,0x10000);
 	FlipCount=0;
 	IntHigh=0;
-	cpunum_set_irq_callback(0,icallback);
+	cpu_set_irq_callback(machine->cpu[0],icallback);
 	Bank=0;
-	memory_set_bankptr(1,memory_region(REGION_USER1)+0);
+	memory_set_bankptr(machine, 1,memory_region(machine, "user1")+0);
 	FlashCmd=0xff;
 	OldPort4=0;
 
-	DMA0ctrl=0;
-	DMA1ctrl=0;
+	DMActrl[0]=0;
+	DMActrl[1]=0;
 
-	Timer0ctrl=0;
-	Timer1ctrl=0;
-	Timer2ctrl=0;
-	Timer3ctrl=0;
+	for (i=0; i<4; i++)
+	{
+		Timerctrl[i]=0;
+		timer_adjust_oneshot(Timer[i],attotime_never,0);
+	}
 
-	Timer0=timer_alloc(Timer0cb, NULL);
-	timer_adjust(Timer0,attotime_never,0,attotime_never);
-
-	Timer1=timer_alloc(Timer1cb, NULL);
-	timer_adjust(Timer1,attotime_never,0,attotime_never);
-
-	Timer2=timer_alloc(Timer2cb, NULL);
-	timer_adjust(Timer2,attotime_never,0,attotime_never);
-
-	Timer3=timer_alloc(Timer3cb, NULL);
-	timer_adjust(Timer3,attotime_never,0,attotime_never);
-
-	VR0_Snd_Set_Areas(textureram,frameram);
+	vr0_snd_set_areas(textureram,frameram);
 #ifdef IDLE_LOOP_SPEEDUP
 	FlipCntRead=0;
 #endif
@@ -618,48 +543,33 @@ static VIDEO_START(crystal)
 {
 }
 
-static void plot_pixel_rgb(mame_bitmap *bitmap, int x, int y , int color)
+static UINT16 GetVidReg(const address_space *space, UINT16 reg)
 {
-	//565 to 555
-	color=(color&0x1f)|((color>>1)&0x7fe0);
-	if (bitmap->bpp == 32)
-	{
-		UINT32 cb=(color&0x1f)<<3;
-		UINT32 cg=(color&0x3e0)>>2;
-		UINT32 cr=(color&0x7c00)>>7;
-		*BITMAP_ADDR32(bitmap, y, x) = cb | (cg<<8) | (cr<<16);
-	}
-	else
-	{
-		*BITMAP_ADDR16(bitmap, y, x) = color;
-	}
+	return memory_read_word(space,0x03000000+reg);
 }
 
-static UINT16 GetVidReg(UINT16 reg)
+static void SetVidReg(const address_space *space, UINT16 reg,UINT16 val)
 {
-	return program_read_word_32le(0x03000000+reg);
-}
-
-static void SetVidReg(UINT16 reg,UINT16 val)
-{
-	program_write_word_32le(0x03000000+reg,val);
+	memory_write_word(space,0x03000000+reg,val);
 }
 
 
 static VIDEO_UPDATE(crystal)
 {
+	const address_space *space = cpu_get_address_space(screen->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	int DoFlip;
 
 
 	UINT32 B0=0x0;
-	UINT32 B1=(GetVidReg(0x90)&0x8000)?0x400000:0x100000;
+	UINT32 B1=(GetVidReg(space,0x90)&0x8000)?0x400000:0x100000;
 	UINT16 *Front,*Back;
 	UINT16 *Visible,*DrawDest;
 	UINT16 *srcline;
-	int x,y;
+	int y;
 	UINT16 head,tail;
+	UINT32 width=video_screen_get_width(screen);
 
-	if(GetVidReg(0x8e)&1)
+	if(GetVidReg(space,0x8e)&1)
 	{
 		Front=(UINT16*) (frameram+B1/4);
 		Back=(UINT16*) (frameram+B0/4);
@@ -674,7 +584,7 @@ static VIDEO_UPDATE(crystal)
 	DrawDest=(UINT16 *) frameram;
 
 
-	if(GetVidReg(0x8c)&0x80)
+	if(GetVidReg(space,0x8c)&0x80)
 		DrawDest=Front;
 	else
 		DrawDest=Back;
@@ -684,11 +594,11 @@ static VIDEO_UPDATE(crystal)
 	srcline=(UINT16 *) DrawDest;
 
 	DoFlip=0;
-	head=GetVidReg(0x82);
-	tail=GetVidReg(0x80);
+	head=GetVidReg(space,0x82);
+	tail=GetVidReg(space,0x80);
 	while((head&0x7ff)!=(tail&0x7ff))
 	{
-		DoFlip=vrender0_ProcessPacket(0x03800000+head*64,DrawDest,(UINT8*)textureram);
+		DoFlip=vrender0_ProcessPacket(space,0x03800000+head*64,DrawDest,(UINT8*)textureram);
 		head++;
 		head&=0x7ff;
 		if(DoFlip)
@@ -696,25 +606,26 @@ static VIDEO_UPDATE(crystal)
 	}
 
 	if(DoFlip)
-		SetVidReg(0x8e,GetVidReg(0x8e)^1);
+		SetVidReg(space,0x8e,GetVidReg(space,0x8e)^1);
 
 	srcline=(UINT16 *) Visible;
 	for(y=0;y<240;y++)
-		for(x=0;x<320;x++)
-			plot_pixel_rgb(bitmap,x,y,srcline[y*512+x]);
+		memcpy(BITMAP_ADDR16(bitmap, y, 0), &srcline[y*512], width*2);
+
 	return 0;
 }
 
 static VIDEO_EOF(crystal)
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	UINT16 head,tail;
 	int DoFlip=0;
 
-	head=GetVidReg(0x82);
-	tail=GetVidReg(0x80);
+	head=GetVidReg(space,0x82);
+	tail=GetVidReg(space,0x80);
 	while((head&0x7ff)!=(tail&0x7ff))
 	{
-		UINT16 Packet0=program_read_word_32le(0x03800000+head*64);
+		UINT16 Packet0=memory_read_word(space,0x03800000+head*64);
 		if(Packet0&0x81)
 			DoFlip=1;
 		head++;
@@ -722,7 +633,7 @@ static VIDEO_EOF(crystal)
 		if(DoFlip)
 			break;
 	}
-	SetVidReg(0x82,head);
+	SetVidReg(space,0x82,head);
 	if(DoFlip)
 	{
 		if(FlipCount)
@@ -733,61 +644,63 @@ static VIDEO_EOF(crystal)
 
 static INTERRUPT_GEN(crystal_interrupt)
 {
-	IntReq(24);		//VRender0 VBlank
+	IntReq(device->machine, 24);		//VRender0 VBlank
 }
 
 static INPUT_PORTS_START(crystal)
-	PORT_START
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
-	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
-	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
-	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(1)
-	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(2)
+	PORT_START("P1_P2")
+	PORT_BIT( 0x00000001, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
+	PORT_BIT( 0x00000002, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT( 0x00000004, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
+	PORT_BIT( 0x00000008, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
+	PORT_BIT( 0x00000010, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
+	PORT_BIT( 0x00000020, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
+	PORT_BIT( 0x00000040, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(1)
+	PORT_BIT( 0x00000080, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(2)
+	PORT_BIT( 0x0000ff00, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(2)
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(2)
-	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(1)
-	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(2)
-	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(1)
-	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(2)
+	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
+	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(2)
+	PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
+	PORT_BIT( 0x00080000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(2)
+	PORT_BIT( 0x00100000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(1)
+	PORT_BIT( 0x00200000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(2)
+	PORT_BIT( 0x00400000, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(1)
+	PORT_BIT( 0x00800000, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(2)
+	PORT_BIT( 0xff000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(3)
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(4)
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(3)
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(4)
-	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(3)
-	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(4)
-	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(3)
-	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(4)
+	PORT_START("P3_P4")
+	PORT_BIT( 0x00000001, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(3)
+	PORT_BIT( 0x00000002, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(4)
+	PORT_BIT( 0x00000004, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(3)
+	PORT_BIT( 0x00000008, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(4)
+	PORT_BIT( 0x00000010, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(3)
+	PORT_BIT( 0x00000020, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(4)
+	PORT_BIT( 0x00000040, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(3)
+	PORT_BIT( 0x00000080, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(4)
+	PORT_BIT( 0x0000ff00, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(3)
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(4)
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(3)
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(4)
-	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(3)
-	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(4)
-	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(3)
-	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(4)
+	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(3)
+	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(4)
+	PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(3)
+	PORT_BIT( 0x00080000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(4)
+	PORT_BIT( 0x00100000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(3)
+	PORT_BIT( 0x00200000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(4)
+	PORT_BIT( 0x00400000, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(3)
+	PORT_BIT( 0x00800000, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(4)
+	PORT_BIT( 0xff000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
-	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_START2 )
-	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_START3 )
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_START4 )
-	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME(DEF_STR( Test )) PORT_CODE(KEYCODE_F2)
+	PORT_START("SYSTEM")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_START3 )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START4 )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_SERVICE1 )
+	PORT_SERVICE_NO_TOGGLE( 0x80, IP_ACTIVE_LOW )
 
-	PORT_START
+	PORT_START("DSW")
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Pause ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -812,82 +725,117 @@ static INPUT_PORTS_START(crystal)
 	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Test ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-
 INPUT_PORTS_END
 
-static const struct VR0Interface vr0_interface =
+static const vr0_interface vr0_config =
 {
 	0x04800000
 };
 
 
 static MACHINE_DRIVER_START( crystal )
-	MDRV_CPU_ADD(SE3208, 43000000)
+	MDRV_CPU_ADD("main", SE3208, 43000000)
 	MDRV_CPU_PROGRAM_MAP(crystal_mem,0)
- 	MDRV_CPU_VBLANK_INT(crystal_interrupt,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+ 	MDRV_CPU_VBLANK_INT("main", crystal_interrupt)
 
+	MDRV_MACHINE_START(crystal)
 	MDRV_MACHINE_RESET(crystal)
 
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB15)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(320, 240)
 	MDRV_SCREEN_VISIBLE_AREA(0, 319, 0, 239)
-	MDRV_PALETTE_LENGTH(8192)
 
 	MDRV_VIDEO_START(crystal)
 	MDRV_VIDEO_UPDATE(crystal)
 	MDRV_VIDEO_EOF(crystal)
 
+	MDRV_PALETTE_INIT(RRRRR_GGGGGG_BBBBB)
+	MDRV_PALETTE_LENGTH(65536)
+
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(VRENDER0, 0)
-	MDRV_SOUND_CONFIG(vr0_interface)
+	MDRV_SOUND_ADD("vrender", VRENDER0, 0)
+	MDRV_SOUND_CONFIG(vr0_config)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
+/*
+    Top blade screen is 32 pixels wider
+*/
+static MACHINE_DRIVER_START( topbladv )
+	MDRV_IMPORT_FROM(crystal)
+
+	MDRV_SCREEN_MODIFY("main")
+	MDRV_SCREEN_SIZE(320+32, 240)
+	MDRV_SCREEN_VISIBLE_AREA(0, 319+32, 0, 239)
+
+MACHINE_DRIVER_END
+
 ROM_START( crysbios )
-	ROM_REGION( 0x20000, REGION_CPU1, 0 ) // bios
+	ROM_REGION( 0x20000, "main", 0 ) // bios
 	ROM_LOAD("mx27l1000.u14",  0x000000, 0x020000, CRC(BEFF39A9) SHA1(b6f6dda58d9c82273f9422c1bd623411e58982cb) )
 
-	ROM_REGION32_LE( 0x3000000, REGION_USER1, ROMREGION_ERASEFF ) // Flash
+	ROM_REGION32_LE( 0x3000000, "user1", ROMREGION_ERASEFF ) // Flash
 
-	ROM_REGION( 0x10000, REGION_USER2,	ROMREGION_ERASEFF )	//Unmapped flash
+	ROM_REGION( 0x10000, "user2",	ROMREGION_ERASEFF )	//Unmapped flash
 ROM_END
 
 ROM_START( crysking )
-	ROM_REGION( 0x20000, REGION_CPU1, 0 ) // bios
+	ROM_REGION( 0x20000, "main", 0 ) // bios
 	ROM_LOAD("mx27l1000.u14",  0x000000, 0x020000, CRC(BEFF39A9) SHA1(b6f6dda58d9c82273f9422c1bd623411e58982cb))
 
-	ROM_REGION32_LE( 0x3000000, REGION_USER1, 0 ) // Flash
+	ROM_REGION32_LE( 0x3000000, "user1", 0 ) // Flash
 	ROM_LOAD("bcsv0004f01.u1",  0x0000000, 0x1000000, CRC(8FEFF120) SHA1(2ea42fa893bff845b5b855e2556789f8354e9066) )
 	ROM_LOAD("bcsv0004f02.u2",  0x1000000, 0x1000000, CRC(0E799845) SHA1(419674ce043cb1efb18303f4cb7fdbbae642ee39) )
 	ROM_LOAD("bcsv0004f03.u3",  0x2000000, 0x1000000, CRC(659E2D17) SHA1(342c98f3f695ef4dea8b533612451c4d2fb58809) )
 
-	ROM_REGION( 0x10000, REGION_USER2,	ROMREGION_ERASEFF )	//Unmapped flash
+	ROM_REGION( 0x10000, "user2",	ROMREGION_ERASEFF )	//Unmapped flash
 ROM_END
 
 ROM_START( evosocc )
-	ROM_REGION( 0x20000, REGION_CPU1, 0 ) // bios
+	ROM_REGION( 0x20000, "main", 0 ) // bios
 	ROM_LOAD("mx27l1000.u14",  0x000000, 0x020000, CRC(BEFF39A9) SHA1(b6f6dda58d9c82273f9422c1bd623411e58982cb))
 
-	ROM_REGION32_LE( 0x3000000, REGION_USER1, 0 ) // Flash
+	ROM_REGION32_LE( 0x3000000, "user1", 0 ) // Flash
 	ROM_LOAD("bcsv0001u01",  0x0000000, 0x1000000, CRC(2581A0EA) SHA1(ee483ac60a3ed00a21cb515974cec4af19916a7d) )
 	ROM_LOAD("bcsv0001u02",  0x1000000, 0x1000000, CRC(47EF1794) SHA1(f573706c17d1342b9b7aed9b40b8b648f0bf58db) )
 	ROM_LOAD("bcsv0001u03",  0x2000000, 0x1000000, CRC(F396A2EC) SHA1(f305eb10856fb5d4c229a6b09d6a2fb21b24ce66) )
 
-	ROM_REGION( 0x10000, REGION_USER2,	ROMREGION_ERASEFF )	//Unmapped flash
+	ROM_REGION( 0x10000, "user2",	ROMREGION_ERASEFF )	//Unmapped flash
+ROM_END
+
+ROM_START( topbladv )
+	ROM_REGION( 0x20000, "main", 0 ) // bios
+	ROM_LOAD("mx27l1000.u14",  0x000000, 0x020000, CRC(BEFF39A9) SHA1(b6f6dda58d9c82273f9422c1bd623411e58982cb))
+
+	ROM_REGION32_LE( 0x1000000, "user1", 0 ) // Flash
+	ROM_LOAD("flash.u1",  0x0000000, 0x1000000, CRC(bd23f640) SHA1(1d22aa2c828642bb7c1dfea4e13f777f95acc701) )
+
+	ROM_REGION( 0x10000, "user2",	ROMREGION_ERASEFF )	//Unmapped flash
+ROM_END
+
+
+ROM_START( officeye )
+	ROM_REGION( 0x20000, "main", 0 ) // bios (not the standard one)
+	ROM_LOAD("bios.u14",  0x000000, 0x020000, CRC(ffc57e90) SHA1(6b6a17fd4798dea9c7b880f3063be8494e7db302) )
+
+	ROM_REGION32_LE( 0x2000000, "user1", 0 ) // Flash
+	ROM_LOAD("flash.u1",  0x0000000, 0x1000000, CRC(d3f3eec4) SHA1(ea728415bd4906964b7d37f4379a8a3bd42a1c2d) )
+	ROM_LOAD("flash.u2",  0x1000000, 0x1000000, CRC(e4f85d0a) SHA1(2ddfa6b3a30e69754aa9d96434ff3d37784bfa57) )
+
+	ROM_REGION( 0x10000, "user2",	ROMREGION_ERASEFF )	//Unmapped flash
 ROM_END
 
 
 static DRIVER_INIT(crysking)
 {
-	UINT16 *Rom=(UINT16*) memory_region(REGION_USER1);
+	UINT16 *Rom=(UINT16*) memory_region(machine, "user1");
 
 	//patch the data feed by the protection
 
@@ -906,7 +854,7 @@ static DRIVER_INIT(crysking)
 
 static DRIVER_INIT(evosocc)
 {
-	UINT16 *Rom=(UINT16*) memory_region(REGION_USER1);
+	UINT16 *Rom=(UINT16*) memory_region(machine, "user1");
 	Rom+=0x1000000*2/2;
 
 	Rom[WORD_XOR_LE(0x97388E/2)]=0x90FC;	//PUSH R2..R7
@@ -922,6 +870,48 @@ static DRIVER_INIT(evosocc)
 	Rom[WORD_XOR_LE(0x974ED2/2)]=0x9001;	//PUSH R0
 }
 
-GAME( 2001, crysbios,		   0,  crystal, crystal,        0, ROT0, "Brezzasoft", "Crystal System BIOS", GAME_IS_BIOS_ROOT )
-GAME( 2001, crysking,	crysbios,  crystal, crystal, crysking, ROT0, "Brezzasoft", "The Crystal of Kings", 0 )
-GAME( 2001, evosocc,   crysbios,  crystal, crystal,  evosocc, ROT0, "Evoga", "Evolution Soccer", 0 )
+static DRIVER_INIT(topbladv)
+{
+	UINT16 *Rom=(UINT16*) memory_region(machine, "user1");
+
+	Rom[WORD_XOR_LE(0x12d7a/2)]=0x90FC;	//PUSH R7-R6-R5-R4-R3-R2
+	Rom[WORD_XOR_LE(0x12d7c/2)]=0x9001;	//PUSH R0
+
+	Rom[WORD_XOR_LE(0x2fe18/2)]=0x9001;	//PUSH R0
+	Rom[WORD_XOR_LE(0x2fe1a/2)]=0x9200;	//PUSH SR
+
+	Rom[WORD_XOR_LE(0x18880/2)]=0x9001;	//PUSH R0
+	Rom[WORD_XOR_LE(0x18882/2)]=0x9200;	//PUSH SR
+
+	Rom[WORD_XOR_LE(0xDACE/2)]=0x901C;	//PUSH R4-R3-R2
+	Rom[WORD_XOR_LE(0xDAD0/2)]=0x9001;	//PUSH R0
+
+}
+
+static DRIVER_INIT(officeye)
+{
+	UINT16 *Rom=(UINT16*) memory_region(machine, "user1");
+
+	Rom[WORD_XOR_LE(0x9c9e/2)]=0x901C;	//PUSH R4-R3-R2
+	Rom[WORD_XOR_LE(0x9ca0/2)]=0x9001;	//PUSH R0
+
+	Rom[WORD_XOR_LE(0x9EE4/2)]=0x907C;	//PUSH R6-R5-R4-R3-R2
+	Rom[WORD_XOR_LE(0x9EE6/2)]=0x9001;	//PUSH R0
+
+	Rom[WORD_XOR_LE(0x4B2E0/2)]=0x9004;	//PUSH R2
+	Rom[WORD_XOR_LE(0x4B2E2/2)]=0x9001;	//PUSH R0
+
+/*
+    Rom[WORD_XOR_LE(0x18880/2)]=0x9001; //PUSH R0
+    Rom[WORD_XOR_LE(0x18882/2)]=0x9200; //PUSH SR
+ */
+}
+
+
+
+GAME( 2001, crysbios,        0, crystal, crystal,        0, ROT0, "Brezzasoft", "Crystal System BIOS", GAME_IS_BIOS_ROOT )
+GAME( 2001, crysking, crysbios, crystal, crystal, crysking, ROT0, "Brezzasoft", "The Crystal of Kings", 0 )
+GAME( 2001, evosocc,  crysbios, crystal, crystal,  evosocc, ROT0, "Evoga", "Evolution Soccer", 0 )
+GAME( 2003, topbladv, crysbios, topbladv,crystal, topbladv, ROT0, "SonoKong / Expotato", "Top Blade V", GAME_NOT_WORKING ) // protection
+GAME( 2001, officeye,        0, crystal, crystal, officeye, ROT0, "Danbi", "Office Yeo In Cheon Ha (version 1.2)", GAME_NOT_WORKING ) // protection
+
