@@ -84,6 +84,7 @@ Stephh's notes (based on the game Z80 code and some tests) :
 */
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
 #include "deprecat.h"
 #include "audio/seibu.h"
 
@@ -93,9 +94,9 @@ static int coin_stat=0;
 
 static UINT8 *mainram;
 
-static void ar_coin_hack(void)
+static void ar_coin_hack(running_machine *machine)
 {
-	if(input_port_5_r(0)&1)
+	if(input_port_read(machine, "COIN") & 1)
 	{
 		if(coin_stat==0)
 		{
@@ -139,13 +140,13 @@ static WRITE8_HANDLER(cshooter_txram_w)
 
 static VIDEO_START(cshooter)
 {
-	cshooter_txtilemap = tilemap_create(get_cstx_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,32, 32);
+	cshooter_txtilemap = tilemap_create(machine, get_cstx_tile_info,tilemap_scan_rows, 8,8,32, 32);
 	tilemap_set_transparent_pen(cshooter_txtilemap, 3);
 }
 
 static VIDEO_UPDATE(cshooter)
 {
-	fillbitmap(bitmap, 0/*get_black_pen(machine)*/, &machine->screen[0].visarea);
+	bitmap_fill(bitmap, cliprect, 0/*get_black_pen(screen->screen->machine)*/);
 	tilemap_mark_all_tiles_dirty(cshooter_txtilemap);
 
 	//sprites
@@ -157,28 +158,28 @@ static VIDEO_UPDATE(cshooter)
 			{
 				int tile=0x30+((spriteram[i]>>2)&0x1f);
 
-				drawgfx(bitmap,machine->gfx[0],
+				drawgfx(bitmap,screen->machine->gfx[0],
 							tile,
 							spriteram[i+1],
 							0, 0,
 							spriteram[i+3],spriteram[i+2],
 							cliprect,TRANSPARENCY_PEN,3);
 
-				drawgfx(bitmap,machine->gfx[0],
+				drawgfx(bitmap,screen->machine->gfx[0],
 							tile,
 							spriteram[i+1],
 							0, 0,
 							spriteram[i+3]+8,spriteram[i+2],
 							cliprect,TRANSPARENCY_PEN,3);
 
-				drawgfx(bitmap,machine->gfx[0],
+				drawgfx(bitmap,screen->machine->gfx[0],
 							tile,
 							spriteram[i+1],
 							0, 0,
 							spriteram[i+3]+8,spriteram[i+2]+8,
 							cliprect,TRANSPARENCY_PEN,3);
 
-				drawgfx(bitmap,machine->gfx[0],
+				drawgfx(bitmap,screen->machine->gfx[0],
 							tile,
 							spriteram[i+1],
 							0, 0,
@@ -198,13 +199,13 @@ static VIDEO_UPDATE(cshooter)
 
 static INTERRUPT_GEN( cshooter_interrupt )
 {
-	if(cpu_getiloops())
-		cpunum_set_input_line_and_vector(machine, 0, 0, HOLD_LINE, 0x08);
+	if(cpu_getiloops(device))
+		cpu_set_input_line_and_vector(device, 0, HOLD_LINE, 0x08);
 	else
-      cpunum_set_input_line_and_vector(machine, 0, 0, HOLD_LINE, 0x10);
+      cpu_set_input_line_and_vector(device, 0, HOLD_LINE, 0x10);
 
 	if(mainram!=NULL)
-		ar_coin_hack();
+		ar_coin_hack(device->machine);
 
 }
 
@@ -221,8 +222,7 @@ static READ8_HANDLER ( cshooter_coin_r )
 	/* Even reads must return 0xff - Odd reads must return the contents of input port 5.
        Code at 0x5061 is executed once during P.O.S.T. where there is one read.
        Code at 0x50b4 is then executed each frame (not sure) where there are 2 reads. */
-
-	return ( (cshooter_counter++ & 1) ? 0xff : input_port_5_r(0) );
+	return ( (cshooter_counter++ & 1) ? 0xff : input_port_read(space->machine, "COIN") );
 }
 
 static WRITE8_HANDLER ( cshooter_c500_w )
@@ -235,7 +235,7 @@ static WRITE8_HANDLER ( cshooter_c700_w )
 
 static WRITE8_HANDLER ( bank_w )
 {
-	memory_set_bankptr(1,&memory_region(REGION_USER1)[0x4000*((data>>4)&3)]);
+	memory_set_bankptr(space->machine, 1,&memory_region(space->machine, "user1")[0x4000*((data>>4)&3)]);
 }
 
 
@@ -243,14 +243,14 @@ static WRITE8_HANDLER(pal_w)
 {
 	paletteram[offset]=data;
 	offset&=0xff;
-	palette_set_color_rgb(Machine, offset, pal4bit(paletteram[offset] >> 4), pal4bit(paletteram[offset]), pal4bit(paletteram[offset+0x100]));
+	palette_set_color_rgb(space->machine, offset, pal4bit(paletteram[offset] >> 4), pal4bit(paletteram[offset]), pal4bit(paletteram[offset+0x100]));
 }
 
 static WRITE8_HANDLER(pal2_w)
 {
 	paletteram[offset]=data;
 	offset&=0x1ff;
-	palette_set_color_rgb(Machine, offset, pal4bit(paletteram[offset] >> 4), pal4bit(paletteram[offset]), pal4bit(paletteram[offset+0x200]));
+	palette_set_color_rgb(space->machine, offset, pal4bit(paletteram[offset] >> 4), pal4bit(paletteram[offset]), pal4bit(paletteram[offset+0x200]));
 }
 
 static READ8_HANDLER(pal_r)
@@ -259,44 +259,44 @@ static READ8_HANDLER(pal_r)
 }
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0xafff) AM_READ(MRA8_BANK1)
-	AM_RANGE(0xb000, 0xb0ff) AM_READ(MRA8_RAM)			// sound related ?
+	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x8000, 0xafff) AM_READ(SMH_BANK1)
+	AM_RANGE(0xb000, 0xb0ff) AM_READ(SMH_RAM)			// sound related ?
 	AM_RANGE(0xc000, 0xc1ff) AM_WRITE(pal_w) AM_READ(pal_r) AM_BASE(&paletteram)
-	AM_RANGE(0xc200, 0xc200) AM_READ(input_port_0_r)
-	AM_RANGE(0xc201, 0xc201) AM_READ(input_port_1_r)
-	AM_RANGE(0xc202, 0xc202) AM_READ(input_port_2_r)
-	AM_RANGE(0xc203, 0xc203) AM_READ(input_port_3_r)
-	AM_RANGE(0xc204, 0xc204) AM_READ(input_port_4_r)
+	AM_RANGE(0xc200, 0xc200) AM_READ_PORT("IN0")
+	AM_RANGE(0xc201, 0xc201) AM_READ_PORT("IN1")
+	AM_RANGE(0xc202, 0xc202) AM_READ_PORT("IN2")
+	AM_RANGE(0xc203, 0xc203) AM_READ_PORT("DSW2")
+	AM_RANGE(0xc204, 0xc204) AM_READ_PORT("DSW1")
 	AM_RANGE(0xc205, 0xc205) AM_READ(cshooter_coin_r)	// hack until I understand
-	AM_RANGE(0xd000, 0xd7ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xd800, 0xdfff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xe000, 0xffff) AM_READ(MRA8_RAM)
+	AM_RANGE(0xd000, 0xd7ff) AM_READ(SMH_RAM)
+	AM_RANGE(0xd800, 0xdfff) AM_READ(SMH_RAM)
+	AM_RANGE(0xe000, 0xffff) AM_READ(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x8000, 0xafff) AM_WRITE(MWA8_RAM)			// to be confirmed
+	AM_RANGE(0x0000, 0x7fff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x8000, 0xafff) AM_WRITE(SMH_RAM)			// to be confirmed
 	AM_RANGE(0xc500, 0xc500) AM_WRITE(cshooter_c500_w)
-	AM_RANGE(0xc600, 0xc600) AM_WRITE(MWA8_NOP)			// see notes
+	AM_RANGE(0xc600, 0xc600) AM_WRITE(SMH_NOP)			// see notes
 	AM_RANGE(0xc700, 0xc700) AM_WRITE(cshooter_c700_w)
-	AM_RANGE(0xc801, 0xc801) AM_WRITE(MWA8_NOP)			// see notes
+	AM_RANGE(0xc801, 0xc801) AM_WRITE(SMH_NOP)			// see notes
 	AM_RANGE(0xd000, 0xd7ff) AM_WRITE(cshooter_txram_w) AM_BASE(&cshooter_txram)
-	AM_RANGE(0xd800, 0xdfff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xe000, 0xffff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0xd800, 0xdfff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0xe000, 0xffff) AM_WRITE(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( arreadmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(MRA8_BANK1)
+	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_BANK1)
 	AM_RANGE(0xb000, 0xb0ff) AM_RAM			// sound related ?
-	AM_RANGE(0xb100, 0xb1ff) AM_RAM//READ(MRA8_BANK1)           // sound related ?
-	AM_RANGE(0xc000, 0xc000) AM_READ(input_port_0_r)
-	AM_RANGE(0xc001, 0xc001) AM_READ(input_port_1_r)
-	AM_RANGE(0xc002, 0xc002) AM_READ(input_port_2_r)
-	AM_RANGE(0xc003, 0xc003) AM_READ(input_port_3_r)
-	AM_RANGE(0xc004, 0xc004) AM_READ(input_port_4_r)
-	AM_RANGE(0xd000, 0xd7ff) AM_READ(MRA8_RAM)
+	AM_RANGE(0xb100, 0xb1ff) AM_RAM//READ(SMH_BANK1)           // sound related ?
+	AM_RANGE(0xc000, 0xc000) AM_READ_PORT("IN0")
+	AM_RANGE(0xc001, 0xc001) AM_READ_PORT("IN1")
+	AM_RANGE(0xc002, 0xc002) AM_READ_PORT("IN2")
+	AM_RANGE(0xc003, 0xc003) AM_READ_PORT("DSW2")
+	AM_RANGE(0xc004, 0xc004) AM_READ_PORT("DSW1")
+	AM_RANGE(0xd000, 0xd7ff) AM_READ(SMH_RAM)
 	AM_RANGE(0xd800, 0xdbff) AM_WRITE(pal2_w) AM_READ(pal_r) AM_BASE(&paletteram)
 	AM_RANGE(0xdc11, 0xdc11) AM_WRITE(bank_w)
 	AM_RANGE(0xdc00, 0xddff) AM_RAM
@@ -306,41 +306,29 @@ static ADDRESS_MAP_START( arreadmem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( arwritemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
-
-
+	AM_RANGE(0x0000, 0x7fff) AM_WRITE(SMH_ROM)
 	AM_RANGE(0xc500, 0xc500) AM_WRITE(cshooter_c500_w)
-	AM_RANGE(0xc600, 0xc600) AM_WRITE(MWA8_NOP)			// see notes
+	AM_RANGE(0xc600, 0xc600) AM_WRITE(SMH_NOP)			// see notes
 	AM_RANGE(0xc700, 0xc700) AM_WRITE(cshooter_c700_w)
-	AM_RANGE(0xc801, 0xc801) AM_WRITE(MWA8_NOP)			// see notes
+	AM_RANGE(0xc801, 0xc801) AM_WRITE(SMH_NOP)			// see notes
 	AM_RANGE(0xd000, 0xd7ff) AM_WRITE(cshooter_txram_w) AM_BASE(&cshooter_txram)
-
-ADDRESS_MAP_END
-
-
-static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
 ADDRESS_MAP_END
 
 
 /* Sound CPU */
 
 static ADDRESS_MAP_START( s_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xf800, 0xffff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0000, 0x1fff) AM_READ(SMH_ROM)
+	AM_RANGE(0xf800, 0xffff) AM_READ(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( s_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xc000, 0xc000) AM_WRITE(MWA8_NOP) // YM2203_control_port_0_w ?
-	AM_RANGE(0xc001, 0xc001) AM_WRITE(MWA8_NOP) // YM2203_write_port_0_w
-	AM_RANGE(0xc800, 0xc800) AM_WRITE(MWA8_NOP) // YM2203_control_port_1_w ?
-	AM_RANGE(0xc801, 0xc801) AM_WRITE(MWA8_NOP) // YM2203_write_port_1_w
-	AM_RANGE(0xf800, 0xffff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x0000, 0x1fff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0xc000, 0xc000) AM_WRITE(SMH_NOP) // ym2203_control_port_0_w ?
+	AM_RANGE(0xc001, 0xc001) AM_WRITE(SMH_NOP) // ym2203_write_port_0_w
+	AM_RANGE(0xc800, 0xc800) AM_WRITE(SMH_NOP) // ym2203_control_port_1_w ?
+	AM_RANGE(0xc801, 0xc801) AM_WRITE(SMH_NOP) // ym2203_write_port_1_w
+	AM_RANGE(0xf800, 0xffff) AM_WRITE(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( s2_readmem, ADDRESS_SPACE_PROGRAM, 8 )
@@ -349,29 +337,17 @@ static ADDRESS_MAP_START( s2_readmem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( s2_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x4000, 0x4000) AM_WRITE(SMH_NOP) // ym2203_control_port_0_w ?
+	AM_RANGE(0x4001, 0x4001) AM_WRITE(SMH_NOP) // ym2203_write_port_0_w
 
-	AM_RANGE(0x4000, 0x4000) AM_WRITE(MWA8_NOP) // YM2203_control_port_0_w ?
-	AM_RANGE(0x4001, 0x4001) AM_WRITE(MWA8_NOP) // YM2203_write_port_0_w
-
-	AM_RANGE(0x4008, 0x4008) AM_WRITE(MWA8_NOP) // YM2203_control_port_0_w ?
-	AM_RANGE(0x4009, 0x4009) AM_WRITE(MWA8_NOP) // YM2203_write_port_0_w
-
-
+	AM_RANGE(0x4008, 0x4008) AM_WRITE(SMH_NOP) // ym2203_control_port_0_w ?
+	AM_RANGE(0x4009, 0x4009) AM_WRITE(SMH_NOP) // ym2203_write_port_0_w
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( s_readport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( s_writeport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-ADDRESS_MAP_END
-
-
 
 
 static INPUT_PORTS_START( cshooter )
-	PORT_START	/* IN0  (0xc200) */
+	PORT_START("IN0")	/* IN0  (0xc200) */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
@@ -381,7 +357,7 @@ static INPUT_PORTS_START( cshooter )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	/* IN1  (0xc201) */
+	PORT_START("IN1")	/* IN1  (0xc201) */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
@@ -391,7 +367,7 @@ static INPUT_PORTS_START( cshooter )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	/* START    (0xc202) */
+	PORT_START("IN2")	/* START    (0xc202) */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -401,7 +377,7 @@ static INPUT_PORTS_START( cshooter )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	/* DSW2 (0xc203) */
+	PORT_START("DSW2")	/* DSW2 (0xc203) */
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( Easy ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( Medium ) )
@@ -420,7 +396,7 @@ static INPUT_PORTS_START( cshooter )
 	PORT_DIPUNUSED( 0x40, IP_ACTIVE_LOW )
 	PORT_DIPUNUSED( 0x80, IP_ACTIVE_LOW )
 
-	PORT_START	/* DSW1 (0xc204) */
+	PORT_START("DSW1")	/* DSW1 (0xc204) */
 	PORT_DIPNAME( 0x01, 0x01, "Coin Slots" )
 	PORT_DIPSETTING(    0x01, "1" )
 	PORT_DIPSETTING(    0x00, "2" )
@@ -440,7 +416,7 @@ static INPUT_PORTS_START( cshooter )
 	PORT_DIPUNUSED( 0x40, IP_ACTIVE_LOW )
 	PORT_DIPUNUSED( 0x80, IP_ACTIVE_LOW )
 
-	PORT_START	/* COIN (0xc205) */
+	PORT_START("COIN")	/* COIN (0xc205) */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(1)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_IMPULSE(1)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -465,30 +441,28 @@ static const gfx_layout cshooter_charlayout =
 
 
 static GFXDECODE_START( cshooter )
-	GFXDECODE_ENTRY( REGION_GFX1, 0,     cshooter_charlayout,   0, 64  )
-	GFXDECODE_ENTRY( REGION_GFX1, 128/8, cshooter_charlayout,   0, 64  )
+	GFXDECODE_ENTRY( "gfx1", 0,     cshooter_charlayout,   0, 64  )
+	GFXDECODE_ENTRY( "gfx1", 128/8, cshooter_charlayout,   0, 64  )
 GFXDECODE_END
 
 static MACHINE_DRIVER_START( cshooter )
-	MDRV_CPU_ADD(Z80,6000000)		 /* ? MHz */
+	MDRV_CPU_ADD("main", Z80,XTAL_12MHz/2)		 /* verified on pcb */
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_IO_MAP(readport,writeport)
-	MDRV_CPU_VBLANK_INT(cshooter_interrupt,2)
+	MDRV_CPU_VBLANK_INT_HACK(cshooter_interrupt,2)
 
-	MDRV_CPU_ADD(Z80,6000000)		 /* ? MHz */
+	MDRV_CPU_ADD("audio", Z80,XTAL_14_31818MHz/4)		 /* verified on pcb */
 	MDRV_CPU_PROGRAM_MAP(s_readmem,s_writemem)
-	MDRV_CPU_IO_MAP(s_readport,s_writeport)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
 
 	MDRV_MACHINE_RESET(cshooter)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 256)
 	MDRV_SCREEN_VISIBLE_AREA(0, 256-1, 16, 256-1-16)
+
 	MDRV_GFXDECODE(cshooter)
 	MDRV_PALETTE_LENGTH(0x1000)
 
@@ -496,29 +470,28 @@ static MACHINE_DRIVER_START( cshooter )
 	MDRV_VIDEO_UPDATE(cshooter)
 
 	/* sound hardware */
+	/* YM2151 and ym3931 seibu custom cpu running at XTAL_14_31818MHz/4 */
+
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( airraid )
-	MDRV_CPU_ADD(Z80,6000000)		 /* ? MHz */
+	MDRV_CPU_ADD("main", Z80,XTAL_12MHz/2)		 /* verified on pcb */
 	MDRV_CPU_PROGRAM_MAP(arreadmem,arwritemem)
-	MDRV_CPU_IO_MAP(readport,writeport)
-	MDRV_CPU_VBLANK_INT(cshooter_interrupt,2)
+	MDRV_CPU_VBLANK_INT_HACK(cshooter_interrupt,2)
 
-	MDRV_CPU_ADD(Z80,6000000)		 /* ? MHz */
+	MDRV_CPU_ADD("audio", Z80,XTAL_14_31818MHz/4)		 /* verified on pcb */
 	MDRV_CPU_PROGRAM_MAP(s2_readmem,s2_writemem)
-	MDRV_CPU_IO_MAP(s_readport,s_writeport)
-
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
 
 	MDRV_MACHINE_RESET(cshooter)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 256)
 	MDRV_SCREEN_VISIBLE_AREA(0, 256-1, 16, 256-1-16)
+
 	MDRV_GFXDECODE(cshooter)
 	MDRV_PALETTE_LENGTH(0x1000)
 
@@ -526,6 +499,7 @@ static MACHINE_DRIVER_START( airraid )
 	MDRV_VIDEO_UPDATE(cshooter)
 
 	/* sound hardware */
+	/* YM2151 and ym3931 seibu custom cpu running at XTAL_14_31818MHz/4 */
 MACHINE_DRIVER_END
 
 
@@ -584,25 +558,25 @@ data in the custom SIPs. I am not sure though.
 
 
 ROM_START( cshooter )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )	// Main CPU?
+	ROM_REGION( 0x10000, "main", 0 )	// Main CPU?
 	ROM_LOAD( "r1",  0x00000, 0x08000, CRC(fbe8c518) SHA1(bff8319f4892e6d06f1c7a679f67dc8407279cfa) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	// Sub/Sound CPU?
+	ROM_REGION( 0x10000, "audio", 0 )	// Sub/Sound CPU?
 	ROM_LOAD( "r4",  0x00000, 0x08000, CRC(84fed017) SHA1(9a564c9379eb48569cfba48562889277991864d8) )
 
-	ROM_REGION( 0x0800, REGION_CPU3, 0 )	/* 2k for the microcontroller */
+	ROM_REGION( 0x0800, "cpu2", 0 )	/* 2k for the microcontroller */
 	ROM_LOAD( "68705.bin",    0x0000, 0x0800, NO_DUMP )
 
-	ROM_REGION( 0x02000, REGION_GFX1, 0 )	// TX Layer
+	ROM_REGION( 0x02000, "gfx1", 0 )	// TX Layer
 	ROM_LOAD( "r3",  0x00000, 0x02000, CRC(67b50a47) SHA1(b1f4aefc9437edbeefba5371149cc08c0b55c741) )	// only 1 byte difference with 3.f11, bad dump?
 
-	ROM_REGION( 0x10000, REGION_GFX2, 0 )
+	ROM_REGION( 0x10000, "gfx2", 0 )
 	ROM_LOAD( "gfx.bin",    0x0000, 0x10000, NO_DUMP )
 
-	ROM_REGION( 0x10000, REGION_USER1, 0 )	// Sprites & Backgrounds ?
+	ROM_REGION( 0x10000, "user1", 0 )	// Sprites & Backgrounds ?
 	ROM_LOAD( "r2",  0x00000, 0x10000, CRC(5ddf9f4e) SHA1(69e4d422ca272bf2e9f00edbe7d23760485fdfe6) )
 
-	ROM_REGION( 0x220, REGION_PROMS, 0 )
+	ROM_REGION( 0x220, "proms", 0 )
 	ROM_LOAD( "0.bpr", 0x0000, 0x0020, CRC(93e2d292) SHA1(af8edd0cfe85f28ede9604cfaf4516d54e5277c9) )	/* priority? (not used) */
 	ROM_LOAD( "1.bpr", 0x0020, 0x0100, CRC(cf14ba30) SHA1(3284b6809075756b3c8e07d9705fc7eacb7556f1) )	/* timing? (not used) */
 	ROM_LOAD( "2.bpr", 0x0120, 0x0100, CRC(0eaf5158) SHA1(bafd4108708f66cd7b280e47152b108f3e254fc9) )	/* timing? (not used) */
@@ -640,22 +614,22 @@ Note, all ROMs have official sticker, "(C) SEIBU KAIHATSU INC." and a number.
 */
 
 ROM_START( cshootre )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )	// Main CPU?
+	ROM_REGION( 0x10000, "main", 0 )	// Main CPU?
 	ROM_LOAD( "1.k19",  0x00000, 0x08000, CRC(71418952) SHA1(9745ca006576381c9e9595d8e42ab276bab80a41) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	// Sub/Sound CPU?
+	ROM_REGION( 0x10000, "audio", 0 )	// Sub/Sound CPU?
 	ROM_LOAD( "5.6f",  0x00000, 0x02000, CRC(30be398c) SHA1(6c61200ee8888d6270c8cec50423b3b5602c2027) )	// 5.g6
 
-	ROM_REGION( 0x02000, REGION_GFX1,  ROMREGION_INVERT )	// TX Layer
+	ROM_REGION( 0x02000, "gfx1",  ROMREGION_INVERT )	// TX Layer
 	ROM_LOAD( "3.f11",  0x00000, 0x02000, CRC(704c26d7) SHA1(e5964f409cbc2c4752e3969f3e84ace08d5ad9cb) )	// only 1 byte difference with R3, bad dump?
 
-	ROM_REGION( 0x10000, REGION_GFX2, 0 )
+	ROM_REGION( 0x10000, "gfx2", 0 )
 	ROM_LOAD( "gfx.bin",    0x0000, 0x10000, NO_DUMP )
 
-	ROM_REGION( 0x10000, REGION_USER1, 0 )	// Sprites & Backgrounds ?
+	ROM_REGION( 0x10000, "user1", 0 )	// Sprites & Backgrounds ?
 	ROM_LOAD( "2.k20",  0x00000, 0x10000, CRC(5812fe72) SHA1(3b28bff6b62a411d2195bb228952db62ad32ef3d) )
 
-	ROM_REGION( 0x08000, REGION_USER2, 0 )	// ?? sound ??
+	ROM_REGION( 0x08000, "user2", 0 )	// ?? sound ??
 	ROM_LOAD( "4.7f",  0x00000, 0x08000, CRC(3cd715b4) SHA1(da735fb5d262908ddf7ed7dacdea68899f1723ff) )	// 4.g8
 ROM_END
 
@@ -682,22 +656,22 @@ SEI0030BU          SEI0060BU                             sw1 xx xxxxx
 */
 
 ROM_START( airraid )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )	// Main CPU?
+	ROM_REGION( 0x10000, "main", 0 )	// Main CPU?
 	ROM_LOAD( "1.16j",  0x00000, 0x08000, CRC(7ac2cedf) SHA1(272831f51a2731e067b5aec6dba6bddd3c5350c9) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	// Sub/Sound CPU?
+	ROM_REGION( 0x10000, "audio", 0 )	// Sub/Sound CPU?
 	ROM_LOAD( "5.6f",  0x00000, 0x02000, CRC(30be398c) SHA1(6c61200ee8888d6270c8cec50423b3b5602c2027) )
 
-	ROM_REGION( 0x02000, REGION_GFX1, ROMREGION_INVERT )	// TX Layer
+	ROM_REGION( 0x02000, "gfx1", ROMREGION_INVERT )	// TX Layer
 	ROM_LOAD( "3.13e",  0x00000, 0x02000, CRC(672ec0e8) SHA1(a11cd90d6494251ceee3bc7c72f4e7b1580b77e2) )
 
-	ROM_REGION( 0x10000, REGION_GFX2, 0 )
+	ROM_REGION( 0x10000, "gfx2", 0 )
 	ROM_LOAD( "gfx.bin",    0x0000, 0x10000, NO_DUMP )
 
-	ROM_REGION( 0x10000, REGION_USER1, 0 )	// bg maps
+	ROM_REGION( 0x10000, "user1", 0 )	// bg maps
 	ROM_LOAD( "2.19j",  0x00000, 0x10000, CRC(842ae6c2) SHA1(0468445e4ab6f42bac786f9a258df3972fd1fde9) )
 
-	ROM_REGION( 0x08000, REGION_USER2, 0 )	// ?? sound ??
+	ROM_REGION( 0x08000, "user2", 0 )	// ?? sound ??
 	ROM_LOAD( "4.7f",  0x00000, 0x08000, CRC(3cd715b4) SHA1(da735fb5d262908ddf7ed7dacdea68899f1723ff) )
 ROM_END
 
@@ -705,21 +679,22 @@ ROM_END
 static DRIVER_INIT( cshooter )
 {
 	/* temp so it boots */
-	UINT8 *rom = memory_region(REGION_CPU1);
+	UINT8 *rom = memory_region(machine, "main");
 
 	rom[0xa2] = 0x00;
 	rom[0xa3] = 0x00;
 	rom[0xa4] = 0x00;
-	memory_set_bankptr(1,&memory_region(REGION_USER1)[0]);
+	memory_set_bankptr(machine, 1,&memory_region(machine, "user1")[0]);
 }
 
 static DRIVER_INIT( cshootre )
 {
+	const address_space *space = cputag_get_address_space(machine, "main", ADDRESS_SPACE_PROGRAM);
 	int A;
-	UINT8 *rom = memory_region(REGION_CPU1);
+	UINT8 *rom = memory_region(machine, "main");
 	UINT8 *decrypt = auto_malloc(0x8000);
 
-	memory_set_decrypted_region(0, 0x0000, 0x7fff, decrypt);
+	memory_set_decrypted_region(space, 0x0000, 0x7fff, decrypt);
 
 	for (A = 0x0000;A < 0x8000;A++)
 	{
@@ -746,8 +721,8 @@ static DRIVER_INIT( cshootre )
 			rom[A] = BITSWAP8(rom[A],7,6,1,4,3,2,5,0);
 	}
 
-	memory_set_bankptr(1,&memory_region(REGION_USER1)[0]);
-	seibu_sound_decrypt(REGION_CPU2,0x2000);
+	memory_set_bankptr(machine, 1,&memory_region(machine, "user1")[0]);
+	seibu_sound_decrypt(machine,"audio",0x2000);
 }
 
 
@@ -755,3 +730,4 @@ static DRIVER_INIT( cshootre )
 GAME( 1987, cshooter, 0,        cshooter, cshooter, cshooter, ROT270, "[Seibu Kaihatsu] (Taito license)",  "Cross Shooter (not encrypted)", GAME_NOT_WORKING | GAME_NO_SOUND )
 GAME( 1987, cshootre, cshooter, airraid, cshooter, cshootre, ROT270, "[Seibu Kaihatsu] (J.K.H. license)", "Cross Shooter (encrypted)", GAME_NOT_WORKING | GAME_NO_SOUND )
 GAME( 1987, airraid,  cshooter, airraid, cshooter, cshootre, ROT270, "Seibu Kaihatsu",                    "Air Raid (encrypted)", GAME_NOT_WORKING | GAME_NO_SOUND )
+
