@@ -55,6 +55,7 @@ To do:
 ***************************************************************************/
 
 #include "driver.h"
+#include "cpu/m68000/m68000.h"
 #include "deprecat.h"
 #include "machine/eeprom.h"
 #include "sound/okim6295.h"
@@ -101,7 +102,7 @@ static WRITE32_HANDLER( darkhors_tmapram2_w )
 	tilemap_mark_tile_dirty(darkhors_tmap2, offset);
 }
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	UINT32 *s		=	spriteram32;
 	UINT32 *end		=	spriteram32 + 0x02000/4;
@@ -138,11 +139,11 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 
 static VIDEO_START( darkhors )
 {
-	darkhors_tmap			=	tilemap_create(	get_tile_info_0, tilemap_scan_rows,
-												TILEMAP_TYPE_PEN, 16,16, 0x40,0x40	);
+	darkhors_tmap			=	tilemap_create(	machine, get_tile_info_0, tilemap_scan_rows,
+												16,16, 0x40,0x40	);
 
-	darkhors_tmap2			=	tilemap_create(	get_tile_info_1, tilemap_scan_rows,
-												TILEMAP_TYPE_PEN, 16,16, 0x40,0x40	);
+	darkhors_tmap2			=	tilemap_create(	machine, get_tile_info_1, tilemap_scan_rows,
+												16,16, 0x40,0x40	);
 
 	tilemap_set_transparent_pen(darkhors_tmap, 0);
 	tilemap_set_transparent_pen(darkhors_tmap2, 0);
@@ -165,7 +166,7 @@ static VIDEO_UPDATE( darkhors )
 	}
 #endif
 
-	fillbitmap(bitmap,get_black_pen(machine),cliprect);
+	bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
 
 	tilemap_set_scrollx(darkhors_tmap,0, (darkhors_tmapscroll[0] >> 16) - 5);
 	tilemap_set_scrolly(darkhors_tmap,0, (darkhors_tmapscroll[0] & 0xffff) - 0xff );
@@ -175,7 +176,7 @@ static VIDEO_UPDATE( darkhors )
 	tilemap_set_scrolly(darkhors_tmap2,0, (darkhors_tmapscroll2[0] & 0xffff) - 0xff );
 	if (layers_ctrl & 2)	tilemap_draw(bitmap,cliprect, darkhors_tmap2, 0, 0);
 
-	if (layers_ctrl & 4)	draw_sprites(machine,bitmap,cliprect);
+	if (layers_ctrl & 4)	draw_sprites(screen->machine,bitmap,cliprect);
 
 #if DARKHORS_DEBUG
 #if 0
@@ -200,7 +201,7 @@ static VIDEO_UPDATE( darkhors )
 
 ***************************************************************************/
 
-static const struct EEPROM_interface eeprom_interface =
+static const eeprom_interface eeprom_intf =
 {
 	7,				// address bits 7
 	8,				// data bits    8
@@ -217,67 +218,61 @@ static const struct EEPROM_interface eeprom_interface =
 static NVRAM_HANDLER( darkhors )
 {
 	if (read_or_write)
-		EEPROM_save(file);
+		eeprom_save(file);
 	else
 	{
-		EEPROM_init(&eeprom_interface);
+		eeprom_init(machine, &eeprom_intf);
 
-		if (file) EEPROM_load(file);
+		if (file) eeprom_load(file);
 		else
 		{
 			// Set the EEPROM to Factory Defaults
-			EEPROM_set_data(memory_region(REGION_USER1),(1<<7));
+			eeprom_set_data(memory_region(machine, "user1"),(1<<7));
 		}
 	}
 }
 
-static READ32_HANDLER( darkhors_eeprom_r )
-{
-	// bit 31?
-	return readinputport(4) | ((EEPROM_read_bit() & 1) << (7+16));
-}
-
 static WRITE32_HANDLER( darkhors_eeprom_w )
 {
 	if (data & ~0xff000000)
-		logerror("CPU #0 PC: %06X - Unknown EEPROM bit written %08X\n",activecpu_get_pc(),data);
+		logerror("CPU #0 PC: %06X - Unknown EEPROM bit written %08X\n",cpu_get_pc(space->cpu),data);
 
-	if ( ACCESSING_MSB32 )
+	if ( ACCESSING_BITS_24_31 )
 	{
 		// latch the bit
-		EEPROM_write_bit(data & 0x04000000);
+		eeprom_write_bit(data & 0x04000000);
 
 		// reset line asserted: reset.
-		EEPROM_set_cs_line((data & 0x01000000) ? CLEAR_LINE : ASSERT_LINE );
+		eeprom_set_cs_line((data & 0x01000000) ? CLEAR_LINE : ASSERT_LINE );
 
 		// clock line asserted: write latch or select next bit to read
-		EEPROM_set_clock_line((data & 0x02000000) ? ASSERT_LINE : CLEAR_LINE );
+		eeprom_set_clock_line((data & 0x02000000) ? ASSERT_LINE : CLEAR_LINE );
 	}
 }
 
-static WRITE32_HANDLER( OKIM6295_data_0_msb32_w )
+static WRITE32_HANDLER( okim6295_data_0_msb32_w )
 {
-	if (ACCESSING_MSB32)
-		OKIM6295_data_0_msb_w(offset, data >> 16, mem_mask >> 16);
+	if (ACCESSING_BITS_24_31)
+		okim6295_data_0_msb_w(space, offset, data >> 16, mem_mask >> 16);
 }
 
-static READ32_HANDLER( OKIM6295_status_0_msb32_r )
+static READ32_HANDLER( okim6295_status_0_msb32_r )
 {
-	return OKIM6295_status_0_msb_r(offset, mem_mask >> 16) << 16;
+	return okim6295_status_0_msb_r(space, offset, mem_mask >> 16) << 16;
 }
 
 static WRITE32_HANDLER( paletteram32_xBBBBBGGGGGRRRRR_dword_w )
 {
 	paletteram16 = (UINT16 *)paletteram32;
-	if (ACCESSING_MSW32)	paletteram16_xBBBBBGGGGGRRRRR_word_w(offset*2, data >> 16, mem_mask >> 16);
-	if (ACCESSING_LSW32)	paletteram16_xBBBBBGGGGGRRRRR_word_w(offset*2+1, data, mem_mask);
+	if (ACCESSING_BITS_16_31)	paletteram16_xBBBBBGGGGGRRRRR_word_w(space, offset*2, data >> 16, mem_mask >> 16);
+	if (ACCESSING_BITS_0_15)	paletteram16_xBBBBBGGGGGRRRRR_word_w(space, offset*2+1, data, mem_mask);
 }
 
 static UINT32 input_sel;
 static WRITE32_HANDLER( darkhors_input_sel_w )
 {
 	COMBINE_DATA(&input_sel);
-//  if (ACCESSING_MSW32)    popmessage("%04X",data >> 16);
+//  if (ACCESSING_BITS_16_31)    popmessage("%04X",data >> 16);
 }
 
 static int mask_to_bit( int mask )
@@ -301,47 +296,48 @@ static READ32_HANDLER( darkhors_input_sel_r )
 	// from bit mask to bit number
 	int bit_p1 = mask_to_bit((input_sel & 0x00ff0000) >> 16);
 	int bit_p2 = mask_to_bit((input_sel & 0xff000000) >> 24);
+	static const char *const portnames[] = { "IN0", "IN1", "IN2", "IN3", "IN4", "IN5", "IN6", "IN7" };
 
-	return	(readinputport(5 + bit_p1) & 0x00ffffff) |
-			(readinputport(5 + bit_p2) & 0xff000000) ;
+	return	(input_port_read(space->machine, portnames[bit_p1]) & 0x00ffffff) |
+			(input_port_read(space->machine, portnames[bit_p2]) & 0xff000000) ;
 }
 
 static WRITE32_HANDLER( darkhors_unk1_w )
 {
 	// 0x1000 lockout
-//  if (ACCESSING_MSW32)    popmessage("%04X",data >> 16);
+//  if (ACCESSING_BITS_16_31)    popmessage("%04X",data >> 16);
 }
 
 static ADDRESS_MAP_START( darkhors_readmem, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ( MRA32_ROM					)
-	AM_RANGE(0x400000, 0x41ffff) AM_READ( MRA32_RAM					)
-	AM_RANGE(0x4e0080, 0x4e0083) AM_READ( darkhors_eeprom_r			)
-	AM_RANGE(0x580000, 0x580003) AM_READ( input_port_0_dword_r		)
-	AM_RANGE(0x580004, 0x580007) AM_READ( input_port_1_dword_r		)
+	AM_RANGE(0x000000, 0x0fffff) AM_READ( SMH_ROM					)
+	AM_RANGE(0x400000, 0x41ffff) AM_READ( SMH_RAM					)
+	AM_RANGE(0x4e0080, 0x4e0083) AM_READ_PORT("4e0080")
+	AM_RANGE(0x580000, 0x580003) AM_READ_PORT("580000")
+	AM_RANGE(0x580004, 0x580007) AM_READ_PORT("580004")
 	AM_RANGE(0x580008, 0x58000b) AM_READ( darkhors_input_sel_r		)
-	AM_RANGE(0x580084, 0x580087) AM_READ( OKIM6295_status_0_msb32_r	)
-	AM_RANGE(0x580200, 0x580203) AM_READ( MRA32_NOP					)
-	AM_RANGE(0x580400, 0x580403) AM_READ( input_port_2_dword_r		)
-	AM_RANGE(0x580420, 0x580423) AM_READ( input_port_3_dword_r		)
-	AM_RANGE(0x800000, 0x87ffff) AM_READ( MRA32_RAM					)
+	AM_RANGE(0x580084, 0x580087) AM_READ( okim6295_status_0_msb32_r	)
+	AM_RANGE(0x580200, 0x580203) AM_READ( SMH_NOP					)
+	AM_RANGE(0x580400, 0x580403) AM_READ_PORT("580400")
+	AM_RANGE(0x580420, 0x580423) AM_READ_PORT("580420")
+	AM_RANGE(0x800000, 0x87ffff) AM_READ( SMH_RAM					)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( darkhors_writemem, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE( MWA32_ROM				)
-	AM_RANGE(0x400000, 0x41ffff) AM_WRITE( MWA32_RAM				)
+	AM_RANGE(0x000000, 0x0fffff) AM_WRITE( SMH_ROM				)
+	AM_RANGE(0x400000, 0x41ffff) AM_WRITE( SMH_RAM				)
 	AM_RANGE(0x490040, 0x490043) AM_WRITE( darkhors_eeprom_w		)
 	AM_RANGE(0x58000c, 0x58000f) AM_WRITE( darkhors_input_sel_w		)
 	AM_RANGE(0x4e0080, 0x4e0083) AM_WRITE( darkhors_unk1_w			)
-	AM_RANGE(0x580084, 0x580087) AM_WRITE( OKIM6295_data_0_msb32_w	)
-	AM_RANGE(0x800000, 0x86bfff) AM_WRITE( MWA32_RAM				)
+	AM_RANGE(0x580084, 0x580087) AM_WRITE( okim6295_data_0_msb32_w	)
+	AM_RANGE(0x800000, 0x86bfff) AM_WRITE( SMH_RAM				)
 	AM_RANGE(0x86c000, 0x86ffff) AM_WRITE( darkhors_tmapram_w		)	AM_BASE(&darkhors_tmapram)
 	AM_RANGE(0x870000, 0x873fff) AM_WRITE( darkhors_tmapram2_w		)	AM_BASE(&darkhors_tmapram2)
-	AM_RANGE(0x874000, 0x87dfff) AM_WRITE( MWA32_RAM				)
-	AM_RANGE(0x87e000, 0x87ffff) AM_WRITE( MWA32_RAM				)	AM_BASE(&spriteram32)
+	AM_RANGE(0x874000, 0x87dfff) AM_WRITE( SMH_RAM				)
+	AM_RANGE(0x87e000, 0x87ffff) AM_WRITE( SMH_RAM				)	AM_BASE(&spriteram32)
 	AM_RANGE(0x880000, 0x89ffff) AM_WRITE( paletteram32_xBBBBBGGGGGRRRRR_dword_w)	AM_BASE(&paletteram32)
-	AM_RANGE(0x8a0000, 0x8bffff) AM_WRITE( MWA32_RAM				)	// this should still be palette ram!
-	AM_RANGE(0x8c0120, 0x8c012f) AM_WRITE( MWA32_RAM				) AM_BASE(&darkhors_tmapscroll)
-	AM_RANGE(0x8c0130, 0x8c013f) AM_WRITE( MWA32_RAM				) AM_BASE(&darkhors_tmapscroll2)
+	AM_RANGE(0x8a0000, 0x8bffff) AM_WRITE( SMH_RAM				)	// this should still be palette ram!
+	AM_RANGE(0x8c0120, 0x8c012f) AM_WRITE( SMH_RAM				) AM_BASE(&darkhors_tmapscroll)
+	AM_RANGE(0x8c0130, 0x8c013f) AM_WRITE( SMH_RAM				) AM_BASE(&darkhors_tmapscroll2)
 ADDRESS_MAP_END
 
 
@@ -354,11 +350,11 @@ ADDRESS_MAP_END
 ***************************************************************************/
 
 static INPUT_PORTS_START( darkhors )
-	PORT_START	// IN0 - 580000
+	PORT_START("580000")
 	PORT_BIT( 0xff7fffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00800000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("?") PORT_CODE(KEYCODE_RCONTROL)
 
-	PORT_START	// IN1 - 580004
+	PORT_START("580004")
 	PORT_BIT( 0x0000ffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_BILL1 )	// bill in
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_COIN1 )	// coin in s1
@@ -371,17 +367,17 @@ static INPUT_PORTS_START( darkhors )
 	PORT_BIT( 0x08000000, IP_ACTIVE_LOW, IPT_COIN2 )	// coin drop p2
 	PORT_BIT( 0x10000000, IP_ACTIVE_LOW, IPT_SPECIAL)	// hopper full p2
 
-	PORT_START	// IN2 - 580400
+	PORT_START("580400")
 	PORT_BIT( 0xfffcffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("0") PORT_CODE(KEYCODE_0_PAD)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("9") PORT_CODE(KEYCODE_9_PAD)
 
-	PORT_START	// IN3 - 580420
+	PORT_START("580420")
 	PORT_BIT( 0xfffcffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("0*") PORT_CODE(KEYCODE_0_PAD)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("9*") PORT_CODE(KEYCODE_9_PAD)
 
-	PORT_START	// IN4 - 4e0080
+	PORT_START("4e0080")
 	PORT_BIT( 0x0000ffff, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW,  IPT_SERVICE1 )	// config
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW,  IPT_SERVICE2 )	// reset
@@ -390,7 +386,7 @@ static INPUT_PORTS_START( darkhors )
 	PORT_BIT( 0x00100000, IP_ACTIVE_LOW,  IPT_SERVICE  ) PORT_NAME(DEF_STR( Test )) PORT_CODE(KEYCODE_F1) // test
 	PORT_BIT( 0x00200000, IP_ACTIVE_LOW,  IPT_UNKNOWN  )	// door 1
 	PORT_BIT( 0x00400000, IP_ACTIVE_LOW,  IPT_UNKNOWN  )	// door 2
-	PORT_BIT( 0x00800000, IP_ACTIVE_HIGH, IPT_SPECIAL  )	// eeprom
+	PORT_BIT( 0x00800000, IP_ACTIVE_HIGH, IPT_SPECIAL  ) PORT_CUSTOM(eeprom_bit_r, NULL)
 	PORT_BIT( 0x01000000, IP_ACTIVE_LOW,  IPT_START1   )	// start
 	PORT_BIT( 0x02000000, IP_ACTIVE_LOW,  IPT_OTHER ) PORT_NAME("P1 Payout") PORT_CODE(KEYCODE_LCONTROL)	// payout
 	PORT_BIT( 0x04000000, IP_ACTIVE_LOW,  IPT_OTHER ) PORT_NAME("P1 Cancel") PORT_CODE(KEYCODE_LALT)		// cancel
@@ -400,7 +396,7 @@ static INPUT_PORTS_START( darkhors )
 	PORT_BIT( 0x40000000, IP_ACTIVE_LOW,  IPT_UNKNOWN  )
 	PORT_BIT( 0x80000000, IP_ACTIVE_LOW,  IPT_UNKNOWN  )
 
-	PORT_START	// IN5 - 580008(0)
+	PORT_START("IN0")	/* 580008(0) */
 	PORT_BIT( 0x0000ffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 1") PORT_CODE(KEYCODE_1_PAD)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 2") PORT_CODE(KEYCODE_2_PAD)
@@ -419,7 +415,7 @@ static INPUT_PORTS_START( darkhors )
 	PORT_BIT( 0x40000000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 Bet 7") //PORT_CODE(KEYCODE_)
 	PORT_BIT( 0x80000000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 Bet 8") //PORT_CODE(KEYCODE_)
 
-	PORT_START	// IN6 - 580008(1)
+	PORT_START("IN1")	/* 580008(1) */
 	PORT_BIT( 0x0000ffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 1-2") PORT_CODE(KEYCODE_Z)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 1-3") PORT_CODE(KEYCODE_A)
@@ -438,7 +434,7 @@ static INPUT_PORTS_START( darkhors )
 	PORT_BIT( 0x40000000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P2 Bet 1-8") //PORT_CODE(KEYCODE_)
 	PORT_BIT( 0x80000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN7 - 580008(2)
+	PORT_START("IN2")	/* 580008(2) */
 	PORT_BIT( 0x0000ffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 2-3") PORT_CODE(KEYCODE_X)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 2-4") PORT_CODE(KEYCODE_S)
@@ -457,7 +453,7 @@ static INPUT_PORTS_START( darkhors )
 	PORT_BIT( 0x40000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN - 580008(3)
+	PORT_START("IN3")	/* 580008(3) */
 	PORT_BIT( 0x0000ffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 3-4") PORT_CODE(KEYCODE_C)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 3-5") PORT_CODE(KEYCODE_D)
@@ -476,7 +472,7 @@ static INPUT_PORTS_START( darkhors )
 	PORT_BIT( 0x40000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN8 - 580008(4)
+	PORT_START("IN4")	/* 580008(4) */
 	PORT_BIT( 0x0000ffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 4-5") PORT_CODE(KEYCODE_V)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 4-6") PORT_CODE(KEYCODE_F)
@@ -495,7 +491,7 @@ static INPUT_PORTS_START( darkhors )
 	PORT_BIT( 0x40000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN9 - 580008(5)
+	PORT_START("IN5")	/* 580008(5) */
 	PORT_BIT( 0x0000ffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 5-6") PORT_CODE(KEYCODE_B)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 5-7") PORT_CODE(KEYCODE_G)
@@ -514,7 +510,7 @@ static INPUT_PORTS_START( darkhors )
 	PORT_BIT( 0x40000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN10 - 580008(6)
+	PORT_START("IN6")	/* 580008(6) */
 	PORT_BIT( 0x0000ffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 6-7") PORT_CODE(KEYCODE_N)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 6-8") PORT_CODE(KEYCODE_H)
@@ -533,7 +529,7 @@ static INPUT_PORTS_START( darkhors )
 	PORT_BIT( 0x40000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80000000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN11 - 580008(7)
+	PORT_START("IN7")	/* 580008(7) */
 	PORT_BIT( 0x0000ffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("P1 Bet 7-8") PORT_CODE(KEYCODE_M)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -576,7 +572,7 @@ static const gfx_layout layout_16x16x8 =
 };
 
 static GFXDECODE_START( darkhors )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, layout_16x16x8, 0, 0x10000/64 )	// color codes should be doubled
+	GFXDECODE_ENTRY( "gfx1", 0, layout_16x16x8, 0, 0x10000/64 )	// color codes should be doubled
 GFXDECODE_END
 
 /***************************************************************************
@@ -589,29 +585,29 @@ GFXDECODE_END
 
 static INTERRUPT_GEN( darkhors )
 {
-	switch (cpu_getiloops())
+	switch (cpu_getiloops(device))
 	{
-		case 0:	cpunum_set_input_line(machine, 0, 3, HOLD_LINE);	break;
-		case 1:	cpunum_set_input_line(machine, 0, 4, HOLD_LINE);	break;
-		case 2:	cpunum_set_input_line(machine, 0, 5, HOLD_LINE);	break;
+		case 0:	cpu_set_input_line(device, 3, HOLD_LINE);	break;
+		case 1:	cpu_set_input_line(device, 4, HOLD_LINE);	break;
+		case 2:	cpu_set_input_line(device, 5, HOLD_LINE);	break;
 	}
 }
 
 static MACHINE_DRIVER_START( darkhors )
-	MDRV_CPU_ADD(M68EC020, 12000000) // 36MHz/3 ??
+	MDRV_CPU_ADD("main", M68EC020, 12000000) // 36MHz/3 ??
 	MDRV_CPU_PROGRAM_MAP(darkhors_readmem,darkhors_writemem)
-	MDRV_CPU_VBLANK_INT(darkhors,3)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT_HACK(darkhors,3)
 
 	MDRV_NVRAM_HANDLER(darkhors)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(0x190, 0x100)
 	MDRV_SCREEN_VISIBLE_AREA(0, 0x190-1, 8, 0x100-8-1)
+
 	MDRV_GFXDECODE(darkhors)
 	MDRV_PALETTE_LENGTH(0x10000)
 
@@ -621,8 +617,8 @@ static MACHINE_DRIVER_START( darkhors )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(OKIM6295, 528000)	// ??
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high) // clock frequency & pin 7 not verified
+	MDRV_SOUND_ADD("oki", OKIM6295, 528000)	// ??
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // clock frequency & pin 7 not verified
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -635,11 +631,11 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( darkhors )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )	// 68EC020 code
+	ROM_REGION( 0x100000, "main", 0 )	// 68EC020 code
 	ROM_LOAD32_WORD_SWAP( "prg2", 0x00000, 0x80000, CRC(f2ec5818) SHA1(326937a331496880f517f41b0b8ab54e55fd7af7) )
 	ROM_LOAD32_WORD_SWAP( "prg1", 0x00002, 0x80000, CRC(b80f8f59) SHA1(abc26dd8b36da0d510978364febe385f69fb317f) )
 
-	ROM_REGION( 0x400000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x400000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "gfx1", 0x000000, 0x80000, CRC(e9fe9967) SHA1(a79d75c09f0eac6372de8d6e98c5eecf38ef750c) )
 	ROM_LOAD( "gfx2", 0x080000, 0x80000, CRC(0853c5c5) SHA1(2b49ffe607278817f1f8219a79f5906be53ee6f4) )
 	ROM_LOAD( "gfx3", 0x100000, 0x80000, CRC(6e89278f) SHA1(044c15e00ea95fd3f108fa916000a1000789c8e8) )
@@ -650,10 +646,10 @@ ROM_START( darkhors )
 	ROM_FILL(         0x300000, 0x80000, 0 ) // a zero-fill seems fine
 	ROM_LOAD( "gfx8", 0x380000, 0x80000, CRC(590bec2a) SHA1(7fdbb21f1a3eccde65e91eb2443a0e01487c59c3) ) // 000xxxxxxxxxxxxxxxx = 0x00
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )	// Samples
+	ROM_REGION( 0x80000, "oki", 0 )	// Samples
 	ROM_LOAD( "snd", 0x00000, 0x80000, CRC(7aeb12d3) SHA1(3e81725fc206baa7559da87552a0cd73b7616155) )
 
-	ROM_REGION( 0x80000, REGION_USER1, ROMREGION_BE )	// EEPROM
+	ROM_REGION( 0x80000, "user1", ROMREGION_BE )	// EEPROM
 	ROM_LOAD( "eeprom", 0x00000, 0x80000, CRC(45314fdb) SHA1(c4bd5508e5b51a6e0356c049f1ccf2b5d94caee9) )
 ROM_END
 
@@ -667,8 +663,8 @@ ROM_END
 
 static DRIVER_INIT( darkhors )
 {
-	UINT32 *rom    = (UINT32 *) memory_region(REGION_CPU1);
-	UINT8  *eeprom = (UINT8 *)  memory_region(REGION_USER1);
+	UINT32 *rom    = (UINT32 *) memory_region(machine, "main");
+	UINT8  *eeprom = (UINT8 *)  memory_region(machine, "user1");
 	int i;
 
 #if 1
