@@ -26,7 +26,6 @@
     You could even multiply the PC by the stack pointer if you wanted."
 
 
-
  driver by Pierpaolo Prazzoli & Tomasz Slanina
 
  - Pierpaolo Prazzoli 2006.05.06
@@ -51,17 +50,18 @@
 *********************************************************************/
 
 #include "driver.h"
+#include "cpu/e132xs/e132xs.h"
 
 static UINT32 *vram;
 static int vbuffer = 0;
-static mame_bitmap *bitmaps[2];
 
 static int flash_roms;
 static UINT32 flash_cmd = 0;
+static INT32 first_offset;
 
 static READ32_HANDLER( flash_r )
 {
-	UINT32 *ROM = (UINT32 *)memory_region(REGION_USER1);
+	UINT32 *ROM = (UINT32 *)memory_region(space->machine, "user1");
 
 	if(offset >= (0x2000000 - flash_roms * 0x400000) / 4)
 	{
@@ -92,15 +92,13 @@ static READ32_HANDLER( flash_r )
 
 static WRITE32_HANDLER( flash_w )
 {
-	static INT32 first_offset = -1;
-
 	if(flash_cmd == 0x20200000)
 	{
 		// erase game settings
 		if(data == 0xd0d00000)
 		{
 			// point to game settings
-			UINT8 *rom = (UINT8 *)memory_region(REGION_USER1) + offset*4;
+			UINT8 *rom = (UINT8 *)memory_region(space->machine, "user1") + offset*4;
 
 			// erase one block
 			memset(rom, 0xff, 0x10000);
@@ -118,11 +116,11 @@ static WRITE32_HANDLER( flash_w )
 		}
 		else
 		{
-			UINT16 *rom = (UINT16 *)memory_region(REGION_USER1);
+			UINT16 *rom = (UINT16 *)memory_region(space->machine, "user1");
 
 			// write game settings
 
-			if(ACCESSING_LSW32)
+			if(ACCESSING_BITS_0_15)
 				rom[BYTE_XOR_BE(offset*2 + 1)] = data & 0xffff;
 			else
 				rom[BYTE_XOR_BE(offset*2 + 0)] = (data & 0xffff0000) >> 16;
@@ -139,55 +137,21 @@ static WRITE32_HANDLER( flash_w )
 	}
 }
 
-static void plot_pixel_rgb(int x, int y, int color)
-{
-	if (bitmaps[vbuffer]->bpp == 32)
-	{
-		UINT32 b = (color & 0x001f) << 3;
-		UINT32 g = (color & 0x03e0) >> 2;
-		UINT32 r = (color & 0x7c00) >> 7;
-		*BITMAP_ADDR32(bitmaps[vbuffer], y, x) = b | (g<<8) | (r<<16);
-	}
-	else
-	{
-		/* color is BGR; convert to RGB */
-		color = ((color & 0x1f) << 10) | (color & 0x3e0) | ((color & 0x7c00) >> 10);
-		*BITMAP_ADDR16(bitmaps[vbuffer], y, x) = color;
-	}
-}
-
 static WRITE32_HANDLER( vram_w )
 {
-	int x,y;
+	UINT32 *dest = &vram[offset+(0x40000/4)*vbuffer];
 
-	switch(mem_mask)
+	if (mem_mask == 0xffffffff)
 	{
-		case 0:
-			vram_w(offset,data,0x0000ffff);
-			vram_w(offset,data,0xffff0000);
-			return;
+		if (~data & 0x80000000)
+			*dest = (*dest & 0x0000ffff) | (data & 0xffff0000);
 
-		case 0xffff:
-			if(data & 0x80000000)
-				return;
-		break;
-
-		case 0xffff0000:
-			if(data & 0x8000)
-				return;
-		break;
-	}
-
-	COMBINE_DATA(&vram[offset+(0x40000/4)*vbuffer]);
-
-	y = offset >> 8;
-	x = offset & 0xff;
-
-	if(x < 320/2 && y < 240)
-	{
-		plot_pixel_rgb(x*2,  y,(vram[offset+(0x40000/4)*vbuffer]>>16) & 0x7fff);
-		plot_pixel_rgb(x*2+1,y, vram[offset+(0x40000/4)*vbuffer] & 0x7fff);
+		if (~data & 0x00008000)
+			*dest = (*dest & 0xffff0000) | (data & 0x0000ffff);
 	}
+	else if (((mem_mask == 0xffff0000) && (~data & 0x80000000)) ||
+	    	 ((mem_mask == 0x0000ffff) && (~data & 0x00008000)))
+		COMBINE_DATA(dest);
 }
 
 static READ32_HANDLER( vram_r )
@@ -216,8 +180,8 @@ static WRITE32_HANDLER( coin_w )
 static READ32_HANDLER( vblank_r )
 {
 	/* burn a bunch of cycles because this is polled frequently during busy loops */
-	activecpu_adjust_icount(-100);
-	return input_port_0_dword_r(offset, 0);
+	cpu_eat_cycles(space->cpu, 100);
+	return input_port_read(space->machine, "VBLANK");
 }
 
 static ADDRESS_MAP_START( cpu_map, ADDRESS_SPACE_PROGRAM, 32 )
@@ -225,13 +189,13 @@ static ADDRESS_MAP_START( cpu_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x40000000, 0x4003ffff) AM_READWRITE(vram_r, vram_w)
 	AM_RANGE(0xe0000000, 0xe1ffffff) AM_READWRITE(flash_r, flash_w)
 	AM_RANGE(0xe2000000, 0xe3ffffff) AM_READWRITE(flash_r, flash_w)
-	AM_RANGE(0xffc00000, 0xffffffff) AM_ROM AM_REGION(REGION_USER1, 0x1c00000)
+	AM_RANGE(0xffc00000, 0xffffffff) AM_ROM AM_REGION("user1", 0x1c00000)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( io_map, ADDRESS_SPACE_IO, 32 )
 	AM_RANGE(0x0200, 0x0203) AM_READNOP // used to sync with the protecion PIC? tested bits 0 and 1
 	AM_RANGE(0x0400, 0x0403) AM_READWRITE(vblank_r, vbuffer_w)
-	AM_RANGE(0x0a10, 0x0a13) AM_READ(input_port_1_dword_r)
+	AM_RANGE(0x0a10, 0x0a13) AM_READ_PORT("INPUTS")
 	AM_RANGE(0x0200, 0x0203) AM_WRITE(coin_w)
 	AM_RANGE(0x0c00, 0x0c03) AM_WRITENOP // writes only: 1, 0, 1 at startup
 	AM_RANGE(0x0c80, 0x0c83) AM_WRITENOP // sound commands / latches
@@ -245,7 +209,7 @@ static NVRAM_HANDLER( flashroms )
 	if (read_or_write)
 	{
 		// point to game settings
-		UINT8 *rom = (UINT8 *)memory_region(REGION_USER1) + 0x1c00000 + 0x360000;
+		UINT8 *rom = (UINT8 *)memory_region(machine, "user1") + 0x1c00000 + 0x360000;
 		UINT8 tmp[0x40000];
 		int i;
 
@@ -258,7 +222,7 @@ static NVRAM_HANDLER( flashroms )
 	else if (file)
 	{
 		// point to game settings
-		UINT8 *rom = (UINT8 *)memory_region(REGION_USER1) + 0x1c00000 + 0x360000;
+		UINT8 *rom = (UINT8 *)memory_region(machine, "user1") + 0x1c00000 + 0x360000;
 		UINT8 tmp[0x40000];
 		int i;
 
@@ -271,11 +235,11 @@ static NVRAM_HANDLER( flashroms )
 }
 
 static INPUT_PORTS_START( dgpix )
-	PORT_START
+	PORT_START("VBLANK")
 	PORT_BIT( 0x00000003, IP_ACTIVE_LOW, IPT_VBLANK ) //value 2 is used by fmaniac3
 	PORT_BIT( 0xfffffffc, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("INPUTS")
 	PORT_BIT( 0x00000001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x00000002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN	) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x00000004, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT	) PORT_8WAY PORT_PLAYER(1)
@@ -293,7 +257,6 @@ static INPUT_PORTS_START( dgpix )
 	PORT_BIT( 0x00004000, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x00008000, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_SERVICE_NO_TOGGLE( 0x00010000, IP_ACTIVE_LOW )
-	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_SERVICE1 )
 	PORT_BIT( 0x00080000, IP_ACTIVE_LOW, IPT_UNUSED )
@@ -307,18 +270,41 @@ INPUT_PORTS_END
 static VIDEO_START( dgpix )
 {
 	vram = auto_malloc(0x40000*2);
-	bitmaps[0] = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
-	bitmaps[1] = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
 }
 
 static VIDEO_UPDATE( dgpix )
 {
-	copybitmap(bitmap,bitmaps[vbuffer ^ 1],0,0,0,0,cliprect);
+	int y;
+
+	for (y = 0; y < 240; y++)
+	{
+		int x;
+		UINT32 *src = &vram[(vbuffer ? 0 : 0x10000) | (y << 8)];
+		UINT16 *dest = BITMAP_ADDR16(bitmap, y, 0);
+
+		for (x = 0; x < 320; x += 2)
+		{
+			dest[0] = (*src >> 16) & 0x7fff;
+			dest[1] = (*src >>  0) & 0x7fff;
+
+			src++;
+			dest += 2;
+		}
+	}
+
 	return 0;
 }
 
+static MACHINE_RESET( dgpix )
+{
+	vbuffer = 0;
+	flash_cmd = 0;
+	first_offset = -1;
+}
+
+
 static MACHINE_DRIVER_START( dgpix )
-	MDRV_CPU_ADD(E132XT, 20000000*4)	/* 4x internal multiplier */
+	MDRV_CPU_ADD("main", E132XT, 20000000*4)	/* 4x internal multiplier */
 	MDRV_CPU_PROGRAM_MAP(cpu_map,0)
 	MDRV_CPU_IO_MAP(io_map,0)
 
@@ -327,16 +313,18 @@ static MACHINE_DRIVER_START( dgpix )
     running at 16.9MHz
 */
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-
+	MDRV_MACHINE_RESET(dgpix)
 	MDRV_NVRAM_HANDLER(flashroms)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB15)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
+	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(512, 256)
 	MDRV_SCREEN_VISIBLE_AREA(0, 319, 0, 239)
+
+	MDRV_PALETTE_INIT(BBBBB_GGGGG_RRRRR)
 	MDRV_PALETTE_LENGTH(32768)
 
 	MDRV_VIDEO_START(dgpix)
@@ -401,15 +389,15 @@ SEC KM6161002    : Graphics RAM (SOJ44)
 */
 
 ROM_START( xfiles )
-	ROM_REGION32_BE( 0x2000000, REGION_USER1, ROMREGION_ERASE00 ) /* Hyperstone CPU Code & Data */
+	ROM_REGION32_BE( 0x2000000, "user1", ROMREGION_ERASE00 ) /* Hyperstone CPU Code & Data */
 	/* 0 - 0x17fffff empty space */
 	ROM_LOAD16_WORD_SWAP( "u8.bin",  0x1800000, 0x400000, CRC(3b2c2bc1) SHA1(1c07fb5bd8a8c9b5fb169e6400fef845f3aee7aa) )
 	ROM_LOAD16_WORD_SWAP( "u9.bin",  0x1c00000, 0x400000, CRC(6ecdd1eb) SHA1(e26c9711e589865cc75ec693d382758fa52528b8) )
 
-	ROM_REGION( 0x400000, REGION_CPU2, 0 ) /* sound rom */
+	ROM_REGION( 0x400000, "cpu1", 0 ) /* sound rom */
 	ROM_LOAD16_WORD_SWAP( "u10.bin", 0x0000000, 0x400000, CRC(f2ef1eb9) SHA1(d033d140fce6716d7d78509aa5387829f0a1404c) )
 
-	ROM_REGION( 0x1000, REGION_CPU3, ROMREGION_DISPOSE ) /* PIC */
+	ROM_REGION( 0x1000, "cpu2", ROMREGION_DISPOSE ) /* PIC */
 	ROM_LOAD( "xfiles_pic",  0x0000, 0x1000, NO_DUMP ) // protected
 ROM_END
 
@@ -476,17 +464,17 @@ Notes:
 */
 
 ROM_START( kdynastg )
-	ROM_REGION32_BE( 0x2000000, REGION_USER1, ROMREGION_ERASE00 )  /* Hyperstone CPU Code & Data */
+	ROM_REGION32_BE( 0x2000000, "user1", ROMREGION_ERASE00 )  /* Hyperstone CPU Code & Data */
 	/* 0 - 0x0ffffff empty space */
 	ROM_LOAD16_WORD_SWAP( "flash.u6",  0x1000000, 0x400000, CRC(280dd64e) SHA1(0e23b227b1183fb5591c3a849b5a5fe7faa23cc8) )
 	ROM_LOAD16_WORD_SWAP( "flash.u7",  0x1400000, 0x400000, CRC(f9125894) SHA1(abaad31f7a02143ea7029e47e6baf2976365f70c) )
 	ROM_LOAD16_WORD_SWAP( "flash.u8",  0x1800000, 0x400000, CRC(1016b61c) SHA1(eab4934e1f41cc26259e5187a94ceebd45888a94) )
 	ROM_LOAD16_WORD_SWAP( "flash.u9",  0x1c00000, 0x400000, CRC(093d9243) SHA1(2a643acc7144193aaa3606a84b0c67aadb4c543b) )
 
-	ROM_REGION( 0x400000, REGION_CPU2, 0 ) /* sound rom */
+	ROM_REGION( 0x400000, "cpu1", 0 ) /* sound rom */
 	ROM_LOAD16_WORD_SWAP( "flash.u10", 0x0000000, 0x400000, CRC(3f103cb1) SHA1(2ff9bd73f3005f09d872018b81c915b01d6703f5) )
 
-	ROM_REGION( 0x1000, REGION_CPU3, ROMREGION_DISPOSE ) /* PIC */
+	ROM_REGION( 0x1000, "cpu2", ROMREGION_DISPOSE ) /* PIC */
 	ROM_LOAD( "kdynastg_pic",  0x0000, 0x1000, NO_DUMP ) // protected
 ROM_END
 
@@ -554,21 +542,21 @@ Notes:
 */
 
 ROM_START( fmaniac3 )
-	ROM_REGION32_BE( 0x2000000, REGION_USER1, ROMREGION_ERASE00 ) /* Hyperstone CPU Code & Data */
+	ROM_REGION32_BE( 0x2000000, "user1", ROMREGION_ERASE00 ) /* Hyperstone CPU Code & Data */
 	/* 0 - 0x17fffff empty space */
 	ROM_LOAD16_WORD_SWAP( "flash.u8", 0x1800000, 0x400000, CRC(dc08a224) SHA1(4d14145eb84ad13674296f81e90b9d60403fa0de) )
 	ROM_LOAD16_WORD_SWAP( "flash.u9", 0x1c00000, 0x400000, CRC(c1fee95f) SHA1(0ed5ed9fa18e7da9242a6df2c210c46de25a2281) )
 
-	ROM_REGION( 0x400000, REGION_CPU2, 0 ) /* sound rom */
+	ROM_REGION( 0x400000, "cpu1", 0 ) /* sound rom */
 	ROM_LOAD16_WORD_SWAP( "flash.u10", 0x000000, 0x400000, CRC(dfeb91a0) SHA1(a4a79073c3f6135957ea8a4a66a9c71a3a39893c) )
 
-	ROM_REGION( 0x1000, REGION_CPU3, ROMREGION_DISPOSE ) /* PIC */
+	ROM_REGION( 0x1000, "cpu2", ROMREGION_DISPOSE ) /* PIC */
 	// not present
 ROM_END
 
 static DRIVER_INIT( xfiles )
 {
-	UINT8 *rom = (UINT8 *)memory_region(REGION_USER1) + 0x1c00000;
+	UINT8 *rom = (UINT8 *)memory_region(machine, "user1") + 0x1c00000;
 
 	rom[BYTE4_XOR_BE(0x3aa92e)] = 3;
 	rom[BYTE4_XOR_BE(0x3aa92f)] = 0;
@@ -578,14 +566,14 @@ static DRIVER_INIT( xfiles )
 	rom[BYTE4_XOR_BE(0x3aa933)] = 0;
 
 //  protection related ?
-//  memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0xf0c8b440, 0xf0c8b447, 0, 0, MRA32_NOP );
+//  memory_install_read32_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xf0c8b440, 0xf0c8b447, 0, 0, SMH_NOP );
 
 	flash_roms = 2;
 }
 
 static DRIVER_INIT( kdynastg )
 {
-	UINT8 *rom = (UINT8 *)memory_region(REGION_USER1) + 0x1c00000;
+	UINT8 *rom = (UINT8 *)memory_region(machine, "user1") + 0x1c00000;
 
 	rom[BYTE4_XOR_BE(0x3aaa10)] = 3; // 129f0 - nopped call
 	rom[BYTE4_XOR_BE(0x3aaa11)] = 0;
@@ -598,7 +586,7 @@ static DRIVER_INIT( kdynastg )
 	rom[BYTE4_XOR_BE(0x3a45c9)] = 0;
 
 //  protection related ?
-//  memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0x12341234, 0x12341243, 0, 0, MRA32_NOP );
+//  memory_install_read32_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x12341234, 0x12341243, 0, 0, SMH_NOP );
 
 	flash_roms = 4;
 }
