@@ -225,9 +225,9 @@ ProtectionOut( int i, UINT8 data )
 } /* ProtectionOut */
 
 static int
-GetLives( void )
+GetLives( running_machine *machine )
 {
-	int dsw = readinputport(4);
+	int dsw = input_port_read(machine, "DSW2");
 	switch( dsw&0x30 )
 	{
 	case 0x10: return 3;
@@ -240,7 +240,7 @@ GetLives( void )
 
 static WRITE8_HANDLER( coinplus_w )
 {
-	int dsw = readinputport(3);
+	int dsw = input_port_read(space->machine, "DSW1");
 	coin_counter_w( 0, data&1 );
 	coin_counter_w( 1, data&2 );
 	if( data&1 )
@@ -268,9 +268,9 @@ static WRITE8_HANDLER( coinplus_w )
 } /* coinplus_w */
 
 static void
-OutputProtectionState( int i, int type )
+OutputProtectionState( running_machine *machine, int i, int type )
 {
-	int io = ~readinputport(0);
+	int io = ~input_port_read(machine, "IN0");
 	int dat = 0x00;
 
 	switch( mDjBoyState )
@@ -337,7 +337,7 @@ OutputProtectionState( int i, int type )
 		{ /* p1 start */
 			dat = 0x16;
 			mDjBoyState = eDJBOY_ACTIVE_GAMEPLAY;
-			lives[0] = GetLives();
+			lives[0] = GetLives(machine);
 			logerror( "P1 START!\n" );
 			coin-=4;
 		}
@@ -345,8 +345,8 @@ OutputProtectionState( int i, int type )
 		{ /* p2 start */
 			dat = 0x0a;
 			mDjBoyState = eDJBOY_ACTIVE_GAMEPLAY;
-			lives[0] = GetLives();
-			lives[1] = GetLives();
+			lives[0] = GetLives(machine);
+			lives[1] = GetLives(machine);
 			logerror( "P2 START!\n" );
 			coin-=8;
 		}
@@ -364,7 +364,7 @@ OutputProtectionState( int i, int type )
 			if( (io&1) && lives[0]==0 )
 			{
 				dat = 0x12; /* continue (P1) */
-				lives[0] = GetLives();
+				lives[0] = GetLives(machine);
 				mDjBoyState = eDJBOY_ACTIVE_GAMEPLAY;
 				coin-=4;
 				logerror( "P1 CONTINUE!\n" );
@@ -372,7 +372,7 @@ OutputProtectionState( int i, int type )
 			else if( (io&2) && lives[1]==0 )
 			{
 				dat = 0x08; /* continue (P2) */
-				lives[1] = GetLives();
+				lives[1] = GetLives(machine);
 				mDjBoyState = eDJBOY_ACTIVE_GAMEPLAY;
 				coin-=4;
 				logerror( "P2 CONTINUE!\n" );
@@ -385,7 +385,7 @@ OutputProtectionState( int i, int type )
 } /* OutputProtectionState */
 
 static void
-CommonProt( int i, int type )
+CommonProt( running_machine *machine, int i, int type )
 {
 	int displayedCredits = coin/4;
 	if( displayedCredits>9 )
@@ -393,22 +393,22 @@ CommonProt( int i, int type )
 		displayedCredits = 9;
 	}
 	ProtectionOut( i++, displayedCredits );
-	ProtectionOut( i++, readinputport(0) ); /* COIN/START */
-	OutputProtectionState( i, type );
+	ProtectionOut( i++, input_port_read(machine, "IN0") ); /* COIN/START */
+	OutputProtectionState( machine, i, type );
 } /* CommonProt */
 
 static WRITE8_HANDLER( beast_data_w )
 {
 	prot_busy_count = 1;
 
-	logerror( "0x%04x: prot_w(0x%02x)\n", activecpu_get_pc(), data );
+	logerror( "0x%04x: prot_w(0x%02x)\n", cpu_get_pc(space->cpu), data );
 
-	watchdog_reset_w(0,0);
+	watchdog_reset_w(space,0,0);
 
 	if( prot_mode == ePROT_WAIT_DSW1_WRITEBACK )
 	{
 		logerror( "[DSW1_WRITEBACK]\n" );
-		ProtectionOut( 0, readinputport(4) ); /* DSW2 */
+		ProtectionOut( 0, input_port_read(space->machine, "DSW2") ); /* DSW2 */
 		prot_mode = ePROT_WAIT_DSW2_WRITEBACK;
 	}
 	else if( prot_mode == ePROT_WAIT_DSW2_WRITEBACK )
@@ -454,11 +454,11 @@ static WRITE8_HANDLER( beast_data_w )
 			break;
 
 		case 0x01: // pc=7389
-			OutputProtectionState( 0, 0x01 );
+			OutputProtectionState( space->machine, 0, 0x01 );
 			break;
 
 		case 0x02:
-			CommonProt( 0,0x02 );
+			CommonProt( space->machine,0,0x02 );
 			break;
 
 		case 0x03: /* prepare for memory write to protection device ram (pc == 0x7987) */ // -> 0x02
@@ -472,48 +472,48 @@ static WRITE8_HANDLER( beast_data_w )
 			ProtectionOut( 1,0 ); // ?
 			ProtectionOut( 2,0 ); // ?
 			ProtectionOut( 3,0 ); // ?
-			CommonProt(    4,0x04 );
+			CommonProt(    space->machine, 4,0x04 );
 			break;
 
 		case 0x05: /* 0x71f4 */
-			ProtectionOut( 0,readinputport(1) ); // to $42
+			ProtectionOut( 0,input_port_read(space->machine, "IN1") ); // to $42
 			ProtectionOut( 1,0 ); // ?
-			ProtectionOut( 2,readinputport(2) ); // to $43
+			ProtectionOut( 2,input_port_read(space->machine, "IN2") ); // to $43
 			ProtectionOut( 3,0 ); // ?
 			ProtectionOut( 4,0 ); // ?
-			CommonProt(    5,0x05 );
+			CommonProt(    space->machine, 5,0x05 );
 			break;
 
 		case 0x07:
-			CommonProt( 0,0x07 );
+			CommonProt( space->machine, 0,0x07 );
 			break;
 
 		case 0x08: /* pc == 0x727a */
-			ProtectionOut( 0,readinputport(0) ); /* COIN/START */
-			ProtectionOut( 1,readinputport(1) ); /* JOY1 */
-			ProtectionOut( 2,readinputport(2) ); /* JOY2 */
-			ProtectionOut( 3,readinputport(3) ); /* DSW1 */
-			ProtectionOut( 4,readinputport(4) ); /* DSW2 */
-			CommonProt(    5, 0x08 );
+			ProtectionOut( 0,input_port_read(space->machine, "IN0") ); /* COIN/START */
+			ProtectionOut( 1,input_port_read(space->machine, "IN1") ); /* JOY1 */
+			ProtectionOut( 2,input_port_read(space->machine, "IN2") ); /* JOY2 */
+			ProtectionOut( 3,input_port_read(space->machine, "DSW1") ); /* DSW1 */
+			ProtectionOut( 4,input_port_read(space->machine, "DSW2") ); /* DSW2 */
+			CommonProt(    space->machine, 5, 0x08 );
 			break;
 
 		case 0x09:
 			ProtectionOut( 0,0 ); // ?
 			ProtectionOut( 1,0 ); // ?
 			ProtectionOut( 2,0 ); // ?
-			CommonProt(    3, 0x09 );
+			CommonProt(    space->machine, 3, 0x09 );
 			break;
 
 		case 0x0a:
-			CommonProt( 0,0x0a );
+			CommonProt( space->machine,0,0x0a );
 			break;
 
 		case 0x0c:
-			CommonProt( 1,0x0c );
+			CommonProt( space->machine,1,0x0c );
 			break;
 
 		case 0x0d:
-			CommonProt( 2,0x0d );
+			CommonProt( space->machine,2,0x0d );
 			break;
 
 		case 0xfe: /* prepare for memory read from protection device ram (pc == 0x79ee, 0x7a3f) */
@@ -531,7 +531,7 @@ static WRITE8_HANDLER( beast_data_w )
 			break;
 
 		case 0xff: /* read DSW (pc == 0x714d) */
-			ProtectionOut( 0,readinputport(3) ); /* DSW1 */
+			ProtectionOut( 0,input_port_read(space->machine, "DSW1") ); /* DSW1 */
 			prot_mode = ePROT_WAIT_DSW1_WRITEBACK;
 			break;
 
@@ -601,7 +601,7 @@ static WRITE8_HANDLER( beast_data_w )
 		default:
 		case 0x97:
 		case 0x9a:
-			logerror( "!!0x%04x: prot_w(0x%02x)\n", activecpu_get_pc(), data );
+			logerror( "!!0x%04x: prot_w(0x%02x)\n", cpu_get_pc(space->cpu), data );
 			break;
 		}
 	}
@@ -624,7 +624,7 @@ static READ8_HANDLER( beast_data_r )
 	{
 		logerror( "prot_r: data expected!\n" );
 	}
-	logerror( "0x%04x: prot_r() == 0x%02x\n", activecpu_get_pc(), data );
+	logerror( "0x%04x: prot_r() == 0x%02x\n", cpu_get_pc(space->cpu), data );
 	return data;
 } /* beast_data_r */
 
@@ -657,14 +657,14 @@ static DRIVER_INIT( djboyj )
 
 static WRITE8_HANDLER( trigger_nmi_on_cpu0 )
 {
-	cpunum_set_input_line(Machine, 0, INPUT_LINE_NMI, PULSE_LINE);
+	cpu_set_input_line(space->machine->cpu[0], INPUT_LINE_NMI, PULSE_LINE);
 }
 
 static WRITE8_HANDLER( cpu0_bankswitch_w )
 {
-	unsigned char *RAM = memory_region(REGION_CPU1);
+	unsigned char *RAM = memory_region(space->machine, "main");
 	data ^= bankxor;
-	memory_set_bankptr(4,&RAM[0x10000]); /* unsure if/how this area is banked */
+	memory_set_bankptr(space->machine, 4,&RAM[0x10000]); /* unsure if/how this area is banked */
 	if( data < 4 )
 	{
 		RAM = &RAM[0x2000 * data];
@@ -673,7 +673,7 @@ static WRITE8_HANDLER( cpu0_bankswitch_w )
 	{
 		RAM = &RAM[0x10000 + 0x2000 * (data-4)];
 	}
-	memory_set_bankptr(1,RAM);
+	memory_set_bankptr(space->machine, 1,RAM);
 }
 
 /******************************************************************************/
@@ -686,25 +686,25 @@ static WRITE8_HANDLER( cpu0_bankswitch_w )
  */
 static WRITE8_HANDLER( cpu1_bankswitch_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU2);
+	UINT8 *RAM = memory_region(space->machine, "cpu1");
 	djboy_set_videoreg( data );
 	switch( data&0xf )
 	{
 	/* bs65.5y */
-	case 0x00: memory_set_bankptr(2,&RAM[0x00000]); break;
-	case 0x01: memory_set_bankptr(2,&RAM[0x04000]); break;
-	case 0x02: memory_set_bankptr(2,&RAM[0x10000]); break;
-	case 0x03: memory_set_bankptr(2,&RAM[0x14000]); break;
+	case 0x00: memory_set_bankptr(space->machine, 2,&RAM[0x00000]); break;
+	case 0x01: memory_set_bankptr(space->machine, 2,&RAM[0x04000]); break;
+	case 0x02: memory_set_bankptr(space->machine, 2,&RAM[0x10000]); break;
+	case 0x03: memory_set_bankptr(space->machine, 2,&RAM[0x14000]); break;
 
 	/* bs101.6w */
-	case 0x08: memory_set_bankptr(2,&RAM[0x18000]); break;
-	case 0x09: memory_set_bankptr(2,&RAM[0x1c000]); break;
-	case 0x0a: memory_set_bankptr(2,&RAM[0x20000]); break;
-	case 0x0b: memory_set_bankptr(2,&RAM[0x24000]); break;
-	case 0x0c: memory_set_bankptr(2,&RAM[0x28000]); break;
-	case 0x0d: memory_set_bankptr(2,&RAM[0x2c000]); break;
-	case 0x0e: memory_set_bankptr(2,&RAM[0x30000]); break;
-	case 0x0f: memory_set_bankptr(2,&RAM[0x34000]); break;
+	case 0x08: memory_set_bankptr(space->machine, 2,&RAM[0x18000]); break;
+	case 0x09: memory_set_bankptr(space->machine, 2,&RAM[0x1c000]); break;
+	case 0x0a: memory_set_bankptr(space->machine, 2,&RAM[0x20000]); break;
+	case 0x0b: memory_set_bankptr(space->machine, 2,&RAM[0x24000]); break;
+	case 0x0c: memory_set_bankptr(space->machine, 2,&RAM[0x28000]); break;
+	case 0x0d: memory_set_bankptr(space->machine, 2,&RAM[0x2c000]); break;
+	case 0x0e: memory_set_bankptr(space->machine, 2,&RAM[0x30000]); break;
+	case 0x0f: memory_set_bankptr(space->machine, 2,&RAM[0x34000]); break;
 
 	default:
 		break;
@@ -715,13 +715,13 @@ static WRITE8_HANDLER( cpu1_bankswitch_w )
 
 static WRITE8_HANDLER( trigger_nmi_on_sound_cpu2 )
 {
-	soundlatch_w(0,data);
-	cpunum_set_input_line(Machine, 2, INPUT_LINE_NMI, PULSE_LINE);
+	soundlatch_w(space,0,data);
+	cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_NMI, PULSE_LINE);
 } /* trigger_nmi_on_sound_cpu2 */
 
 static WRITE8_HANDLER( cpu2_bankswitch_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU3);
+	UINT8 *RAM = memory_region(space->machine, "cpu2");
 
 	if( data<3 )
 	{
@@ -731,39 +731,39 @@ static WRITE8_HANDLER( cpu2_bankswitch_w )
 	{
 		RAM = &RAM[0x10000 + 0x4000*(data-3)];
 	}
-	memory_set_bankptr(3,RAM);
+	memory_set_bankptr(space->machine, 3,RAM);
 }
 
 /******************************************************************************/
 
 static ADDRESS_MAP_START( cpu0_am, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0xafff) AM_READ(MRA8_BANK4)
+	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x8000, 0xafff) AM_READ(SMH_BANK4)
 	AM_RANGE(0xb000, 0xbfff) AM_READWRITE( pandora_spriteram_r, pandora_spriteram_w )
-	AM_RANGE(0xc000, 0xdfff) AM_READ(MRA8_BANK1)
-	AM_RANGE(0xe000, 0xefff) AM_READ(MRA8_RAM) AM_WRITE(MWA8_RAM) AM_BASE(&sharedram)
-	AM_RANGE(0xf000, 0xf7ff) AM_READ(MRA8_RAM) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xf800, 0xffff) AM_READ(MRA8_RAM) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0xc000, 0xdfff) AM_READ(SMH_BANK1)
+	AM_RANGE(0xe000, 0xefff) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM) AM_BASE(&sharedram)
+	AM_RANGE(0xf000, 0xf7ff) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM)
+	AM_RANGE(0xf800, 0xffff) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( cpu0_port_am, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_WRITE(cpu0_bankswitch_w)
 ADDRESS_MAP_END
 
 /******************************************************************************/
 
 static ADDRESS_MAP_START( cpu1_am, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(MRA8_BANK2)
-	AM_RANGE(0xc000, 0xcfff) AM_READ(MRA8_RAM) AM_WRITE(djboy_videoram_w) AM_BASE(&videoram)
-	AM_RANGE(0xd000, 0xd3ff) AM_READ(MRA8_RAM) AM_WRITE(djboy_paletteram_w) AM_BASE(&paletteram)
-	AM_RANGE(0xd400, 0xd8ff) AM_READ(MRA8_RAM) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_BANK2)
+	AM_RANGE(0xc000, 0xcfff) AM_READ(SMH_RAM) AM_WRITE(djboy_videoram_w) AM_BASE(&videoram)
+	AM_RANGE(0xd000, 0xd3ff) AM_READ(SMH_RAM) AM_WRITE(djboy_paletteram_w) AM_BASE(&paletteram)
+	AM_RANGE(0xd400, 0xd8ff) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM)
 	AM_RANGE(0xe000, 0xffff) AM_READ(sharedram_r) AM_WRITE(sharedram_w)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( cpu1_port_am, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_WRITE(cpu1_bankswitch_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(trigger_nmi_on_sound_cpu2)
 	AM_RANGE(0x04, 0x04) AM_READ(beast_data_r) AM_WRITE(beast_data_w)
@@ -777,19 +777,19 @@ ADDRESS_MAP_END
 /******************************************************************************/
 
 static ADDRESS_MAP_START( cpu2_am, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(MRA8_BANK3)
-	AM_RANGE(0xc000, 0xdfff) AM_READ(MRA8_RAM) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_BANK3)
+	AM_RANGE(0xc000, 0xdfff) AM_READ(SMH_RAM) AM_WRITE(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( cpu2_port_am, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_WRITE(cpu2_bankswitch_w)
-	AM_RANGE(0x02, 0x02) AM_READ(YM2203_status_port_0_r) AM_WRITE(YM2203_control_port_0_w)
-	AM_RANGE(0x03, 0x03) AM_READ(YM2203_read_port_0_r) AM_WRITE(YM2203_write_port_0_w)
+	AM_RANGE(0x02, 0x02) AM_READ(ym2203_status_port_0_r) AM_WRITE(ym2203_control_port_0_w)
+	AM_RANGE(0x03, 0x03) AM_READ(ym2203_read_port_0_r) AM_WRITE(ym2203_write_port_0_w)
 	AM_RANGE(0x04, 0x04) AM_READ(soundlatch_r)
-	AM_RANGE(0x06, 0x06) AM_READ(OKIM6295_status_0_r) AM_WRITE(OKIM6295_data_0_w)
-	AM_RANGE(0x07, 0x07) AM_READ(OKIM6295_status_1_r) AM_WRITE(OKIM6295_data_1_w)
+	AM_RANGE(0x06, 0x06) AM_READ(okim6295_status_0_r) AM_WRITE(okim6295_data_0_w)
+	AM_RANGE(0x07, 0x07) AM_READ(okim6295_status_1_r) AM_WRITE(okim6295_data_1_w)
 ADDRESS_MAP_END
 
 /******************************************************************************/
@@ -812,8 +812,8 @@ static const gfx_layout tile_layout =
 };
 
 static GFXDECODE_START( djboy )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, tile_layout, 0x100, 16 ) /* sprite bank */
-	GFXDECODE_ENTRY( REGION_GFX2, 0, tile_layout, 0x000, 16 ) /* background tiles */
+	GFXDECODE_ENTRY( "gfx1", 0, tile_layout, 0x100, 16 ) /* sprite bank */
+	GFXDECODE_ENTRY( "gfx2", 0, tile_layout, 0x000, 16 ) /* background tiles */
 GFXDECODE_END
 
 /******************************************************************************/
@@ -822,34 +822,34 @@ static INTERRUPT_GEN( djboy_interrupt )
 { /* CPU1 uses interrupt mode 2. For now, just alternate the two interrupts. */
 	static int addr = 0xff;
 	addr ^= 0x02;
-	cpunum_set_input_line_and_vector(machine, 0, 0, HOLD_LINE, addr);
+	cpu_set_input_line_and_vector(device, 0, HOLD_LINE, addr);
 }
 
 static MACHINE_DRIVER_START( djboy )
-	MDRV_CPU_ADD(Z80,6000000)
+	MDRV_CPU_ADD("main", Z80,6000000)
 	MDRV_CPU_PROGRAM_MAP(cpu0_am,0)
 	MDRV_CPU_IO_MAP(cpu0_port_am,0)
-	MDRV_CPU_VBLANK_INT(djboy_interrupt,2)
+	MDRV_CPU_VBLANK_INT_HACK(djboy_interrupt,2)
 
-	MDRV_CPU_ADD(Z80,6000000)
+	MDRV_CPU_ADD("cpu1", Z80,6000000)
 	MDRV_CPU_PROGRAM_MAP(cpu1_am,0)
 	MDRV_CPU_IO_MAP(cpu1_port_am,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
-	MDRV_CPU_ADD(Z80, 6000000)
+	MDRV_CPU_ADD("cpu2", Z80, 6000000)
 	MDRV_CPU_PROGRAM_MAP(cpu2_am,0)
 	MDRV_CPU_IO_MAP(cpu2_port_am,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
+	MDRV_QUANTUM_TIME(HZ(6000))
+
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(100)
-
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-
 	MDRV_SCREEN_SIZE(256, 256)
 	MDRV_SCREEN_VISIBLE_AREA(0, 256-1, 16, 256-16-1)
+
 	MDRV_GFXDECODE(djboy)
 	MDRV_PALETTE_LENGTH(0x200)
 
@@ -859,110 +859,119 @@ static MACHINE_DRIVER_START( djboy )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_ADD("ym", YM2203, 3000000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
 
-	MDRV_SOUND_ADD(OKIM6295, 12000000 / 8)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7low)
+	MDRV_SOUND_ADD("oki1", OKIM6295, 12000000 / 8)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7low)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD(OKIM6295, 12000000 / 8)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7low)
+	MDRV_SOUND_ADD("oki2", OKIM6295, 12000000 / 8)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7low)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 ROM_START( djboy )
-	ROM_REGION( 0x48000, REGION_CPU1, 0 )
+	ROM_REGION( 0x48000, "main", 0 )
 	ROM_LOAD( "bs64.4b",  0x00000, 0x08000, CRC(b77aacc7) SHA1(78100d4695738a702f13807526eb1bcac759cce3) )
 	ROM_CONTINUE( 0x10000, 0x18000 )
 	ROM_LOAD( "bs100.4d", 0x28000, 0x20000, CRC(081e8af8) SHA1(3589dab1cf31b109a40370b4db1f31785023e2ed) )
 
-	ROM_REGION( 0x38000, REGION_CPU2, 0 )
+	ROM_REGION( 0x38000, "cpu1", 0 )
 	ROM_LOAD( "bs65.5y",  0x00000, 0x08000, CRC(0f1456eb) SHA1(62ed48c0d71c1fabbb3f6ada60381f57f692cef8) )
 	ROM_CONTINUE( 0x10000, 0x08000 )
 	ROM_LOAD( "bs101.6w", 0x18000, 0x20000, CRC(a7c85577) SHA1(8296b96d5f69f6c730b7ed77fa8c93496b33529c) )
 
-	ROM_REGION( 0x24000, REGION_CPU3, 0 ) /* sound */
+	ROM_REGION( 0x24000, "cpu2", 0 ) /* sound */
 	ROM_LOAD( "bs200.8c", 0x00000, 0x0c000, CRC(f6c19e51) SHA1(82193f71122df07cce0a7f057a87b89eb2d587a1) )
 	ROM_CONTINUE( 0x10000, 0x14000 )
 
-	ROM_REGION( 0x200000, REGION_GFX1, 0 ) /* sprites */
+	ROM_REGION( 0x200000, "gfx1", 0 ) /* sprites */
 	ROM_LOAD( "bs000.1h", 0x000000, 0x80000, CRC(be4bf805) SHA1(a73c564575fe89d26225ca8ec2d98b6ac319ac18) )
 	ROM_LOAD( "bs001.1f", 0x080000, 0x80000, CRC(fdf36e6b) SHA1(a8762458dfd5201304247c113ceb85e96e33d423) )
 	ROM_LOAD( "bs002.1d", 0x100000, 0x80000, CRC(c52fee7f) SHA1(bd33117f7a57899fd4ec0a77413107edd9c44629) )
 	ROM_LOAD( "bs003.1k", 0x180000, 0x80000, CRC(ed89acb4) SHA1(611af362606b73cd2cf501678b463db52dcf69c4) )
 	ROM_LOAD( "bs07.1b",  0x1f0000, 0x10000, CRC(d9b7a220) SHA1(ba3b528d50650c209c986268bb29b42ff1276eb2) )  // replaces last 0x200 tiles
 
-	ROM_REGION( 0x100000, REGION_GFX2, 0 ) /* background */
+	ROM_REGION( 0x100000, "gfx2", 0 ) /* background */
 	ROM_LOAD( "bs004.1s", 0x000000, 0x80000, CRC(2f1392c3) SHA1(1bc3030b3612766a02133eef0b4d20013c0495a4) )
 	ROM_LOAD( "bs005.1u", 0x080000, 0x80000, CRC(46b400c4) SHA1(35f4823364bbff1fc935994498d462bbd3bc6044) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 ) /* OKI-M6295 samples */
+	ROM_REGION( 0x40000, "oki1", 0 ) /* OKI-M6295 samples */
+	ROM_LOAD( "bs203.5j", 0x000000, 0x40000, CRC(805341fb) SHA1(fb94e400e2283aaa806814d5a39d6196457dc822) )
+
+	ROM_REGION( 0x40000, "oki2", 0 ) /* OKI-M6295 samples */
 	ROM_LOAD( "bs203.5j", 0x000000, 0x40000, CRC(805341fb) SHA1(fb94e400e2283aaa806814d5a39d6196457dc822) )
 ROM_END
 
 ROM_START( djboya )
-	ROM_REGION( 0x48000, REGION_CPU1, 0 )
+	ROM_REGION( 0x48000, "main", 0 )
 	ROM_LOAD( "bs19s.rom",  0x00000, 0x08000, CRC(17ce9f6c) SHA1(a0c1832b05dc46991e8949067ca0278f5498835f) )
 	ROM_CONTINUE( 0x10000, 0x18000 )
 	ROM_LOAD( "bs100.4d", 0x28000, 0x20000, CRC(081e8af8) SHA1(3589dab1cf31b109a40370b4db1f31785023e2ed) )
 
-	ROM_REGION( 0x38000, REGION_CPU2, 0 )
+	ROM_REGION( 0x38000, "cpu1", 0 )
 	ROM_LOAD( "bs15s.rom",  0x00000, 0x08000, CRC(e6f966b2) SHA1(f9df16035a8b09d87eb70315b216892e25d99b03) )
 	ROM_CONTINUE( 0x10000, 0x08000 )
 	ROM_LOAD( "bs101.6w", 0x18000, 0x20000, CRC(a7c85577) SHA1(8296b96d5f69f6c730b7ed77fa8c93496b33529c) )
 
-	ROM_REGION( 0x24000, REGION_CPU3, 0 ) /* sound */
+	ROM_REGION( 0x24000, "cpu2", 0 ) /* sound */
 	ROM_LOAD( "bs200.8c", 0x00000, 0x0c000, CRC(f6c19e51) SHA1(82193f71122df07cce0a7f057a87b89eb2d587a1) )
 	ROM_CONTINUE( 0x10000, 0x14000 )
 
-	ROM_REGION( 0x200000, REGION_GFX1, 0 ) /* sprites */
+	ROM_REGION( 0x200000, "gfx1", 0 ) /* sprites */
 	ROM_LOAD( "bs000.1h", 0x000000, 0x80000, CRC(be4bf805) SHA1(a73c564575fe89d26225ca8ec2d98b6ac319ac18) )
 	ROM_LOAD( "bs001.1f", 0x080000, 0x80000, CRC(fdf36e6b) SHA1(a8762458dfd5201304247c113ceb85e96e33d423) )
 	ROM_LOAD( "bs002.1d", 0x100000, 0x80000, CRC(c52fee7f) SHA1(bd33117f7a57899fd4ec0a77413107edd9c44629) )
 	ROM_LOAD( "bs003.1k", 0x180000, 0x80000, CRC(ed89acb4) SHA1(611af362606b73cd2cf501678b463db52dcf69c4) )
 	ROM_LOAD( "bs07.1b",  0x1f0000, 0x10000, CRC(d9b7a220) SHA1(ba3b528d50650c209c986268bb29b42ff1276eb2) )  // replaces last 0x200 tiles
 
-	ROM_REGION( 0x100000, REGION_GFX2, 0 ) /* background */
+	ROM_REGION( 0x100000, "gfx2", 0 ) /* background */
 	ROM_LOAD( "bs004.1s", 0x000000, 0x80000, CRC(2f1392c3) SHA1(1bc3030b3612766a02133eef0b4d20013c0495a4) )
 	ROM_LOAD( "bs005.1u", 0x080000, 0x80000, CRC(46b400c4) SHA1(35f4823364bbff1fc935994498d462bbd3bc6044) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 ) /* OKI-M6295 samples */
+	ROM_REGION( 0x40000, "oki1", 0 ) /* OKI-M6295 samples */
+	ROM_LOAD( "bs203.5j", 0x000000, 0x40000, CRC(805341fb) SHA1(fb94e400e2283aaa806814d5a39d6196457dc822) )
+
+	ROM_REGION( 0x40000, "oki2", 0 ) /* OKI-M6295 samples */
 	ROM_LOAD( "bs203.5j", 0x000000, 0x40000, CRC(805341fb) SHA1(fb94e400e2283aaa806814d5a39d6196457dc822) )
 ROM_END
 
 ROM_START( djboyj )
-	ROM_REGION( 0x48000, REGION_CPU1, 0 )
+	ROM_REGION( 0x48000, "main", 0 )
 	ROM_LOAD( "bs12.4b",  0x00000, 0x08000, CRC(0971523e) SHA1(f90cd02cedf8632f4b651de7ea75dc8c0e682f6e) )
 	ROM_CONTINUE( 0x10000, 0x18000 )
 	ROM_LOAD( "bs100.4d", 0x28000, 0x20000, CRC(081e8af8) SHA1(3589dab1cf31b109a40370b4db1f31785023e2ed) )
 
-	ROM_REGION( 0x38000, REGION_CPU2, 0 )
+	ROM_REGION( 0x38000, "cpu1", 0 )
 	ROM_LOAD( "bs13.5y",  0x00000, 0x08000, CRC(5c3f2f96) SHA1(bb7ee028a2d8d3c76a78a29fba60bcc36e9399f5) )
 	ROM_CONTINUE( 0x10000, 0x08000 )
 	ROM_LOAD( "bs101.6w", 0x18000, 0x20000, CRC(a7c85577) SHA1(8296b96d5f69f6c730b7ed77fa8c93496b33529c) )
 
-	ROM_REGION( 0x24000, REGION_CPU3, 0 ) /* sound */
+	ROM_REGION( 0x24000, "cpu2", 0 ) /* sound */
 	ROM_LOAD( "bs200.8c", 0x00000, 0x0c000, CRC(f6c19e51) SHA1(82193f71122df07cce0a7f057a87b89eb2d587a1) )
 	ROM_CONTINUE( 0x10000, 0x14000 )
 
-	ROM_REGION( 0x200000, REGION_GFX1, 0 ) /* sprites */
+	ROM_REGION( 0x200000, "gfx1", 0 ) /* sprites */
 	ROM_LOAD( "bs000.1h", 0x000000, 0x80000, CRC(be4bf805) SHA1(a73c564575fe89d26225ca8ec2d98b6ac319ac18) )
 	ROM_LOAD( "bs001.1f", 0x080000, 0x80000, CRC(fdf36e6b) SHA1(a8762458dfd5201304247c113ceb85e96e33d423) )
 	ROM_LOAD( "bs002.1d", 0x100000, 0x80000, CRC(c52fee7f) SHA1(bd33117f7a57899fd4ec0a77413107edd9c44629) )
 	ROM_LOAD( "bs003.1k", 0x180000, 0x80000, CRC(ed89acb4) SHA1(611af362606b73cd2cf501678b463db52dcf69c4) )
 	ROM_LOAD( "bsxx.1b",  0x1f0000, 0x10000, CRC(22c8aa08) SHA1(5521c9d73b4ee82a2de1992d6edc7ef62788ad72) ) // replaces last 0x200 tiles
 
-	ROM_REGION( 0x100000, REGION_GFX2, 0 ) /* background */
+	ROM_REGION( 0x100000, "gfx2", 0 ) /* background */
 	ROM_LOAD( "bs004.1s", 0x000000, 0x80000, CRC(2f1392c3) SHA1(1bc3030b3612766a02133eef0b4d20013c0495a4) )
 	ROM_LOAD( "bs005.1u", 0x080000, 0x80000, CRC(46b400c4) SHA1(35f4823364bbff1fc935994498d462bbd3bc6044) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 ) /* OKI-M6295 samples */
+	ROM_REGION( 0x40000, "oki1", 0 ) /* OKI-M6295 samples */
+	ROM_LOAD( "bs-204.5j", 0x000000, 0x40000, CRC(510244f0) SHA1(afb502d46d268ad9cd209ae1da72c50e4e785626) )
+
+	ROM_REGION( 0x40000, "oki2", 0 ) /* OKI-M6295 samples */
 	ROM_LOAD( "bs-204.5j", 0x000000, 0x40000, CRC(510244f0) SHA1(afb502d46d268ad9cd209ae1da72c50e4e785626) )
 ROM_END
 
 static INPUT_PORTS_START( djboy )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN1 )
@@ -972,7 +981,7 @@ static INPUT_PORTS_START( djboy )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_SERVICE )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
@@ -982,7 +991,7 @@ static INPUT_PORTS_START( djboy )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) /* jump */
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
@@ -992,7 +1001,7 @@ static INPUT_PORTS_START( djboy )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("DSW1")
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
@@ -1016,7 +1025,7 @@ static INPUT_PORTS_START( djboy )
 	PORT_DIPSETTING(    0xc0, DEF_STR( 2C_3C ) )
 	PORT_DIPSETTING(    0x40, DEF_STR( 1C_2C ) )
 
-	PORT_START
+	PORT_START("DSW2")
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Easy ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Normal ) )
