@@ -50,7 +50,7 @@ Notes:
 *********************************************************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
 #include "sound/ay8910.h"
 #include "sound/okim6295.h"
 #include "sound/2413intf.h"
@@ -94,11 +94,11 @@ static TILE_GET_INFO( get_tile_info2 )
 
 static VIDEO_START(dunhuang)
 {
-	tmap = tilemap_create(	get_tile_info, tilemap_scan_rows,
-							TILEMAP_TYPE_PEN, 8,8, 0x40,0x20	);
+	tmap = tilemap_create(	machine, get_tile_info, tilemap_scan_rows,
+							8,8, 0x40,0x20	);
 
-	tmap2 = tilemap_create(	get_tile_info2, tilemap_scan_rows,
-							TILEMAP_TYPE_PEN, 8,32, 0x40,0x8	);
+	tmap2 = tilemap_create(	machine, get_tile_info2, tilemap_scan_rows,
+							8,32, 0x40,0x8	);
 
 	tilemap_set_transparent_pen(tmap,   0);
 	tilemap_set_transparent_pen(tmap2,  0);
@@ -126,7 +126,7 @@ if (input_code_pressed(KEYCODE_Z))
 }
 #endif
 
-	fillbitmap(bitmap,get_black_pen(machine),cliprect);
+	bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
 
 	switch (dunhuang_layers)
 	{
@@ -213,7 +213,7 @@ static WRITE8_HANDLER( dunhuang_clear_y_w )
 static WRITE8_HANDLER( dunhuang_horiz_clear_w )
 {
 	int i;
-//  logerror("%06x: horiz clear, y = %02x, data = %02d\n", activecpu_get_pc(), dunhuang_clear_y,data);
+//  logerror("%06x: horiz clear, y = %02x, data = %02d\n", cpu_get_pc(space->cpu), dunhuang_clear_y,data);
 	for (i = 0; i < 0x40; i++)
 	{
 		int addr = dunhuang_clear_y * 0x40 + i;
@@ -229,7 +229,7 @@ static WRITE8_HANDLER( dunhuang_horiz_clear_w )
 static WRITE8_HANDLER( dunhuang_vert_clear_w )
 {
 	int i;
-//  logerror("%06x: vert clear, x = %02x, y = %02x, data = %02x\n", activecpu_get_pc(), dunhuang_pos_x,dunhuang_pos_y,data);
+//  logerror("%06x: vert clear, x = %02x, y = %02x, data = %02x\n", cpu_get_pc(space->cpu), dunhuang_pos_x,dunhuang_pos_y,data);
 	for (i = 0; i < 0x08; i++)
 	{
 		int addr = (dunhuang_pos_x & 0x3f) + (i & 0x07) * 0x40;
@@ -259,11 +259,11 @@ static WRITE8_HANDLER( dunhuang_block_h_w )
 	int i,j, addr;
 	UINT8 *tile_addr;
 
-//  logerror("%06x: block dst %x, src %x, xy %x %x, wh %x %x, clr %x\n", activecpu_get_pc(), dunhuang_block_dest, (dunhuang_block_addr_hi << 8) + dunhuang_block_addr_lo, dunhuang_block_x,dunhuang_block_y,dunhuang_block_w+1,dunhuang_block_h+1,dunhuang_block_c);
+//  logerror("%06x: block dst %x, src %x, xy %x %x, wh %x %x, clr %x\n", cpu_get_pc(space->cpu), dunhuang_block_dest, (dunhuang_block_addr_hi << 8) + dunhuang_block_addr_lo, dunhuang_block_x,dunhuang_block_y,dunhuang_block_w+1,dunhuang_block_h+1,dunhuang_block_c);
 
 	dunhuang_block_h = data;
 
-	tile_addr = memory_region(REGION_GFX2) + ((dunhuang_block_addr_hi << 8) + dunhuang_block_addr_lo)*4;
+	tile_addr = memory_region(space->machine, "gfx2") + ((dunhuang_block_addr_hi << 8) + dunhuang_block_addr_lo)*4;
 
 	switch (dunhuang_block_dest)
 	{
@@ -298,7 +298,7 @@ static WRITE8_HANDLER( dunhuang_block_h_w )
 			break;
 
 		default:
-			popmessage("%06x: block dst=%x", activecpu_get_pc(), dunhuang_block_dest);
+			popmessage("%06x: block dst=%x", cpu_get_pc(space->cpu), dunhuang_block_dest);
 	}
 }
 
@@ -310,7 +310,7 @@ static WRITE8_HANDLER( dunhuang_paldata_w )
 {
 	dunhuang_paldata[dunhuang_paloffs] = data;
 
-	palette_set_color_rgb( Machine, dunhuang_paloffs/3,
+	palette_set_color_rgb( space->machine, dunhuang_paloffs/3,
 		pal6bit(dunhuang_paldata[(dunhuang_paloffs/3)*3+0]),
 		pal6bit(dunhuang_paldata[(dunhuang_paloffs/3)*3+1]),
 		pal6bit(dunhuang_paldata[(dunhuang_paloffs/3)*3+2])
@@ -334,7 +334,7 @@ static WRITE8_HANDLER( dunhuang_layers_w )
 static ADDRESS_MAP_START( dunhuang_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE( 0x0000, 0x5fff ) AM_ROM
 	AM_RANGE( 0x6000, 0x7fff ) AM_RAM
-	AM_RANGE( 0x8000, 0xffff ) AM_READ( MRA8_BANK1 )
+	AM_RANGE( 0x8000, 0xffff ) AM_READ( SMH_BANK1 )
 ADDRESS_MAP_END
 
 // Inputs
@@ -345,37 +345,37 @@ static UINT8 dunhuang_hopper;
 static WRITE8_HANDLER( dunhuang_input_w )	{	dunhuang_input = data;	}
 static READ8_HANDLER( dunhuang_service_r )
 {
-	return readinputport(5)
-	 | ((dunhuang_hopper && !(cpu_getcurrentframe()%10)) ? 0x00 : 0x08)	// bit 3: hopper sensor
+	return input_port_read(space->machine, "SERVICE")
+	 | ((dunhuang_hopper && !(video_screen_get_frame_number(space->machine->primary_screen)%10)) ? 0x00 : 0x08)	// bit 3: hopper sensor
 	 | 0x80																// bit 7 low -> tiles block transferrer busy
 	;
 }
 
 static READ8_HANDLER( dunhuang_dsw_r )
 {
-	if (!(dunhuang_input & 0x01))	return readinputport(0);
-	if (!(dunhuang_input & 0x02))	return readinputport(1);
-	if (!(dunhuang_input & 0x04))	return readinputport(2);
-	if (!(dunhuang_input & 0x08))	return readinputport(3);
-	if (!(dunhuang_input & 0x10))	return readinputport(4);
-	logerror("%06x: warning, unknown dsw bits read, dunhuang_input = %02x\n", activecpu_get_pc(), dunhuang_input);
+	if (!(dunhuang_input & 0x01))	return input_port_read(space->machine, "DSW1");
+	if (!(dunhuang_input & 0x02))	return input_port_read(space->machine, "DSW2");
+	if (!(dunhuang_input & 0x04))	return input_port_read(space->machine, "DSW3");
+	if (!(dunhuang_input & 0x08))	return input_port_read(space->machine, "DSW4");
+	if (!(dunhuang_input & 0x10))	return input_port_read(space->machine, "DSW5");
+	logerror("%06x: warning, unknown dsw bits read, dunhuang_input = %02x\n", cpu_get_pc(space->cpu), dunhuang_input);
 	return 0xff;
 }
 static READ8_HANDLER( dunhuang_input_r )
 {
-	if (!(dunhuang_input & 0x01))	return readinputport(6);
-	if (!(dunhuang_input & 0x02))	return readinputport(7);
-	if (!(dunhuang_input & 0x04))	return readinputport(8);
-	if (!(dunhuang_input & 0x08))	return readinputport(9);
-	if (!(dunhuang_input & 0x10))	return readinputport(10);
-	logerror("%06x: warning, unknown input bits read, dunhuang_input = %02x\n", activecpu_get_pc(), dunhuang_input);
+	if (!(dunhuang_input & 0x01))	return input_port_read(space->machine, "IN0");
+	if (!(dunhuang_input & 0x02))	return input_port_read(space->machine, "IN1");
+	if (!(dunhuang_input & 0x04))	return input_port_read(space->machine, "IN2");
+	if (!(dunhuang_input & 0x08))	return input_port_read(space->machine, "IN3");
+	if (!(dunhuang_input & 0x10))	return input_port_read(space->machine, "IN4");
+	logerror("%06x: warning, unknown input bits read, dunhuang_input = %02x\n", cpu_get_pc(space->cpu), dunhuang_input);
 	return 0xff;
 }
 
 static WRITE8_HANDLER( dunhuang_rombank_w )
 {
-	UINT8 *rom = memory_region(REGION_CPU1);
-	memory_set_bankptr( 1, rom + 0x10000 + 0x8000 * ((data >> 2) & 0x7) );
+	UINT8 *rom = memory_region(space->machine, "main");
+	memory_set_bankptr(space->machine,  1, rom + 0x10000 + 0x8000 * ((data >> 2) & 0x7) );
 
 	// ?                data & 0x01
 	// ?                data & 0x02
@@ -417,8 +417,8 @@ static ADDRESS_MAP_START( dunhuang_io_map, ADDRESS_SPACE_IO, 8 )
 
 	AM_RANGE( 0x001b, 0x001b ) AM_WRITE( dunhuang_block_dest_w )
 
-	AM_RANGE( 0x0081, 0x0081 ) AM_WRITE( YM2413_register_port_0_w	)
-	AM_RANGE( 0x0089, 0x0089 ) AM_WRITE( YM2413_data_port_0_w		)
+	AM_RANGE( 0x0081, 0x0081 ) AM_WRITE( ym2413_register_port_0_w	)
+	AM_RANGE( 0x0089, 0x0089 ) AM_WRITE( ym2413_data_port_0_w		)
 
 //  AM_RANGE( 0x0082, 0x0082 ) AM_WRITE( dunhuang_82_w )
 
@@ -431,9 +431,9 @@ static ADDRESS_MAP_START( dunhuang_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE( 0x0086, 0x0086 ) AM_WRITE( dunhuang_rombank_w )
 	AM_RANGE( 0x0087, 0x0087 ) AM_WRITE( dunhuang_layers_w )
 
-	AM_RANGE( 0x0088, 0x0088 ) AM_READ( AY8910_read_port_0_r )
-	AM_RANGE( 0x0090, 0x0090 ) AM_WRITE( AY8910_write_port_0_w )
-	AM_RANGE( 0x0098, 0x0098 ) AM_WRITE( AY8910_control_port_0_w )
+	AM_RANGE( 0x0088, 0x0088 ) AM_READ( ay8910_read_port_0_r )
+	AM_RANGE( 0x0090, 0x0090 ) AM_WRITE( ay8910_write_port_0_w )
+	AM_RANGE( 0x0098, 0x0098 ) AM_WRITE( ay8910_control_port_0_w )
 ADDRESS_MAP_END
 
 
@@ -443,7 +443,7 @@ ADDRESS_MAP_END
 ***************************************************************************/
 
 static INPUT_PORTS_START( dunhuang )
-	PORT_START	// IN0 - DSW1
+	PORT_START("DSW1")		/* IN0 - DSW1 */
 	PORT_DIPNAME( 0x0f, 0x0f, "Main Game Chance (%)" )	PORT_DIPLOCATION("SW1:1,2,3,4")
 	PORT_DIPSETTING(    0x00, "78" )
 	PORT_DIPSETTING(    0x01, "80" )
@@ -473,7 +473,7 @@ static INPUT_PORTS_START( dunhuang )
 	PORT_DIPSETTING(    0x80, "Keys" )
 	PORT_DIPSETTING(    0x00, "Payout" )
 
-	PORT_START	// IN1 - DSW2
+	PORT_START("DSW2")		/* IN1 - DSW2 */
 	PORT_DIPUNKNOWN_DIPLOC( 0x01, 0x01, "SW2:1" )
 	PORT_DIPNAME( 0x06, 0x06, "Credits Per Coin" )		PORT_DIPLOCATION("SW2:2,3")
 	PORT_DIPSETTING(    0x06, "1" )
@@ -494,7 +494,7 @@ static INPUT_PORTS_START( dunhuang )
 	PORT_DIPSETTING(    0x80, "1000" )
 	PORT_DIPSETTING(    0xc0, "3000" )
 
-	PORT_START	// IN2 - DSW3
+	PORT_START("DSW3")		/* IN2 - DSW3 */
 	PORT_DIPNAME( 0x03, 0x03, "Min Bet" )				PORT_DIPLOCATION("SW3:1,2")
 	PORT_DIPSETTING(    0x03, "1" )
 	PORT_DIPSETTING(    0x02, "2" )
@@ -516,7 +516,7 @@ static INPUT_PORTS_START( dunhuang )
 	PORT_DIPSETTING(    0x80, "5" )
 	PORT_DIPSETTING(    0xc0, "6" )
 
-	PORT_START	// IN3 - DSW4
+	PORT_START("DSW4")		/* IN3 - DSW4 */
 	PORT_DIPNAME( 0x07, 0x07, "Credits Limit" )			PORT_DIPLOCATION("SW4:1,2,3")
 	PORT_DIPSETTING(    0x07, "2k" )
 	PORT_DIPSETTING(    0x06, "3k" )
@@ -542,7 +542,7 @@ static INPUT_PORTS_START( dunhuang )
 	PORT_DIPSETTING(    0x00, DEF_STR( No ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( Yes ) )
 
-	PORT_START	// IN4 - DSW5
+	PORT_START("DSW5")		/* IN4 - DSW5 */
 	PORT_DIPNAME( 0x03, 0x03, "Douple Up Chance (%)" )	PORT_DIPLOCATION("SW5:1,2")
 	PORT_DIPSETTING(    0x00, "50" )
 	PORT_DIPSETTING(    0x01, "60" )
@@ -566,7 +566,7 @@ static INPUT_PORTS_START( dunhuang )
 	PORT_DIPSETTING(    0x80, "Strong" )
 	PORT_DIPSETTING(    0x00, "Weak" )
 
-	PORT_START	// IN5 - SERVICE
+	PORT_START("SERVICE")		/* IN5 - SERVICE */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW,  IPT_SERVICE3 )		// clear (during boot)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW,  IPT_SERVICE2 )		// book
 	PORT_BIT( 0x04, IP_ACTIVE_LOW,  IPT_SERVICE  )		// test (in game: dips, during boot: service mode)
@@ -576,7 +576,7 @@ static INPUT_PORTS_START( dunhuang )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_SPECIAL )		// 0 = tiles block transferrer busy
 
-	PORT_START	// IN6 - P1
+	PORT_START("IN0")		/* IN6 - P1 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_MAHJONG_A )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_E )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_I )
@@ -586,7 +586,7 @@ static INPUT_PORTS_START( dunhuang )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN7 - P1
+	PORT_START("IN1")		/* IN7 - P1 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_MAHJONG_B )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_F )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_J )
@@ -596,7 +596,7 @@ static INPUT_PORTS_START( dunhuang )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN8 - P1
+	PORT_START("IN2")		/* IN8 - P1 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_MAHJONG_C )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_G )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_K )
@@ -606,7 +606,7 @@ static INPUT_PORTS_START( dunhuang )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN9 - P1
+	PORT_START("IN3")		/* IN9 - P1 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_MAHJONG_D )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_H )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_L )
@@ -616,7 +616,7 @@ static INPUT_PORTS_START( dunhuang )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN10 - P1
+	PORT_START("IN4")		/* IN10 - P1 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_MAHJONG_LAST_CHANCE	)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_SCORE )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_DOUBLE_UP )
@@ -655,8 +655,8 @@ static const gfx_layout layout_8x32 =
 };
 
 static GFXDECODE_START( dunhuang )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, layout_8x8,  0, 16 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0, layout_8x32, 0, 16 )
+	GFXDECODE_ENTRY( "gfx1", 0, layout_8x8,  0, 16 )
+	GFXDECODE_ENTRY( "gfx2", 0, layout_8x32, 0, 16 )
 GFXDECODE_END
 
 
@@ -664,29 +664,32 @@ GFXDECODE_END
                                 Machine Drivers
 ***************************************************************************/
 
-static const struct AY8910interface dunhuang_ay8910_interface =
+static const ay8910_interface dunhuang_ay8910_interface =
 {
-//  A                   B
-	0,					dunhuang_dsw_r,	// R
-	dunhuang_input_w,	0				// W
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
+	//  A                   B
+	NULL,					dunhuang_dsw_r,	// R
+	dunhuang_input_w,		NULL			// W
 };
 
 static MACHINE_DRIVER_START( dunhuang )
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80,12000000/2)
+	MDRV_CPU_ADD("main", Z80,12000000/2)
 	MDRV_CPU_PROGRAM_MAP(dunhuang_map,0)
 	MDRV_CPU_IO_MAP(dunhuang_io_map,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_WATCHDOG_TIME_INIT(ATTOTIME_IN_SEC(5))
+	MDRV_WATCHDOG_TIME_INIT(SEC(5))
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(512, 256)
 	MDRV_SCREEN_VISIBLE_AREA(0+8, 512-8-1, 0+16, 256-16-1)
+
 	MDRV_GFXDECODE(dunhuang)
 	MDRV_PALETTE_LENGTH(0x100)
 
@@ -696,15 +699,15 @@ static MACHINE_DRIVER_START( dunhuang )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM2413, 3579545)
+	MDRV_SOUND_ADD("ym", YM2413, 3579545)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
 
-	MDRV_SOUND_ADD_TAG("ay8910", AY8910, 12000000/8)
+	MDRV_SOUND_ADD("ay8910", AY8910, 12000000/8)
 	MDRV_SOUND_CONFIG(dunhuang_ay8910_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 
-	MDRV_SOUND_ADD(OKIM6295, 12000000/8)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high)
+	MDRV_SOUND_ADD("oki", OKIM6295, 12000000/8)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
 MACHINE_DRIVER_END
 
@@ -714,19 +717,19 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( dunhuang )
-	ROM_REGION( 0x50000, REGION_CPU1, 0 )
+	ROM_REGION( 0x50000, "main", 0 )
 	ROM_LOAD( "rom1.u9", 0x00000, 0x40000, CRC(843a0117) SHA1(26a838cb3552ea6a9ec55940fcbf83b06c068743) )
 	ROM_RELOAD(          0x10000, 0x40000 )
 
-	ROM_REGION( 0xc0000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0xc0000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "rom3.u4", 0x00000, 0x80000, CRC(1ff5d35e) SHA1(b808eb4f81be8fc77a58dadd661a9cc2b376a509) )
 	ROM_LOAD( "rom2.u5", 0x80000, 0x40000, CRC(384fa1d3) SHA1(f329db17aacacf1768ebd6ca2cc612503db93fac) )
 
-	ROM_REGION( 0xc0000, REGION_GFX2, 0 )	// do not dispose
+	ROM_REGION( 0xc0000, "gfx2", 0 )	// do not dispose
 	ROM_LOAD( "rom4.u3", 0x00000, 0x40000, CRC(7db45227) SHA1(2a12a2b8a1e58946ce3e7c770b3ca4803c3c3ccd) )
 	ROM_LOAD( "rom5.u2", 0x40000, 0x80000, CRC(d609880e) SHA1(3d69800e959e8f24ef950fea4312610c4407f6ba) )
 
-	ROM_REGION( 0x20000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x20000, "oki", 0 )
 	ROM_LOAD( "rom6.u1", 0x00000, 0x20000, CRC(31cfdc29) SHA1(725249eae9227eadf05418b799e0da0254bb2f51) )
 ROM_END
 
