@@ -19,6 +19,8 @@ TODO:
 *********************************************************************/
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
+#include "cpu/i8085/i8085.h"
 #include "deprecat.h"
 #include "sound/ay8910.h"
 
@@ -86,7 +88,7 @@ INLINE int vysnc_chain_counter_to_vpos(UINT16 counter)
 
 static TIMER_CALLBACK( interrupt_clear_callback )
 {
-	cpunum_set_input_line(machine, 0, 0, CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], 0, CLEAR_LINE);
 }
 
 
@@ -96,10 +98,10 @@ static TIMER_CALLBACK( interrupt_assert_callback )
 	int next_vpos;
 
 	/* compute vector and set the interrupt line */
-	int vpos = video_screen_get_vpos(0);
+	int vpos = video_screen_get_vpos(machine->primary_screen);
 	UINT16 counter = vpos_to_vysnc_chain_counter(vpos);
 	UINT8 vector = 0xc7 | ((counter & 0x80) >> 3) | ((~counter & 0x80) >> 4);
-	cpunum_set_input_line_and_vector(machine, 0, 0, ASSERT_LINE, vector);
+	cpu_set_input_line_and_vector(machine->cpu[0], 0, ASSERT_LINE, vector);
 
 	/* set up for next interrupt */
 	if (counter == INT_TRIGGER_COUNT_1)
@@ -108,40 +110,40 @@ static TIMER_CALLBACK( interrupt_assert_callback )
 		next_counter = INT_TRIGGER_COUNT_1;
 
 	next_vpos = vysnc_chain_counter_to_vpos(next_counter);
-	timer_adjust(interrupt_assert_timer, video_screen_get_time_until_pos(0, next_vpos, 0), 0, attotime_zero);
-	timer_adjust(interrupt_clear_timer, video_screen_get_time_until_pos(0, vpos + 1, 0), 0, attotime_zero);
+	timer_adjust_oneshot(interrupt_assert_timer, video_screen_get_time_until_pos(machine->primary_screen, next_vpos, 0), 0);
+	timer_adjust_oneshot(interrupt_clear_timer, video_screen_get_time_until_pos(machine->primary_screen, vpos + 1, 0), 0);
 }
 
 
-static void create_interrupt_timers(void)
+static void create_interrupt_timers(running_machine *machine)
 {
-	interrupt_clear_timer = timer_alloc(interrupt_clear_callback, NULL);
-	interrupt_assert_timer = timer_alloc(interrupt_assert_callback, NULL);
+	interrupt_clear_timer = timer_alloc(machine, interrupt_clear_callback, NULL);
+	interrupt_assert_timer = timer_alloc(machine, interrupt_assert_callback, NULL);
 }
 
 
-static void start_interrupt_timers(void)
+static void start_interrupt_timers(running_machine *machine)
 {
 	int vpos = vysnc_chain_counter_to_vpos(INT_TRIGGER_COUNT_1);
-	timer_adjust(interrupt_assert_timer, video_screen_get_time_until_pos(0, vpos, 0), 0, attotime_zero);
+	timer_adjust_oneshot(interrupt_assert_timer, video_screen_get_time_until_pos(machine->primary_screen, vpos, 0), 0);
 }
 
 
 
 static MACHINE_START( enigma2 )
 {
-	create_interrupt_timers();
+	create_interrupt_timers(machine);
 }
 
 
 static MACHINE_RESET( enigma2 )
 {
 	last_sound_data = 0;
-	cpunum_set_input_line(machine, 1, INPUT_LINE_NMI, CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[1], INPUT_LINE_NMI, CLEAR_LINE);
 
 	engima2_flip_screen = 0;
 
-	start_interrupt_timers();
+	start_interrupt_timers(machine);
 }
 
 
@@ -169,11 +171,13 @@ static VIDEO_UPDATE( enigma2 )
 
 	pen_t pens[NUM_PENS];
 
-	UINT8 *color_map_base = engima2_flip_screen ? &memory_region(REGION_PROMS)[0x0400] : memory_region(REGION_PROMS);
-	UINT8 *star_map_base = (blink_count & 0x08) ? &memory_region(REGION_PROMS)[0x0c00] : &memory_region(REGION_PROMS)[0x0800];
+	const rectangle *visarea = video_screen_get_visible_area(screen);
+	UINT8 *prom = memory_region(screen->machine, "proms");
+	UINT8 *color_map_base = engima2_flip_screen ? &prom[0x0400] : &prom[0x0000];
+	UINT8 *star_map_base = (blink_count & 0x08) ? &prom[0x0c00] : &prom[0x0800];
 
 	UINT8 x = 0;
-	UINT16 bitmap_y = machine->screen[screen].visarea.min_y;
+	UINT16 bitmap_y = visarea->min_y;
 	UINT8 y = (UINT8)vpos_to_vysnc_chain_counter(bitmap_y);
 	UINT8 video_data = 0;
 	UINT8 fore_color = 0;
@@ -192,8 +196,8 @@ static VIDEO_UPDATE( enigma2 )
 			offs_t color_map_address = (y >> 3 << 5) | (x >> 3);
 			/* the schematics shows it like this, but it doesn't work as this would
                produce no stars, due to the contents of the PROM -- maybe there is
-               a star disabled bit somewhere that's connected here instead of flip_screen */
-			/* star_map_address = (y >> 4 << 6) | (engima2_flip_screen << 5) | (x >> 3); */
+               a star disabled bit somewhere that's connected here instead of flip_screen_get(screen->machine) */
+			/* star_map_address = (y >> 4 << 6) | (engima2_flip_screen_get() << 5) | (x >> 3); */
 			offs_t star_map_address = (y >> 4 << 6) | 0x20 | (x >> 3);
 
 			offs_t videoram_address = (y << 5) | (x >> 3);
@@ -235,10 +239,8 @@ static VIDEO_UPDATE( enigma2 )
 		if (x == 0)
 		{
 			/* end of screen? */
-			if (bitmap_y == machine->screen[screen].visarea.max_y)
-			{
+			if (bitmap_y == visarea->max_y)
 				break;
-			}
 
 			/* next row */
 			y = y + 1;
@@ -255,7 +257,8 @@ static VIDEO_UPDATE( enigma2 )
 static VIDEO_UPDATE( enigma2a )
 {
 	UINT8 x = 0;
-	UINT16 bitmap_y = machine->screen[screen].visarea.min_y;
+	const rectangle *visarea = video_screen_get_visible_area(screen);
+	UINT16 bitmap_y = visarea->min_y;
 	UINT8 y = (UINT8)vpos_to_vysnc_chain_counter(bitmap_y);
 	UINT8 video_data = 0;
 
@@ -298,10 +301,8 @@ static VIDEO_UPDATE( enigma2a )
 		if (x == 0)
 		{
 			/* end of screen? */
-			if (bitmap_y == machine->screen[screen].visarea.max_y)
-			{
+			if (bitmap_y == visarea->max_y)
 				break;
-			}
 
 			/* next row */
 			y = y + 1;
@@ -318,18 +319,18 @@ static READ8_HANDLER( dip_switch_r )
 {
 	UINT8 ret = 0x00;
 
-if (LOG_PROT) logerror("DIP SW Read: %x at %x (prot data %x)\n", offset, activecpu_get_pc(), protection_data);
+if (LOG_PROT) logerror("DIP SW Read: %x at %x (prot data %x)\n", offset, cpu_get_pc(space->cpu), protection_data);
 	switch (offset)
 	{
 	case 0x01:
 		if (protection_data != 0xff)
 			ret = protection_data ^ 0x88;
 		else
-			ret = readinputport(2);
+			ret = input_port_read(space->machine, "DSW");
 		break;
 
 	case 0x02:
-		if (activecpu_get_pc() == 0x07e5)
+		if (cpu_get_pc(space->cpu) == 0x07e5)
 			ret = 0xaa;
 		else
 			ret = 0xf4;
@@ -350,7 +351,7 @@ static WRITE8_HANDLER( sound_data_w )
 	if (!(data & 0x04) && (last_sound_data & 0x04))
 		sound_latch = (sound_latch << 1) | (~data & 0x01);
 
-	cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, (data & 0x02) ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_NMI, (data & 0x02) ? ASSERT_LINE : CLEAR_LINE);
 
 	last_sound_data = data;
 }
@@ -364,35 +365,37 @@ static READ8_HANDLER( sound_latch_r )
 
 static WRITE8_HANDLER( protection_data_w )
 {
-if (LOG_PROT) logerror("Protection Data Write: %x at %x\n", data, safe_activecpu_get_pc());
+if (LOG_PROT) logerror("Protection Data Write: %x at %x\n", data, cpu_get_pc(space->cpu));
 	protection_data = data;
 }
 
 
 static WRITE8_HANDLER( enigma2_flip_screen_w )
 {
-	engima2_flip_screen = ((data >> 5) & 0x01) && ((readinputport(2) & 0x20) == 0x20);
+	engima2_flip_screen = ((data >> 5) & 0x01) && ((input_port_read(space->machine, "DSW") & 0x20) == 0x20);
 }
 
 
 static CUSTOM_INPUT( p1_controls_r )
 {
-	return readinputportbytag("P1CONTROLS");
+	return input_port_read(field->port->machine, "P1CONTROLS");
 }
 
 
 static CUSTOM_INPUT( p2_controls_r )
 {
 	if (engima2_flip_screen)
-		return readinputportbytag("P2CONTROLS");
+		return input_port_read(field->port->machine, "P2CONTROLS");
 	else
-		return readinputportbytag("P1CONTROLS");
+		return input_port_read(field->port->machine, "P1CONTROLS");
 }
 
 
 
-static const struct AY8910interface ay8910_interface =
+static const ay8910_interface ay8910_config =
 {
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
 	sound_latch_r,
 	0,
 	0,
@@ -402,17 +405,17 @@ static const struct AY8910interface ay8910_interface =
 
 
 static ADDRESS_MAP_START( engima2_main_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(15) )
+	ADDRESS_MAP_GLOBAL_MASK(0x7fff)
 	AM_RANGE(0x0000, 0x1fff) AM_ROM AM_WRITENOP
 	AM_RANGE(0x2000, 0x3fff) AM_MIRROR(0x4000) AM_RAM AM_BASE(&enigma2_ram)
 	AM_RANGE(0x4000, 0x4fff) AM_ROM AM_WRITENOP
-	AM_RANGE(0x5000, 0x57ff) AM_READWRITE(dip_switch_r, MWA8_NOP)
+	AM_RANGE(0x5000, 0x57ff) AM_READWRITE(dip_switch_r, SMH_NOP)
 	AM_RANGE(0x5800, 0x5800) AM_MIRROR(0x07f8) AM_NOP
-	AM_RANGE(0x5801, 0x5801) AM_MIRROR(0x07f8) AM_READWRITE(input_port_0_r, MWA8_NOP)
-	AM_RANGE(0x5802, 0x5802) AM_MIRROR(0x07f8) AM_READWRITE(input_port_1_r, MWA8_NOP)
-	AM_RANGE(0x5803, 0x5803) AM_MIRROR(0x07f8) AM_READWRITE(MRA8_NOP, sound_data_w)
+	AM_RANGE(0x5801, 0x5801) AM_MIRROR(0x07f8) AM_READ_PORT("IN0") AM_WRITENOP
+	AM_RANGE(0x5802, 0x5802) AM_MIRROR(0x07f8) AM_READ_PORT("IN1") AM_WRITENOP
+	AM_RANGE(0x5803, 0x5803) AM_MIRROR(0x07f8) AM_READWRITE(SMH_NOP, sound_data_w)
 	AM_RANGE(0x5804, 0x5804) AM_MIRROR(0x07f8) AM_NOP
-	AM_RANGE(0x5805, 0x5805) AM_MIRROR(0x07f8) AM_READWRITE(MRA8_NOP, enigma2_flip_screen_w)
+	AM_RANGE(0x5805, 0x5805) AM_MIRROR(0x07f8) AM_READWRITE(SMH_NOP, enigma2_flip_screen_w)
 	AM_RANGE(0x5806, 0x5807) AM_MIRROR(0x07f8) AM_NOP
 ADDRESS_MAP_END
 
@@ -421,19 +424,19 @@ static ADDRESS_MAP_START( engima2a_main_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x1fff) AM_ROM AM_WRITENOP
 	AM_RANGE(0x2000, 0x3fff) AM_MIRROR(0x4000) AM_RAM AM_BASE(&enigma2_ram)
 	AM_RANGE(0x4000, 0x4fff) AM_ROM AM_WRITENOP
-	AM_RANGE(0x5000, 0x57ff) AM_READWRITE(dip_switch_r, MWA8_NOP)
+	AM_RANGE(0x5000, 0x57ff) AM_READWRITE(dip_switch_r, SMH_NOP)
 	AM_RANGE(0x5800, 0x5fff) AM_NOP
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( engima2a_main_cpu_io_map, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(3) )
+	ADDRESS_MAP_GLOBAL_MASK(0x7)
 	AM_RANGE(0x00, 0x00) AM_NOP
-	AM_RANGE(0x01, 0x01) AM_READWRITE(input_port_0_r, MWA8_NOP)
-	AM_RANGE(0x02, 0x02) AM_READWRITE(input_port_1_r, MWA8_NOP)
-	AM_RANGE(0x03, 0x03) AM_READWRITE(MRA8_NOP, sound_data_w)
+	AM_RANGE(0x01, 0x01) AM_READ_PORT("IN0") AM_WRITENOP
+	AM_RANGE(0x02, 0x02) AM_READ_PORT("IN1") AM_WRITENOP
+	AM_RANGE(0x03, 0x03) AM_READWRITE(SMH_NOP, sound_data_w)
 	AM_RANGE(0x04, 0x04) AM_NOP
-	AM_RANGE(0x05, 0x05) AM_READWRITE(MRA8_NOP, enigma2_flip_screen_w)
+	AM_RANGE(0x05, 0x05) AM_READWRITE(SMH_NOP, enigma2_flip_screen_w)
 	AM_RANGE(0x06, 0x07) AM_NOP
 ADDRESS_MAP_END
 
@@ -442,9 +445,9 @@ static ADDRESS_MAP_START( engima2_audio_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0fff) AM_MIRROR(0x1000) AM_ROM AM_WRITENOP
 	AM_RANGE(0x2000, 0x7fff) AM_NOP
 	AM_RANGE(0x8000, 0x83ff) AM_MIRROR(0x1c00) AM_RAM
-	AM_RANGE(0xa000, 0xa000) AM_MIRROR(0x1ffc) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0xa001, 0xa001) AM_MIRROR(0x1ffc) AM_WRITE(AY8910_write_port_0_w)
-	AM_RANGE(0xa002, 0xa002) AM_MIRROR(0x1ffc) AM_READ(AY8910_read_port_0_r)
+	AM_RANGE(0xa000, 0xa000) AM_MIRROR(0x1ffc) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0xa001, 0xa001) AM_MIRROR(0x1ffc) AM_WRITE(ay8910_write_port_0_w)
+	AM_RANGE(0xa002, 0xa002) AM_MIRROR(0x1ffc) AM_READ(ay8910_read_port_0_r)
 	AM_RANGE(0xa003, 0xa003) AM_MIRROR(0x1ffc) AM_NOP
 	AM_RANGE(0xc000, 0xffff) AM_NOP
 ADDRESS_MAP_END
@@ -452,21 +455,21 @@ ADDRESS_MAP_END
 
 
 static INPUT_PORTS_START( enigma2 )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_START2 )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_START1 )
-	PORT_BIT( 0x78, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(p1_controls_r, 0)
+	PORT_BIT( 0x78, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(p1_controls_r, NULL)
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT( 0x78, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(p2_controls_r, 0)
+	PORT_BIT( 0x78, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(p2_controls_r, NULL)
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("DSW")
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x00, "3" )
 	PORT_DIPSETTING(    0x01, "4" )
@@ -489,14 +492,14 @@ static INPUT_PORTS_START( enigma2 )
 	PORT_DIPSETTING(    0x80, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 
-	PORT_START_TAG("P1CONTROLS")
+	PORT_START("P1CONTROLS")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_PLAYER(1)
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(1)
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY PORT_PLAYER(1)
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY PORT_PLAYER(1)
 	PORT_BIT( 0xf0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START_TAG("P2CONTROLS")
+	PORT_START("P2CONTROLS")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY PORT_PLAYER(2)
@@ -506,23 +509,23 @@ INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( enigma2a )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_START2 )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_START1 )
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT( 0x70, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(p1_controls_r, 0)
+	PORT_BIT( 0x70, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(p1_controls_r, NULL)
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT( 0x70, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(p2_controls_r, 0)
+	PORT_BIT( 0x70, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(p2_controls_r, NULL)
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("DSW")
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x00, "3" )
 	PORT_DIPSETTING(    0x01, "4" )
@@ -545,13 +548,13 @@ static INPUT_PORTS_START( enigma2a )
 	PORT_DIPSETTING(    0x80, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 
-	PORT_START_TAG("P1CONTROLS")
+	PORT_START("P1CONTROLS")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(1)
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY PORT_PLAYER(1)
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY PORT_PLAYER(1)
 	PORT_BIT( 0xf8, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START_TAG("P2CONTROLS")
+	PORT_START("P2CONTROLS")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY PORT_PLAYER(2)
@@ -562,29 +565,28 @@ INPUT_PORTS_END
 static MACHINE_DRIVER_START( enigma2 )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", Z80, CPU_CLOCK)
+	MDRV_CPU_ADD("main", Z80, CPU_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(engima2_main_cpu_map,0)
 
-	MDRV_CPU_ADD(Z80, 2500000)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,8)
+	MDRV_CPU_ADD("audio", Z80, 2500000)
+	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,8)
 	MDRV_CPU_PROGRAM_MAP(engima2_audio_cpu_map,0)
 
 	MDRV_MACHINE_START(enigma2)
 	MDRV_MACHINE_RESET(enigma2)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_VIDEO_UPDATE(enigma2)
 
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_RAW_PARAMS(PIXEL_CLOCK, HTOTAL, HBEND, HBSTART, VTOTAL, VBEND, VBSTART)
 
 	/* audio hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, AY8910_CLOCK)
-	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ADD("ay", AY8910, AY8910_CLOCK)
+	MDRV_SOUND_CONFIG(ay8910_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -592,37 +594,36 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( enigma2a )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", 8080, CPU_CLOCK)
+	MDRV_CPU_ADD("main", 8080, CPU_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(engima2a_main_cpu_map,0)
 	MDRV_CPU_IO_MAP(engima2a_main_cpu_io_map,0)
 
-	MDRV_CPU_ADD(Z80, 2500000)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,8)
+	MDRV_CPU_ADD("audio", Z80, 2500000)
+	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,8)
 	MDRV_CPU_PROGRAM_MAP(engima2_audio_cpu_map,0)
 
 	MDRV_MACHINE_START(enigma2)
 	MDRV_MACHINE_RESET(enigma2)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_VIDEO_UPDATE(enigma2a)
 
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_RAW_PARAMS(PIXEL_CLOCK, HTOTAL, HBEND, HBSTART, VTOTAL, VBEND, VBSTART)
 
 	/* audio hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, AY8910_CLOCK)
-	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ADD("ay", AY8910, AY8910_CLOCK)
+	MDRV_SOUND_CONFIG(ay8910_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
 
 ROM_START( enigma2 )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "1.5d",         0x0000, 0x0800, CRC(499749de) SHA1(401928ff41d3b4cbb68e6ad3bf3be4a10ae1781f) )
 	ROM_LOAD( "2.7d",         0x0800, 0x0800, CRC(173c1329) SHA1(3f1ad46d0e58ab236e4ff2b385d09fbf113627da) )
 	ROM_LOAD( "3.8d",         0x1000, 0x0800, CRC(c7d3e6b1) SHA1(43f7c3a02b46747998260d5469248f21714fe12b) )
@@ -630,17 +631,17 @@ ROM_START( enigma2 )
 	ROM_LOAD( "5.11d",   	  0x4000, 0x0800, CRC(098ac15b) SHA1(cce28a2540a9eabb473391fff92895129ae41751) )
 	ROM_LOAD( "6.13d",   	  0x4800, 0x0800, CRC(240a9d4b) SHA1(ca1c69fafec0471141ce1254ddfaef54fecfcbf0) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "enigma2.s",    0x0000, 0x1000, CRC(68fd8c54) SHA1(69996d5dfd996f0aacb26e397bef314204a2a88a) )
 
-	ROM_REGION( 0x1000, REGION_PROMS, 0 )	/* color map/star map */
+	ROM_REGION( 0x1000, "proms", 0 )	/* color map/star map */
 	ROM_LOAD( "7.11f",        0x0000, 0x0800, CRC(409b5aad) SHA1(1b774a70f725637458ed68df9ed42476291b0e43) )
 	ROM_LOAD( "8.13f",        0x0800, 0x0800, CRC(e9cb116d) SHA1(41da4f46c5614ec3345c233467ebad022c6b0bf5) )
 ROM_END
 
 
 ROM_START( enigma2a )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "36_en1.bin",   0x0000, 0x0800, CRC(15f44806) SHA1(4a2f7bc91d4edf7a069e0865d964371c97af0a0a) )
 	ROM_LOAD( "35_en2.bin",   0x0800, 0x0800, CRC(e841072f) SHA1(6ab02fd9fdeac5ab887cd25eee3d6b70ab01f849) )
 	ROM_LOAD( "34_en3.bin",   0x1000, 0x0800, CRC(43d06cf4) SHA1(495af05d54c0325efb67347f691e64d194645d85) )
@@ -648,7 +649,7 @@ ROM_START( enigma2a )
 	ROM_LOAD( "5.11d",        0x4000, 0x0800, CRC(098ac15b) SHA1(cce28a2540a9eabb473391fff92895129ae41751) )
 	ROM_LOAD( "6.13d",   	  0x4800, 0x0800, CRC(240a9d4b) SHA1(ca1c69fafec0471141ce1254ddfaef54fecfcbf0) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "sound.bin",    0x0000, 0x0800, BAD_DUMP CRC(5f092d3c) SHA1(17c70f6af1b5560a45e6b1bdb330a98b27570fe9) )
 ROM_END
 
@@ -657,10 +658,11 @@ ROM_END
 static DRIVER_INIT(enigma2)
 {
 	offs_t i;
+	UINT8 *rom = memory_region(machine, "audio");
 
 	for(i = 0; i < 0x2000; i++)
 	{
-		memory_region(REGION_CPU2)[i] = BITSWAP8(memory_region(REGION_CPU2)[i],4,5,6,0,7,1,3,2);
+		rom[i] = BITSWAP8(rom[i],4,5,6,0,7,1,3,2);
 	}
 }
 
