@@ -14,11 +14,15 @@
 ***************************************************************************/
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
 #include "exerion.h"
 #include "sound/ay8910.h"
 
+
 static UINT8 *exerion_ram;
 
+
+
 /*************************************
  *
  *  Interrupts & inputs
@@ -28,15 +32,14 @@ static UINT8 *exerion_ram;
 static READ8_HANDLER( exerion_port01_r )
 {
 	/* the cocktail flip bit muxes between ports 0 and 1 */
-	return exerion_cocktail_flip ? input_port_1_r(offset) : input_port_0_r(offset);
+	return exerion_cocktail_flip ? input_port_read(space->machine, "IN1") : input_port_read(space->machine, "IN0");
 }
 
 
-static INTERRUPT_GEN( exerion_interrupt )
+static INPUT_CHANGED( coin_inserted )
 {
-	/* Exerion triggers NMIs on coin insertion */
-	if (readinputport(4) & 1)
-		cpunum_set_input_line(machine, 0, INPUT_LINE_NMI, PULSE_LINE);
+	/* coin insertion causes an NMI */
+	cpu_set_input_line(field->port->machine->cpu[0], INPUT_LINE_NMI, newval ? CLEAR_LINE : ASSERT_LINE);
 }
 
 
@@ -62,7 +65,7 @@ static READ8_HANDLER( exerion_porta_r )
 static WRITE8_HANDLER( exerion_portb_w )
 {
 	/* pull the expected value from the ROM */
-	porta = memory_region(REGION_CPU1)[0x5f76];
+	porta = memory_region(space->machine, "main")[0x5f76];
 	portb = data;
 
 	logerror("Port B = %02X\n", data);
@@ -71,8 +74,8 @@ static WRITE8_HANDLER( exerion_portb_w )
 
 static READ8_HANDLER( exerion_protection_r )
 {
-	if (activecpu_get_pc() == 0x4143)
-		return memory_region(REGION_CPU1)[0x33c0 + (exerion_ram[0xd] << 2) + offset];
+	if (cpu_get_pc(space->cpu) == 0x4143)
+		return memory_region(space->machine, "main")[0x33c0 + (exerion_ram[0xd] << 2) + offset];
 	else
 		return exerion_ram[0x8 + offset];
 }
@@ -93,15 +96,15 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x8800, 0x887f) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
 	AM_RANGE(0x8800, 0x8bff) AM_RAM
 	AM_RANGE(0xa000, 0xa000) AM_READ(exerion_port01_r)
-	AM_RANGE(0xa800, 0xa800) AM_READ(input_port_2_r)
-	AM_RANGE(0xb000, 0xb000) AM_READ(input_port_3_r)
+	AM_RANGE(0xa800, 0xa800) AM_READ_PORT("DSW0")
+	AM_RANGE(0xb000, 0xb000) AM_READ_PORT("DSW1")
 	AM_RANGE(0xc000, 0xc000) AM_WRITE(exerion_videoreg_w)
 	AM_RANGE(0xc800, 0xc800) AM_WRITE(soundlatch_w)
-	AM_RANGE(0xd000, 0xd000) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0xd001, 0xd001) AM_WRITE(AY8910_write_port_0_w)
-	AM_RANGE(0xd800, 0xd800) AM_WRITE(AY8910_control_port_1_w)
-	AM_RANGE(0xd801, 0xd801) AM_WRITE(AY8910_write_port_1_w)
-	AM_RANGE(0xd802, 0xd802) AM_READ(AY8910_read_port_1_r)
+	AM_RANGE(0xd000, 0xd000) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0xd001, 0xd001) AM_WRITE(ay8910_write_port_0_w)
+	AM_RANGE(0xd800, 0xd800) AM_WRITE(ay8910_control_port_1_w)
+	AM_RANGE(0xd801, 0xd801) AM_WRITE(ay8910_write_port_1_w)
+	AM_RANGE(0xd802, 0xd802) AM_READ(ay8910_read_port_1_r)
 ADDRESS_MAP_END
 
 
@@ -129,7 +132,7 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( exerion )
-	PORT_START_TAG("IN0")      /* player 1 inputs (muxed on 0xa000) */
+	PORT_START("IN0")      /* player 1 inputs (muxed on 0xa000) */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
@@ -139,7 +142,7 @@ static INPUT_PORTS_START( exerion )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START_TAG("IN1")      /* player 2 inputs (muxed on 0xa000) */
+	PORT_START("IN1")      /* player 2 inputs (muxed on 0xa000) */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
@@ -149,7 +152,7 @@ static INPUT_PORTS_START( exerion )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START_TAG("DSW0")      /* dip switches (0xa800) */
+	PORT_START("DSW0")      /* dip switches (0xa800) */
 	PORT_DIPNAME( 0x07, 0x02, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x00, "1" )
 	PORT_DIPSETTING(    0x01, "2" )
@@ -172,7 +175,7 @@ static INPUT_PORTS_START( exerion )
 	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( Cocktail ) )
 
-	PORT_START_TAG("DSW1")      /* dip switches/VBLANK (0xb000) */
+	PORT_START("DSW1")      /* dip switches/VBLANK (0xb000) */
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_VBLANK )
 	PORT_DIPNAME( 0x02, 0x00, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
@@ -184,13 +187,8 @@ static INPUT_PORTS_START( exerion )
 	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_4C ) )
 	PORT_BIT( 0xf0, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("FAKE")      /* FAKE */
-	/* The coin slots are not memory mapped. */
-	/* This fake input port is used by the interrupt */
-	/* handler to be notified of coin insertions. We use IMPULSE to */
-	/* trigger exactly one interrupt, without having to check when the */
-	/* user releases the key. */
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
+	PORT_START("COIN")
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin_inserted, 0)
 INPUT_PORTS_END
 
 
@@ -248,9 +246,9 @@ static const gfx_layout bigspritelayout =
 
 
 static GFXDECODE_START( exerion )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, charlayout,         0, 64 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0, spritelayout,     256, 64 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0, bigspritelayout,  256, 64 )
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout,         0, 64 )
+	GFXDECODE_ENTRY( "gfx2", 0, spritelayout,     256, 64 )
+	GFXDECODE_ENTRY( "gfx2", 0, bigspritelayout,  256, 64 )
 GFXDECODE_END
 
 
@@ -261,11 +259,13 @@ GFXDECODE_END
  *
  *************************************/
 
-static const struct AY8910interface ay8910_interface =
+static const ay8910_interface ay8910_config =
 {
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
 	exerion_porta_r,
-	0,
-	0,
+	NULL,
+	NULL,
 	exerion_portb_w
 };
 
@@ -279,33 +279,32 @@ static const struct AY8910interface ay8910_interface =
 
 static MACHINE_DRIVER_START( exerion )
 
-	MDRV_CPU_ADD(Z80, EXERION_CPU_CLOCK)
+	MDRV_CPU_ADD("main", Z80, EXERION_CPU_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(main_map,0)
-	MDRV_CPU_VBLANK_INT(exerion_interrupt,1)
 
-	MDRV_CPU_ADD(Z80, EXERION_CPU_CLOCK)
+	MDRV_CPU_ADD("sub", Z80, EXERION_CPU_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(sub_map,0)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_RAW_PARAMS(EXERION_PIXEL_CLOCK, EXERION_HTOTAL, EXERION_HBEND, EXERION_HBSTART, EXERION_VTOTAL, EXERION_VBEND, EXERION_VBSTART)
+
 	MDRV_GFXDECODE(exerion)
-	MDRV_PALETTE_LENGTH(32)
-	MDRV_COLORTABLE_LENGTH(256*3)
+	MDRV_PALETTE_LENGTH(256*3)
 
 	MDRV_PALETTE_INIT(exerion)
 	MDRV_VIDEO_START(exerion)
 	MDRV_VIDEO_UPDATE(exerion)
 
-	/* sound hardware */
+	/* audio hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, EXERION_AY8910_CLOCK)
+	MDRV_SOUND_ADD("ay1", AY8910, EXERION_AY8910_CLOCK)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 
-	MDRV_SOUND_ADD(AY8910, EXERION_AY8910_CLOCK)
-	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ADD("ay2", AY8910, EXERION_AY8910_CLOCK)
+	MDRV_SOUND_CONFIG(ay8910_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 MACHINE_DRIVER_END
 
@@ -318,28 +317,28 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( exerion )
-	ROM_REGION( 0x6000, REGION_CPU1, 0 )
+	ROM_REGION( 0x6000, "main", 0 )
 	ROM_LOAD( "exerion.07",   0x0000, 0x2000, CRC(4c78d57d) SHA1(ac702e9ad2bc05493fb1355858667c31c36acfe4) )
 	ROM_LOAD( "exerion.08",   0x2000, 0x2000, CRC(dcadc1df) SHA1(91388f617cfaa4289ca1c84c697fcfdd8834ae15) )
 	ROM_LOAD( "exerion.09",   0x4000, 0x2000, CRC(34cc4d14) SHA1(511c9de038f7bcaf6f7c96f2cbbe50a80673fa72) )
 
-	ROM_REGION( 0x2000, REGION_CPU2, 0 )     /* 64k for the second CPU */
+	ROM_REGION( 0x2000, "sub", 0 )     /* 64k for the second CPU */
 	ROM_LOAD( "exerion.05",   0x0000, 0x2000, CRC(32f6bff5) SHA1(a4d0289f9d1d9eea7ca9a32a0616af48da74b401) )
 
-	ROM_REGION( 0x02000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x02000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "exerion.06",   0x00000, 0x2000, CRC(435a85a4) SHA1(f6846bfee11df754405d4d796e7d8ac0321b6eb6) ) /* fg chars */
 
-	ROM_REGION( 0x04000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x04000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "exerion.11",   0x00000, 0x2000, CRC(f0633a09) SHA1(8989bcb12abadde34777f7c189cfa6e2dfe92d62) ) /* sprites */
 	ROM_LOAD( "exerion.10",   0x02000, 0x2000, CRC(80312de0) SHA1(4fa3bb9d5c62e41a54e8909f8d3b47637137e913) )
 
-	ROM_REGION( 0x08000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x08000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "exerion.03",   0x00000, 0x2000, CRC(790595b8) SHA1(8016ac2394b25db38e962bcff4805380082f6683) ) /* bg data */
 	ROM_LOAD( "exerion.04",   0x02000, 0x2000, CRC(d7abd0b9) SHA1(ca6413ecd324cf84e11b703a4eda2c1e6d28ff15) )
 	ROM_LOAD( "exerion.01",   0x04000, 0x2000, CRC(5bb755cb) SHA1(ec92c518c116a78dbb23381468cefb3f930212cc) )
 	ROM_LOAD( "exerion.02",   0x06000, 0x2000, CRC(a7ecbb70) SHA1(3c359d5bb21290a45d3eb18fea2b1f9439b931be) )
 
-	ROM_REGION( 0x0420, REGION_PROMS, 0 )
+	ROM_REGION( 0x0420, "proms", 0 )
 	ROM_LOAD( "exerion.e1",   0x0000, 0x0020, CRC(2befcc20) SHA1(a24d3f691413378fde545a6ddcef7e5118e74019) ) /* palette */
 	ROM_LOAD( "exerion.i8",   0x0020, 0x0100, CRC(31db0e08) SHA1(1041a778e86d3fe6f057cf40a0a08b30760f3887) ) /* fg char lookup table */
 	ROM_LOAD( "exerion.h10",  0x0120, 0x0100, CRC(63b4c555) SHA1(30243041be4fa77ada71e8b29d721cad51640c29) ) /* sprite lookup table */
@@ -349,27 +348,27 @@ ROM_END
 
 
 ROM_START( exeriont )
-	ROM_REGION( 0x6000, REGION_CPU1, 0 )
+	ROM_REGION( 0x6000, "main", 0 )
 	ROM_LOAD( "prom5.4p",     0x0000, 0x4000, CRC(58b4dc1b) SHA1(3e34d1eda0b0537dac1062e96259d4cc7c64049c) )
 	ROM_LOAD( "prom6.4s",     0x4000, 0x2000, CRC(fca18c2d) SHA1(31077dada3ed4aa2e26af933f589e01e0c71e5cd) )
 
-	ROM_REGION( 0x2000, REGION_CPU2, 0 )     /* 64k for the second CPU */
+	ROM_REGION( 0x2000, "sub", 0 )     /* 64k for the second CPU */
 	ROM_LOAD( "exerion.05",   0x0000, 0x2000, CRC(32f6bff5) SHA1(a4d0289f9d1d9eea7ca9a32a0616af48da74b401) )
 
-	ROM_REGION( 0x02000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x02000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "exerion.06",   0x00000, 0x2000, CRC(435a85a4) SHA1(f6846bfee11df754405d4d796e7d8ac0321b6eb6) ) /* fg chars */
 
-	ROM_REGION( 0x04000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x04000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "exerion.11",   0x00000, 0x2000, CRC(f0633a09) SHA1(8989bcb12abadde34777f7c189cfa6e2dfe92d62) ) /* sprites */
 	ROM_LOAD( "exerion.10",   0x02000, 0x2000, CRC(80312de0) SHA1(4fa3bb9d5c62e41a54e8909f8d3b47637137e913) )
 
-	ROM_REGION( 0x08000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x08000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "exerion.03",   0x00000, 0x2000, CRC(790595b8) SHA1(8016ac2394b25db38e962bcff4805380082f6683) ) /* bg data */
 	ROM_LOAD( "exerion.04",   0x02000, 0x2000, CRC(d7abd0b9) SHA1(ca6413ecd324cf84e11b703a4eda2c1e6d28ff15) )
 	ROM_LOAD( "exerion.01",   0x04000, 0x2000, CRC(5bb755cb) SHA1(ec92c518c116a78dbb23381468cefb3f930212cc) )
 	ROM_LOAD( "exerion.02",   0x06000, 0x2000, CRC(a7ecbb70) SHA1(3c359d5bb21290a45d3eb18fea2b1f9439b931be) )
 
-	ROM_REGION( 0x0420, REGION_PROMS, 0 )
+	ROM_REGION( 0x0420, "proms", 0 )
 	ROM_LOAD( "exerion.e1",   0x0000, 0x0020, CRC(2befcc20) SHA1(a24d3f691413378fde545a6ddcef7e5118e74019) ) /* palette */
 	ROM_LOAD( "exerion.i8",   0x0020, 0x0100, CRC(31db0e08) SHA1(1041a778e86d3fe6f057cf40a0a08b30760f3887) ) /* fg char lookup table */
 	ROM_LOAD( "exerion.h10",  0x0120, 0x0100, CRC(63b4c555) SHA1(30243041be4fa77ada71e8b29d721cad51640c29) ) /* sprite lookup table */
@@ -379,27 +378,27 @@ ROM_END
 
 
 ROM_START( exerionb )
-	ROM_REGION( 0x6000, REGION_CPU1, 0 )
+	ROM_REGION( 0x6000, "main", 0 )
 	ROM_LOAD( "eb5.bin",      0x0000, 0x4000, CRC(da175855) SHA1(11ea46fd1d504e16e5ffc604d74c1ce210d6be1c) )
 	ROM_LOAD( "eb6.bin",      0x4000, 0x2000, CRC(0dbe2eff) SHA1(5b0e5e8453619beec46c4350d1b2ed571fe3dc24) )
 
-	ROM_REGION( 0x2000, REGION_CPU2, 0 )     /* 64k for the second CPU */
+	ROM_REGION( 0x2000, "sub", 0 )     /* 64k for the second CPU */
 	ROM_LOAD( "exerion.05",   0x0000, 0x2000, CRC(32f6bff5) SHA1(a4d0289f9d1d9eea7ca9a32a0616af48da74b401) )
 
-	ROM_REGION( 0x02000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x02000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "exerion.06",   0x00000, 0x2000, CRC(435a85a4) SHA1(f6846bfee11df754405d4d796e7d8ac0321b6eb6) ) /* fg chars */
 
-	ROM_REGION( 0x04000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x04000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "exerion.11",   0x00000, 0x2000, CRC(f0633a09) SHA1(8989bcb12abadde34777f7c189cfa6e2dfe92d62) ) /* sprites */
 	ROM_LOAD( "exerion.10",   0x02000, 0x2000, CRC(80312de0) SHA1(4fa3bb9d5c62e41a54e8909f8d3b47637137e913) )
 
-	ROM_REGION( 0x08000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x08000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "exerion.03",   0x00000, 0x2000, CRC(790595b8) SHA1(8016ac2394b25db38e962bcff4805380082f6683) ) /* bg data */
 	ROM_LOAD( "exerion.04",   0x02000, 0x2000, CRC(d7abd0b9) SHA1(ca6413ecd324cf84e11b703a4eda2c1e6d28ff15) )
 	ROM_LOAD( "exerion.01",   0x04000, 0x2000, CRC(5bb755cb) SHA1(ec92c518c116a78dbb23381468cefb3f930212cc) )
 	ROM_LOAD( "exerion.02",   0x06000, 0x2000, CRC(a7ecbb70) SHA1(3c359d5bb21290a45d3eb18fea2b1f9439b931be) )
 
-	ROM_REGION( 0x0420, REGION_PROMS, 0 )
+	ROM_REGION( 0x0420, "proms", 0 )
 	ROM_LOAD( "exerion.e1",   0x0000, 0x0020, CRC(2befcc20) SHA1(a24d3f691413378fde545a6ddcef7e5118e74019) ) /* palette */
 	ROM_LOAD( "exerion.i8",   0x0020, 0x0100, CRC(31db0e08) SHA1(1041a778e86d3fe6f057cf40a0a08b30760f3887) ) /* fg char lookup table */
 	ROM_LOAD( "exerion.h10",  0x0120, 0x0100, CRC(63b4c555) SHA1(30243041be4fa77ada71e8b29d721cad51640c29) ) /* sprite lookup table */
@@ -424,8 +423,8 @@ static DRIVER_INIT( exerion )
 
 	/* make a temporary copy of the character data */
 	src = temp;
-	dst = memory_region(REGION_GFX1);
-	length = memory_region_length(REGION_GFX1);
+	dst = memory_region(machine, "gfx1");
+	length = memory_region_length(machine, "gfx1");
 	memcpy(src, dst, length);
 
 	/* decode the characters */
@@ -442,8 +441,8 @@ static DRIVER_INIT( exerion )
 
 	/* make a temporary copy of the sprite data */
 	src = temp;
-	dst = memory_region(REGION_GFX2);
-	length = memory_region_length(REGION_GFX2);
+	dst = memory_region(machine, "gfx2");
+	length = memory_region_length(machine, "gfx2");
 	memcpy(src, dst, length);
 
 	/* decode the sprites */
@@ -465,7 +464,7 @@ static DRIVER_INIT( exerion )
 
 static DRIVER_INIT( exerionb )
 {
-	UINT8 *ram = memory_region(REGION_CPU1);
+	UINT8 *ram = memory_region(machine, "main");
 	int addr;
 
 	/* the program ROMs have data lines D1 and D2 swapped. Decode them. */
