@@ -1,12 +1,10 @@
 /***************************************************************************
 
-Express Raider - (c) 1986 Data East USA
+Express Raider - (c) 1986 Data East Corporation / Data East USA
 
 Ernesto Corvi
 ernesto@imagina.com
 
-Last Modified 14th Jul 2003
-
 Memory Map:
 Main CPU: ( 6502 )
 0000-05ff RAM
@@ -20,7 +18,8 @@ Main CPU: ( 6502 )
 2100-2100 Sound latch write
 2800-2801 Protection
 3800-3800 VBblank ( bootleg 1 only )
-4000-ffff MRA8_ROM
+4000-ffff SMH_ROM
+ffc0-ffc0 VBblank ( bootleg 2 only )
 
 Sound Cpu: ( 6809 )
 0000-1fff RAM
@@ -58,10 +57,159 @@ sign has been defaced by the bootleggers
 2nd bootleg set expects to read vblank status from 0xFFC0, country warning
 sign is intact, however Credit is spelt incorrectly.
 
+
+Stephh's notes (based on the games M6502 code and some tests) :
+
+1) 'exprraid'
+
+  - "@ 1986 DATA EAST USA, INC." (US)
+  - Number of enemies on "shoot" stages is determined by the level
+    (see code at 0x5d21 where location 0x0e is level number-1).
+    Note that time tables are coded backwards (locomotive first,
+    then 5th wagon, then 4th wagon ... up to 1st wagon).
+    This number of enemies is also supposed to be determined
+    by "Difficulty" settings (DSW1 bits 3 and 4).
+    There is however an ingame bug that reads DSW1 bits 4 and 5 :
+
+      5D2F: AD 03 18      lda  $1803
+      5D32: 49 FF         eor  #$FF
+      5D34: 4A            lsr  a
+      5D35: 4A            lsr  a
+      5D36: 4A            lsr  a
+      5D37: 29 06         and  #$06
+
+    So number of enemies is also determined by "Demo Sound" setting !
+    Correct code shall be :
+
+      5D37: 29 03         and  #$03
+
+  - Time for each wagon on "shoot" stage is determined by the level
+    (see code at 0x6873 where location 0x0e is level number-1).
+    Note that time tables are coded backwards (locomotive first,
+    then 5th wagon, then 4th wagon ... up to 1st wagon).
+  - In the US manual, "bonus lives" settings are told be either
+    "Every 50000" or "50000/80000".
+    However, when you look at code at 0xe4a1, you'll notice that
+    settings shall be "50000 only" and "50000/80000".
+  - "Coin Mode" as well "Mode 2 Coinage" settings (DSW0 bits 0 to 4)
+    are undocumented in the US manual.
+    "Coin Mode" is tested though via code at 0xe7c5.
+    Coinage tables :
+      * 0xe7e2 : COIN1 - 0xe7ea : COIN2 (Mode 1)
+      * 0xe7f2 : COIN1 - 0xe7fa : COIN2 (Mode 2)
+  - "Force Coinage" (DSW1 bit 6) setting is undocumented in the US manual.
+    It is tested though via code at 0xe794.
+    When this Dip Switch is set to "On", pressing COIN1 or COIN2 always
+    adds 1 credit regardless of the "Coinage" and "Coin Mode" settings.
+  - At the begining of each level, you have text in upper case
+    which gives you some hints to pass the level or some advice.
+  - In this version, due to extra code at 0xfd80, you only have 4 wagons
+    for the "shoot" stages instead of 5.
+  - Continue play is always available and score is NOT reset to 0.
+
+2) 'exprrada'
+
+  - "@ 1986 DATA EAST CORPORATION" + no code to display the Warning screen (World)
+  - Same way to code number of enemies in "shoot" stages as in 'exprraid'
+    (code at 5ce4) and same ingame bug :
+
+      5CF4: AD 03 18      lda  $1803
+      5CF7: 49 FF         eor  #$FF
+      5CF9: 4A            lsr  a
+      5CFA: 4A            lsr  a
+      5CFB: 4A            lsr  a
+      5CFC: 29 06         and  #$06
+
+    Correct code shall be :
+
+      5CFC: 29 03         and  #$03
+
+    You'll notice by looking at the tables that there are sometimes
+    more enemies than in 'exprraid'.
+  - Time for each wagon on "shoot" stage is determined by the level
+    (see code at 0x6834 where location 0x0e is level number-1).
+    This time is also supposed to be determined by "Difficulty"
+    settings (DSW1 bits 3 and 4).
+    There is however an ingame bug that reads DSW1 bits 4 and 5 :
+
+      683B: AD 03 18      lda  $1803
+      683E: 49 FF         eor  #$FF
+      6840: 4A            lsr  a
+      6841: 4A            lsr  a
+      6842: 4A            lsr  a
+      6843: 4A            lsr  a
+      6844: 29 03         and  #$03
+
+    So Time is also determined by "Demo Sound" setting because of
+    extra "lsr a" instruction at 0x6843 !
+    Correct code shall be :
+
+      6843: EA            nop
+
+    Fortunately, table at 0x685f is filled with 0x30 so you'll
+    always have 30 seconds to "clear" the wagon (which is more
+    than the time you have in 'exprraid').
+    For the locomotive, time is always set to 0x20 = 20 seconds
+    (which is again more than the time you have in 'exprraid').
+  - "Bonus lives" routine starts at 0xe49b.
+  - Coinage related stuff starts at 0xe78e.
+    Coinage tables :
+      * 0xe7dc : COIN1 - 0xe7e4 : COIN2 (Mode 1)
+      * 0xe7ec : COIN1 - 0xe7f4 : COIN2 (Mode 2)
+  - At the begining of each level, you have text in lower case
+    which doesn't give you any hints to pass the level nor advice.
+  - In this version, you always have 5 wagons for the "shoot" stages.
+  - Continue play is always available but score is reset to 0.
+
+3) 'wexpress'
+
+  - "@ 1986 DATA EAST CORPORATION" + no code to display the Warning screen (World)
+  - This version is based on 'exprrada' so all comments also fit
+    for this set. The main difference is that reads from 0x2800
+    and 0x2801 (protection) are either discarded (jumps are noped
+    or patched) or changed to read what shall be the correct value
+    (reads from 0x2801 occur almost all the time).
+    So IMO this set looks like a World bootleg .
+
+4) 'wexpresb'
+
+  - "@ 1986 DATA EAST CORPORATION" + extra code to display the Warning screen (Japan)
+  - Modified Warning screen
+  - This version is heavily based on 'exprrada' (even if I think
+    that there shall exist a "better" Japan undumped version)
+    so all comments also fit for this set. The main difference is
+    the way protection is bypassed (in a different way than 'wexpress'
+    as reads from 0x2801 only occur when a life is lost).
+    The other difference is that you can NOT continue a game.
+  - "Bonus lives" routine starts at 0xe4e5.
+  - Coinage related stuff starts at 0xe7d8.
+  - Coinage tables :
+      * 0xe826 : COIN1 - 0xe82e : COIN2 (Mode 1)
+      * 0xe836 : COIN1 - 0xe83e : COIN2 (Mode 2)
+
+5) 'wexpresc'
+
+  - "@ 1986 DATA EAST CORPORATION" + extra code to display the Warning screen (Japan)
+  - Original Warning screen
+  - "CREDIT" mispelled to "CRDDIT".
+  - This version is heavily based on 'exprrada' (even if I think
+    that there shall exist a "better" Japan undumped version)
+    so all comments also fit for this set. The main difference is
+    the way protection is bypassed (in a different way than 'wexpress'
+    but also in a different way than 'wexpresb' as reads from 0x2801
+    occur when you lose a life but also on "shoot" stages).
+    The other difference is that you can NOT continue a game as in 'wexpresb'.
+  - "Bonus lives" routine starts at 0xe4e5 (same as 'wexpresb')
+  - Coinage related stuff starts at 0xe7d8 (same as 'wexpresb').
+  - Coinage tables (same as 'wexpresb') :
+      * 0xe826 : COIN1 - 0xe82e : COIN2 (Mode 1)
+      * 0xe836 : COIN1 - 0xe83e : COIN2 (Mode 2)
+
+
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/m6502/m6502.h"
 #include "cpu/m6809/m6809.h"
 #include "sound/2203intf.h"
 #include "sound/3812intf.h"
@@ -99,32 +247,27 @@ static READ8_HANDLER( exprraid_protection_r )
 
 static WRITE8_HANDLER( sound_cpu_command_w )
 {
-    soundlatch_w(0,data);
-    cpunum_set_input_line(Machine, 1,INPUT_LINE_NMI,PULSE_LINE);
+    soundlatch_w(space,0,data);
+    cpu_set_input_line(space->machine->cpu[1],INPUT_LINE_NMI,PULSE_LINE);
 }
 
 static READ8_HANDLER( vblank_r )
 {
-	int val = readinputport( 0 );
-
-	if ( ( val & 0x02 ) )
-		cpu_spin();
-
-	return val;
+	return input_port_read(space->machine, "IN0");
 }
 
 static ADDRESS_MAP_START( master_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x00ff, 0x00ff) AM_READ(vblank_r) /* HACK!!!! see init_exprraid below */
     AM_RANGE(0x0000, 0x05ff) AM_RAM AM_BASE(&main_ram)
     AM_RANGE(0x0600, 0x07ff) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-    AM_RANGE(0x0800, 0x0bff) AM_RAM AM_WRITE(exprraid_videoram_w) AM_BASE(&videoram)
-    AM_RANGE(0x0c00, 0x0fff) AM_RAM AM_WRITE(exprraid_colorram_w) AM_BASE(&colorram)
+    AM_RANGE(0x0800, 0x0bff) AM_RAM_WRITE(exprraid_videoram_w) AM_BASE(&videoram)
+    AM_RANGE(0x0c00, 0x0fff) AM_RAM_WRITE(exprraid_colorram_w) AM_BASE(&colorram)
 	AM_RANGE(0x1317, 0x1317) AM_READNOP // ???
 	AM_RANGE(0x1700, 0x1700) AM_READNOP // ???
-    AM_RANGE(0x1800, 0x1800) AM_READ(input_port_1_r) /* DSW 0 */
-    AM_RANGE(0x1801, 0x1801) AM_READ(input_port_2_r) /* Controls */
-    AM_RANGE(0x1802, 0x1802) AM_READ(input_port_3_r) /* Coins */
-    AM_RANGE(0x1803, 0x1803) AM_READ(input_port_4_r) /* DSW 1 */
+    AM_RANGE(0x1800, 0x1800) AM_READ_PORT("DSW0")	/* DSW 0 */
+    AM_RANGE(0x1801, 0x1801) AM_READ_PORT("IN1")	/* Controls */
+    AM_RANGE(0x1802, 0x1802) AM_READ_PORT("IN2")	/* Coins */
+    AM_RANGE(0x1803, 0x1803) AM_READ_PORT("DSW1")	/* DSW 1 */
 	AM_RANGE(0x2000, 0x2000) AM_WRITENOP // ???
     AM_RANGE(0x2001, 0x2001) AM_WRITE(sound_cpu_command_w)
 	AM_RANGE(0x2002, 0x2002) AM_WRITE(exprraid_flipscreen_w)
@@ -139,77 +282,90 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( slave_map, ADDRESS_SPACE_PROGRAM, 8 )
     AM_RANGE(0x0000, 0x1fff) AM_RAM
-    AM_RANGE(0x2000, 0x2000) AM_READWRITE(YM2203_status_port_0_r, YM2203_control_port_0_w)
-	AM_RANGE(0x2001, 0x2001) AM_READWRITE(YM2203_read_port_0_r, YM2203_write_port_0_w)
-    AM_RANGE(0x4000, 0x4000) AM_READWRITE(YM3526_status_port_0_r, YM3526_control_port_0_w)
-    AM_RANGE(0x4001, 0x4001) AM_WRITE(YM3526_write_port_0_w)
+    AM_RANGE(0x2000, 0x2000) AM_READWRITE(ym2203_status_port_0_r, ym2203_control_port_0_w)
+	AM_RANGE(0x2001, 0x2001) AM_READWRITE(ym2203_read_port_0_r, ym2203_write_port_0_w)
+    AM_RANGE(0x4000, 0x4000) AM_READWRITE(ym3526_status_port_0_r, ym3526_control_port_0_w)
+    AM_RANGE(0x4001, 0x4001) AM_WRITE(ym3526_write_port_0_w)
 	AM_RANGE(0x6000, 0x6000) AM_READ(soundlatch_r)
     AM_RANGE(0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
 
 static INPUT_PORTS_START( exprraid )
-	PORT_START /* IN 0 - 0x3800 */
+	PORT_START("IN0")	/* IN 0 - 0x3800 */
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_VBLANK )
 
-	PORT_START /* DSW 0 - 0x1800 */
-	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(    0x01, DEF_STR( 1C_3C ) )
-	PORT_DIPNAME( 0x0c, 0x0c, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(    0x08, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING(    0x04, DEF_STR( 1C_3C ) )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Flip_Screen ) )
+	PORT_START("DSW0")	/* DSW 0 - 0x1800 */
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Coin_A ) )           PORT_DIPLOCATION("SW1:1,2")
+	PORT_DIPSETTING(    0x00, DEF_STR( 2C_1C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x10)
+	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x10)
+	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x10)
+	PORT_DIPSETTING(    0x03, DEF_STR( 1C_2C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x00)
+	PORT_DIPSETTING(    0x01, DEF_STR( 1C_3C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x10)
+	PORT_DIPSETTING(    0x02, DEF_STR( 1C_3C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x00)
+	PORT_DIPSETTING(    0x01, DEF_STR( 1C_4C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x00)
+	PORT_DIPSETTING(    0x00, DEF_STR( 1C_6C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x00)
+	PORT_DIPNAME( 0x0c, 0x0c, DEF_STR( Coin_B ) )           PORT_DIPLOCATION("SW1:3,4")
+	PORT_DIPSETTING(    0x00, DEF_STR( 4C_1C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x00)
+	PORT_DIPSETTING(    0x04, DEF_STR( 3C_1C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x00)
+	PORT_DIPSETTING(    0x00, DEF_STR( 2C_1C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x10)
+	PORT_DIPSETTING(    0x08, DEF_STR( 2C_1C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x00)
+	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_1C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x10)
+	PORT_DIPSETTING(    0x0c, DEF_STR( 1C_1C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x00)
+	PORT_DIPSETTING(    0x08, DEF_STR( 1C_2C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x10)
+	PORT_DIPSETTING(    0x04, DEF_STR( 1C_3C ) ) PORT_CONDITION("DSW0",0x10,PORTCOND_EQUALS,0x10)
+	PORT_DIPNAME( 0x10, 0x10, "Coin Mode" )                 PORT_DIPLOCATION("SW1:5")     /* see notes */
+	PORT_DIPSETTING(    0x10, "Mode 1" )
+	PORT_DIPSETTING(    0x00, "Mode 2" )
+	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Flip_Screen ) )      PORT_DIPLOCATION("SW1:6")
 	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Cabinet ) )
+	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Cabinet ) )          PORT_DIPLOCATION("SW1:5")
 	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
 	PORT_DIPSETTING(    0x40, DEF_STR( Cocktail ) )
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_DIPUNUSED_DIPLOC( 0x80, IP_ACTIVE_LOW, "SW1:8" )
 
-	PORT_START /* IN 1 - 0x1801 */
+	PORT_START("IN1")	/* IN 1 - 0x1801 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT )  PORT_8WAY
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )    PORT_8WAY
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )  PORT_8WAY
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START /* IN 2 - 0x1802 */
+	PORT_START("IN2")	/* IN 2 - 0x1802 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT )  PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )    PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )  PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )
 
-	PORT_START /* IN 3 - 0x1803 */
-	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Lives ) )
+	PORT_START("DSW1")	/* DSW 1 - 0x1803 */
+	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Lives ) )            PORT_DIPLOCATION("SW2:1,2")
 	PORT_DIPSETTING(    0x01, "1" )
 	PORT_DIPSETTING(    0x03, "3" )
 	PORT_DIPSETTING(    0x02, "5" )
 	PORT_DIPSETTING(	0x00, DEF_STR( Infinite ) )
-	PORT_DIPNAME( 0x04, 0x04, DEF_STR( Bonus_Life ) )
-	PORT_DIPSETTING(    0x04, "50K+" )
-	PORT_DIPSETTING(    0x00, "50K 80K" )
-	PORT_DIPNAME( 0x18, 0x18, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(    0x10, DEF_STR( Easy ) )
-	PORT_DIPSETTING(    0x18, DEF_STR( Normal ) )
+	PORT_DIPNAME( 0x04, 0x04, DEF_STR( Bonus_Life ) )       PORT_DIPLOCATION("SW2:3")     /* see notes */
+	PORT_DIPSETTING(    0x00, "50k 80k" )
+	PORT_DIPSETTING(    0x04, "50k only" )
+	PORT_DIPNAME( 0x18, 0x18, DEF_STR( Difficulty ) )       PORT_DIPLOCATION("SW1:4,5")   /* see notes */
+	PORT_DIPSETTING(    0x18, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x10, DEF_STR( Normal ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( Hard ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Very_Hard ) )
-	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Demo_Sounds ) )
+	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Demo_Sounds ) )      PORT_DIPLOCATION("SW2:6")     /* see notes */
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x20, DEF_STR( On ) )
-	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_DIPNAME( 0x40, 0x40, "Force Coinage = 1C/1C" )     PORT_DIPLOCATION("SW2:7")     /* see notes */
+	PORT_DIPSETTING(    0x40, DEF_STR( No ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Yes ) )
+	PORT_DIPUNUSED_DIPLOC( 0x80, IP_ACTIVE_LOW, "SW1:8" )
 INPUT_PORTS_END
 
 
@@ -264,27 +420,27 @@ static const gfx_layout tile2 =
 
 
 static GFXDECODE_START( exprraid )
-	GFXDECODE_ENTRY( REGION_GFX1, 0x00000, charlayout,   128, 2 ) /* characters */
-	GFXDECODE_ENTRY( REGION_GFX2, 0x00000, spritelayout,  64, 8 ) /* sprites */
-	GFXDECODE_ENTRY( REGION_GFX3, 0x00000, tile1,          0, 4 ) /* background tiles */
-	GFXDECODE_ENTRY( REGION_GFX3, 0x00000, tile2,          0, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x04000, tile1,          0, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x04000, tile2,          0, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x08000, tile1,          0, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x08000, tile2,          0, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x0c000, tile1,          0, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x0c000, tile2,          0, 4 )
+	GFXDECODE_ENTRY( "gfx1", 0x00000, charlayout,   128, 2 ) /* characters */
+	GFXDECODE_ENTRY( "gfx2", 0x00000, spritelayout,  64, 8 ) /* sprites */
+	GFXDECODE_ENTRY( "gfx3", 0x00000, tile1,          0, 4 ) /* background tiles */
+	GFXDECODE_ENTRY( "gfx3", 0x00000, tile2,          0, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x04000, tile1,          0, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x04000, tile2,          0, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x08000, tile1,          0, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x08000, tile2,          0, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x0c000, tile1,          0, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x0c000, tile2,          0, 4 )
 GFXDECODE_END
 
 
 
 /* handler called by the 3812 emulator when the internal timers cause an IRQ */
-static void irqhandler(int linestate)
+static void irqhandler(running_machine *machine, int linestate)
 {
-	cpunum_set_input_line_and_vector(Machine, 1,0,linestate,0xff);
+	cpu_set_input_line_and_vector(machine->cpu[1],0,linestate,0xff);
 }
 
-static const struct YM3526interface ym3526_interface =
+static const ym3526_interface ym3526_config =
 {
 	irqhandler
 };
@@ -293,33 +449,37 @@ static INTERRUPT_GEN( exprraid_interrupt )
 {
 	static int coin = 0;
 
-	if ( ( ~readinputport( 3 ) ) & 0xc0 ) {
-		if ( coin == 0 ) {
+	if ((~input_port_read(device->machine, "IN2")) & 0xc0 )
+	{
+		if ( coin == 0 )
+		{
 			coin = 1;
-			cpunum_set_input_line(machine, 0, INPUT_LINE_NMI, PULSE_LINE);
+			cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 		}
-	} else
+	}
+	else
 		coin = 0;
 }
 
 static MACHINE_DRIVER_START( exprraid )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M6502, 4000000)        /* 4 MHz ??? */
+	MDRV_CPU_ADD("main", M6502, 4000000)        /* 4 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(master_map, 0)
-	MDRV_CPU_VBLANK_INT(exprraid_interrupt,1)
+	MDRV_CPU_VBLANK_INT("main", exprraid_interrupt)
 
-	MDRV_CPU_ADD(M6809, 2000000)        /* 2 MHz ??? */
+	MDRV_CPU_ADD("slave", M6809, 2000000)        /* 2 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(slave_map, 0)
 								/* IRQs are caused by the YM3526 */
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(32*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 1*8, 31*8-1)
+
 	MDRV_GFXDECODE(exprraid)
 	MDRV_PALETTE_LENGTH(256)
 
@@ -330,11 +490,11 @@ static MACHINE_DRIVER_START( exprraid )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM2203, 1500000)
+	MDRV_SOUND_ADD("ym1", YM2203, 1500000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 
-	MDRV_SOUND_ADD(YM3526, 3600000)
-	MDRV_SOUND_CONFIG(ym3526_interface)
+	MDRV_SOUND_ADD("ym2", YM3526, 3600000)
+	MDRV_SOUND_CONFIG(ym3526_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
 MACHINE_DRIVER_END
 
@@ -347,17 +507,17 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( exprraid )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "cz01",    0x4000, 0x4000, CRC(dc8f9fba) SHA1(cae6af54fc0081d606b6884e8873aed356a37ba9) )
 	ROM_LOAD( "cz00",    0x8000, 0x8000, CRC(a81290bc) SHA1(ddb0acda6124427bee691f9926c41fda27ed816e) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the sub cpu */
+	ROM_REGION( 0x10000, "slave", 0 )	/* 64k for the sub cpu */
 	ROM_LOAD( "cz02",    0x8000, 0x8000, CRC(552e6112) SHA1(f8412a63cab0aa47321d602f69bf534426c6aa5d) )
 
-	ROM_REGION( 0x04000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x04000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "cz07",    0x00000, 0x4000, CRC(686bac23) SHA1(b6c96ed40e90a8ba32c2e78a65f9589d387b0254) )	/* characters */
 
-	ROM_REGION( 0x30000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x30000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "cz09",    0x00000, 0x8000, CRC(1ed250d1) SHA1(c98b0440e4319308e683e857bbfeb6a150c76ff3) )	/* sprites */
 	ROM_LOAD( "cz08",    0x08000, 0x8000, CRC(2293fc61) SHA1(bf81db375f5424396559dcf0e04d34a52f6a020a) )
 	ROM_LOAD( "cz13",    0x10000, 0x8000, CRC(7c3bfd00) SHA1(87b48e09aaeacf78f3260df893b0922e25d10a5d) )
@@ -365,38 +525,38 @@ ROM_START( exprraid )
 	ROM_LOAD( "cz11",    0x20000, 0x8000, CRC(b7418335) SHA1(e9d08ee651b9221c371e2629a757bceca7b6192b) )
 	ROM_LOAD( "cz10",    0x28000, 0x8000, CRC(2f611978) SHA1(fb60be573184d2af1dfdd543e68eeec53f2788f2) )
 
-	ROM_REGION( 0x20000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x20000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "cz04",    0x00000, 0x8000, CRC(643a1bd3) SHA1(b23631d96cb413808f65f3ebe8fe6539b6140606) )	/* tiles */
 	/* Save 0x08000-0x0ffff to expand the previous so we can decode the thing */
 	ROM_LOAD( "cz05",    0x10000, 0x8000, CRC(c44570bf) SHA1(3e9b8b6b36c7f5ae016dba3987ea19a29bd5ee5b) )	/* tiles */
 	ROM_LOAD( "cz06",    0x18000, 0x8000, CRC(b9bb448b) SHA1(84974b1f3a5b58cd427d874f805a6dd9244c1101) )	/* tiles */
 
-	ROM_REGION( 0x8000, REGION_GFX4, 0 )     /* background tilemaps */
+	ROM_REGION( 0x8000, "gfx4", 0 )     /* background tilemaps */
 	ROM_LOAD( "cz03",    0x0000, 0x8000, CRC(6ce11971) SHA1(16bfa69b3ad02253e81c8110c9b840be03952790) )
 
-	ROM_REGION( 0x0400, REGION_PROMS, 0 )
+	ROM_REGION( 0x0400, "proms", 0 )
 	ROM_LOAD( "cz17.prm", 0x0000, 0x0100, CRC(da31dfbc) SHA1(ac476440864f538918f7bef2e1db82fd19195f89) ) /* red */
 	ROM_LOAD( "cz16.prm", 0x0100, 0x0100, CRC(51f25b4c) SHA1(bfcca57613fbb22919e00db1f6a8c7ca50faa60b) ) /* green */
 	ROM_LOAD( "cz15.prm", 0x0200, 0x0100, CRC(a6168d7f) SHA1(0c7b31adcd764ce2631c3fb5c1a968b01f65e741) ) /* blue */
 	ROM_LOAD( "cz14.prm", 0x0300, 0x0100, CRC(52aad300) SHA1(ff09772b930afa87e28d0628ef85a589a3d149c9) ) /* ??? */
 
-	ROM_REGION( 0x0400, REGION_PLDS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "plds", ROMREGION_DISPOSE )
 	ROM_LOAD( "pal16r4a.5c",   0x0000, 0x0104, CRC(d66aaa87) SHA1(dc29b473238ed6a9de2076c79644b613a9ba6924) )
 	ROM_LOAD( "pal16r4a.5e",   0x0200, 0x0104, CRC(9a8766a7) SHA1(5f84ad9e633daeb14531ef527827ef3d9b269437) )
 ROM_END
 
 ROM_START( exprrada )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "cz01-2e.15a", 0x4000, 0x4000, CRC(a0ae6756) SHA1(7f7ec1efddbb62e9d201c6013bca8ab72c3f75f6) )
 	ROM_LOAD( "cz00-4e.16b", 0x8000, 0x8000, CRC(910f6ccc) SHA1(1dbf164a7add9335d90ee07b6db9a162a28e407b) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the sub cpu */
+	ROM_REGION( 0x10000, "slave", 0 )	/* 64k for the sub cpu */
 	ROM_LOAD( "cz02-1.2a",    0x8000, 0x8000, CRC(552e6112) SHA1(f8412a63cab0aa47321d602f69bf534426c6aa5d) )
 
-	ROM_REGION( 0x04000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x04000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "cz07.5b",    0x00000, 0x4000, CRC(686bac23) SHA1(b6c96ed40e90a8ba32c2e78a65f9589d387b0254) )	/* characters */
 
-	ROM_REGION( 0x30000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x30000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "cz09.16h",    0x00000, 0x8000, CRC(1ed250d1) SHA1(c98b0440e4319308e683e857bbfeb6a150c76ff3) )	/* sprites */
 	ROM_LOAD( "cz08.14h",    0x08000, 0x8000, CRC(2293fc61) SHA1(bf81db375f5424396559dcf0e04d34a52f6a020a) )
 	ROM_LOAD( "cz13.16k",    0x10000, 0x8000, CRC(7c3bfd00) SHA1(87b48e09aaeacf78f3260df893b0922e25d10a5d) )
@@ -404,38 +564,38 @@ ROM_START( exprrada )
 	ROM_LOAD( "cz11.13k",    0x20000, 0x8000, CRC(b7418335) SHA1(e9d08ee651b9221c371e2629a757bceca7b6192b) )
 	ROM_LOAD( "cz10.11k",    0x28000, 0x8000, CRC(2f611978) SHA1(fb60be573184d2af1dfdd543e68eeec53f2788f2) )
 
-	ROM_REGION( 0x20000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x20000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "cz04.8e",    0x00000, 0x8000, CRC(643a1bd3) SHA1(b23631d96cb413808f65f3ebe8fe6539b6140606) )	/* tiles */
 	/* Save 0x08000-0x0ffff to expand the previous so we can decode the thing */
 	ROM_LOAD( "cz05.8f",    0x10000, 0x8000, CRC(c44570bf) SHA1(3e9b8b6b36c7f5ae016dba3987ea19a29bd5ee5b) )	/* tiles */
 	ROM_LOAD( "cz06.8h",    0x18000, 0x8000, CRC(b9bb448b) SHA1(84974b1f3a5b58cd427d874f805a6dd9244c1101) )	/* tiles */
 
-	ROM_REGION( 0x8000, REGION_GFX4, 0 )     /* background tilemaps */
+	ROM_REGION( 0x8000, "gfx4", 0 )     /* background tilemaps */
 	ROM_LOAD( "cz03.12d",    0x0000, 0x8000, CRC(6ce11971) SHA1(16bfa69b3ad02253e81c8110c9b840be03952790) )
 
-	ROM_REGION( 0x0400, REGION_PROMS, 0 )
+	ROM_REGION( 0x0400, "proms", 0 )
 	ROM_LOAD( "cz17.prm", 0x0000, 0x0100, CRC(da31dfbc) SHA1(ac476440864f538918f7bef2e1db82fd19195f89) ) /* red */
 	ROM_LOAD( "cz16.prm", 0x0100, 0x0100, CRC(51f25b4c) SHA1(bfcca57613fbb22919e00db1f6a8c7ca50faa60b) ) /* green */
 	ROM_LOAD( "cz15.prm", 0x0200, 0x0100, CRC(a6168d7f) SHA1(0c7b31adcd764ce2631c3fb5c1a968b01f65e741) ) /* blue */
 	ROM_LOAD( "cz14.prm", 0x0300, 0x0100, CRC(52aad300) SHA1(ff09772b930afa87e28d0628ef85a589a3d149c9) ) /* ??? */
 
-	ROM_REGION( 0x0400, REGION_PLDS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "plds", ROMREGION_DISPOSE )
 	ROM_LOAD( "pal16r4a.5c",   0x0000, 0x0104, CRC(d66aaa87) SHA1(dc29b473238ed6a9de2076c79644b613a9ba6924) )
 	ROM_LOAD( "pal16r4a.5e",   0x0200, 0x0104, CRC(9a8766a7) SHA1(5f84ad9e633daeb14531ef527827ef3d9b269437) )
 ROM_END
 
 ROM_START( wexpress )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "2",       0x4000, 0x4000, CRC(ea5e5a8f) SHA1(fa92bcb6b97c2966cd330b309eba73f9c059f14e) )
 	ROM_LOAD( "1",       0x8000, 0x8000, CRC(a7daae12) SHA1(a97f4bc05a3ec096d8c717bdf096f4b0e59dc2c2) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the sub cpu */
+	ROM_REGION( 0x10000, "slave", 0 )	/* 64k for the sub cpu */
 	ROM_LOAD( "cz02",    0x8000, 0x8000, CRC(552e6112) SHA1(f8412a63cab0aa47321d602f69bf534426c6aa5d) )
 
-	ROM_REGION( 0x04000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x04000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "cz07",    0x00000, 0x4000, CRC(686bac23) SHA1(b6c96ed40e90a8ba32c2e78a65f9589d387b0254) )	/* characters */
 
-	ROM_REGION( 0x30000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x30000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "cz09",    0x00000, 0x8000, CRC(1ed250d1) SHA1(c98b0440e4319308e683e857bbfeb6a150c76ff3) )	/* sprites */
 	ROM_LOAD( "cz08",    0x08000, 0x8000, CRC(2293fc61) SHA1(bf81db375f5424396559dcf0e04d34a52f6a020a) )
 	ROM_LOAD( "cz13",    0x10000, 0x8000, CRC(7c3bfd00) SHA1(87b48e09aaeacf78f3260df893b0922e25d10a5d) )
@@ -443,38 +603,38 @@ ROM_START( wexpress )
 	ROM_LOAD( "cz11",    0x20000, 0x8000, CRC(b7418335) SHA1(e9d08ee651b9221c371e2629a757bceca7b6192b) )
 	ROM_LOAD( "cz10",    0x28000, 0x8000, CRC(2f611978) SHA1(fb60be573184d2af1dfdd543e68eeec53f2788f2) )
 
-	ROM_REGION( 0x20000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x20000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "4",       0x00000, 0x8000, CRC(f2e93ff0) SHA1(2e631966e1fa0b2699aa782b589d36801072ba03) )	/* tiles */
 	/* Save 0x08000-0x0ffff to expand the previous so we can decode the thing */
 	ROM_LOAD( "cz05",    0x10000, 0x8000, CRC(c44570bf) SHA1(3e9b8b6b36c7f5ae016dba3987ea19a29bd5ee5b) )	/* tiles */
 	ROM_LOAD( "6",       0x18000, 0x8000, CRC(c3a56de5) SHA1(aefc516c6c69b12291c0bda03729910181a91a17) )	/* tiles */
 
-	ROM_REGION( 0x8000, REGION_GFX4, 0 )     /* background tilemaps */
+	ROM_REGION( 0x8000, "gfx4", 0 )     /* background tilemaps */
 	ROM_LOAD( "3",        0x0000, 0x8000, CRC(242e3e64) SHA1(4fa8e93ef055bfdbe3bd619c53bf2448e1b832f0) )
 
-	ROM_REGION( 0x0400, REGION_PROMS, 0 )
+	ROM_REGION( 0x0400, "proms", 0 )
 	ROM_LOAD( "cz17.prm", 0x0000, 0x0100, CRC(da31dfbc) SHA1(ac476440864f538918f7bef2e1db82fd19195f89) ) /* red */
 	ROM_LOAD( "cz16.prm", 0x0100, 0x0100, CRC(51f25b4c) SHA1(bfcca57613fbb22919e00db1f6a8c7ca50faa60b) ) /* green */
 	ROM_LOAD( "cz15.prm", 0x0200, 0x0100, CRC(a6168d7f) SHA1(0c7b31adcd764ce2631c3fb5c1a968b01f65e741) ) /* blue */
 	ROM_LOAD( "cz14.prm", 0x0300, 0x0100, CRC(52aad300) SHA1(ff09772b930afa87e28d0628ef85a589a3d149c9) ) /* ??? */
 
-	ROM_REGION( 0x0400, REGION_PLDS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "plds", ROMREGION_DISPOSE )
 	ROM_LOAD( "pal16r4a.5c",   0x0000, 0x0104, CRC(d66aaa87) SHA1(dc29b473238ed6a9de2076c79644b613a9ba6924) )
 	ROM_LOAD( "pal16r4a.5e",   0x0200, 0x0104, CRC(9a8766a7) SHA1(5f84ad9e633daeb14531ef527827ef3d9b269437) )
 ROM_END
 
 ROM_START( wexpresb )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "wexpress.3", 0x4000, 0x4000, CRC(b4dd0fa4) SHA1(8d17eb28ae92486c67859871ea2bef8f50f39dbd) )
 	ROM_LOAD( "wexpress.1", 0x8000, 0x8000, CRC(e8466596) SHA1(dbbd3b84d0f017292595fc19f7412b984851221a) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the sub cpu */
+	ROM_REGION( 0x10000, "slave", 0 )	/* 64k for the sub cpu */
 	ROM_LOAD( "cz02",    0x8000, 0x8000, CRC(552e6112) SHA1(f8412a63cab0aa47321d602f69bf534426c6aa5d) )
 
-	ROM_REGION( 0x04000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x04000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "cz07",    0x00000, 0x4000, CRC(686bac23) SHA1(b6c96ed40e90a8ba32c2e78a65f9589d387b0254) )	/* characters */
 
-	ROM_REGION( 0x30000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x30000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "cz09",    0x00000, 0x8000, CRC(1ed250d1) SHA1(c98b0440e4319308e683e857bbfeb6a150c76ff3) )	/* sprites */
 	ROM_LOAD( "cz08",    0x08000, 0x8000, CRC(2293fc61) SHA1(bf81db375f5424396559dcf0e04d34a52f6a020a) )
 	ROM_LOAD( "cz13",    0x10000, 0x8000, CRC(7c3bfd00) SHA1(87b48e09aaeacf78f3260df893b0922e25d10a5d) )
@@ -482,16 +642,16 @@ ROM_START( wexpresb )
 	ROM_LOAD( "cz11",    0x20000, 0x8000, CRC(b7418335) SHA1(e9d08ee651b9221c371e2629a757bceca7b6192b) )
 	ROM_LOAD( "cz10",    0x28000, 0x8000, CRC(2f611978) SHA1(fb60be573184d2af1dfdd543e68eeec53f2788f2) )
 
-	ROM_REGION( 0x20000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x20000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "4",       0x00000, 0x8000, CRC(f2e93ff0) SHA1(2e631966e1fa0b2699aa782b589d36801072ba03) )	/* tiles */
 	/* Save 0x08000-0x0ffff to expand the previous so we can decode the thing */
 	ROM_LOAD( "cz05",    0x10000, 0x8000, CRC(c44570bf) SHA1(3e9b8b6b36c7f5ae016dba3987ea19a29bd5ee5b) )	/* tiles */
 	ROM_LOAD( "6",       0x18000, 0x8000, CRC(c3a56de5) SHA1(aefc516c6c69b12291c0bda03729910181a91a17) )	/* tiles */
 
-	ROM_REGION( 0x8000, REGION_GFX4, 0 )     /* background tilemaps */
+	ROM_REGION( 0x8000, "gfx4", 0 )     /* background tilemaps */
 	ROM_LOAD( "3",        0x0000, 0x8000, CRC(242e3e64) SHA1(4fa8e93ef055bfdbe3bd619c53bf2448e1b832f0) )
 
-	ROM_REGION( 0x0400, REGION_PROMS, 0 )
+	ROM_REGION( 0x0400, "proms", 0 )
 	ROM_LOAD( "cz17.prm", 0x0000, 0x0100, CRC(da31dfbc) SHA1(ac476440864f538918f7bef2e1db82fd19195f89) ) /* red */
 	ROM_LOAD( "cz16.prm", 0x0100, 0x0100, CRC(51f25b4c) SHA1(bfcca57613fbb22919e00db1f6a8c7ca50faa60b) ) /* green */
 	ROM_LOAD( "cz15.prm", 0x0200, 0x0100, CRC(a6168d7f) SHA1(0c7b31adcd764ce2631c3fb5c1a968b01f65e741) ) /* blue */
@@ -499,17 +659,17 @@ ROM_START( wexpresb )
 ROM_END
 
 ROM_START( wexpresc )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "s2",      0x4000, 0x4000, CRC(40d70fcb) SHA1(1327d39f872a39e020972952e5756ca59c55f9d0) )
 	ROM_LOAD( "s1",      0x8000, 0x8000, CRC(7c573824) SHA1(f5e4d4f0866c08c88d012a77e8aa2e74a779f986) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the sub cpu */
+	ROM_REGION( 0x10000, "slave", 0 )	/* 64k for the sub cpu */
 	ROM_LOAD( "cz02",    0x8000, 0x8000, CRC(552e6112) SHA1(f8412a63cab0aa47321d602f69bf534426c6aa5d) )
 
-	ROM_REGION( 0x04000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x04000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "cz07",    0x00000, 0x4000, CRC(686bac23) SHA1(b6c96ed40e90a8ba32c2e78a65f9589d387b0254) )	/* characters */
 
-	ROM_REGION( 0x30000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x30000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "cz09",    0x00000, 0x8000, CRC(1ed250d1) SHA1(c98b0440e4319308e683e857bbfeb6a150c76ff3) )	/* sprites */
 	ROM_LOAD( "cz08",    0x08000, 0x8000, CRC(2293fc61) SHA1(bf81db375f5424396559dcf0e04d34a52f6a020a) )
 	ROM_LOAD( "cz13",    0x10000, 0x8000, CRC(7c3bfd00) SHA1(87b48e09aaeacf78f3260df893b0922e25d10a5d) )
@@ -517,16 +677,16 @@ ROM_START( wexpresc )
 	ROM_LOAD( "cz11",    0x20000, 0x8000, CRC(b7418335) SHA1(e9d08ee651b9221c371e2629a757bceca7b6192b) )
 	ROM_LOAD( "cz10",    0x28000, 0x8000, CRC(2f611978) SHA1(fb60be573184d2af1dfdd543e68eeec53f2788f2) )
 
-	ROM_REGION( 0x20000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x20000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "4",       0x00000, 0x8000, CRC(f2e93ff0) SHA1(2e631966e1fa0b2699aa782b589d36801072ba03) )	/* tiles */
 	/* Save 0x08000-0x0ffff to expand the previous so we can decode the thing */
 	ROM_LOAD( "cz05",    0x10000, 0x8000, CRC(c44570bf) SHA1(3e9b8b6b36c7f5ae016dba3987ea19a29bd5ee5b) )	/* tiles */
 	ROM_LOAD( "6",       0x18000, 0x8000, CRC(c3a56de5) SHA1(aefc516c6c69b12291c0bda03729910181a91a17) )	/* tiles */
 
-	ROM_REGION( 0x8000, REGION_GFX4, 0 )     /* background tilemaps */
+	ROM_REGION( 0x8000, "gfx4", 0 )     /* background tilemaps */
 	ROM_LOAD( "3",        0x0000, 0x8000, CRC(242e3e64) SHA1(4fa8e93ef055bfdbe3bd619c53bf2448e1b832f0) )
 	/* Proms Weren't Present In This Set, Using the One from the Other */
-	ROM_REGION( 0x0400, REGION_PROMS, 0 )
+	ROM_REGION( 0x0400, "proms", 0 )
 	ROM_LOAD( "cz17.prm", 0x0000, 0x0100, CRC(da31dfbc) SHA1(ac476440864f538918f7bef2e1db82fd19195f89) ) /* red */
 	ROM_LOAD( "cz16.prm", 0x0100, 0x0100, CRC(51f25b4c) SHA1(bfcca57613fbb22919e00db1f6a8c7ca50faa60b) ) /* green */
 	ROM_LOAD( "cz15.prm", 0x0200, 0x0100, CRC(a6168d7f) SHA1(0c7b31adcd764ce2631c3fb5c1a968b01f65e741) ) /* blue */
@@ -534,11 +694,11 @@ ROM_START( wexpresc )
 ROM_END
 
 
-static void exprraid_gfx_expand(void)
+static void exprraid_gfx_expand(running_machine *machine)
 {
 	/* Expand the background rom so we can use regular decode routines */
 
-	UINT8	*gfx = memory_region(REGION_GFX3);
+	UINT8	*gfx = memory_region(machine, "gfx3");
 	int				offs = 0x10000-0x1000;
 	int				i;
 
@@ -556,9 +716,9 @@ static void exprraid_gfx_expand(void)
 }
 
 
-static void patch_rom1(void)
+static void patch_rom1(running_machine *machine)
 {
-	UINT8 *rom = memory_region(REGION_CPU1);
+	UINT8 *rom = memory_region(machine, "main");
 	int i;
 
 	/* HACK!: Implement custom opcode as regular with a mapped io read */
@@ -577,13 +737,13 @@ static void patch_rom1(void)
 
 static DRIVER_INIT( wexpress )
 {
-	patch_rom1();
-	exprraid_gfx_expand();
+	patch_rom1(machine);
+	exprraid_gfx_expand(machine);
 }
 
 static DRIVER_INIT( exprraid )
 {
-	UINT8 *rom = memory_region(REGION_CPU1);
+	UINT8 *rom = memory_region(machine, "main");
 
 
 	/* decode vectors */
@@ -596,20 +756,20 @@ static DRIVER_INIT( exprraid )
 	rom[0xfffe] = rom[0xfff3];
 	rom[0xffff] = rom[0xfff2];
 
-	patch_rom1();
-	exprraid_gfx_expand();
+	patch_rom1(machine);
+	exprraid_gfx_expand(machine);
 }
 
 static DRIVER_INIT( wexpresb )
 {
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x3800, 0x3800, 0, 0, vblank_r);
-	exprraid_gfx_expand();
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x3800, 0x3800, 0, 0, vblank_r);
+	exprraid_gfx_expand(machine);
 }
 
 static DRIVER_INIT( wexpresc )
 {
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xFFC0, 0xFFC0, 0, 0, vblank_r);
-	exprraid_gfx_expand();
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xFFC0, 0xFFC0, 0, 0, vblank_r);
+	exprraid_gfx_expand(machine);
 }
 
 
