@@ -61,7 +61,6 @@
 ****************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "cpu/tms34010/tms34010.h"
 #include "cpu/m6502/m6502.h"
 #include "sound/dac.h"
@@ -105,7 +104,7 @@ static TIMER_CALLBACK( master_sound_nmi_callback );
 
 static MACHINE_RESET( exterm )
 {
-	sound_nmi_timer = timer_alloc(master_sound_nmi_callback, NULL);
+	sound_nmi_timer = timer_alloc(machine, master_sound_nmi_callback, NULL);
 }
 
 
@@ -118,13 +117,13 @@ static MACHINE_RESET( exterm )
 
 static WRITE16_HANDLER( exterm_host_data_w )
 {
-	tms34010_host_w(1, offset / TOWORD(0x00100000), data);
+	tms34010_host_w(space->machine->cpu[1], offset / TOWORD(0x00100000), data);
 }
 
 
 static READ16_HANDLER( exterm_host_data_r )
 {
-	return tms34010_host_r(1, offset / TOWORD(0x00100000));
+	return tms34010_host_r(space->machine->cpu[1], offset / TOWORD(0x00100000));
 }
 
 
@@ -135,12 +134,12 @@ static READ16_HANDLER( exterm_host_data_r )
  *
  *************************************/
 
-static UINT16 exterm_trackball_port_r(int which, UINT16 mem_mask)
+static UINT16 exterm_trackball_port_r(const address_space *space, int which, UINT16 mem_mask)
 {
 	UINT16 port;
 
 	/* Read the fake input port */
-	UINT8 trackball_pos = readinputport(3 + which);
+	UINT8 trackball_pos = input_port_read(space->machine, which ? "DIAL1" : "DIAL0");
 
 	/* Calculate the change from the last position. */
 	UINT8 trackball_diff = trackball_old[which] - trackball_pos;
@@ -156,8 +155,7 @@ static UINT16 exterm_trackball_port_r(int which, UINT16 mem_mask)
 	aimpos[which] = (aimpos[which] + trackball_diff) & 0x3f;
 
 	/* Combine it with the standard input bits */
-	port = which ? input_port_1_word_r(0, mem_mask) :
-				   input_port_0_word_r(0, mem_mask);
+	port = which ? input_port_read(space->machine, "P2") : input_port_read(space->machine, "P1");
 
 	return (port & 0xc0ff) | (aimpos[which] << 8);
 }
@@ -165,13 +163,13 @@ static UINT16 exterm_trackball_port_r(int which, UINT16 mem_mask)
 
 static READ16_HANDLER( exterm_input_port_0_r )
 {
-	return exterm_trackball_port_r(0, mem_mask);
+	return exterm_trackball_port_r(space, 0, mem_mask);
 }
 
 
 static READ16_HANDLER( exterm_input_port_1_r )
 {
-	return exterm_trackball_port_r(1, mem_mask);
+	return exterm_trackball_port_r(space, 1, mem_mask);
 }
 
 
@@ -187,7 +185,7 @@ static WRITE16_HANDLER( exterm_output_port_0_w )
 	/* All the outputs are activated on the rising edge */
 	static UINT16 last = 0;
 
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		/* Bit 0-1= Resets analog controls */
 		if ((data & 0x0001) && !(last & 0x0001))
@@ -196,11 +194,11 @@ static WRITE16_HANDLER( exterm_output_port_0_w )
 			aimpos[1] = 0;
 	}
 
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		/* Bit 13 = Resets the slave CPU */
 		if ((data & 0x2000) && !(last & 0x2000))
-			cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, PULSE_LINE);
+			cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, PULSE_LINE);
 
 		/* Bits 14-15 = Coin counters */
 		coin_counter_w(0, data & 0x8000);
@@ -215,15 +213,15 @@ static TIMER_CALLBACK( sound_delayed_w )
 {
 	/* data is latched independently for both sound CPUs */
 	master_sound_latch = slave_sound_latch = param;
-	cpunum_set_input_line(machine, 2, M6502_IRQ_LINE, ASSERT_LINE);
-	cpunum_set_input_line(machine, 3, M6502_IRQ_LINE, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[2], M6502_IRQ_LINE, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[3], M6502_IRQ_LINE, ASSERT_LINE);
 }
 
 
 static WRITE16_HANDLER( sound_latch_w )
 {
-	if (ACCESSING_LSB)
-		timer_call_after_resynch(NULL, data & 0xff, sound_delayed_w);
+	if (ACCESSING_BITS_0_7)
+		timer_call_after_resynch(space->machine, NULL, data & 0xff, sound_delayed_w);
 }
 
 
@@ -238,7 +236,7 @@ static TIMER_CALLBACK( master_sound_nmi_callback )
 {
 	/* bit 0 of the sound control determines if the NMI is actually delivered */
 	if (sound_control & 0x01)
-		cpunum_set_input_line(machine, 2, INPUT_LINE_NMI, PULSE_LINE);
+		cpu_set_input_line(machine->cpu[2], INPUT_LINE_NMI, PULSE_LINE);
 }
 
 
@@ -246,9 +244,9 @@ static WRITE8_HANDLER( ym2151_data_latch_w )
 {
 	/* bit 7 of the sound control selects which port */
 	if (sound_control & 0x80)
-		YM2151_data_port_0_w(offset, data);
+		ym2151_data_port_0_w(space, offset, data);
 	else
-		YM2151_register_port_0_w(offset, data);
+		ym2151_register_port_0_w(space, offset, data);
 }
 
 
@@ -258,14 +256,14 @@ static WRITE8_HANDLER( sound_nmi_rate_w )
 	/* this value is latched into up-counters, which are clocked at the */
 	/* input clock / 256 */
 	attotime nmi_rate = attotime_mul(ATTOTIME_IN_HZ(4000000), 4096 * (256 - data));
-	timer_adjust(sound_nmi_timer, nmi_rate, 0, nmi_rate);
+	timer_adjust_periodic(sound_nmi_timer, nmi_rate, 0, nmi_rate);
 }
 
 
 static READ8_HANDLER( sound_master_latch_r )
 {
 	/* read latch and clear interrupt */
-	cpunum_set_input_line(Machine, 2, M6502_IRQ_LINE, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[2], M6502_IRQ_LINE, CLEAR_LINE);
 	return master_sound_latch;
 }
 
@@ -273,7 +271,7 @@ static READ8_HANDLER( sound_master_latch_r )
 static READ8_HANDLER( sound_slave_latch_r )
 {
 	/* read latch and clear interrupt */
-	cpunum_set_input_line(Machine, 3, M6502_IRQ_LINE, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[3], M6502_IRQ_LINE, CLEAR_LINE);
 	return slave_sound_latch;
 }
 
@@ -282,14 +280,14 @@ static WRITE8_HANDLER( sound_slave_dac_w )
 {
 	/* DAC A is used to modulate DAC B */
 	dac_value[offset & 1] = data;
-	DAC_data_16_w(0, (dac_value[0] ^ 0xff) * dac_value[1]);
+	dac_data_16_w(0, (dac_value[0] ^ 0xff) * dac_value[1]);
 }
 
 
 static READ8_HANDLER( sound_nmi_to_slave_r )
 {
 	/* a read from here triggers an NMI pulse to the slave */
-	cpunum_set_input_line(Machine, 3, INPUT_LINE_NMI, PULSE_LINE);
+	cpu_set_input_line(space->machine->cpu[3], INPUT_LINE_NMI, PULSE_LINE);
 	return 0xff;
 }
 
@@ -321,13 +319,13 @@ static ADDRESS_MAP_START( master_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x01000000, 0x013fffff) AM_MIRROR(0xfc000000) AM_READWRITE(exterm_host_data_r, exterm_host_data_w)
 	AM_RANGE(0x01400000, 0x0143ffff) AM_MIRROR(0xfc000000) AM_READ(exterm_input_port_0_r)
 	AM_RANGE(0x01440000, 0x0147ffff) AM_MIRROR(0xfc000000) AM_READ(exterm_input_port_1_r)
-	AM_RANGE(0x01480000, 0x014bffff) AM_MIRROR(0xfc000000) AM_READ(input_port_2_word_r)
+	AM_RANGE(0x01480000, 0x014bffff) AM_MIRROR(0xfc000000) AM_READ_PORT("DSW")
 	AM_RANGE(0x01500000, 0x0153ffff) AM_MIRROR(0xfc000000) AM_WRITE(exterm_output_port_0_w)
 	AM_RANGE(0x01580000, 0x015bffff) AM_MIRROR(0xfc000000) AM_WRITE(sound_latch_w)
 	AM_RANGE(0x015c0000, 0x015fffff) AM_MIRROR(0xfc000000) AM_WRITE(watchdog_reset16_w)
-	AM_RANGE(0x01800000, 0x01807fff) AM_MIRROR(0xfc7f8000) AM_READWRITE(MRA16_RAM, paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x01800000, 0x01807fff) AM_MIRROR(0xfc7f8000) AM_RAM_WRITE(paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x02800000, 0x02807fff) AM_MIRROR(0xfc7f8000) AM_RAM AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)
-	AM_RANGE(0x03000000, 0x03ffffff) AM_MIRROR(0xfc000000) AM_ROM AM_REGION(REGION_USER1, 0)
+	AM_RANGE(0x03000000, 0x03ffffff) AM_MIRROR(0xfc000000) AM_ROM AM_REGION("user1", 0)
 ADDRESS_MAP_END
 
 
@@ -373,7 +371,7 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( exterm )
-	PORT_START      /* IN0 */
+	PORT_START("P1")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_UP) PORT_8WAY PORT_PLAYER(1)
@@ -386,7 +384,7 @@ static INPUT_PORTS_START( exterm )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_SERVICE( 0x8000, IP_ACTIVE_LOW )
 
-	PORT_START      /* IN1 */
+	PORT_START("P2")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_UP) PORT_8WAY PORT_PLAYER(2)
@@ -398,7 +396,7 @@ static INPUT_PORTS_START( exterm )
 	PORT_BIT( 0x3f00, IP_ACTIVE_LOW, IPT_SPECIAL) /* trackball data */
 	PORT_BIT( 0xc000, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	/* DSW */
+	PORT_START("DSW")
 	PORT_DIPNAME( 0x0001, 0x0001, DEF_STR( Unused ) ) /* According to the test screen */
 	PORT_DIPSETTING(	  0x0001, DEF_STR( Off ) )
 	PORT_DIPSETTING(	  0x0000, DEF_STR( On ) )
@@ -427,10 +425,10 @@ static INPUT_PORTS_START( exterm )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START /* IN3, fake trackball input port */
+	PORT_START("DIAL0") /* Fake trackball input port */
 	PORT_BIT( 0xff, 0x00, IPT_DIAL ) PORT_SENSITIVITY(50) PORT_KEYDELTA(10) PORT_REVERSE PORT_PLAYER(1) PORT_CODE_DEC(KEYCODE_Z) PORT_CODE_INC(KEYCODE_X)
 
-	PORT_START /* IN4, fake trackball input port. */
+	PORT_START("DIAL1") /* Fake trackball input port. */
 	PORT_BIT( 0xff, 0x00, IPT_DIAL ) PORT_SENSITIVITY(50) PORT_KEYDELTA(10) PORT_REVERSE PORT_PLAYER(2) PORT_CODE_DEC(KEYCODE_N) PORT_CODE_INC(KEYCODE_M)
 INPUT_PORTS_END
 
@@ -445,7 +443,7 @@ INPUT_PORTS_END
 static const tms34010_config master_config =
 {
 	FALSE,						/* halt on reset */
-	0,							/* the screen operated on */
+	"main",						/* the screen operated on */
 	40000000/8,					/* pixel clock */
 	1,							/* pixels per clock */
 	exterm_scanline_update,		/* scanline updater */
@@ -457,7 +455,7 @@ static const tms34010_config master_config =
 static const tms34010_config slave_config =
 {
 	TRUE,						/* halt on reset */
-	0,							/* the screen operated on */
+	"main",						/* the screen operated on */
 	40000000/8,					/* pixel clock */
 	1,							/* pixels per clock */
 	NULL,						/* scanline updater */
@@ -477,30 +475,29 @@ static const tms34010_config slave_config =
 static MACHINE_DRIVER_START( exterm )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(TMS34010, 40000000)
+	MDRV_CPU_ADD("main", TMS34010, 40000000)
 	MDRV_CPU_CONFIG(master_config)
 	MDRV_CPU_PROGRAM_MAP(master_map,0)
 
-	MDRV_CPU_ADD(TMS34010, 40000000)
+	MDRV_CPU_ADD("slave", TMS34010, 40000000)
 	MDRV_CPU_CONFIG(slave_config)
 	MDRV_CPU_PROGRAM_MAP(slave_map,0)
 
-	MDRV_CPU_ADD(M6502, 2000000)
+	MDRV_CPU_ADD("audio", M6502, 2000000)
 	MDRV_CPU_PROGRAM_MAP(sound_master_map,0)
 
-	MDRV_CPU_ADD(M6502, 2000000)
+	MDRV_CPU_ADD("audioslave", M6502, 2000000)
 	MDRV_CPU_PROGRAM_MAP(sound_slave_map,0)
 
-	MDRV_INTERLEAVE(100)
+	MDRV_QUANTUM_TIME(HZ(6000))
 
 	MDRV_MACHINE_RESET(exterm)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_PALETTE_LENGTH(2048+32768)
 
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_RAW_PARAMS(40000000/8, 318, 0, 256, 264, 0, 240)
 
@@ -510,10 +507,10 @@ static MACHINE_DRIVER_START( exterm )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ADD("dac", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.40)
 
-	MDRV_SOUND_ADD(YM2151, 4000000)
+	MDRV_SOUND_ADD("ym", YM2151, 4000000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -526,13 +523,13 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( exterm )
-	ROM_REGION( 0x10000, REGION_CPU3, 0 )		/* 64k for YM2151 code */
+	ROM_REGION( 0x10000, "audio", 0 )		/* 64k for YM2151 code */
 	ROM_LOAD( "v101y1", 0x8000, 0x8000, CRC(cbeaa837) SHA1(87d8a258f059512dbf9bc0e7cfff728ef9e616f1) )
 
-	ROM_REGION( 0x10000, REGION_CPU4, 0 )		/* 64k for DAC code */
+	ROM_REGION( 0x10000, "audioslave", 0 )		/* 64k for DAC code */
 	ROM_LOAD( "v101d1", 0x8000, 0x8000, CRC(83268b7d) SHA1(a9139e80e2382122e9919c0555937e120d4414cf) )
 
-	ROM_REGION16_LE( 0x200000, REGION_USER1, 0 )	/* 2MB for 34010 code */
+	ROM_REGION16_LE( 0x200000, "user1", 0 )	/* 2MB for 34010 code */
 	ROM_LOAD16_BYTE( "v101bg0",  0x000000, 0x10000, CRC(8c8e72cf) SHA1(5e0fa805334f54f7e0293ea400bacb0e3e79ed56) )
 	ROM_LOAD16_BYTE( "v101bg1",  0x000001, 0x10000, CRC(cc2da0d8) SHA1(4ac23048d3ca771e315388603ad3b1b25030d6ff) )
 	ROM_LOAD16_BYTE( "v101bg2",  0x020000, 0x10000, CRC(2dcb3653) SHA1(2d74b58b02ae0587e3789d69feece268f582f226) )
