@@ -5,17 +5,18 @@ Filetto (c) 1990 Novarmatic
 driver by Angelo Salese & Chris Hardy
 
 TODO:
-- Move the emulation of the VGA/CGA/EGA in a proper file,various old arcade games uses them,
-  namely several Mega-Touch type games...
-- The current emulation hasn't any PC-specific chip hooked-up,it just have the minimum
-  requirements & some kludges to let this boot.
-- Can't reset (currently for "Duplicate save state function (0, 0x41b900)"),pit8253 issue
-  probably.
+- Use the MESS implementation of the CGA video emulation;
+- Add a proper FDC device,if you enable it will give a boot error,probably because it
+  expects that in the floppy drive shouldn't be anything,there's currently a kludge that
+  does the trick;
+- Add sound,"buzzer" PC sound plus the UM5100 sound chip,might be connected to the
+  prototyping card;
 
 ********************************************************************************************
 HW notes:
-The PCB is a (un?)modified IBM-PC with a CGA adapter & a prototyping card that controls the
-interface between the pc and the Jamma connectors.
+The PCB is a un-modified IBM-PC with a CGA adapter & a prototyping card that controls the
+interface between the pc and the Jamma connectors.Additionally there's also a UM5100 sound
+chip for the sound.
 PCB Part Number: S/N 90289764 NOVARXT
 PCB Contents:
 1x UMC 8923S-UM5100 voice processor (upper board)
@@ -26,6 +27,7 @@ PCB Contents:
 1x UMC 8928LP-UM8272A floppy disk controller (lower board)
 1x UMC 8935CS-UM82C11 Printer Adapter Interface (lower board)
 1x UMC 8936CS-UM8250B Programmable asynchronous communications element (lower board)
+There isn't any keyboard found connected to the pcb.
 ********************************************************************************************
 SW notes:
 The software of this game can be extracted with a normal Windows program extractor.
@@ -49,7 +51,7 @@ Vector & irq notes (Mainly a memo for me):
 
 7c69 -> int $13 (FDC check),done
 7c6c
-16ef9 -> read dsw?
+16ef9 -> read dsw
 159cd []
 [2361c]
 12eae
@@ -62,20 +64,23 @@ AH
 ******************************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/i86/i86.h"
 #include "video/generic.h"
 #include "machine/pit8253.h"
 #include "machine/8255ppi.h"
+#include "machine/8237dma.h"
+#include "machine/pic8259.h"
+#include "machine/mc146818.h"
+#include "sound/hc55516.h"
 
 #define SET_VISIBLE_AREA(_x_,_y_) \
 	{ \
-	screen_state *state = &machine->screen[0]; \
-	rectangle visarea = state->visarea; \
+	rectangle visarea = *video_screen_get_visible_area(machine->primary_screen); \
 	visarea.min_x = 0; \
 	visarea.max_x = _x_-1; \
 	visarea.min_y = 0; \
 	visarea.max_y = _y_-1; \
-	video_screen_configure(0, _x_, _y_, &visarea, state->refresh ); \
+	video_screen_configure(machine->primary_screen, _x_, _y_, &visarea, video_screen_get_frame_period(machine->primary_screen).attoseconds ); \
 	} \
 
 
@@ -83,13 +88,17 @@ static UINT8 *vga_vram,*work_ram;
 static UINT8 video_regs[0x19];
 static UINT8 *vga_mode;
 static UINT8 hv_blank;
+
+static int bank;
+static int lastvalue;
+
 /*Add here Video regs defines...*/
 
 
 #define RES_320x200 0
 #define RES_640x200 1
 
-static void cga_alphanumeric_tilemap(running_machine *machine, mame_bitmap *bitmap,const rectangle *cliprect,UINT16 size,UINT32 map_offs);
+static void cga_alphanumeric_tilemap(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect,UINT16 size,UINT32 map_offs);
 
 static VIDEO_START( filetto )
 {
@@ -102,14 +111,26 @@ static READ8_HANDLER( vga_hvretrace_r )
     ---- x--- Vertical Retrace
     ---- ---x Horizontal Retrace
     */
-	//v_blank^=8;
-	//h_blank^=1;
-	return (hv_blank);
+	static UINT8 res;
+	static int h,w;
+	res = 0;
+	h = video_screen_get_height(space->machine->primary_screen);
+	w = video_screen_get_width(space->machine->primary_screen);
+
+//  popmessage("%d %d",h,w);
+
+	if (video_screen_get_hpos(space->machine->primary_screen) > h)
+		res|= 1;
+
+	if (video_screen_get_vpos(space->machine->primary_screen) > w)
+		res|= 8;
+
+	return res;
 }
 
-
+//Note: this should be converted to red/green/brown instead of magenta/cyan/white
 /*Basic Graphic mode */
-static void cga_graphic_bitmap(running_machine *machine,mame_bitmap *bitmap,const rectangle *cliprect,UINT16 size,UINT32 map_offs)
+static void cga_graphic_bitmap(running_machine *machine,bitmap_t *bitmap,const rectangle *cliprect,UINT16 size,UINT32 map_offs)
 {
 	static UINT16 x,y,pen = 0;
 	static UINT32 offs;
@@ -197,7 +218,7 @@ static void cga_graphic_bitmap(running_machine *machine,mame_bitmap *bitmap,cons
 
 
 
-static void cga_alphanumeric_tilemap(running_machine *machine, mame_bitmap *bitmap,const rectangle *cliprect,UINT16 size,UINT32 map_offs)
+static void cga_alphanumeric_tilemap(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect,UINT16 size,UINT32 map_offs)
 {
 	static UINT32 offs,x,y,max_x,max_y;
 
@@ -245,21 +266,21 @@ static VIDEO_UPDATE( filetto )
             xxxx xx1x  Select graphics
             xxxx xxx1  80x25 text
             */
-	fillbitmap(bitmap, machine->pens[0], cliprect);
+	bitmap_fill(bitmap, cliprect, 0);
 
 	if(vga_mode[0] & 8)
 	{
 		if(vga_mode[0] & 2)
-			cga_graphic_bitmap(machine,bitmap,cliprect,0,0x18000);
+			cga_graphic_bitmap(screen->machine,bitmap,cliprect,0,0x18000);
 		else
 		{
 			switch(vga_mode[0] & 1)
 			{
 				case 0x00:
-					cga_alphanumeric_tilemap(machine,bitmap,cliprect,RES_320x200,0x18000);
+					cga_alphanumeric_tilemap(screen->machine,bitmap,cliprect,RES_320x200,0x18000);
 					break;
 				case 0x01:
-					cga_alphanumeric_tilemap(machine,bitmap,cliprect,RES_640x200,0x18000);
+					cga_alphanumeric_tilemap(screen->machine,bitmap,cliprect,RES_640x200,0x18000);
 					break;
 			}
 		}
@@ -270,7 +291,7 @@ static VIDEO_UPDATE( filetto )
 
 static READ8_HANDLER( vga_regs_r )
 {
-	logerror("(PC=%05x) Warning: VGA reg port read\n",activecpu_get_pc());
+	logerror("(PC=%05x) Warning: VGA reg port read\n",cpu_get_pc(space->cpu));
 	return 0xff;
 }
 
@@ -285,9 +306,12 @@ static WRITE8_HANDLER( vga_regs_w )
 	if(offset == 1)
 	{
 		if(video_index <= 0x18)
+		{
 			video_regs[video_index] = data;
+			//logerror("write %02x to video register [%02x]",data,video_index);
+		}
 		else
-			logerror("(PC=%05x) Warning: Undefined VGA reg port write (I=%02x D=%02x)\n",activecpu_get_pc(),video_index,data);
+			logerror("(PC=%05x) Warning: Undefined VGA reg port write (I=%02x D=%02x)\n",cpu_get_pc(space->cpu),video_index,data);
 	}
 }
 
@@ -296,13 +320,24 @@ static WRITE8_HANDLER( vga_vram_w )
 	vga_vram[offset] = data;
 }
 
+/*end of Video HW file*/
+
+static struct {
+	const device_config	*pit8253;
+	const device_config	*pic8259_1;
+	const device_config	*pic8259_2;
+	const device_config	*dma8237_1;
+	const device_config	*dma8237_2;
+} filetto_devices;
+
+
 static UINT8 disk_data[2];
 
 static READ8_HANDLER( disk_iobank_r )
 {
-	printf("Read Prototyping card [%02x] @ PC=%05x\n",offset,activecpu_get_pc());
-	if(offset == 1)
-		return readinputport(1);
+	//printf("Read Prototyping card [%02x] @ PC=%05x\n",offset,cpu_get_pc(space->cpu));
+	//if(offset == 0) return input_port_read(space->machine, "DSW");
+	if(offset == 1) return input_port_read(space->machine, "IN1");
 
 	return disk_data[offset];
 }
@@ -329,11 +364,9 @@ static WRITE8_HANDLER( disk_iobank_w )
     sets the selected rom that appears in $C0000-$CFFFF
 
 */
-	static int bank = -1;
-	static int lastvalue = -1;
 	int newbank = 0;
 
-	printf("bank %d set to %02X\n", offset,data);
+//  printf("bank %d set to %02X\n", offset,data);
 
 	if (data == 0xF0)
 	{
@@ -351,12 +384,12 @@ static WRITE8_HANDLER( disk_iobank_w )
 			newbank = 3;
 	}
 
-	printf("newbank = %d\n", newbank);
+//  printf("newbank = %d\n", newbank);
 
 	if (newbank != bank)
 	{
 		bank = newbank;
-		memory_set_bankptr( 1,memory_region(REGION_USER1) + 0x10000 * bank );
+		memory_set_bankptr(space->machine,  1,memory_region(space->machine, "user1") + 0x10000 * bank );
 	}
 
 	lastvalue = data;
@@ -364,66 +397,35 @@ static WRITE8_HANDLER( disk_iobank_w )
 	disk_data[offset] = data;
 }
 
+/*********************************
+Pit8253
+*********************************/
 
-/*RTC?*/
-static READ8_HANDLER( undefined_r )
+static PIT8253_OUTPUT_CHANGED( pc_timer0_w )
 {
-	logerror("(PC=%05x) Warning: Undefined read\n",activecpu_get_pc());
-	return 0x00;
-}
-
-static WRITE8_HANDLER( nmi_enable_w )
-{
-	//if(data & 0x80)
-		//cpunum_set_input_line(Machine, 0, INPUT_LINE_NMI,ASSERT_LINE);
-	//if(!(data & 0x80))
-		//cpunum_set_input_line(Machine, 0, INPUT_LINE_NMI,CLEAR_LINE);
-}
-
-static READ8_HANDLER( kludge_r )
-{
-	return mame_rand(Machine);
-}
-
-static void pc_timer0_w(int state)
-{
-	//if (state)
-	//  pic8259_0_issue_irq(0);
+    pic8259_set_irq_line(filetto_devices.pic8259_1, 0, state);
 }
 
 static const struct pit8253_config pc_pit8253_config =
 {
-	TYPE8253,
 	{
 		{
 			4772720/4,				/* heartbeat IRQ */
-			pc_timer0_w,
-			NULL
+			pc_timer0_w
 		}, {
 			4772720/4,				/* dram refresh */
-			NULL,
 			NULL
 		}, {
 			4772720/4,				/* pio port c pin 4, and speaker polling enough */
-			NULL,
-			NULL//pc_sh_speaker_change_clock
+			NULL
 		}
 	}
 };
 
-static UINT8 drive_data;
-
-static WRITE8_HANDLER( drive_selection_w )
-{
-	drive_data = data;
-	/*Write to this area then expects that location [43e] has the bit 7 activated*/
-	work_ram[0x3e] = 0x80;
-}
-
 static UINT8 port_b_data;
 static UINT8 wss1_data,wss2_data;
 
-static READ8_HANDLER( port_a_r )
+static READ8_DEVICE_HANDLER( port_a_r )
 {
 	if(!(port_b_data & 0x80))//???
 	{
@@ -439,67 +441,66 @@ static READ8_HANDLER( port_a_r )
 	}
 	else//keyboard emulation
 	{
-		cpunum_set_input_line(Machine, 0,1,PULSE_LINE);
+		//cpu_set_input_line(device->machine->cpu[0],1,PULSE_LINE);
 		return 0x00;//Keyboard is disconnected
 		//return 0xaa;//Keyboard code
 	}
 }
 
-static READ8_HANDLER( port_b_r )
+static READ8_DEVICE_HANDLER( port_b_r )
 {
 	return port_b_data;
 }
 
-static READ8_HANDLER( port_c_r )
+static READ8_DEVICE_HANDLER( port_c_r )
 {
 	return wss2_data;//???
 }
 
-static WRITE8_HANDLER( port_b_w )
+/*'buzzer' sound routes here*/
+static WRITE8_DEVICE_HANDLER( port_b_w )
 {
 	port_b_data = data;
+//  hc55516_digit_w(0, data);
+//  popmessage("%02x",data);
 }
 
-static WRITE8_HANDLER( wss_1_w )
+static WRITE8_DEVICE_HANDLER( wss_1_w )
 {
 	wss1_data = data;
 }
 
-static WRITE8_HANDLER( wss_2_w )
+static WRITE8_DEVICE_HANDLER( wss_2_w )
 {
 	wss2_data = data;
 }
 
-static WRITE8_HANDLER( sys_reset_w )
+static WRITE8_DEVICE_HANDLER( sys_reset_w )
 {
-	cpunum_set_input_line(Machine, 0,INPUT_LINE_RESET,PULSE_LINE);
+	cpu_set_input_line(device->machine->cpu[0],INPUT_LINE_RESET,PULSE_LINE);
 }
 
 
-static const ppi8255_interface filetto_ppi8255_intf =
+static const ppi8255_interface filetto_ppi8255_intf[2] =
 {
-	2, 							/* 2 chips */
-	{ port_a_r,NULL },			/* Port A read */
-	{ port_b_r,NULL },			/* Port B read */
-	{ port_c_r,NULL },  		/* Port C read */
-	{ NULL	  ,wss_1_w },   	/* Port A write */
-	{ port_b_w,wss_2_w },   	/* Port B write */
-	{ NULL	  ,sys_reset_w },	/* Port C write */
+	{
+		port_a_r,			/* Port A read */
+		port_b_r,			/* Port B read */
+		port_c_r,  			/* Port C read */
+		NULL,   			/* Port A write */
+		port_b_w,  		 	/* Port B write */
+		NULL				/* Port C write */
+	},
+	{
+		NULL,				/* Port A read */
+		NULL,				/* Port B read */
+		NULL,				/* Port C read */
+		wss_1_w,			/* Port A write */
+		wss_2_w,			/* Port B write */
+		sys_reset_w			/* Port C write */
+	}
 };
 
-static UINT8 irq_data[2];
-
-static READ8_HANDLER( irq_ctrl_8259_r )
-{
-	return irq_data[offset];
-}
-
-static WRITE8_HANDLER( irq_ctrl_8259_w )
-{
-//  usrintf_showmessage("Write to irq device %02x %02x\n",offset,data);
-	irq_data[offset] = data;
-}
-
 /*Floppy Disk Controller 765 device*/
 /*Currently we only emulate it at a point that the BIOS will pass the checks*/
 static UINT8 status;
@@ -511,7 +512,7 @@ static UINT8 status;
 static READ8_HANDLER( fdc765_status_r )
 {
 	static UINT8 tmp,clr_status;
-	popmessage("Read FDC status @ PC=%05x",activecpu_get_pc());
+//  popmessage("Read FDC status @ PC=%05x",cpu_get_pc(space->cpu));
 	tmp = status | 0x80;
 	clr_status++;
 	if(clr_status == 0x10)
@@ -533,34 +534,152 @@ static WRITE8_HANDLER( fdc765_data_w )
 	status = (FDC_WRITE);
 }
 
+static UINT8 drive_data;
+
+static WRITE8_HANDLER( drive_selection_w )
+{
+	drive_data = data;
+	/*write to this area then expects that location [43e] has the bit 7 activated*/
+	work_ram[0x3e] = 0x80;
+}
+
+/******************
+DMA8237 Controller
+******************/
+
+static UINT8 dma_offset[2][4];
+static UINT8 at_pages[0x10];
+
+static DMA8237_MEM_READ( pc_dma_read_byte )
+{
+	const address_space *space = cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	offs_t page_offset = (((offs_t) dma_offset[0][channel]) << 16)
+		& 0xFF0000;
+
+	return memory_read_byte(space, page_offset + offset);
+}
+
+
+static DMA8237_MEM_WRITE( pc_dma_write_byte )
+{
+	const address_space *space = cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	offs_t page_offset = (((offs_t) dma_offset[0][channel]) << 16)
+		& 0xFF0000;
+
+	memory_write_byte(space, page_offset + offset, data);
+}
+
+static READ8_HANDLER(dma_page_select_r)
+{
+	UINT8 data = at_pages[offset % 0x10];
+
+	switch(offset % 8) {
+	case 1:
+		data = dma_offset[(offset / 8) & 1][2];
+		break;
+	case 2:
+		data = dma_offset[(offset / 8) & 1][3];
+		break;
+	case 3:
+		data = dma_offset[(offset / 8) & 1][1];
+		break;
+	case 7:
+		data = dma_offset[(offset / 8) & 1][0];
+		break;
+	}
+	return data;
+}
+
+
+static WRITE8_HANDLER(dma_page_select_w)
+{
+	at_pages[offset % 0x10] = data;
+
+	switch(offset % 8) {
+	case 1:
+		dma_offset[(offset / 8) & 1][2] = data;
+		break;
+	case 2:
+		dma_offset[(offset / 8) & 1][3] = data;
+		break;
+	case 3:
+		dma_offset[(offset / 8) & 1][1] = data;
+		break;
+	case 7:
+		dma_offset[(offset / 8) & 1][0] = data;
+		break;
+	}
+}
+
+
+static const struct dma8237_interface dma8237_1_config =
+{
+	"main",
+	1.0e-6, // 1us
+
+	pc_dma_read_byte,
+	pc_dma_write_byte,
+
+	{ 0, 0, NULL, NULL },
+	{ 0, 0, NULL, NULL },
+	NULL
+};
+
+/******************
+8259 IRQ controller
+******************/
+
+static PIC8259_SET_INT_LINE( pic8259_1_set_int_line ) {
+	cpu_set_input_line(device->machine->cpu[0], 0, interrupt ? HOLD_LINE : CLEAR_LINE);
+}
+
+static const struct pic8259_interface pic8259_1_config = {
+	pic8259_1_set_int_line
+};
+
+static PIC8259_SET_INT_LINE( pic8259_2_set_int_line ) {
+	pic8259_set_irq_line( filetto_devices.pic8259_1, 2, interrupt);
+}
+
+static const struct pic8259_interface pic8259_2_config = {
+	pic8259_2_set_int_line
+};
+
+static IRQ_CALLBACK(irq_callback)
+{
+	int r = 0;
+	r = pic8259_acknowledge(filetto_devices.pic8259_2);
+	if (r==0)
+	{
+		r = pic8259_acknowledge(filetto_devices.pic8259_1);
+	}
+	return r;
+}
+
 static ADDRESS_MAP_START( filetto_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x00000, 0x003ff) AM_RAM //irq vectors
 	AM_RANGE(0x00400, 0x007ff) AM_RAM AM_BASE(&work_ram)
 	AM_RANGE(0x00800, 0x9ffff) AM_RAM //work RAM 640KB
-//  AM_RANGE(0xa0000, 0xb7fff) AM_RAM //VGA RAM
-	AM_RANGE(0xa0000, 0xbffff) AM_READWRITE(MRA8_RAM,vga_vram_w) AM_BASE(&vga_vram)//VGA RAM
-	AM_RANGE(0xc0000, 0xcffff) AM_READ(MRA8_BANK1)
-
+	AM_RANGE(0xa0000, 0xbffff) AM_READWRITE(SMH_RAM,vga_vram_w) AM_BASE(&vga_vram)//VGA RAM
+	AM_RANGE(0xc0000, 0xcffff) AM_READ(SMH_BANK1)
 	AM_RANGE(0xf0000, 0xfffff) AM_ROM
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( filetto_io, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x0000, 0x000f) AM_RAM //AM_READWRITE(dma8237_0_r,dma8237_0_w) //8237 DMA Controller
-	AM_RANGE(0x0020, 0x0021) AM_READWRITE(irq_ctrl_8259_r,irq_ctrl_8259_w)//AM_READWRITE(pic8259_0_r,pic8259_0_w) //8259 Interrupt control
-	AM_RANGE(0x0040, 0x0043) AM_READ(kludge_r) //AM_READWRITE(pit8253_0_r,pit8253_0_w) //8253 PIT
-	AM_RANGE(0x0060, 0x0063) AM_READWRITE(ppi8255_0_r,ppi8255_0_w) //PPI 8255
-	AM_RANGE(0x0064, 0x0066) AM_READWRITE(ppi8255_1_r,ppi8255_1_w) //PPI 8255
-	AM_RANGE(0x0073, 0x0073) AM_READ(undefined_r)
-	AM_RANGE(0x0080, 0x0087) AM_RAM //AM_READWRITE(dma_page_select_r,dma_page_select_w)
-	AM_RANGE(0x00a0, 0x00a0) AM_WRITE(nmi_enable_w)
-	//AM_RANGE(0x0200, 0x020f) AM_RAM //game port
+	AM_RANGE(0x0000, 0x000f) AM_DEVREADWRITE(DMA8237, "dma8237_1", dma8237_r, dma8237_w ) //8237 DMA Controller
+	AM_RANGE(0x0020, 0x002f) AM_DEVREADWRITE(PIC8259, "pic8259_1", pic8259_r, pic8259_w ) //8259 Interrupt control
+	AM_RANGE(0x0040, 0x0043) AM_DEVREADWRITE(PIT8253, "pit8253", pit8253_r, pit8253_w)    //8253 PIT
+	AM_RANGE(0x0060, 0x0063) AM_DEVREADWRITE(PPI8255, "ppi8255_0", ppi8255_r, ppi8255_w)  //PPI 8255
+	AM_RANGE(0x0064, 0x0066) AM_DEVREADWRITE(PPI8255, "ppi8255_1", ppi8255_r, ppi8255_w)  //PPI 8255
+	AM_RANGE(0x0070, 0x007f) AM_READWRITE(mc146818_port_r,mc146818_port_w)
+	AM_RANGE(0x0080, 0x0087) AM_READWRITE(dma_page_select_r,dma_page_select_w)
+	AM_RANGE(0x00a0, 0x00af) AM_DEVREADWRITE(PIC8259, "pic8259_2", pic8259_r, pic8259_w )
+//  AM_RANGE(0x0200, 0x020f) AM_RAM //game port
+	AM_RANGE(0x0201, 0x0201) AM_READ_PORT("COIN") //game port
 	AM_RANGE(0x0278, 0x027f) AM_RAM //printer (parallel) port latch
 	AM_RANGE(0x02f8, 0x02ff) AM_RAM //Modem port
-
-	AM_RANGE(0x0310, 0x0311) AM_READWRITE(disk_iobank_r,disk_iobank_w) //Prototyping card (???)
-	AM_RANGE(0x0312, 0x0312) AM_READ(input_port_0_r)
-
-//  AM_RANGE(0x0300, 0x031f) AM_RAM //Prototyping card (???)
+	AM_RANGE(0x0310, 0x0311) AM_READWRITE(disk_iobank_r,disk_iobank_w) //Prototyping card
+	AM_RANGE(0x0312, 0x0312) AM_READ_PORT("IN0") //Prototyping card,read only
 	AM_RANGE(0x0378, 0x037f) AM_RAM //printer (parallel) port
 	AM_RANGE(0x03bc, 0x03bf) AM_RAM //printer port
 	AM_RANGE(0x03b4, 0x03b5) AM_READWRITE(vga_regs_r,vga_regs_w) //various VGA/CGA/EGA regs
@@ -575,51 +694,37 @@ static ADDRESS_MAP_START( filetto_io, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static INPUT_PORTS_START( filetto )
-	PORT_START
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNUSED ) //START1
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_2WAY PORT_PLAYER(1)
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_2WAY PORT_PLAYER(1)
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNUSED ) //START2
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_2WAY PORT_PLAYER(2)
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_2WAY PORT_PLAYER(2)
+	PORT_START("IN0")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_4WAY PORT_PLAYER(1)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_4WAY PORT_PLAYER(1)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_4WAY PORT_PLAYER(1)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_4WAY PORT_PLAYER(2)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_4WAY PORT_PLAYER(2)
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_4WAY PORT_PLAYER(2)
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
 
-	/*
-    DSW1
-    bit 0   = coinage (0=1co/1cr, 1= 2co/1cr)
-    bit 1   = demo_sounds (0=no,1=yes)
-    bit 2   = extra play (0=no extra play,1=play at 6th match reached)
-    bit 3   = difficulty (0=normal,1=hard)
-    bit 4-7 = <unused>
-    DSW2
-    <unused>
-    */
-	PORT_START
-	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Unknown ) )
+	PORT_START("IN1")
+	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Coinage ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) )
+	PORT_DIPNAME( 0x02, 0x00, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x04, 0x04, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x04, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x04, "Extra Play" )
+	PORT_DIPSETTING(    0x04, DEF_STR( No ) )
+	PORT_DIPSETTING(    0x00, "Play at 6th match reached" )
+	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Normal ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( Hard ) )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
+
+	PORT_START("COIN")
+	PORT_BIT( 0x0f, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0xe0, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
 static const gfx_layout dos_chars =
@@ -646,18 +751,12 @@ static const gfx_layout dos_chars2 =
 };
 
 static GFXDECODE_START( filetto )
-	GFXDECODE_ENTRY( REGION_GFX1, 0x0000, dos_chars,    0, 16 )
-	GFXDECODE_ENTRY( REGION_GFX1, 0x1000, dos_chars2,   0, 16 )
-	GFXDECODE_ENTRY( REGION_GFX1, 0x1800, dos_chars2,   0, 16 )
+	GFXDECODE_ENTRY( "gfx1", 0x0000, dos_chars,    0, 16 )
+	GFXDECODE_ENTRY( "gfx1", 0x1000, dos_chars2,   0, 16 )
+	GFXDECODE_ENTRY( "gfx1", 0x1800, dos_chars2,   0, 16 )
 GFXDECODE_END
 
 
-static MACHINE_RESET(filetto)
-{
-	ppi8255_init(&filetto_ppi8255_intf);
-	pit8253_init(1, &pc_pit8253_config);
-}
-
 /*
 BLACK = 0
 BLUE = 1
@@ -669,7 +768,6 @@ BROWN = 6
 LIGHT GRAY = 7
 */
 
-
 static PALETTE_INIT(filetto)
 {
 	/*Note:palette colors are 6bpp...
@@ -698,70 +796,82 @@ static PALETTE_INIT(filetto)
 	palette_set_color(machine, 29+2,MAKE_RGB(0xff,0xff,0xff));
 
 	palette_set_color(machine, 0xf0,MAKE_RGB(0x00,0x00,0x00));
-	palette_set_color(machine, 0xf1,MAKE_RGB(0x00,0x00,0x9f));
-	palette_set_color(machine, 0xf2,MAKE_RGB(0x00,0x9f,0x00));
-	palette_set_color(machine, 0xf3,MAKE_RGB(0x00,0x9f,0x9f));
-	palette_set_color(machine, 0xf4,MAKE_RGB(0x9f,0x00,0x00));
-	palette_set_color(machine, 0xf5,MAKE_RGB(0x9f,0x00,0x9f));
-	palette_set_color(machine, 0xf6,MAKE_RGB(0x9f,0x9f,0x00));
-	palette_set_color(machine, 0xf7,MAKE_RGB(0x9f,0x9f,0x9f));
-	palette_set_color(machine, 0xf8,MAKE_RGB(0x3f,0x3f,0x3f));
-	palette_set_color(machine, 0xf9,MAKE_RGB(0x3f,0x3f,0xff));
-	palette_set_color(machine, 0xfa,MAKE_RGB(0x3f,0xff,0x3f));
-	palette_set_color(machine, 0xfb,MAKE_RGB(0x3f,0xff,0xff));
-	palette_set_color(machine, 0xfc,MAKE_RGB(0xff,0x3f,0x10));
-	palette_set_color(machine, 0xfd,MAKE_RGB(0xff,0x3f,0xff));
-	palette_set_color(machine, 0xfe,MAKE_RGB(0xff,0xff,0x3f));
+	palette_set_color(machine, 0xf1,MAKE_RGB(0x00,0x00,0xaa));
+	palette_set_color(machine, 0xf2,MAKE_RGB(0x00,0xaa,0x00));
+	palette_set_color(machine, 0xf3,MAKE_RGB(0x00,0xaa,0xaa));
+	palette_set_color(machine, 0xf4,MAKE_RGB(0xaa,0x00,0x00));
+	palette_set_color(machine, 0xf5,MAKE_RGB(0xaa,0x00,0xaa));
+	palette_set_color(machine, 0xf6,MAKE_RGB(0xaa,0xaa,0x00));
+	palette_set_color(machine, 0xf7,MAKE_RGB(0xaa,0xaa,0xaa));
+	palette_set_color(machine, 0xf8,MAKE_RGB(0x55,0x55,0x55));
+	palette_set_color(machine, 0xf9,MAKE_RGB(0x55,0x55,0xff));
+	palette_set_color(machine, 0xfa,MAKE_RGB(0x55,0xff,0x55));
+	palette_set_color(machine, 0xfb,MAKE_RGB(0x55,0xff,0xff));
+	palette_set_color(machine, 0xfc,MAKE_RGB(0xff,0x55,0x55));
+	palette_set_color(machine, 0xfd,MAKE_RGB(0xff,0x55,0xff));
+	palette_set_color(machine, 0xfe,MAKE_RGB(0xff,0xff,0x55));
 	palette_set_color(machine, 0xff,MAKE_RGB(0xff,0xff,0xff));
 }
 
-#define HBLANK_1 if(!(hv_blank & 1)) hv_blank^= 1;
-#define HBLANK_0 if(hv_blank & 1) hv_blank^= 1;
-
-#define VBLANK_1 if(!(hv_blank & 8)) hv_blank^= 8;
-#define VBLANK_0 if(hv_blank & 8) hv_blank^= 8;
-
-static INTERRUPT_GEN( filetto_irq )
+static MACHINE_RESET( filetto )
 {
-	/*TODO: Timings are guessed*/
-	/*H-Blank*/
-	if((cpu_getiloops() % 8) == 0){ HBLANK_1; }
-	else						  { HBLANK_0; }
-
-	/*V-Blank*/
-	if(cpu_getiloops() >= 180) 	  { VBLANK_1; }
-	else						  { VBLANK_0; }
+	bank = -1;
+	lastvalue = -1;
+	hv_blank = 0;
+	cpu_set_irq_callback(machine->cpu[0], irq_callback);
+	filetto_devices.pit8253 = device_list_find_by_tag( machine->config->devicelist, PIT8253, "pit8253" );
+	filetto_devices.pic8259_1 = device_list_find_by_tag( machine->config->devicelist, PIC8259, "pic8259_1" );
+	filetto_devices.pic8259_2 = device_list_find_by_tag( machine->config->devicelist, PIC8259, "pic8259_2" );
+	filetto_devices.dma8237_1 = device_list_find_by_tag( machine->config->devicelist, DMA8237, "dma8237_1" );
+	filetto_devices.dma8237_2 = device_list_find_by_tag( machine->config->devicelist, DMA8237, "dma8237_2" );
 }
 
-
 static MACHINE_DRIVER_START( filetto )
-	MDRV_CPU_ADD_TAG("main", I8088, 8000000)
+	MDRV_CPU_ADD("main", I8088, 8000000)
 	MDRV_CPU_PROGRAM_MAP(filetto_map,0)
 	MDRV_CPU_IO_MAP(filetto_io,0)
-	MDRV_CPU_VBLANK_INT(filetto_irq,200)
+
+	MDRV_MACHINE_RESET( filetto )
+
+	MDRV_PIT8253_ADD( "pit8253", pc_pit8253_config )
+
+	MDRV_PPI8255_ADD( "ppi8255_0", filetto_ppi8255_intf[0] )
+	MDRV_PPI8255_ADD( "ppi8255_1", filetto_ppi8255_intf[1] )
+
+	MDRV_DMA8237_ADD( "dma8237_1", dma8237_1_config )
+
+	MDRV_PIC8259_ADD( "pic8259_1", pic8259_1_config )
+
+	MDRV_PIC8259_ADD( "pic8259_2", pic8259_2_config )
 
 	MDRV_GFXDECODE(filetto)
 
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(640, 480)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 640-1, 0*8, 480-1)
+
 	MDRV_PALETTE_LENGTH(0x100)
 
-	MDRV_MACHINE_RESET(filetto)
 	MDRV_PALETTE_INIT(filetto)
 
 	MDRV_VIDEO_START(filetto)
 	MDRV_VIDEO_UPDATE(filetto)
+
+	/*Sound Hardware*/
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD("voice", HC55516, 8000000/4)//8923S-UM5100 is a HC55536 with ROM hook-up
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.60)
+
+//  PC "buzzer" sound
 MACHINE_DRIVER_END
 
 
 ROM_START( filetto )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )
-
+	ROM_REGION( 0x100000, "main", 0 )
 	ROM_LOAD("u49.bin", 0xfc000, 0x2000, CRC(1be6948a) SHA1(9c433f63d347c211ee4663f133e8417221bc4bf0))
 	ROM_RELOAD(         0xf8000, 0x2000 )
 	ROM_RELOAD(         0xf4000, 0x2000 )
@@ -771,17 +881,16 @@ ROM_START( filetto )
 	ROM_RELOAD(         0xf6000, 0x2000 )
 	ROM_RELOAD(         0xf2000, 0x2000 )
 
-
-	ROM_REGION( 0x40000, REGION_USER1, 0 ) // program data
+	ROM_REGION( 0x40000, "user1", 0 ) // program data
 	ROM_LOAD( "m0.u1", 0x00000, 0x10000, CRC(2408289d) SHA1(eafc144a557a79b58bcb48545cb9c9778e61fcd3) )
 	ROM_LOAD( "m1.u2", 0x10000, 0x10000, CRC(5b623114) SHA1(0d9a14e6b7f57ce4fa09762343b610a973910f58) )
 	ROM_LOAD( "m2.u3", 0x20000, 0x10000, CRC(abc64869) SHA1(564fc9d90d241a7b7776160b3fd036fb08037355) )
 	ROM_LOAD( "m3.u4", 0x30000, 0x10000, CRC(0c1e8a67) SHA1(f1b9280c65fcfcb5ec481cae48eb6f52d6cdbc9d) )
 
-	ROM_REGION( 0x2000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD("u67.bin", 0x0000, 0x2000, CRC(09710122) SHA1(de84bdd9245df287bbd3bb808f0c3531d13a3545) )
 
-	ROM_REGION( 0x40000, REGION_USER2, ROMREGION_DISPOSE ) // unknown
+	ROM_REGION( 0x40000, "user2", ROMREGION_DISPOSE ) // UM5100 sample roms?
 	ROM_LOAD16_BYTE("v1.u15",  0x00000, 0x20000, CRC(613ddd07) SHA1(ebda3d559315879819cb7034b5696f8e7861fe42) )
 	ROM_LOAD16_BYTE("v2.u14",  0x00001, 0x20000, CRC(427e012e) SHA1(50514a6307e63078fe7444a96e39d834684db7df) )
 ROM_END
@@ -791,5 +900,5 @@ static DRIVER_INIT( filetto )
 	//...
 }
 
-GAME( 1990, filetto,    0, filetto,    filetto,   filetto, ROT0,  "Novarmatic", "Filetto (v1.05 901009)",GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 1990, filetto,    0, filetto,    filetto,   filetto, ROT0,  "Novarmatic", "Filetto (v1.05 901009)",GAME_NO_SOUND | GAME_IMPERFECT_COLORS)
 
