@@ -13,6 +13,7 @@ replaced by a 6th button to start games. This is a feature of the PCB for privat
 ***************************************************************************/
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
 #include "machine/8255ppi.h"
 #include "machine/ticket.h"
 #include "sound/dac.h"
@@ -59,17 +60,19 @@ static WRITE8_HANDLER( findout_bitmap_w )
 }
 
 
-static READ8_HANDLER( portC_r )
+static READ8_DEVICE_HANDLER( portC_r )
 {
 	return 4;
 }
 
-static READ8_HANDLER( port1_r )
+static READ8_DEVICE_HANDLER( port1_r )
 {
-	return input_port_1_r(0) | (ticket_dispenser_0_r(0) >> 5);
+	const address_space *space = cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	return input_port_read(device->machine, "IN0") | (ticket_dispenser_0_r(space, 0) >> 5);
 }
 
-static WRITE8_HANDLER( lamps_w )
+static WRITE8_DEVICE_HANDLER( lamps_w )
 {
 	/* 5 button lamps */
 	set_led_status(0,data & 0x01);
@@ -83,47 +86,56 @@ static WRITE8_HANDLER( lamps_w )
 	set_led_status(7,data & 0x80);
 }
 
-static WRITE8_HANDLER( sound_w )
+static WRITE8_DEVICE_HANDLER( sound_w )
 {
+	const address_space *space = cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 	/* bit 3 - coin lockout (lamp6 in test modes, set to lamp 10 as in getrivia.c) */
 	coin_lockout_global_w(~data & 0x08);
 	set_led_status(9,data & 0x08);
 
 	/* bit 5 - ticket out in trivia games */
-	ticket_dispenser_w(0, (data & 0x20)<< 2);
+	ticket_dispenser_w(space, 0, (data & 0x20)<< 2);
 
 	/* bit 6 enables NMI */
-	interrupt_enable_w(0,data & 0x40);
+	interrupt_enable_w(space, 0,data & 0x40);
 
 	/* bit 7 goes directly to the sound amplifier */
-	DAC_data_w(0,((data & 0x80) >> 7) * 255);
+	dac_data_w(0,((data & 0x80) >> 7) * 255);
 
-//  logerror("%04x: sound_w %02x\n",activecpu_get_pc(),data);
+//  logerror("%s: sound_w %02x\n",cpuexec_describe_context(device->machine),data);
 //  popmessage("%02x",data);
 }
 
-static const ppi8255_interface ppi8255_intf =
+static const ppi8255_interface ppi8255_intf[2] =
 {
-	2, 									/* 2 chips */
-	{ input_port_0_r, input_port_2_r },	/* Port A read */
-	{ port1_r, 	NULL },			/* Port B read */
-	{ NULL,		portC_r },		/* Port C read */
-	{ NULL,		NULL },			/* Port A write */
-	{ NULL,		lamps_w },		/* Port B write */
-	{ sound_w,	NULL },			/* Port C write */
+	{
+		DEVICE8_PORT("DSWA"),		/* Port A read */
+		port1_r,					/* Port B read */
+		NULL,						/* Port C read */
+		NULL,						/* Port A write */
+		NULL,						/* Port B write */
+		sound_w,					/* Port C write */
+	},
+	{
+		DEVICE8_PORT("IN1"),		/* Port A read */
+		NULL,						/* Port B read */
+		portC_r,					/* Port C read */
+		NULL,						/* Port A write */
+		lamps_w,					/* Port B write */
+		NULL						/* Port C write */
+	}
 };
 
 static MACHINE_RESET( findout )
 {
-	ppi8255_init(&ppi8255_intf);
-
-	ticket_dispenser_init(100, 1, 1);
+	ticket_dispenser_init(machine, 100, 1, 1);
 }
 
 
 static READ8_HANDLER( catchall )
 {
-	int pc = activecpu_get_pc();
+	int pc = cpu_get_pc(space->cpu);
 
 	if (pc != 0x3c74 && pc != 0x0364 && pc != 0x036d)	/* weed out spurious blit reads */
 		logerror("%04x: unmapped memory read from %04x\n",pc,offset);
@@ -133,27 +145,27 @@ static READ8_HANDLER( catchall )
 
 static WRITE8_HANDLER( banksel_main_w )
 {
-	memory_set_bankptr(1,memory_region(REGION_CPU1) + 0x8000);
+	memory_set_bankptr(space->machine, 1,memory_region(space->machine, "main") + 0x8000);
 }
 static WRITE8_HANDLER( banksel_1_w )
 {
-	memory_set_bankptr(1,memory_region(REGION_CPU1) + 0x10000);
+	memory_set_bankptr(space->machine, 1,memory_region(space->machine, "main") + 0x10000);
 }
 static WRITE8_HANDLER( banksel_2_w )
 {
-	memory_set_bankptr(1,memory_region(REGION_CPU1) + 0x18000);
+	memory_set_bankptr(space->machine, 1,memory_region(space->machine, "main") + 0x18000);
 }
 static WRITE8_HANDLER( banksel_3_w )
 {
-	memory_set_bankptr(1,memory_region(REGION_CPU1) + 0x20000);
+	memory_set_bankptr(space->machine, 1,memory_region(space->machine, "main") + 0x20000);
 }
 static WRITE8_HANDLER( banksel_4_w )
 {
-	memory_set_bankptr(1,memory_region(REGION_CPU1) + 0x28000);
+	memory_set_bankptr(space->machine, 1,memory_region(space->machine, "main") + 0x28000);
 }
 static WRITE8_HANDLER( banksel_5_w )
 {
-	memory_set_bankptr(1,memory_region(REGION_CPU1) + 0x30000);
+	memory_set_bankptr(space->machine, 1,memory_region(space->machine, "main") + 0x30000);
 }
 
 
@@ -181,21 +193,21 @@ static WRITE8_HANDLER( signature_w )
 
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x4000, 0x47ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x4800, 0x4803) AM_READ(ppi8255_0_r)
-	AM_RANGE(0x5000, 0x5003) AM_READ(ppi8255_1_r)
+	AM_RANGE(0x0000, 0x3fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x4000, 0x47ff) AM_READ(SMH_RAM)
+	AM_RANGE(0x4800, 0x4803) AM_DEVREAD(PPI8255, "ppi8255_0", ppi8255_r)
+	AM_RANGE(0x5000, 0x5003) AM_DEVREAD(PPI8255, "ppi8255_1", ppi8255_r)
 	AM_RANGE(0x6400, 0x6400) AM_READ(signature_r)
-	AM_RANGE(0x7800, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_BANK1)
+	AM_RANGE(0x7800, 0x7fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x8000, 0xffff) AM_READ(SMH_BANK1)
 	AM_RANGE(0x0000, 0xffff) AM_READ(catchall)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x4000, 0x47ff) AM_WRITE(MWA8_RAM) AM_BASE(&generic_nvram) AM_SIZE(&generic_nvram_size)
-	AM_RANGE(0x4800, 0x4803) AM_WRITE(ppi8255_0_w)
-	AM_RANGE(0x5000, 0x5003) AM_WRITE(ppi8255_1_w)
+	AM_RANGE(0x0000, 0x3fff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x4000, 0x47ff) AM_WRITE(SMH_RAM) AM_BASE(&generic_nvram) AM_SIZE(&generic_nvram_size)
+	AM_RANGE(0x4800, 0x4803) AM_DEVWRITE(PPI8255, "ppi8255_0", ppi8255_w)
+	AM_RANGE(0x5000, 0x5003) AM_DEVWRITE(PPI8255, "ppi8255_1", ppi8255_w)
 	/* banked ROMs are enabled by low 6 bits of the address */
 	AM_RANGE(0x603e, 0x603e) AM_WRITE(banksel_1_w)
 	AM_RANGE(0x603d, 0x603d) AM_WRITE(banksel_2_w)
@@ -204,16 +216,16 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x602f, 0x602f) AM_WRITE(banksel_5_w)
 	AM_RANGE(0x601f, 0x601f) AM_WRITE(banksel_main_w)
 	AM_RANGE(0x6200, 0x6200) AM_WRITE(signature_w)
-	AM_RANGE(0x7800, 0x7fff) AM_WRITE(MWA8_ROM)	/* space for diagnostic ROM? */
+	AM_RANGE(0x7800, 0x7fff) AM_WRITE(SMH_ROM)	/* space for diagnostic ROM? */
 	AM_RANGE(0x8000, 0x8002) AM_WRITE(findout_drawctrl_w)
 	AM_RANGE(0xc000, 0xffff) AM_WRITE(findout_bitmap_w)  AM_BASE(&videoram)
-	AM_RANGE(0x8000, 0xffff) AM_WRITE(MWA8_ROM)	/* overlapped by the above */
+	AM_RANGE(0x8000, 0xffff) AM_WRITE(SMH_ROM)	/* overlapped by the above */
 ADDRESS_MAP_END
 
 
 
 #define REELFUN_STANDARD_INPUT \
-	PORT_START_TAG("IN0") \
+	PORT_START("IN0") \
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(2) \
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_IMPULSE(2) \
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
@@ -223,7 +235,7 @@ ADDRESS_MAP_END
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 \
-	PORT_START	/* IN1 */\
+	PORT_START("IN1")	/* IN1 */\
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_NAME("1 Left A-Z") \
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_NAME("2 Right A-Z") \
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_NAME("3 Select Letter") \
@@ -234,7 +246,7 @@ ADDRESS_MAP_END
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 #define TRIVIA_STANDARD_INPUT \
-	PORT_START_TAG("IN0") \
+	PORT_START("IN0") \
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(2) \
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_IMPULSE(2) \
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_SPECIAL )		/* ticket status */ \
@@ -244,7 +256,7 @@ ADDRESS_MAP_END
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN ) \
 \
-	PORT_START	/* IN1 */\
+	PORT_START("IN1")	/* IN1 */\
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) \
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 ) \
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON3 ) \
@@ -255,7 +267,7 @@ ADDRESS_MAP_END
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 static INPUT_PORTS_START( reelfun )
-	PORT_START
+	PORT_START("DSWA")
 	PORT_DIPNAME( 0x07, 0x01, "Coinage Multiplier" )
 	PORT_DIPSETTING(    0x07, "7" )
 	PORT_DIPSETTING(    0x06, "6" )
@@ -285,7 +297,7 @@ static INPUT_PORTS_START( reelfun )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( findout )
-	PORT_START      /* DSW A */
+	PORT_START("DSWA")		/* DSW A */
 	PORT_DIPNAME( 0x07, 0x01, DEF_STR( Coinage ) )
 	PORT_DIPSETTING(    0x07, DEF_STR( 7C_1C ) )
 	PORT_DIPSETTING(    0x06, DEF_STR( 6C_1C ) )
@@ -315,7 +327,7 @@ static INPUT_PORTS_START( findout )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( gt103 )
-	PORT_START      /* DSW A */
+	PORT_START("DSWA")		/* DSW A */
 	PORT_DIPNAME( 0x07, 0x01, "Coinage Multiplier" )
 	PORT_DIPSETTING(    0x07, "7" )
 	PORT_DIPSETTING(    0x06, "6" )
@@ -345,7 +357,7 @@ static INPUT_PORTS_START( gt103 )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( gt103a )
-	PORT_START_TAG ("DSWA")
+	PORT_START("DSWA")
 	PORT_DIPNAME( 0x03, 0x01, "Questions" )
 	PORT_DIPSETTING(    0x00, "4" )
 	PORT_DIPSETTING(    0x01, "5" )
@@ -370,7 +382,7 @@ static INPUT_PORTS_START( gt103a )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(2) PORT_CONDITION("DSWA", 0x40, PORTCOND_EQUALS, 0x40)
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON6 ) PORT_IMPULSE(2) PORT_CONDITION("DSWA", 0x40, PORTCOND_EQUALS, 0x00) PORT_NAME ("Start in no coins mode")
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_IMPULSE(2) PORT_CONDITION("DSWA", 0x40, PORTCOND_EQUALS, 0x40)
@@ -382,7 +394,7 @@ static INPUT_PORTS_START( gt103a )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	/* IN1 */
+	PORT_START("IN1")	/* IN1 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON3 )
@@ -407,7 +419,7 @@ static INPUT_PORTS_START( quiz )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( gt507uk )
-	PORT_START      /* DSW A */
+	PORT_START("DSWA")		/* DSW A */
 	PORT_DIPNAME( 0x01, 0x00, "If Ram Error" )
 	PORT_DIPSETTING( 0x01, "Freeze" )
 	PORT_DIPSETTING( 0x00, "Play" )
@@ -444,30 +456,33 @@ INPUT_PORTS_END
 static MACHINE_DRIVER_START( findout )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80,4000000)	/* 4 MHz */
+	MDRV_CPU_ADD("main", Z80,4000000)	/* 4 MHz */
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", nmi_line_pulse)
 
 	MDRV_MACHINE_RESET(findout)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(512, 256)
 	MDRV_SCREEN_VISIBLE_AREA(48, 511-48, 16, 255-16)
+
 	MDRV_PALETTE_LENGTH(256)
 
 	MDRV_VIDEO_START(generic_bitmapped)
 	MDRV_VIDEO_UPDATE(generic_bitmapped)
 
+	MDRV_PPI8255_ADD( "ppi8255_0", ppi8255_intf[0] )
+	MDRV_PPI8255_ADD( "ppi8255_1", ppi8255_intf[1] )
+
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ADD("dac", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -480,7 +495,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( reelfun ) /* v7.01 */
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "reelfun.cnt",          0x00000, 0x4000, CRC(d9d1e92b) SHA1(337f66a37b3734d565b3ff3d912e0f690fd7c445) )
 	ROM_LOAD( "reelfun.prg",          0x08000, 0x2000, CRC(615d846a) SHA1(ffa1c47393f4f364aa34d14cf3ac2f56d9eaecb0) )	/* banked */
 	ROM_LOAD( "reelfun-1-title",      0x10000, 0x8000, CRC(0e165fbc) SHA1(a3a5b7db72ab86efe973f649f5dfe5133830e3fc) )	/* banked ROMs for solution data */
@@ -491,7 +506,7 @@ ROM_START( reelfun ) /* v7.01 */
 ROM_END
 
 ROM_START( findout )
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "12.bin",       0x00000, 0x4000, CRC(21132d4c) SHA1(e3562ee2f46b3f022a852a0e0b1c8fb8164f64a3) )
 	ROM_LOAD( "11.bin",       0x08000, 0x2000, CRC(0014282c) SHA1(c6792f2ff712ba3759ff009950d78750df844d01) )	/* banked */
 	ROM_LOAD( "13.bin",       0x10000, 0x8000, CRC(cea91a13) SHA1(ad3b395ab0362f3decf178824b1feb10b6335bb3) )	/* banked ROMs for solution data */
@@ -500,12 +515,12 @@ ROM_START( findout )
 	ROM_LOAD( "16.bin",       0x28000, 0x8000, CRC(143f9ac8) SHA1(4411e8ba853d7d5c032115ce23453362ab82e9bb) )
 	ROM_LOAD( "17.bin",       0x30000, 0x8000, CRC(dd743bc7) SHA1(63f7e01ac5cda76a1d3390b6b83f4429b7d3b781) )
 
-	ROM_REGION( 0x0200, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0200, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "82s147.bin",   0x0000, 0x0200, CRC(f3b663bb) SHA1(5a683951c8d3a2baac4b49e379d6e10e35465c8a) )	/* unknown */
 ROM_END
 
 ROM_START( gt507uk )
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "triv_3_2.bin",    0x00000, 0x4000, CRC(2d72a081) SHA1(8aa32acf335d027466799b097e0de66bcf13247f) )
 	ROM_LOAD( "rom_ad.bin",      0x08000, 0x2000, CRC(c81cc847) SHA1(057b7b75a2fe1abf88b23e7b2de230d9f96139f5) )
 	ROM_LOAD( "aerospace",       0x10000, 0x8000, CRC(cb555d46) SHA1(559ae05160d7893ff96311a2177eba039a4cf186) )
@@ -516,7 +531,7 @@ ROM_START( gt507uk )
 ROM_END
 
 ROM_START( gt103 )
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "trvmast3.bin",    0x00000, 0x4000, CRC(9ea277bc) SHA1(f813de572a3b5e2ad601dc6559dc93c30bb7a38c) )
 	ROM_LOAD( "comics-cartoons", 0x10000, 0x8000, CRC(193c868e) SHA1(75f18eb6cc6467e927961271374bedaf7736e20b) )
 	ROM_LOAD( "general_3",       0x18000, 0x8000, CRC(b0376464) SHA1(d1812d6dd42cd7f3753fcc0d2647b56a91bfcc9d) )
@@ -526,7 +541,7 @@ ROM_START( gt103 )
 ROM_END
 
 ROM_START( gt5 ) /* v5.06, From a TRIV3D romboard */
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "program",         0x00000, 0x4000, CRC(e9d6226c) SHA1(42e62c5cafa3f051bf48c18c8c549ffcd4c766c5) )
 	ROM_LOAD( "entertainment_2", 0x10000, 0x8000, CRC(c75c2331) SHA1(9c5947616a4cba2623c599def6cf3b2b1981b681) ) /* rom / question set #15 */
 	ROM_LOAD( "facts_2",         0x18000, 0x8000, CRC(7836ef31) SHA1(6a84cfa39de392eed46a4b37752e00b6d094bbd6) )
@@ -536,7 +551,7 @@ ROM_START( gt5 ) /* v5.06, From a TRIV3D romboard */
 ROM_END
 
 ROM_START( gt103a )
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "t_3a-8_1.bin", 0x00000, 0x4000, CRC(02aef306) SHA1(1ffc10c79a55d41ea36bcaab13cb3f02cb3f9712) )
 	ROM_LOAD( "rich-famous",  0x10000, 0x8000, CRC(39e07e4a) SHA1(6e5a0bcefaa1169f313e8818cf50919108b3e121) )
 	ROM_LOAD( "rock-n-roll",  0x18000, 0x8000, CRC(1be036b1) SHA1(0b262906044950319dd911b956ac2e0b433f6c7f) )
@@ -546,7 +561,7 @@ ROM_START( gt103a )
 ROM_END
 
 ROM_START( gt103a1 )
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "prog1_versiona",  0x00000, 0x4000, CRC(537d6566) SHA1(282a33e4a9fc54d34094393c00026bf31ccd6ab5) )
 	ROM_LOAD( "general",         0x10000, 0x8000, CRC(1efa01c3) SHA1(801ef5ab55184e488b08ef99ebd641ea4f7edb24) )
 	ROM_LOAD( "new_science_2",   0x18000, 0x8000, CRC(3bd80fb8) SHA1(9a196595bc5dc6ed5ee5853786839ed4847fa436) )
@@ -556,7 +571,7 @@ ROM_START( gt103a1 )
 ROM_END
 
 ROM_START( gt103a2 )
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "prog1_versionc", 0x00000, 0x4000, CRC(340246a4) SHA1(d655e1cf2b1e87a05e87ff6af4b794e6d54a2a52) )
 	ROM_LOAD( "cars-women",     0x10000, 0x8000, CRC(4c5dd1df) SHA1(f3e2146eeab07ec71617c7614c6e8f6bc844e6e3) )
 	ROM_LOAD( "cops_&_robbers", 0x18000, 0x8000, CRC(8b367c33) SHA1(013468157bf469c9cf138809fdc45b3ba60a423b) )
@@ -566,7 +581,7 @@ ROM_START( gt103a2 )
 ROM_END
 
 ROM_START( gt103a3 )
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "prog1_versionc", 0x00000, 0x4000, CRC(340246a4) SHA1(d655e1cf2b1e87a05e87ff6af4b794e6d54a2a52) )
 	ROM_LOAD( "new_sports",     0x10000, 0x8000, CRC(19eff1a3) SHA1(8e024ae6cc572176c90d819a438ace7b2512dbf2) )
 	ROM_LOAD( "new_general",    0x18000, 0x8000, CRC(ba1f5b92) SHA1(7e94be0ef6904331d3a6b266e5887e9a15c5e7f9) )
@@ -575,7 +590,7 @@ ROM_START( gt103a3 )
 ROM_END
 
 ROM_START( gt103a4 )
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "prog1_versiona",   0x00000, 0x4000, CRC(537d6566) SHA1(282a33e4a9fc54d34094393c00026bf31ccd6ab5) )
 	ROM_LOAD( "vices",            0x10000, 0x8000, CRC(e6069955) SHA1(68f7453f21a4ce1be912141bbe947fbd81d918a3) )
 	ROM_LOAD( "science",          0x18000, 0x8000, CRC(2f940ebd) SHA1(bead4988ac0a97d70f2a3c0b40a05968436de2ed) )
@@ -584,7 +599,7 @@ ROM_START( gt103a4 )
 ROM_END
 
 ROM_START( gt103aa )
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "t_3a-8_1.bin",    0x00000, 0x4000, CRC(02aef306) SHA1(1ffc10c79a55d41ea36bcaab13cb3f02cb3f9712) )
 	ROM_LOAD( "rock-n-roll_alt", 0x10000, 0x8000, CRC(8eb83052) SHA1(93e3c1ae6c2048fb44ecafe1013b6a96da38fa84) )
 	ROM_LOAD( "science_alt",     0x18000, 0x8000, CRC(9eaebd18) SHA1(3a4d787cb006dbb23ce346577cb1bb5e543ba52c) )
@@ -594,7 +609,7 @@ ROM_START( gt103aa )
 ROM_END
 
 ROM_START( gt103ab )
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "t_3a-8_1.bin",      0x00000, 0x4000, CRC(02aef306) SHA1(1ffc10c79a55d41ea36bcaab13cb3f02cb3f9712) )
 	ROM_LOAD( "entertainment_alt", 0x10000, 0x8000, CRC(9a6628b9) SHA1(c0cb7e974329d4d5b91f107296d21a674e35a51b) )
 	ROM_LOAD( "general_alt",       0x18000, 0x8000, CRC(df34f7f9) SHA1(329d123eea711d5135dc02dd7b89b220ce8ddd28) )
@@ -604,7 +619,7 @@ ROM_START( gt103ab )
 ROM_END
 
 ROM_START( gt103asx )
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "t_3a-8_1.bin",    0x00000, 0x4000, CRC(02aef306) SHA1(1ffc10c79a55d41ea36bcaab13cb3f02cb3f9712) )
 	ROM_LOAD( "adult_sex_2",     0x10000, 0x8000, CRC(0d683f21) SHA1(f47ce3c31c4c5ed02247fa280303e6ae760315df) )
 	ROM_LOAD( "adult_sex_2_alt", 0x18000, 0x8000, CRC(8c0eacc8) SHA1(ddaa25548d161394b41c65a2db57a9fcf793062b) )
@@ -614,7 +629,7 @@ ROM_START( gt103asx )
 ROM_END
 
 ROM_START( quiz )
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "1.bin",        0x00000, 0x4000, CRC(4e3204da) SHA1(291f1c9b8c4c07881621c3ecbba7af80f86b9520) )
 	ROM_LOAD( "2.bin",        0x10000, 0x8000, CRC(b79f3ae1) SHA1(4b4aa50ec95138bc8ee4bc2a61bcbfa2515ac854) )
 	ROM_LOAD( "3.bin",        0x18000, 0x8000, CRC(9c7e9608) SHA1(35ee9aa36d16bca64875640224c7fe9d327a95c3) )
@@ -622,12 +637,12 @@ ROM_START( quiz )
 	ROM_LOAD( "5.bin",        0x28000, 0x8000, CRC(e9cdae21) SHA1(4de4a4edf9eccd8f9f7b935f47bee42c10ad606f) )
 	ROM_LOAD( "6.bin",        0x30000, 0x8000, CRC(89e2b7e8) SHA1(e85c66f0cf37418f522c2d6384997d52f2f15117) )
 
-	ROM_REGION( 0x0200, REGION_PROMS, 0 ) /* unknown */
+	ROM_REGION( 0x0200, "proms", 0 ) /* unknown */
 	ROM_LOAD( "prom_am27s29pc.bin", 0x0000, 0x0200, CRC(19e3f161) SHA1(52da3c1e50c2329454de14cb9c46149e573e562b) )
 ROM_END
 
 ROM_START( quiz211 )
-	ROM_REGION( 0x38000, REGION_CPU1, 0 )
+	ROM_REGION( 0x38000, "main", 0 )
 	ROM_LOAD( "1a.bin",         0x000000, 0x4000, CRC(116de0ea) SHA1(9af97b100aa2c79a58de055abe726d6e2e00aab4) )
 	ROM_CONTINUE(				0x000000, 0x4000 ) // halves identical
 	ROM_LOAD( "hobby.bin",      0x10000, 0x8000, CRC(c86d0c2b) SHA1(987ef17c7b9cc119511a16cbd98ec44d24665af5) )
@@ -636,7 +651,7 @@ ROM_START( quiz211 )
 	ROM_LOAD( "spettacolo.bin", 0x28000, 0x8000, CRC(38b8e37a) SHA1(e6df575f61ac61e825d98eaef99c128647806a75) )
 	ROM_LOAD( "mondiali90.bin", 0x30000, 0x4000, CRC(35622870) SHA1(f2dab64106ca4ef07175a0ad9491470964d8a0d2) )
 
-	ROM_REGION( 0x0e00, REGION_PROMS, 0 ) /* unknown */
+	ROM_REGION( 0x0e00, "proms", 0 ) /* unknown */
 	ROM_LOAD( "prom_27s13-1.bin", 0x0000, 0x0200, NO_DUMP )
 	ROM_LOAD( "prom_27s13-2.bin", 0x0200, 0x0200, NO_DUMP )
 	ROM_LOAD( "prom_27s13-3.bin", 0x0400, 0x0200, NO_DUMP )
@@ -645,7 +660,7 @@ ROM_START( quiz211 )
 	ROM_LOAD( "prom_27s13-6.bin", 0x0a00, 0x0200, NO_DUMP )
 	ROM_LOAD( "prom_6349-1n.bin", 0x0c00, 0x0200, CRC(19e3f161) SHA1(52da3c1e50c2329454de14cb9c46149e573e562b) )
 
-	ROM_REGION( 0x0100, REGION_PLDS, 0 )
+	ROM_REGION( 0x0100, "plds", 0 )
 	ROM_LOAD( "pal10l8cn.bin",   0x0000, 0x002c, CRC(86095226) SHA1(e7496efbd5ca240f0df2dfa5627402342c7f5384) )
 ROM_END
 
