@@ -82,9 +82,10 @@ Stephh's notes :
 */
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/m68000/m68000.h"
 #include "cpu/upd7810/upd7810.h"
 #include "sound/okim6295.h"
+#include "includes/fitfight.h"
 
 
 UINT16 *fitfight_spriteram;
@@ -102,12 +103,6 @@ char bbprot_kludge;
 
 static UINT16 fitfight_700000_data = 0;
 
-WRITE16_HANDLER( fof_bak_tileram_w );
-WRITE16_HANDLER( fof_mid_tileram_w );
-WRITE16_HANDLER( fof_txt_tileram_w );
-VIDEO_START(fitfight);
-VIDEO_UPDATE(fitfight);
-
 static READ16_HANDLER(fitfight_700000_r)
 {
 	UINT16 data = fitfight_700000_data;
@@ -141,15 +136,15 @@ static WRITE16_HANDLER(fitfight_700000_w)
 static ADDRESS_MAP_START( fitfight_main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 
-	AM_RANGE(0x100000, 0x100001) AM_WRITE(MWA16_RAM) AM_BASE(&fof_100000)
+	AM_RANGE(0x100000, 0x100001) AM_WRITE(SMH_RAM) AM_BASE(&fof_100000)
 	//written at scanline 5, allways 1. Used by histryma/fitfight @0x0000ec2c/@0x0000f076
 
-	AM_RANGE(0x200000, 0x200001) AM_READ(input_port_0_word_r)
-	AM_RANGE(0x300000, 0x300001) AM_READ(input_port_1_word_r)	// for 'histryma' only
-	AM_RANGE(0x400000, 0x400001) AM_READ(input_port_2_word_r)
-	AM_RANGE(0x500000, 0x500001) AM_READ(input_port_3_word_r)
+	AM_RANGE(0x200000, 0x200001) AM_READ_PORT("P1_P2")
+	AM_RANGE(0x300000, 0x300001) AM_READ_PORT("EXTRA")	// for 'histryma' only
+	AM_RANGE(0x400000, 0x400001) AM_READ_PORT("SYSTEM_DSW2")
+	AM_RANGE(0x500000, 0x500001) AM_READ_PORT("DSW3_DSW1")
 
-	AM_RANGE(0x600000, 0x600001) AM_WRITE(MWA16_RAM) AM_BASE(&fof_600000)
+	AM_RANGE(0x600000, 0x600001) AM_WRITE(SMH_RAM) AM_BASE(&fof_600000)
 	//  Is 0x600000 controlling the slave audio CPU? data is 0x1111000zzzzzzzzz (9 sign. bits)
 	//  Used by histryma/fitfight:
 	//      @0x000031ae/0x00002b3a: 0xF000, once, during POST
@@ -163,27 +158,27 @@ static ADDRESS_MAP_START( fitfight_main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x700000, 0x700001) AM_WRITE(fitfight_700000_w) AM_BASE(&fof_700000)
 	//  kept at 0xe07900/0xe04c56
 
-	AM_RANGE(0x800000, 0x800001) AM_WRITE(MWA16_RAM) AM_BASE(&fof_800000)
+	AM_RANGE(0x800000, 0x800001) AM_WRITE(SMH_RAM) AM_BASE(&fof_800000)
 	//written at scanline 1, allways 0. Used by histryma/fitfight @0x00001d76/@0x00000f6a
 
-	AM_RANGE(0x900000, 0x900001) AM_WRITE(MWA16_RAM) AM_BASE(&fof_900000) //mid tilemap scroll
+	AM_RANGE(0x900000, 0x900001) AM_WRITE(SMH_RAM) AM_BASE(&fof_900000) //mid tilemap scroll
 	//  fitfigth: @0x00002b42,@0x00000f76
 	//  histryma: @0x000031b6,@0x00001d82
 
-	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(MWA16_RAM) AM_BASE(&fof_a00000) //bak tilemap scroll
+	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(SMH_RAM) AM_BASE(&fof_a00000) //bak tilemap scroll
 	//  fitfight: @0x00002b4a,@0x00000f82
 	//  histryma: @0x000031be,@0x00001d8e
 
 	AM_RANGE(0xb00000, 0xb03fff) AM_WRITENOP /* unused layer? */
-	AM_RANGE(0xb04000, 0xb07fff) AM_READWRITE(MRA16_RAM,fof_bak_tileram_w) AM_BASE(&fof_bak_tileram)
-	AM_RANGE(0xb08000, 0xb0bfff) AM_READWRITE(MRA16_RAM,fof_mid_tileram_w) AM_BASE(&fof_mid_tileram)
-	AM_RANGE(0xb0c000, 0xb0ffff) AM_READWRITE(MRA16_RAM,fof_txt_tileram_w) AM_BASE(&fof_txt_tileram)
+	AM_RANGE(0xb04000, 0xb07fff) AM_READWRITE(SMH_RAM,fof_bak_tileram_w) AM_BASE(&fof_bak_tileram)
+	AM_RANGE(0xb08000, 0xb0bfff) AM_READWRITE(SMH_RAM,fof_mid_tileram_w) AM_BASE(&fof_mid_tileram)
+	AM_RANGE(0xb0c000, 0xb0ffff) AM_READWRITE(SMH_RAM,fof_txt_tileram_w) AM_BASE(&fof_txt_tileram)
 
 	AM_RANGE(0xb10000, 0xb13fff) AM_WRITENOP //used by histryma @0x0000b25a
 	AM_RANGE(0xb14000, 0xb17fff) AM_WRITENOP //used by histryma @0x0000b25a,b270
 	AM_RANGE(0xb18000, 0xb1bfff) AM_WRITENOP //used by histryma @0x0000b25a,b270,b286
 
-	AM_RANGE(0xc00000, 0xc00fff) AM_READWRITE(MRA16_RAM,paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0xc00000, 0xc00fff) AM_READWRITE(SMH_RAM,paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE(&paletteram16)
 
 	AM_RANGE(0xd00000, 0xd007ff) AM_RAM AM_BASE(&fitfight_spriteram)
 
@@ -193,27 +188,27 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( bbprot_main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 
-	AM_RANGE(0x100000, 0x100001) AM_WRITE(MWA16_RAM) AM_BASE(&fof_100000)
+	AM_RANGE(0x100000, 0x100001) AM_WRITE(SMH_RAM) AM_BASE(&fof_100000)
 
-	AM_RANGE(0x300000, 0x300001) AM_READ(input_port_0_word_r)
-	AM_RANGE(0x380000, 0x380001) AM_READ(input_port_1_word_r)
-	AM_RANGE(0x400000, 0x400001) AM_READ(input_port_2_word_r)
-	AM_RANGE(0x480000, 0x480001) AM_READ(input_port_3_word_r)
+	AM_RANGE(0x300000, 0x300001) AM_READ_PORT("P1_P2")
+	AM_RANGE(0x380000, 0x380001) AM_READ_PORT("EXTRA")
+	AM_RANGE(0x400000, 0x400001) AM_READ_PORT("SYSTEM_DSW2")
+	AM_RANGE(0x480000, 0x480001) AM_READ_PORT("DSW3_DSW1")
 
-	AM_RANGE(0x600000, 0x600001) AM_WRITE(MWA16_RAM) AM_BASE(&fof_600000)
+	AM_RANGE(0x600000, 0x600001) AM_WRITE(SMH_RAM) AM_BASE(&fof_600000)
 
 	AM_RANGE(0x700000, 0x700001) AM_READWRITE(bbprot_700000_r,fitfight_700000_w) AM_BASE(&fof_700000)
 
-	AM_RANGE(0x800000, 0x800001) AM_WRITE(MWA16_RAM) AM_BASE(&fof_800000)
-	AM_RANGE(0x900000, 0x900001) AM_WRITE(MWA16_RAM) AM_BASE(&fof_900000)
-	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(MWA16_RAM) AM_BASE(&fof_a00000)
+	AM_RANGE(0x800000, 0x800001) AM_WRITE(SMH_RAM) AM_BASE(&fof_800000)
+	AM_RANGE(0x900000, 0x900001) AM_WRITE(SMH_RAM) AM_BASE(&fof_900000)
+	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(SMH_RAM) AM_BASE(&fof_a00000)
 
 	AM_RANGE(0xb00000, 0xb03fff) AM_WRITENOP /* unused layer? */
-	AM_RANGE(0xb04000, 0xb07fff) AM_READWRITE(MRA16_RAM,fof_bak_tileram_w) AM_BASE(&fof_bak_tileram)
-	AM_RANGE(0xb08000, 0xb0bfff) AM_READWRITE(MRA16_RAM,fof_mid_tileram_w) AM_BASE(&fof_mid_tileram)
-	AM_RANGE(0xb0c000, 0xb0ffff) AM_READWRITE(MRA16_RAM,fof_txt_tileram_w) AM_BASE(&fof_txt_tileram)
+	AM_RANGE(0xb04000, 0xb07fff) AM_READWRITE(SMH_RAM,fof_bak_tileram_w) AM_BASE(&fof_bak_tileram)
+	AM_RANGE(0xb08000, 0xb0bfff) AM_READWRITE(SMH_RAM,fof_mid_tileram_w) AM_BASE(&fof_mid_tileram)
+	AM_RANGE(0xb0c000, 0xb0ffff) AM_READWRITE(SMH_RAM,fof_txt_tileram_w) AM_BASE(&fof_txt_tileram)
 
-	AM_RANGE(0xc00000, 0xc00fff) AM_READ(MRA16_RAM)
+	AM_RANGE(0xc00000, 0xc00fff) AM_READ(SMH_RAM)
 	AM_RANGE(0xc00000, 0xc03fff) AM_WRITE(paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE(&paletteram16)
 
 	AM_RANGE(0xd00000, 0xd007ff) AM_RAM AM_BASE(&fitfight_spriteram)
@@ -226,42 +221,42 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( snd_mem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
-	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_BANK1)	/* ??? External ROM */
+	AM_RANGE(0x4000, 0x7fff) AM_READ(SMH_BANK1)	/* ??? External ROM */
 	AM_RANGE(0x8000, 0x87ff) AM_RAM
 	AM_RANGE(0xff00, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
 static READ8_HANDLER(snd_porta_r)
 {
-	//mame_printf_debug("PA R @%x\n",activecpu_get_pc());
-	return mame_rand(Machine);
+	//mame_printf_debug("PA R @%x\n",cpu_get_pc(space->cpu));
+	return mame_rand(space->machine);
 }
 
 static READ8_HANDLER(snd_portb_r)
 {
-	//mame_printf_debug("PB R @%x\n",activecpu_get_pc());
-	return mame_rand(Machine);
+	//mame_printf_debug("PB R @%x\n",cpu_get_pc(space->cpu));
+	return mame_rand(space->machine);
 }
 
 static READ8_HANDLER(snd_portc_r)
 {
-	//mame_printf_debug("PC R @%x\n",activecpu_get_pc());
-	return mame_rand(Machine);
+	//mame_printf_debug("PC R @%x\n",cpu_get_pc(space->cpu));
+	return mame_rand(space->machine);
 }
 
 static WRITE8_HANDLER(snd_porta_w)
 {
-	//mame_printf_debug("PA W %x @%x\n",data,activecpu_get_pc());
+	//mame_printf_debug("PA W %x @%x\n",data,cpu_get_pc(space->cpu));
 }
 
 static WRITE8_HANDLER(snd_portb_w)
 {
-	//mame_printf_debug("PB W %x @%x\n",data,activecpu_get_pc());
+	//mame_printf_debug("PB W %x @%x\n",data,cpu_get_pc(space->cpu));
 }
 
 static WRITE8_HANDLER(snd_portc_w)
 {
-	//mame_printf_debug("PC W %x @%x\n",data,activecpu_get_pc());
+	//mame_printf_debug("PC W %x @%x\n",data,cpu_get_pc(space->cpu));
 }
 
 static ADDRESS_MAP_START( snd_io, ADDRESS_SPACE_IO, 8 )
@@ -272,10 +267,10 @@ ADDRESS_MAP_END
 
 static INTERRUPT_GEN( snd_irq )
 {
-	cpunum_set_input_line(machine, 1,UPD7810_INTF2,HOLD_LINE);
+	cpu_set_input_line(device,UPD7810_INTF2,HOLD_LINE);
 }
 
-static UPD7810_CONFIG sound_cpu_config =
+static const UPD7810_CONFIG sound_cpu_config =
 {
     TYPE_7810,
     0
@@ -285,7 +280,7 @@ static UPD7810_CONFIG sound_cpu_config =
 /* I've put the inputs the same way they can be read in the "test mode" */
 
 static INPUT_PORTS_START( fitfight )
-	PORT_START	// 0x200000.w
+	PORT_START("P1_P2")	// 0x200000.w
 	/* players inputs -> 0xe022cc.w */
 	PORT_BIT(  0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 	PORT_BIT(  0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
@@ -304,10 +299,10 @@ static INPUT_PORTS_START( fitfight )
 	PORT_BIT(  0x4000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
 	PORT_BIT(  0x8000, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START	// 0x300000.w (unused)
+	PORT_START("EXTRA")	// 0x300000.w (unused)
 	PORT_BIT(  0xffff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	// 0x400000.w
+	PORT_START("SYSTEM_DSW2")	// 0x400000.w
 	/* LSB : system inputs -> 0xe022cf.b */
 	PORT_BIT(  0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT(  0x0002, IP_ACTIVE_LOW, IPT_COIN2 )
@@ -361,7 +356,7 @@ static INPUT_PORTS_START( fitfight )
 	PORT_DIPSETTING(      0x0600, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(      0x0700, DEF_STR( 1C_1C ) )
 
-	PORT_START	// 0x500000.w
+	PORT_START("DSW3_DSW1")	// 0x500000.w
 	/* MSB : SW3 -> 0xe04c24.b (cpl) */
 	PORT_DIPNAME( 0xe000, 0xe000, "Next Credit" )
 	PORT_DIPSETTING(      0x0000, DEF_STR( 4C_1C ) )
@@ -413,7 +408,7 @@ static INPUT_PORTS_START( fitfight )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( histryma )
-	PORT_START	// 0x200000.w
+	PORT_START("P1_P2")	// 0x200000.w
 	/* players inputs -> 0xe02cf2.w and 0xe02cf8.w */
 	PORT_BIT(  0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 	PORT_BIT(  0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
@@ -432,7 +427,7 @@ static INPUT_PORTS_START( histryma )
 	PORT_BIT(  0x4000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
 	PORT_BIT(  0x8000, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START	// 0x300000.w
+	PORT_START("EXTRA")	// 0x300000.w
 	/* LSB : players extra inputs -> 0xe02cf5.b and 0xe02cfb.b */
 	PORT_BIT(  0x0001, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT(  0x0002, IP_ACTIVE_LOW, IPT_BUTTON6 ) PORT_PLAYER(1)
@@ -445,7 +440,7 @@ static INPUT_PORTS_START( histryma )
 	/* MSB : unused */
 	PORT_BIT(  0xff00, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	// 0x400000.w
+	PORT_START("SYSTEM_DSW2")	// 0x400000.w
 	/* LSB : system inputs -> 0xe02cf7.b and 0xe02cfd.b */
 	PORT_BIT(  0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT(  0x0002, IP_ACTIVE_LOW, IPT_COIN2 )
@@ -499,7 +494,7 @@ static INPUT_PORTS_START( histryma )
 	PORT_DIPSETTING(      0x0000, DEF_STR( 4C_3C ) )
 	PORT_DIPSETTING(      0x0700, DEF_STR( 1C_1C ) )
 
-	PORT_START	// 0x500000.w
+	PORT_START("DSW3_DSW1")	// 0x500000.w
 	/* MSB : SW3 -> 0xe05872.b (cpl) */
 	PORT_DIPNAME( 0xe000, 0xe000, DEF_STR( Coin_B ) )
 	PORT_DIPSETTING(      0xe000, DEF_STR( 1C_1C ) )
@@ -555,7 +550,7 @@ INPUT_PORTS_END
    (the only difference being that there is no "Needed Points/Maximum Points"
    Dip Switch, the value always being set to "2/3") */
 static INPUT_PORTS_START( bbprot )
-	PORT_START	// 0x300000.w
+	PORT_START("P1_P2")	// 0x300000.w
 	/* players inputs -> 0xe0545e.w and 0xe05464.w */
 	PORT_BIT(  0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 	PORT_BIT(  0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
@@ -574,7 +569,7 @@ static INPUT_PORTS_START( bbprot )
 	PORT_BIT(  0x4000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
 	PORT_BIT(  0x8000, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START	// 0x380000.w
+	PORT_START("EXTRA")	// 0x380000.w
 	/* LSB : players extra inputs -> 0xe05461.b and 0xe05467.b */
 	PORT_BIT(  0x0001, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT(  0x0002, IP_ACTIVE_LOW, IPT_BUTTON6 ) PORT_PLAYER(1)
@@ -587,7 +582,7 @@ static INPUT_PORTS_START( bbprot )
 	/* MSB : unused */
 	PORT_BIT(  0xff00, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	// 0x400000.w
+	PORT_START("SYSTEM_DSW2")	// 0x400000.w
 	/* LSB : system inputs -> 0xe05463.b and 0xe05469.b */
 	PORT_BIT(  0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT(  0x0002, IP_ACTIVE_LOW, IPT_COIN2 )
@@ -641,7 +636,7 @@ static INPUT_PORTS_START( bbprot )
 	PORT_DIPSETTING(      0x0000, DEF_STR( 4C_3C ) )
 	PORT_DIPSETTING(      0x0700, DEF_STR( 1C_1C ) )
 
-	PORT_START	// 0x480000.w
+	PORT_START("DSW3_DSW1")	// 0x480000.w
 	/* MSB : SW3 -> 0xe07e82.b (cpl) */
 	PORT_DIPNAME( 0xe000, 0xe000, DEF_STR( Coin_B ) )
 	PORT_DIPSETTING(      0xe000, DEF_STR( 1C_1C ) )
@@ -734,43 +729,43 @@ static const gfx_layout bbprot_sprite_layout =
 };
 
 static GFXDECODE_START( fitfight )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, fof_tile_layout,   0x000, 256  ) /* tx tiles */
-	GFXDECODE_ENTRY( REGION_GFX1, 0, fof_tile_layout,   0x200, 256  ) /* mid tiles */
-	GFXDECODE_ENTRY( REGION_GFX1, 0, fof_tile_layout,   0x400, 256  ) /* bg tiles */
-	GFXDECODE_ENTRY( REGION_GFX2, 0, fof_sprite_layout, 0x600, 256  ) /* sprites */
+	GFXDECODE_ENTRY( "gfx1", 0, fof_tile_layout,   0x000, 256  ) /* tx tiles */
+	GFXDECODE_ENTRY( "gfx1", 0, fof_tile_layout,   0x200, 256  ) /* mid tiles */
+	GFXDECODE_ENTRY( "gfx1", 0, fof_tile_layout,   0x400, 256  ) /* bg tiles */
+	GFXDECODE_ENTRY( "gfx2", 0, fof_sprite_layout, 0x600, 256  ) /* sprites */
 
 GFXDECODE_END
 
 static GFXDECODE_START( prot )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, fof_tile_layout,     0x0000, 256  ) /* tx tiles */
-	GFXDECODE_ENTRY( REGION_GFX1, 0, fof_tile_layout,     0x0800, 256  ) /* mid tiles */
-	GFXDECODE_ENTRY( REGION_GFX1, 0, fof_tile_layout,     0x1000, 256  ) /* bg tiles */
-	GFXDECODE_ENTRY( REGION_GFX2, 0, bbprot_sprite_layout,0x1800, 256  ) /* sprites */
+	GFXDECODE_ENTRY( "gfx1", 0, fof_tile_layout,     0x0000, 256  ) /* tx tiles */
+	GFXDECODE_ENTRY( "gfx1", 0, fof_tile_layout,     0x0800, 256  ) /* mid tiles */
+	GFXDECODE_ENTRY( "gfx1", 0, fof_tile_layout,     0x1000, 256  ) /* bg tiles */
+	GFXDECODE_ENTRY( "gfx2", 0, bbprot_sprite_layout,0x1800, 256  ) /* sprites */
 
 GFXDECODE_END
 
 
 static MACHINE_DRIVER_START( fitfight )
-	MDRV_CPU_ADD_TAG("main",M68000, 12000000)
+	MDRV_CPU_ADD("main",M68000, 12000000)
 	MDRV_CPU_PROGRAM_MAP(fitfight_main_map,0)
-	MDRV_CPU_VBLANK_INT(irq2_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq2_line_hold)
 
-	MDRV_CPU_ADD(UPD7810, 12000000)
-	/* audio CPU */
+	MDRV_CPU_ADD("audio", UPD7810, 12000000)
 	MDRV_CPU_CONFIG(sound_cpu_config)
 	MDRV_CPU_PROGRAM_MAP(snd_mem, 0)
 	MDRV_CPU_IO_MAP(snd_io, 0)
-	MDRV_CPU_VBLANK_INT(snd_irq,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", snd_irq)
 
 	MDRV_GFXDECODE(fitfight)
 
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(40*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(2*8, 39*8-1, 2*8, 30*8-1)
+
 	MDRV_PALETTE_LENGTH(0x800)
 
 	MDRV_VIDEO_START(fitfight)
@@ -778,25 +773,26 @@ static MACHINE_DRIVER_START( fitfight )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(OKIM6295, 1333333) // ~8080Hz ??? TODO: find out the real frequency
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7low)
+	MDRV_SOUND_ADD("oki", OKIM6295, 1333333) // ~8080Hz ??? TODO: find out the real frequency
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7low)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( bbprot )
-	MDRV_CPU_ADD_TAG("main",M68000, 12000000)
+	MDRV_CPU_ADD("main",M68000, 12000000)
 	MDRV_CPU_PROGRAM_MAP(bbprot_main_map,0)
-	MDRV_CPU_VBLANK_INT(irq2_line_hold,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", irq2_line_hold)
 
 	MDRV_GFXDECODE(prot)
 
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(40*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(2*8, 39*8-1, 2*8, 30*8-1)
+
 	MDRV_PALETTE_LENGTH(0x2000)
 
 	MDRV_VIDEO_START(fitfight)
@@ -804,8 +800,8 @@ static MACHINE_DRIVER_START( bbprot )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(OKIM6295, 1333333) // ~8080Hz ??? TODO: find out the real frequency
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7low)
+	MDRV_SOUND_ADD("oki", OKIM6295, 1333333) // ~8080Hz ??? TODO: find out the real frequency
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7low)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -832,25 +828,25 @@ running!), but incredibly fun to see such a thing :) Hope you enjoy it!
 ***/
 
 ROM_START( fitfight )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_REGION( 0x100000, "main", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "u138_ff1.bin", 0x000001, 0x080000, CRC(165600fe) SHA1(b1987dbf34abdb6d08bdf7f71b256b62125e6517) )
 	ROM_LOAD16_BYTE( "u125_ff1.bin", 0x000000, 0x080000, CRC(2f9bdb66) SHA1(4c1ade349f1219d448453b27d4a7517966912ffa) )
 
-	ROM_REGION( 0x01c000, REGION_CPU2, 0 ) /* Sound Program */
+	ROM_REGION( 0x01c000, "audio", 0 ) /* Sound Program */
 	ROM_LOAD( "u23_ff1.bin",  0x000000, 0x004000, CRC(e2d6d768) SHA1(233e5501ffda8db48341fa66f16b630544803a89) )
 	ROM_CONTINUE(          0x010000, 0x00c000 )
 
-	ROM_REGION( 0x100000, REGION_SOUND1, 0 ) /* OKI Samples? */
+	ROM_REGION( 0x100000, "oki", 0 ) /* OKI Samples? */
 	ROM_LOAD( "h7e_ff1.bin",  0x000000, 0x080000, CRC(3e12dfd8) SHA1(8f21abfc6a6aac9ad3fafe97d0279739c7b9fab9) ) //seems to be a merge of 2 0x040000 roms
 	ROM_LOAD( "h18e_ff1.bin", 0x080000, 0x080000, CRC(a7f36dbe) SHA1(206efb7f32d6123ed3e22790ff38dd0a8e1626d7) ) //seems to be a merge of 2 0x040000 roms
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE ) /* GFX */
+	ROM_REGION( 0x100000, "gfx1", ROMREGION_DISPOSE ) /* GFX */
 	ROM_LOAD( "p1_ff1.bin",   0x0c0000, 0x040000, CRC(542593b3) SHA1(068d9b5dc98a8353462705c64d2d287f270510a9) )
 	ROM_LOAD( "p2_ff1.bin",   0x080000, 0x040000, CRC(fc517470) SHA1(45f33de393a89301051ec865ba665ad3366e29f7) )
 	ROM_LOAD( "p4_ff1.bin",   0x040000, 0x040000, CRC(a8754268) SHA1(c03ea06ba79ff799399d17dc0eb86f5a7e2e3f8e) )
 	ROM_LOAD( "p8_ff1.bin",   0x000000, 0x040000, CRC(bd55182a) SHA1(5253565fc2b73c70d9cbc8dbc9b0a201b21efa91) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_DISPOSE ) /* Sprites */
+	ROM_REGION( 0x400000, "gfx2", ROMREGION_DISPOSE ) /* Sprites */
 	ROM_LOAD( "s1_ff1.bin",   0x300000, 0x080000, CRC(90a57445) SHA1(44a88de1377d685c2bc185187b5ba151d900792d) )
 	ROM_LOAD( "s1_ff1h.bin",  0x380000, 0x080000, CRC(07e23f95) SHA1(c2af437199f352264e5238547f9d14639cb6f329) )
 
@@ -886,25 +882,25 @@ It was dumped from a faulty board, wich doesn't boot, but with intact eproms :)
 ***/
 
 ROM_START( histryma )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_REGION( 0x100000, "main", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "l_th.bin", 0x000001, 0x080000, CRC(5af9356a) SHA1(f3d797dcc528a3a2a4f0ebbf07d59bd2cc868622) )
 	ROM_LOAD16_BYTE( "r_th.bin", 0x000000, 0x080000, CRC(1a44b504) SHA1(621d95b67d413da3e8a90c0cde494b2529b92407) )
 
-	ROM_REGION( 0x01c000, REGION_CPU2, 0 ) /* Sound Program */
+	ROM_REGION( 0x01c000, "audio", 0 ) /* Sound Program */
 	ROM_LOAD( "y61f.bin",  0x000000, 0x004000, CRC(b588525a) SHA1(b768bd75d6351430f9656289146119e9c0308554) )
 	ROM_CONTINUE(          0x010000, 0x00c000 )
 
-	ROM_REGION( 0x100000, REGION_SOUND1, 0 ) /* OKI Samples? */
+	ROM_REGION( 0x100000, "oki", 0 ) /* OKI Samples? */
 	ROM_LOAD( "u7_th.bin",  0x000000, 0x080000, CRC(88b41ef5) SHA1(565e2c4554dde79cd2da8b8a181b3378818223cc) ) //seems to be a merge of 2 0x040000 roms
 	ROM_LOAD( "u18_th.bin", 0x080000, 0x080000, CRC(a734cd77) SHA1(3fe4cba6f6d691dfc4775de634e6e39bf4bb08b8) ) //seems to be a merge of 2 0x040000 roms
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE ) /* GFX */
+	ROM_REGION( 0x100000, "gfx1", ROMREGION_DISPOSE ) /* GFX */
 	ROM_LOAD( "p1_th.bin",   0x0c0000, 0x040000, CRC(501c5336) SHA1(1743221d73d59ba40ddad3f69bc4aa1a51c29962) )
 	ROM_LOAD( "p2_th.bin",   0x080000, 0x040000, CRC(f50666c7) SHA1(46856e70426388c9704eed94d4dbbbe5674b9be6) )
 	ROM_LOAD( "p4_th.bin",   0x040000, 0x040000, CRC(c70223cf) SHA1(d3ee1b73a22a0aaab909141b32696c6b48f2b7ee) )
 	ROM_LOAD( "p8_th.bin",   0x000000, 0x040000, CRC(8104b963) SHA1(ed02c3be16b8e94d9316391fe0f9fcf39679c1de) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_DISPOSE ) /* Sprites */
+	ROM_REGION( 0x400000, "gfx2", ROMREGION_DISPOSE ) /* Sprites */
 	ROM_LOAD( "s1_th.bin",   0x300000, 0x080000, CRC(e9c2d27a) SHA1(f47cc318f4a3db84858b4d302be4063f3bb1b071) )
 	ROM_LOAD( "s1h_th.bin",  0x380000, 0x080000, CRC(d806c92e) SHA1(4781dd08755cd91f3d09ff418a9d13744d888922) )
 
@@ -951,17 +947,17 @@ but with a different date wrote on the stickers, those are the ??_DD_MM.bin file
 ***/
 
 ROM_START( bbprot )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_REGION( 0x100000, "main", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "l_bb.bin", 0x000001, 0x080000, CRC(2b7b9a9a) SHA1(51088358814cc337af150526ac7fd6216c102299) )
 	ROM_LOAD16_BYTE( "r_bb.bin", 0x000000, 0x080000, CRC(28480f3e) SHA1(b89533fd01781e1b83c98b0b61a77f554fbdb4f3) )
 
-	ROM_REGION( 0x200000, REGION_GFX1, ROMREGION_DISPOSE ) /* BG GFX */
+	ROM_REGION( 0x200000, "gfx1", ROMREGION_DISPOSE ) /* BG GFX */
 	ROM_LOAD( "p1_29_11.bin",   0x180000, 0x080000, CRC(e7da36c1) SHA1(c7ea40b57088145019c1be3e34ba9e94c60bef78) )
 	ROM_LOAD( "p2_29_11.bin",   0x100000, 0x080000, CRC(0411e1aa) SHA1(99ae1a45848f8227899989334f3035222bd5da39) )
 	ROM_LOAD( "p4_29_11.bin",   0x080000, 0x080000, CRC(885942bf) SHA1(d9bde8c12be7d02dde442873e0852c7c85478254) )
 	ROM_LOAD( "p8_29_11.bin",   0x000000, 0x080000, CRC(44f94575) SHA1(90c1a97e70d312b4475ce2d333e110e027c377b9) )
 
-	ROM_REGION( 0x780000, REGION_GFX2, ROMREGION_DISPOSE ) /* Sprites */
+	ROM_REGION( 0x780000, "gfx2", ROMREGION_DISPOSE ) /* Sprites */
 	ROM_LOAD( "s1_21_12.bin",  0x600000, 0x080000, CRC(0b396256) SHA1(6e69641cd012e60618a68386342108d04e826e3c) )
 	ROM_LOAD( "s1_x.bin",      0x700000, 0x080000, CRC(b95dfbb8) SHA1(b37452900b07bc13bc9d1702ef1ff737ff0f393c) )
 	ROM_LOAD( "s1_h.bin",      0x680000, 0x080000, CRC(d20b6ac3) SHA1(8b6a5f1da47be456da528ddaaf18e2321261683e) )
@@ -987,17 +983,17 @@ ROM_END
 
 static DRIVER_INIT( fitfight )
 {
-//  UINT16 *mem16 = (UINT16 *)memory_region(REGION_CPU1);
+//  UINT16 *mem16 = (UINT16 *)memory_region(machine, "main");
 //  mem16[0x0165B2/2]=0x4e71; // for now so it boots
-	memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0x700000, 0x700001, 0, 0, fitfight_700000_r);
+	memory_install_read16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x700000, 0x700001, 0, 0, fitfight_700000_r);
 	bbprot_kludge = 0;
 }
 
 static DRIVER_INIT( histryma )
 {
-//  UINT16 *mem16 = (UINT16 *)memory_region(REGION_CPU1);
+//  UINT16 *mem16 = (UINT16 *)memory_region(machine, "main");
 //  mem16[0x017FDC/2]=0x4e71; // for now so it boots
-	memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0x700000, 0x700001, 0, 0, histryma_700000_r);
+	memory_install_read16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x700000, 0x700001, 0, 0, histryma_700000_r);
 	bbprot_kludge = 0;
 }
 
