@@ -40,7 +40,7 @@ Dumping Notes:
 
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
 #include "machine/laserdsc.h"
 
 /* Assumed to be the same as segald hardware */
@@ -50,16 +50,17 @@ static UINT8 nmi_enable;
 static UINT8 start_lamp;
 static UINT8 ldp_read_latch;
 static UINT8 ldp_write_latch;
+static UINT8 brake_gas;
 
 static UINT8* tile_RAM;
 static UINT8* sprite_RAM;
 static UINT8* palette_RAM;
 
-static laserdisc_info *discinfo;
+static const device_config *laserdisc;
 
 
 /* VIDEO GOODS */
-static void gpworld_draw_tiles(running_machine *machine, mame_bitmap *bitmap,const rectangle *cliprect)
+static void gpworld_draw_tiles(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect)
 {
 	UINT8 characterX, characterY;
 
@@ -76,9 +77,9 @@ static void gpworld_draw_tiles(running_machine *machine, mame_bitmap *bitmap,con
 	}
 }
 
-INLINE void draw_pixel(mame_bitmap *bitmap,const rectangle *cliprect,int x,int y,int color)
+INLINE void draw_pixel(bitmap_t *bitmap,const rectangle *cliprect,int x,int y,int color,int flip)
 {
-	if (flip_screen)
+	if (flip)
 	{
 		x = bitmap->width - x - 1;
 		y = bitmap->height - y - 1;
@@ -93,7 +94,7 @@ INLINE void draw_pixel(mame_bitmap *bitmap,const rectangle *cliprect,int x,int y
 	*BITMAP_ADDR32(bitmap, y, x) = color;
 }
 
-static void gpworld_draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect)
+static void gpworld_draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	const int SPR_Y_TOP     = 0;
 	const int SPR_Y_BOTTOM  = 1;
@@ -103,10 +104,11 @@ static void gpworld_draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect)
 	const int SPR_SKIP_HI   = 5;
 	const int SPR_GFXOFS_LO = 6;
 	const int SPR_GFXOFS_HI = 7;
+	int flip = flip_screen_get(machine);
 
 	int i;
 
-	UINT8 *GFX = memory_region(REGION_GFX2);
+	UINT8 *GFX = memory_region(machine, "gfx2");
 
 	/* Heisted from Daphne which heisted it from MAME */
 	for (i = 0; i < 0x800; i += 8)
@@ -133,7 +135,7 @@ static void gpworld_draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect)
 
             logerror("%02x %02x %02x %02x %02x %02x %02x %02x\n", spr_reg[SPR_Y_TOP], spr_reg[SPR_Y_BOTTOM], spr_reg[SPR_X_LO], spr_reg[SPR_X_HI],
                                                                   spr_reg[SPR_SKIP_LO], spr_reg[SPR_SKIP_HI], spr_reg[SPR_GFXOFS_LO], spr_reg[SPR_GFXOFS_HI]);
-            draw_pixel(bitmap,cliprect,sx,sy,0xffffffff);
+            draw_pixel(bitmap,cliprect,sx,sy,0xffffffff,flip);
 */
 
 			for (row = 0; row < height; row++)
@@ -179,10 +181,10 @@ static void gpworld_draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect)
 					}
 
 					/* Daphne says "don't draw the pixel if it's black". */
-					draw_pixel(bitmap,cliprect,x+0,y,palette_get_color(Machine, pixel1 + (sprite_color*0x10 + 0x200)));
-					draw_pixel(bitmap,cliprect,x+1,y,palette_get_color(Machine, pixel2 + (sprite_color*0x10 + 0x200)));
-					draw_pixel(bitmap,cliprect,x+2,y,palette_get_color(Machine, pixel3 + (sprite_color*0x10 + 0x200)));
-					draw_pixel(bitmap,cliprect,x+3,y,palette_get_color(Machine, pixel4 + (sprite_color*0x10 + 0x200)));
+					draw_pixel(bitmap,cliprect,x+0,y,palette_get_color(machine, pixel1 + (sprite_color*0x10 + 0x200)),flip);
+					draw_pixel(bitmap,cliprect,x+1,y,palette_get_color(machine, pixel2 + (sprite_color*0x10 + 0x200)),flip);
+					draw_pixel(bitmap,cliprect,x+2,y,palette_get_color(machine, pixel3 + (sprite_color*0x10 + 0x200)),flip);
+					draw_pixel(bitmap,cliprect,x+3,y,palette_get_color(machine, pixel4 + (sprite_color*0x10 + 0x200)),flip);
 
 					x += 4;
 
@@ -204,19 +206,20 @@ static void gpworld_draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect)
 
 static VIDEO_UPDATE( gpworld )
 {
-	fillbitmap(bitmap, 0, cliprect);
+	bitmap_fill(bitmap, cliprect, 0);
 
-	gpworld_draw_tiles(machine, bitmap, cliprect);
-	gpworld_draw_sprites(bitmap, cliprect);
-
-	/* display disc information */
-	if (discinfo != NULL)
-		popmessage("%s", laserdisc_describe_state(discinfo));
+	gpworld_draw_tiles(screen->machine, bitmap, cliprect);
+	gpworld_draw_sprites(screen->machine, bitmap, cliprect);
 
 	return 0;
 }
 
 
+static MACHINE_START( gpworld )
+{
+	laserdisc = device_list_find_by_tag(machine->config->devicelist, LASERDISC, "laserdisc");
+}
+
 
 /* MEMORY HANDLERS */
 /* READS */
@@ -225,6 +228,15 @@ static READ8_HANDLER( ldp_read )
 	return ldp_read_latch;
 }
 
+static READ8_HANDLER( pedal_in )
+{
+	if (brake_gas)
+		return 	input_port_read(space->machine, "INACCEL");
+
+	return 	input_port_read(space->machine, "INBRAKE");
+
+}
+
 /* WRITES */
 static WRITE8_HANDLER( ldp_write )
 {
@@ -235,15 +247,20 @@ static WRITE8_HANDLER( misc_io_write )
 {
 	start_lamp = (data & 0x04) >> 1;
 	nmi_enable = (data & 0x40) >> 6;
-/*  dunno      = (data & 0x80) >> 7; */
+	/*  dunno      = (data & 0x80) >> 7; */ //coin counter???
 
 	logerror("NMI : %x (0x%x)\n", nmi_enable, data);
 }
 
+static WRITE8_HANDLER( brake_gas_write )
+{
+	brake_gas = data & 0x01;
+}
+
 static WRITE8_HANDLER( palette_write )
 {
 	/* This is all just a (bad) guess */
-	int pal_index, r, g, b;
+	int pal_index, r, g, b, a;
 
 	palette_RAM[offset] = data;
 
@@ -253,11 +270,11 @@ static WRITE8_HANDLER( palette_write )
 	b = (palette_RAM[pal_index]   & 0xf0) << 0;
 	g = (palette_RAM[pal_index]   & 0x0f) << 4;
 	r = (palette_RAM[pal_index+1] & 0x0f) << 4;
-	/* int dunno = (palette_RAM[pal_index+1] & 0x80) >> 7; */
+	a = (palette_RAM[pal_index+1] & 0x80) ? 0 : 255;	/* guess */
 
 	/* logerror("PAL WRITE index : %x  rgb : %d %d %d (real %x) at %x\n", pal_index, r,g,b, data, offset); */
 
-	palette_set_color(Machine, pal_index, MAKE_RGB(r, g, b));
+	palette_set_color(space->machine, pal_index, MAKE_ARGB(a, r, g, b));
 }
 
 /* PROGRAM MAP */
@@ -268,10 +285,10 @@ static ADDRESS_MAP_START( mainmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xd000,0xd7ff) AM_RAM AM_BASE(&tile_RAM)
 	AM_RANGE(0xd800,0xd800) AM_READWRITE(ldp_read,ldp_write)
 /*  AM_RANGE(0xd801,0xd801) AM_READ(???) */
-	AM_RANGE(0xda00,0xda00) AM_READ_PORT("INWHEEL")
+	AM_RANGE(0xda00,0xda00) AM_READ_PORT("INWHEEL")	//8255 here....
 /*  AM_RANGE(0xda01,0xda01) AM_WRITE(???) */					/* These inputs are interesting - there are writes and reads all over these addr's */
-/*  AM_RANGE(0xda02,0xda02) AM_READ_PORT("???") */				/* Reads here during the input test. */
-	AM_RANGE(0xda20,0xda20) AM_READ_PORT("INACCEL")				/* Seems to control both the brake and accel at once - maybe tied to 0xda02? Or to the writes here... */
+	AM_RANGE(0xda02,0xda02) AM_WRITE(brake_gas_write)				/*bit 0 select gas/brake input */
+	AM_RANGE(0xda20,0xda20) AM_READ(pedal_in)
 
 	AM_RANGE(0xe000,0xffff) AM_RAM								/* Potentially not all work RAM? */
 ADDRESS_MAP_END
@@ -279,7 +296,7 @@ ADDRESS_MAP_END
 
 /* I/O MAP */
 static ADDRESS_MAP_START( mainport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x01,0x01) AM_WRITE(misc_io_write)
 	AM_RANGE(0x80,0x80) AM_READ_PORT("IN0")
 	AM_RANGE(0x81,0x81) AM_READ_PORT("IN1")
@@ -290,7 +307,7 @@ ADDRESS_MAP_END
 
 /* PORTS */
 static INPUT_PORTS_START( gpworld )
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -300,7 +317,7 @@ static INPUT_PORTS_START( gpworld )
 	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("IN1")
+	PORT_START("IN1")
 	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )		/* maybe? it's not listed in the test screen. */
 	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_SERVICE )
@@ -310,7 +327,7 @@ static INPUT_PORTS_START( gpworld )
 	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("INWHEEL")
+	PORT_START("INWHEEL")
 	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME( "SLIGHT RIGHT" ) PORT_CODE( KEYCODE_Y )
 	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME( "MEDIUM RIGHT" ) PORT_CODE( KEYCODE_U )
 	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME( "STRONG RIGHT" ) PORT_CODE( KEYCODE_I )
@@ -320,10 +337,13 @@ static INPUT_PORTS_START( gpworld )
 	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME( "STRONG LEFT" ) PORT_CODE( KEYCODE_E )
 	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME( "FIERCE LEFT" ) PORT_CODE( KEYCODE_W )
 
-	PORT_START_TAG("INACCEL")	/* both accelerator & brake right now :P */
+	PORT_START("INACCEL")
 	PORT_BIT( 0xff, 0x00, IPT_PEDAL ) PORT_SENSITIVITY(30) PORT_KEYDELTA(10) PORT_PLAYER(1)
 
-	PORT_START_TAG("DSW1")
+	PORT_START("INBRAKE")
+	PORT_BIT( 0xff, 0x00, IPT_PEDAL2 ) PORT_SENSITIVITY(30) PORT_KEYDELTA(10) PORT_PLAYER(1)
+
+	PORT_START("DSW1")
 	PORT_DIPNAME( 0xf0, 0xf0, DEF_STR( Coin_A ) ) PORT_DIPLOCATION("SW1:1,2,3,4")
 	PORT_DIPSETTING(    0x70, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( 3C_1C ) )
@@ -359,7 +379,7 @@ static INPUT_PORTS_START( gpworld )
 	PORT_DIPSETTING(    0x0b, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0x0a, DEF_STR( 1C_6C ) )
 
-	PORT_START_TAG("DSW2")
+	PORT_START("DSW2")
 	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Demo_Sounds ) ) PORT_DIPLOCATION("SW2:1")
 	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -385,15 +405,9 @@ static INPUT_PORTS_START( gpworld )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 INPUT_PORTS_END
 
-static MACHINE_START( gpworld )
-{
-	discinfo = laserdisc_init(LASERDISC_TYPE_LDV1000, get_disk_handle(0), 0);
-	return;
-}
-
 static TIMER_CALLBACK( irq_stop )
 {
-	cpunum_set_input_line(machine, 0, 0, CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], 0, CLEAR_LINE);
 }
 
 static INTERRUPT_GEN( vblank_callback_gpworld )
@@ -401,16 +415,14 @@ static INTERRUPT_GEN( vblank_callback_gpworld )
 	/* Do an NMI if the enabled bit is set */
 	if (nmi_enable)
 	{
-		laserdisc_data_w(discinfo,ldp_write_latch);
-		ldp_read_latch  = laserdisc_data_r(discinfo);
-		cpunum_set_input_line(machine, 0, INPUT_LINE_NMI, PULSE_LINE);
+		laserdisc_data_w(laserdisc,ldp_write_latch);
+		ldp_read_latch  = laserdisc_data_r(laserdisc);
+		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 	}
 
 	/* The time the IRQ line stays high is set just long enough to happen after the NMI - hacky? */
-	cpunum_set_input_line(machine, 0, 0, ASSERT_LINE);
-	timer_set(ATTOTIME_IN_USEC(100), NULL, 0, irq_stop);
-
-	laserdisc_vsync(discinfo);
+	cpu_set_input_line(device, 0, ASSERT_LINE);
+	timer_set(device->machine, ATTOTIME_IN_USEC(100), NULL, 0, irq_stop);
 }
 
 static const gfx_layout gpworld_tile_layout =
@@ -425,47 +437,51 @@ static const gfx_layout gpworld_tile_layout =
 };
 
 static GFXDECODE_START( gpworld )
-	GFXDECODE_ENTRY(REGION_GFX1, 0, gpworld_tile_layout, 0x0, 0x100)
+	GFXDECODE_ENTRY("gfx1", 0, gpworld_tile_layout, 0x0, 0x100)
 GFXDECODE_END
 
 /* DRIVER */
 static MACHINE_DRIVER_START( gpworld )
-/*  main cpu */
-	MDRV_CPU_ADD(Z80, GUESSED_CLOCK)
+
+	/* main cpu */
+	MDRV_CPU_ADD("main", Z80, GUESSED_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(mainmem,0)
 	MDRV_CPU_IO_MAP(mainport,0)
-	MDRV_CPU_VBLANK_INT(vblank_callback_gpworld, 1)
+	MDRV_CPU_VBLANK_INT("main", vblank_callback_gpworld)
 
 	MDRV_MACHINE_START(gpworld)
 
-/*  video */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_LASERDISC_ADD("laserdisc", PIONEER_LDV1000, "main", "ldsound")
+	MDRV_LASERDISC_OVERLAY(gpworld, 512, 256, BITMAP_FORMAT_INDEXED16)
 
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 0*8, 32*8-1)
+	/* video hardware */
+	MDRV_LASERDISC_SCREEN_ADD_NTSC("main", BITMAP_FORMAT_INDEXED16)
 
 	MDRV_GFXDECODE(gpworld)
 	MDRV_PALETTE_LENGTH(1024)
-	MDRV_VIDEO_UPDATE(gpworld)
 
+	/* sound hardware */
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD("ldsound", CUSTOM, 0)
+	MDRV_SOUND_CONFIG(laserdisc_custom_interface)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
 ROM_START( gpworld )
-	ROM_REGION( 0xc000, REGION_CPU1, 0 )
+	ROM_REGION( 0xc000, "main", 0 )
 	ROM_LOAD( "epr6162a.ic51", 0x0000, 0x4000, CRC(70e42574) SHA1(2fa50c7a67a2efb6b2c313850ace40e42d18b0a8) )
 	ROM_LOAD( "epr6163.ic67",  0x4000, 0x4000, CRC(49539e46) SHA1(7cfd5b6b356c3fa5439e6fe3ac2e6a097b722a2c) )
 	ROM_LOAD( "epr6164.ic83",  0x8000, 0x4000, CRC(7f0e6853) SHA1(c255ac6e4b61faa8da9b5aa70f12c868b81acfe1) )
 
 	/* Tiles */
-	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "epr6148.ic18", 0x0000, 0x1000, CRC(a4b11cf5) SHA1(9697494335089b13071d773812eec373ef5b358c) )
 
 	/* Sprites */
-	ROM_REGION( 0x30000, REGION_GFX2, 0 )
+	ROM_REGION( 0x30000, "gfx2", 0 )
 	ROM_LOAD( "epr6149.ic111", 0x00000, 0x4000, CRC(7e6c4797) SHA1(acf934e1f3f55a0d1cd1630f6a78f9954f1ec53f) )
 	ROM_LOAD( "epr6151.ic110", 0x04000, 0x4000, CRC(26d72b96) SHA1(759ef85877edfc37f2a1a242bf1c9b0e8d5e9a88) )
 	ROM_LOAD( "epr6150.ic128", 0x08000, 0x4000, CRC(6837e095) SHA1(b2ac8341fcf0037d186b0759227597643ca0336d) )
@@ -480,10 +496,13 @@ ROM_START( gpworld )
 	/*                 ic123 Unpopulated? */
 
 	/* Misc PROMs */
-	ROM_REGION( 0x0220, REGION_PROMS, 0 )
+	ROM_REGION( 0x0220, "proms", 0 )
 	ROM_LOAD( "pr6146.ic2",  0x000, 0x020, CRC(d10801a0) SHA1(89e9ac0d9c9eee6efd5455a3416c436ceda8f632) )
 	ROM_LOAD( "pr6147.ic28", 0x020, 0x100, CRC(b7173df9) SHA1(044beda43cb1793033021a08b3ee3441d5ffe6c3) )
 	ROM_LOAD( "pr5501.ic14", 0x120, 0x100, CRC(1bdf71d4) SHA1(ac52e948cce6df4abb7543c08e2c6454efd63e79) )
+
+	DISK_REGION( "laserdisc" )
+	DISK_IMAGE_READONLY( "gpworld", 0, NO_DUMP )
 ROM_END
 
 
@@ -491,6 +510,7 @@ static DRIVER_INIT( gpworld )
 {
 	nmi_enable = 0;
 	start_lamp = 0;
+	brake_gas = 0;
 	ldp_write_latch = ldp_read_latch = 0;
 }
 
