@@ -63,7 +63,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "cpu/m68000/m68000.h"
 #include "video/taitoic.h"
 #include "machine/eeprom.h"
@@ -97,7 +96,7 @@ static WRITE32_HANDLER( color_ram_w )
 		g = (a &0xff00) >> 8;
 		b = (a &0xff);
 
-		palette_set_color(Machine,offset,MAKE_RGB(r,g,b));
+		palette_set_color(space->machine,offset,MAKE_RGB(r,g,b));
 	}
 }
 
@@ -108,7 +107,7 @@ static WRITE32_HANDLER( color_ram_w )
 
 static TIMER_CALLBACK( groundfx_interrupt5 )
 {
-	cpunum_set_input_line(machine, 0,5,HOLD_LINE); //from 5... ADC port
+	cpu_set_input_line(machine->cpu[0],5,HOLD_LINE); //from 5... ADC port
 }
 
 
@@ -128,7 +127,7 @@ static const UINT8 default_eeprom[128]=
 	0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff,0xff
 };
 
-static const struct EEPROM_interface groundfx_eeprom_interface =
+static const eeprom_interface groundfx_eeprom_interface =
 {
 	6,				/* address bits */
 	16,				/* data bits */
@@ -142,13 +141,13 @@ static const struct EEPROM_interface groundfx_eeprom_interface =
 static NVRAM_HANDLER( groundfx )
 {
 	if (read_or_write)
-		EEPROM_save(file);
+		eeprom_save(file);
 	else {
-		EEPROM_init(&groundfx_eeprom_interface);
+		eeprom_init(machine, &groundfx_eeprom_interface);
 		if (file)
-			EEPROM_load(file);
+			eeprom_load(file);
 		else
-			EEPROM_set_data(default_eeprom,128);  /* Default the gun setup values */
+			eeprom_set_data(default_eeprom,128);  /* Default the gun setup values */
 	}
 }
 
@@ -157,24 +156,14 @@ static NVRAM_HANDLER( groundfx )
             GAME INPUTS
 **********************************************************/
 
-
-static READ32_HANDLER( groundfx_input_r )
+static CUSTOM_INPUT( frame_counter_r )
 {
-	switch (offset)
-	{
-		case 0x00:
-		{
-			return (input_port_0_word_r(0,0) << 16) | input_port_1_word_r(0,0) |
-				  (EEPROM_read_bit() << 7) | frame_counter;
-		}
+	return frame_counter;
+}
 
-		case 0x01:
-		{
-			return input_port_2_word_r(0,0) | (coin_word << 16);
-		}
- 	}
-
-	return 0xffffffff;
+static CUSTOM_INPUT( coin_word_r )
+{
+	return coin_word;
 }
 
 static WRITE32_HANDLER( groundfx_input_w )
@@ -183,16 +172,16 @@ static WRITE32_HANDLER( groundfx_input_w )
 	{
 		case 0x00:
 		{
-			if (ACCESSING_MSB32)	/* $500000 is watchdog */
+			if (ACCESSING_BITS_24_31)	/* $500000 is watchdog */
 			{
-				watchdog_reset_w(0,data >> 24);
+				watchdog_reset(space->machine);
 			}
 
-			if (ACCESSING_LSB32)
+			if (ACCESSING_BITS_0_7)
 			{
-				EEPROM_set_clock_line((data & 0x20) ? ASSERT_LINE : CLEAR_LINE);
-				EEPROM_write_bit(data & 0x40);
-				EEPROM_set_cs_line((data & 0x10) ? CLEAR_LINE : ASSERT_LINE);
+				eeprom_set_clock_line((data & 0x20) ? ASSERT_LINE : CLEAR_LINE);
+				eeprom_write_bit(data & 0x40);
+				eeprom_set_cs_line((data & 0x10) ? CLEAR_LINE : ASSERT_LINE);
 				return;
 			}
 
@@ -201,7 +190,7 @@ static WRITE32_HANDLER( groundfx_input_w )
 
 		case 0x01:
 		{
-			if (ACCESSING_MSB32)
+			if (ACCESSING_BITS_24_31)
 			{
 				coin_lockout_w(0,~data & 0x01000000);
 				coin_lockout_w(1,~data & 0x02000000);
@@ -215,25 +204,25 @@ static WRITE32_HANDLER( groundfx_input_w )
 
 static READ32_HANDLER( groundfx_adc_r )
 {
-	return (input_port_3_word_r(0,0) << 8) | input_port_4_word_r(0,0);
+	return (input_port_read(space->machine, "AN0") << 8) | input_port_read(space->machine, "AN1");
 }
 
 static WRITE32_HANDLER( groundfx_adc_w )
 {
 	/* One interrupt per input port (4 per frame, though only 2 used).
         1000 cycle delay is arbitrary */
-	timer_set(ATTOTIME_IN_CYCLES(1000,0), NULL, 0, groundfx_interrupt5);
+	timer_set(space->machine, cpu_clocks_to_attotime(space->cpu,1000), NULL, 0, groundfx_interrupt5);
 }
 
 static WRITE32_HANDLER( rotate_control_w )	/* only a guess that it's rotation */
 {
-		if (ACCESSING_LSW32)
+		if (ACCESSING_BITS_0_15)
 		{
 			groundfx_rotate_ctrl[port_sel] = data;
 			return;
 		}
 
-		if (ACCESSING_MSW32)
+		if (ACCESSING_BITS_16_31)
 		{
 			port_sel = (data &0x70000) >> 16;
 		}
@@ -261,35 +250,36 @@ static WRITE32_HANDLER( motor_control_w )
 ***********************************************************/
 
 static ADDRESS_MAP_START( groundfx_readmem, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x1fffff) AM_READ(MRA32_ROM)
-	AM_RANGE(0x200000, 0x21ffff) AM_READ(MRA32_RAM)	/* main CPUA ram */
-	AM_RANGE(0x300000, 0x303fff) AM_READ(MRA32_RAM)	/* sprite ram */
-	AM_RANGE(0x500000, 0x500007) AM_READ(groundfx_input_r)
+	AM_RANGE(0x000000, 0x1fffff) AM_READ(SMH_ROM)
+	AM_RANGE(0x200000, 0x21ffff) AM_READ(SMH_RAM)	/* main CPUA ram */
+	AM_RANGE(0x300000, 0x303fff) AM_READ(SMH_RAM)	/* sprite ram */
+	AM_RANGE(0x500000, 0x500003) AM_READ_PORT("BUTTONS")
+	AM_RANGE(0x500004, 0x500007) AM_READ_PORT("SYSTEM")
 	AM_RANGE(0x600000, 0x600003) AM_READ(groundfx_adc_r)
-	AM_RANGE(0x700000, 0x7007ff) AM_READ(MRA32_RAM)
+	AM_RANGE(0x700000, 0x7007ff) AM_READ(SMH_RAM)
 	AM_RANGE(0x800000, 0x80ffff) AM_READ(TC0480SCP_long_r)	  /* tilemaps */
 	AM_RANGE(0x830000, 0x83002f) AM_READ(TC0480SCP_ctrl_long_r)	// debugging
 	AM_RANGE(0x900000, 0x90ffff) AM_READ(TC0100SCN_long_r)	/* piv tilemaps */
 	AM_RANGE(0x920000, 0x92000f) AM_READ(TC0100SCN_ctrl_long_r)
-	AM_RANGE(0xa00000, 0xa0ffff) AM_READ(MRA32_RAM) /* palette ram */
-	AM_RANGE(0xb00000, 0xb003ff) AM_READ(MRA32_RAM)	// ?? single bytes
-	AM_RANGE(0xc00000, 0xc00007) AM_READ(MRA32_NOP) /* Network? */
+	AM_RANGE(0xa00000, 0xa0ffff) AM_READ(SMH_RAM) /* palette ram */
+	AM_RANGE(0xb00000, 0xb003ff) AM_READ(SMH_RAM)	// ?? single bytes
+	AM_RANGE(0xc00000, 0xc00007) AM_READ(SMH_NOP) /* Network? */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( groundfx_writemem, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x1fffff) AM_WRITE(MWA32_ROM)
-	AM_RANGE(0x200000, 0x21ffff) AM_WRITE(MWA32_RAM) AM_BASE(&groundfx_ram)
-	AM_RANGE(0x300000, 0x303fff) AM_WRITE(MWA32_RAM) AM_BASE(&spriteram32) AM_SIZE(&spriteram_size)
+	AM_RANGE(0x000000, 0x1fffff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x200000, 0x21ffff) AM_WRITE(SMH_RAM) AM_BASE(&groundfx_ram)
+	AM_RANGE(0x300000, 0x303fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram32) AM_SIZE(&spriteram_size)
 	AM_RANGE(0x400000, 0x400003) AM_WRITE(motor_control_w)	/* gun vibration */
-	AM_RANGE(0x500000, 0x500007) AM_WRITE(groundfx_input_w)	/* eerom etc. */
+	AM_RANGE(0x500000, 0x500007) AM_WRITE(groundfx_input_w)	/* eeprom etc. */
 	AM_RANGE(0x600000, 0x600003) AM_WRITE(groundfx_adc_w)
-	AM_RANGE(0x700000, 0x7007ff) AM_WRITE(MWA32_RAM) AM_BASE(&f3_shared_ram)
+	AM_RANGE(0x700000, 0x7007ff) AM_WRITE(SMH_RAM) AM_BASE(&f3_shared_ram)
 	AM_RANGE(0x800000, 0x80ffff) AM_WRITE(TC0480SCP_long_w)	  /* tilemaps */
 	AM_RANGE(0x830000, 0x83002f) AM_WRITE(TC0480SCP_ctrl_long_w)
 	AM_RANGE(0x900000, 0x90ffff) AM_WRITE(TC0100SCN_long_w)	/* piv tilemaps */
 	AM_RANGE(0x920000, 0x92000f) AM_WRITE(TC0100SCN_ctrl_long_w)
 	AM_RANGE(0xa00000, 0xa0ffff) AM_WRITE(color_ram_w) AM_BASE(&paletteram32)
-	AM_RANGE(0xb00000, 0xb003ff) AM_WRITE(MWA32_RAM)	// single bytes, blending ??
+	AM_RANGE(0xb00000, 0xb003ff) AM_WRITE(SMH_RAM)	// single bytes, blending ??
 	AM_RANGE(0xd00000, 0xd00003) AM_WRITE(rotate_control_w)	/* perhaps port based rotate control? */
 	/* f00000 is seat control? */
 ADDRESS_MAP_END
@@ -299,47 +289,46 @@ ADDRESS_MAP_END
 ***********************************************************/
 
 static INPUT_PORTS_START( groundfx )
-	PORT_START      /* IN0 */
-	PORT_BIT( 0xffff, IP_ACTIVE_LOW,  IPT_UNUSED )
+	PORT_START("BUTTONS")
+	PORT_BIT( 0x00000001, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(frame_counter_r, NULL)
+	PORT_BIT( 0x00000002, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00000004, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00000008, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00000010, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00000020, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00000040, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00000080, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(eeprom_bit_r, NULL)
+	PORT_BIT( 0x00000100, IP_ACTIVE_LOW, IPT_BUTTON3 )		/* shift hi */
+	PORT_BIT( 0x00000200, IP_ACTIVE_LOW, IPT_BUTTON1 )		/* brake */
+	PORT_BIT( 0x00000400, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00000800, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00001000, IP_ACTIVE_LOW, IPT_BUTTON2 )		/* shift low */
+	PORT_BIT( 0x00002000, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00004000, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00008000, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0xffff0000, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START      /* IN1 */
-	PORT_BIT( 0x0001, IP_ACTIVE_HIGH,  IPT_SPECIAL ) /* Frame counter */
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x0020, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x0040, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x0080, IP_ACTIVE_HIGH, IPT_SPECIAL )	/* reserved for EEROM */
-	PORT_BIT( 0x0100, IP_ACTIVE_LOW,  IPT_BUTTON3 ) /* shift hi */
-	PORT_BIT( 0x0200, IP_ACTIVE_LOW,  IPT_BUTTON1 ) /* brake */
-	PORT_BIT( 0x0400, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x0800, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x1000, IP_ACTIVE_LOW,  IPT_BUTTON2 ) /* shift low */
-	PORT_BIT( 0x2000, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x4000, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x8000, IP_ACTIVE_LOW,  IPT_UNUSED )
+	PORT_START("SYSTEM")
+	PORT_SERVICE_NO_TOGGLE( 0x00000001, IP_ACTIVE_LOW )
+	PORT_BIT( 0x00000002, IP_ACTIVE_LOW, IPT_SERVICE1 )
+	PORT_BIT( 0x00000004, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x00000008, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT( 0x00000010, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00000020, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00000040, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00000080, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0xffff0000, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(coin_word_r, NULL)
 
-	PORT_START      /* IN2 */
-	PORT_BIT(0x01, IP_ACTIVE_LOW,  IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2)
-	PORT_BIT( 0x02, IP_ACTIVE_LOW,  IPT_SERVICE1 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW,  IPT_COIN1 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW,  IPT_COIN2 )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW,  IPT_UNUSED )
-	PORT_BIT( 0x80, IP_ACTIVE_LOW,  IPT_UNUSED )
-
-	PORT_START	/* IN 2, steering wheel */
+	PORT_START("AN0")	/* IN 2, steering wheel */
 	PORT_BIT( 0xff, 0x7f, IPT_AD_STICK_X ) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_REVERSE PORT_PLAYER(1)
 
-	PORT_START	/* IN 3, accel */
+	PORT_START("AN1")	/* IN 3, accel */
 	PORT_BIT( 0xff, 0xff, IPT_AD_STICK_Y ) PORT_SENSITIVITY(20) PORT_KEYDELTA(10) PORT_PLAYER(1)
 
-	PORT_START	/* IN 4, sound volume */
+	PORT_START("AN2")	/* IN 4, sound volume */
 	PORT_BIT( 0xff, 0x00, IPT_AD_STICK_X ) PORT_SENSITIVITY(20) PORT_KEYDELTA(10) PORT_REVERSE PORT_PLAYER(2)
 
-	PORT_START	/* IN 5, unknown */
+	PORT_START("AN3")	/* IN 5, unknown */
 	PORT_BIT( 0xff, 0x00, IPT_AD_STICK_Y ) PORT_SENSITIVITY(20) PORT_KEYDELTA(10) PORT_PLAYER(2)
 INPUT_PORTS_END
 
@@ -382,9 +371,9 @@ static const gfx_layout pivlayout =
 };
 
 static GFXDECODE_START( groundfx )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x0, tile16x16_layout,  4096, 512 )
-	GFXDECODE_ENTRY( REGION_GFX1, 0x0, charlayout,        0, 512 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x0, pivlayout,         0, 512 )
+	GFXDECODE_ENTRY( "gfx2", 0x0, tile16x16_layout,  4096, 512 )
+	GFXDECODE_ENTRY( "gfx1", 0x0, charlayout,        0, 512 )
+	GFXDECODE_ENTRY( "gfx3", 0x0, pivlayout,         0, 512 )
 GFXDECODE_END
 
 
@@ -394,36 +383,36 @@ GFXDECODE_END
 
 static MACHINE_RESET( groundfx )
 {
-	taito_f3_soundsystem_reset();
-	f3_68681_reset();
+	taito_f3_soundsystem_reset(machine);
+	f3_68681_reset(machine);
 }
 
 static INTERRUPT_GEN( groundfx_interrupt )
 {
 	frame_counter^=1;
-	cpunum_set_input_line(machine, 0, 4, HOLD_LINE);
+	cpu_set_input_line(device, 4, HOLD_LINE);
 }
 
 static MACHINE_DRIVER_START( groundfx )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68EC020, 16000000)	/* 16 MHz */
+	MDRV_CPU_ADD("main", M68EC020, 16000000)	/* 16 MHz */
 	MDRV_CPU_PROGRAM_MAP(groundfx_readmem,groundfx_writemem)
-	MDRV_CPU_VBLANK_INT(groundfx_interrupt,1)
+	MDRV_CPU_VBLANK_INT("main", groundfx_interrupt)
 
 	TAITO_F3_SOUND_SYSTEM_CPU(16000000)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-
 	MDRV_MACHINE_RESET(groundfx)
 	MDRV_NVRAM_HANDLER(groundfx)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(40*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0, 40*8-1, 3*8, 32*8-1)
+
 	MDRV_GFXDECODE(groundfx)
 	MDRV_PALETTE_LENGTH(16384)
 
@@ -439,37 +428,37 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( groundfx )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 )	/* 2048K for 68020 code (CPU A) */
+	ROM_REGION( 0x200000, "main", 0 )	/* 2048K for 68020 code (CPU A) */
 	ROM_LOAD32_BYTE( "d51-24.79", 0x00000, 0x80000, CRC(5caaa031) SHA1(03e727e26df701e3f5e16c5f933d5b29a528945a) )
 	ROM_LOAD32_BYTE( "d51-23.61", 0x00001, 0x80000, CRC(462e3c9b) SHA1(7f116ee755748497b911868a948d3e3b5134e475) )
 	ROM_LOAD32_BYTE( "d51-22.77", 0x00002, 0x80000, CRC(b6b04d88) SHA1(58685ee8fd788dcbfe318f1e3c06d93e2128034c) )
 	ROM_LOAD32_BYTE( "d51-21.59", 0x00003, 0x80000, CRC(21ecde2b) SHA1(c6d3738f34c8e24346e7784b14aeff300ae2d225) )
 
-	ROM_REGION( 0x180000, REGION_CPU2, 0 )
+	ROM_REGION( 0x180000, "audio", 0 )
 	ROM_LOAD16_BYTE( "d51-29.54", 0x100000, 0x40000,  CRC(4b64f41d) SHA1(040427668d13f7320d23805098d6d0e1aa8d121e) )
 	ROM_LOAD16_BYTE( "d51-30.56", 0x100001, 0x40000,  CRC(45f339fe) SHA1(cc7adfb2b86070f5bb426542e3b7ed2a50b3c39e) )
 
-	ROM_REGION( 0x400000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x400000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD16_BYTE( "d51-08.35", 0x000000, 0x200000, CRC(835b7a0f) SHA1(0131fceabd73b0045b5d4ae0bb2f03efdd407962) )	/* SCR 16x16 tiles */
 	ROM_LOAD16_BYTE( "d51-09.34", 0x000001, 0x200000, CRC(6dabd83d) SHA1(3dbd7ea36b9900faa6420af1f1600efe295db74c) )
 
-	ROM_REGION( 0x1000000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1000000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD32_BYTE( "d51-03.47", 0x800000, 0x200000, CRC(629a5c99) SHA1(cfc1c0b07ecefd6eddb83edcbcf710e8b8de19e4) )	/* OBJ 16x16 tiles */
 	ROM_LOAD32_BYTE( "d51-04.48", 0x000000, 0x200000, CRC(f49b14b7) SHA1(31129771159c1295a074c8311344ece525302289) )
 	ROM_LOAD32_BYTE( "d51-05.49", 0x000001, 0x200000, CRC(3a2e2cbf) SHA1(ed2c1ca9211b1d70b4767a54e08263a3e4867199) )
 	ROM_LOAD32_BYTE( "d51-06.50", 0x000002, 0x200000, CRC(d33ce2a0) SHA1(92c4504344672ea798cd6dd34f4b46848bf9f82b) )
 	ROM_LOAD32_BYTE( "d51-07.51", 0x000003, 0x200000, CRC(24b2f97d) SHA1(6980e67b435d189ce897c0301e0411763410ab47) )
 
-	ROM_REGION( 0x400000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x400000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD16_BYTE( "d51-10.95", 0x000000, 0x100000, CRC(d5910604) SHA1(8efe13884cfdef208394ddfe19f43eb1b9f78ff3) )	/* PIV 8x8 tiles, 6bpp */
 	ROM_LOAD16_BYTE( "d51-11.96", 0x000001, 0x100000, CRC(fee5f5c6) SHA1(1be88747f9c71c348dd61a8f0040007df3a3e6a6) )
 	ROM_LOAD       ( "d51-12.97", 0x300000, 0x100000, CRC(d630287b) SHA1(2fa09e1821b7280d193ca9a2a270759c3c3189d1) )
 	ROM_FILL       (              0x200000, 0x100000, 0 )
 
-	ROM_REGION16_LE( 0x80000, REGION_USER1, 0 )
+	ROM_REGION16_LE( 0x80000, "user1", 0 )
 	ROM_LOAD16_WORD( "d51-13.7", 0x00000,  0x80000,  CRC(36921b8b) SHA1(2130120f78a3b984618a53054fc937cf727177b9) )	/* STY, spritemap */
 
-	ROM_REGION16_BE( 0x1000000, REGION_SOUND1, ROMREGION_ERASE00 )
+	ROM_REGION16_BE( 0x1000000, "ensoniq.0", ROMREGION_ERASE00 )
 	ROM_LOAD16_BYTE( "d51-01.73", 0x000000, 0x200000, CRC(92f09155) SHA1(8015e1997818bb480174394eb43840bf26679bcf) )	/* Ensoniq samples */
 	ROM_LOAD16_BYTE( "d51-02.74", 0xc00000, 0x200000, CRC(20a9428f) SHA1(c9033d02a49c72f704808f5f899101617d5814e5) )
 ROM_END
@@ -478,12 +467,12 @@ ROM_END
 static READ32_HANDLER( irq_speedup_r_groundfx )
 {
 	int ptr;
-	if ((activecpu_get_sp()&2)==0) ptr=groundfx_ram[(activecpu_get_sp()&0x1ffff)/4];
-	else ptr=(((groundfx_ram[(activecpu_get_sp()&0x1ffff)/4])&0x1ffff)<<16) |
-	(groundfx_ram[((activecpu_get_sp()&0x1ffff)/4)+1]>>16);
+	if ((cpu_get_sp(space->cpu)&2)==0) ptr=groundfx_ram[(cpu_get_sp(space->cpu)&0x1ffff)/4];
+	else ptr=(((groundfx_ram[(cpu_get_sp(space->cpu)&0x1ffff)/4])&0x1ffff)<<16) |
+	(groundfx_ram[((cpu_get_sp(space->cpu)&0x1ffff)/4)+1]>>16);
 
-	if (activecpu_get_pc()==0x1ece && ptr==0x1b9a)
-		cpu_spinuntil_int();
+	if (cpu_get_pc(space->cpu)==0x1ece && ptr==0x1b9a)
+		cpu_spinuntil_int(space->cpu);
 
 	return groundfx_ram[0xb574/4];
 }
@@ -492,12 +481,12 @@ static READ32_HANDLER( irq_speedup_r_groundfx )
 static DRIVER_INIT( groundfx )
 {
 	UINT32 offset,i;
-	UINT8 *gfx = memory_region(REGION_GFX3);
-	int size=memory_region_length(REGION_GFX3);
+	UINT8 *gfx = memory_region(machine, "gfx3");
+	int size=memory_region_length(machine, "gfx3");
 	int data;
 
 	/* Speedup handlers */
-	memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0x20b574, 0x20b577, 0, 0, irq_speedup_r_groundfx);
+	memory_install_read32_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x20b574, 0x20b577, 0, 0, irq_speedup_r_groundfx);
 
 	/* make piv tile GFX format suitable for gfxdecode */
 	offset = size/2;
