@@ -95,7 +95,7 @@
 *********************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/e132xs/e132xs.h"
 #include "sound/okim6295.h"
 
 static UINT32 *gstream_vram;
@@ -108,16 +108,45 @@ static tilemap *gstream_tilemap3;
 static UINT32 tilemap1_scrollx, tilemap2_scrollx, tilemap3_scrollx;
 static UINT32 tilemap1_scrolly, tilemap2_scrolly, tilemap3_scrolly;
 
+static CUSTOM_INPUT( gstream_mirror_service_r )
+{
+	int result;
+
+	/* PORT_SERVICE_NO_TOGGLE */
+	result = (input_port_read(field->port->machine, "IN0") & 0x8000) >> 15;
+
+	return ~result;
+}
+
+static CUSTOM_INPUT( gstream_mirror_r )
+{
+	int result;
+
+	/* IPT_COIN1 */
+	result  = ((input_port_read(field->port->machine, "IN0") & 0x200) >>  9)<<0;
+	/* IPT_COIN2 */
+	result |= ((input_port_read(field->port->machine, "IN1") & 0x200) >>  9)<<1;
+	/* IPT_START1 */
+	result |= ((input_port_read(field->port->machine, "IN0") & 0x400) >> 10)<<2;
+	/* IPT_START2 */
+	result |= ((input_port_read(field->port->machine, "IN1") & 0x400) >> 10)<<3;
+	/* PORT_SERVICE_NO_TOGGLE */
+	result |= ((input_port_read(field->port->machine, "IN0") & 0x8000) >> 15)<<6;
+
+	return ~result;
+}
+
+
 static WRITE32_HANDLER( gstream_palette_w )
 {
 	COMBINE_DATA(&paletteram32[offset]);
 
-	palette_set_color_rgb(Machine,offset*2,pal5bit(paletteram32[offset] >> (0+16)),
+	palette_set_color_rgb(space->machine,offset*2,pal5bit(paletteram32[offset] >> (0+16)),
 		                             pal5bit(paletteram32[offset] >> (6+16)),
 									 pal5bit(paletteram32[offset] >> (11+16)));
 
 
-	palette_set_color_rgb(Machine,offset*2+1,pal5bit(paletteram32[offset] >> (0)),
+	palette_set_color_rgb(space->machine,offset*2+1,pal5bit(paletteram32[offset] >> (0)),
 		                             pal5bit(paletteram32[offset] >> (6)),
 									 pal5bit(paletteram32[offset] >> (11)));
 }
@@ -126,7 +155,7 @@ static WRITE32_HANDLER( gstream_vram_w )
 {
 	COMBINE_DATA(&gstream_vram[offset]);
 
-	if (ACCESSING_MSB32)
+	if (ACCESSING_BITS_24_31)
 	{
 		if (offset>=0x000/4 && offset<0x400/4)
 		{
@@ -153,54 +182,89 @@ static WRITE32_HANDLER( gstream_tilemap3_scrolly_w ) { tilemap3_scrolly = data;
 static ADDRESS_MAP_START( gstream_32bit_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x00000000, 0x003FFFFF) AM_RAM AM_BASE(&gstream_workram) // work ram
 //  AM_RANGE(0x40000000, 0x40FFFFFF) AM_RAM // ?? lots of data gets copied here if present, but game runs without it??
-	AM_RANGE(0x80000000, 0x80003FFF) AM_RAM AM_WRITE(gstream_vram_w) AM_BASE(&gstream_vram) // video ram
-	AM_RANGE(0x4E000000, 0x4E1FFFFF) AM_ROM AM_REGION(REGION_USER2,0) // main game rom
+	AM_RANGE(0x80000000, 0x80003FFF) AM_RAM_WRITE(gstream_vram_w) AM_BASE(&gstream_vram) // video ram
+	AM_RANGE(0x4E000000, 0x4E1FFFFF) AM_ROM AM_REGION("user2",0) // main game rom
 	AM_RANGE(0x4F000000, 0x4F000003) AM_WRITE(gstream_tilemap3_scrollx_w)
 	AM_RANGE(0x4F200000, 0x4F200003) AM_WRITE(gstream_tilemap3_scrolly_w)
-	AM_RANGE(0x4F400000, 0x4F406FFF) AM_RAM AM_WRITE(gstream_palette_w) AM_BASE(&paletteram32)
+	AM_RANGE(0x4F400000, 0x4F406FFF) AM_RAM_WRITE(gstream_palette_w) AM_BASE(&paletteram32)
 	AM_RANGE(0x4F800000, 0x4F800003) AM_WRITE(gstream_tilemap1_scrollx_w)
 	AM_RANGE(0x4FA00000, 0x4FA00003) AM_WRITE(gstream_tilemap1_scrolly_w)
 	AM_RANGE(0x4FC00000, 0x4FC00003) AM_WRITE(gstream_tilemap2_scrollx_w)
 	AM_RANGE(0x4FE00000, 0x4FE00003) AM_WRITE(gstream_tilemap2_scrolly_w)
 	AM_RANGE(0xFFC00000, 0xFFC01FFF) AM_RAM AM_BASE(&generic_nvram32) AM_SIZE(&generic_nvram_size) // Backup RAM
-	AM_RANGE(0xFFF80000, 0xFFFFFFFF) AM_ROM AM_REGION(REGION_USER1,0) // boot rom
+	AM_RANGE(0xFFF80000, 0xFFFFFFFF) AM_ROM AM_REGION("user1",0) // boot rom
 ADDRESS_MAP_END
 
-static READ32_HANDLER( gstream_oki_0_r ) { return OKIM6295_status_0_r(0); }
-static READ32_HANDLER( gstream_oki_1_r ) { return OKIM6295_status_1_r(0); }
-static WRITE32_HANDLER( gstream_oki_0_w ) { OKIM6295_data_0_w(0, data & 0xff); }
-static WRITE32_HANDLER( gstream_oki_1_w ) { OKIM6295_data_1_w(0, data & 0xff); }
+static READ32_HANDLER( gstream_oki_0_r ) { return okim6295_status_0_r(space, 0); }
+static READ32_HANDLER( gstream_oki_1_r ) { return okim6295_status_1_r(space, 0); }
+static WRITE32_HANDLER( gstream_oki_0_w ) { okim6295_data_0_w(space, 0, data & 0xff); }
+static WRITE32_HANDLER( gstream_oki_1_w ) { okim6295_data_1_w(space, 0, data & 0xff); }
 
-static WRITE32_HANDLER( gstream_oki_4030_w )
+static WRITE32_HANDLER( gstream_oki_banking_w )
 {
-/*
-    // the only nibbles that are written are: 0x6 0x7 0x9 0xa 0xb 0xe 0xd 0xf which should map to the 8 oki banks
+	/* OKI BANKING  (still far from perfect, based on game behaviour)
 
-    static const int bank_lookup[16] = { -1, -1, -1, -1, -1, -1, 0, 1, -1, 2, 3, 4, -1, 5, 6, 7 };
+    The two okis can indifferently play music or samples and are switched on the fly during game
+    This is a preliminary table of the banks:
 
-    static int old_bank_0 = -1;
-    static int old_bank_1 = -1;
+    BANK    MUSIC   SAMPLES
+     0         X
+     1    X
+     2    X
+     3    X
+     4         X
+     5    X
+     6    X
+     7    X
 
-    if(bank_lookup[data & 0xf] != old_bank_0)
-    {
-        old_bank_0 = bank_lookup[data & 0xf];
+    Two nibbles are used in this handler: (data & 0xf) and ((data >> 4) & 0xf)
+    The values for the first nibble are the followings and should map the 8 oki banks:
+    - 0x6, 0x7, 0x9, 0xa, 0xb, 0xd, 0xe, 0xf
+    The values for the second nibble are the followings and should probably be used too:
+    - 0x6, 0x9, 0xa
 
-        if(old_bank_0 != -1)
-            OKIM6295_set_bank_base(0, old_bank_0 * 0x40000);
-        else
-            logerror("oki_0 banking value = %X\n",data & 0xf);
-    }
+    Same values are redudant, for example:
+    level 2: data = 0x99
+    level 6: data = 0x99
+    (this means same background music for the two levels - it could be correct, though)
 
-    if(bank_lookup[(data >> 4) & 0xf] != old_bank_1)
-    {
-        old_bank_1 = bank_lookup[(data >> 4) & 0xf];
+    Also with current implementation, using only (data & 0xf), we have to force some values
+    manually, because the correspondent places in the table are already used
 
-        if(old_bank_1 != -1)
-            OKIM6295_set_bank_base(1, old_bank_1 * 0x40000);
-        else
-            logerror("oki_1 banking value = %X\n",(data >> 4) & 0xf);
-    }
-*/
+    Musics order is completely guessed but close to what the original PCB game should be */
+
+	static const int bank_table_0[16] = { -1, -1, -1, -1, -1, -1, 0, 0, -1, 6, 0, 5, -1, 0, 0, 0 };
+	static const int bank_table_1[16] = { -1, -1, -1, -1, -1, -1, 2, 2, -1, 0, 0, 4, -1, 1, 1, 1 };
+
+	static int bank_0 = 0;
+	static int bank_1 = 0;
+
+	//popmessage("oki_0 banking value = %X\noki_1 banking value = %X\n",data & 0xf,(data >> 4) & 0xf);
+
+	bank_0 = bank_table_0[data & 0xf];
+	bank_1 = bank_table_1[data & 0xf];		// (data >> 4) & 0xf ??
+
+	/* some values are already used in the table, so we force them manually */
+	if ((data == 0x6f) || (data == 0x6e))
+	{
+		bank_0 = 0; 	// level 3b-5a samples
+		bank_1 = 6;		// level 3b-5a music
+	}
+
+	if (data == 0x9b)
+	{
+		bank_0 = 7;		// level 7 music
+		bank_1 = 0;		// level 7 samples
+	}
+
+	if (data == 0x9f)
+	{
+		bank_0 = 0;		// end sequence samples
+		bank_1 = 3;		// end sequence music
+	}
+
+	okim6295_set_bank_base(0, bank_0 * 0x40000);
+	okim6295_set_bank_base(1, bank_1 * 0x40000);
 }
 
 static WRITE32_HANDLER( gstream_oki_4040_w )
@@ -209,18 +273,17 @@ static WRITE32_HANDLER( gstream_oki_4040_w )
 }
 
 static ADDRESS_MAP_START( gstream_io, ADDRESS_SPACE_IO, 32 )
-	AM_RANGE(0x4000, 0x4003) AM_READ(input_port_0_dword_r)
-	AM_RANGE(0x4010, 0x4013) AM_READ(input_port_1_dword_r)
-	AM_RANGE(0x4020, 0x4023) AM_READ(input_port_2_dword_r) // extra coin switches etc
-	AM_RANGE(0x4030, 0x4033) AM_WRITE(gstream_oki_4030_w) // ??
-	AM_RANGE(0x4040, 0x4043) AM_WRITE(gstream_oki_4040_w) // ??
-	AM_RANGE(0x4050, 0x4053) AM_READWRITE(gstream_oki_1_r, gstream_oki_1_w) // music
-	AM_RANGE(0x4060, 0x4063) AM_READWRITE(gstream_oki_0_r, gstream_oki_0_w) // samples
+	AM_RANGE(0x4000, 0x4003) AM_READ_PORT("IN0")
+	AM_RANGE(0x4010, 0x4013) AM_READ_PORT("IN1")
+	AM_RANGE(0x4020, 0x4023) AM_READ_PORT("IN2") 	// extra coin switches etc
+	AM_RANGE(0x4030, 0x4033) AM_WRITE(gstream_oki_banking_w) 	// oki banking
+	AM_RANGE(0x4040, 0x4043) AM_WRITE(gstream_oki_4040_w) 	// ??
+	AM_RANGE(0x4050, 0x4053) AM_READWRITE(gstream_oki_1_r, gstream_oki_1_w) 	// music and samples
+	AM_RANGE(0x4060, 0x4063) AM_READWRITE(gstream_oki_0_r, gstream_oki_0_w) 	// music and samples
 ADDRESS_MAP_END
 
-
 static INPUT_PORTS_START( gstream )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(1)
@@ -233,10 +296,10 @@ static INPUT_PORTS_START( gstream )
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT( 0xe000, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x7000, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_SERVICE_NO_TOGGLE( 0x8000, IP_ACTIVE_LOW )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(2)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(2)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(2)
@@ -249,16 +312,12 @@ static INPUT_PORTS_START( gstream )
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_SERVICE2 )
-	PORT_BIT( 0xe000, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_SERVICE_NO_TOGGLE( 0x8000, IP_ACTIVE_LOW )
+	PORT_BIT( 0x7000, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_SPECIAL )	PORT_CUSTOM(gstream_mirror_service_r, NULL)
 
-	PORT_START
-    PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN1 ) // mirror of some inputs...
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_START2 )
-    PORT_BIT( 0xffb0, IP_ACTIVE_LOW, IPT_UNUSED )
-    PORT_SERVICE_NO_TOGGLE( 0x40, IP_ACTIVE_LOW )
+	PORT_START("IN2")
+	PORT_BIT( 0x004f, IP_ACTIVE_LOW, IPT_SPECIAL )	PORT_CUSTOM(gstream_mirror_r, NULL)
+	PORT_BIT( 0xffb0, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
 
@@ -292,8 +351,8 @@ static const gfx_layout layout32x32 =
 };
 
 static GFXDECODE_START( gstream )
- 	GFXDECODE_ENTRY( REGION_GFX2, 0, layout32x32, 0, 0x80 )
- 	GFXDECODE_ENTRY( REGION_GFX1, 0, layout16x16, 0, 0x80 )
+ 	GFXDECODE_ENTRY( "gfx2", 0, layout32x32, 0, 0x80 )
+ 	GFXDECODE_ENTRY( "gfx1", 0, layout16x16, 0, 0x80 )
 GFXDECODE_END
 
 
@@ -326,9 +385,9 @@ static TILE_GET_INFO( get_gs3_tile_info )
 
 static VIDEO_START(gstream)
 {
-	gstream_tilemap1 = tilemap_create(get_gs1_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN, 32, 32,16,16);
-	gstream_tilemap2 = tilemap_create(get_gs2_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN, 32, 32,16,16);
-	gstream_tilemap3 = tilemap_create(get_gs3_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN, 32, 32,16,16);
+	gstream_tilemap1 = tilemap_create(machine, get_gs1_tile_info,tilemap_scan_rows, 32, 32,16,16);
+	gstream_tilemap2 = tilemap_create(machine, get_gs2_tile_info,tilemap_scan_rows, 32, 32,16,16);
+	gstream_tilemap3 = tilemap_create(machine, get_gs3_tile_info,tilemap_scan_rows, 32, 32,16,16);
 
 	tilemap_set_transparent_pen(gstream_tilemap1,0);
 	tilemap_set_transparent_pen(gstream_tilemap2,0);
@@ -379,23 +438,22 @@ static VIDEO_UPDATE(gstream)
 		if (x & 0x8000) x-=0x10000;
 		if (y & 0x8000) y-=0x10000;
 
-		drawgfx(bitmap,machine->gfx[1],code,col,0,0,x-2,y,cliprect,TRANSPARENCY_PEN,0);
+		drawgfx(bitmap,screen->machine->gfx[1],code,col,0,0,x-2,y,cliprect,TRANSPARENCY_PEN,0);
 	}
 
 	return 0;
 }
 
 static MACHINE_DRIVER_START( gstream )
-	MDRV_CPU_ADD_TAG("main", E132XT, 16000000*4)	/* 4x internal multiplier */
+	MDRV_CPU_ADD("main", E132XT, 16000000*4)	/* 4x internal multiplier */
 	MDRV_CPU_PROGRAM_MAP(gstream_32bit_map,0)
 	MDRV_CPU_IO_MAP(gstream_io,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(320, 240)
 	MDRV_SCREEN_VISIBLE_AREA(0, 319, 0, 239)
@@ -410,23 +468,23 @@ static MACHINE_DRIVER_START( gstream )
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(OKIM6295, 1000000) /* 1 Mhz? */
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7low) // pin 7 not verified
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MDRV_SOUND_ADD("oki1", OKIM6295, 1000000) /* 1 Mhz? */
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // pin 7 not verified
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 
-	MDRV_SOUND_ADD(OKIM6295, 1000000) /* 1 Mhz? */
-	MDRV_SOUND_CONFIG(okim6295_interface_region_2_pin7low) // pin 7 not verified
-	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
+	MDRV_SOUND_ADD("oki2", OKIM6295, 1000000) /* 1 Mhz? */
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // pin 7 not verified
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
 MACHINE_DRIVER_END
 
 ROM_START( gstream )
-	ROM_REGION32_BE( 0x080000, REGION_USER1, 0 ) /* Hyperstone CPU Code */
+	ROM_REGION32_BE( 0x080000, "user1", 0 ) /* Hyperstone CPU Code */
 	ROM_LOAD( "u56.bin", 0x000000, 0x080000, CRC(0d0c6a38) SHA1(a810bfc1c9158cccc37710d0ea7268e26e520cc2) )
 
-	ROM_REGION32_BE( 0x200000, REGION_USER2, 0 ) /* Hyperstone CPU Code */
+	ROM_REGION32_BE( 0x200000, "user2", 0 ) /* Hyperstone CPU Code */
 	ROM_LOAD16_WORD_SWAP( "gs_prg_02.bin", 0x000000, 0x200000, CRC(2f8a6bea) SHA1(c0a32838f4bd8599f09002139f87562db625c1c5) )
 
-	ROM_REGION( 0x1000000, REGION_GFX1, ROMREGION_DISPOSE )  /* sprite tiles (16x16x8) */
+	ROM_REGION( 0x1000000, "gfx1", ROMREGION_DISPOSE )  /* sprite tiles (16x16x8) */
 	ROM_LOAD32_WORD( "gs_gr_07.bin", 0x000000, 0x200000, CRC(84e66fe1) SHA1(73d828714f9ed9baffdc06998f5bf3298396fe9c) )
 	ROM_LOAD32_WORD( "gs_gr_11.bin", 0x000002, 0x200000, CRC(946d71d1) SHA1(516bd3f4d7f5bce59f0593ed6565114dbd5a4ef0) )
 	ROM_LOAD32_WORD( "gs_gr_08.bin", 0x400000, 0x200000, CRC(abd0d6aa) SHA1(dd294bbdda05697df84247257f735ab51bc26ca3) )
@@ -436,7 +494,7 @@ ROM_START( gstream )
 	ROM_LOAD32_WORD( "gs_gr_10.bin", 0xc00000, 0x200000, CRC(d696d15d) SHA1(85aaa5cdb35f3a8d3266bb8debec0558c860cb53) )
 	ROM_LOAD32_WORD( "gs_gr_14.bin", 0xc00002, 0x200000, CRC(6bd2a1e1) SHA1(aedca91643f14ececc101a7708255ce9b1d70f68) )
 
-	ROM_REGION( 0xc00000, REGION_GFX2, ROMREGION_DISPOSE )  /* bg tiles (32x32x8) */
+	ROM_REGION( 0xc00000, "gfx2", ROMREGION_DISPOSE )  /* bg tiles (32x32x8) */
 	ROM_LOAD( "gs_gr_01.bin", 0x000000, 0x200000, CRC(b82cfab8) SHA1(08f0eaef5c927fb056c6cc9342e39f445aae9062) )
 	ROM_LOAD( "gs_gr_02.bin", 0x200000, 0x200000, CRC(37e19cbd) SHA1(490ebb037fce09100ec4bba3f73ecdf101526641) )
 	ROM_LOAD( "gs_gr_03.bin", 0x400000, 0x200000, CRC(1a3b2b11) SHA1(a4b1dc1a9709f8f8f2ab2190d7badc246caa540f) )
@@ -444,21 +502,21 @@ ROM_START( gstream )
 	ROM_LOAD( "gs_gr_05.bin", 0x800000, 0x200000, CRC(ef283a73) SHA1(8b598facb344eac33138611abc141a2acb375983) )
 	ROM_LOAD( "gs_gr_06.bin", 0xa00000, 0x200000, CRC(d4e3a2b2) SHA1(4577c007172c718bf7ca55a8ccee5455c281026c) )
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "oki1", 0 )
 	ROM_LOAD( "gs_snd_01.bin", 0x000000, 0x080000, CRC(79b64d3f) SHA1(b2166210d3a3b85b9ace90749a444c881f69d551) )
 	ROM_LOAD( "gs_snd_02.bin", 0x080000, 0x080000, CRC(e49ed92c) SHA1(a3d7b3fe93a786a246acf2657d9056398c793078) )
 	ROM_LOAD( "gs_snd_03.bin", 0x100000, 0x080000, CRC(2bfff4ac) SHA1(cce1bb3c78b86722c926854c737f9589806012ba) )
 	ROM_LOAD( "gs_snd_04.bin", 0x180000, 0x080000, CRC(b259de3b) SHA1(1a64f41d4344fefad5832332f1a7655e23f6b017) )
 
-	ROM_REGION( 0x200000, REGION_SOUND2, 0 )
-	ROM_COPY( REGION_SOUND1, 0, 0, 0x200000 )
+	ROM_REGION( 0x200000, "oki2", 0 )
+	ROM_COPY( "oki1", 0, 0, 0x200000 )
 ROM_END
 
 static READ32_HANDLER( gstream_speedup_r )
 {
-	if (activecpu_get_pc()==0xc0001592)
+	if (cpu_get_pc(space->cpu)==0xc0001592)
 	{
-		activecpu_eat_cycles(50);
+		cpu_spinuntil_int(space->cpu);
 	}
 
 	return gstream_workram[0xd1ee0/4];
@@ -466,7 +524,8 @@ static READ32_HANDLER( gstream_speedup_r )
 
 static DRIVER_INIT( gstream )
 {
-	memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0xd1ee0, 0xd1ee3, 0, 0, gstream_speedup_r );
+	memory_install_read32_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xd1ee0, 0xd1ee3, 0, 0, gstream_speedup_r );
 
 }
+
 GAME( 2002, gstream, 0, gstream, gstream, gstream, ROT270, "Oriental Soft Japan", "G-Stream G2020", GAME_IMPERFECT_SOUND )
