@@ -33,7 +33,8 @@ Merge with other Video System games ?
 ******************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
+#include "cpu/m68000/m68000.h"
 #include "gstriker.h"
 #include "sound/2610intf.h"
 
@@ -181,20 +182,15 @@ Frequencies: 68k is XTAL_32MHZ/2
 
 //UINT16 *gs_videoram3;
 static UINT16 *gs_mixer_regs;
-
-/* in video */
-VIDEO_UPDATE( gstriker );
-VIDEO_START( gstriker );
-VIDEO_START( twrldc94 );
+static UINT16 dmmy_8f_ret;
 
 
 /*** MISC READ / WRITE HANDLERS **********************************************/
 
 static READ16_HANDLER(dmmy_8f)
 {
-	static int ret = 0xFFFF;
-	ret = ~ret;
-	return ret;
+	dmmy_8f_ret = ~dmmy_8f_ret;
+	return dmmy_8f_ret;
 }
 
 /*** SOUND RELATED ***********************************************************/
@@ -203,11 +199,11 @@ static int pending_command;
 
 static WRITE16_HANDLER( sound_command_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		pending_command = 1;
-		soundlatch_w(offset,data & 0xff);
-		cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, PULSE_LINE);
+		soundlatch_w(space,offset,data & 0xff);
+		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_NMI, PULSE_LINE);
 	}
 }
 
@@ -225,11 +221,11 @@ static WRITE8_HANDLER( gs_sh_pending_command_clear_w )
 
 static WRITE8_HANDLER( gs_sh_bankswitch_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU2);
+	UINT8 *RAM = memory_region(space->machine, "audio");
 	int bankaddress;
 
 	bankaddress = 0x10000 + (data & 0x03) * 0x8000;
-	memory_set_bankptr(1,&RAM[bankaddress]);
+	memory_set_bankptr(space->machine, 1,&RAM[bankaddress]);
 }
 
 /*** GFX DECODE **************************************************************/
@@ -263,27 +259,25 @@ static const gfx_layout gs_16x16x4_layout =
 };
 
 static GFXDECODE_START( gstriker )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, gs_8x8x4_layout,     0, 256 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0, gs_16x16x4_layout,   0, 256 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0, gs_16x16x4_layout,   0, 256 )
+	GFXDECODE_ENTRY( "gfx1", 0, gs_8x8x4_layout,     0, 256 )
+	GFXDECODE_ENTRY( "gfx2", 0, gs_16x16x4_layout,   0, 256 )
+	GFXDECODE_ENTRY( "gfx3", 0, gs_16x16x4_layout,   0, 256 )
 
 GFXDECODE_END
 
 /*** MORE SOUND RELATED ******************************************************/
 
-static void gs_ym2610_irq(int irq)
+static void gs_ym2610_irq(running_machine *machine, int irq)
 {
 	if (irq)
-		cpunum_set_input_line(Machine, 1, 0, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[1], 0, ASSERT_LINE);
 	else
-		cpunum_set_input_line(Machine, 1, 0, CLEAR_LINE);
+		cpu_set_input_line(machine->cpu[1], 0, CLEAR_LINE);
 }
 
-static const struct YM2610interface ym2610_interface =
+static const ym2610_interface ym2610_config =
 {
-	gs_ym2610_irq,
-	REGION_SOUND1,
-	REGION_SOUND2
+	gs_ym2610_irq
 };
 
 /*** MEMORY LAYOUTS **********************************************************/
@@ -293,68 +287,84 @@ UINT16 *gstriker_lineram;
 
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x100000, 0x103fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x140000, 0x141fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x180000, 0x181fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x1c0000, 0x1c0fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0xffc000, 0xffffff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM)
+	AM_RANGE(0x100000, 0x103fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x140000, 0x141fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x180000, 0x181fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x1c0000, 0x1c0fff) AM_READ(SMH_RAM)
+	AM_RANGE(0xffc000, 0xffffff) AM_READ(SMH_RAM)
 
-  	AM_RANGE(0x200000, 0x20007f) AM_READ(MRA16_RAM)
-	AM_RANGE(0x200080, 0x200081) AM_READ(input_port_1_word_r)
-	AM_RANGE(0x200082, 0x200083) AM_READ(input_port_2_word_r)
-	AM_RANGE(0x200084, 0x200085) AM_READ(input_port_0_word_r)
-	AM_RANGE(0x200086, 0x200087) AM_READ(input_port_3_word_r)
-	AM_RANGE(0x200088, 0x200089) AM_READ(input_port_4_word_r)
+  	AM_RANGE(0x200000, 0x20007f) AM_READ(SMH_RAM)
+	AM_RANGE(0x200080, 0x200081) AM_READ_PORT("P1")
+	AM_RANGE(0x200082, 0x200083) AM_READ_PORT("P2")
+	AM_RANGE(0x200084, 0x200085) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0x200086, 0x200087) AM_READ_PORT("DSW1")
+	AM_RANGE(0x200088, 0x200089) AM_READ_PORT("DSW2")
 	AM_RANGE(0x20008e, 0x20008f) AM_READ(dmmy_8f)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(MWA16_ROM)
+	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(SMH_ROM)
 	AM_RANGE(0x100000, 0x103fff) AM_WRITE(MB60553_0_vram_w) AM_BASE(&MB60553_0_vram)
-	AM_RANGE(0x140000, 0x141fff) AM_WRITE(MWA16_RAM) AM_BASE(&CG10103_0_vram)
+	AM_RANGE(0x140000, 0x141fff) AM_WRITE(SMH_RAM) AM_BASE(&CG10103_0_vram)
 	AM_RANGE(0x180000, 0x180fff) AM_WRITE(VS920A_0_vram_w) AM_BASE(&VS920A_0_vram)
-	AM_RANGE(0x181000, 0x181fff) AM_WRITE(MWA16_RAM) AM_BASE(&gstriker_lineram)
+	AM_RANGE(0x181000, 0x181fff) AM_WRITE(SMH_RAM) AM_BASE(&gstriker_lineram)
 	AM_RANGE(0x1c0000, 0x1c0fff) AM_WRITE(paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x200000, 0x20000f) AM_WRITE(MB60553_0_regs_w)
-	AM_RANGE(0x200040, 0x20005f) AM_WRITE(MWA16_RAM) AM_BASE(&gs_mixer_regs)
+	AM_RANGE(0x200040, 0x20005f) AM_WRITE(SMH_RAM) AM_BASE(&gs_mixer_regs)
 	AM_RANGE(0x2000a0, 0x2000a1) AM_WRITE(sound_command_w)
-	AM_RANGE(0xffc000, 0xffffff) AM_WRITE(MWA16_RAM) AM_BASE(&work_ram)
+	AM_RANGE(0xffc000, 0xffffff) AM_WRITE(SMH_RAM) AM_BASE(&work_ram)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x77ff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x7800, 0x7fff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_BANK1)
+	AM_RANGE(0x0000, 0x77ff) AM_READ(SMH_ROM)
+	AM_RANGE(0x7800, 0x7fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x8000, 0xffff) AM_READ(SMH_BANK1)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x77ff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x7800, 0x7fff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0x8000, 0xffff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x0000, 0x77ff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x7800, 0x7fff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0x8000, 0xffff) AM_WRITE(SMH_ROM)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_readport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x00, 0x00) AM_READ(YM2610_status_port_0_A_r)
-	AM_RANGE(0x02, 0x02) AM_READ(YM2610_status_port_0_B_r)
+static ADDRESS_MAP_START( sound_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x00, 0x00) AM_READWRITE(ym2610_status_port_0_a_r, ym2610_control_port_0_a_w)
+	AM_RANGE(0x01, 0x01) AM_WRITE(ym2610_data_port_0_a_w)
+	AM_RANGE(0x02, 0x02) AM_READWRITE(ym2610_status_port_0_b_r, ym2610_control_port_0_b_w)
+	AM_RANGE(0x03, 0x03) AM_WRITE(ym2610_data_port_0_b_w)
+	AM_RANGE(0x04, 0x04) AM_WRITE(gs_sh_bankswitch_w)
+	AM_RANGE(0x08, 0x08) AM_WRITE(gs_sh_pending_command_clear_w)
 	AM_RANGE(0x0c, 0x0c) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_writeport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x00, 0x00) AM_WRITE(YM2610_control_port_0_A_w)
-	AM_RANGE(0x01, 0x01) AM_WRITE(YM2610_data_port_0_A_w)
-	AM_RANGE(0x02, 0x02) AM_WRITE(YM2610_control_port_0_B_w)
-	AM_RANGE(0x03, 0x03) AM_WRITE(YM2610_data_port_0_B_w)
-	AM_RANGE(0x04, 0x04) AM_WRITE(gs_sh_bankswitch_w)
-	AM_RANGE(0x08, 0x08) AM_WRITE(gs_sh_pending_command_clear_w)
+
+static ADDRESS_MAP_START( vgoal_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM
+	AM_RANGE(0x100000, 0x103fff) AM_RAM_WRITE(MB60553_0_vram_w) AM_BASE(&MB60553_0_vram)
+	AM_RANGE(0x140000, 0x141fff) AM_RAM AM_BASE(&CG10103_0_vram)
+	AM_RANGE(0x180000, 0x180fff) AM_RAM_WRITE(VS920A_0_vram_w) AM_BASE(&VS920A_0_vram)
+	AM_RANGE(0x181000, 0x181fff) AM_RAM AM_BASE(&gstriker_lineram)
+	AM_RANGE(0x1c0000, 0x1c4fff) AM_RAM_WRITE(paletteram16_xRRRRRGGGGGBBBBB_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x200000, 0x20000f) AM_WRITE(MB60553_0_regs_w)
+	AM_RANGE(0x200040, 0x20005f) AM_RAM AM_BASE(&gs_mixer_regs)
+
+	AM_RANGE(0x200080, 0x200081) AM_READ_PORT("P1")
+	AM_RANGE(0x200082, 0x200083) AM_READ_PORT("P2")
+	AM_RANGE(0x200084, 0x200085) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0x200086, 0x200087) AM_READ_PORT("DSW1")
+	AM_RANGE(0x200088, 0x200089) AM_READ_PORT("DSW2")
+	AM_RANGE(0x20008e, 0x20008f) AM_READ(dmmy_8f)
+
+	AM_RANGE(0x2000a0, 0x2000a1) AM_WRITE(sound_command_w)
+	AM_RANGE(0xffc000, 0xffffff) AM_RAM AM_BASE(&work_ram)
 ADDRESS_MAP_END
 
 /*** INPUT PORTS *************************************************************/
 
-static INPUT_PORTS_START( gstriker )
-	PORT_START
+static INPUT_PORTS_START( gstriker_generic )
+	PORT_START("SYSTEM")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_START1 )
@@ -365,7 +375,7 @@ static INPUT_PORTS_START( gstriker )
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN) // vbl?
 	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* probably unused */
 
-	PORT_START      /* IN1 */
+	PORT_START("P1")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
@@ -376,7 +386,7 @@ static INPUT_PORTS_START( gstriker )
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(1)	// "Spare"
 	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* probably unused */
 
-	PORT_START
+	PORT_START("P2")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
@@ -386,8 +396,12 @@ static INPUT_PORTS_START( gstriker )
 	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(2)	// "Spare"
 	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* probably unused */
+INPUT_PORTS_END
 
-	PORT_START
+static INPUT_PORTS_START( gstriker )
+	PORT_INCLUDE( gstriker_generic )
+
+	PORT_START("DSW1")
 	PORT_DIPNAME( 0x0003, 0x0003, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(      0x0001, DEF_STR( 3C_1C ) )
 	PORT_DIPSETTING(      0x0002, DEF_STR( 2C_1C ) )
@@ -412,7 +426,7 @@ static INPUT_PORTS_START( gstriker )
 	PORT_DIPSETTING(      0x0080, "2" )
 	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* probably unused */
 
-	PORT_START
+	PORT_START("DSW2")
 	PORT_DIPNAME( 0x0001, 0x0001, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(      0x0001, DEF_STR( Normal ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Hard ) )
@@ -436,25 +450,140 @@ static INPUT_PORTS_START( gstriker )
 	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* probably unused */
 INPUT_PORTS_END
 
+static INPUT_PORTS_START( twrldc94 )
+	PORT_INCLUDE( gstriker_generic )
+
+	PORT_START("DSW1")
+	PORT_DIPNAME( 0x0007, 0x0007, DEF_STR( Coin_A ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( 4C_1C ) )
+	PORT_DIPSETTING(      0x0001, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(      0x0002, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(      0x0007, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(      0x0006, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(      0x0005, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(      0x0004, DEF_STR( 1C_4C ) )
+	PORT_DIPSETTING(      0x0003, DEF_STR( 1C_6C ) )
+
+	PORT_DIPNAME( 0x0038, 0x0038, DEF_STR( Coin_B ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( 4C_1C ) )
+	PORT_DIPSETTING(      0x0008, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(      0x0010, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(      0x0038, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(      0x0030, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(      0x0028, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(      0x0020, DEF_STR( 1C_4C ) )
+	PORT_DIPSETTING(      0x0018, DEF_STR( 1C_6C ) )
+
+	PORT_DIPNAME( 0x00c0, 0x00c0, "Play Time" )
+	PORT_DIPSETTING(      0x0000, "P v CPU 1:00, P v P 1:30" )
+	PORT_DIPSETTING(      0x00c0, "P v CPU 1:30, P v P 2:00" )
+	PORT_DIPSETTING(      0x0040, "P v CPU 2:00, P v P 2:30" )
+	PORT_DIPSETTING(      0x0080, "P v CPU 2:30, P v P 3:00" )
+	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* probably unused */
+
+	PORT_START("DSW2")
+	PORT_DIPNAME( 0x0003, 0x0003, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( Very_Hard ) )
+	PORT_DIPSETTING(      0x0001, DEF_STR( Hard ) )
+	PORT_DIPSETTING(      0x0002, DEF_STR( Easy ) )
+	PORT_DIPSETTING(      0x0003, DEF_STR( Normal ) )
+
+	PORT_DIPNAME( 0x0004, 0x0004, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0004, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0008, 0x0008, "Show Configuration" )
+	PORT_DIPSETTING(      0x0008, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0010, 0x0010, "Countdown" )
+	PORT_DIPSETTING(      0x0010, "54 sec" )
+	PORT_DIPSETTING(      0x0000, "60 sec" )
+	PORT_DIPNAME( 0x0020, 0x0020, "Start credit" )
+	PORT_DIPSETTING(      0x0020, "1" )
+	PORT_DIPSETTING(      0x0000, "2" )
+	PORT_DIPNAME( 0x0040, 0x0040, DEF_STR( Unused ) )
+	PORT_DIPSETTING(      0x0040, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_SERVICE( 0x0080, IP_ACTIVE_LOW )
+	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* probably unused */
+INPUT_PORTS_END
+
+static INPUT_PORTS_START( vgoalsoc )
+	PORT_INCLUDE( gstriker_generic )
+
+	PORT_START("DSW1")
+	PORT_DIPNAME( 0x0007, 0x0007, DEF_STR( Coin_A ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( 4C_1C ) )
+	PORT_DIPSETTING(      0x0001, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(      0x0002, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(      0x0007, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(      0x0006, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(      0x0005, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(      0x0004, DEF_STR( 1C_4C ) )
+	PORT_DIPSETTING(      0x0003, DEF_STR( 1C_6C ) )
+
+	PORT_DIPNAME( 0x0038, 0x0038, DEF_STR( Coin_B ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( 4C_1C ) )
+	PORT_DIPSETTING(      0x0008, DEF_STR( 3C_1C ) )
+	PORT_DIPSETTING(      0x0010, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(      0x0038, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(      0x0030, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(      0x0028, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(      0x0020, DEF_STR( 1C_4C ) )
+	PORT_DIPSETTING(      0x0018, DEF_STR( 1C_6C ) )
+
+	PORT_DIPNAME( 0x00c0, 0x00c0, DEF_STR (Unknown) ) // Probably difficulty
+	PORT_DIPSETTING(      0x0080, "A" )
+	PORT_DIPSETTING(      0x00c0, "B" )
+	PORT_DIPSETTING(      0x0040, "C" )
+	PORT_DIPSETTING(      0x0000, "D" )
+	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* probably unused */
+
+	PORT_START("DSW2")
+	PORT_DIPNAME( 0x0003, 0x0003, "Player VS CPU Time" ) // no coperative
+	PORT_DIPSETTING(      0x0002, "1:00" )
+	PORT_DIPSETTING(      0x0003, "1:30" )
+	PORT_DIPSETTING(      0x0001, "2:00" )
+	PORT_DIPSETTING(      0x0000, "2:30" )
+	PORT_DIPNAME( 0x000c, 0x000c, "Player VS Player Time" )
+	PORT_DIPSETTING(      0x0008, "1:30" )
+	PORT_DIPSETTING(      0x000c, "2:00" )
+	PORT_DIPSETTING(      0x0004, "2:30" )
+	PORT_DIPSETTING(      0x0000, "3:00" )
+	PORT_DIPNAME( 0x0010, 0x0010, "Countdown" )
+	PORT_DIPSETTING(      0x0010, "54 sec" )
+	PORT_DIPSETTING(      0x0000, "60 sec" )
+	PORT_DIPNAME( 0x0020, 0x0000, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(      0x0020, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0040, 0x0040, "DWS2:6" )		// hangs at POST
+	PORT_DIPSETTING(      0x0040, DEF_STR( Off ) )
+	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x0080, 0x0080, "Start credit" )
+	PORT_DIPSETTING(      0x0080, "1" )
+	PORT_DIPSETTING(      0x0000, "2" )
+	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* probably unused */
+INPUT_PORTS_END
+
 /*** MACHINE DRIVER **********************************************************/
 
 static MACHINE_DRIVER_START( gstriker )
-	MDRV_CPU_ADD(M68000, 10000000)
+	MDRV_CPU_ADD("main", M68000, 10000000)
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_VBLANK_INT(irq1_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq1_line_hold)
 
-	MDRV_CPU_ADD(Z80,8000000/2)
-	/* audio CPU */	/* 4 MHz ??? */
+	MDRV_CPU_ADD("audio", Z80,8000000/2)	/* 4 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
-	MDRV_CPU_IO_MAP(sound_readport,sound_writeport)
+	MDRV_CPU_IO_MAP(sound_io_map,0)
 
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_AFTER_VBLANK)
+
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(5000) /* hand-tuned, it needs a bit */)
-
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_UPDATE_AFTER_VBLANK)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*8, 64*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 28*8-1)
+
 	MDRV_GFXDECODE(gstriker)
 	MDRV_PALETTE_LENGTH(0x800)
 
@@ -463,8 +592,8 @@ static MACHINE_DRIVER_START( gstriker )
 
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(YM2610, 8000000)
-	MDRV_SOUND_CONFIG(ym2610_interface)
+	MDRV_SOUND_ADD("ym", YM2610, 8000000)
+	MDRV_SOUND_CONFIG(ym2610_config)
 	MDRV_SOUND_ROUTE(0, "left",  0.25)
 	MDRV_SOUND_ROUTE(0, "right", 0.25)
 	MDRV_SOUND_ROUTE(1, "left",  1.0)
@@ -476,37 +605,75 @@ static MACHINE_DRIVER_START( twrldc94 )
 	MDRV_VIDEO_START( twrldc94 )
 MACHINE_DRIVER_END
 
+
+static MACHINE_DRIVER_START( vgoal )
+	MDRV_CPU_ADD("main", M68000, 16000000)
+	MDRV_CPU_PROGRAM_MAP(vgoal_map,0)
+	MDRV_CPU_VBLANK_INT("main", irq1_line_hold)
+
+	MDRV_CPU_ADD("audio", Z80,8000000/2)	/* 4 MHz ??? */
+	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
+	MDRV_CPU_IO_MAP(sound_io_map,0)
+
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_AFTER_VBLANK)
+
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(5000) /* hand-tuned, it needs a bit */)
+	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MDRV_SCREEN_SIZE(64*8, 64*8)
+	MDRV_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 28*8-1)
+
+	MDRV_GFXDECODE(gstriker)
+	MDRV_PALETTE_LENGTH(0x2000)
+
+	MDRV_VIDEO_START(vgoalsoc)
+	MDRV_VIDEO_UPDATE(gstriker)
+
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD("ym", YM2610, 8000000)
+	MDRV_SOUND_CONFIG(ym2610_config)
+	MDRV_SOUND_ROUTE(0, "left",  0.25)
+	MDRV_SOUND_ROUTE(0, "right", 0.25)
+	MDRV_SOUND_ROUTE(1, "left",  1.0)
+	MDRV_SOUND_ROUTE(2, "right", 1.0)
+MACHINE_DRIVER_END
+
+
+
+
 /*** ROM LOADING *************************************************************/
 
 ROM_START( gstriker )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, "main", 0 )
 	ROM_LOAD16_WORD_SWAP( "human-1.u58",  0x00000, 0x80000, CRC(45cf4857) SHA1(8133a9a7bdd547cc3d69140a68a1a5a7341e9f5b) )
 
-	ROM_REGION( 0x40000, REGION_CPU2, 0 )
+	ROM_REGION( 0x40000, "audio", 0 )
 	ROM_LOAD( "human-3.u87",  0x00000, 0x20000, CRC(2f28c01e) SHA1(63829ad7969d197b2f2c87cb88bdb9e9880ed2d6) )
 	ROM_RELOAD(               0x10000, 0x20000 )
 
-	ROM_REGION( 0x20000, REGION_GFX1, 0 ) // score tilemap
+	ROM_REGION( 0x20000, "gfx1", 0 ) // score tilemap
 	ROM_LOAD( "human-2.u79",  0x00000, 0x20000, CRC(a981993b) SHA1(ed92c7581d2b84a8628744dd5f8a2266c45dcd5b) )
 
-	ROM_REGION( 0x200000, REGION_GFX2, 0 ) // scroll tilemap
+	ROM_REGION( 0x200000, "gfx2", 0 ) // scroll tilemap
 	ROM_LOAD( "scrgs105.u2",  0x00000, 0x200000, CRC(d584b568) SHA1(64c5e4fdbb859873e51f62d8f5314598108270ef) )
 	ROM_LOAD( "scrgs105.u4",  0x00000, 0x200000, CRC(d584b568) SHA1(64c5e4fdbb859873e51f62d8f5314598108270ef) ) // same content, dif pos on board
 
-	ROM_REGION( 0x1000000, REGION_GFX3, 0 )
+	ROM_REGION( 0x1000000, "gfx3", 0 )
 	ROM_LOAD( "scrgs101.u25", 0x000000, 0x200000, CRC(becaea24) SHA1(e96fca863f49f50992f56c7defa5a69599608785) )
 	ROM_LOAD( "scrgs102.u24", 0x200000, 0x200000, CRC(0dae7aba) SHA1(304f336994be33fa8239c13e6fd9967c06f97d5c) )
 	ROM_LOAD( "scrgs103.u23", 0x400000, 0x200000, CRC(3448fe92) SHA1(c4c2d2d5610795aff6633b0601ff484897598904) )
 	ROM_LOAD( "scrgs104.u22", 0x600000, 0x200000, CRC(0ac33e5a) SHA1(9d7717d80f2c6817bac3fad50c39e04f0aa94255) )
 	ROM_LOAD( "human-4.u6",   0xf80000, 0x080000, CRC(a990f9bb) SHA1(7ce31d4c650eb244e2ab285f253a98d6613b7dc8) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x40000, "ym.deltat", 0 )
 	ROM_LOAD( "scrgs106.u93", 0x00000, 0x040000, CRC(93c9868c) SHA1(dcecb34e46405155e35aaf134b8547430d23f5a7) )
 
-	ROM_REGION( 0x100000, REGION_SOUND2, 0 )
+	ROM_REGION( 0x100000, "ym", 0 )
 	ROM_LOAD( "scrgs107.u99", 0x00000, 0x100000, CRC(ecc0a01b) SHA1(239e832b7d22925460a8f44eb82e782cd13aba49) )
 
-	ROM_REGION( 0x1000, REGION_PLDS, 0 )
+	ROM_REGION( 0x1000, "plds", 0 )
 	ROM_LOAD( "pal16l8.s201a.u52",   0x0000, 0x0104, CRC(724faf0f) SHA1(755fad09d188af58efce733a9f1256b1abc7c360) )
 	ROM_LOAD( "pal16l8.s202a.u74",   0x0200, 0x0104, CRC(ad5c4722) SHA1(0aad71b73c6674e15596b7de59160a5156a4118d) )
 	ROM_LOAD( "pal16l8.s203a.u75",   0x0400, 0x0104, CRC(ad197e2d) SHA1(e0691b79b8433285a0bafea1d52b0166f6417c20) )
@@ -515,106 +682,106 @@ ROM_START( gstriker )
 ROM_END
 
 ROM_START( vgoalsoc )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, "main", 0 )
 	ROM_LOAD16_WORD_SWAP( "c16_u37.u37",  0x00000, 0x80000, CRC(18c05440) SHA1(0fc78ee0ba6d7817d4a93a80f668f193c352c00d) )
 
-	ROM_REGION( 0x40000, REGION_CPU2, 0 )
+	ROM_REGION( 0x40000, "audio", 0 )
 	ROM_LOAD( "c16_u65.u65",  0x000000, 0x040000, CRC(2f7bf23c) SHA1(1a1a06f57bbac59807679e3762cb2f23ab1ad35e) )
 
-	ROM_REGION( 0x20000, REGION_GFX1, 0 ) // score tilemap
+	ROM_REGION( 0x20000, "gfx1", 0 ) // score tilemap
 	ROM_LOAD( "c16_u48.u48",  0x000000, 0x020000, CRC(ca059e7f) SHA1(2fa48b0fec1210575f3a1ecee7d2aec0af3fa9c4) )
 
-	ROM_REGION( 0x100000, REGION_GFX2, 0 ) // screen tilemap
+	ROM_REGION( 0x100000, "gfx2", 0 ) // screen tilemap
 	ROM_LOAD( "c13_u20.u20",  0x000000, 0x100000, CRC(bc6e07e8) SHA1(3f164165a2eed909aaf38d1ae23a622482d39f96) )
 	ROM_LOAD( "c13_u17.u17",  0x000000, 0x100000, CRC(bc6e07e8) SHA1(3f164165a2eed909aaf38d1ae23a622482d39f96) ) // same content, dif pos on board
 
-	ROM_REGION( 0x400000, REGION_GFX3, 0 )
+	ROM_REGION( 0x400000, "gfx3", 0 )
 	ROM_LOAD( "c13_u11.u11",  0x000000, 0x200000, CRC(76d09f27) SHA1(ffef83954426f9e56bbe2d98b32cea675c063fab) )
 	ROM_LOAD( "c13_u12.u12",  0x200000, 0x200000, CRC(a3874419) SHA1(c9fa283106ada3419e311f400fcf4251b32318c4) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x40000, "ym.deltat", 0 )
 	ROM_LOAD( "c13_u86.u86",  0x000000, 0x040000, CRC(4b76a162) SHA1(38dcb7536662f5f520e59f3ff746b42e9df789d2) )
 
-	ROM_REGION( 0x200000, REGION_SOUND2, 0 )
+	ROM_REGION( 0x200000, "ym", 0 )
 	ROM_LOAD( "c13_u104.104", 0x000000, 0x200000, CRC(8437b6f8) SHA1(79f183dcbf3cde5c77e086e4fdd8341809396e37) )
 ROM_END
 
 ROM_START( vgoalsca )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, "main", 0 )
 	ROM_LOAD16_WORD_SWAP( "vgoalc16.u37", 0x00000, 0x80000, CRC(775ef300) SHA1(d0ab1c13a19ce646c6edfc25a0c0994989560cbc) )
 
-	ROM_REGION( 0x40000, REGION_CPU2, 0 )
+	ROM_REGION( 0x40000, "audio", 0 )
 	ROM_LOAD( "c16_u65.u65",  0x000000, 0x040000, CRC(2f7bf23c) SHA1(1a1a06f57bbac59807679e3762cb2f23ab1ad35e) )
 
-	ROM_REGION( 0x20000, REGION_GFX1, 0 ) // fixed tile
+	ROM_REGION( 0x20000, "gfx1", 0 ) // fixed tile
 	ROM_LOAD( "c16_u48.u48",  0x000000, 0x020000, CRC(ca059e7f) SHA1(2fa48b0fec1210575f3a1ecee7d2aec0af3fa9c4) )
 
-	ROM_REGION( 0x200000, REGION_GFX2, 0 ) // scroll tile
+	ROM_REGION( 0x200000, "gfx2", 0 ) // scroll tile
 	ROM_LOAD( "vgoalc16.u20", 0x000000, 0x200000, CRC(2b211fb2) SHA1(4e04e099a1dae7abdb0732808a5d74fdc7afcf45) )
 	ROM_LOAD( "vgoalc16.u17", 0x000000, 0x200000, CRC(2b211fb2) SHA1(4e04e099a1dae7abdb0732808a5d74fdc7afcf45) ) // same content, dif pos on board
 
-	ROM_REGION( 0x400000, REGION_GFX3, 0 )
+	ROM_REGION( 0x400000, "gfx3", 0 )
 	ROM_LOAD( "vgoalc16.u11", 0x000000, 0x200000, CRC(5bc3146c) SHA1(ede4def1ddc4390fed8fd89643900967faff3640) )
 	ROM_LOAD( "c13_u12.u12",  0x200000, 0x200000, CRC(a3874419) SHA1(c9fa283106ada3419e311f400fcf4251b32318c4) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x40000, "ym.deltat", 0 )
 	ROM_LOAD( "c13_u86.u86",  0x000000, 0x040000, CRC(4b76a162) SHA1(38dcb7536662f5f520e59f3ff746b42e9df789d2) )
 
-	ROM_REGION( 0x100000, REGION_SOUND2, 0 )
+	ROM_REGION( 0x100000, "ym", 0 )
 	ROM_LOAD( "vgoalc16.104", 0x000000, 0x100000, CRC(6fb06e1b) SHA1(c4584b480fe1165f8e2f887acaa578690514d35d) )
 ROM_END
 
 ROM_START( twrldc94 )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, "main", 0 )
 	ROM_LOAD16_WORD_SWAP( "13.u37",           0x00000, 0x80000, CRC(42adb463) SHA1(ec7bcb684489b56f81ab851a9d8f42d54679363b) )
 
-	ROM_REGION( 0x40000, REGION_CPU2, 0 )
+	ROM_REGION( 0x40000, "audio", 0 )
 	ROM_LOAD( "12.u65",           0x000000, 0x040000, CRC(f316e7fc) SHA1(a2215605518e7293774735371c65abcead99bd88) )
 
-	ROM_REGION( 0x20000, REGION_GFX1, 0 ) // fixed tile
+	ROM_REGION( 0x20000, "gfx1", 0 ) // fixed tile
 	ROM_LOAD( "11.u48",           0x000000, 0x020000, CRC(37d6dcb6) SHA1(679dd8b615497fff23c4638d413b5d4a724d3f2a) )
 
-	ROM_REGION( 0x200000, REGION_GFX2, 0 ) // scroll tile
+	ROM_REGION( 0x200000, "gfx2", 0 ) // scroll tile
 	ROM_LOAD( "u17",          0x000000, 0x200000, CRC(a5e40a61) SHA1(a2cb452fb069862570870653b29b045d12caf062) )
 	ROM_LOAD( "u20",          0x000000, 0x200000, CRC(a5e40a61) SHA1(a2cb452fb069862570870653b29b045d12caf062) )
 
-	ROM_REGION( 0x800000, REGION_GFX3, 0 )
+	ROM_REGION( 0x800000, "gfx3", 0 )
 	ROM_LOAD( "u11",          0x000000, 0x200000, CRC(dd93fd45) SHA1(26491815b5443fe6d8b1ef4d795c5151fd75c101) )
 	ROM_LOAD( "u12",          0x200000, 0x200000, CRC(8e3c9bd2) SHA1(bfd23157c836148a3860ccea5191f656fdd98ef4) )
 	ROM_LOAD( "u13",          0x400000, 0x200000, CRC(8db6b3a9) SHA1(9422cd5d6fb57a7eaa7a13bdf4ccee1f8b57f773) )
 	ROM_LOAD( "u14",          0x600000, 0x200000, CRC(89739c31) SHA1(29cd779bfe93448fb6cbfe6f8e3661dd659c0d21) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x40000, "ym.deltat", 0 )
 	ROM_LOAD( "u86",          0x000000, 0x040000, CRC(775f45dc) SHA1(1a740dd880d9f873e93dfc096fbcae1784b4f522) )
 
-	ROM_REGION( 0x100000, REGION_SOUND2, 0 )
+	ROM_REGION( 0x100000, "ym", 0 )
 	ROM_LOAD( "u104",         0x000000, 0x100000, CRC(df07d0af) SHA1(356560e164ff222bc9004fe202f829c93244a6c9) )
 ROM_END
 
 ROM_START( twrdc94a )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, "main", 0 )
 	ROM_LOAD16_WORD_SWAP( "twrdc94a_13.u37",           0x00000, 0x80000, CRC(08f314ee) SHA1(3fca5050f5bcd60533d3bd9dea81ba631a98bfd6) )
 
-	ROM_REGION( 0x40000, REGION_CPU2, 0 )
+	ROM_REGION( 0x40000, "audio", 0 )
 	ROM_LOAD( "twrdc94a_12.u65",           0x000000, 0x040000, CRC(c131f5a4) SHA1(d8cc7c463ad628f6f052489a73b97f998532738d) )
 
-	ROM_REGION( 0x20000, REGION_GFX1, 0 ) // fixed tile
+	ROM_REGION( 0x20000, "gfx1", 0 ) // fixed tile
 	ROM_LOAD( "twrdc94a_11.u48",           0x000000, 0x020000, CRC(37d6dcb6) SHA1(679dd8b615497fff23c4638d413b5d4a724d3f2a) )
 
-	ROM_REGION( 0x200000, REGION_GFX2, 0 ) // scroll tile
+	ROM_REGION( 0x200000, "gfx2", 0 ) // scroll tile
 	ROM_LOAD( "u17",          0x000000, 0x200000, CRC(a5e40a61) SHA1(a2cb452fb069862570870653b29b045d12caf062) )
 	ROM_LOAD( "u20",          0x000000, 0x200000, CRC(a5e40a61) SHA1(a2cb452fb069862570870653b29b045d12caf062) )
 
-	ROM_REGION( 0x800000, REGION_GFX3, 0 )
+	ROM_REGION( 0x800000, "gfx3", 0 )
 	ROM_LOAD( "u11",          0x000000, 0x200000, CRC(dd93fd45) SHA1(26491815b5443fe6d8b1ef4d795c5151fd75c101) )
 	ROM_LOAD( "u12",          0x200000, 0x200000, CRC(8e3c9bd2) SHA1(bfd23157c836148a3860ccea5191f656fdd98ef4) )
 	ROM_LOAD( "u13",          0x400000, 0x200000, CRC(8db6b3a9) SHA1(9422cd5d6fb57a7eaa7a13bdf4ccee1f8b57f773) )
 	ROM_LOAD( "u14",          0x600000, 0x200000, CRC(89739c31) SHA1(29cd779bfe93448fb6cbfe6f8e3661dd659c0d21) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x40000, "ym.deltat", 0 )
 	ROM_LOAD( "u86",          0x000000, 0x040000, CRC(775f45dc) SHA1(1a740dd880d9f873e93dfc096fbcae1784b4f522) )
 
-	ROM_REGION( 0x100000, REGION_SOUND2, 0 )
+	ROM_REGION( 0x100000, "ym", 0 )
 	ROM_LOAD( "u104",         0x000000, 0x100000, CRC(df07d0af) SHA1(356560e164ff222bc9004fe202f829c93244a6c9) )
 ROM_END
 
@@ -636,27 +803,221 @@ or to advance into the tests.
 work_ram[0x000/2] = (_num_ & 0xffff0000) >> 16;\
 work_ram[0x002/2] = (_num_ & 0x0000ffff) >> 0;
 
+static int gametype = 0;
+static UINT16 mcu_data = 0;
+
 static WRITE16_HANDLER( twrldc94_mcu_w )
 {
-	switch(data)
+	mcu_data = data;
+}
+
+static READ16_HANDLER( twrldc94_mcu_r )
+{
+	return mcu_data;
+}
+
+static UINT16 prot_reg[2] = {0,0}; // current,last
+static WRITE16_HANDLER( twrldc94_prot_reg_w )
+{
+	prot_reg[1] = prot_reg[0];
+	prot_reg[0] = data;
+
+	if( ((prot_reg[1] & 2) == 2) && ((prot_reg[0] & 2) == 0) )
 	{
-		/*P.O.S.T. / Test Mode*/
-		case 0x53: PC(0x00000a4c); break;
-		/*Time Up*/
-		case 0x68: break;
-		/*Title Screen*/
-		case 0x69: break;
-		/*Gameplay / Attract mode*/
-		case 0x6b: PC(0x00000746); break;
-		/*(after the P.O.S.T.)*/
-		case 0x6e: PC(0x00000746); break;/*WRONG?*/
-		default: popmessage("Unknown MCU CMD %04x",data);
+		switch( gametype )
+		{
+			case 1:
+				switch(mcu_data)
+				{
+					#define NULL_SUB 0x0000828E
+					case 0x53: PC(0x0000a4c); break; // boot -> main loop
+
+					/*
+                        68 and 62 could be sprite or sound changes, or ?
+                        68(),61()
+                        if( !carry )
+                        {
+                            68(),65()
+                        }
+                        else
+                        {
+                            62(),72()
+                        }
+                    */
+					case 0x68: PC(NULL_SUB); break; // time up doesn't block long enough for pk shootout
+					case 0x61: PC(0x0003AF4); break; // after time up, pk shootout???
+					case 0x65: PC(0x0003F26); break;
+
+					// 62->72
+					case 0x62: PC(NULL_SUB); break;	// after lose shootout, continue ???
+					case 0x72: PC(0x000409E); break; // game over
+
+					/*
+                        Attract mode is pre programmed loop called from main
+                        that runs through top11->demoplay
+                        (NOTE: sprites for demo play are being drawn at 0x141000,
+                        this address is used in a few places, and there's some activity
+                        further up around 0x1410b0.)
+
+                        The loop begins with three prot calls:
+                        one always present (may be diversion to 0x0010DC8 unreachable code
+                        and prot cases 6a,79,6f) and two alternating calls.
+                        The loop is 6e -> [6b|69] -> top11 -> (4 segment)playdemo
+
+                        These are the likely suspects for attract mode:
+                        0x0010E28 red tecmo on black
+                        0x0010EEC bouncing ball and player with game title
+                        0x00117A2 single segment demo play with player sprites at 0x140000
+                        0x001120A sliding display of player photos
+                        0x0010DC8 unreachable code at end of attract loop with cases 6a,79,6f
+
+                    */
+					case 0x6e: PC(0x0010E28); break; // loop
+					case 0x6b: PC(0x0010EEC); break; // attract even
+					case 0x69: PC(0x001120A); break; // attract odd
+
+					// In "continue" screen
+					// if( w@FFE078 & 80) 75
+					// *** after 75 beq
+					case 0x75: PC(NULL_SUB); break;
+
+					// unreachable code at end of attract loop 6a->79->6f
+					case 0x6a: PC(NULL_SUB); break;
+					case 0x79: PC(NULL_SUB); break;
+					case 0x6f: PC(NULL_SUB); break;
+
+					default:
+						popmessage("Unknown MCU CMD %04x",mcu_data);
+						PC(NULL_SUB);
+						break;
+				}
+				break;
+
+			case 2:
+				switch(mcu_data)
+				{
+					case 0x53: PC(0x00000a5c); break; // POST
+
+					default:
+						popmessage("Unknown MCU CMD %04x",mcu_data);
+						PC(NULL_SUB);
+						break;
+				}
+				break;
+
+
+			case 3:
+				switch(mcu_data)
+				{
+					case 0x33: PC(0x00063416); break; // *after game over, is this right?
+					case 0x3d: PC(0x0006275C); break; // after sprite ram init, team select
+					case 0x42: PC(0x0006274E); break; // after press start, init sprite ram
+					case 0x43: PC(0x0006a000); break; // POST
+					case 0x50: PC(0x00001900); break; // enter main loop
+					case 0x65: PC(0x0006532C); break; // results
+					case 0x70: PC(0x00063416); break; // *attract loop ends, what should happen after "standings" display?
+					case 0x74: PC(0x000650D8); break; // after time up, show scores and continue
+					case 0x79: PC(0x0006072E); break; // after select, start match
+
+					default:
+						popmessage("Unknown MCU CMD %04x",mcu_data);
+						PC(0x00000586); // rts
+						break;
+				}
+				break;
+		}
 	}
 }
 
+static READ16_HANDLER( twrldc94_prot_reg_r )
+{
+	// bit 0 is for debugging vgoalsoc?
+	// Setting it results in a hang with a digit displayed on screen
+	// For twrldc94, it just disables sound.
+
+	return prot_reg[0];
+}
+
+/*
+    vgoalsoc uses a set of programmable timers.
+    There is a code implementation for at 00065F00 that appears to have
+    been RTSed out.
+    I'm guessing it was replaced with an external implementation.
+
+    This does indicate though that the protection could be performing
+    other more complicated functions.
+
+    The tick count is usually set to 0x3c => it's driven off vblank?
+*/
+//work_ram[ (0xffe900 - 0xffc00) ]
+#define COUNTER1_ENABLE work_ram[0x2900/2] >> 8
+#define COUNTER2_ENABLE (work_ram[0x2900/2] & 0xff)
+#define TICK_1 work_ram[0x2908/2]
+#define TICKCOUNT_1 work_ram[0x290a/2]
+#define TICK_2 work_ram[0x290c/2]
+#define TICKCOUNT_3 work_ram[0x290e/2]
+#define COUNTER_1 work_ram[0x2928/2]
+#define COUNTER_2 work_ram[0x292a/2]
+static READ16_HANDLER( vbl_toggle_r )
+{
+	return 0xff;
+}
+
+static WRITE16_HANDLER( vbl_toggle_w )
+{
+	if( COUNTER1_ENABLE == 1 )
+	{
+		TICK_1 = (TICK_1 - 1) & 0xff;	// 8bit
+		if( TICK_1 <= 0 )
+		{
+			TICK_1 = TICKCOUNT_1;
+			COUNTER_1 = (COUNTER_1 - 1);// & 0xff; has to be 16bit for continue timer.
+		}
+	}
+
+	if( COUNTER2_ENABLE == 2 )
+	{
+		TICK_2  = (TICK_2 - 1) & 0xff;
+		if( TICK_2 <= 0 )
+		{
+			TICK_2 = TICKCOUNT_3;
+			COUNTER_2 = (COUNTER_2 - 1);// & 0xff;
+		}
+	}
+}
+
+static void mcu_init( running_machine *machine )
+{
+	dmmy_8f_ret = 0xFFFF;
+	pending_command = 0;
+	mcu_data = 0;
+
+	memory_install_write16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x20008a, 0x20008b, 0, 0, twrldc94_mcu_w);
+	memory_install_read16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x20008a, 0x20008b, 0, 0, twrldc94_mcu_r);
+
+	memory_install_write16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x20008e, 0x20008f, 0, 0, twrldc94_prot_reg_w);
+	memory_install_read16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x20008e, 0x20008f, 0, 0, twrldc94_prot_reg_r);
+}
+
 static DRIVER_INIT( twrldc94 )
 {
-	memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0x20008a, 0x20008b, 0, 0, twrldc94_mcu_w);
+	gametype = 1;
+	mcu_init( machine );
+}
+
+static DRIVER_INIT( twrldc94a )
+{
+	gametype = 2;
+	mcu_init( machine );
+}
+
+static DRIVER_INIT( vgoalsoc )
+{
+	gametype = 3;
+	mcu_init( machine );
+
+	memory_install_write16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x200090, 0x200091, 0, 0, vbl_toggle_w); // vblank toggle
+	memory_install_read16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x200090, 0x200091, 0, 0, vbl_toggle_r);
 }
 
 /*** GAME DRIVERS ************************************************************/
@@ -664,7 +1025,8 @@ static DRIVER_INIT( twrldc94 )
 GAME( 1993, gstriker, 0,        gstriker, gstriker, 0,        ROT0, "Human", "Grand Striker", GAME_IMPERFECT_GRAPHICS )
 
 /* Similar, but not identical hardware, appear to be protected by an MCU :-( */
-GAME( 199?, vgoalsoc, 0,        gstriker, gstriker, 0,        ROT0, "Tecmo", "V Goal Soccer (set 1)", GAME_NOT_WORKING )
-GAME( 199?, vgoalsca, vgoalsoc, gstriker, gstriker, 0,        ROT0, "Tecmo", "V Goal Soccer (set 2)", GAME_NOT_WORKING )
-GAME( 1994, twrldc94, 0,        twrldc94, gstriker, twrldc94, ROT0, "Tecmo", "Tecmo World Cup '94 (set 1)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_GRAPHICS )
-GAME( 1994, twrdc94a, twrldc94, twrldc94, gstriker, twrldc94, ROT0, "Tecmo", "Tecmo World Cup '94 (set 2)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_GRAPHICS )
+GAME( 199?, vgoalsoc, 0,        vgoal,    vgoalsoc, vgoalsoc,   ROT0, "Tecmo", "V Goal Soccer (set 1)", GAME_NOT_WORKING )
+GAME( 199?, vgoalsca, vgoalsoc, vgoal,    vgoalsoc, vgoalsoc,   ROT0, "Tecmo", "V Goal Soccer (set 2)", GAME_NOT_WORKING )
+GAME( 1994, twrldc94, 0,        twrldc94, twrldc94, twrldc94,   ROT0, "Tecmo", "Tecmo World Cup '94 (set 1)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_GRAPHICS )
+GAME( 1994, twrdc94a, twrldc94, twrldc94, twrldc94, twrldc94a,  ROT0, "Tecmo", "Tecmo World Cup '94 (set 2)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION | GAME_IMPERFECT_GRAPHICS )
+
