@@ -15,6 +15,7 @@
 */
 
 #include "driver.h"
+#include "cpu/arm7/arm7.h"
 #include "cpu/arm7/arm7core.h"
 
 
@@ -40,7 +41,7 @@ static WRITE32_HANDLER( igs_cg_videoram_w )
 {
 	COMBINE_DATA(&igs_cg_videoram[offset]);
 	//if(data!=0)
-	logerror("PC(%08X) CG @%x = %x!\n",activecpu_get_pc(),offset ,igs_cg_videoram[offset]);
+	logerror("PC(%08X) CG @%x = %x!\n",cpu_get_pc(space->cpu),offset ,igs_cg_videoram[offset]);
 
 
 
@@ -132,10 +133,10 @@ static WRITE32_HANDLER( igs_pallete32_w )
 
 static VIDEO_START(igs_majhong)
 {
-	igs_tx_tilemap= tilemap_create(get_tx_tilemap_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN, 8, 8,64,32);
+	igs_tx_tilemap= tilemap_create(machine, get_tx_tilemap_tile_info,tilemap_scan_rows, 8, 8,64,32);
 	tilemap_set_transparent_pen(igs_tx_tilemap,15);
-	igs_bg_tilemap= tilemap_create(get_bg_tilemap_tile_info,tilemap_scan_rows,0, 8, 8,64,32);
-	//igs_bg_tilemap= tilemap_create(get_bg_tilemap_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN, 8, 8,64,32);
+	igs_bg_tilemap= tilemap_create(machine, get_bg_tilemap_tile_info,tilemap_scan_rows, 8, 8,64,32);
+	//igs_bg_tilemap= tilemap_create(machine, get_bg_tilemap_tile_info,tilemap_scan_rows, 8, 8,64,32);
 	//tilemap_set_transparent_pen(igs_bg_tilemap,15);
 	logerror("Video START OK!\n");
 }
@@ -143,7 +144,7 @@ static VIDEO_START(igs_majhong)
 static VIDEO_UPDATE(igs_majhong)
 {
 	//??????????
-	fillbitmap(bitmap,get_black_pen(machine),&machine->screen[0].visarea);
+	bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
 
 	//??????
 	tilemap_draw(bitmap,cliprect,igs_bg_tilemap,0,0);
@@ -169,15 +170,15 @@ static VIDEO_UPDATE(igs_majhong)
 
 static ADDRESS_MAP_START( igs_majhong_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x00000000, 0x00003fff) AM_ROM /* Internal ROM */
-	AM_RANGE(0x08000000, 0x0807ffff) AM_ROM AM_REGION(REGION_USER1, 0)/* Game ROM */
+	AM_RANGE(0x08000000, 0x0807ffff) AM_ROM AM_REGION("user1", 0)/* Game ROM */
 	AM_RANGE(0x10000000, 0x100003ff) AM_RAM AM_BASE(&igs_mainram)// main ram for asic?
 	AM_RANGE(0x18000000, 0x18007fff) AM_RAM
 
-	AM_RANGE(0x38001000, 0x380017ff) AM_READWRITE(MRA32_RAM, igs_cg_videoram_w) AM_BASE(&igs_cg_videoram)		//0x200 * 1   CG PALLETE?
-	AM_RANGE(0x38001800, 0x38001fff) AM_READWRITE(MRA32_RAM, igs_pallete32_w) AM_BASE(&igs_pallete32)		//0x200 * 1
+	AM_RANGE(0x38001000, 0x380017ff) AM_RAM_WRITE(igs_cg_videoram_w) AM_BASE(&igs_cg_videoram)		//0x200 * 1   CG PALLETE?
+	AM_RANGE(0x38001800, 0x38001fff) AM_RAM_WRITE(igs_pallete32_w) AM_BASE(&igs_pallete32)		//0x200 * 1
 
-	AM_RANGE(0x38004000, 0x38005FFF) AM_READWRITE(MRA32_RAM, igs_tx_videoram_w) AM_BASE(&igs_tx_videoram) /* Text Layer */
-	AM_RANGE(0x38006000, 0x38007FFF) AM_READWRITE(MRA32_RAM, igs_bg_videoram_w) AM_BASE(&igs_bg_videoram) /* CG Layer */
+	AM_RANGE(0x38004000, 0x38005FFF) AM_RAM_WRITE(igs_tx_videoram_w) AM_BASE(&igs_tx_videoram) /* Text Layer */
+	AM_RANGE(0x38006000, 0x38007FFF) AM_RAM_WRITE(igs_bg_videoram_w) AM_BASE(&igs_bg_videoram) /* CG Layer */
 
 
 	AM_RANGE(0x38002010, 0x38002017) AM_RAM		//??????????????
@@ -218,11 +219,11 @@ static const UINT8 sdwx_tab[] =
 	0x12,0x56,0x97,0x26,0x1D,0x5F,0xA7,0xF8,0x89,0x3F,0x14,0x36,0x72,0x3B,0x48,0x7B,
 	0xF1,0xED,0x72,0xB7,0x7A,0x56,0x05,0xDE,0x7B,0x27,0x6D,0xCF,0x33,0x4C,0x14,0x86,
 };
-static void sdwx_decrypt(void)
+static void sdwx_decrypt(running_machine *machine)
 {
 
 	int i;
-	UINT16 *src = (UINT16 *) memory_region(REGION_USER1);
+	UINT16 *src = (UINT16 *) memory_region(machine, "user1");
 
 	int rom_size = 0x80000;
 
@@ -263,11 +264,11 @@ static void sdwx_decrypt(void)
 
 
 
-static void sdwx_gfx_decrypt(void)
+static void sdwx_gfx_decrypt(running_machine *machine)
 {
 	int i;
 	unsigned rom_size = 0x80000;
-	UINT8 *src = (UINT8 *) (memory_region(REGION_GFX1));
+	UINT8 *src = (UINT8 *) (memory_region(machine, "gfx1"));
 	UINT8 *result_data = malloc_or_die(rom_size);
 
 	for (i=0; i<rom_size; i++)
@@ -352,33 +353,35 @@ static const gfx_layout gfxlayout_16x16x16 =
 #endif
 
 static GFXDECODE_START( igs_m027 )
-    GFXDECODE_ENTRY( REGION_GFX1, 0, gfxlayout_8x8x4,   0, 16  )
-   // GFXDECODE_ENTRY( REGION_GFX2, 0, gfxlayout_16x16x16, 0, 16  )
+    GFXDECODE_ENTRY( "gfx1", 0, gfxlayout_8x8x4,   0, 16  )
+   // GFXDECODE_ENTRY( "gfx2", 0, gfxlayout_16x16x16, 0, 16  )
 GFXDECODE_END
 
 
 static INTERRUPT_GEN( igs_majhong_interrupt )
 {
-	cpunum_set_input_line(machine, 0, ARM7_FIRQ_LINE, PULSE_LINE);
+	generic_pulse_irq_line(device, ARM7_FIRQ_LINE);
 }
 
 
 static MACHINE_DRIVER_START( igs_majhong )
-	MDRV_CPU_ADD_TAG("main",ARM7, 20000000)
+	MDRV_CPU_ADD("main",ARM7, 20000000)
 
 	MDRV_CPU_PROGRAM_MAP(igs_majhong_map,0)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_CPU_VBLANK_INT(igs_majhong_interrupt,1)
+	MDRV_CPU_VBLANK_INT("main", igs_majhong_interrupt)
 	//MDRV_NVRAM_HANDLER(generic_0fill)
 
 	MDRV_GFXDECODE(igs_m027)
 
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(512, 256)
 	MDRV_SCREEN_VISIBLE_AREA(0, 512-1, 0, 256-1)
+
 	MDRV_PALETTE_LENGTH(0x200)
 
 	MDRV_VIDEO_START( igs_majhong )
@@ -393,8 +396,8 @@ MACHINE_DRIVER_END
 
 static DRIVER_INIT( sdwx )
 {
-	sdwx_decrypt();
-	sdwx_gfx_decrypt();
+	sdwx_decrypt(machine);
+	sdwx_gfx_decrypt(machine);
 	logerror("init OK!\n");
 }
 
@@ -406,20 +409,20 @@ static DRIVER_INIT( sdwx )
 
 ***************************************************************************/
 ROM_START( sdwx )
-	ROM_REGION( 0x04000, REGION_CPU1, 0 )
+	ROM_REGION( 0x04000, "main", 0 )
 	/* Internal rom of IGS027A ARM based MCU */
 	ROM_LOAD( "sdwx_igs027a", 0x00000, 0x4000, NO_DUMP )
 
-	ROM_REGION( 0x80000, REGION_USER1, 0 ) // external ARM data / prg
+	ROM_REGION( 0x80000, "user1", 0 ) // external ARM data / prg
 	ROM_LOAD( "prg.u16", 0x000000, 0x80000, CRC(c94ef6a8) SHA1(69f2f356e05206b0866a9020253d9a112b56316c) )
 
-	ROM_REGION( 0x80000, REGION_GFX1, 0 )
+	ROM_REGION( 0x80000, "gfx1", 0 )
 	ROM_LOAD( "text.u24", 0x000000, 0x80000, CRC(60b415ac) SHA1(b4475b0ba1e70504cac9ac05078873df0b16495b) )
 
-	ROM_REGION( 0x200000, REGION_GFX2, 0 )
+	ROM_REGION( 0x200000, "gfx2", 0 )
 	ROM_LOAD( "cg.u25", 0x000000, 0x200000, CRC(709b9a42) SHA1(18c4b8e159b29c168f5cafb437fe6eb123672471) )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x80000, "unknown", 0 )
 	ROM_LOAD( "sp.u2", 0x00000, 0x80000, CRC(216b5418) SHA1(b7bc24ced0ccb5476c974420aa506c13b971fc9f) )
 ROM_END
 
@@ -427,98 +430,98 @@ ROM_END
 
 
 ROM_START( sddz )
-	ROM_REGION( 0x04000, REGION_CPU1, 0 )
+	ROM_REGION( 0x04000, "main", 0 )
 	/* Internal rom of IGS027A ARM based MCU */
 	ROM_LOAD( "sddz_igs027a", 0x00000, 0x4000, NO_DUMP )
 
-	ROM_REGION( 0x80000, REGION_USER1, 0 ) // external ARM data / prg
+	ROM_REGION( 0x80000, "user1", 0 ) // external ARM data / prg
 	ROM_LOAD( "ddz_218cn.u17", 0x000000, 0x80000, CRC(3cfe38d5) SHA1(9c7f82ecffbc22879583519d5f753bb35e973ee3) )
 
-	ROM_REGION( 0x80000, REGION_GFX1, 0 )
+	ROM_REGION( 0x80000, "gfx1", 0 )
 	ROM_LOAD( "ddz_text.u27", 0x000000, 0x80000, CRC(520dc392) SHA1(0ab2620f20af8253806b6ff4e1d9d77a694da17c) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, 0 )
+	ROM_REGION( 0x400000, "gfx2", 0 )
 	ROM_LOAD( "ddz_ani.u28", 0x000000, 0x400000, CRC(72487508) SHA1(9f4bbc858960ddaae403e4a3330b2345f6fd6cb3))
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "unknown", 0 )
 	ROM_LOAD( "ddz_sp.u4", 0x00000, 0x200000, CRC(7ef65d95) SHA1(345c587cd449d6d06908e9687480be76b2cb2d28) )
 ROM_END
 
 
 
 ROM_START( lhzb3 )
-	ROM_REGION( 0x04000, REGION_CPU1, 0 )
+	ROM_REGION( 0x04000, "main", 0 )
 	/* Internal rom of IGS027A ARM based MCU */
 	ROM_LOAD( "lhzb3_igs027a", 0x00000, 0x4000, NO_DUMP )
 
-	ROM_REGION( 0x80000, REGION_USER1, 0 ) // external ARM data / prg
+	ROM_REGION( 0x80000, "user1", 0 ) // external ARM data / prg
 	ROM_LOAD( "lhzb3_104.u9", 0x000000, 0x80000, CRC(70d61846) SHA1(662b59702ef6f26129de6b16346786df92f99097) )
 
-	ROM_REGION( 0x80000, REGION_GFX1, 0 )
+	ROM_REGION( 0x80000, "gfx1", 0 )
 	ROM_LOAD( "lhzb3_text.u17", 0x000000, 0x80000,CRC(a82398a9) SHA1(4d2987f57096b7f24ce6571ed3be6dcb33bce88d) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, 0 )
+	ROM_REGION( 0x400000, "gfx2", 0 )
 	ROM_LOAD( "m2401.u18", 0x000000, 0x400000,  CRC(81428f18) SHA1(9fb19c8a79cc3443642f4b044e04735df2cb45be) )
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "unknown", 0 )
 	ROM_LOAD( "s2402.u14", 0x00000, 0x100000, CRC(56083fe2) SHA1(62afd651809bf5e639bfda6e5579dbf4b903b664) )
 ROM_END
 
 
 ROM_START( lhzb4 )
-	ROM_REGION( 0x04000, REGION_CPU1, 0 )
+	ROM_REGION( 0x04000, "main", 0 )
 	/* Internal rom of IGS027A ARM based MCU */
 	ROM_LOAD( "lhzb4_igs027a", 0x00000, 0x4000, NO_DUMP )
 
-	ROM_REGION( 0x80000, REGION_USER1, 0 ) // external ARM data / prg
+	ROM_REGION( 0x80000, "user1", 0 ) // external ARM data / prg
 	ROM_LOAD( "lhzb4_104.u17", 0x000000, 0x80000, CRC(6f349bbb) SHA1(54cf895889ef0f208637ba732ede696ca3603ee0) )
 
-	ROM_REGION( 0x80000, REGION_GFX1, 0 )
+	ROM_REGION( 0x80000, "gfx1", 0 )
 	ROM_LOAD( "lhzb4_text.u27", 0x000000, 0x80000, CRC(8488b039) SHA1(59bc9eccba810fcac2a53866b2da1e71bfd8a6e7) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, 0 )
+	ROM_REGION( 0x400000, "gfx2", 0 )
 	ROM_LOAD( "a05501.u28", 0x000000, 0x400000, CRC(f78b3714) SHA1(c73d8e50b04126bc4f91783384713624ed133ee2) )
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "unknown", 0 )
 	ROM_LOAD( "w05502.u5", 0x00000, 0x200000, CRC(467f677e) SHA1(63927c0d606176c0e22db89ea3a9777ed702abbd) )
 ROM_END
 
 
 
 ROM_START( klxyj )
-	ROM_REGION( 0x04000, REGION_CPU1, 0 )
+	ROM_REGION( 0x04000, "main", 0 )
 	/* Internal rom of IGS027A ARM based MCU */
 	ROM_LOAD( "klxyj_igs027a", 0x00000, 0x4000, NO_DUMP )
 
-	ROM_REGION( 0x80000, REGION_USER1, 0 ) // external ARM data / prg
+	ROM_REGION( 0x80000, "user1", 0 ) // external ARM data / prg
 	ROM_LOAD( "klxyj_104.u16", 0x000000, 0x80000, CRC(8cb9bdc2) SHA1(5a13d0ff6488a938617a9ea89e7cf607539a1f49) )
 
-	ROM_REGION( 0x80000, REGION_GFX1, 0 )
+	ROM_REGION( 0x80000, "gfx1", 0 )
 	ROM_LOAD( "klxyj_text.u24", 0x000000, 0x80000, CRC(22dcebd0) SHA1(0383f017135230d020d12c8c6cc3aeb136fe9106) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, 0 )
+	ROM_REGION( 0x400000, "gfx2", 0 )
 	ROM_LOAD( "a4202.u25", 0x000000, 0x400000, CRC(97a68f85) SHA1(177c8c23fd0d585b24a71359ede005ac9a2e4d4d) )
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "unknown", 0 )
 	ROM_LOAD( "w4201.u2", 0x00000, 0x100000, CRC(464f11ab) SHA1(56e45bd31f667fc30387fcd4c940a94819b7ef0f) )
 ROM_END
 
 
 ROM_START( mgfx )
-	ROM_REGION( 0x04000, REGION_CPU1, 0 )
+	ROM_REGION( 0x04000, "main", 0 )
 	/* Internal rom of IGS027A ARM based MCU */
 	ROM_LOAD( "mgfx_igs027a", 0x00000, 0x4000, NO_DUMP )
 
-	ROM_REGION( 0x80000, REGION_USER1, 0 ) // external ARM data / prg
+	ROM_REGION( 0x80000, "user1", 0 ) // external ARM data / prg
 	ROM_LOAD( "mgfx_101.u10", 0x000000, 0x80000, CRC(897c88a1) SHA1(0f7a7808b9503ff28ad32c0b8e071cb24cff59b1) )
 
-	ROM_REGION( 0x80000, REGION_GFX1, 0 )
+	ROM_REGION( 0x80000, "gfx1", 0 )
 	ROM_LOAD( "mgfx_text.u9", 0x000000, 0x80000, CRC(e41e7768) SHA1(3d0add7c75c23533309e799fd8853c815e6f811c) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, 0 )
+	ROM_REGION( 0x400000, "gfx2", 0 )
 	ROM_LOAD( "mgfx_ani.u17", 0x000000, 0x400000, CRC(9fc75f4d) SHA1(acb600739dcf252a5210e28ec96d749573061b27) )
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "unknown", 0 )
 	ROM_LOAD( "mgfx_sp.u14", 0x00000, 0x100000, CRC(9bb28fc8) SHA1(6368753c29607f2d212d68c5cca3f10aa069649b) )
 ROM_END
 
@@ -569,21 +572,21 @@ Notes:
 */
 
 ROM_START( bigd2 )
-	ROM_REGION( 0x04000, REGION_CPU1, 0 )
+	ROM_REGION( 0x04000, "main", 0 )
 	/* Internal rom of IGS027A ARM based MCU */
 	ROM_LOAD( "bigd2_igs027a", 0x00000, 0x4000, NO_DUMP )
 
-	ROM_REGION( 0x80000, REGION_USER1, 0 ) // external ARM data / prg
+	ROM_REGION( 0x80000, "user1", 0 ) // external ARM data / prg
 	ROM_LOAD( "p2600.u10", 0x000000, 0x80000, CRC(9ad34135) SHA1(54717753d1296efe49946369fd4a27181f19dbc0) )
 
-	ROM_REGION( 0x80000, REGION_GFX1, 0 )
+	ROM_REGION( 0x80000, "gfx1", 0 )
 	ROM_LOAD( "t2604.u9", 0x000000, 0x80000, CRC(5401a52d) SHA1(05b47a4b39939c1d5904e3fbd5cc56d6ee9b7953) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, 0 )
+	ROM_REGION( 0x400000, "gfx2", 0 )
 	ROM_LOAD( "m2601.u17", 0x000000, 0x400000, CRC(89736e3f) SHA1(6a22e2eb10d2c740cf21640c43a8caf4c72d3be7) )
 	ROM_LOAD( "m2603.u18", 0x000000, 0x080000, CRC(fb2e91a8) SHA1(29b2f0ce3749539cbe4cfb5c40b240cc7f6147f1) )
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "unknown", 0 )
 	ROM_LOAD( "s2602.u14", 0x00000, 0x100000, CRC(f137028c) SHA1(0e4114222820bca2f7026fa653e2b96a489a0183) )
 ROM_END
 
