@@ -5,13 +5,13 @@
     driver by Phil Bennett
 
     Games supported:
+        * Coronation Street Quiz Game
         * Cluedo (3 sets)
         * Hangman
         * Scrabble
         * Trivial Pursuit
 
     ROMS wanted:
-        * Coronation Street
         * Snakes and Ladders
 
     Known issues:
@@ -78,9 +78,8 @@
 ****************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/m68000/m68000.h"
 #include "cpu/tms34010/tms34010.h"
-#include "cpu/tms34010/34010ops.h"
 #include "sound/upd7759.h"
 #include "jpmimpct.h"
 #include "machine/meters.h"
@@ -154,19 +153,10 @@ static struct
  *
  *************************************/
 
-static void update_irqs(void)
+static void update_irqs(running_machine *machine)
 {
-	int newstate = 0;
-
-	if (tms_irq)
-		newstate = 2;
-	if (duart_1_irq)
-		newstate = 5;
-
-	if (newstate)
-		cpunum_set_input_line(Machine, 0, newstate, ASSERT_LINE);
-	else
-		cpunum_set_input_line(Machine, 0, 7, CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], 2, tms_irq ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], 5, duart_1_irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -180,22 +170,22 @@ static MACHINE_RESET( jpmimpct )
 {
 	memset(&duart_1, 0, sizeof(duart_1));
 
-	duart_1_timer = timer_alloc(duart_1_timer_event, NULL);
+	duart_1_timer = timer_alloc(machine, duart_1_timer_event, NULL);
 
 	/* Reset states */
 	duart_1_irq = tms_irq = 0;
 	touch_cnt = 0;
 
 //  duart_1.IVR=0x0f;
-	state_save_register_global(tms_irq);
-	state_save_register_global(duart_1_irq);
-	state_save_register_global(touch_cnt);
-	state_save_register_global_array(touch_data);
+	state_save_register_global(machine, tms_irq);
+	state_save_register_global(machine, duart_1_irq);
+	state_save_register_global(machine, touch_cnt);
+	state_save_register_global_array(machine, touch_data);
 
 	/* TODO! */
-	state_save_register_global(duart_1.ISR);
-	state_save_register_global(duart_1.IMR);
-	state_save_register_global(duart_1.CT);
+	state_save_register_global(machine, duart_1.ISR);
+	state_save_register_global(machine, duart_1.IMR);
+	state_save_register_global(machine, duart_1.CT);
 }
 
 
@@ -207,12 +197,12 @@ static MACHINE_RESET( jpmimpct )
 
 static WRITE16_HANDLER( m68k_tms_w )
 {
-	tms34010_host_w(1, offset, data);
+	tms34010_host_w(space->machine->cpu[1], offset, data);
 }
 
 static READ16_HANDLER( m68k_tms_r )
 {
-	return tms34010_host_r(1, offset);
+	return tms34010_host_r(space->machine->cpu[1], offset);
 }
 
 
@@ -250,7 +240,7 @@ static TIMER_CALLBACK( duart_1_timer_event )
 	duart_1.ISR |= 0x08;
 
 	duart_1_irq = 1;
-	update_irqs();
+	update_irqs(machine);
 }
 
 static READ16_HANDLER( duart_1_r )
@@ -295,19 +285,19 @@ static READ16_HANDLER( duart_1_r )
 		}
 		case 0xd:
 		{
-			val = readinputportbytag("TEST/DEMO");
+			val = input_port_read(space->machine, "TEST/DEMO");
 			break;
 		}
 		case 0xe:
 		{
 			attotime rate = attotime_mul(ATTOTIME_IN_HZ(MC68681_1_CLOCK), 16 * duart_1.CT);
-			timer_adjust(duart_1_timer, rate, 0, rate);
+			timer_adjust_periodic(duart_1_timer, rate, 0, rate);
 			break;
 		}
 		case 0xf:
 		{
 			duart_1_irq = 0;
-			update_irqs();
+			update_irqs(space->machine);
 			duart_1.ISR |= ~0x8;
 			break;
 		}
@@ -409,11 +399,11 @@ static READ16_HANDLER( duart_2_r )
 		{
 			if (touch_cnt == 0)
 			{
-				if ( readinputportbytag("TOUCH") & 0x1 )
+				if ( input_port_read(space->machine, "TOUCH") & 0x1 )
 				{
 					touch_data[0] = 0x2a;
-					touch_data[1] = 0x7 - (readinputportbytag("TOUCH_Y") >> 5) + 0x30;
-					touch_data[2] = (readinputportbytag("TOUCH_X") >> 5) + 0x30;
+					touch_data[1] = 0x7 - (input_port_read(space->machine, "TOUCH_Y") >> 5) + 0x30;
+					touch_data[2] = (input_port_read(space->machine, "TOUCH_X") >> 5) + 0x30;
 
 					/* Return RXRDY */
 					return 0x1;
@@ -477,22 +467,22 @@ static READ16_HANDLER( inputs1_r )
 	{
 		case 0:
 		{
-			val = readinputportbytag("DSW");
+			val = input_port_read(space->machine, "DSW");
 			break;
 		}
 		case 2:
 		{
-			val = readinputportbytag("SW2");
+			val = input_port_read(space->machine, "SW2");
 			break;
 		}
 		case 4:
 		{
-			val = readinputportbytag("SW1");
+			val = input_port_read(space->machine, "SW1");
 			break;
 		}
 		case 9:
 		{
-			val = readinputportbytag("COINS");
+			val = input_port_read(space->machine, "COINS");
 			break;
 		}
 	}
@@ -508,7 +498,7 @@ static READ16_HANDLER( inputs1_r )
  *************************************/
 static WRITE16_HANDLER( volume_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		upd7759_set_bank_base(0, 0x20000 * ((data >> 1) & 3));
 		upd7759_reset_w(0, data & 0x01);
@@ -517,7 +507,7 @@ static WRITE16_HANDLER( volume_w )
 
 static WRITE16_HANDLER( upd7759_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		upd7759_port_w(0, data);
 		upd7759_start_w(0, 0);
@@ -527,7 +517,7 @@ static WRITE16_HANDLER( upd7759_w )
 
 static READ16_HANDLER( upd7759_r )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		return upd7759_busy_r(0);
 	}
@@ -568,7 +558,7 @@ static READ16_HANDLER( jpmio_r )
 
 static WRITE16_HANDLER( jpmio_w )
 {
-	long cycles  = ATTOTIME_TO_CYCLES(0, timer_get_time() );
+	UINT64 cycles = cpu_get_total_cycles(space->cpu);
 	switch (offset)
 	{
 		case 0x02:
@@ -661,8 +651,8 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( tms_program_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xc0000000, 0xc00001ff) AM_READWRITE(tms34010_io_register_r, tms34010_io_register_w)
 	AM_RANGE(0x00000000, 0x003fffff) AM_MIRROR(0xf8000000) AM_RAM AM_BASE(&tms_vram)
-	AM_RANGE(0x00800000, 0x00ffffff) AM_MIRROR(0xf8000000) AM_ROM AM_REGION(REGION_USER1, 0x100000)
-	AM_RANGE(0x02000000, 0x027fffff) AM_MIRROR(0xf8000000) AM_ROM AM_REGION(REGION_USER1, 0)
+	AM_RANGE(0x00800000, 0x00ffffff) AM_MIRROR(0xf8000000) AM_ROM AM_REGION("user1", 0x100000)
+	AM_RANGE(0x02000000, 0x027fffff) AM_MIRROR(0xf8000000) AM_ROM AM_REGION("user1", 0)
 	AM_RANGE(0x01000000, 0x0100003f) AM_MIRROR(0xf87fffc0) AM_READWRITE(bt477_r, bt477_w)
 	AM_RANGE(0x07800000, 0x07bfffff) AM_MIRROR(0xf8400000) AM_RAM
 ADDRESS_MAP_END
@@ -674,51 +664,57 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-#define IMPACT_STANDARD \
-	PORT_START_TAG("DSW") \
-	PORT_DIPNAME( 0x01, 0x01, "DSW 0 (toggle to stop alarm)") \
-	PORT_DIPSETTING(	0x01, DEF_STR( Off ) ) \
-	PORT_DIPSETTING(	0x00, DEF_STR( On ) ) \
-	PORT_DIPNAME( 0x02, 0x02, "DSW 1") \
-	PORT_DIPSETTING(	0x02, DEF_STR( Off ) ) \
-	PORT_DIPSETTING(	0x00, DEF_STR( On ) ) \
-	PORT_DIPNAME( 0x04, 0x04, "DSW 2") \
-	PORT_DIPSETTING(	0x04, DEF_STR( Off ) ) \
-	PORT_DIPSETTING(	0x00, DEF_STR( On ) ) \
-	PORT_DIPNAME( 0x08, 0x08, "DSW 3") \
-	PORT_DIPSETTING(	0x08, DEF_STR( Off ) ) \
-	PORT_DIPSETTING(	0x00, DEF_STR( On ) ) \
-	PORT_DIPNAME( 0x10, 0x10, "DSW 4") \
-	PORT_DIPSETTING(	0x10, DEF_STR( Off ) ) \
-	PORT_DIPSETTING(	0x00, DEF_STR( On ) ) \
-	PORT_DIPNAME( 0x20, 0x20, "DSW 5") \
-	PORT_DIPSETTING(	0x20, DEF_STR( Off ) ) \
-	PORT_DIPSETTING(	0x00, DEF_STR( On ) ) \
-	PORT_DIPNAME( 0x40, 0x40, "DSW 6") \
-	PORT_DIPSETTING(	0x40, DEF_STR( Off ) ) \
-	PORT_DIPSETTING(	0x00, DEF_STR( On ) ) \
-	PORT_DIPNAME( 0x80, 0x80, "DSW 7") \
-	PORT_DIPSETTING(	0x80, DEF_STR( Off ) ) \
-	PORT_DIPSETTING(	0x00, DEF_STR( On ) ) \
-	PORT_START_TAG("SW1") \
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_SERVICE1 ) PORT_TOGGLE PORT_NAME( "Back Door" ) \
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SERVICE2 ) PORT_TOGGLE PORT_NAME( "Cash Door" ) \
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE3 ) PORT_TOGGLE PORT_NAME( "Refill Key" ) \
-	PORT_START_TAG("TEST/DEMO") \
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_SERVICE4 ) PORT_NAME( "Test/Demo" ) \
+static INPUT_PORTS_START( common )
+	PORT_START("DSW")
+	PORT_DIPNAME( 0x01, 0x01, "DSW 0 (toggle to stop alarm)")
+	PORT_DIPSETTING(	0x01, DEF_STR( Off ) )
+	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x02, "DSW 1")
+	PORT_DIPSETTING(	0x02, DEF_STR( Off ) )
+	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04, 0x04, "DSW 2")
+	PORT_DIPSETTING(	0x04, DEF_STR( Off ) )
+	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08, 0x08, "DSW 3")
+	PORT_DIPSETTING(	0x08, DEF_STR( Off ) )
+	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10, 0x10, "DSW 4")
+	PORT_DIPSETTING(	0x10, DEF_STR( Off ) )
+	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x20, 0x20, "DSW 5")
+	PORT_DIPSETTING(	0x20, DEF_STR( Off ) )
+	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x40, 0x40, "DSW 6")
+	PORT_DIPSETTING(	0x40, DEF_STR( Off ) )
+	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x80, 0x80, "DSW 7")
+	PORT_DIPSETTING(	0x80, DEF_STR( Off ) )
+	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
 
-#define IMPACT_TOUCHSCREEN \
-	PORT_START_TAG("TOUCH") \
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_IMPULSE(1) PORT_NAME( "Touch screen" ) \
-	PORT_START_TAG("TOUCH_X") \
-	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_X ) PORT_CROSSHAIR(X, 1.0, 0.0, 0) PORT_SENSITIVITY(45) PORT_KEYDELTA(15) \
-	PORT_START_TAG("TOUCH_Y") \
-	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_Y ) PORT_CROSSHAIR(Y, 1.0, 0.0, 0) PORT_SENSITIVITY(45) PORT_KEYDELTA(15) \
+	PORT_START("SW1")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_SERVICE1 ) PORT_TOGGLE PORT_NAME( "Back Door" )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SERVICE2 ) PORT_TOGGLE PORT_NAME( "Cash Door" )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE3 ) PORT_TOGGLE PORT_NAME( "Refill Key" )
+
+	PORT_START("TEST/DEMO")
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_SERVICE4 ) PORT_NAME( "Test/Demo" )
+INPUT_PORTS_END
+
+static INPUT_PORTS_START( touchscreen )
+	PORT_START("TOUCH")
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_IMPULSE(1) PORT_NAME( "Touch screen" )
+
+	PORT_START("TOUCH_X")
+	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_X ) PORT_CROSSHAIR(X, 1.0, 0.0, 0) PORT_SENSITIVITY(45) PORT_KEYDELTA(15)
+
+	PORT_START("TOUCH_Y")
+	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_Y ) PORT_CROSSHAIR(Y, 1.0, 0.0, 0) PORT_SENSITIVITY(45) PORT_KEYDELTA(15)
+INPUT_PORTS_END
 
 static INPUT_PORTS_START( hngmnjpm )
-	IMPACT_STANDARD
+	PORT_INCLUDE( common )
 
-	PORT_START_TAG("COINS")
+	PORT_START("COINS")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 1 pound" )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 50p" )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 20p" )
@@ -728,17 +724,41 @@ static INPUT_PORTS_START( hngmnjpm )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("SW2")
+	PORT_START("SW2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_NAME( "Collect" )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_NAME( "'3'" )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_NAME( "'2'" )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_NAME( "'1'" )
 INPUT_PORTS_END
 
-static INPUT_PORTS_START( cluedo )
-	IMPACT_STANDARD
+static INPUT_PORTS_START( coronatn )
+	PORT_INCLUDE( common )
 
-	PORT_START_TAG("COINS")
+	PORT_START("COINS")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 1 pound" )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 50p" )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 20p" )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_COIN4 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 10p" )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_COIN5 ) PORT_IMPULSE(1) PORT_NAME( "Token: 20" )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN6 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 5p" )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("SW2")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_NAME( "Ask Ken" )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_NAME( "Collect" )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_NAME( "'1'" )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_NAME( "'2'" )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON5 ) PORT_NAME( "'3'" )
+	PORT_BIT( 0xe0, IP_ACTIVE_LOW, IPT_UNUSED )
+INPUT_PORTS_END
+
+static INPUT_PORTS_START( cluedo )
+	PORT_INCLUDE( common )
+
+	PORT_INCLUDE( touchscreen )
+
+	PORT_START("COINS")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 1 pound" )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 50p" )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 20p" )
@@ -748,16 +768,16 @@ static INPUT_PORTS_START( cluedo )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("SW2")
+	PORT_START("SW2")
 	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	IMPACT_TOUCHSCREEN
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( trivialp )
-	IMPACT_STANDARD
+	PORT_INCLUDE( common )
 
-	PORT_START_TAG("COINS")
+	PORT_INCLUDE( touchscreen )
+
+	PORT_START("COINS")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 1 pound" )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 50p" )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 20p" )
@@ -767,17 +787,17 @@ static INPUT_PORTS_START( trivialp )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("SW2")
+	PORT_START("SW2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_NAME( "Pass" )
 	PORT_BIT( 0xfe, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	IMPACT_TOUCHSCREEN
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( scrabble )
-	IMPACT_STANDARD
+	PORT_INCLUDE( common )
 
-	PORT_START_TAG("COINS")
+	PORT_INCLUDE( touchscreen )
+
+	PORT_START("COINS")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 1 pound" )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 50p" )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 ) PORT_IMPULSE(1) PORT_NAME( "Coin: 20p" )
@@ -787,41 +807,27 @@ static INPUT_PORTS_START( scrabble )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("SW2")
+	PORT_START("SW2")
 	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
-	IMPACT_TOUCHSCREEN
 INPUT_PORTS_END
 
 
-/*************************************
- *
- *  Sound definitions
- *
- *************************************/
-
-static const struct upd7759_interface upd7759_interface =
-{
-	REGION_SOUND1
-};
-
-
 /*************************************
  *
  *  TMS34010 configuration
  *
  *************************************/
 
-static void jpmimpct_tms_irq(int state)
+static void jpmimpct_tms_irq(const device_config *device, int state)
 {
 	tms_irq = state;
-	update_irqs();
+	update_irqs(device->machine);
 }
 
 static const tms34010_config tms_config =
 {
 	TRUE,                       /* halt on reset */
-	0,                          /* the screen operated on */
+	"main",                     /* the screen operated on */
 	40000000/16,                /* pixel clock */
 	4,                          /* pixels per clock */
 	jpmimpct_scanline_update,   /* scanline updater */
@@ -838,25 +844,24 @@ static const tms34010_config tms_config =
  *************************************/
 
 static MACHINE_DRIVER_START( jpmimpct )
-	MDRV_CPU_ADD(M68000, 8000000)
+	MDRV_CPU_ADD("main", M68000, 8000000)
 	MDRV_CPU_PROGRAM_MAP(m68k_program_map, 0)
 
- 	MDRV_CPU_ADD(TMS34010, 40000000)
+ 	MDRV_CPU_ADD("dsp", TMS34010, 40000000)
 	MDRV_CPU_CONFIG(tms_config)
 	MDRV_CPU_PROGRAM_MAP(tms_program_map, 0)
 
-	MDRV_INTERLEAVE(500)
+	MDRV_QUANTUM_TIME(HZ(30000))
 	MDRV_MACHINE_RESET(jpmimpct)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_RAW_PARAMS(40000000/4, 156*4, 0, 100*4, 328, 0, 300)
 	MDRV_PALETTE_LENGTH(256)
 
 	MDRV_SPEAKER_STANDARD_MONO("mono")
-	MDRV_SOUND_ADD(UPD7759, UPD7759_STANDARD_CLOCK)
-	MDRV_SOUND_CONFIG(upd7759_interface)
+	MDRV_SOUND_ADD("upd", UPD7759, UPD7759_STANDARD_CLOCK)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
 	MDRV_VIDEO_START(jpmimpct)
@@ -871,7 +876,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( cluedo )
-	ROM_REGION( 0x1000000, REGION_CPU1, 0 )
+	ROM_REGION( 0x1000000, "main", 0 )
 	ROM_LOAD16_BYTE( "7322.bin", 0x000000, 0x080000, CRC(049ad02d) SHA1(10297dd466d0019e8d6c162028a23dd235494fb4) )
 	ROM_LOAD16_BYTE( "7323.bin", 0x000001, 0x080000, CRC(47ce9c40) SHA1(596a1628142d3c81f2c4ab11ed421f27d082d5f6) )
 	ROM_LOAD16_BYTE( "7324.bin", 0x100000, 0x080000, CRC(5946bd75) SHA1(cc4ffa1e4c3628de6b60027d95df413b6d94e669) )
@@ -885,17 +890,17 @@ ROM_START( cluedo )
 	ROM_LOAD16_BYTE( "6982.bin", 0xe00001, 0x080000, CRC(7478e91b) SHA1(158b473b46aeccf011669cb58dc3a1596370d8f1) )
 	ROM_FILL(                    0xf00000, 0x100000, 0xff )
 
-	ROM_REGION16_LE( 0x200000, REGION_USER1, 0 )
+	ROM_REGION16_LE( 0x200000, "user1", 0 )
 	ROM_LOAD16_BYTE( "clugrb1", 0x000000, 0x80000, CRC(176ae2df) SHA1(135fd2640c255e5321b1a6ba35f72fa2ba8f04b8) )
 	ROM_LOAD16_BYTE( "clugrb2", 0x000001, 0x80000, CRC(06ab2f78) SHA1(4325fd9096e73956310e97e244c7fe1ee8d27f5c) )
-	ROM_COPY( REGION_USER1, 0x000000, 0x100000, 0x100000 )
+	ROM_COPY( "user1", 0x000000, 0x100000, 0x100000 )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x80000, "upd", 0 )
 	ROM_LOAD( "1214.bin", 0x000000, 0x80000, CRC(fe43aeae) SHA1(017a471af5766ef41fa46982c02941fb4fc35174) )
 ROM_END
 
 ROM_START( cluedo2c )
-	ROM_REGION( 0x1000000, REGION_CPU1, 0 )
+	ROM_REGION( 0x1000000, "main", 0 )
 	ROM_LOAD16_BYTE( "clu2c1.bin", 0x000000, 0x080000, CRC(bf94a3c0) SHA1(e5a0d17136691642aba339f574aec7c27ed90848) )
 	ROM_LOAD16_BYTE( "clu2c2.bin", 0x000001, 0x080000, CRC(960cda80) SHA1(6b5946ed1241bc673f42991f57e0c74753085b63) )
 	ROM_LOAD16_BYTE( "clu2c3.bin", 0x100000, 0x080000, CRC(9d61b28d) SHA1(41c0e17b3933686a2e6f343cd39f90e5663c7787) )
@@ -909,17 +914,17 @@ ROM_START( cluedo2c )
 	ROM_LOAD16_BYTE( "6982.bin", 0xe00001, 0x080000, CRC(7478e91b) SHA1(158b473b46aeccf011669cb58dc3a1596370d8f1) )
 	ROM_FILL(                    0xf00000, 0x100000, 0xff )
 
-	ROM_REGION16_LE( 0x200000, REGION_USER1, 0 )
+	ROM_REGION16_LE( 0x200000, "user1", 0 )
 	ROM_LOAD16_BYTE( "clugrb1", 0x000000, 0x80000, CRC(176ae2df) SHA1(135fd2640c255e5321b1a6ba35f72fa2ba8f04b8) )
 	ROM_LOAD16_BYTE( "clugrb2", 0x000001, 0x80000, CRC(06ab2f78) SHA1(4325fd9096e73956310e97e244c7fe1ee8d27f5c) )
-	ROM_COPY( REGION_USER1, 0x000000, 0x100000, 0x100000 )
+	ROM_COPY( "user1", 0x000000, 0x100000, 0x100000 )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x80000, "upd", 0 )
 	ROM_LOAD( "1214.bin", 0x000000, 0x80000, CRC(fe43aeae) SHA1(017a471af5766ef41fa46982c02941fb4fc35174) )
 ROM_END
 
 ROM_START( cluedo2 )
-	ROM_REGION( 0x1000000, REGION_CPU1, 0 )
+	ROM_REGION( 0x1000000, "main", 0 )
 	ROM_LOAD16_BYTE( "clu21.bin", 0x000000, 0x080000, CRC(b1aa0103)SHA1(52d10a428710cd04313a2638fc3c23fb9d0ab6db))
 	ROM_LOAD16_BYTE( "clu22.bin", 0x000001, 0x080000, CRC(90d8dd28)SHA1(3124a8313c6b362176283e145c4af27f5deac683))
 	ROM_LOAD16_BYTE( "clu23.bin", 0x100000, 0x080000, CRC(196bd993)SHA1(50920441707fc6cae9d36961d92ce213e53c4238))
@@ -933,17 +938,17 @@ ROM_START( cluedo2 )
 	ROM_LOAD16_BYTE( "6982.bin", 0xe00001, 0x080000, CRC(7478e91b) SHA1(158b473b46aeccf011669cb58dc3a1596370d8f1) )
 	ROM_FILL(                    0xf00000, 0x100000, 0xff )
 
-	ROM_REGION16_LE( 0x200000, REGION_USER1, 0 )
+	ROM_REGION16_LE( 0x200000, "user1", 0 )
 	ROM_LOAD16_BYTE( "clugrb1", 0x000000, 0x80000, CRC(176ae2df) SHA1(135fd2640c255e5321b1a6ba35f72fa2ba8f04b8) )
 	ROM_LOAD16_BYTE( "clugrb2", 0x000001, 0x80000, CRC(06ab2f78) SHA1(4325fd9096e73956310e97e244c7fe1ee8d27f5c) )
-	ROM_COPY( REGION_USER1, 0x000000, 0x100000, 0x100000 )
+	ROM_COPY( "user1", 0x000000, 0x100000, 0x100000 )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x80000, "upd", 0 )
 	ROM_LOAD( "clue2as1.bin", 0x000000, 0x80000, CRC(16b2bc45) SHA1(56963f5d63b5a091b89b96f4ca9327010006c024) )
 ROM_END
 
 ROM_START( trivialp )
-	ROM_REGION( 0x1000000, REGION_CPU1, 0 )
+	ROM_REGION( 0x1000000, "main", 0 )
 	ROM_LOAD16_BYTE( "1422.bin", 0x000000, 0x080000, CRC(5e39c946) SHA1(bae7f572a32e90d716813271f03e7868be603086) )
 	ROM_LOAD16_BYTE( "1423.bin", 0x000001, 0x080000, CRC(bb48c225) SHA1(b479f0bdb69ad11af17b5457c02a9d9618ede455) )
 	ROM_LOAD16_BYTE( "1424.bin", 0x100000, 0x080000, CRC(c37d045b) SHA1(3c127b14e1dc1e453fb08c741847c712d1fea78b) )
@@ -958,48 +963,16 @@ ROM_START( trivialp )
 	ROM_LOAD16_BYTE( "tp-q7.bin", 0xf00000, 0x080000, CRC(e075e5d7) SHA1(3490730c569678d48fb2d810484de063882f71a5) )
 	ROM_LOAD16_BYTE( "tp-q8.bin", 0xf00001, 0x080000, CRC(12f90e74) SHA1(a39a1cee6107d1e83954e3cabf191fd5c89777f8) )
 
-	ROM_REGION16_LE( 0x200000, REGION_USER1, 0 )
+	ROM_REGION16_LE( 0x200000, "user1", 0 )
 	ROM_LOAD16_BYTE( "tp-gr1.bin", 0x000000, 0x100000, CRC(7fa955f7) SHA1(9ecae4c8c26bfa1701c39148099bf0f8b5974ac8) )
 	ROM_LOAD16_BYTE( "tp-gr2.bin", 0x000001, 0x100000, CRC(2495d785) SHA1(eb89eb299a7000364a0a0f59459d1ec27755fca1) )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x80000, "upd", 0 )
 	ROM_LOAD( "tp-snd.bin", 0x000000, 0x80000, CRC(7e2cb00a) SHA1(670ee5dd5c60313676b9271901b4df9e6ebd5955) )
 ROM_END
 
-ROM_START( hngmnjpm )
-	ROM_REGION( 0x1000000, REGION_CPU1, 0 )
-	ROM_LOAD16_BYTE( "20264.bin", 0x000000, 0x080000, CRC(50074528) SHA1(8128b2270518af873df4b94d50c5c9849dda3e42) )
-	ROM_LOAD16_BYTE( "20265.bin", 0x000001, 0x080000, CRC(a0a6985c) SHA1(ed960e6e88df111aebf208d7105dc241aa916684) )
-	ROM_FILL(                     0x100000, 0x100000, 0xff )
-
-	ROM_LOAD16_BYTE( "hang-q1.bin", 0xc00000, 0x080000, CRC(0be99a57) SHA1(49fe7faeccd3f9608927ff333fd5783e3cd7d266) )
-	ROM_LOAD16_BYTE( "hang-q2.bin", 0xc00001, 0x080000, CRC(71328f71) SHA1(59481b27dbcad109070cc4fd5c9c93f948991f03) )
-	ROM_LOAD16_BYTE( "hang-q3.bin", 0xd00000, 0x080000, CRC(3fabeb81) SHA1(67b4561ec4ac8c00728c86e2bce66f432c5f1e86) )
-	ROM_LOAD16_BYTE( "hang-q4.bin", 0xd00001, 0x080000, CRC(64fbf56b) SHA1(c5077f9995b890925ef608742ba77ef995de5a3b) )
-	ROM_LOAD16_BYTE( "hang-q5.bin", 0xe00000, 0x080000, CRC(283e0c7f) SHA1(64ed626e181d851d3ffd4a1c0e613cd769e0ae31) )
-	ROM_LOAD16_BYTE( "hang-q6.bin", 0xe00001, 0x080000, CRC(9a6d3667) SHA1(b4706d77dcd43e6f75e3e5e8bd1fbeebe84b8f60) )
-	ROM_FILL(                       0xf00000, 0x100000, 0xff )
-
-	ROM_REGION16_LE( 0x200000, REGION_USER1, 0 )
-	ROM_LOAD16_BYTE( "hang-gr1.bin", 0x000000, 0x100000, CRC(5919344c) SHA1(b5c1f98ebfc65743fa2f6c264179ed7115532a6b) )
-	ROM_LOAD16_BYTE( "hang-gr2.bin", 0x000001, 0x100000, CRC(3194c6d4) SHA1(11d5e7bfe60912b0eab2a1d06d1a74853ec23567) )
-
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )
-	ROM_LOAD( "hang-so1.bin", 0x000000, 0x80000, CRC(5efe1712) SHA1(e4e7a73a1b1897ed6e96306f99d234fb3b47c59b) )
-
-	/* Likely to be the same for the other games */
-	ROM_REGION( 0x0a00, REGION_PLDS, ROMREGION_DISPOSE )
-	ROM_LOAD( "s60-3.bin", 0x0000, 0x0117, CRC(19e1d28b) SHA1(12dff4bea16b95807f1a9455b6785468ca5de858) )
-	ROM_LOAD( "s61-6.bin", 0x0000, 0x0117, CRC(c72cec0e) SHA1(9d6e5510600987f9359af9ecc3e95f5bd8444bcd) )
-	ROM_LOAD( "ig1.1.bin", 0x0000, 0x02DD, CRC(4e11fa4e) SHA1(ded2d2086c4360708462024054e5409962ea8589) )
-	ROM_LOAD( "ig2.1.bin", 0x0000, 0x0157, CRC(2365878b) SHA1(d91d9906aadcfd8cff7ee6b92449c522f73a29e1) )
-	ROM_LOAD( "ig3.2.bin", 0x0000, 0x0117, CRC(4970dad7) SHA1(c5931db3d66c7d1027a762be10f9e3d9e321b70f) )
-	ROM_LOAD( "jpms6.bin", 0x0000, 0x0117, CRC(1fba3b6f) SHA1(0e33e49cbf24e836deb1ef16385ff20549ef188e) )
-	ROM_LOAD( "mem-2.bin", 0x0000, 0x0157, CRC(92832445) SHA1(b6edcc6d4f721f0e91e9fcf322163db017afaee1) )
-ROM_END
-
 ROM_START( scrabble )
-	ROM_REGION( 0x1000000, REGION_CPU1, 0 )
+	ROM_REGION( 0x1000000, "main", 0 )
 	ROM_LOAD16_BYTE( "1562.bin", 0x000000, 0x080000, CRC(d7303b98) SHA1(46e8ed04c8fdc092b7d8910d3e3f6cc62f691646) )
 	ROM_LOAD16_BYTE( "1563.bin", 0x000001, 0x080000, CRC(77f61ba1) SHA1(276dc8b2c23880740309c456d4e4b2eae249cdde) )
 	ROM_FILL(                    0x100000, 0x100000, 0xff )
@@ -1012,14 +985,66 @@ ROM_START( scrabble )
 	ROM_LOAD16_BYTE( "scra-q6.bin", 0xe00001, 0x080000, CRC(8b792c9c) SHA1(9a5cc6c4d7e807cbabd174ab7454cdaa93dc3cec) )
 	ROM_FILL(                       0xf00000, 0x100000, 0xff )
 
-	ROM_REGION16_LE( 0x200000, REGION_USER1, 0 )
+	ROM_REGION16_LE( 0x200000, "user1", 0 )
 	ROM_LOAD16_BYTE( "scra-g1.bin", 0x000000, 0x100000, CRC(04a17df9) SHA1(c215c90d8add3ff608c24aac242369874f6bf9d7) )
 	ROM_LOAD16_BYTE( "scra-g2.bin", 0x000001, 0x100000, CRC(724375e6) SHA1(709211a2d7b86f4e83c94a37010fe61ef9a734de) )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x80000, "upd", 0 )
 	ROM_LOAD( "scra-snd.bin", 0x000000, 0x80000, CRC(287759ef) SHA1(bd37500689b7b2fb4fbc65056e92486c0c00ff61) )
 ROM_END
 
+ROM_START( hngmnjpm )
+	ROM_REGION( 0x1000000, "main", 0 )
+	ROM_LOAD16_BYTE( "20264.bin", 0x000000, 0x080000, CRC(50074528) SHA1(8128b2270518af873df4b94d50c5c9849dda3e42) )
+	ROM_LOAD16_BYTE( "20265.bin", 0x000001, 0x080000, CRC(a0a6985c) SHA1(ed960e6e88df111aebf208d7105dc241aa916684) )
+	ROM_FILL(                     0x100000, 0x100000, 0xff )
+
+	ROM_LOAD16_BYTE( "hang-q1.bin", 0xc00000, 0x080000, CRC(0be99a57) SHA1(49fe7faeccd3f9608927ff333fd5783e3cd7d266) )
+	ROM_LOAD16_BYTE( "hang-q2.bin", 0xc00001, 0x080000, CRC(71328f71) SHA1(59481b27dbcad109070cc4fd5c9c93f948991f03) )
+	ROM_LOAD16_BYTE( "hang-q3.bin", 0xd00000, 0x080000, CRC(3fabeb81) SHA1(67b4561ec4ac8c00728c86e2bce66f432c5f1e86) )
+	ROM_LOAD16_BYTE( "hang-q4.bin", 0xd00001, 0x080000, CRC(64fbf56b) SHA1(c5077f9995b890925ef608742ba77ef995de5a3b) )
+	ROM_LOAD16_BYTE( "hang-q5.bin", 0xe00000, 0x080000, CRC(283e0c7f) SHA1(64ed626e181d851d3ffd4a1c0e613cd769e0ae31) )
+	ROM_LOAD16_BYTE( "hang-q6.bin", 0xe00001, 0x080000, CRC(9a6d3667) SHA1(b4706d77dcd43e6f75e3e5e8bd1fbeebe84b8f60) )
+	ROM_FILL(                       0xf00000, 0x100000, 0xff )
+
+	ROM_REGION16_LE( 0x200000, "user1", 0 )
+	ROM_LOAD16_BYTE( "hang-gr1.bin", 0x000000, 0x100000, CRC(5919344c) SHA1(b5c1f98ebfc65743fa2f6c264179ed7115532a6b) )
+	ROM_LOAD16_BYTE( "hang-gr2.bin", 0x000001, 0x100000, CRC(3194c6d4) SHA1(11d5e7bfe60912b0eab2a1d06d1a74853ec23567) )
+
+	ROM_REGION( 0x80000, "upd", 0 )
+	ROM_LOAD( "hang-so1.bin", 0x000000, 0x80000, CRC(5efe1712) SHA1(e4e7a73a1b1897ed6e96306f99d234fb3b47c59b) )
+
+	/* Likely to be the same for the other games */
+	ROM_REGION( 0x0a00, "plds", ROMREGION_DISPOSE )
+	ROM_LOAD( "s60-3.bin", 0x0000, 0x0117, CRC(19e1d28b) SHA1(12dff4bea16b95807f1a9455b6785468ca5de858) )
+	ROM_LOAD( "s61-6.bin", 0x0000, 0x0117, CRC(c72cec0e) SHA1(9d6e5510600987f9359af9ecc3e95f5bd8444bcd) )
+	ROM_LOAD( "ig1.1.bin", 0x0000, 0x02DD, CRC(4e11fa4e) SHA1(ded2d2086c4360708462024054e5409962ea8589) )
+	ROM_LOAD( "ig2.1.bin", 0x0000, 0x0157, CRC(2365878b) SHA1(d91d9906aadcfd8cff7ee6b92449c522f73a29e1) )
+	ROM_LOAD( "ig3.2.bin", 0x0000, 0x0117, CRC(4970dad7) SHA1(c5931db3d66c7d1027a762be10f9e3d9e321b70f) )
+	ROM_LOAD( "jpms6.bin", 0x0000, 0x0117, CRC(1fba3b6f) SHA1(0e33e49cbf24e836deb1ef16385ff20549ef188e) )
+	ROM_LOAD( "mem-2.bin", 0x0000, 0x0157, CRC(92832445) SHA1(b6edcc6d4f721f0e91e9fcf322163db017afaee1) )
+ROM_END
+
+ROM_START( coronatn )
+	ROM_REGION( 0x1000000, "main", 0 )
+	ROM_LOAD16_BYTE( "20824.bin", 0x000000, 0x080000, CRC(f5cc07cb) SHA1(45b83829ba9bd5f22c2978bbde9c0e25c476e719) )
+	ROM_LOAD16_BYTE( "20825.bin", 0x000001, 0x080000, CRC(2e749edf) SHA1(12b24836a71085aef8ca1bc61e6671f8d6e1908c) )
+	ROM_FILL(                     0x100000, 0x100000, 0xff )
+
+	ROM_LOAD16_BYTE( "cs-q1.bin", 0xc00000, 0x080000, CRC(beef496a) SHA1(6089ee8b0821d5b8cb8f724748888a0915083622) )
+	ROM_LOAD16_BYTE( "cs-q2.bin", 0xc00001, 0x080000, CRC(16f88f36) SHA1(78c829d837cc09fdd1119ba73168d272843f7f50) )
+	ROM_LOAD16_BYTE( "cs-q3.bin", 0xd00000, 0x080000, CRC(1d412b03) SHA1(2400fa776effeb2ab21234a6ecf183ed0cffa92e) )
+	ROM_LOAD16_BYTE( "cs-q4.bin", 0xd00001, 0x080000, CRC(55c23ab9) SHA1(0eaa8c88315ef4544f1d1ef2fec2c6edc3589db3) )
+	ROM_LOAD16_BYTE( "cs-q5.bin", 0xe00000, 0x080000, CRC(289f4db0) SHA1(8eca9df9e278bf77be4b2aad4c80ea6a1880fe96) )
+	ROM_LOAD16_BYTE( "cs-q6.bin", 0xe00001, 0x080000, CRC(791d9d39) SHA1(44f3dcbfe8523118d52785844e103a480e8e13b5) )
+
+	ROM_REGION16_LE( 0x200000, "user1", 0 )
+	ROM_LOAD16_BYTE( "cs-ag1.bin", 0x000000, 0x100000, CRC(7ce449cc) SHA1(408e1405c80e623ee120cea65760ca9a8554cc29) )
+	ROM_LOAD16_BYTE( "cs-ag2.bin", 0x000001, 0x100000, CRC(7026df0c) SHA1(a000d72c06ad37879673324880fb0e715f55788e) )
+
+	ROM_REGION( 0x80000, "upd", 0 )
+	ROM_LOAD( "cs-sound.bin", 0x000000, 0x80000, CRC(96ea4e9f) SHA1(a5443d893f38f3e279f2eb9f4500547e7b8efa37) )
+ROM_END
 
 /*************************************
  *
@@ -1027,9 +1052,10 @@ ROM_END
  *
  *************************************/
 
-GAME( 1995, cluedo,   0,      jpmimpct, cluedo,   0, ROT0, "JPM", "Cluedo (prod. 2D)",          GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
-GAME( 1995, cluedo2c, cluedo, jpmimpct, cluedo,   0, ROT0, "JPM", "Cluedo (prod. 2C)",          GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
-GAME( 1995, cluedo2,  cluedo, jpmimpct, cluedo,   0, ROT0, "JPM", "Cluedo (prod. 2)",         	GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
-GAME( 1996, trivialp, 0,      jpmimpct, trivialp, 0, ROT0, "JPM", "Trivial Pursuit (prod. 1D)", GAME_SUPPORTS_SAVE )
-GAME( 1997, scrabble, 0,      jpmimpct, scrabble, 0, ROT0, "JPM", "Scrabble (rev. F)",          GAME_SUPPORTS_SAVE )
-GAME( 1998, hngmnjpm, 0,      jpmimpct, hngmnjpm, 0, ROT0, "JPM", "Hangman (JPM)",              GAME_SUPPORTS_SAVE )
+GAME( 1995, cluedo,   0,      jpmimpct, cluedo,   0, ROT0, "JPM", "Cluedo (prod. 2D)",           GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
+GAME( 1995, cluedo2c, cluedo, jpmimpct, cluedo,   0, ROT0, "JPM", "Cluedo (prod. 2C)",           GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
+GAME( 1995, cluedo2,  cluedo, jpmimpct, cluedo,   0, ROT0, "JPM", "Cluedo (prod. 2)",         	 GAME_IMPERFECT_GRAPHICS | GAME_SUPPORTS_SAVE )
+GAME( 1996, trivialp, 0,      jpmimpct, trivialp, 0, ROT0, "JPM", "Trivial Pursuit (prod. 1D)",  GAME_SUPPORTS_SAVE )
+GAME( 1997, scrabble, 0,      jpmimpct, scrabble, 0, ROT0, "JPM", "Scrabble (rev. F)",           GAME_SUPPORTS_SAVE )
+GAME( 1998, hngmnjpm, 0,      jpmimpct, hngmnjpm, 0, ROT0, "JPM", "Hangman (JPM)",               GAME_SUPPORTS_SAVE )
+GAME( 1999, coronatn, 0,      jpmimpct, coronatn, 0, ROT0, "JPM", "Coronation Street Quiz Game", GAME_SUPPORTS_SAVE )
