@@ -1,6 +1,17 @@
 /***************************************************************************
 
-    Sun Electronics Kangaroo hardware
+    Sun Electronics hardware:
+
+       TVG-1-CPU-B
+         2 x Z80
+         AY-3-9810
+         8-way DipSwitch
+         Service Switch
+         Program ROMS (both Main & Sound)
+         MB8841 (at least for Kangaroo)
+       TVG-1-VIDEO-B
+         10MHz OSC
+         Graphic ROMS
 
     driver by Ville Laitinen
 
@@ -69,6 +80,65 @@
     (CPU#0) standard IM 1 interrupt mode (rst #38 every vblank)
     (CPU#1) same here
 
+
+                       Kangaroo Memory Map
+    HEX        R/W   D7 D6 D5 D4 D3 D2 D2 D0  function
+
+------------  Game Microprocessor Memory Space (Z80 - IC15) --------------
+
+    0000-5FFF   R    D  D  D  D  D  D  D  D   Z80 24K Program ROM
+
+    E000-E3FF  R/W   D  D  D  D  D  D  D  D   1K Working RAM
+
+    E400        R    D  D  D  D  D  D  D  D   Option Switch (DSW0 8 way dipswitch)
+
+    E800        W    D  D  D  D  D  D  D  D   Low  Byte\ Start Address of Data in Pictures ROM for DMA
+    E801        W    D  D  D  D  D  D  D  D   High Byte/
+    E802        W    D  D  D  D  D  D  D  D   Low  Byte\ Start Address in Bit Map RAM (where picture is to be written) During DMA
+    E803        W    D  D  D  D  D  D  D  D   High Byte/
+    E804        W    D  D  D  D  D  D  D  D   Low  Byte\ Picture Size for DMA and DMA Start
+    E805        W    D  D  D  D  D  D  D  D   High Byte/
+    E806        W    D  D  D  D  D  D  D  D   Vertical Start Address in Bit Map
+    E807        W    D  D  D  D  D  D  D  D   Horizontal Start Address in Bit Map
+    E808        W                      D  D   Bank Select Latch
+    E809        W          D  D  D  D  D  D   A & B Bit Map Control Latch (A=playfield, B=motion)
+    E80A        W          D  D  D  D  D  D   Color Shading Latch
+
+    EC00        W    D  D  D  D  D  D  D  D   Sound DATA to Sound Microprocessor
+    EC00        R                         D   Utility Coin Switch
+    EC00        R                      D      1 Player Start
+    EC00        R                   D         2 Player Start
+    EC00        R                D            Left Coin Input
+    EC00        R             D               Right Coin Input
+
+    ED00        W                         D   Coin Counter 1
+    ED00        W                      D      Coin Counter 2 (European games)
+    ED00        R                         D   Player 1 Right
+    ED00        R                      D      Player 1 Left
+    ED00        R                   D         Player 1 Up
+    ED00        R                D            Player 1 Down
+    ED00        R             D               Player 1 Punch
+
+    EE00        R                         D   Player 2 Right
+    EE00        R                      D      Player 2 Left
+    EE00        R                   D         Player 2 Up
+    EE00        R                D            Player 2 Down
+    EE00        R             D               Player 2 Punch
+
+    EFxx-EFxx   W                D  D  D  D   Output to Custom MB8841 Microcomputer
+    EFxx-EFxx   R                D  D  D  D   Input from Custom MB8841 Microcomputer
+
+------------  Sound Microprocessor Memory Space (Z80 - IC34) --------------
+
+    0000-0FFF   R    D  D  D  D  D  D  D  D   Z80 4K Program ROM
+
+    4000-43FF  R/W   D  D  D  D  D  D  D  D   1K Working RAM
+
+    6000        R    D  D  D  D  D  D  D  D   Read DATA from Game Microprocessor
+
+    7000        W    D  D  D  D  D  D  D  D   Write to Sound Chip (GI-AY-3-9810 - IC50)
+    8000        W    D  D  D  D  D  D  D  D   Read from Sound Chip
+
 ****************************************************************************
 
     In test mode, to test sound press 1 and 2 player start simultaneously.
@@ -78,12 +148,13 @@
     resetting
 
     TODO:
-    - There is a custom microcontroller on the original Kangaroo board which is
-      not emulated. This MIGHT cause some problems, but we don't know of any.
+    - There is a custom MB8841 microcontroller on the original Kangaroo board which
+      is not emulated. This MIGHT cause some problems, but we don't know of any.
 
 ***************************************************************************/
 
 #include "driver.h"
+#include "cpu/mb88xx/mb88xx.h"
 #include "kangaroo.h"
 #include "cpu/z80/z80.h"
 #include "sound/ay8910.h"
@@ -108,15 +179,15 @@ static UINT8 kangaroo_clock;
 
 static MACHINE_START( kangaroo )
 {
-	memory_configure_bank(1, 0, 2, memory_region(REGION_GFX1), 0x2000);
-	state_save_register_global(kangaroo_clock);
+	memory_configure_bank(machine, 1, 0, 2, memory_region(machine, "gfx1"), 0x2000);
+	state_save_register_global(machine, kangaroo_clock);
 }
 
 
 static MACHINE_START( kangaroo_mcu )
 {
 	MACHINE_START_CALL(kangaroo);
-	memory_install_readwrite8_handler(0, ADDRESS_SPACE_PROGRAM, 0xef00, 0xefff, 0, 0, mcu_sim_r, mcu_sim_w);
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xef00, 0xefff, 0, 0, mcu_sim_r, mcu_sim_w);
 	kangaroo_clock = 0;
 }
 
@@ -134,7 +205,7 @@ static MACHINE_RESET( kangaroo )
 	/* the copy protection. */
 	/* Anyway, what I do here is just immediately generate the NMI, so the game */
 	/* properly starts. */
-	cpunum_set_input_line(machine, 0, INPUT_LINE_NMI, PULSE_LINE);
+	cpu_set_input_line(machine->cpu[0], INPUT_LINE_NMI, PULSE_LINE);
 }
 
 
@@ -145,7 +216,7 @@ static MACHINE_RESET( kangaroo )
  *
  *************************************/
 
-/* I have no idea what the security chip is nor whether it really does,
+/* The security chip is a MB8841 with 2K internal rom. Currently it's unknown what it really does,
    this just seems to do the trick -V-
 */
 
@@ -204,8 +275,8 @@ static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x0fff) AM_ROM
 	AM_RANGE(0x4000, 0x43ff) AM_MIRROR(0x0c00) AM_RAM
 	AM_RANGE(0x6000, 0x6000) AM_MIRROR(0x0fff) AM_READ(soundlatch_r)
-	AM_RANGE(0x7000, 0x7000) AM_MIRROR(0x0fff) AM_WRITE(AY8910_write_port_0_w)
-	AM_RANGE(0x8000, 0x8000) AM_MIRROR(0x0fff) AM_WRITE(AY8910_control_port_0_w)
+	AM_RANGE(0x7000, 0x7000) AM_MIRROR(0x0fff) AM_WRITE(ay8910_write_port_0_w)
+	AM_RANGE(0x8000, 0x8000) AM_MIRROR(0x0fff) AM_WRITE(ay8910_control_port_0_w)
 ADDRESS_MAP_END
 
 
@@ -214,8 +285,8 @@ static ADDRESS_MAP_START( sound_portmap, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x0000, 0x0fff) AM_ROM
 	AM_RANGE(0x4000, 0x43ff) AM_MIRROR(0x0c00) AM_RAM
 	AM_RANGE(0x6000, 0x6000) AM_MIRROR(0x0fff) AM_READ(soundlatch_r)
-	AM_RANGE(0x7000, 0x7000) AM_MIRROR(0x0fff) AM_WRITE(AY8910_write_port_0_w)
-	AM_RANGE(0x8000, 0x8000) AM_MIRROR(0x0fff) AM_WRITE(AY8910_control_port_0_w)
+	AM_RANGE(0x7000, 0x7000) AM_MIRROR(0x0fff) AM_WRITE(ay8910_write_port_0_w)
+	AM_RANGE(0x8000, 0x8000) AM_MIRROR(0x0fff) AM_WRITE(ay8910_control_port_0_w)
 ADDRESS_MAP_END
 
 
@@ -239,14 +310,14 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( fnkyfish )
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SERVICE1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_START1 )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_START2 )
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_COIN1 )
 	PORT_BIT( 0xf0, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 
-	PORT_START_TAG("IN1")
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_8WAY
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_8WAY
@@ -254,7 +325,7 @@ static INPUT_PORTS_START( fnkyfish )
 	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON1 )
 	PORT_BIT( 0xe0, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 
-	PORT_START_TAG("IN2")
+	PORT_START("IN2")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL
@@ -262,7 +333,7 @@ static INPUT_PORTS_START( fnkyfish )
 	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_COCKTAIL
 	PORT_BIT( 0xe0, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 
-	PORT_START_TAG("DSW0")
+	PORT_START("DSW0")
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x00, "3" )
 	PORT_DIPSETTING(    0x01, "5" )
@@ -291,7 +362,7 @@ INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( kangaroo )
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SERVICE1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_START1 )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_START2 )
@@ -307,7 +378,7 @@ static INPUT_PORTS_START( kangaroo )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 
-	PORT_START_TAG("IN1")
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_8WAY
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_8WAY
@@ -317,7 +388,7 @@ static INPUT_PORTS_START( kangaroo )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_SERVICE( 0x80, IP_ACTIVE_HIGH )
 
-	PORT_START_TAG("IN2")
+	PORT_START("IN2")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL
@@ -327,7 +398,7 @@ static INPUT_PORTS_START( kangaroo )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 
-	PORT_START_TAG("DSW0")
+	PORT_START("DSW0")
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x00, "3" )
 	PORT_DIPSETTING(    0x01, "5" )
@@ -370,23 +441,23 @@ INPUT_PORTS_END
 static MACHINE_DRIVER_START( nomcu )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80, MASTER_CLOCK/4)
+	MDRV_CPU_ADD("main", Z80, MASTER_CLOCK/4)
 	MDRV_CPU_PROGRAM_MAP(main_map,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
-	MDRV_CPU_ADD(Z80, MASTER_CLOCK/8)
+	MDRV_CPU_ADD("audio", Z80, MASTER_CLOCK/8)
 	MDRV_CPU_PROGRAM_MAP(sound_map,0)
 	MDRV_CPU_IO_MAP(sound_portmap,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
 	MDRV_MACHINE_START(kangaroo)
 	MDRV_MACHINE_RESET(kangaroo)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_UPDATE_SCANLINE)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_SCANLINE)
 
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_RAW_PARAMS(MASTER_CLOCK, 320*2, 0*2, 256*2, 260, 8, 248)
 
 	MDRV_VIDEO_START(kangaroo)
@@ -394,7 +465,7 @@ static MACHINE_DRIVER_START( nomcu )
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
-	MDRV_SOUND_ADD(AY8910, MASTER_CLOCK/8)
+	MDRV_SOUND_ADD("ay", AY8910, MASTER_CLOCK/8)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
@@ -404,7 +475,7 @@ static MACHINE_DRIVER_START( mcu )
 
 	MDRV_MACHINE_START(kangaroo_mcu)
 
-	MDRV_CPU_ADD(MB8841, MASTER_CLOCK/4/12)
+	MDRV_CPU_ADD("mcu", MB8841, MASTER_CLOCK/4/12)
 	MDRV_CPU_FLAGS(CPU_DISABLE)
 	MDRV_CPU_PROGRAM_MAP(mcu_map,0)
 MACHINE_DRIVER_END
@@ -418,16 +489,16 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( fnkyfish )
-	ROM_REGION( 0x14000, REGION_CPU1, 0 )
+	ROM_REGION( 0x14000, "main", 0 )
 	ROM_LOAD( "tvg_64.0",    0x0000,  0x1000, CRC(af728803) SHA1(1cbbf863f0eb4c759d6037ef9d9d0f4586b7b570) )
 	ROM_LOAD( "tvg_65.1",    0x1000,  0x1000, CRC(71959e6b) SHA1(7336cbf3eefd081cd657a56fb6a8fbdac1b51c2c) )
 	ROM_LOAD( "tvg_66.2",    0x2000,  0x1000, CRC(5ccf68d4) SHA1(c885df8b2b1bcb578ceab6615caf633dac02a5b2) )
 	ROM_LOAD( "tvg_67.3",    0x3000,  0x1000, CRC(938ff36f) SHA1(bf660217ff82d5850ab97238ed2e32199d04f8c9) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "tvg_68.8",    0x0000,  0x1000, CRC(d36bb2be) SHA1(330160161857407fda62f16e7f43b8833744fd34) )
 
-	ROM_REGION( 0x4000, REGION_GFX1, 0 )
+	ROM_REGION( 0x4000, "gfx1", 0 )
 	ROM_LOAD( "tvg_69.v0",   0x0000, 0x1000, CRC(cd532d0b) SHA1(7a64f8bab1a0feafd53a4b81ac3b624a7c1bd26a) ) /* graphics ROMs */
 	ROM_LOAD( "tvg_71.v2",   0x1000, 0x1000, CRC(a59c9713) SHA1(60dafa3d5a70b7e727b7c4688f8f3125735c31ec) )
 	ROM_LOAD( "tvg_70.v1",   0x2000, 0x1000, CRC(fd308ef1) SHA1(d07f964cab875b0e47f3469fa5211684a5725dfe) )
@@ -436,33 +507,33 @@ ROM_END
 
 
 ROM_START( kangaroo )
-	ROM_REGION( 0x14000, REGION_CPU1, 0 )
-	ROM_LOAD( "tvg_75.0",    0x0000, 0x1000, CRC(0d18c581) SHA1(0e0f89d644b79e887c53e5294783843ca7e875ba) )
-	ROM_LOAD( "tvg_76.1",    0x1000, 0x1000, CRC(5978d37a) SHA1(684c1092de4a0927a03752903c86c3bbe99e868a) )
-	ROM_LOAD( "tvg_77.2",    0x2000, 0x1000, CRC(522d1097) SHA1(09fe627a46d32df2e098d9fad7757f9d61bef41f) )
-	ROM_LOAD( "tvg_78.3",    0x3000, 0x1000, CRC(063da970) SHA1(582ff21dd46c651f07a4846e0f8a7544a5891988) )
-	ROM_LOAD( "tvg_79.4",    0x4000, 0x1000, CRC(9e5cf8ca) SHA1(015387f038c5670f88c9b22453d074bd9b2a129d) )
-	ROM_LOAD( "tvg_80.5",    0x5000, 0x1000, CRC(2fc18049) SHA1(31fcac8eb660739a1672346136a1581a5ef20325) )
+	ROM_REGION( 0x14000, "main", 0 ) /* On TVG-1-CPU-B board */
+	ROM_LOAD( "tvg_75.0",    0x0000, 0x1000, CRC(0d18c581) SHA1(0e0f89d644b79e887c53e5294783843ca7e875ba) ) /* IC7 */
+	ROM_LOAD( "tvg_76.1",    0x1000, 0x1000, CRC(5978d37a) SHA1(684c1092de4a0927a03752903c86c3bbe99e868a) ) /* IC8 */
+	ROM_LOAD( "tvg_77.2",    0x2000, 0x1000, CRC(522d1097) SHA1(09fe627a46d32df2e098d9fad7757f9d61bef41f) ) /* IC9 */
+	ROM_LOAD( "tvg_78.3",    0x3000, 0x1000, CRC(063da970) SHA1(582ff21dd46c651f07a4846e0f8a7544a5891988) ) /* IC10 */
+	ROM_LOAD( "tvg_79.4",    0x4000, 0x1000, CRC(9e5cf8ca) SHA1(015387f038c5670f88c9b22453d074bd9b2a129d) ) /* IC16 */
+	ROM_LOAD( "tvg_80.5",    0x5000, 0x1000, CRC(2fc18049) SHA1(31fcac8eb660739a1672346136a1581a5ef20325) ) /* IC17 */
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
-	ROM_LOAD( "tvg_81.8",    0x0000, 0x1000, CRC(fb449bfd) SHA1(f593a0339f47e121736a927587132aeb52704557) )
+	ROM_REGION( 0x10000, "audio", 0 ) /* On TVG-1-CPU-B board */
+	ROM_LOAD( "tvg_81.8",    0x0000, 0x1000, CRC(fb449bfd) SHA1(f593a0339f47e121736a927587132aeb52704557) ) /* IC24 */
 
-	ROM_REGION( 0x0800, REGION_CPU3, 0 )	/* code for the 8841 custom MCU */
-	ROM_LOAD( "8841.rom",    0x0000, 0x0800, NO_DUMP )
+	ROM_REGION( 0x0800, "mcu", 0 )	/* internal ROM from the 8841 custom MCU */
+	ROM_LOAD( "mb8841.ic29",    0x0000, 0x0800, NO_DUMP )
 
-	ROM_REGION( 0x0800, REGION_USER1, 0 )	/* data for the 8841 custom MCU */
-	ROM_LOAD( "tvg_82.12",   0x0000, 0x0800, CRC(57766f69) SHA1(94a7a557d8325799523d5e1a88653a9a3fbe34f9) )
+	ROM_REGION( 0x0800, "user1", 0 )	/* data for the 8841 custom MCU */
+	ROM_LOAD( "tvg_82.12",   0x0000, 0x0800, CRC(57766f69) SHA1(94a7a557d8325799523d5e1a88653a9a3fbe34f9) ) /* IC28 */
 
-	ROM_REGION( 0x4000, REGION_GFX1, 0 )
-	ROM_LOAD( "tvg_83.v0",   0x0000, 0x1000, CRC(c0446ca6) SHA1(fca6ba565051337c0198c93b7b8477632e0dd0b6) )
-	ROM_LOAD( "tvg_85.v2",   0x1000, 0x1000, CRC(72c52695) SHA1(87f4715fbb7d509bd9cc4e71e2afb0d475bbac13) )
-	ROM_LOAD( "tvg_84.v1",   0x2000, 0x1000, CRC(e4cb26c2) SHA1(5016db9d48fdcfb757618659d063b90862eb0e90) )
-	ROM_LOAD( "tvg_86.v3",   0x3000, 0x1000, CRC(9e6a599f) SHA1(76b4eddb4efcd8189d8cc5962d8497e82885f212) )
+	ROM_REGION( 0x4000, "gfx1", 0 ) /* On TVG-1-VIDEO-B board */
+	ROM_LOAD( "tvg_83.v0",   0x0000, 0x1000, CRC(c0446ca6) SHA1(fca6ba565051337c0198c93b7b8477632e0dd0b6) ) /* IC76 */
+	ROM_LOAD( "tvg_85.v2",   0x1000, 0x1000, CRC(72c52695) SHA1(87f4715fbb7d509bd9cc4e71e2afb0d475bbac13) ) /* IC77 */
+	ROM_LOAD( "tvg_84.v1",   0x2000, 0x1000, CRC(e4cb26c2) SHA1(5016db9d48fdcfb757618659d063b90862eb0e90) ) /* IC52 */
+	ROM_LOAD( "tvg_86.v3",   0x3000, 0x1000, CRC(9e6a599f) SHA1(76b4eddb4efcd8189d8cc5962d8497e82885f212) ) /* IC53 */
 ROM_END
 
 
 ROM_START( kangaroa )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "136008-101.ic7",    0x0000, 0x1000, CRC(0d18c581) SHA1(0e0f89d644b79e887c53e5294783843ca7e875ba) )
 	ROM_LOAD( "136008-102.ic8",    0x1000, 0x1000, CRC(5978d37a) SHA1(684c1092de4a0927a03752903c86c3bbe99e868a) )
 	ROM_LOAD( "136008-103.ic9",    0x2000, 0x1000, CRC(522d1097) SHA1(09fe627a46d32df2e098d9fad7757f9d61bef41f) )
@@ -470,16 +541,16 @@ ROM_START( kangaroa )
 	ROM_LOAD( "136008-105.ic16",   0x4000, 0x1000, CRC(82a26c7d) SHA1(09087552dbe4d27df79396072c0f9b916f78f89b) )
 	ROM_LOAD( "136008-106.ic17",   0x5000, 0x1000, CRC(3dead542) SHA1(0b5d329b1ebbacc650d06289b4e080304e728ea7) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "136008-107.ic24",   0x0000, 0x1000, CRC(fb449bfd) SHA1(f593a0339f47e121736a927587132aeb52704557) )
 
-	ROM_REGION( 0x0800, REGION_CPU3, 0 )	/* code for the 8841 custom MCU */
-	ROM_LOAD( "8841.rom",          0x0000, 0x0800, NO_DUMP )
+	ROM_REGION( 0x0800, "mcu", 0 )	/* internal ROM from the 8841 custom MCU */
+	ROM_LOAD( "mb8841.ic29",          0x0000, 0x0800, NO_DUMP )
 
-	ROM_REGION( 0x0800, REGION_USER1, 0 )	/* data for the 8841 custom MCU */
+	ROM_REGION( 0x0800, "user1", 0 )	/* data for the 8841 custom MCU */
 	ROM_LOAD( "136008-112.ic28",   0x0000, 0x0800, CRC(57766f69) SHA1(94a7a557d8325799523d5e1a88653a9a3fbe34f9) )
 
-	ROM_REGION( 0x4000, REGION_GFX1, 0 )
+	ROM_REGION( 0x4000, "gfx1", 0 )
 	ROM_LOAD( "136008-108.ic76",   0x0000, 0x1000, CRC(c0446ca6) SHA1(fca6ba565051337c0198c93b7b8477632e0dd0b6) )
 	ROM_LOAD( "136008-110.ic77",   0x1000, 0x1000, CRC(72c52695) SHA1(87f4715fbb7d509bd9cc4e71e2afb0d475bbac13) )
 	ROM_LOAD( "136008-109.ic52",   0x2000, 0x1000, CRC(e4cb26c2) SHA1(5016db9d48fdcfb757618659d063b90862eb0e90) )
@@ -488,7 +559,7 @@ ROM_END
 
 
 ROM_START( kangarob )
-	ROM_REGION( 0x14000, REGION_CPU1, 0 )
+	ROM_REGION( 0x14000, "main", 0 )
 	ROM_LOAD( "tvg_75.0",    0x0000, 0x1000, CRC(0d18c581) SHA1(0e0f89d644b79e887c53e5294783843ca7e875ba) )
 	ROM_LOAD( "tvg_76.1",    0x1000, 0x1000, CRC(5978d37a) SHA1(684c1092de4a0927a03752903c86c3bbe99e868a) )
 	ROM_LOAD( "tvg_77.2",    0x2000, 0x1000, CRC(522d1097) SHA1(09fe627a46d32df2e098d9fad7757f9d61bef41f) )
@@ -496,10 +567,10 @@ ROM_START( kangarob )
 	ROM_LOAD( "tvg_79.4",    0x4000, 0x1000, CRC(9e5cf8ca) SHA1(015387f038c5670f88c9b22453d074bd9b2a129d) )
 	ROM_LOAD( "k6",          0x5000, 0x1000, CRC(7644504a) SHA1(7a8a4bd163d2cdf27390ab2ef65fb7fa6fc1a361) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "tvg_81.8",    0x0000, 0x1000, CRC(fb449bfd) SHA1(f593a0339f47e121736a927587132aeb52704557) )
 
-	ROM_REGION( 0x4000, REGION_GFX1, 0 )
+	ROM_REGION( 0x4000, "gfx1", 0 )
 	ROM_LOAD( "tvg_83.v0",   0x0000, 0x1000, CRC(c0446ca6) SHA1(fca6ba565051337c0198c93b7b8477632e0dd0b6) )
 	ROM_LOAD( "tvg_85.v2",   0x1000, 0x1000, CRC(72c52695) SHA1(87f4715fbb7d509bd9cc4e71e2afb0d475bbac13) )
 	ROM_LOAD( "tvg_84.v1",   0x2000, 0x1000, CRC(e4cb26c2) SHA1(5016db9d48fdcfb757618659d063b90862eb0e90) )
