@@ -1,27 +1,27 @@
-/*  Konami M2 Hardware
-
-    Preliminary driver by Ville Linde
-
-    Games on this hardware:
-    =======================
-
-    Game                 | Konami ID
-    ---------------------------------
-    Evil Night           | GN810
-    Heat of Eleven '98   | GX703
-    Tobe! Polystars      | GX623
-    Battle Tryst         | G?636
-
-*/
-
 /*
-Tobe! PolyStars
-Konami, 1997
+Konami M2 Hardware
+Preliminary driver by Ville Linde
 
-This game runs on 3DO-based Konami M2 hardware.
 
-PCB Layout
-----------
+Konami M2 Hardware Overview
+Konami, 1997-1998
+
+This hardware is 3DO-based with two IBM Power PC CPUs.
+
+There were only 5 known games on this hardware. They include....
+
+Game                                                 Year    CD Codes     Konami Part#
+--------------------------------------------------------------------------------------
+Battle Tryst                                         1998    636JAC02
+Evil Night                                           1998    810UBA02
+Hell Night ((alt. Region title, same as Evil Night)  1998    810EAA02
+Heat Of Eleven '98                                   1998    703EAA02
+Polystars                                            1997    623JAA02     003894
+Total Vice                                           1997    639AAB01
+
+
+PCB Layouts
+-----------
 
 Top Board
 
@@ -67,7 +67,7 @@ PWB403045B (C) 1997 KONAMI CO., LTD.
 |       NJM5532D                    9.83MHz                |
 |                                   19.66MHz               |
 |J                |--------|   93C46.7K                    |-|
-|A                | 058232 |                623B01.8Q      | |
+|A                | 058232 |                BOOTROM.8Q     | |
 |M                |--------|   |------|                    | |
 |M       |------|              |003461|                    | |
 |A       |056879|              |      |                    | |CN15
@@ -79,24 +79,114 @@ PWB403045B (C) 1997 KONAMI CO., LTD.
 |                                                          |
 |----------------------------------------------------------|
 Notes:
-      056879   - Konami custom IC, location 10E (QFP120)
-      058232   - Konami custom ceramic flat pack IC, DAC?
-      003461   - Konami custom IC, location 11K (QFP100)
-      CN16     - 4 pin connector for CD-DA in from CDROM
-      CN15     - Standard (PC-compatible) 40 pin IDE CDROM flat cable connector and 4 pin power plug connector,
-                 connected to Panasonic CR-583 8-speed CDROM drive.
-                 CDROM disc contains 1 data track & 24 audio tracks. Total Capacity: 581 MBytes
-                 Konami part number: 003894
-                 Software revision: 623JAA02
-      LA4705   - LA4705 Power Amplifier
-      623B01.8Q- 16MBit MASKROM. Location 8Q (DIP42)
-      93C46.7K - 128bytes x8bit Serial EEPROM. Location 7K (DIP8)
-      DSW      - 8 position dip switch
+      056879     - Konami custom IC, location 10E (QFP120)
+      058232     - Konami custom ceramic flat pack IC, DAC?
+      003461     - Konami custom IC, location 11K (QFP100)
+      CN16       - 4 pin connector for CD-DA in from CDROM
+      CN15       - Standard (PC-compatible) 40 pin IDE CDROM flat cable connector and 4 pin power plug connector,
+                   connected to Panasonic CR-583 8-speed CDROM drive.
+      LA4705     - LA4705 Power Amplifier
+      DSW        - 8 position dip switch
+      BOOTROM.8Q - 16MBit MASKROM. Location 8Q (DIP42)
+                   Battle Tryst       - 636A01.8Q
+                   Evil Night         -       .8Q
+                   Heat Of Eleven '98 -       .8Q
+                   Polystars          - 623B01.8Q
+                   Total Vice         -       .8Q
+      93C46.7K   - 128bytes x8bit Serial EEPROM. Location 7K (DIP8)
+                   NOTE! There is very mild protection to stop game-swapping. It is based on the information in the EEPROM
+                   being the same as the Time Keeper NVRAM.
+                   For example, in Evil Night, the first line of the NVRAM in hex is 474E38313000000019984541410002A601FEFE01
+                   Looking at it in ascii:  GN810.....EAA.......
+                   Hex 474E383130 = GN810
+                   1998 = the year of the game
+                   Hex 454141 = EAA (the version = europe english)
+                   The numbers after this appear to be unimportant (at least with regards to swapping games anyway).
+                   All the other data after the first line is used for high scores tables etc.
+                   The important part is that the data in the EEPROM should be the same as the NVRAM, but the EEPROM data
+                   is byte-swapped! If the two don't match, the check on 7K or the NVRAM will fail and the PCB will reboot
+                   forever.
 
+Some lower boards have two connectors underneath for a protection sub-board or sound board. These are detailed below....
+
+GX636-PWB(A) (C) 1997 KONAMI CO., LTD.
+|-------------------------|
+| CN4 CN3  |---------|    |
+|          |---------|CN2 |
+|          PAL            |
+|                         |
+|             NVRAM       |
+|                         |
+|          |---------|    |
+|          |---------|CN1 |
+|-------------------------|
+Notes:
+      NVRAM  - With Heat of Eleven '98, uses Dallas DS1643 NonVolatile TimeKeeping RAM
+               With Battle Tryst, uses ST M48T58Y-70PC1 NonVolatile TimeKeeping RAM
+               With Poly Stars, a sub board is not used at all
+      PAL    - PALCE16V8Q, stamped 'X636A1'
+      CN3    - 4-pin sound cable tied to CN16 (CD-DA Input) on main lower board
+      CN4    - 4-pin sound cable tied to CDROM analog audio output connector
+
+GQ639 PWB 403327(A)
+|-----------------------------------------|
+|       639JAA02.xx                       |
+|                                         |
+|                                         |
+|                   |---------|           |
+|                   |---------|           |
+|                                         |
+|                                         |
+|               PAL                       |
+|                                         |
+|                                         |
+|                                         |
+|                                         |
+|                   |---------|           |
+|      YMZ280B      |---------|           |
+|                                         |
+|      16.9344MHz                         |
+|                                         |
+|                                         |
+|-----------------------------------------|
+Notes:
+      This PCB is used on Total Vice only.
+      639JAA02.xx - 8MBit Sound data ROM (DIP42)
+      PAL         - PAL16V8H stampd '       '
+
+
+PWB0000047043 (C) 1998 KONAMI CO., LTD.
+|-----------------------------------------|
+| CN4     CN3                             |
+|                                         |
+|                                         |
+|                   |---------|           |
+|                   |---------|           |
+|        16.9344MHz              M48T58Y  |
+|                      PAL                |
+|          YMZ280B                        |
+|                                         |
+|                                         |
+|                                         |
+|                                         |
+|                   |---------|           |
+|                   |---------|           |
+|                                         |
+|                                         |
+|                                         |
+|              810A03.16H                 |
+|-----------------------------------------|
+Notes:
+      This PCB is used on Evil Night/Hell Night only.
+      810A03.16H - 16MBit Sound data ROM (DIP42, byte mode)
+      PAL        - PAL16V8H stamped 'N810B1'
+      M48T58Y    - ST M48T58Y-70PC1 NonVolatile TimeKeeping RAM
+      CN3        - 4-pin sound cable tied to CN16 (CD-DA Input) on main lower board
+      CN4        - 4-pin sound cable tied to CDROM analog audio output connector
 */
 
+
 #include "driver.h"
-#include "deprecat.h"
 #include "cdrom.h"
 #include "cpu/powerpc/ppc.h"
 
@@ -131,13 +221,13 @@ static VIDEO_UPDATE( m2 )
 			UINT16 *d = BITMAP_ADDR16(bitmap, j, 0);
 			for (i=0; i < 512; i++)
 			{
-				d[i^3] = *fb++;
+				d[i^3] = *fb++ & 0x7fff;
 			}
 		}
 	}
 	else
 	{
-		fillbitmap(bitmap, 0, cliprect);
+		bitmap_fill(bitmap, cliprect, 0);
 	}
 	return 0;
 }
@@ -146,7 +236,7 @@ static READ64_HANDLER(irq_enable_r)
 {
 	UINT64 r = 0;
 
-	if (!(mem_mask & U64(0xffffffff00000000)))
+	if (ACCESSING_BITS_32_63)
 	{
 		r |= (UINT64)(irq_enable) << 32;
 	}
@@ -156,7 +246,7 @@ static READ64_HANDLER(irq_enable_r)
 
 static WRITE64_HANDLER(irq_enable_w)
 {
-	if (!(mem_mask & U64(0xffffffff00000000)))
+	if (ACCESSING_BITS_32_63)
 	{
 		irq_enable |= (UINT32)(data >> 32);
 	}
@@ -166,7 +256,7 @@ static READ64_HANDLER(irq_active_r)
 {
 	UINT64 r = 0;
 
-	if (!(mem_mask & U64(0xffffffff00000000)))
+	if (ACCESSING_BITS_32_63)
 	{
 		r |= (UINT64)(irq_active) << 32;
 	}
@@ -185,7 +275,7 @@ static READ64_HANDLER(unk1_r)
 #ifdef UNUSED_FUNCTION
 static READ64_HANDLER(unk2_r)
 {
-	if (!(mem_mask & U64(0xffffffff00000000)))
+	if (ACCESSING_BITS_32_63)
 	{
 		return (UINT64)0xa5 << 32;
 	}
@@ -193,7 +283,7 @@ static READ64_HANDLER(unk2_r)
 }
 #endif
 
-static UINT64 unk3 = -1;
+static UINT64 unk3;
 static READ64_HANDLER(unk3_r)
 {
 	//return U64(0xffffffffffffffff);
@@ -204,14 +294,14 @@ static UINT32 unk20004 = 0;
 static READ64_HANDLER(unk4_r)
 {
 	UINT64 r = 0;
-//  logerror("unk4_r: %08X, %08X%08X at %08X\n", offset, (UINT32)(mem_mask>>32), (UINT32)(mem_mask), activecpu_get_pc());
+//  logerror("unk4_r: %08X, %08X%08X at %08X\n", offset, (UINT32)(mem_mask>>32), (UINT32)(mem_mask), cpu_get_pc(space->cpu));
 
-	if (!(mem_mask & U64(0xffffffff00000000)))
+	if (ACCESSING_BITS_32_63)
 	{
 		// MCfg
 		r |= (UINT64)((0 << 13) | (5 << 10)) << 32;
 	}
-	if (!(mem_mask & U64(0x00000000ffffffff)))
+	if (ACCESSING_BITS_0_31)
 	{
 		r |= unk20004 & ~0x800000;
 	}
@@ -221,14 +311,14 @@ static READ64_HANDLER(unk4_r)
 static WRITE64_HANDLER(unk4_w)
 {
 //  logerror("unk4_w: %08X%08X, %08X, %08X%08X at %08X\n", (UINT32)(data >> 32), (UINT32)(data),
-//      offset, (UINT32)(mem_mask>>32), (UINT32)(mem_mask), activecpu_get_pc());
+//      offset, (UINT32)(mem_mask>>32), (UINT32)(mem_mask), cpu_get_pc(space->cpu));
 
-	if (!(mem_mask & U64(0x00000000ffffffff)))
+	if (ACCESSING_BITS_0_31)
 	{
 		if (data & 0x800000)
 		{
-			mame_printf_debug("CPU%d: CPU1 IRQ at %08X\n", cpu_getactivecpu(), activecpu_get_pc());
-			cpunum_set_input_line(Machine, 1, INPUT_LINE_IRQ0, ASSERT_LINE);
+			mame_printf_debug("CPU '%s': CPU1 IRQ at %08X\n", space->cpu->tag, cpu_get_pc(space->cpu));
+			cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_IRQ0, ASSERT_LINE);
 		}
 
 		unk20004 = (UINT32)(data);
@@ -245,7 +335,7 @@ static READ64_HANDLER(unk30000_r)
 
 static READ64_HANDLER(unk30030_r)
 {
-	if (!(mem_mask & U64(0x00000000ffffffff)))
+	if (ACCESSING_BITS_0_31)
 	{
 		return 1;
 	}
@@ -254,11 +344,11 @@ static READ64_HANDLER(unk30030_r)
 
 static WRITE64_HANDLER(video_w)
 {
-	if (!(mem_mask & U64(0xffffffff00000000)))
+	if (ACCESSING_BITS_32_63)
 	{
 		vdl0_address = (UINT32)(data >> 32);
 	}
-	if (!(mem_mask & U64(0x00000000ffffffff)))
+	if (ACCESSING_BITS_0_31)
 	{
 		vdl1_address = (UINT32)(data);
 	}
@@ -266,7 +356,7 @@ static WRITE64_HANDLER(video_w)
 
 static WRITE64_HANDLER(video_irq_ack_w)
 {
-	if (!(mem_mask & U64(0xffffffff00000000)))
+	if (ACCESSING_BITS_32_63)
 	{
 		if ((data >> 32) & 0x8000)
 		{
@@ -319,11 +409,11 @@ static WRITE64_HANDLER(unk4000418_w)
 
 static WRITE64_HANDLER(reset_w)
 {
-	if (!(mem_mask & U64(0xffffffff00000000)))
+	if (ACCESSING_BITS_32_63)
 	{
 		if (data & U64(0x100000000))
 		{
-			cpunum_set_input_line(Machine, 0, INPUT_LINE_RESET, PULSE_LINE);
+			cpu_set_input_line(space->machine->cpu[0], INPUT_LINE_RESET, PULSE_LINE);
 			unk3 = 0;
 		}
 	}
@@ -367,7 +457,7 @@ static CDE_DMA cde_dma[2];
 
 static void cde_init(void)
 {
-	cdrom_file *cd = cdrom_open(get_disk_handle(0));
+	cdrom_file *cd = cdrom_open(get_disk_handle("cdrom"));
 	const cdrom_toc *toc = cdrom_get_toc(cd);
 
 	if (cd)
@@ -696,7 +786,7 @@ static void cde_handle_reports(void)
 	}
 }
 
-static void cde_dma_transfer(int channel, int next)
+static void cde_dma_transfer(const address_space *space, int channel, int next)
 {
 	UINT32 address;
 	int length;
@@ -715,7 +805,7 @@ static void cde_dma_transfer(int channel, int next)
 
 	for (i=0; i < cde_dma[channel].next_length; i++)
 	{
-		program_write_byte_64be(address, 0xff);		// TODO: do the real transfer...
+		memory_write_byte(space, address, 0xff);		// TODO: do the real transfer...
 		address++;
 	}
 }
@@ -725,7 +815,7 @@ static READ64_HANDLER(cde_r)
 	UINT32 r = 0;
 	int reg = offset * 2;
 
-	if (!(mem_mask & U64(0x00000000ffffffff)))
+	if (ACCESSING_BITS_0_31)
 		reg++;
 
 	switch (reg)
@@ -780,7 +870,7 @@ static READ64_HANDLER(cde_r)
 
 		default:
 		{
-	//      mame_printf_debug("cde_r: %08X at %08X\n", reg*4, activecpu_get_pc());
+	//      mame_printf_debug("cde_r: %08X at %08X\n", reg*4, cpu_get_pc(space->cpu));
 			break;
 		}
 	}
@@ -800,7 +890,7 @@ static WRITE64_HANDLER(cde_w)
 	int reg = offset * 2;
 	UINT32 d;
 
-	if (!(mem_mask & U64(0x00000000ffffffff)))
+	if (ACCESSING_BITS_0_31)
 	{
 		reg++;
 		d = (UINT32)(data);
@@ -814,7 +904,7 @@ static WRITE64_HANDLER(cde_w)
 	{
 		case 0x028/4:		// Command write
 		{
-			//printf("cde_w: %08X, %08X at %08X\n", d, reg*4, activecpu_get_pc());
+			//printf("cde_w: %08X, %08X at %08X\n", d, reg*4, cpu_get_pc(space->cpu));
 
 			if (d == 0x0180)
 			{
@@ -853,13 +943,13 @@ static WRITE64_HANDLER(cde_w)
 			{
 				cde_dma[0].dma_done = 1;
 
-				cde_dma_transfer(0, 0);
+				cde_dma_transfer(space, 0, 0);
 			}
 			if (d & 0x40)
 			{
 				cde_dma[0].dma_done = 1;
 
-				cde_dma_transfer(0, 1);
+				cde_dma_transfer(space, 0, 1);
 			}
 			break;
 		}
@@ -942,7 +1032,7 @@ static WRITE64_HANDLER(cde_w)
 
 		default:
 		{
-	//      mame_printf_debug("cde_w: %08X, %08X at %08X\n", d, reg*4, activecpu_get_pc());
+	//      mame_printf_debug("cde_w: %08X, %08X at %08X\n", d, reg*4, cpu_get_pc(space->cpu));
 			break;
 		}
 	}
@@ -953,7 +1043,7 @@ static READ64_HANDLER(device2_r)
 	UINT32 r = 0;
 	int reg = offset * 2;
 
-	if (!(mem_mask & U64(0x00000000ffffffff)))
+	if (ACCESSING_BITS_0_31)
 		reg++;
 
 	switch (reg)
@@ -983,9 +1073,9 @@ static READ64_HANDLER(cpu_r)
 {
 	UINT64 r = 0;
 
-	if (!(mem_mask & U64(0xffffffff00000000)))
+	if (ACCESSING_BITS_32_63)
 	{
-		r = (UINT64)(cpu_getactivecpu() ? 0x80000000 : 0);
+		r = (UINT64)((space->cpu != space->machine->cpu[0]) ? 0x80000000 : 0);
 		//r |= 0x40000000;  // sets Video-LowRes !?
 		return r << 32;
 	}
@@ -1013,18 +1103,16 @@ static ADDRESS_MAP_START( m2_main, ADDRESS_SPACE_PROGRAM, 64 )
 	AM_RANGE(0x10000008, 0x10001007) AM_NOP		// ???
 	AM_RANGE(0x20000000, 0x201fffff) AM_ROM AM_SHARE(2)
 	AM_RANGE(0x40000000, 0x407fffff) AM_RAM AM_SHARE(3) AM_BASE(&main_ram)
-	AM_RANGE(0xfff00000, 0xffffffff) AM_ROM AM_REGION(REGION_USER1, 0) AM_SHARE(2)
+	AM_RANGE(0xfff00000, 0xffffffff) AM_ROM AM_REGION("user1", 0) AM_SHARE(2)
 ADDRESS_MAP_END
 
 static INPUT_PORTS_START( m2 )
 INPUT_PORTS_END
 
 
-static const ppc_config ppc602_config =
+static const powerpc_config ppc602_config =
 {
-	PPC_MODEL_602,
-	0x20,				/* Multiplier 2, Bus = 33MHz, Core = 66MHz */
-	BUS_FREQUENCY_33MHZ
+	33000000			/* Multiplier 2, Bus = 33MHz, Core = 66MHz */
 };
 
 static INTERRUPT_GEN(m2)
@@ -1039,30 +1127,31 @@ static INTERRUPT_GEN(m2)
         irq_active |= 0x8;
     }*/
 
-	cpunum_set_input_line(machine, 0, INPUT_LINE_IRQ0, ASSERT_LINE);
+	cpu_set_input_line(device, INPUT_LINE_IRQ0, ASSERT_LINE);
 }
 
 static MACHINE_DRIVER_START( m2 )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(PPC602, 33000000)	/* actually PPC602, 66MHz */
+	MDRV_CPU_ADD("main", PPC602, 33000000)	/* actually PPC602, 66MHz */
 	MDRV_CPU_CONFIG(ppc602_config)
 	MDRV_CPU_PROGRAM_MAP(m2_main, 0)
-	MDRV_CPU_VBLANK_INT(m2, 1)
+	MDRV_CPU_VBLANK_INT("main", m2)
 
-	MDRV_CPU_ADD(PPC602, 33000000)	/* actually PPC602, 66MHz */
+	MDRV_CPU_ADD("sub", PPC602, 33000000)	/* actually PPC602, 66MHz */
 	MDRV_CPU_CONFIG(ppc602_config)
 	MDRV_CPU_PROGRAM_MAP(m2_main, 0)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-
  	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB15)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(640, 480)
 	MDRV_SCREEN_VISIBLE_AREA(0, 511, 0, 383)
-	MDRV_PALETTE_LENGTH(65536)
+
+	MDRV_PALETTE_LENGTH(32768)
+	MDRV_PALETTE_INIT(RRRRR_GGGGG_BBBBB)
 
 	MDRV_VIDEO_START(m2)
 	MDRV_VIDEO_UPDATE(m2)
@@ -1070,64 +1159,76 @@ static MACHINE_DRIVER_START( m2 )
 MACHINE_DRIVER_END
 
 
-#define ROM_REGION64_BE(length,type,flags)	      ROM_REGION(length, type, (flags) | ROMREGION_64BIT | ROMREGION_BE)
-
 ROM_START(polystar)
-	ROM_REGION64_BE(0x200000, REGION_USER1, 0)	/* boot rom */
+	ROM_REGION64_BE(0x200000, "user1", 0)	/* boot rom */
 	ROM_LOAD16_WORD("623b01.8q", 0x000000, 0x200000, CRC(bd879f93) SHA1(e2d63bfbd2b15260a2664082652442eadea3eab6))
 
-	ROM_REGION( 0x80, REGION_USER2, 0 ) /* serial eeprom */
+	ROM_REGION( 0x80, "user2", 0 ) /* serial eeprom */
 	ROM_LOAD( "93c46.7k",  0x000000, 0x000080, CRC(66d02984) SHA1(d07c57d198c611b6ff67a783c20a3d038ba34cd1) )
 
-	DISK_REGION( REGION_DISKS )
+	DISK_REGION( "cdrom" )
 	DISK_IMAGE( "623jaa02", 0, MD5(6071c1b70c190fa7c50676eb5308e024) SHA1(a7dc6086d0244b5472f61b41992623c7a9dc2e9c))
 ROM_END
 
 ROM_START(btltryst)
-	ROM_REGION64_BE(0x200000, REGION_USER1, 0)	/* boot rom */
+	ROM_REGION64_BE(0x200000, "user1", 0)	/* boot rom */
 	ROM_LOAD16_WORD("636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b))
 
-	DISK_REGION( REGION_DISKS )
+	DISK_REGION( "cdrom" )
 	DISK_IMAGE( "btltryst", 0, MD5(4286d25a896d1450705f742cccd26ef2) SHA1(becc606b8480f6a09365b611565d83cfdc82b0b3))
 ROM_END
 
 ROM_START(heatof11)
-	ROM_REGION64_BE(0x200000, REGION_USER1, 0)	/* boot rom */
+	ROM_REGION64_BE(0x200000, "user1", 0)	/* boot rom */
 	ROM_LOAD16_WORD("636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b))
 
-	ROM_REGION( 0x2000, REGION_USER2, 0 ) /* timekeeper eeprom */
+	ROM_REGION( 0x2000, "user2", 0 ) /* timekeeper eeprom */
 	ROM_LOAD( "dallas.5e",  0x000000, 0x002000, CRC(8611ff09) SHA1(6410236947d99c552c4a1f7dd5fd8c7a5ae4cba1) )
 
-	DISK_REGION( REGION_DISKS )
+	DISK_REGION( "cdrom" )
 	DISK_IMAGE( "heatof11", 0, MD5(1eef9f191439f13d1a867629226b0230) SHA1(87599d03aecadf5d119d05173bdef2940bcce515))
 ROM_END
 
 ROM_START(evilngt)
-	ROM_REGION64_BE(0x200000, REGION_USER1, 0)	/* boot rom */
+	ROM_REGION64_BE(0x200000, "user1", 0)	/* boot rom */
 	ROM_LOAD16_WORD("636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b))
 
-	ROM_REGION( 0x1000, REGION_USER2, 0 ) /* timekeeper eeprom */
+	ROM_REGION( 0x1000, "user2", 0 ) /* timekeeper eeprom */
 	ROM_LOAD( "m48t58y.u1",  0x000000, 0x001000, CRC(169bb8f4) SHA1(55c0bafab5d309fe69156489186e232aa87ca0dd) )
 ROM_END
 
-ROM_START(totlvice)
-	ROM_REGION64_BE(0x200000, REGION_USER1, 0)	/* boot rom */
+ROM_START(hellngt)
+	ROM_REGION64_BE(0x200000, "user1", 0)	/* boot rom */
 	ROM_LOAD16_WORD("636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b))
 
-	ROM_REGION( 0x100000, REGION_USER2, 0 ) /* sound rom on sub board */
+	ROM_REGION( 0x1000, "user2", 0 ) /* timekeeper eeprom */
+	ROM_LOAD( "m48t58y.u1",  0x000000, 0x001000, CRC(169bb8f4) SHA1(55c0bafab5d309fe69156489186e232aa87ca0dd) )
+
+	DISK_REGION( "cdrom" )
+	DISK_IMAGE( "810eaa02", 0, MD5(250a1b9cc2a25aed6c27321dd8f4f8a2) SHA1(d2f48a389f8091e03ada81c255231c7957d1aee3))
+ROM_END
+
+ROM_START(totlvice)
+	ROM_REGION64_BE(0x200000, "user1", 0)	/* boot rom */
+	ROM_LOAD16_WORD("636a01.8q", 0x000000, 0x200000, CRC(7b1dc738) SHA1(32ae8e7ddd38fcc70b4410275a2cc5e9a0d7d33b))
+
+	ROM_REGION( 0x100000, "user2", 0 ) /* sound rom on sub board */
 	ROM_LOAD( "639jaa02.bin",  0x000000, 0x100000, CRC(c6163818) SHA1(b6f8f2d808b98610becc0a5be5443ece3908df0b) )
 
-	DISK_REGION( REGION_DISKS )
+	DISK_REGION( "cdrom" )
 	DISK_IMAGE( "639jad01", 0, MD5(bc3156be374e7a99040763bf0cea7ad3) SHA1(c4503d9954c72dd8f70521f313f0338528116c26))
 ROM_END
 
 static DRIVER_INIT( m2 )
 {
+	unk3 = U64(0xffffffffffffffff);
+	unk20004 = 0;
 	cde_init();
 }
 
-GAME( 1997, polystar, 0, m2, m2, m2, ROT0, "Konami", "Tobe! Polystars (ver JAA)", GAME_NOT_WORKING | GAME_NO_SOUND )
-GAME( 1997, totlvice, 0, m2, m2, m2, ROT0, "Konami", "Total Vice (ver JAD)", GAME_NOT_WORKING | GAME_NO_SOUND )
-GAME( 1998, btltryst, 0, m2, m2, m2, ROT0, "Konami", "Battle Tryst (ver JAC)", GAME_NOT_WORKING | GAME_NO_SOUND )
-GAME( 1998, heatof11, 0, m2, m2, m2, ROT0, "Konami", "Heat of Eleven '98 (ver EAA)", GAME_NOT_WORKING | GAME_NO_SOUND )
-GAME( 1998, evilngt,  0, m2, m2, m2, ROT0, "Konami", "Evil Night (ver EAA)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1997, polystar, 0,       m2, m2, m2, ROT0, "Konami", "Tobe! Polystars (ver JAA)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1997, totlvice, 0,       m2, m2, m2, ROT0, "Konami", "Total Vice (ver JAD)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1998, btltryst, 0,       m2, m2, m2, ROT0, "Konami", "Battle Tryst (ver JAC)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1998, heatof11, 0,       m2, m2, m2, ROT0, "Konami", "Heat of Eleven '98 (ver EAA)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1998, evilngt,  0,       m2, m2, m2, ROT0, "Konami", "Evil Night (ver EAA)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1998, hellngt,  evilngt, m2, m2, m2, ROT0, "Konami", "Hell Night (ver EAA)", GAME_NOT_WORKING | GAME_NO_SOUND )
