@@ -17,7 +17,7 @@ TODO:
 */
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/m6800/m6800.h"
 #include "cpu/s2650/s2650.h"
 #include "machine/6821pia.h"
 #include "video/s2636.h"
@@ -25,14 +25,16 @@ TODO:
 #include "sound/sn76477.h"
 #include "sound/tms3615.h"
 
-extern WRITE8_HANDLER( laserbat_csound1_w );
-extern WRITE8_HANDLER( laserbat_csound2_w );
+WRITE8_HANDLER( laserbat_csound1_w );
+WRITE8_HANDLER( laserbat_csound2_w );
 
 static tilemap *bg_tilemap;
 static int laserbat_video_page = 0;
 static int laserbat_input_mux = 0;
-
-static mame_bitmap *collision_bitmap;
+static s2636_t *s2636_0, *s2636_1, *s2636_2;
+static UINT8 *s2636_0_ram;
+static UINT8 *s2636_1_ram;
+static UINT8 *s2636_2_ram;
 
 /* information for the single 32x32 sprite displayed */
 static struct sprite_info
@@ -78,7 +80,7 @@ static WRITE8_HANDLER( laserbat_input_mux_w )
 {
 	laserbat_input_mux = (data & 0x30) >> 4;
 
-	flip_screen = data & 0x08;
+	flip_screen_set_no_update(space->machine, data & 0x08);
 
 	coin_counter_w(0,data & 1);
 
@@ -88,8 +90,9 @@ static WRITE8_HANDLER( laserbat_input_mux_w )
 
 static READ8_HANDLER( laserbat_input_r )
 {
-	// Add coktail inputs
-	return readinputport(0 + laserbat_input_mux);
+	static const char *const portnames[] = { "IN0", "IN1", "IN2", "IN3" };
+
+	return input_port_read(space->machine, portnames[laserbat_input_mux]);
 }
 
 static WRITE8_HANDLER( laserbat_cnteff_w )
@@ -182,9 +185,9 @@ static ADDRESS_MAP_START( laserbat_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x7800, 0x7bff) AM_ROM
 
 	AM_RANGE(0x1400, 0x14ff) AM_MIRROR(0x6000) AM_WRITENOP // always 0 (bullet ram in Quasar)
-	AM_RANGE(0x1500, 0x15ff) AM_MIRROR(0x6000) AM_RAM AM_BASE(&s2636_1_ram)
-	AM_RANGE(0x1600, 0x16ff) AM_MIRROR(0x6000) AM_RAM AM_BASE(&s2636_2_ram)
-	AM_RANGE(0x1700, 0x17ff) AM_MIRROR(0x6000) AM_RAM AM_BASE(&s2636_3_ram)
+	AM_RANGE(0x1500, 0x15ff) AM_MIRROR(0x6000) AM_RAM AM_BASE(&s2636_0_ram)
+	AM_RANGE(0x1600, 0x16ff) AM_MIRROR(0x6000) AM_RAM AM_BASE(&s2636_1_ram)
+	AM_RANGE(0x1700, 0x17ff) AM_MIRROR(0x6000) AM_RAM AM_BASE(&s2636_2_ram)
 	AM_RANGE(0x1800, 0x1bff) AM_MIRROR(0x6000) AM_WRITE(laserbat_videoram_w)
 	AM_RANGE(0x1c00, 0x1fff) AM_MIRROR(0x6000) AM_RAM
 ADDRESS_MAP_END
@@ -196,7 +199,7 @@ static ADDRESS_MAP_START( laserbat_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x04, 0x05) AM_WRITE(sprite_x_y_w)
 	AM_RANGE(0x06, 0x06) AM_WRITE(laserbat_input_mux_w)
 	AM_RANGE(0x07, 0x07) AM_WRITE(laserbat_csound2_w)
-	AM_RANGE(S2650_SENSE_PORT, S2650_SENSE_PORT) AM_READ(input_port_4_r)
+	AM_RANGE(S2650_SENSE_PORT, S2650_SENSE_PORT) AM_READ_PORT("SENSE")
 ADDRESS_MAP_END
 
 
@@ -208,7 +211,7 @@ static ADDRESS_MAP_START( catnmous_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x04, 0x05) AM_WRITE(sprite_x_y_w)
 	AM_RANGE(0x06, 0x06) AM_WRITE(laserbat_input_mux_w)
 	AM_RANGE(0x07, 0x07) AM_WRITENOP // unknown
-	AM_RANGE(S2650_SENSE_PORT, S2650_SENSE_PORT) AM_READ(input_port_4_r)
+	AM_RANGE(S2650_SENSE_PORT, S2650_SENSE_PORT) AM_READ_PORT("SENSE")
 ADDRESS_MAP_END
 
 // the same as in zaccaria.c ?
@@ -220,7 +223,7 @@ ADDRESS_MAP_END
 
 
 static INPUT_PORTS_START( laserbat )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN2 )
@@ -230,7 +233,7 @@ static INPUT_PORTS_START( laserbat )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON4 )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -252,7 +255,7 @@ static INPUT_PORTS_START( laserbat )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME("Reset")
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( 1C_2C ) )
@@ -276,7 +279,7 @@ static INPUT_PORTS_START( laserbat )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -294,12 +297,12 @@ static INPUT_PORTS_START( laserbat )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )
 
-	PORT_START	/* SENSE */
+	PORT_START("SENSE")
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_VBLANK )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( lazarian )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN2 )
@@ -309,7 +312,7 @@ static INPUT_PORTS_START( lazarian )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON4 )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -331,7 +334,7 @@ static INPUT_PORTS_START( lazarian )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME("Reset")
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) )
@@ -354,7 +357,7 @@ static INPUT_PORTS_START( lazarian )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -372,12 +375,12 @@ static INPUT_PORTS_START( lazarian )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )
 
-	PORT_START	/* SENSE */
+	PORT_START("SENSE")
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_VBLANK )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( catnmous )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN2 )
@@ -387,7 +390,7 @@ static INPUT_PORTS_START( catnmous )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -405,7 +408,7 @@ static INPUT_PORTS_START( catnmous )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME("Reset")
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( 1C_2C ) )
@@ -429,7 +432,7 @@ static INPUT_PORTS_START( catnmous )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -455,7 +458,7 @@ static INPUT_PORTS_START( catnmous )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START	/* SENSE */
+	PORT_START("SENSE")
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_VBLANK )
 INPUT_PORTS_END
 
@@ -488,52 +491,82 @@ static const gfx_layout sprites_layout =
 };
 
 static GFXDECODE_START( laserbat )
-	GFXDECODE_ENTRY( REGION_GFX1, 0x0000, charlayout,       0, 256 )	/* Rom chars */
-	GFXDECODE_ENTRY( REGION_CPU1, 0x1500, s2636_gfx_layout, 0,   8 )	/* s2636 #1  */
-	GFXDECODE_ENTRY( REGION_CPU1, 0x1600, s2636_gfx_layout, 0,   8 )	/* s2636 #2  */
-	GFXDECODE_ENTRY( REGION_CPU1, 0x1700, s2636_gfx_layout, 0,   8 )	/* s2636 #3  */
-	GFXDECODE_ENTRY( REGION_GFX2, 0x0000, sprites_layout,   0,   8 )	/* Sprites   */
+	GFXDECODE_ENTRY( "gfx1", 0x0000, charlayout,       0, 256 )	/* Rom chars */
+	GFXDECODE_ENTRY( "gfx2", 0x0000, sprites_layout,   0,   8 )	/* Sprites   */
 GFXDECODE_END
 
 static TILE_GET_INFO( get_tile_info )
 {
 	// wrong color index!
-	SET_TILE_INFO(0, videoram[tile_index], colorram[tile_index], 0);
+	SET_TILE_INFO(0, videoram[tile_index], colorram[tile_index] & 0x7f, 0);
 }
 
 static VIDEO_START( laserbat )
 {
-	bg_tilemap = tilemap_create(get_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,32,32);
+	int screen_width = video_screen_get_width(machine->primary_screen);
+	int screen_height = video_screen_get_height(machine->primary_screen);
+
+	bg_tilemap = tilemap_create(machine, get_tile_info,tilemap_scan_rows,8,8,32,32);
 
 	videoram = (UINT8 *)auto_malloc(0x400);
 	colorram = (UINT8 *)auto_malloc(0x400);
 
-	collision_bitmap = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,BITMAP_FORMAT_INDEXED8);
-
-	s2636_x_offset = -19;
+	/* configure the S2636 chips */
+	s2636_0 = s2636_config(s2636_0_ram, screen_height, screen_width, 0, -19);
+	s2636_1 = s2636_config(s2636_1_ram, screen_height, screen_width, 0, -19);
+	s2636_2 = s2636_config(s2636_2_ram, screen_height, screen_width, 0, -19);
 }
 
 static VIDEO_UPDATE( laserbat )
 {
+	int y;
+	bitmap_t *s2636_0_bitmap;
+	bitmap_t *s2636_1_bitmap;
+	bitmap_t *s2636_2_bitmap;
+
 	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
 
-	s2636_update_bitmap(machine,bitmap,s2636_1_ram,1,collision_bitmap);
-	s2636_update_bitmap(machine,bitmap,s2636_2_ram,2,collision_bitmap);
-	s2636_update_bitmap(machine,bitmap,s2636_3_ram,3,collision_bitmap);
+    /* update the S2636 chips */
+	s2636_0_bitmap = s2636_update(s2636_0, cliprect);
+	s2636_1_bitmap = s2636_update(s2636_1, cliprect);
+	s2636_2_bitmap = s2636_update(s2636_2, cliprect);
+
+	/* copy the S2636 images into the main bitmap */
+	for (y = cliprect->min_y; y <= cliprect->max_y; y++)
+	{
+		int x;
+
+		for (x = cliprect->min_x; x <= cliprect->max_x; x++)
+		{
+			int pixel0 = *BITMAP_ADDR16(s2636_0_bitmap, y, x);
+			int pixel1 = *BITMAP_ADDR16(s2636_1_bitmap, y, x);
+			int pixel2 = *BITMAP_ADDR16(s2636_2_bitmap, y, x);
+
+			if (S2636_IS_PIXEL_DRAWN(pixel0))
+				*BITMAP_ADDR16(bitmap, y, x) = S2636_PIXEL_COLOR(pixel0);
+
+			if (S2636_IS_PIXEL_DRAWN(pixel1))
+				*BITMAP_ADDR16(bitmap, y, x) = S2636_PIXEL_COLOR(pixel1);
+
+			if (S2636_IS_PIXEL_DRAWN(pixel2))
+				*BITMAP_ADDR16(bitmap, y, x) = S2636_PIXEL_COLOR(pixel2);
+		}
+	}
 
 	if(sprite_info.enable)
-		drawgfx(bitmap,machine->gfx[4],
+		drawgfx(bitmap,screen->machine->gfx[1],
 		        sprite_info.code,
 				sprite_info.color,
 				0,0,
 				sprite_info.x - 6,sprite_info.y,
 				cliprect,TRANSPARENCY_PEN,0);
+
 	return 0;
 }
 
 /* Laser Battle sound **********************************/
 
-static const struct SN76477interface sn76477_interface =
+static const sn76477_interface laserbat_sn76477_interface =
 {
 	RES_K(47), 		/*  4 noise_res         R21    47K */
 	0,				/*  5 filter_res (variable) */
@@ -562,17 +595,17 @@ static const struct SN76477interface sn76477_interface =
 
 /* Cat'N Mouse sound ***********************************/
 
-static void zaccaria_irq0a(int state) { cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, state ? ASSERT_LINE : CLEAR_LINE); }
-static void zaccaria_irq0b(int state) { cpunum_set_input_line(Machine, 1,0,state ? ASSERT_LINE : CLEAR_LINE); }
+static void zaccaria_irq0a(running_machine *machine, int state) { cpu_set_input_line(machine->cpu[1], INPUT_LINE_NMI, state ? ASSERT_LINE : CLEAR_LINE); }
+static void zaccaria_irq0b(running_machine *machine, int state) { cpu_set_input_line(machine->cpu[1],0,state ? ASSERT_LINE : CLEAR_LINE); }
 
 static int active_8910,port0a;
 
 static READ8_HANDLER( zaccaria_port0a_r )
 {
 	if (active_8910 == 0)
-		return AY8910_read_port_0_r(0);
+		return ay8910_read_port_0_r(space,0);
 	else
-		return AY8910_read_port_1_r(0);
+		return ay8910_read_port_1_r(space,0);
 }
 
 static WRITE8_HANDLER( zaccaria_port0a_w )
@@ -590,9 +623,9 @@ static WRITE8_HANDLER( zaccaria_port0b_w )
 	{
 		/* bit 0 goes to the 8910 #0 BC1 pin */
 		if (last & 0x01)
-			AY8910_control_port_0_w(0,port0a);
+			ay8910_control_port_0_w(space,0,port0a);
 		else
-			AY8910_write_port_0_w(0,port0a);
+			ay8910_write_port_0_w(space,0,port0a);
 	}
 	else if ((last & 0x02) == 0x00 && (data & 0x02) == 0x02)
 	{
@@ -605,9 +638,9 @@ static WRITE8_HANDLER( zaccaria_port0b_w )
 	{
 		/* bit 2 goes to the 8910 #1 BC1 pin */
 		if (last & 0x04)
-			AY8910_control_port_1_w(0,port0a);
+			ay8910_control_port_1_w(space,0,port0a);
 		else
-			AY8910_write_port_1_w(0,port0a);
+			ay8910_write_port_1_w(space,0,port0a);
 	}
 	else if ((last & 0x08) == 0x00 && (data & 0x08) == 0x08)
 	{
@@ -626,17 +659,19 @@ static const pia6821_interface pia_0_intf =
 	/*irqs   : A/B             */ zaccaria_irq0a, zaccaria_irq0b
 };
 
-static const struct AY8910interface ay8910_interface =
+static const ay8910_interface ay8910_config =
 {
-	0,
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
+	NULL,
 	soundlatch_r,
-	0,//ay8910_port0a_w,
-	0
+	NULL,//ay8910_port0a_w,
+	NULL
 };
 
 static MACHINE_START( catnmous )
 {
-	pia_config(0, &pia_0_intf);
+	pia_config(machine, 0, &pia_0_intf);
 }
 
 static MACHINE_RESET( catnmous )
@@ -647,37 +682,35 @@ static MACHINE_RESET( catnmous )
 
 static INTERRUPT_GEN( laserbat_interrupt )
 {
-	cpunum_set_input_line_and_vector(machine, 0,0,PULSE_LINE,0x0a);
+	generic_pulse_irq_line_and_vector(device,0,0x0a);
 }
 
 static INTERRUPT_GEN( zaccaria_cb1_toggle )
 {
 	static int toggle;
 
-	pia_0_cb1_w(0,toggle & 1);
+	pia_0_cb1_w(cpu_get_address_space(device, ADDRESS_SPACE_PROGRAM),0,toggle & 1);
 	toggle ^= 1;
 }
 
 
 static MACHINE_DRIVER_START( laserbat )
 
-	MDRV_CPU_ADD(S2650, 14318180/4) // ???
+	MDRV_CPU_ADD("main", S2650, 14318180/4) // ???
 	MDRV_CPU_PROGRAM_MAP(laserbat_map,0)
 	MDRV_CPU_IO_MAP(laserbat_io_map,0)
-	MDRV_CPU_VBLANK_INT(laserbat_interrupt,1)
-
-	MDRV_SCREEN_REFRESH_RATE(50)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", laserbat_interrupt)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(50)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 256)
 	MDRV_SCREEN_VISIBLE_AREA(1*8, 29*8-1, 2*8, 32*8-1)
 
 	MDRV_GFXDECODE(laserbat)
 	MDRV_PALETTE_LENGTH(1024)
-	MDRV_COLORTABLE_LENGTH(4096)
 
 	MDRV_VIDEO_START(laserbat)
 	MDRV_VIDEO_UPDATE(laserbat)
@@ -685,42 +718,40 @@ static MACHINE_DRIVER_START( laserbat )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SN76477, 0) // output not connected
-	MDRV_SOUND_CONFIG(sn76477_interface)
+	MDRV_SOUND_ADD("sn", SN76477, 0) // output not connected
+	MDRV_SOUND_CONFIG(laserbat_sn76477_interface)
 
-	MDRV_SOUND_ADD(TMS3615, 4000000/8/2) // 250 kHz, from second chip's clock out
+	MDRV_SOUND_ADD("tms1", TMS3615, 4000000/8/2) // 250 kHz, from second chip's clock out
 	MDRV_SOUND_ROUTE(TMS3615_FOOTAGE_8, "mono", 1.0)
 
-	MDRV_SOUND_ADD(TMS3615, 4000000/8) // 500 kHz
+	MDRV_SOUND_ADD("tms2", TMS3615, 4000000/8) // 500 kHz
 	MDRV_SOUND_ROUTE(TMS3615_FOOTAGE_8, "mono", 1.0)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( catnmous )
 
-	MDRV_CPU_ADD(S2650, 14318000/4)	/* ? */
+	MDRV_CPU_ADD("main", S2650, 14318000/4)	/* ? */
 	MDRV_CPU_PROGRAM_MAP(laserbat_map,0)
 	MDRV_CPU_IO_MAP(catnmous_io_map,0)
-	MDRV_CPU_VBLANK_INT(laserbat_interrupt,1)
+	MDRV_CPU_VBLANK_INT("main", laserbat_interrupt)
 
-	MDRV_CPU_ADD(M6802,3580000) /* ? */
+	MDRV_CPU_ADD("audio", M6802,3580000) /* ? */
 	MDRV_CPU_PROGRAM_MAP(catnmous_sound_map,0)
 	MDRV_CPU_PERIODIC_INT(zaccaria_cb1_toggle, (double)3580000/4096)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-
 	MDRV_MACHINE_START(catnmous)
 	MDRV_MACHINE_RESET(catnmous)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 256)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 32*8-1)
 
 	MDRV_GFXDECODE(laserbat)
 	MDRV_PALETTE_LENGTH(1024)
-	MDRV_COLORTABLE_LENGTH(4096)
 
 	MDRV_VIDEO_START(laserbat)
 	MDRV_VIDEO_UPDATE(laserbat)
@@ -728,11 +759,11 @@ static MACHINE_DRIVER_START( catnmous )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, 3580000/2) // ?
-	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ADD("ay1", AY8910, 3580000/2) // ?
+	MDRV_SOUND_CONFIG(ay8910_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_SOUND_ADD(AY8910, 3580000/2) // ?
+	MDRV_SOUND_ADD("ay2", AY8910, 3580000/2) // ?
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -757,7 +788,7 @@ Xtal : 4.000 Mhz
 */
 
 ROM_START( laserbat )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "lb02.7c",      0x0000, 0x0400, CRC(23a257cd) SHA1(08d9e1ff1a5cd8a5e5af6a12ba6104d3b2ccfddf) )
 	ROM_CONTINUE(			  0x4000, 0x0400 )
 	ROM_LOAD( "lb02.6c",      0x0400, 0x0400, CRC(d1d6a67a) SHA1(727898c733633daffb0193cf4a556f89fe7e8a5a) )
@@ -779,20 +810,20 @@ ROM_START( laserbat )
 	ROM_LOAD( "lb02.2b",      0x3000, 0x0400, CRC(39000248) SHA1(58c6d1c588f4d1a3f579fe14faa8d2ccdfdc001e) )
 	ROM_CONTINUE(			  0x7000, 0x0400 )
 
-	ROM_REGION( 0x1800, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1800, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "lb02.8g",      0x0000, 0x0800, CRC(4bb9f452) SHA1(1ff4ef94f0da3b59377548f3341b083af83f83c6) )
 	ROM_LOAD( "lb02.10g",     0x0800, 0x0800, CRC(5fec6517) SHA1(868e57e8498cf1ab0fa3635845cdb5800fd96855) )
 	ROM_LOAD( "lb02.11g",     0x1000, 0x0800, CRC(ceaf00a4) SHA1(2e789898207caa7619dcbb01f52c3532d1482618) )
 
-	ROM_REGION( 0x0800, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0800, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "lb02.14l",     0x0000, 0x0800, CRC(d29962d1) SHA1(5b6d0856c3ebbd5833b522f7c0240309cf3c9777) )
 
-	ROM_REGION( 0x0100, REGION_PLDS, 0 )
+	ROM_REGION( 0x0100, "plds", 0 )
 	ROM_LOAD( "82s100_prom",  0x0000, 0x00f5, NO_DUMP )
 ROM_END
 
 ROM_START( lazarian )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "laz.7c",      0x0000, 0x0400, CRC(a2454cf2) SHA1(163b9323e77ee0107e13860b3468e002c335df9e) )
 	ROM_CONTINUE(			 0x4000, 0x0400 )
 	ROM_LOAD( "laz.6c",      0x0400, 0x0400, CRC(23ee6013) SHA1(7ad53d6c321b0161906a512f6575620fd049d2f7) )
@@ -816,20 +847,20 @@ ROM_START( lazarian )
 	ROM_CONTINUE(			 0x3000, 0x0400 )
 	ROM_CONTINUE(			 0x7000, 0x0400 )
 
-	ROM_REGION( 0x1800, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1800, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "laz.8g",      0x0000, 0x0800, CRC(3cf76c01) SHA1(1824bc05e8dd2a522409e95fe81d2ad64182dcac) )
 	ROM_LOAD( "laz.10g",     0x0800, 0x0800, CRC(256ae65d) SHA1(7f9e8ea1bbcb9e2175544556795c88c9981db571) )
 	ROM_LOAD( "laz.11g",     0x1000, 0x0800, CRC(fec8266a) SHA1(7b90ae8d9eeb148012cca1bc93546dc3bf509258) )
 
-	ROM_REGION( 0x0800, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0800, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "laz.14l",      0x0000, 0x0800, CRC(d29962d1) SHA1(5b6d0856c3ebbd5833b522f7c0240309cf3c9777) )
 
-	ROM_REGION( 0x0100, REGION_PLDS, 0 )
+	ROM_REGION( 0x0100, "plds", 0 )
 	ROM_LOAD( "lz82s100.10m", 0x0000, 0x00f5, CRC(c3eb562a) SHA1(65dff81b2e5321d530e5171dab9aa3809ab38b4d) )
 ROM_END
 
 ROM_START( catnmous )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "02-1.7c",      0x0000, 0x0400, CRC(d26ec566) SHA1(ceb16f64a3c1ff25a9eab6549f1ae24085bb9e27) )
 	ROM_CONTINUE(			  0x4000, 0x0400 )
 	ROM_LOAD( "02-2.6c",      0x0400, 0x0400, CRC(02a7e36c) SHA1(8495b2906ecb0791a47e9b6f1959ed6cbc14cce8) )
@@ -853,25 +884,25 @@ ROM_START( catnmous )
 	ROM_CONTINUE(			  0x3000, 0x0400 )
 	ROM_CONTINUE(			  0x7000, 0x0400 )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "sound01.1d",   0xd000, 0x1000, CRC(f65cb9d0) SHA1(a2fe7563c6da055bf6aa20797b2d9fa184f0133c) )
 	ROM_LOAD( "sound01.1f",   0xe000, 0x1000, CRC(473c44de) SHA1(ff08b02d45a2c23cabb5db716aa203225a931424) )
 	ROM_LOAD( "sound01.1e",   0xf000, 0x1000, CRC(1bd90c93) SHA1(20fd2b765a42e25cf7f716e6631b8c567785a866) )
 
-	ROM_REGION( 0x1800, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1800, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "type01.8g",    0x0000, 0x0800, CRC(2b180d4a) SHA1(b6f48ffdbad64b4d9f1fe838000187800c51228c) )
 	ROM_LOAD( "type01.10g",   0x0800, 0x0800, CRC(e5259f9b) SHA1(396753291ab36c3ed72208d619665fc0f33d1e17) )
 	ROM_LOAD( "type01.11g",   0x1000, 0x0800, CRC(2999f378) SHA1(929082383b2b0006de171587adb932ce57316963) )
 
-	ROM_REGION( 0x0800, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0800, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "type01.14l",   0x0000, 0x0800, CRC(af79179a) SHA1(de61af7d02c93be326a33ee51572e3da7a25dab0) )
 
-	ROM_REGION( 0x0100, REGION_PLDS, 0 )
+	ROM_REGION( 0x0100, "plds", 0 )
 	ROM_LOAD( "82s100.13m",   0x0000, 0x00f5, CRC(6b724cdb) SHA1(8a0ca3b171b103661a3b2fffbca3d7162089e243) )
 ROM_END
 
 ROM_START( catmousa )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "catnmous.7c",  0x0000, 0x0400, CRC(0bf9fc06) SHA1(7d5857121fe51f43e4ae7db34df720198994afdd) )
 	ROM_CONTINUE(			  0x4000, 0x0400 )
 	ROM_LOAD( "catnmous.6c",  0x0400, 0x0400, CRC(b0e140a0) SHA1(68d8ca25642e872f2177d09b78d553c033411dd5) )
@@ -894,20 +925,20 @@ ROM_START( catmousa )
 	ROM_LOAD( "catnmous.2b",  0x3000, 0x0400, BAD_DUMP CRC(880728fa) SHA1(f204d669c190ad0cf2c885af12625026534db655) )
 	ROM_CONTINUE(			  0x7000, 0x0400 )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "snd.1d",       0xd000, 0x1000, CRC(f65cb9d0) SHA1(a2fe7563c6da055bf6aa20797b2d9fa184f0133c) )
 	ROM_LOAD( "snd.1f",       0xe000, 0x1000, CRC(473c44de) SHA1(ff08b02d45a2c23cabb5db716aa203225a931424) )
 	ROM_LOAD( "snd.1e",       0xf000, 0x1000, CRC(1bd90c93) SHA1(20fd2b765a42e25cf7f716e6631b8c567785a866) )
 
-	ROM_REGION( 0x1800, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1800, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "catnmous.8g",  0x0000, 0x0800, CRC(2b180d4a) SHA1(b6f48ffdbad64b4d9f1fe838000187800c51228c) )
 	ROM_LOAD( "catnmous.10g", 0x0800, 0x0800, CRC(e5259f9b) SHA1(396753291ab36c3ed72208d619665fc0f33d1e17) )
 	ROM_LOAD( "catnmous.11g", 0x1000, 0x0800, CRC(2999f378) SHA1(929082383b2b0006de171587adb932ce57316963) )
 
-	ROM_REGION( 0x0800, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0800, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "catnmous.14l", 0x0000, 0x0800, CRC(af79179a) SHA1(de61af7d02c93be326a33ee51572e3da7a25dab0) )
 
-	ROM_REGION( 0x0100, REGION_PLDS, 0 )
+	ROM_REGION( 0x0100, "plds", 0 )
 	ROM_LOAD( "82s100.13m", 0x0000, 0x00f5, NO_DUMP )
 ROM_END
 
