@@ -64,13 +64,13 @@ Notes:
 
 #include "driver.h"
 #include "deprecat.h"
-#include "cpu/h83002/h83002.h"
+#include "cpu/h83002/h8.h"
 
 /***************************************************************************
                                 Video Hardware
 ***************************************************************************/
 
-static mame_bitmap *lastfght_bitmap[2];
+static bitmap_t *lastfght_bitmap[2];
 static int clr_offset;
 static int lastfght_dest;
 
@@ -78,7 +78,7 @@ static VIDEO_START( lastfght )
 {
 	int i;
 	for (i = 0; i < 2; i++)
-		lastfght_bitmap[i] = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
+		lastfght_bitmap[i] = video_screen_auto_bitmap_alloc(machine->primary_screen);
 
 	colorram = auto_malloc(256*3);
 }
@@ -92,7 +92,7 @@ static VIDEO_UPDATE( lastfght )
 	int x, y, count = 0;
 	static unsigned base = 0;
 	static int view_roms = 0;
-	UINT8 *gfxdata = memory_region( REGION_GFX1 );
+	UINT8 *gfxdata = memory_region( screen->machine, "gfx1" );
 	UINT8 data;
 
 	if ( input_code_pressed_once(KEYCODE_ENTER) )	view_roms ^= 1;
@@ -100,16 +100,16 @@ static VIDEO_UPDATE( lastfght )
 	{
 		if ( input_code_pressed_once(KEYCODE_PGDN) )	base += 512 * 256;
 		if ( input_code_pressed_once(KEYCODE_PGUP) )	base -= 512 * 256;
-		base %= memory_region_length( REGION_GFX1 );
+		base %= memory_region_length( screen->machine, "gfx1" );
 
 		count = base;
 
-		fillbitmap( bitmap, get_black_pen(machine), cliprect );
+		bitmap_fill( bitmap, cliprect , get_black_pen(screen->machine));
 		for ( y = 0 ; y < 256; y++ )
 		{
 			for ( x = 0; x < 512; x++ )
 			{
-				data = ( ((count&0xf)==0)&&((count&0x1e00)==0) )? get_white_pen(Machine) : gfxdata[count];	// white grid or data
+				data = ( ((count&0xf)==0)&&((count&0x1e00)==0) )? get_white_pen(screen->machine) : gfxdata[count];	// white grid or data
 				*BITMAP_ADDR16(bitmap, y, x) = data;
 				count++;
 			}
@@ -129,10 +129,10 @@ static VIDEO_UPDATE( lastfght )
 
 static WRITE16_HANDLER(colordac_w)
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		colorram[clr_offset] = data;
-		palette_set_color_rgb(Machine, clr_offset/3,
+		palette_set_color_rgb(space->machine, clr_offset/3,
 			pal6bit(colorram[(clr_offset/3)*3+0]),
 			pal6bit(colorram[(clr_offset/3)*3+1]),
 			pal6bit(colorram[(clr_offset/3)*3+2])
@@ -140,7 +140,7 @@ static WRITE16_HANDLER(colordac_w)
 		clr_offset = (clr_offset+1) % (256*3);
 	}
 
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		clr_offset = (data>>8) * 3;
 	}
@@ -154,114 +154,114 @@ static int lastfght_x, lastfght_y, lastfght_w, lastfght_h;
 // high byte of a 16 bit register
 static WRITE16_HANDLER( lastfght_hi_w )
 {
-	if (ACCESSING_MSB)	logerror("%06x: 600000.b = %02x\n", activecpu_get_pc(),data>>8);
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_8_15)	logerror("%06x: 600000.b = %02x\n", cpu_get_pc(space->cpu),data>>8);
+	if (ACCESSING_BITS_0_7)
 	{
 		lastfght_hi	=	data << 8;
-		//logerror("%06x: lastfght_hi  = %02x\n", activecpu_get_pc(),data);
+		//logerror("%06x: lastfght_hi  = %02x\n", cpu_get_pc(space->cpu),data);
 	}
 }
 // screen x
 static WRITE16_HANDLER( lastfght_x_w )
 {
-	if (ACCESSING_MSB)	logerror("%06x: 800008.b = %02x\n", activecpu_get_pc(),data>>8);
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_8_15)	logerror("%06x: 800008.b = %02x\n", cpu_get_pc(space->cpu),data>>8);
+	if (ACCESSING_BITS_0_7)
 	{
 		lastfght_x	=	lastfght_hi | data;
-		//logerror("%06x: lastfght_x   = %02x\n", activecpu_get_pc(),data);
+		//logerror("%06x: lastfght_x   = %02x\n", cpu_get_pc(space->cpu),data);
 	}
 }
 // screen y, screen width - 1
 static WRITE16_HANDLER( lastfght_yw_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		lastfght_y	=	lastfght_hi | (data >> 8);
-		//logerror("%06x: lastfght_y   = %02x\n", activecpu_get_pc(),data>>8);
+		//logerror("%06x: lastfght_y   = %02x\n", cpu_get_pc(space->cpu),data>>8);
 	}
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		lastfght_w	=	lastfght_hi | data;
-		//logerror("%06x: lastfght_w   = %02x\n", activecpu_get_pc(),data);
+		//logerror("%06x: lastfght_w   = %02x\n", cpu_get_pc(space->cpu),data);
 	}
 }
 // screen height - 1
 static WRITE16_HANDLER( lastfght_h_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		lastfght_h	=	lastfght_hi | (data >> 8);
-		//logerror("%06x: lastfght_h   = %02x\n", activecpu_get_pc(),data>>8);
+		//logerror("%06x: lastfght_h   = %02x\n", cpu_get_pc(space->cpu),data>>8);
 	}
-	if (ACCESSING_LSB)	logerror("%06x: 80000d.b = %02x\n", activecpu_get_pc(),data);
+	if (ACCESSING_BITS_0_7)	logerror("%06x: 80000d.b = %02x\n", cpu_get_pc(space->cpu),data);
 }
 // source delta x << 6, source x << 6
 static WRITE16_HANDLER( lastfght_sx_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		lastfght_dsx	=	lastfght_hi | (data >> 8);
-		//logerror("%06x: lastfght_dsx = %02x\n", activecpu_get_pc(),data>>8);
+		//logerror("%06x: lastfght_dsx = %02x\n", cpu_get_pc(space->cpu),data>>8);
 	}
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		lastfght_sx	=	lastfght_hi | data;
-		//logerror("%06x: lastfght_sx  = %02x\n", activecpu_get_pc(),data);
+		//logerror("%06x: lastfght_sx  = %02x\n", cpu_get_pc(space->cpu),data);
 	}
 }
 // source y << 6, source y1 << 6
 static WRITE16_HANDLER( lastfght_sy_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		lastfght_sy	=	lastfght_hi | (data >> 8);
-		//logerror("%06x: lastfght_sy  = %02x\n", activecpu_get_pc(),data>>8);
+		//logerror("%06x: lastfght_sy  = %02x\n", cpu_get_pc(space->cpu),data>>8);
 	}
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		lastfght_sy1	=	lastfght_hi | data;
-		//logerror("%06x: lastfght_sy1 = %02x\n", activecpu_get_pc(),data);
+		//logerror("%06x: lastfght_sy1 = %02x\n", cpu_get_pc(space->cpu),data);
 	}
 }
 // source rom (0x200000 bytes), source page (512x256 bytes)
 static WRITE16_HANDLER( lastfght_sr_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		lastfght_sp	=	(lastfght_hi>>8) >> 4;
-		//logerror("%06x: lastfght_sp  = %02x\n", activecpu_get_pc(),data>>8);
+		//logerror("%06x: lastfght_sp  = %02x\n", cpu_get_pc(space->cpu),data>>8);
 	}
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		lastfght_sr	=	data;
-		//logerror("%06x: lastfght_sr  = %02x\n", activecpu_get_pc(),data);
+		//logerror("%06x: lastfght_sr  = %02x\n", cpu_get_pc(space->cpu),data);
 	}
 }
 // source x1 << 6, source delta y << 6
 static WRITE16_HANDLER( lastfght_sd_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		lastfght_sx1	=	lastfght_hi | (data >> 8);
-		//logerror("%06x: lastfght_sx1 = %02x\n", activecpu_get_pc(),data>>8);
+		//logerror("%06x: lastfght_sx1 = %02x\n", cpu_get_pc(space->cpu),data>>8);
 	}
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		lastfght_dsy	=	lastfght_hi | data;
-		//logerror("%06x: lastfght_dsy = %02x\n", activecpu_get_pc(),data);
+		//logerror("%06x: lastfght_dsy = %02x\n", cpu_get_pc(space->cpu),data);
 	}
 }
 // start blit
 static WRITE16_HANDLER( lastfght_blit_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		int x,y, addr;
-		UINT8 *gfxdata = memory_region( REGION_GFX1 );
-		mame_bitmap *dest = lastfght_bitmap[lastfght_dest];
+		UINT8 *gfxdata = memory_region( space->machine, "gfx1" );
+		bitmap_t *dest = lastfght_bitmap[lastfght_dest];
 
 #if 0
-		logerror("%06x: blit x %03x, y %03x, w %03x, h %03x, sx %03x.%02x, sx1 %03x.%02x, dsx %03x.%02x, sy %03x.%02x, sy1 %03x.%02x, dsy %03x.%02x, sp %02x, sr %02x, data %02x\n", activecpu_get_pc(),
+		logerror("%06x: blit x %03x, y %03x, w %03x, h %03x, sx %03x.%02x, sx1 %03x.%02x, dsx %03x.%02x, sy %03x.%02x, sy1 %03x.%02x, dsy %03x.%02x, sp %02x, sr %02x, data %02x\n", cpu_get_pc(space->cpu),
 				lastfght_x,lastfght_y,lastfght_w+1,lastfght_h+1,
 				lastfght_sx>>6,lastfght_sx&0x3f,	lastfght_sx1>>6,lastfght_dsx&0x3f,	lastfght_sx1>>6,lastfght_sx1&0x3f,
 				lastfght_sy>>6,lastfght_sy&0x3f,	lastfght_sy1>>6,lastfght_dsy&0x3f,	lastfght_sy1>>6,lastfght_sy1&0x3f,
@@ -285,12 +285,12 @@ static WRITE16_HANDLER( lastfght_blit_w )
 			}
 		}
 	}
-	if (ACCESSING_LSB)	logerror("%06x: 600007.b = %02x\n", activecpu_get_pc(),data);
+	if (ACCESSING_BITS_0_7)	logerror("%06x: 600007.b = %02x\n", cpu_get_pc(space->cpu),data);
 }
 // toggle framebuffer
 static WRITE16_HANDLER( lastfght_dest_w )
 {
-	if (ACCESSING_LSB)	lastfght_dest ^= 1;
+	if (ACCESSING_BITS_0_7)	lastfght_dest ^= 1;
 }
 
 static READ16_HANDLER( lastfght_c00000_r )
@@ -306,12 +306,12 @@ static READ16_HANDLER( lastfght_c00002_r )
 {
 	// high byte:
 	// mask 0x1c: from sound?
-	return (mame_rand(Machine) & 0x1c00) | readinputport(0);
+	return (mame_rand(space->machine) & 0x1c00) | input_port_read(space->machine, "IN0");
 }
 
 static READ16_HANDLER( lastfght_c00004_r )
 {
-	return readinputport(1);
+	return input_port_read(space->machine, "IN1");
 }
 
 static READ16_HANDLER( lastfght_c00006_r )
@@ -319,7 +319,7 @@ static READ16_HANDLER( lastfght_c00006_r )
 	// low byte:
 	// bit 7 = protection?
 	// bit 5 = blitter?
-	return readinputport(2);
+	return input_port_read(space->machine, "IN2");
 }
 
 static WRITE16_HANDLER( lastfght_c00006_w )
@@ -338,8 +338,8 @@ static READ16_HANDLER( lastfght_sound_r )
 
 static WRITE16_HANDLER( lastfght_sound_w )
 {
-	if (ACCESSING_MSB)	logerror("%06x: sound_w msb = %02x\n", activecpu_get_pc(),data>>8);
-	if (ACCESSING_LSB)	logerror("%06x: sound_w lsb = %02x\n", activecpu_get_pc(),data);
+	if (ACCESSING_BITS_8_15)	logerror("%06x: sound_w msb = %02x\n", cpu_get_pc(space->cpu),data>>8);
+	if (ACCESSING_BITS_0_7)	logerror("%06x: sound_w lsb = %02x\n", cpu_get_pc(space->cpu),data);
 }
 
 /***************************************************************************
@@ -347,10 +347,10 @@ static WRITE16_HANDLER( lastfght_sound_w )
 ***************************************************************************/
 
 static ADDRESS_MAP_START( lastfght_map, ADDRESS_SPACE_PROGRAM, 16 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(24) )
+	ADDRESS_MAP_GLOBAL_MASK(0xffffff)
 
-	AM_RANGE( 0x000000, 0x07ffff ) AM_ROM AM_REGION(REGION_CPU1, 0)
-	AM_RANGE( 0x080000, 0x0fffff ) AM_ROM AM_REGION(REGION_CPU1, 0)
+	AM_RANGE( 0x000000, 0x07ffff ) AM_ROM AM_REGION("main", 0)
+	AM_RANGE( 0x080000, 0x0fffff ) AM_ROM AM_REGION("main", 0)
 
 	AM_RANGE( 0x200000, 0x20ffff ) AM_RAM AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)	// battery
 
@@ -358,7 +358,7 @@ static ADDRESS_MAP_START( lastfght_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE( 0x600002, 0x600003 ) AM_READWRITE( lastfght_sound_r, lastfght_sound_w )
 	AM_RANGE( 0x600006, 0x600007 ) AM_WRITE( lastfght_blit_w )
 	AM_RANGE( 0x600008, 0x600009 ) AM_WRITE( colordac_w )
-	AM_RANGE( 0x60000a, 0x60000b ) AM_WRITE( MWA16_NOP )	// colordac?
+	AM_RANGE( 0x60000a, 0x60000b ) AM_WRITE( SMH_NOP )	// colordac?
 
 	AM_RANGE( 0x800000, 0x800001 ) AM_WRITE( lastfght_sx_w )
 	AM_RANGE( 0x800002, 0x800003 ) AM_WRITE( lastfght_sd_w )
@@ -384,7 +384,7 @@ ADDRESS_MAP_END
 ***************************************************************************/
 
 static INPUT_PORTS_START( lastfght )
-	PORT_START	// IN0 - c00002&3
+	PORT_START("IN0")	/* IN0 - c00002&3 */
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_SERVICE1		)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_UNKNOWN		)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_OTHER			) PORT_NAME("Reset") PORT_CODE(KEYCODE_F1)
@@ -403,7 +403,7 @@ static INPUT_PORTS_START( lastfght )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN		)
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN		)
 
-	PORT_START	// IN1 - c00004&5
+	PORT_START("IN1")	/* IN1 - c00004&5 */
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_BUTTON1		)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_BUTTON2		)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_UNKNOWN		)
@@ -422,7 +422,7 @@ static INPUT_PORTS_START( lastfght )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_COIN1			)
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_COIN2			)
 
-	PORT_START	// IN2 - c00006&7
+	PORT_START("IN2")	/* IN2 - c00006&7 */
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_UNKNOWN		)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_UNKNOWN		)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_UNKNOWN		)
@@ -449,30 +449,31 @@ INPUT_PORTS_END
 
 static INTERRUPT_GEN( unknown_interrupt )
 {
-	switch (cpu_getiloops())
+	switch (cpu_getiloops(device))
 	{
 		case 0:
-			cpunum_set_input_line(machine, 0, 0, PULSE_LINE);
+			generic_pulse_irq_line(device, 0);
 			break;
 		default:
-			h8_3002_InterruptRequest(24);
+			cpu_set_input_line(device->machine->cpu[0], H8_METRO_TIMER_HACK, HOLD_LINE);
 			break;
 	}
 }
 
 static MACHINE_DRIVER_START( lastfght )
-	MDRV_CPU_ADD(H83044, 32000000/2)
+	MDRV_CPU_ADD("main", H83044, 32000000/2)
 	MDRV_CPU_PROGRAM_MAP( lastfght_map, 0 )
-	MDRV_CPU_VBLANK_INT(unknown_interrupt,2)
+	MDRV_CPU_VBLANK_INT_HACK(unknown_interrupt,2)
 
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES( VIDEO_TYPE_RASTER )
+	MDRV_PALETTE_LENGTH( 256 )
+
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE( 512, 256 )
 	MDRV_SCREEN_VISIBLE_AREA( 0, 512-1, 0, 256-16-1 )
-	MDRV_PALETTE_LENGTH( 256 )
 	MDRV_SCREEN_REFRESH_RATE( 60 )
 
 	MDRV_VIDEO_START( lastfght )
@@ -485,22 +486,22 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( lastfght )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )		// H8/3044 program
+	ROM_REGION( 0x100000, "main", 0 )		// H8/3044 program
 	ROM_LOAD( "v106.u16", 0x000000, 0x080000, CRC(7aec89f4) SHA1(7cff00844ad82a0f8d19b1bd07ba3a2bced69d66) )
 
-	ROM_REGION( 0x800000, REGION_GFX1, 0 )		// Blitter data
+	ROM_REGION( 0x800000, "gfx1", 0 )		// Blitter data
 	ROM_LOAD( "1.b1", 0x000000, 0x200000, CRC(6c438136) SHA1(138934e948bbd6bd80f354f037badedef6cd8cb1) )
 	ROM_LOAD( "2.b2", 0x200000, 0x200000, CRC(9710bcff) SHA1(0291385489a065ed895c99ae7197fdeac0a0e2a0) )
 	ROM_LOAD( "3.b3", 0x400000, 0x200000, CRC(4236c79a) SHA1(94f093d12c096d38d1e7278796f6d58e4ba14e2e) )
 	ROM_LOAD( "4.b4", 0x600000, 0x200000, CRC(68153b0f) SHA1(46ddf37d5885f411e0e6de9c7e8969ba3a00f17f) )
 
-	ROM_REGION( 0x100000, REGION_SOUND1, 0 )	// Samples
+	ROM_REGION( 0x100000, "samples", 0 )	// Samples
 	ROM_LOAD( "v100.u7", 0x000000, 0x100000, CRC(c134378c) SHA1(999c75f3a7890421cfd904a926ca377ee43a6825) )
 ROM_END
 
 static DRIVER_INIT(lastfght)
 {
-	UINT16 *rom = (UINT16*)memory_region(REGION_CPU1);
+	UINT16 *rom = (UINT16*)memory_region(machine, "main");
 
 	// pass initial check (protection ? hw?)
 	rom[0x00354/2] = 0x403e;
