@@ -165,7 +165,6 @@ maybe some priority issues / sprite placement issues..
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "video/konamiic.h"
 #include "cpu/m6809/m6809.h"
 #include "cpu/hd6309/hd6309.h"
@@ -177,8 +176,11 @@ maybe some priority issues / sprite placement issues..
 #define SOUND_CLOCK		XTAL_18_432MHz
 
 
-#define GUNX( a ) (( ( readinputport( a ) * 287 ) / 0xff ) + 16)
-#define GUNY( a ) (( ( readinputport( a ) * 223 ) / 0xff ) + 10)
+static const char *const gunnames[] = { "LIGHT0_X", "LIGHT0_Y", "LIGHT1_X", "LIGHT1_Y" };
+
+/* a = 1, 2 = player # */
+#define GUNX( a ) (( ( input_port_read(space->machine, gunnames[2 * (a - 1)]) * 287 ) / 0xff ) + 16)
+#define GUNY( a ) (( ( input_port_read(space->machine, gunnames[2 * (a - 1) + 1]) * 223 ) / 0xff ) + 10)
 
 VIDEO_START(lethalen);
 VIDEO_UPDATE(lethalen);
@@ -195,7 +197,7 @@ static const UINT8 lethalen_default_eeprom[48] = {
 	0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF
 };
 
-static const struct EEPROM_interface eeprom_interface =
+static const eeprom_interface eeprom_intf =
 {
 	7,			/* address bits */
 	8,			/* data bits */
@@ -209,30 +211,25 @@ static const struct EEPROM_interface eeprom_interface =
 static NVRAM_HANDLER( lethalen )
 {
 	if (read_or_write)
-		EEPROM_save(file);
+		eeprom_save(file);
 	else
 	{
-		EEPROM_init(&eeprom_interface);
+		eeprom_init(machine, &eeprom_intf);
 
 		if (file)
 		{
 			init_eeprom_count = 0;
-			EEPROM_load(file);
+			eeprom_load(file);
 		}
 		else
 		{
 			init_eeprom_count = 10;
-			EEPROM_set_data(lethalen_default_eeprom,48);
+			eeprom_set_data(lethalen_default_eeprom,48);
 
 		}
 	}
 }
 
-static READ8_HANDLER( control2_r )
-{
-	return 0x02 | EEPROM_read_bit() | (input_port_1_r(0) & 0xf0);
-}
-
 static WRITE8_HANDLER( control2_w )
 {
 	/* bit 0 is data */
@@ -245,24 +242,24 @@ static WRITE8_HANDLER( control2_w )
 
 	cur_control2 = data;
 
-	EEPROM_write_bit(cur_control2 & 0x01);
-	EEPROM_set_cs_line((cur_control2 & 0x02) ? CLEAR_LINE : ASSERT_LINE);
-	EEPROM_set_clock_line((cur_control2 & 0x04) ? ASSERT_LINE : CLEAR_LINE);
+	eeprom_write_bit(cur_control2 & 0x01);
+	eeprom_set_cs_line((cur_control2 & 0x02) ? CLEAR_LINE : ASSERT_LINE);
+	eeprom_set_clock_line((cur_control2 & 0x04) ? ASSERT_LINE : CLEAR_LINE);
 }
 
 static INTERRUPT_GEN(lethalen_interrupt)
 {
-	if (K056832_is_IRQ_enabled(0)) cpunum_set_input_line(machine, 0, HD6309_IRQ_LINE, HOLD_LINE);
+	if (K056832_is_IRQ_enabled(0)) cpu_set_input_line(device, HD6309_IRQ_LINE, HOLD_LINE);
 }
 
 static WRITE8_HANDLER( sound_cmd_w )
 {
-	soundlatch_w(0, data);
+	soundlatch_w(space, 0, data);
 }
 
 static WRITE8_HANDLER( sound_irq_w )
 {
-	cpunum_set_input_line(Machine, 1, 0, HOLD_LINE);
+	cpu_set_input_line(space->machine->cpu[1], 0, HOLD_LINE);
 }
 
 static READ8_HANDLER( sound_status_r )
@@ -270,16 +267,16 @@ static READ8_HANDLER( sound_status_r )
 	return 0xf;
 }
 
-static void sound_nmi(void)
+static void sound_nmi(running_machine *machine)
 {
-	cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, PULSE_LINE);
+	cpu_set_input_line(machine->cpu[1], INPUT_LINE_NMI, PULSE_LINE);
 }
 
 static WRITE8_HANDLER( le_bankswitch_w )
 {
-	UINT8 *prgrom = (UINT8 *)memory_region(REGION_CPU1)+0x10000;
+	UINT8 *prgrom = (UINT8 *)memory_region(space->machine, "main")+0x10000;
 
-	memory_set_bankptr(1, &prgrom[data * 0x2000]);
+	memory_set_bankptr(space->machine, 1, &prgrom[data * 0x2000]);
 }
 
 static READ8_HANDLER( le_4800_r )
@@ -301,7 +298,7 @@ static READ8_HANDLER( le_4800_r )
 				case 0x44:
 				case 0x45:
 				case 0x46:
-					return K053244_r(offset-0x40);
+					return K053244_r(space,offset-0x40);
 					break;
 
 				case 0x80:
@@ -336,24 +333,24 @@ static READ8_HANDLER( le_4800_r )
 				case 0x9d:
 				case 0x9e:
 				case 0x9f:
-					return K054000_r(offset-0x80);
+					return K054000_r(space,offset-0x80);
 					break;
 
 				case 0xca:
-					return sound_status_r(0);
+					return sound_status_r(space,0);
 					break;
 			}
 		}
 		else if (offset < 0x1800)
-			return K053245_r((offset - 0x0800) & 0x07ff);
+			return K053245_r(space,(offset - 0x0800) & 0x07ff);
 		else if (offset < 0x2000)
-			return K056832_ram_code_lo_r(offset - 0x1800);
+			return K056832_ram_code_lo_r(space,offset - 0x1800);
 		else if (offset < 0x2800)
-			return K056832_ram_code_hi_r(offset - 0x2000);
+			return K056832_ram_code_hi_r(space,offset - 0x2000);
 		else if (offset < 0x3000)
-			return K056832_ram_attr_lo_r(offset - 0x2800);
+			return K056832_ram_attr_lo_r(space,offset - 0x2800);
 		else // (offset < 0x3800)
-			return K056832_ram_attr_hi_r(offset - 0x3000);
+			return K056832_ram_attr_hi_r(space,offset - 0x3000);
 	}
 
 	return 0;
@@ -363,7 +360,7 @@ static WRITE8_HANDLER( le_4800_w )
 {
 	if (cur_control2 & 0x10)	// RAM enable
 	{
-		paletteram_xBBBBBGGGGGRRRRR_be_w(offset,data);
+		paletteram_xBBBBBGGGGGRRRRR_be_w(space,offset,data);
 	}
 	else
 	{
@@ -372,11 +369,11 @@ static WRITE8_HANDLER( le_4800_w )
 			switch (offset)
 			{
 				case 0xc6:
-					sound_cmd_w(0, data);
+					sound_cmd_w(space, 0, data);
 					break;
 
 				case 0xc7:
-					sound_irq_w(0, data);
+					sound_irq_w(space, 0, data);
 					break;
 
 				case 0x40:
@@ -386,7 +383,7 @@ static WRITE8_HANDLER( le_4800_w )
 				case 0x44:
 				case 0x45:
 				case 0x46:
-					K053244_w(offset-0x40, data);
+					K053244_w(space, offset-0x40, data);
 					break;
 
 				case 0x80:
@@ -421,34 +418,34 @@ static WRITE8_HANDLER( le_4800_w )
 				case 0x9d:
 				case 0x9e:
 				case 0x9f:
-					K054000_w(offset-0x80, data);
+					K054000_w(space, offset-0x80, data);
 					break;
 
 				default:
-					logerror("Unknown LE 48xx register write: %x to %x (PC=%x)\n", data, offset, activecpu_get_pc());
+					logerror("Unknown LE 48xx register write: %x to %x (PC=%x)\n", data, offset, cpu_get_pc(space->cpu));
 					break;
 			}
 		}
 		else if (offset < 0x1800)
 		{
-			K053245_w((offset - 0x0800) & 0x07ff, data);
+			K053245_w(space, (offset - 0x0800) & 0x07ff, data);
 
 		}
 		else if (offset < 0x2000)
-			K056832_ram_code_lo_w(offset - 0x1800, data);
+			K056832_ram_code_lo_w(space, offset - 0x1800, data);
 		else if (offset < 0x2800)
-			K056832_ram_code_hi_w(offset - 0x2000, data);
+			K056832_ram_code_hi_w(space, offset - 0x2000, data);
 		else if (offset < 0x3000)
-			K056832_ram_attr_lo_w(offset - 0x2800, data);
+			K056832_ram_attr_lo_w(space, offset - 0x2800, data);
 		else // (offset < 0x3800)
-			K056832_ram_attr_hi_w(offset - 0x3000, data);
+			K056832_ram_attr_hi_w(space, offset - 0x3000, data);
 	}
 }
 
 // use one more palette entry for the BG color
 static WRITE8_HANDLER(le_bgcolor_w)
 {
-	paletteram_xBBBBBGGGGGRRRRR_be_w(0x3800+offset, data);
+	paletteram_xBBBBBGGGGGRRRRR_be_w(space,0x3800+offset, data);
 }
 
 static READ8_HANDLER(guns_r)
@@ -456,22 +453,22 @@ static READ8_HANDLER(guns_r)
 	switch (offset)
 	{
 		case 0:
-			return GUNX(2)>>1;
+			return GUNX(1)>>1;
 			break;
 		case 1:
-			if ((240-GUNY(3)) == 7)
+			if ((240-GUNY(1)) == 7)
 				return 0;
 			else
-				return (240-GUNY(3));
+				return (240-GUNY(1));
 			break;
 		case 2:
-			return GUNX(4)>>1;
+			return GUNX(2)>>1;
 			break;
 		case 3:
-			if ((240-GUNY(5)) == 7)
+			if ((240-GUNY(2)) == 7)
 				return 0;
 			else
-				return (240-GUNY(5));
+				return (240-GUNY(2));
 			break;
 	}
 
@@ -482,36 +479,36 @@ static READ8_HANDLER(gunsaux_r)
 {
 	int res = 0;
 
-	if (GUNX(2) & 1) res |= 0x80;
-	if (GUNX(4) & 1) res |= 0x40;
+	if (GUNX(1) & 1) res |= 0x80;
+	if (GUNX(2) & 1) res |= 0x40;
 
 	return res;
 }
 
 static ADDRESS_MAP_START( le_main, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_READ(MRA8_BANK1) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x0000, 0x1fff) AM_READ(SMH_BANK1) AM_WRITE(SMH_ROM)
 	AM_RANGE(0x2000, 0x3fff) AM_RAM				// work RAM
 	AM_RANGE(0x4000, 0x403f) AM_WRITE(K056832_w)
 	AM_RANGE(0x4040, 0x404f) AM_WRITE(K056832_b_w)
-	AM_RANGE(0x4080, 0x4080) AM_READ(MRA8_NOP)		// watchdog
+	AM_RANGE(0x4080, 0x4080) AM_READ(SMH_NOP)		// watchdog
 	AM_RANGE(0x4090, 0x4090) AM_READNOP
 	AM_RANGE(0x40a0, 0x40a0) AM_READNOP
 	AM_RANGE(0x40c4, 0x40c4) AM_WRITE(control2_w)
 	AM_RANGE(0x40c8, 0x40d0) AM_WRITE(lethalen_palette_control)	// PCU1-PCU3 on the schematics
 	AM_RANGE(0x40d4, 0x40d7) AM_READ(guns_r)
-	AM_RANGE(0x40d8, 0x40d8) AM_READ(control2_r)
-	AM_RANGE(0x40d9, 0x40d9) AM_READ(input_port_0_r)
+	AM_RANGE(0x40d8, 0x40d8) AM_READ_PORT("DSW")
+	AM_RANGE(0x40d9, 0x40d9) AM_READ_PORT("INPUTS")
 	AM_RANGE(0x40db, 0x40db) AM_READ(gunsaux_r)		// top X bit of guns
 	AM_RANGE(0x40dc, 0x40dc) AM_WRITE(le_bankswitch_w)
 	AM_RANGE(0x47fe, 0x47ff) AM_WRITE(le_bgcolor_w)		// BG color
 	AM_RANGE(0x4800, 0x7fff) AM_READWRITE(le_4800_r, le_4800_w)	AM_BASE(&paletteram) // bankswitched: RAM and registers
-	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_BANK2) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x8000, 0xffff) AM_READ(SMH_BANK2) AM_WRITE(SMH_ROM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( le_sound, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xefff) AM_ROM
 	AM_RANGE(0xf000, 0xf7ff) AM_RAM
-	AM_RANGE(0xf800, 0xfa2f) AM_READWRITE(K054539_0_r, K054539_0_w)
+	AM_RANGE(0xf800, 0xfa2f) AM_READWRITE(k054539_0_r, k054539_0_w)
 	AM_RANGE(0xfc00, 0xfc00) AM_WRITE(soundlatch2_w)
 	AM_RANGE(0xfc02, 0xfc02) AM_READ(soundlatch_r)
 	AM_RANGE(0xfc03, 0xfc03) AM_READNOP
@@ -520,8 +517,7 @@ ADDRESS_MAP_END
 /* sound */
 
 static INPUT_PORTS_START( lethalen )
-	/* IN 0 */
-	PORT_START
+	PORT_START("INPUTS")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
@@ -531,58 +527,9 @@ static INPUT_PORTS_START( lethalen )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
 
-	/* IN 1 */
-	PORT_START
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
-        PORT_DIPNAME( 0x10, 0x10, DEF_STR(Language) )
-        PORT_DIPSETTING(    0x10, DEF_STR(English) )
-        PORT_DIPSETTING(    0x00, DEF_STR(Spanish) )
-	PORT_DIPNAME( 0x20, 0x00, "Game Type" )
-	PORT_DIPSETTING(    0x20, "Street" )
-	PORT_DIPSETTING(    0x00, "Arcade" )
-	PORT_DIPNAME( 0x40, 0x40, "Coin Mechanism" )
-	PORT_DIPSETTING(    0x40, "Common" )
-	PORT_DIPSETTING(    0x00, "Independent" )
-	PORT_DIPNAME( 0x0080, 0x0080, "Sound Output" )
-	PORT_DIPSETTING(      0x0000, DEF_STR( Mono ) )
-	PORT_DIPSETTING(      0x0080, DEF_STR( Stereo ) )
-
-	/* IN 2 */
-	PORT_START
-	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_X ) PORT_CROSSHAIR(X, 1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(1)
-
-	/* IN 3 */
-	PORT_START
-	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_Y ) PORT_CROSSHAIR(Y, -1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(1)
-
-	/* IN 4 */
-	PORT_START
-	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_X ) PORT_CROSSHAIR(X, 1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(2)
-
-	/* IN 5 */
-	PORT_START
-	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_Y ) PORT_CROSSHAIR(Y, -1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(2)
-INPUT_PORTS_END
-
-static INPUT_PORTS_START( lethalej )
-	/* IN 0 */
-	PORT_START
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_SERVICE_NO_TOGGLE(0x08, IP_ACTIVE_LOW )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
-
-	/* IN 1 */
-	PORT_START
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_START("DSW")
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(eeprom_bit_r, NULL)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SPECIAL )	/* it must be 1 ? */
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_DIPNAME( 0x10, 0x10, DEF_STR(Language) )
@@ -598,42 +545,57 @@ static INPUT_PORTS_START( lethalej )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Mono ) )
 	PORT_DIPSETTING(      0x0080, DEF_STR( Stereo ) )
 
-	/* IN 2 */
-	PORT_START
-	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_X ) PORT_CROSSHAIR(X, -1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(1) PORT_REVERSE
+	PORT_START("LIGHT0_X")
+	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_X ) PORT_CROSSHAIR(X, 1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(1)
 
-	/* IN 3 */
-	PORT_START
+	PORT_START("LIGHT0_Y")
+	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_Y ) PORT_CROSSHAIR(Y, -1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(1)
+
+	PORT_START("LIGHT1_X")
+	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_X ) PORT_CROSSHAIR(X, 1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(2)
+
+	PORT_START("LIGHT1_Y")
+	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_Y ) PORT_CROSSHAIR(Y, -1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(2)
+INPUT_PORTS_END
+
+static INPUT_PORTS_START( lethalej )
+	PORT_INCLUDE( lethalen )
+
+	PORT_MODIFY("LIGHT0_X")
+	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_X ) PORT_CROSSHAIR(X, 1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(1) PORT_REVERSE
+
+	PORT_MODIFY("LIGHT0_Y")
 	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_Y ) PORT_CROSSHAIR(Y, -1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(1) PORT_REVERSE
 
-	/* IN 4 */
-	PORT_START
-	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_X ) PORT_CROSSHAIR(X, -1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(2) PORT_REVERSE
+	PORT_MODIFY("LIGHT1_X")
+	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_X ) PORT_CROSSHAIR(X, 1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(2) PORT_REVERSE
 
-	/* IN 5 */
-	PORT_START
+	PORT_MODIFY("LIGHT1_Y")
 	PORT_BIT( 0xff, 0x80, IPT_LIGHTGUN_Y ) PORT_CROSSHAIR(Y, -1.0, 0.0, 0) PORT_SENSITIVITY(25) PORT_KEYDELTA(15) PORT_PLAYER(2) PORT_REVERSE
 INPUT_PORTS_END
 
-static const struct K054539interface k054539_interface =
+static const k054539_interface k054539_config =
 {
-	REGION_SOUND1,
+	NULL,
 	NULL,
 	sound_nmi
 };
 
 static MACHINE_START( lethalen )
 {
-	state_save_register_global(cur_control2);
+	state_save_register_global(machine, cur_control2);
 }
 
 static MACHINE_RESET( lethalen )
 {
-	UINT8 *prgrom = (UINT8 *)memory_region(REGION_CPU1);
+	UINT8 *prgrom = (UINT8 *)memory_region(machine, "main");
 
-	memory_set_bankptr(1, &prgrom[0x10000]);
-	memory_set_bankptr(2, &prgrom[0x48000]);
+	memory_set_bankptr(machine, 1, &prgrom[0x10000]);
+	memory_set_bankptr(machine, 2, &prgrom[0x48000]);
+	/* force reset again to read proper reset vector */
+	device_reset(machine->cpu[0]);
 }
+
 static const gfx_layout lethal_6bpp =
 {
 	16,16,
@@ -649,21 +611,18 @@ static const gfx_layout lethal_6bpp =
 
 /* we use this decode instead of the one done by the sprite video start due to it being 6bpp */
 static GFXDECODE_START( lethal )
-	GFXDECODE_ENTRY( REGION_GFX2, 0, lethal_6bpp,   0x000/*0x400*/, 256  ) /* sprites tiles */
+	GFXDECODE_ENTRY( "gfx2", 0, lethal_6bpp,   0x000/*0x400*/, 256  ) /* sprites tiles */
 GFXDECODE_END
 
 static MACHINE_DRIVER_START( lethalen )
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", HD6309, MAIN_CLOCK/2)	// ???
+	MDRV_CPU_ADD("main", HD6309, MAIN_CLOCK/2)	// ???
 	MDRV_CPU_PROGRAM_MAP(le_main, 0)
-	MDRV_CPU_VBLANK_INT(lethalen_interrupt, 1)
+	MDRV_CPU_VBLANK_INT("main", lethalen_interrupt)
 
-	MDRV_CPU_ADD_TAG("sound", Z80, 8000000)
+	MDRV_CPU_ADD("sound", Z80, 8000000)
 	MDRV_CPU_PROGRAM_MAP(le_sound, 0)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-
 	MDRV_MACHINE_START(lethalen)
 	MDRV_MACHINE_RESET(lethalen)
 
@@ -672,7 +631,11 @@ static MACHINE_DRIVER_START( lethalen )
 	MDRV_GFXDECODE(lethal)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
+
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(216, 504-1, 16, 240-1)
@@ -685,8 +648,8 @@ static MACHINE_DRIVER_START( lethalen )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(K054539, 48000)
-	MDRV_SOUND_CONFIG(k054539_interface)
+	MDRV_SOUND_ADD("konami", K054539, 48000)
+	MDRV_SOUND_CONFIG(k054539_config)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
@@ -694,209 +657,210 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( lethalej )
 	MDRV_IMPORT_FROM(lethalen)
 
+	MDRV_SCREEN_MODIFY("main")
 	MDRV_SCREEN_VISIBLE_AREA(224, 512-1, 16, 240-1)
 MACHINE_DRIVER_END
 
 ROM_START( lethalen )	// US version UAE
-	ROM_REGION( 0x50000, REGION_CPU1, 0 )
+	ROM_REGION( 0x50000, "main", 0 )
 	/* main program */
 	ROM_LOAD( "191uae01.u4",    0x10000,  0x40000,  CRC(dca340e3) SHA1(8efbba0e3a459bcfe23c75c584bf3a4ce25148bb) )
 
-	ROM_REGION( 0x020000, REGION_CPU2, 0 )
+	ROM_REGION( 0x020000, "sound", 0 )
 	/* Z80 sound program */
 	ROM_LOAD( "191a02.f4", 0x000000, 0x010000, CRC(72b843cc) SHA1(b44b2f039358c26fa792d740639b66a5c8bf78e7) )
 	ROM_RELOAD(         0x010000, 0x010000 )
 
-	ROM_REGION( 0x400000, REGION_GFX1, 0 )
+	ROM_REGION( 0x400000, "gfx1", 0 )
 	/* tilemaps */
 	ROM_LOAD32_WORD( "191a08", 0x000002, 0x100000, CRC(555bd4db) SHA1(d2e55796b4ab2306ae549fa9e7288e41eaa8f3de) )
 	ROM_LOAD32_WORD( "191a10", 0x000000, 0x100000, CRC(2fa9bf51) SHA1(1e4ec56b41dfd8744347a7b5799e3ebce0939adc) )
 	ROM_LOAD32_WORD( "191a07", 0x200002, 0x100000, CRC(1dad184c) SHA1(b2c4a8e48084005056aef2c8eaccb3d2eca71b73) )
 	ROM_LOAD32_WORD( "191a09", 0x200000, 0x100000, CRC(e2028531) SHA1(63ccce7855d829763e9e248a6c3eb6ea89ab17ee) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_ERASE00 )
+	ROM_REGION( 0x400000, "gfx2", ROMREGION_ERASE00 )
 	/* sprites - fake 6bpp decode is done from here */
 	ROM_LOAD( "191a04", 0x000000, 0x100000, CRC(5c3eeb2b) SHA1(33ea8b3968b78806334b5a0aab3a2c24e45c604e) )
 	ROM_LOAD( "191a05", 0x100000, 0x100000, CRC(f2e3b58b) SHA1(0bbc2fe87a4fd00b5073a884bcfebcf9c2c402ad) )
 	ROM_LOAD( "191a06", 0x200000, 0x100000, CRC(ee11fc08) SHA1(ec6dd684e8261b181d65b8bf1b9e97da5c4468f7) )
 
-	ROM_REGION( 0x200000, REGION_GFX3, ROMREGION_ERASE00 )
-	ROM_COPY(REGION_GFX2,0,0, 0x200000)
+	ROM_REGION( 0x200000, "gfx3", ROMREGION_ERASE00 )
+	ROM_COPY("gfx2",0,0, 0x200000)
 
-	ROM_REGION( 0x200000, REGION_GFX4, ROMREGION_ERASE00 )
-	ROM_COPY(REGION_GFX2,0x200000,0, 0x200000)
+	ROM_REGION( 0x200000, "gfx4", ROMREGION_ERASE00 )
+	ROM_COPY("gfx2",0x200000,0, 0x200000)
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "konami", 0 )
 	/* K054539 samples */
 	ROM_LOAD( "191a03", 0x000000, 0x200000, CRC(9b13fbe8) SHA1(19b02dbd9d6da54045b0ba4dfe7b282c72745c9c))
 ROM_END
 
 ROM_START( lethalej )	// Japan version JAD
-	ROM_REGION( 0x50000, REGION_CPU1, 0 )
+	ROM_REGION( 0x50000, "main", 0 )
 	/* main program */
 	ROM_LOAD( "191jad01.u4",    0x10000,  0x40000, CRC(160a25c0) SHA1(1d3ed5a158e461a73c079fe24a8e9d5e2a87e126) )
 
-	ROM_REGION( 0x020000, REGION_CPU2, 0 )
+	ROM_REGION( 0x020000, "sound", 0 )
 	/* Z80 sound program */
 	ROM_LOAD( "191a02.f4", 0x000000, 0x010000, CRC(72b843cc) SHA1(b44b2f039358c26fa792d740639b66a5c8bf78e7) )
 	ROM_RELOAD(         0x010000, 0x010000 )
 
-	ROM_REGION( 0x400000, REGION_GFX1, 0 )
+	ROM_REGION( 0x400000, "gfx1", 0 )
 	/* tilemaps */
 	ROM_LOAD32_WORD( "191a08", 0x000002, 0x100000, CRC(555bd4db) SHA1(d2e55796b4ab2306ae549fa9e7288e41eaa8f3de) )
 	ROM_LOAD32_WORD( "191a10", 0x000000, 0x100000, CRC(2fa9bf51) SHA1(1e4ec56b41dfd8744347a7b5799e3ebce0939adc) )
 	ROM_LOAD32_WORD( "191a07", 0x200002, 0x100000, CRC(1dad184c) SHA1(b2c4a8e48084005056aef2c8eaccb3d2eca71b73) )
 	ROM_LOAD32_WORD( "191a09", 0x200000, 0x100000, CRC(e2028531) SHA1(63ccce7855d829763e9e248a6c3eb6ea89ab17ee) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_ERASE00 )
+	ROM_REGION( 0x400000, "gfx2", ROMREGION_ERASE00 )
 	/* sprites - fake 6bpp decode is done from here */
 	ROM_LOAD( "191a04", 0x000000, 0x100000, CRC(5c3eeb2b) SHA1(33ea8b3968b78806334b5a0aab3a2c24e45c604e) )
 	ROM_LOAD( "191a05", 0x100000, 0x100000, CRC(f2e3b58b) SHA1(0bbc2fe87a4fd00b5073a884bcfebcf9c2c402ad) )
 	ROM_LOAD( "191a06", 0x200000, 0x100000, CRC(ee11fc08) SHA1(ec6dd684e8261b181d65b8bf1b9e97da5c4468f7) )
 
-	ROM_REGION( 0x200000, REGION_GFX3, ROMREGION_ERASE00 )
-	ROM_COPY(REGION_GFX2,0,0, 0x200000)
+	ROM_REGION( 0x200000, "gfx3", ROMREGION_ERASE00 )
+	ROM_COPY("gfx2",0,0, 0x200000)
 
-	ROM_REGION( 0x200000, REGION_GFX4, ROMREGION_ERASE00 )
-	ROM_COPY(REGION_GFX2,0x200000,0, 0x200000)
+	ROM_REGION( 0x200000, "gfx4", ROMREGION_ERASE00 )
+	ROM_COPY("gfx2",0x200000,0, 0x200000)
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "konami", 0 )
 	/* K054539 samples */
 	ROM_LOAD( "191a03", 0x000000, 0x200000, CRC(9b13fbe8) SHA1(19b02dbd9d6da54045b0ba4dfe7b282c72745c9c))
 ROM_END
 
 ROM_START( lethalux )	// US version ?, proto / hack?, very different to other sets
-	ROM_REGION( 0x50000, REGION_CPU1, 0 )
+	ROM_REGION( 0x50000, "main", 0 )
 	/* main program */
 	ROM_LOAD( "191xxx01.u4",    0x10000,  0x40000, CRC(a3b9e790) SHA1(868b422850be129952c8b11c3c4aa730d8ea1544) ) // hacked? fails rom test
 
-	ROM_REGION( 0x020000, REGION_CPU2, 0 )
+	ROM_REGION( 0x020000, "sound", 0 )
 	/* Z80 sound program */
 	ROM_LOAD( "191a02.f4", 0x000000, 0x010000, CRC(72b843cc) SHA1(b44b2f039358c26fa792d740639b66a5c8bf78e7) )
 	ROM_RELOAD(         0x010000, 0x010000 )
 
-	ROM_REGION( 0x400000, REGION_GFX1, 0 )
+	ROM_REGION( 0x400000, "gfx1", 0 )
 	/* tilemaps */
 	ROM_LOAD32_WORD( "191a08", 0x000002, 0x100000, CRC(555bd4db) SHA1(d2e55796b4ab2306ae549fa9e7288e41eaa8f3de) )
 	ROM_LOAD32_WORD( "191a10", 0x000000, 0x100000, CRC(2fa9bf51) SHA1(1e4ec56b41dfd8744347a7b5799e3ebce0939adc) )
 	ROM_LOAD32_WORD( "191a07", 0x200002, 0x100000, CRC(1dad184c) SHA1(b2c4a8e48084005056aef2c8eaccb3d2eca71b73) )
 	ROM_LOAD32_WORD( "191a09", 0x200000, 0x100000, CRC(e2028531) SHA1(63ccce7855d829763e9e248a6c3eb6ea89ab17ee) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_ERASE00 )
+	ROM_REGION( 0x400000, "gfx2", ROMREGION_ERASE00 )
 	/* sprites - fake 6bpp decode is done from here */
 	ROM_LOAD( "191a04", 0x000000, 0x100000, CRC(5c3eeb2b) SHA1(33ea8b3968b78806334b5a0aab3a2c24e45c604e) )
 	ROM_LOAD( "191a05", 0x100000, 0x100000, CRC(f2e3b58b) SHA1(0bbc2fe87a4fd00b5073a884bcfebcf9c2c402ad) )
 	ROM_LOAD( "191a06", 0x200000, 0x100000, CRC(ee11fc08) SHA1(ec6dd684e8261b181d65b8bf1b9e97da5c4468f7) )
 
-	ROM_REGION( 0x200000, REGION_GFX3, ROMREGION_ERASE00 )
-	ROM_COPY(REGION_GFX2,0,0, 0x200000)
+	ROM_REGION( 0x200000, "gfx3", ROMREGION_ERASE00 )
+	ROM_COPY("gfx2",0,0, 0x200000)
 
-	ROM_REGION( 0x200000, REGION_GFX4, ROMREGION_ERASE00 )
-	ROM_COPY(REGION_GFX2,0x200000,0, 0x200000)
+	ROM_REGION( 0x200000, "gfx4", ROMREGION_ERASE00 )
+	ROM_COPY("gfx2",0x200000,0, 0x200000)
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "konami", 0 )
 	/* K054539 samples */
 	ROM_LOAD( "191a03", 0x000000, 0x200000, CRC(9b13fbe8) SHA1(19b02dbd9d6da54045b0ba4dfe7b282c72745c9c))
 ROM_END
 
 ROM_START( letheab )	// Euro ver. EAB
-	ROM_REGION( 0x50000, REGION_CPU1, 0 )
+	ROM_REGION( 0x50000, "main", 0 )
 	/* main program */
 	ROM_LOAD( "191eab01.u4",    0x10000,  0x40000, CRC(d7ce111e) SHA1(e56137a0ba7664f09b5d05bb39ec6eb4d1e412c7) )
 
-	ROM_REGION( 0x020000, REGION_CPU2, 0 )
+	ROM_REGION( 0x020000, "sound", 0 )
 	/* Z80 sound program */
 	ROM_LOAD( "191a02.f4", 0x000000, 0x010000, CRC(72b843cc) SHA1(b44b2f039358c26fa792d740639b66a5c8bf78e7) )
 	ROM_RELOAD(         0x010000, 0x010000 )
 
-	ROM_REGION( 0x400000, REGION_GFX1, 0 )
+	ROM_REGION( 0x400000, "gfx1", 0 )
 	/* tilemaps */
 	ROM_LOAD32_WORD( "191a08", 0x000002, 0x100000, CRC(555bd4db) SHA1(d2e55796b4ab2306ae549fa9e7288e41eaa8f3de) )
 	ROM_LOAD32_WORD( "191a10", 0x000000, 0x100000, CRC(2fa9bf51) SHA1(1e4ec56b41dfd8744347a7b5799e3ebce0939adc) )
 	ROM_LOAD32_WORD( "191a07", 0x200002, 0x100000, CRC(1dad184c) SHA1(b2c4a8e48084005056aef2c8eaccb3d2eca71b73) )
 	ROM_LOAD32_WORD( "191a09", 0x200000, 0x100000, CRC(e2028531) SHA1(63ccce7855d829763e9e248a6c3eb6ea89ab17ee) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_ERASE00 )
+	ROM_REGION( 0x400000, "gfx2", ROMREGION_ERASE00 )
 	/* sprites - fake 6bpp decode is done from here */
 	ROM_LOAD( "191a04", 0x000000, 0x100000, CRC(5c3eeb2b) SHA1(33ea8b3968b78806334b5a0aab3a2c24e45c604e) )
 	ROM_LOAD( "191a05", 0x100000, 0x100000, CRC(f2e3b58b) SHA1(0bbc2fe87a4fd00b5073a884bcfebcf9c2c402ad) )
 	ROM_LOAD( "191a06", 0x200000, 0x100000, CRC(ee11fc08) SHA1(ec6dd684e8261b181d65b8bf1b9e97da5c4468f7) )
 
-	ROM_REGION( 0x200000, REGION_GFX3, ROMREGION_ERASE00 )
-	ROM_COPY(REGION_GFX2,0,0, 0x200000)
+	ROM_REGION( 0x200000, "gfx3", ROMREGION_ERASE00 )
+	ROM_COPY("gfx2",0,0, 0x200000)
 
-	ROM_REGION( 0x200000, REGION_GFX4, ROMREGION_ERASE00 )
-	ROM_COPY(REGION_GFX2,0x200000,0, 0x200000)
+	ROM_REGION( 0x200000, "gfx4", ROMREGION_ERASE00 )
+	ROM_COPY("gfx2",0x200000,0, 0x200000)
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "konami", 0 )
 	/* K054539 samples */
 	ROM_LOAD( "191a03", 0x000000, 0x200000, CRC(9b13fbe8) SHA1(19b02dbd9d6da54045b0ba4dfe7b282c72745c9c))
 ROM_END
 
 ROM_START( letheae )	// Euro ver. EAE
-	ROM_REGION( 0x50000, REGION_CPU1, 0 )
+	ROM_REGION( 0x50000, "main", 0 )
 	/* main program */
 	ROM_LOAD( "191eae01.u4",    0x10000,  0x40000, CRC(c6a3c6ac) SHA1(96a209a3a5b4af40af36bd7090c59a74f8c8df59) )
 
-	ROM_REGION( 0x020000, REGION_CPU2, 0 )
+	ROM_REGION( 0x020000, "sound", 0 )
 	/* Z80 sound program */
 	ROM_LOAD( "191a02.f4", 0x000000, 0x010000, CRC(72b843cc) SHA1(b44b2f039358c26fa792d740639b66a5c8bf78e7) )
 	ROM_RELOAD(         0x010000, 0x010000 )
 
-	ROM_REGION( 0x400000, REGION_GFX1, 0 )
+	ROM_REGION( 0x400000, "gfx1", 0 )
 	/* tilemaps */
 	ROM_LOAD32_WORD( "191a08", 0x000002, 0x100000, CRC(555bd4db) SHA1(d2e55796b4ab2306ae549fa9e7288e41eaa8f3de) )
 	ROM_LOAD32_WORD( "191a10", 0x000000, 0x100000, CRC(2fa9bf51) SHA1(1e4ec56b41dfd8744347a7b5799e3ebce0939adc) )
 	ROM_LOAD32_WORD( "191a07", 0x200002, 0x100000, CRC(1dad184c) SHA1(b2c4a8e48084005056aef2c8eaccb3d2eca71b73) )
 	ROM_LOAD32_WORD( "191a09", 0x200000, 0x100000, CRC(e2028531) SHA1(63ccce7855d829763e9e248a6c3eb6ea89ab17ee) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_ERASE00 )
+	ROM_REGION( 0x400000, "gfx2", ROMREGION_ERASE00 )
 	/* sprites - fake 6bpp decode is done from here */
 	ROM_LOAD( "191a04", 0x000000, 0x100000, CRC(5c3eeb2b) SHA1(33ea8b3968b78806334b5a0aab3a2c24e45c604e) )
 	ROM_LOAD( "191a05", 0x100000, 0x100000, CRC(f2e3b58b) SHA1(0bbc2fe87a4fd00b5073a884bcfebcf9c2c402ad) )
 	ROM_LOAD( "191a06", 0x200000, 0x100000, CRC(ee11fc08) SHA1(ec6dd684e8261b181d65b8bf1b9e97da5c4468f7) )
 
-	ROM_REGION( 0x200000, REGION_GFX3, ROMREGION_ERASE00 )
-	ROM_COPY(REGION_GFX2,0,0, 0x200000)
+	ROM_REGION( 0x200000, "gfx3", ROMREGION_ERASE00 )
+	ROM_COPY("gfx2",0,0, 0x200000)
 
-	ROM_REGION( 0x200000, REGION_GFX4, ROMREGION_ERASE00 )
-	ROM_COPY(REGION_GFX2,0x200000,0, 0x200000)
+	ROM_REGION( 0x200000, "gfx4", ROMREGION_ERASE00 )
+	ROM_COPY("gfx2",0x200000,0, 0x200000)
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "konami", 0 )
 	/* K054539 samples */
 	ROM_LOAD( "191a03", 0x000000, 0x200000, CRC(9b13fbe8) SHA1(19b02dbd9d6da54045b0ba4dfe7b282c72745c9c))
 ROM_END
 
 ROM_START( lethalua )	// *might* be UAA (writes UA to Eeprom)
-	ROM_REGION( 0x50000, REGION_CPU1, 0 )
+	ROM_REGION( 0x50000, "main", 0 )
 	/* main program */
 	ROM_LOAD( "6_usa.u4",    0x10000,  0x40000, CRC(ab6b8f16) SHA1(8de6c429a6e71144270e79d18ad47b5aad13fe04) )
 
-	ROM_REGION( 0x020000, REGION_CPU2, 0 )
+	ROM_REGION( 0x020000, "sound", 0 )
 	/* Z80 sound program */
 	ROM_LOAD( "191a02.f4", 0x000000, 0x010000, CRC(72b843cc) SHA1(b44b2f039358c26fa792d740639b66a5c8bf78e7) )
 	ROM_RELOAD(         0x010000, 0x010000 )
 
-	ROM_REGION( 0x400000, REGION_GFX1, 0 )
+	ROM_REGION( 0x400000, "gfx1", 0 )
 	/* tilemaps */
 	ROM_LOAD32_WORD( "191a08", 0x000002, 0x100000, CRC(555bd4db) SHA1(d2e55796b4ab2306ae549fa9e7288e41eaa8f3de) )
 	ROM_LOAD32_WORD( "191a10", 0x000000, 0x100000, CRC(2fa9bf51) SHA1(1e4ec56b41dfd8744347a7b5799e3ebce0939adc) )
 	ROM_LOAD32_WORD( "191a07", 0x200002, 0x100000, CRC(1dad184c) SHA1(b2c4a8e48084005056aef2c8eaccb3d2eca71b73) )
 	ROM_LOAD32_WORD( "191a09", 0x200000, 0x100000, CRC(e2028531) SHA1(63ccce7855d829763e9e248a6c3eb6ea89ab17ee) )
 
-	ROM_REGION( 0x400000, REGION_GFX2, ROMREGION_ERASE00 )
+	ROM_REGION( 0x400000, "gfx2", ROMREGION_ERASE00 )
 	/* sprites - fake 6bpp decode is done from here */
 	ROM_LOAD( "191a04", 0x000000, 0x100000, CRC(5c3eeb2b) SHA1(33ea8b3968b78806334b5a0aab3a2c24e45c604e) )
 	ROM_LOAD( "191a05", 0x100000, 0x100000, CRC(f2e3b58b) SHA1(0bbc2fe87a4fd00b5073a884bcfebcf9c2c402ad) )
 	ROM_LOAD( "191a06", 0x200000, 0x100000, CRC(ee11fc08) SHA1(ec6dd684e8261b181d65b8bf1b9e97da5c4468f7) )
 
-	ROM_REGION( 0x200000, REGION_GFX3, ROMREGION_ERASE00 )
-	ROM_COPY(REGION_GFX2,0,0, 0x200000)
+	ROM_REGION( 0x200000, "gfx3", ROMREGION_ERASE00 )
+	ROM_COPY("gfx2",0,0, 0x200000)
 
-	ROM_REGION( 0x200000, REGION_GFX4, ROMREGION_ERASE00 )
-	ROM_COPY(REGION_GFX2,0x200000,0, 0x200000)
+	ROM_REGION( 0x200000, "gfx4", ROMREGION_ERASE00 )
+	ROM_COPY("gfx2",0x200000,0, 0x200000)
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "konami", 0 )
 	/* K054539 samples */
 	ROM_LOAD( "191a03", 0x000000, 0x200000, CRC(9b13fbe8) SHA1(19b02dbd9d6da54045b0ba4dfe7b282c72745c9c))
 ROM_END
@@ -905,9 +869,9 @@ ROM_END
 
 static DRIVER_INIT( lethalen )
 {
-	konami_rom_deinterleave_2_half(REGION_GFX2);
-	konami_rom_deinterleave_2(REGION_GFX3);
-	konami_rom_deinterleave_2(REGION_GFX4);
+	konami_rom_deinterleave_2_half(machine, "gfx2");
+	konami_rom_deinterleave_2(machine, "gfx3");
+	konami_rom_deinterleave_2(machine, "gfx4");
 }
 
 GAME( 1992, lethalen, 0,        lethalen, lethalen, lethalen, ORIENTATION_FLIP_Y, "Konami", "Lethal Enforcers (ver UAE, 11/19/92 15:04)", GAME_IMPERFECT_GRAPHICS) // writes UE to eeprom
