@@ -24,31 +24,35 @@
 */
 
 #include "driver.h"
-#include "deprecat.h"
-#include "sound/okim6295.h"
+#include "cpu/e132xs/e132xs.h"
 #include "machine/eeprom.h"
+#include "sound/okim6295.h"
+#include "cpu/mcs51/mcs51.h"
 
 static tilemap *bg_tilemap, *md_tilemap, *fg_tilemap;
 static UINT32 *bg_videoram, *md_videoram, *fg_videoram, *limenko_videoreg;
 
 static UINT32 *mainram;
+static int spriteram_bit;
+
+static bitmap_t *sprites_bitmap;
+static bitmap_t *sprites_bitmap_pri;
+
+static int prev_sprites_count = 0;
+
+static void draw_sprites(running_machine *machine, UINT32 *sprites, const rectangle *cliprect, int count);
 
 /*****************************************************************************************************
   MISC FUNCTIONS
 *****************************************************************************************************/
 
-static READ32_HANDLER( port2_r )
-{
-	return (EEPROM_read_bit() << 23) | (readinputport(2) & ~(1<<23));
-}
-
 static WRITE32_HANDLER( eeprom_w )
 {
 	// data & 0x80000 -> video disabled?
 
-	EEPROM_write_bit(data & 0x40000);
-	EEPROM_set_cs_line((data & 0x10000) ? CLEAR_LINE : ASSERT_LINE );
-	EEPROM_set_clock_line((data & 0x20000) ? ASSERT_LINE : CLEAR_LINE );
+	eeprom_write_bit(data & 0x40000);
+	eeprom_set_cs_line((data & 0x10000) ? CLEAR_LINE : ASSERT_LINE );
+	eeprom_set_clock_line((data & 0x20000) ? ASSERT_LINE : CLEAR_LINE );
 }
 
 static WRITE32_HANDLER( limenko_coincounter_w )
@@ -61,16 +65,16 @@ static WRITE32_HANDLER( limenko_paletteram_w )
 	UINT16 paldata;
 	COMBINE_DATA(&paletteram32[offset]);
 
-	if(ACCESSING_LSW32)
+	if(ACCESSING_BITS_0_15)
 	{
 		paldata = paletteram32[offset] & 0x7fff;
-		palette_set_color_rgb(Machine, offset * 2 + 1, pal5bit(paldata >> 0), pal5bit(paldata >> 5), pal5bit(paldata >> 10));
+		palette_set_color_rgb(space->machine, offset * 2 + 1, pal5bit(paldata >> 0), pal5bit(paldata >> 5), pal5bit(paldata >> 10));
 	}
 
-	if(ACCESSING_MSW32)
+	if(ACCESSING_BITS_16_31)
 	{
 		paldata = (paletteram32[offset] >> 16) & 0x7fff;
-		palette_set_color_rgb(Machine, offset * 2 + 0, pal5bit(paldata >> 0), pal5bit(paldata >> 5), pal5bit(paldata >> 10));
+		palette_set_color_rgb(space->machine, offset * 2 + 0, pal5bit(paldata >> 0), pal5bit(paldata >> 5), pal5bit(paldata >> 10));
 	}
 }
 
@@ -94,7 +98,41 @@ static WRITE32_HANDLER( fg_videoram_w )
 
 static WRITE32_HANDLER( spotty_soundlatch_w )
 {
-	soundlatch_w(0, (data >> 16) & 0xff);
+	soundlatch_w(space, 0, (data >> 16) & 0xff);
+}
+
+static CUSTOM_INPUT( spriteram_bit_r )
+{
+	return spriteram_bit;
+}
+
+static WRITE32_HANDLER( spriteram_buffer_w )
+{
+	rectangle clip;
+	clip.min_x = 0;
+	clip.max_x = 383;
+	clip.min_y = 0;
+	clip.max_y = 239;
+
+	bitmap_fill(sprites_bitmap_pri,&clip,0);
+	bitmap_fill(sprites_bitmap,&clip,0);
+
+	// toggle spriterams location in the memory map
+	spriteram_bit ^= 1;
+
+	if(spriteram_bit)
+	{
+		// draw the sprites to the frame buffer
+		draw_sprites(space->machine,spriteram32_2,&clip,prev_sprites_count);
+	}
+	else
+	{
+		// draw the sprites to the frame buffer
+		draw_sprites(space->machine,spriteram32,&clip,prev_sprites_count);
+	}
+
+	// buffer the next number of sprites to draw
+	prev_sprites_count = (limenko_videoreg[0] & 0x1ff0000) >> 16;
 }
 
 /*****************************************************************************************************
@@ -103,23 +141,23 @@ static WRITE32_HANDLER( spotty_soundlatch_w )
 
 static ADDRESS_MAP_START( limenko_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x00000000, 0x001fffff) AM_RAM	AM_BASE(&mainram)
-	AM_RANGE(0x40000000, 0x403fffff) AM_ROM AM_REGION(REGION_USER2,0)
-	AM_RANGE(0x80000000, 0x80007fff) AM_RAM AM_WRITE(fg_videoram_w) AM_BASE(&fg_videoram)
-	AM_RANGE(0x80008000, 0x8000ffff) AM_RAM AM_WRITE(md_videoram_w) AM_BASE(&md_videoram)
-	AM_RANGE(0x80010000, 0x80017fff) AM_RAM AM_WRITE(bg_videoram_w) AM_BASE(&bg_videoram)
-	AM_RANGE(0x80018000, 0x80018fff) AM_RAM AM_BASE(&spriteram32)
+	AM_RANGE(0x40000000, 0x403fffff) AM_ROM AM_REGION("user2",0)
+	AM_RANGE(0x80000000, 0x80007fff) AM_RAM_WRITE(fg_videoram_w) AM_BASE(&fg_videoram)
+	AM_RANGE(0x80008000, 0x8000ffff) AM_RAM_WRITE(md_videoram_w) AM_BASE(&md_videoram)
+	AM_RANGE(0x80010000, 0x80017fff) AM_RAM_WRITE(bg_videoram_w) AM_BASE(&bg_videoram)
+	AM_RANGE(0x80018000, 0x80018fff) AM_RAM AM_BASE(&spriteram32) AM_SIZE(&spriteram_size)
 	AM_RANGE(0x80019000, 0x80019fff) AM_RAM AM_BASE(&spriteram32_2)
-	AM_RANGE(0x8001c000, 0x8001dfff) AM_RAM AM_WRITE(limenko_paletteram_w) AM_BASE(&paletteram32)
+	AM_RANGE(0x8001c000, 0x8001dfff) AM_RAM_WRITE(limenko_paletteram_w) AM_BASE(&paletteram32)
 	AM_RANGE(0x8001e000, 0x8001ebff) AM_RAM // ? not used
 	AM_RANGE(0x8001ffec, 0x8001ffff) AM_RAM AM_BASE(&limenko_videoreg)
-	AM_RANGE(0x8003e000, 0x8003e003) AM_WRITENOP // video reg? background pen?
-	AM_RANGE(0xffe00000, 0xffffffff) AM_ROM AM_REGION(REGION_USER1,0)
+	AM_RANGE(0x8003e000, 0x8003e003) AM_WRITE(spriteram_buffer_w)
+	AM_RANGE(0xffe00000, 0xffffffff) AM_ROM AM_REGION("user1",0)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( limenko_io_map, ADDRESS_SPACE_IO, 32 )
-	AM_RANGE(0x0000, 0x0003) AM_READ(input_port_0_dword_r)
-	AM_RANGE(0x0800, 0x0803) AM_READ(input_port_1_dword_r)
-	AM_RANGE(0x1000, 0x1003) AM_READ(port2_r)
+	AM_RANGE(0x0000, 0x0003) AM_READ_PORT("IN0")
+	AM_RANGE(0x0800, 0x0803) AM_READ_PORT("IN1")
+	AM_RANGE(0x1000, 0x1003) AM_READ_PORT("IN2")
 	AM_RANGE(0x4000, 0x4003) AM_WRITE(limenko_coincounter_w)
 	AM_RANGE(0x4800, 0x4803) AM_WRITE(eeprom_w)
 	AM_RANGE(0x5000, 0x5003) AM_WRITENOP // sound latch
@@ -131,36 +169,51 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( spotty_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x00000000, 0x001fffff) AM_RAM	AM_BASE(&mainram)
 	AM_RANGE(0x40002000, 0x400024d3) AM_RAM //?
-	AM_RANGE(0x80000000, 0x80007fff) AM_RAM AM_WRITE(fg_videoram_w) AM_BASE(&fg_videoram)
-	AM_RANGE(0x80008000, 0x8000ffff) AM_RAM AM_WRITE(md_videoram_w) AM_BASE(&md_videoram)
-	AM_RANGE(0x80010000, 0x80017fff) AM_RAM AM_WRITE(bg_videoram_w) AM_BASE(&bg_videoram)
-	AM_RANGE(0x80018000, 0x80018fff) AM_RAM AM_BASE(&spriteram32)
+	AM_RANGE(0x80000000, 0x80007fff) AM_RAM_WRITE(fg_videoram_w) AM_BASE(&fg_videoram)
+	AM_RANGE(0x80008000, 0x8000ffff) AM_RAM_WRITE(md_videoram_w) AM_BASE(&md_videoram)
+	AM_RANGE(0x80010000, 0x80017fff) AM_RAM_WRITE(bg_videoram_w) AM_BASE(&bg_videoram)
+	AM_RANGE(0x80018000, 0x80018fff) AM_RAM AM_BASE(&spriteram32) AM_SIZE(&spriteram_size)
 	AM_RANGE(0x80019000, 0x80019fff) AM_RAM AM_BASE(&spriteram32_2)
-	AM_RANGE(0x8001c000, 0x8001dfff) AM_RAM AM_WRITE(limenko_paletteram_w) AM_BASE(&paletteram32)
+	AM_RANGE(0x8001c000, 0x8001dfff) AM_RAM_WRITE(limenko_paletteram_w) AM_BASE(&paletteram32)
 	AM_RANGE(0x8001e000, 0x8001ebff) AM_RAM // ? not used
 	AM_RANGE(0x8001ffec, 0x8001ffff) AM_RAM AM_BASE(&limenko_videoreg)
-	AM_RANGE(0x8003e000, 0x8003e003) AM_WRITENOP // video reg? background pen?
-	AM_RANGE(0xfff00000, 0xffffffff) AM_ROM AM_REGION(REGION_USER1,0)
+	AM_RANGE(0x8003e000, 0x8003e003) AM_WRITE(spriteram_buffer_w)
+	AM_RANGE(0xfff00000, 0xffffffff) AM_ROM AM_REGION("user1",0)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( spotty_io_map, ADDRESS_SPACE_IO, 32 )
-	AM_RANGE(0x0000, 0x0003) AM_READ(input_port_0_dword_r)
-	AM_RANGE(0x0800, 0x0803) AM_READ(input_port_1_dword_r)
+	AM_RANGE(0x0000, 0x0003) AM_READ_PORT("IN0")
+	AM_RANGE(0x0800, 0x0803) AM_READ_PORT("IN1")
 	AM_RANGE(0x0800, 0x0803) AM_WRITENOP // hopper related
-	AM_RANGE(0x1000, 0x1003) AM_READ(port2_r)
+	AM_RANGE(0x1000, 0x1003) AM_READ_PORT("IN2")
 	AM_RANGE(0x4800, 0x4803) AM_WRITE(eeprom_w)
 	AM_RANGE(0x5000, 0x5003) AM_WRITE(spotty_soundlatch_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( spotty_sound_prg_map, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x0fff) AM_ROM
-ADDRESS_MAP_END
+static UINT8 spotty_sound_cmd=0;
+static WRITE8_HANDLER( spotty_sound_cmd_w )
+{
+	spotty_sound_cmd = data;
+}
+
+static READ8_HANDLER( spotty_sound_cmd_r )
+{
+	return 0; //??? some status bit? if set it executes a jump in the code
+}
+
+static READ8_HANDLER( spotty_sound_r )
+{
+	// check spotty_sound_cmd bits...
+
+	if(spotty_sound_cmd == 0xf7)
+		return soundlatch_r(space,0);
+	else
+		return okim6295_status_0_r(space,0);
+}
 
 static ADDRESS_MAP_START( spotty_sound_io_map, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x0001, 0x0001) AM_READ(soundlatch_r)
-	AM_RANGE(0x0003, 0x0003) AM_READ(OKIM6295_status_0_r)
-	AM_RANGE(0x0001, 0x0001) AM_WRITE(OKIM6295_data_0_w)
-	AM_RANGE(0x0003, 0x0003) AM_WRITENOP
+	AM_RANGE(MCS51_PORT_P1, MCS51_PORT_P1) AM_READWRITE(spotty_sound_r, okim6295_data_0_w) //? sound latch and ?
+	AM_RANGE(MCS51_PORT_P3, MCS51_PORT_P3) AM_READWRITE(spotty_sound_cmd_r, spotty_sound_cmd_w) //not sure about anything...
 ADDRESS_MAP_END
 
 /*****************************************************************************************************
@@ -188,41 +241,147 @@ static TILE_GET_INFO( get_fg_tile_info )
 	SET_TILE_INFO(0,tile,color,0);
 }
 
+static void draw_single_sprite(bitmap_t *dest_bmp,const gfx_element *gfx,
+		UINT32 code,UINT32 color,int flipx,int flipy,int sx,int sy,
+		const rectangle *clip,int priority)
+{
+	int pal_base = gfx->color_base + gfx->color_granularity * (color % gfx->total_colors);
+	UINT8 *source_base = gfx->gfxdata + (code % gfx->total_elements) * gfx->char_modulo;
+
+	int sprite_screen_height = ((1<<16)*gfx->height+0x8000)>>16;
+	int sprite_screen_width = ((1<<16)*gfx->width+0x8000)>>16;
+
+	if (sprite_screen_width && sprite_screen_height)
+	{
+		/* compute sprite increment per screen pixel */
+		int dx = (gfx->width<<16)/sprite_screen_width;
+		int dy = (gfx->height<<16)/sprite_screen_height;
+
+		int ex = sx+sprite_screen_width;
+		int ey = sy+sprite_screen_height;
+
+		int x_index_base;
+		int y_index;
+
+		if( flipx )
+		{
+			x_index_base = (sprite_screen_width-1)*dx;
+			dx = -dx;
+		}
+		else
+		{
+			x_index_base = 0;
+		}
+
+		if( flipy )
+		{
+			y_index = (sprite_screen_height-1)*dy;
+			dy = -dy;
+		}
+		else
+		{
+			y_index = 0;
+		}
+
+		if( clip )
+		{
+			if( sx < clip->min_x)
+			{ /* clip left */
+				int pixels = clip->min_x-sx;
+				sx += pixels;
+				x_index_base += pixels*dx;
+			}
+			if( sy < clip->min_y )
+			{ /* clip top */
+				int pixels = clip->min_y-sy;
+				sy += pixels;
+				y_index += pixels*dy;
+			}
+			/* NS 980211 - fixed incorrect clipping */
+			if( ex > clip->max_x+1 )
+			{ /* clip right */
+				int pixels = ex-clip->max_x-1;
+				ex -= pixels;
+			}
+			if( ey > clip->max_y+1 )
+			{ /* clip bottom */
+				int pixels = ey-clip->max_y-1;
+				ey -= pixels;
+			}
+		}
+
+		if( ex>sx )
+		{ /* skip if inner loop doesn't draw anything */
+			int y;
+
+			for( y=sy; y<ey; y++ )
+			{
+				UINT8 *source = source_base + (y_index>>16) * gfx->line_modulo;
+				UINT16 *dest = BITMAP_ADDR16(dest_bmp, y, 0);
+				UINT8 *pri = BITMAP_ADDR8(sprites_bitmap_pri, y, 0);
+
+				int x, x_index = x_index_base;
+				for( x=sx; x<ex; x++ )
+				{
+					int c = source[x_index>>16];
+					if( c != 0 )
+					{
+						if (pri[x]<priority)
+							dest[x] = pal_base+c;
+
+						pri[x] = priority;
+
+					}
+					x_index += dx;
+				}
+
+				y_index += dy;
+			}
+		}
+	}
+}
+
 // sprites aren't tile based (except for 8x8 ones)
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine *machine, UINT32 *sprites, const rectangle *cliprect, int count)
 {
 	int i;
-	int sprites_on_screen = (limenko_videoreg[0] & 0x1ff0000) >> 16;
 
-	UINT8 *base_gfx	= memory_region(REGION_GFX1);
-	UINT8 *gfx_max	= base_gfx + memory_region_length(REGION_GFX1);
+	UINT8 *base_gfx	= memory_region(machine, "gfx1");
+	UINT8 *gfx_max	= base_gfx + memory_region_length(machine, "gfx1");
 
 	UINT8 *gfxdata;
 	gfx_element gfx;
 
-	for(i = 0; i <= sprites_on_screen*2; i += 2)
+	for(i = 0; i <= count*2; i += 2)
 	{
 		int x, width, flipx, y, height, flipy, code, color, pri;
 
-		if(~spriteram32[i] & 0x80000000) continue;
+		if(~sprites[i] & 0x80000000) continue;
 
-		x = ((spriteram32[i] & 0x1ff0000) >> 16) - 1;
-		width = (((spriteram32[i] & 0xe000000) >> 25) + 1) * 8;
-		flipx = spriteram32[i] & 0x10000000;
-		y = (spriteram32[i] & 0x1ff) + 1;
-		height = (((spriteram32[i] & 0xe00) >> 9) + 1) * 8;
-		flipy = spriteram32[i] & 0x1000;
-		code = spriteram32[i + 1] & 0x7ffff;
-		color = (spriteram32[i + 1] & 0xf0000000) >> 28;
+		x = ((sprites[i] & 0x1ff0000) >> 16);
+		width = (((sprites[i] & 0xe000000) >> 25) + 1) * 8;
+		flipx = sprites[i] & 0x10000000;
+		y = sprites[i] & 0x1ff;
+		height = (((sprites[i] & 0xe00) >> 9) + 1) * 8;
+		flipy = sprites[i] & 0x1000;
+		code = sprites[i + 1] & 0x7ffff;
+		color = (sprites[i + 1] & 0xf0000000) >> 28;
 
-		if(spriteram32[i + 1] & 0x04000000)
-			pri = 0xfffe; // below fg
+		if(sprites[i + 1] & 0x04000000)
+		{
+			// below fg
+			pri = 1;
+		}
 		else
-			pri = 0; // above everything
+		{
+			// above everything
+			pri = 2;
+		}
 
-		gfxdata	= base_gfx + (64*8/8) * code;
+		gfxdata	= base_gfx + 64 * code;
 
 		/* prepare GfxElement on the fly */
+		gfx.machine = machine;
 		gfx.width = width;
 		gfx.height = height;
 		gfx.total_elements = 1;
@@ -240,52 +399,59 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 		if ( (gfxdata + width * height - 1) >= gfx_max )
 			continue;
 
-		pdrawgfx(bitmap,&gfx,
-				 0,
-				 color,
-				 flipx,flipy,
-				 x,y,
-				 cliprect,TRANSPARENCY_PEN,0,pri);
-
-		// wrap around y
-		pdrawgfx(bitmap,&gfx,
-				 0,
-				 color,
-				 flipx,flipy,
-				 x,y - 512,
-				 cliprect,TRANSPARENCY_PEN,0,pri);
+		draw_single_sprite(sprites_bitmap,&gfx,0,color,flipx,flipy,x,y,cliprect,pri);
 
 		// wrap around x
-		pdrawgfx(bitmap,&gfx,
-				 0,
-				 color,
-				 flipx,flipy,
-				 x - 512,y,
-				 cliprect,TRANSPARENCY_PEN,0,pri);
+		draw_single_sprite(sprites_bitmap,&gfx,0,color,flipx,flipy,x-512,y,cliprect,pri);
+
+		// wrap around y
+		draw_single_sprite(sprites_bitmap,&gfx,0,color,flipx,flipy,x,y-512,cliprect,pri);
 
 		// wrap around x and y
-		pdrawgfx(bitmap,&gfx,
-				 0,
-				 color,
-				 flipx,flipy,
-				 x - 512,y - 512,
-				 cliprect,TRANSPARENCY_PEN,0,pri);
+		draw_single_sprite(sprites_bitmap,&gfx,0,color,flipx,flipy,x-512,y-512,cliprect,pri);
+	}
+}
+
+static void copy_sprites(running_machine *machine, bitmap_t *bitmap, bitmap_t *sprites_bitmap, const rectangle *cliprect)
+{
+	int y;
+	for( y=cliprect->min_y; y<=cliprect->max_y; y++ )
+	{
+		UINT16 *source = BITMAP_ADDR16(sprites_bitmap, y, 0);
+		UINT16 *dest = BITMAP_ADDR16(bitmap, y, 0);
+		UINT8 *dest_pri = BITMAP_ADDR8(priority_bitmap, y, 0);
+		UINT8 *source_pri = BITMAP_ADDR8(sprites_bitmap_pri, y, 0);
+
+		int x;
+		for( x=cliprect->min_x; x<=cliprect->max_x; x++ )
+		{
+			if( source[x]!= 0 )
+			{
+				if(dest_pri[x] < source_pri[x])
+					dest[x] = source[x];
+			}
+		}
 	}
 }
 
 static VIDEO_START( limenko )
 {
-	bg_tilemap = tilemap_create(get_bg_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,     8,8,128,64);
-	md_tilemap = tilemap_create(get_md_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,128,64);
-	fg_tilemap = tilemap_create(get_fg_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,128,64);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info,tilemap_scan_rows,8,8,128,64);
+	md_tilemap = tilemap_create(machine, get_md_tile_info,tilemap_scan_rows,8,8,128,64);
+	fg_tilemap = tilemap_create(machine, get_fg_tile_info,tilemap_scan_rows,8,8,128,64);
 
 	tilemap_set_transparent_pen(md_tilemap,0);
 	tilemap_set_transparent_pen(fg_tilemap,0);
+
+	sprites_bitmap     = auto_bitmap_alloc(384,240,BITMAP_FORMAT_INDEXED16);
+	sprites_bitmap_pri = auto_bitmap_alloc(384,240,BITMAP_FORMAT_INDEXED8);
 }
 
 static VIDEO_UPDATE( limenko )
 {
-	fillbitmap(priority_bitmap,0,cliprect);
+	// limenko_videoreg[4] ???? It always has this value: 0xffeffff8 (2 signed bytes? values: -17 and -8 ?)
+
+	bitmap_fill(priority_bitmap,cliprect,0);
 
 	tilemap_set_enable(bg_tilemap, limenko_videoreg[0] & 4);
 	tilemap_set_enable(md_tilemap, limenko_videoreg[0] & 2);
@@ -304,7 +470,7 @@ static VIDEO_UPDATE( limenko )
 	tilemap_draw(bitmap,cliprect,fg_tilemap,0,1);
 
 	if(limenko_videoreg[0] & 8)
-		draw_sprites(machine, bitmap, cliprect);
+		copy_sprites(screen->machine, bitmap, sprites_bitmap, cliprect);
 
 	return 0;
 }
@@ -314,7 +480,7 @@ static VIDEO_UPDATE( limenko )
 *****************************************************************************************************/
 
 static INPUT_PORTS_START( legendoh )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )    PORT_PLAYER(1)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )  PORT_PLAYER(1)
 	PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT )  PORT_PLAYER(1)
@@ -333,7 +499,7 @@ static INPUT_PORTS_START( legendoh )
 	PORT_BIT( 0x80000000, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(3)
 	PORT_BIT( 0x0000ffff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )    PORT_PLAYER(2)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )  PORT_PLAYER(2)
 	PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT )  PORT_PLAYER(2)
@@ -352,7 +518,7 @@ static INPUT_PORTS_START( legendoh )
 	PORT_BIT( 0x80000000, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(4)
 	PORT_BIT( 0x0000ffff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_COIN1 )
@@ -360,7 +526,7 @@ static INPUT_PORTS_START( legendoh )
 	PORT_BIT( 0x00100000, IP_ACTIVE_LOW, IPT_SERVICE1 )
 	PORT_SERVICE_NO_TOGGLE( 0x00200000, IP_ACTIVE_LOW )
 	PORT_BIT( 0x00400000, IP_ACTIVE_HIGH, IPT_SPECIAL ) //security bit
-	PORT_BIT( 0x00800000, IP_ACTIVE_LOW, IPT_SPECIAL ) //eeprom
+	PORT_BIT( 0x00800000, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(eeprom_bit_r, NULL) //eeprom
 	PORT_BIT( 0x01000000, IP_ACTIVE_LOW, IPT_START3 )
 	PORT_BIT( 0x02000000, IP_ACTIVE_LOW, IPT_START4 )
 	PORT_BIT( 0x04000000, IP_ACTIVE_LOW, IPT_COIN3 )
@@ -369,12 +535,12 @@ static INPUT_PORTS_START( legendoh )
 	PORT_DIPNAME( 0x20000000, 0x00000000, "Sound Enable" )
 	PORT_DIPSETTING(          0x20000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(          0x00000000, DEF_STR( On ) )
-	PORT_BIT( 0x80000000, IP_ACTIVE_HIGH, IPT_SPECIAL ) //changes spriteram location, pointing to spriteram32_2
+	PORT_BIT( 0x80000000, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(spriteram_bit_r, NULL) //changes spriteram location
 	PORT_BIT( 0x4000ffff, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( sb2003 )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )    PORT_PLAYER(1)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )  PORT_PLAYER(1)
 	PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT )  PORT_PLAYER(1)
@@ -385,7 +551,7 @@ static INPUT_PORTS_START( sb2003 )
 	PORT_BIT( 0x00800000, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(1)
 	PORT_BIT( 0xff00ffff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )    PORT_PLAYER(2)
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )  PORT_PLAYER(2)
 	PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT )  PORT_PLAYER(2)
@@ -396,23 +562,23 @@ static INPUT_PORTS_START( sb2003 )
 	PORT_BIT( 0x00800000, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(2)
 	PORT_BIT( 0xff00ffff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x00080000, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_SERVICE_NO_TOGGLE( 0x00200000, IP_ACTIVE_LOW )
 	PORT_BIT( 0x00400000, IP_ACTIVE_LOW, IPT_SPECIAL ) //security bit
-	PORT_BIT( 0x00800000, IP_ACTIVE_LOW, IPT_SPECIAL ) //eeprom
+	PORT_BIT( 0x00800000, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(eeprom_bit_r, NULL) //eeprom
 	PORT_DIPNAME( 0x20000000, 0x00000000, "Sound Enable" )
 	PORT_DIPSETTING(          0x20000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(          0x00000000, DEF_STR( On ) )
-	PORT_BIT( 0x80000000, IP_ACTIVE_LOW, IPT_SPECIAL ) //changes spriteram location, pointing to spriteram32_2
+	PORT_BIT( 0x80000000, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(spriteram_bit_r, NULL) //changes spriteram location
 	PORT_BIT( 0x5f10ffff, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( spotty )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )    PORT_NAME("Hold 1")
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )  PORT_NAME("Hold 2")
 	PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT )  PORT_NAME("Hold 3")
@@ -423,7 +589,7 @@ static INPUT_PORTS_START( spotty )
 	PORT_BIT( 0x00800000, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0xff00ffff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_UNUSED )
@@ -434,14 +600,14 @@ static INPUT_PORTS_START( spotty )
 	PORT_BIT( 0x00800000, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0xff00ffff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x00080000, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00080000, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(spriteram_bit_r, NULL) //changes spriteram location
 	PORT_SERVICE_NO_TOGGLE( 0x00200000, IP_ACTIVE_LOW )
-	PORT_BIT( 0x00400000, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x00800000, IP_ACTIVE_LOW, IPT_SPECIAL ) //eeprom
+	PORT_BIT( 0x00400000, IP_ACTIVE_LOW, IPT_SPECIAL ) //security bit
+	PORT_BIT( 0x00800000, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(eeprom_bit_r, NULL) //eeprom
 	PORT_DIPNAME( 0x20000000, 0x20000000, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(          0x00000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(          0x20000000, DEF_STR( On ) )
@@ -466,7 +632,7 @@ static const gfx_layout tile_layout =
 };
 
 static GFXDECODE_START( limenko )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, tile_layout, 0, 16 ) /* tiles */
+	GFXDECODE_ENTRY( "gfx1", 0, tile_layout, 0, 16 ) /* tiles */
 GFXDECODE_END
 
 
@@ -476,18 +642,17 @@ GFXDECODE_END
 
 
 static MACHINE_DRIVER_START( limenko )
-	MDRV_CPU_ADD(E132XN, 20000000*4)	/* 4x internal multiplier */
+	MDRV_CPU_ADD("main", E132XN, 20000000*4)	/* 4x internal multiplier */
 	MDRV_CPU_PROGRAM_MAP(limenko_map,0)
 	MDRV_CPU_IO_MAP(limenko_io_map,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold, 1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
 	MDRV_NVRAM_HANDLER(93C46)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(384, 240)
 	MDRV_SCREEN_VISIBLE_AREA(0, 383, 0, 239)
@@ -502,23 +667,20 @@ static MACHINE_DRIVER_START( limenko )
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( spotty )
-	MDRV_CPU_ADD(GMS30C2232, 20000000)	/* 20 MHz, no internal multiplier */
+	MDRV_CPU_ADD("main", GMS30C2232, 20000000)	/* 20 MHz, no internal multiplier */
 	MDRV_CPU_PROGRAM_MAP(spotty_map,0)
 	MDRV_CPU_IO_MAP(spotty_io_map,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold, 1)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
-	MDRV_CPU_ADD(I8051, 4000000)	/* 4 MHz */
-	MDRV_CPU_PROGRAM_MAP(spotty_sound_prg_map, 0)
-	MDRV_CPU_DATA_MAP(0, 0)
+	MDRV_CPU_ADD("audio", AT89C4051, 4000000)	/* 4 MHz */
 	MDRV_CPU_IO_MAP(spotty_sound_io_map,0)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-
 	MDRV_NVRAM_HANDLER(93C46)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(384, 240)
 	MDRV_SCREEN_VISIBLE_AREA(0, 383, 0, 239)
@@ -532,8 +694,8 @@ static MACHINE_DRIVER_START( spotty )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(OKIM6295, 4000000 / 4 ) //?
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high) // not verified
+	MDRV_SOUND_ADD("oki", OKIM6295, 4000000 / 4 ) //?
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // not verified
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -575,75 +737,75 @@ Notes:
 */
 
 ROM_START( dynabomb )
-	ROM_REGION32_BE( 0x200000, REGION_USER1, 0 ) /* Hyperstone CPU Code */
+	ROM_REGION32_BE( 0x200000, "user1", 0 ) /* Hyperstone CPU Code */
 	ROM_LOAD16_WORD_SWAP( "rom.u6", 0x000000, 0x200000, CRC(457e015d) SHA1(3afb56cdf903c9084c1f283dc50ec504ce3e199f) )
 
-	ROM_REGION32_BE( 0x400000, REGION_USER2, ROMREGION_ERASEFF )
+	ROM_REGION32_BE( 0x400000, "user2", ROMREGION_ERASEFF )
 	ROM_LOAD16_WORD_SWAP( "rom.u5", 0x000000, 0x200000, CRC(7e837adf) SHA1(8613fa187b8d4574b3935aa439aec2515033d64c) )
 
-	ROM_REGION( 0x220000, REGION_CPU2, 0 ) /* sound cpu + data */
+	ROM_REGION( 0x220000, "cpu1", 0 ) /* sound cpu + data */
 	ROM_LOAD( "rom.u16", 0x000000, 0x020000, CRC(f66d7e4d) SHA1(44f1851405ba525f1ed53521f4de12545ea9c46a) )
 	ROM_LOAD( "rom.u17", 0x020000, 0x080000, CRC(20f2417c) SHA1(1bdc0b03215f5002eed4c25d670bbb5411189907) )
 	ROM_LOAD( "rom.u18", 0x020000, 0x080000, CRC(50d76732) SHA1(6179c7365b62df620a10a1253d524807408821de) )
 	// u19 empty
 
-	ROM_REGION( 0x800000, REGION_GFX1, 0 )
+	ROM_REGION( 0x800000, "gfx1", 0 )
 	ROM_LOAD32_BYTE( "rom.u1", 0x000000, 0x200000, CRC(bf33eff6) SHA1(089b6d88d6d744bcfa036c6869f0444d6ceb26c9) )
 	ROM_LOAD32_BYTE( "rom.u2", 0x000001, 0x200000, CRC(790bbcd5) SHA1(fc52c15fffc77dc3b3bc89a9606223c4fbaa578c) )
 	ROM_LOAD32_BYTE( "rom.u3", 0x000002, 0x200000, CRC(ec094b12) SHA1(13c105df066ff308cc7e1842907644790946e5b5) )
 	ROM_LOAD32_BYTE( "rom.u4", 0x000003, 0x200000, CRC(88b24e3c) SHA1(5f267f08144b413b55ef5e15c52e9cda096b80e7) )
 
-	ROM_REGION( 0x200000, REGION_SOUND2, 0 ) /* QDSP wavetable rom */
+	ROM_REGION( 0x200000, "wavetable", 0 ) /* QDSP wavetable rom */
 	ROM_LOAD( "qs1003.u4",    0x000000, 0x200000, CRC(19e4b469) SHA1(9460e5b6a0fbf3fdd6a9fa0dcbf5062a2e07fe02) )
 
 	// u20 empty
 ROM_END
 
 ROM_START( sb2003 ) /* No specific Country/Region */
-	ROM_REGION32_BE( 0x200000, REGION_USER1, 0 ) /* Hyperstone CPU Code */
+	ROM_REGION32_BE( 0x200000, "user1", 0 ) /* Hyperstone CPU Code */
 	ROM_LOAD16_WORD_SWAP( "sb2003_05.u6", 0x00000000, 0x200000, CRC(8aec4554) SHA1(57a12b142eb7bf08dd1e78d3c79222001bbaa636) )
 
-	ROM_REGION32_BE( 0x400000, REGION_USER2, ROMREGION_ERASEFF )
+	ROM_REGION32_BE( 0x400000, "user2", ROMREGION_ERASEFF )
 	// u5 empty
 
-	ROM_REGION( 0x220000, REGION_CPU2, 0 ) /* sound cpu + data */
+	ROM_REGION( 0x220000, "cpu1", 0 ) /* sound cpu + data */
 	ROM_LOAD( "07.u16", 0x000000, 0x020000, CRC(78acc607) SHA1(30a1aed40d45233dce88c6114989c71aa0f99ff7) )
 	// u17 empty
 	ROM_LOAD( "06.u18", 0x020000, 0x200000, CRC(b6ad0d32) SHA1(33e73963ea25e131801dc11f25be6ab18bef03ed) )
 	// u19 empty
 
-	ROM_REGION( 0x800000, REGION_GFX1, 0 )
+	ROM_REGION( 0x800000, "gfx1", 0 )
 	ROM_LOAD32_BYTE( "01.u1", 0x000000, 0x200000, CRC(d2c7091a) SHA1(deff050eb0aee89f60d5ad13053e4f1bd4d35961) )
 	ROM_LOAD32_BYTE( "02.u2", 0x000001, 0x200000, CRC(a0734195) SHA1(8947f351434e2f750c4bdf936238815baaeb8402) )
 	ROM_LOAD32_BYTE( "03.u3", 0x000002, 0x200000, CRC(0f020280) SHA1(2c10baec8dbb201ee5e1c4c9d6b962e2ed02df7d) )
 	ROM_LOAD32_BYTE( "04.u4", 0x000003, 0x200000, CRC(fc2222b9) SHA1(c7ee8cffbbee1673a9f107f3f163d029c3900230) )
 
-	ROM_REGION( 0x200000, REGION_SOUND2, 0 ) /* QDSP wavetable rom */
+	ROM_REGION( 0x200000, "wavetable", 0 ) /* QDSP wavetable rom */
 	ROM_LOAD( "qs1003.u4",    0x000000, 0x200000, CRC(19e4b469) SHA1(9460e5b6a0fbf3fdd6a9fa0dcbf5062a2e07fe02) )
 
 	// u20 (S-ROM) empty
 ROM_END
 
 ROM_START( sb2003a ) /* Asia Region */
-	ROM_REGION32_BE( 0x200000, REGION_USER1, 0 ) /* Hyperstone CPU Code */
+	ROM_REGION32_BE( 0x200000, "user1", 0 ) /* Hyperstone CPU Code */
 	ROM_LOAD16_WORD_SWAP( "sb2003a_05.u6", 0x000000, 0x200000, CRC(265e45a7) SHA1(b9c8b63aa89c08f3d9d404621e301b122f85389a) )
 
-	ROM_REGION32_BE( 0x400000, REGION_USER2, ROMREGION_ERASEFF )
+	ROM_REGION32_BE( 0x400000, "user2", ROMREGION_ERASEFF )
 	// u5 empty
 
-	ROM_REGION( 0x220000, REGION_CPU2, 0 ) /* sound cpu + data */
+	ROM_REGION( 0x220000, "cpu1", 0 ) /* sound cpu + data */
 	ROM_LOAD( "07.u16", 0x000000, 0x020000, CRC(78acc607) SHA1(30a1aed40d45233dce88c6114989c71aa0f99ff7) )
 	// u17 empty
 	ROM_LOAD( "06.u18", 0x020000, 0x200000, CRC(b6ad0d32) SHA1(33e73963ea25e131801dc11f25be6ab18bef03ed) )
 	// u19 empty
 
-	ROM_REGION( 0x800000, REGION_GFX1, 0 )
+	ROM_REGION( 0x800000, "gfx1", 0 )
 	ROM_LOAD32_BYTE( "01.u1", 0x000000, 0x200000, CRC(d2c7091a) SHA1(deff050eb0aee89f60d5ad13053e4f1bd4d35961) )
 	ROM_LOAD32_BYTE( "02.u2", 0x000001, 0x200000, CRC(a0734195) SHA1(8947f351434e2f750c4bdf936238815baaeb8402) )
 	ROM_LOAD32_BYTE( "03.u3", 0x000002, 0x200000, CRC(0f020280) SHA1(2c10baec8dbb201ee5e1c4c9d6b962e2ed02df7d) )
 	ROM_LOAD32_BYTE( "04.u4", 0x000003, 0x200000, CRC(fc2222b9) SHA1(c7ee8cffbbee1673a9f107f3f163d029c3900230) )
 
-	ROM_REGION( 0x200000, REGION_SOUND2, 0 ) /* QDSP wavetable rom */
+	ROM_REGION( 0x200000, "wavetable", 0 ) /* QDSP wavetable rom */
 	ROM_LOAD( "qs1003.u4",    0x000000, 0x200000, CRC(19e4b469) SHA1(9460e5b6a0fbf3fdd6a9fa0dcbf5062a2e07fe02) )
 
 	// u20 (S-ROM) empty
@@ -722,19 +884,19 @@ Link up 2 cabinets, up to 4 players can play at a time as a team
 */
 
 ROM_START( legendoh )
-	ROM_REGION32_BE( 0x200000, REGION_USER1, ROMREGION_ERASEFF ) /* Hyperstone CPU Code */
+	ROM_REGION32_BE( 0x200000, "user1", ROMREGION_ERASEFF ) /* Hyperstone CPU Code */
 	/* sys_rom1 empty */
 	/* sys_rom2 empty */
 	/* sys_rom3 empty */
 	ROM_LOAD16_WORD_SWAP( "01.sys_rom4", 0x180000, 0x80000, CRC(49b4a91f) SHA1(21619e8cd0b2fba8c2e08158497575a1760f52c5) )
 
-	ROM_REGION32_BE( 0x400000, REGION_USER2, 0 )
+	ROM_REGION32_BE( 0x400000, "user2", 0 )
 	ROM_LOAD16_WORD_SWAP( "sys_rom6", 0x000000, 0x200000, CRC(5c13d467) SHA1(ed07b7e1b22293e256787ab079d00c2fb070bf4f) )
 	ROM_LOAD16_WORD_SWAP( "sys_rom5", 0x200000, 0x200000, CRC(19dc8d23) SHA1(433687c6aa24b9456436eecb1dcb57814af3009d) )
 	/* sys_rom8 empty */
 	/* sys_rom7 empty */
 
-	ROM_REGION( 0x1200000, REGION_GFX1, 0 )
+	ROM_REGION( 0x1200000, "gfx1", 0 )
 	ROM_LOAD32_BYTE( "cg_rom10",     0x0000000, 0x200000, CRC(93a48489) SHA1(a14157d31b4e9c8eb7ebe1b2f1b707ec8c8561a0) )
 	ROM_LOAD32_BYTE( "cg_rom20",     0x0000001, 0x200000, CRC(1a6c0258) SHA1(ac7c3b8c2fdfb542103032144a30293d44759fd1) )
 	ROM_LOAD32_BYTE( "cg_rom30",     0x0000002, 0x200000, CRC(a0559ef4) SHA1(6622f7107b374c9da816b9814fe93347e7422190) )
@@ -748,12 +910,12 @@ ROM_START( legendoh )
 	ROM_LOAD32_BYTE( "04.cg_rom32",  0x1000002, 0x080000, CRC(3f486cab) SHA1(6507d4bb9b4aa7d43f1026e932c82629d4fa44dd) )
 	ROM_LOAD32_BYTE( "05.cg_rom42",  0x1000003, 0x080000, CRC(5d807bec) SHA1(c72c77ed0478f705018519cf68a54d22524d05fd) )
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 ) /* sounds */
+	ROM_REGION( 0x200000, "sfx", 0 ) /* sounds */
 	ROM_LOAD( "sou_prg.06",   0x000000, 0x80000, CRC(bfafe7aa) SHA1(3e65869fe0970bafb59a0225642834042fdedfa6) )
 	ROM_LOAD( "sou_rom.07",   0x000000, 0x80000, CRC(4c6eb6d2) SHA1(58bced7bd944e03b0e3dfe1107c01819a33b2b31) )
 	ROM_LOAD( "sou_rom.08",   0x000000, 0x80000, CRC(42c32dd5) SHA1(4702771288ba40119de63feb67eed85667235d81) )
 
-	ROM_REGION( 0x200000, REGION_SOUND2, 0 ) /* QDSP wavetable rom */
+	ROM_REGION( 0x200000, "wavetable", 0 ) /* QDSP wavetable rom */
 	ROM_LOAD( "qs1003.u4",    0x000000, 0x200000, CRC(19e4b469) SHA1(9460e5b6a0fbf3fdd6a9fa0dcbf5062a2e07fe02) )
 ROM_END
 
@@ -784,22 +946,22 @@ SW2 = Reset
 */
 
 ROM_START( spotty )
-	ROM_REGION32_BE( 0x100000, REGION_USER1, ROMREGION_ERASEFF ) /* Hyperstone CPU Code */
+	ROM_REGION32_BE( 0x100000, "user1", ROMREGION_ERASEFF ) /* Hyperstone CPU Code */
 	/* sys_rom1 empty */
 	ROM_LOAD16_WORD_SWAP( "sys_rom2",     0x080000, 0x80000, CRC(6ded8d9b) SHA1(547c532f4014d818c4412244b60dbc439496de20) )
 
-	ROM_REGION( 0x01000, REGION_CPU2, 0 )
+	ROM_REGION( 0x01000, "audio", 0 )
 	ROM_LOAD( "at89c4051.mcu", 0x000000, 0x01000, CRC(82ceab26) SHA1(9bbc454bdcbc70dc01f10a13c9fc01c884918fe8) )
 
 	/* Expand the gfx roms here */
-	ROM_REGION( 0x200000, REGION_GFX1, ROMREGION_ERASE00 )
+	ROM_REGION( 0x200000, "gfx1", ROMREGION_ERASE00 )
 
-	ROM_REGION( 0x200000, REGION_USER2, ROMREGION_ERASE00 )
+	ROM_REGION( 0x200000, "user2", ROMREGION_ERASE00 )
 	ROM_LOAD32_BYTE( "gc_rom1",      0x000000, 0x80000, CRC(ea03f9c5) SHA1(5038c03c519c774da253f9ae4fa205e7eeaa2780) )
 	ROM_LOAD32_BYTE( "gc_rom3",      0x000001, 0x80000, CRC(0ddac0b9) SHA1(f4ac8e6dd7f1cbdeb97139008982e6c17a3d18b9) )
 	/* gc_rom2 empty */
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x40000, "oki", 0 )
 	ROM_LOAD( "sou_rom1",     0x000000, 0x40000, CRC(5791195b) SHA1(de0df8f89f395cbf3508b01aeea05675e110ad04) )
 ROM_END
 
@@ -807,9 +969,9 @@ ROM_END
 
 static READ32_HANDLER( dynabomb_speedup_r )
 {
-	if(activecpu_get_pc() == 0xc25b8)
+	if(cpu_get_pc(space->cpu) == 0xc25b8)
 	{
-		activecpu_eat_cycles(50);
+		cpu_eat_cycles(space->cpu, 50);
 	}
 
 	return mainram[0xe2784/4];
@@ -817,9 +979,9 @@ static READ32_HANDLER( dynabomb_speedup_r )
 
 static READ32_HANDLER( legendoh_speedup_r )
 {
-	if(activecpu_get_pc() == 0x23e32)
+	if(cpu_get_pc(space->cpu) == 0x23e32)
 	{
-		activecpu_eat_cycles(50);
+		cpu_eat_cycles(space->cpu, 50);
 	}
 
 	return mainram[0x32ab0/4];
@@ -827,9 +989,9 @@ static READ32_HANDLER( legendoh_speedup_r )
 
 static READ32_HANDLER( sb2003_speedup_r )
 {
-	if(activecpu_get_pc() == 0x26da4)
+	if(cpu_get_pc(space->cpu) == 0x26da4)
 	{
-		activecpu_eat_cycles(50);
+		cpu_eat_cycles(space->cpu, 50);
 	}
 
 	return mainram[0x135800/4];
@@ -837,9 +999,9 @@ static READ32_HANDLER( sb2003_speedup_r )
 
 static READ32_HANDLER( spotty_speedup_r )
 {
-	if(activecpu_get_pc() == 0x8560)
+	if(cpu_get_pc(space->cpu) == 0x8560)
 	{
-		activecpu_eat_cycles(50);
+		cpu_eat_cycles(space->cpu, 50);
 	}
 
 	return mainram[0x6626c/4];
@@ -847,23 +1009,29 @@ static READ32_HANDLER( spotty_speedup_r )
 
 static DRIVER_INIT( dynabomb )
 {
-	memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0xe2784, 0xe2787, 0, 0, dynabomb_speedup_r );
+	memory_install_read32_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xe2784, 0xe2787, 0, 0, dynabomb_speedup_r );
+
+	spriteram_bit = 1;
 }
 
 static DRIVER_INIT( legendoh )
 {
-	memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0x32ab0, 0x32ab3, 0, 0, legendoh_speedup_r );
+	memory_install_read32_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x32ab0, 0x32ab3, 0, 0, legendoh_speedup_r );
+
+	spriteram_bit = 1;
 }
 
 static DRIVER_INIT( sb2003 )
 {
-	memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0x135800, 0x135803, 0, 0, sb2003_speedup_r );
+	memory_install_read32_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x135800, 0x135803, 0, 0, sb2003_speedup_r );
+
+	spriteram_bit = 1;
 }
 
 static DRIVER_INIT( spotty )
 {
-	UINT8 *dst    = memory_region(REGION_GFX1);
-	UINT8 *src    = memory_region(REGION_USER2);
+	UINT8 *dst    = memory_region(machine, "gfx1");
+	UINT8 *src    = memory_region(machine, "user2");
 	int x;
 
 	/* expand 4bpp roms to 8bpp space */
@@ -875,7 +1043,9 @@ static DRIVER_INIT( spotty )
 		dst[x+2] = (src[x+1]&0x0f) >> 0;
 	}
 
-	memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, 0x6626c, 0x6626f, 0, 0, spotty_speedup_r );
+	memory_install_read32_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x6626c, 0x6626f, 0, 0, spotty_speedup_r );
+
+	spriteram_bit = 1;
 }
 
 GAME( 2000, dynabomb, 0,      limenko, sb2003,   dynabomb, ROT0, "Limenko", "Dynamite Bomber (Korea, Rev 1.5)",   GAME_NO_SOUND )
@@ -884,4 +1054,4 @@ GAME( 2003, sb2003,   0,      limenko, sb2003,   sb2003,   ROT0, "Limenko", "Sup
 GAME( 2003, sb2003a,  sb2003, limenko, sb2003,   sb2003,   ROT0, "Limenko", "Super Bubble 2003 (Asia, Ver 1.0)",  GAME_NO_SOUND )
 
 // this game only use the same graphics chip used in limenko's system
-GAME( 2001, spotty,   0,      spotty,  spotty,   spotty,   ROT0, "Prince Co.", "Spotty (Ver. 2.0.2)",              GAME_IMPERFECT_GRAPHICS | GAME_NO_SOUND )
+GAME( 2001, spotty,   0,      spotty,  spotty,   spotty,   ROT0, "Prince Co.", "Spotty (Ver. 2.0.2)",             GAME_NO_SOUND )
