@@ -10,7 +10,8 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
+#include "cpu/nec/nec.h"
 #include "sound/2203intf.h"
 #include "sound/flt_vol.h"
 #include "lockon.h"
@@ -65,93 +66,72 @@ static WRITE16_HANDLER( adrst_w )
 	lockon_ctrl_reg = data & 0xff;
 
 	/* Bus mastering for shared access */
-	cpunum_set_input_line(Machine, GROUND_CPU, INPUT_LINE_HALT, data & 0x04 ? ASSERT_LINE : CLEAR_LINE);
-	cpunum_set_input_line(Machine, OBJECT_CPU, INPUT_LINE_HALT, data & 0x20 ? ASSERT_LINE : CLEAR_LINE);
-	cpunum_set_input_line(Machine, SOUND_CPU,  INPUT_LINE_HALT, data & 0x40 ? CLEAR_LINE : ASSERT_LINE);
+	cpu_set_input_line(space->machine->cpu[GROUND_CPU], INPUT_LINE_HALT, data & 0x04 ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[OBJECT_CPU], INPUT_LINE_HALT, data & 0x20 ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[SOUND_CPU],  INPUT_LINE_HALT, data & 0x40 ? CLEAR_LINE : ASSERT_LINE);
 }
 
 static READ16_HANDLER( main_gnd_r )
 {
-	UINT16 result;
-
-	cpuintrf_push_context(GROUND_CPU);
-	result = program_read_word(V30_GND_ADDR | offset * 2);
-	cpuintrf_pop_context();
-
-	return result;
+	const address_space *gndspace = cpu_get_address_space(space->machine->cpu[GROUND_CPU], ADDRESS_SPACE_PROGRAM);
+	return memory_read_word(gndspace, V30_GND_ADDR | offset * 2);
 }
 
 static WRITE16_HANDLER( main_gnd_w )
 {
-	cpuintrf_push_context(GROUND_CPU);
+	const address_space *gndspace = cpu_get_address_space(space->machine->cpu[GROUND_CPU], ADDRESS_SPACE_PROGRAM);
 
-	if (ACCESSING_LSB)
-		program_write_byte(V30_GND_ADDR | (offset * 2 + 0), data);
-	if (ACCESSING_MSB)
-		program_write_byte(V30_GND_ADDR | (offset * 2 + 1), data >> 8);
-
-	cpuintrf_pop_context();
+	if (ACCESSING_BITS_0_7)
+		memory_write_byte(gndspace, V30_GND_ADDR | (offset * 2 + 0), data);
+	if (ACCESSING_BITS_8_15)
+		memory_write_byte(gndspace, V30_GND_ADDR | (offset * 2 + 1), data >> 8);
 }
 
 static READ16_HANDLER( main_obj_r )
 {
-	UINT16 result;
-
-	cpuintrf_push_context(OBJECT_CPU);
-	result = program_read_word(V30_OBJ_ADDR | offset * 2);
-	cpuintrf_pop_context();
-
-	return result;
+	const address_space *objspace = cpu_get_address_space(space->machine->cpu[OBJECT_CPU], ADDRESS_SPACE_PROGRAM);
+	return memory_read_word(objspace, V30_OBJ_ADDR | offset * 2);
 }
 
 static WRITE16_HANDLER( main_obj_w )
 {
-	cpuintrf_push_context(OBJECT_CPU);
+	const address_space *objspace = cpu_get_address_space(space->machine->cpu[OBJECT_CPU], ADDRESS_SPACE_PROGRAM);
 
-	if (ACCESSING_LSB)
-		program_write_byte(V30_OBJ_ADDR | (offset * 2 + 0), data);
-	if (ACCESSING_MSB)
-		program_write_byte(V30_OBJ_ADDR | (offset * 2 + 1), data >> 8);
-
-	cpuintrf_pop_context();
+	if (ACCESSING_BITS_0_7)
+		memory_write_byte(objspace, V30_OBJ_ADDR | (offset * 2 + 0), data);
+	if (ACCESSING_BITS_8_15)
+		memory_write_byte(objspace, V30_OBJ_ADDR | (offset * 2 + 1), data >> 8);
 }
 
 static WRITE16_HANDLER( tst_w )
 {
 	if (offset < 0x800)
 	{
-		cpuintrf_push_context(GROUND_CPU);
-		if (ACCESSING_LSB)
-			program_write_byte(V30_GND_ADDR | (offset * 2 + 0), data);
-		if (ACCESSING_MSB)
-			program_write_byte(V30_GND_ADDR | (offset * 2 + 1), data >> 8);
-		cpuintrf_pop_context();
+		const address_space *gndspace = cpu_get_address_space(space->machine->cpu[GROUND_CPU], ADDRESS_SPACE_PROGRAM);
+		const address_space *objspace = cpu_get_address_space(space->machine->cpu[OBJECT_CPU], ADDRESS_SPACE_PROGRAM);
 
-		cpuintrf_push_context(OBJECT_CPU);
-		if (ACCESSING_LSB)
-			program_write_byte(V30_OBJ_ADDR | (offset * 2 + 0), data);
-		if (ACCESSING_MSB)
-			program_write_byte(V30_OBJ_ADDR | (offset * 2 + 1), data >> 8);
-		cpuintrf_pop_context();
+		if (ACCESSING_BITS_0_7)
+			memory_write_byte(gndspace, V30_GND_ADDR | (offset * 2 + 0), data);
+		if (ACCESSING_BITS_8_15)
+			memory_write_byte(gndspace, V30_GND_ADDR | (offset * 2 + 1), data >> 8);
+
+		if (ACCESSING_BITS_0_7)
+			memory_write_byte(objspace, V30_OBJ_ADDR | (offset * 2 + 0), data);
+		if (ACCESSING_BITS_8_15)
+			memory_write_byte(objspace, V30_OBJ_ADDR | (offset * 2 + 1), data >> 8);
 	}
 }
 
 static READ16_HANDLER( main_z80_r )
 {
-	UINT16 val;
-
-	cpuintrf_push_context(SOUND_CPU);
-	val = program_read_byte(offset);
-	cpuintrf_pop_context();
-
-	return 0xff00 | val;
+	const address_space *sndspace = cpu_get_address_space(space->machine->cpu[SOUND_CPU], ADDRESS_SPACE_PROGRAM);
+	return 0xff00 | memory_read_byte(sndspace, offset);
 }
 
 static WRITE16_HANDLER( main_z80_w )
 {
-	cpuintrf_push_context(SOUND_CPU);
-	program_write_byte(offset, data);
-	cpuintrf_pop_context();
+	const address_space *sndspace = cpu_get_address_space(space->machine->cpu[SOUND_CPU], ADDRESS_SPACE_PROGRAM);
+	memory_write_byte(sndspace, offset, data);
 }
 
 static WRITE16_HANDLER( inten_w )
@@ -161,7 +141,7 @@ static WRITE16_HANDLER( inten_w )
 
 static WRITE16_HANDLER( emres_w )
 {
-	watchdog_reset_r(0);
+	watchdog_reset(space->machine);
 	lockon_main_inten = 0;
 }
 
@@ -173,18 +153,18 @@ static WRITE16_HANDLER( emres_w )
  *************************************/
 
 static ADDRESS_MAP_START( main_v30, ADDRESS_SPACE_PROGRAM, 16 )
-	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) )
+	ADDRESS_MAP_UNMAP_HIGH
 	AM_RANGE(0x00000, 0x03fff) AM_RAM
 	AM_RANGE(0x04000, 0x04003) AM_READWRITE(lockon_crtc_r, lockon_crtc_w)
-	AM_RANGE(0x06000, 0x06001) AM_READ(input_port_0_word_r)
+	AM_RANGE(0x06000, 0x06001) AM_READ_PORT("DSW")
 	AM_RANGE(0x08000, 0x081ff) AM_RAM AM_BASE(&lockon_hud_ram) AM_SIZE(&lockon_hudram_size)
-	AM_RANGE(0x09000, 0x09fff) AM_READWRITE(MRA16_RAM, lockon_char_w) AM_BASE(&lockon_char_ram)
+	AM_RANGE(0x09000, 0x09fff) AM_RAM_WRITE(lockon_char_w) AM_BASE(&lockon_char_ram)
 	AM_RANGE(0x0a000, 0x0a001) AM_WRITE(adrst_w)
 	AM_RANGE(0x0b000, 0x0bfff) AM_WRITE(lockon_rotate_w)
 	AM_RANGE(0x0c000, 0x0cfff) AM_WRITE(lockon_fb_clut_w)
 	AM_RANGE(0x0e000, 0x0e001) AM_WRITE(inten_w)
 	AM_RANGE(0x0f000, 0x0f001) AM_WRITE(emres_w)
-	AM_RANGE(0x10000, 0x1ffff) AM_READWRITE(MRA16_NOP, tst_w)
+	AM_RANGE(0x10000, 0x1ffff) AM_READWRITE(SMH_NOP, tst_w)
 	AM_RANGE(0x20000, 0x2ffff) AM_READWRITE(main_z80_r, main_z80_w)
 	AM_RANGE(0x30000, 0x3ffff) AM_READWRITE(main_gnd_r, main_gnd_w)
 	AM_RANGE(0x40000, 0x4ffff) AM_READWRITE(main_obj_r, main_obj_w)
@@ -195,7 +175,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( ground_v30, ADDRESS_SPACE_PROGRAM, 16 )
-	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) )
+	ADDRESS_MAP_UNMAP_HIGH
 	AM_RANGE(0x00000, 0x03fff) AM_RAM
 	AM_RANGE(0x04000, 0x04fff) AM_RAM AM_BASE(&lockon_scene_ram)
 	AM_RANGE(0x08000, 0x08fff) AM_RAM AM_BASE(&lockon_ground_ram) AM_SIZE(&lockon_groundram_size)
@@ -208,7 +188,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( object_v30, ADDRESS_SPACE_PROGRAM, 16 )
-	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) )
+	ADDRESS_MAP_UNMAP_HIGH
 	AM_RANGE(0x00000, 0x03fff) AM_RAM
 	AM_RANGE(0x04000, 0x04001) AM_READWRITE(lockon_obj_4000_r, lockon_obj_4000_w)
 	AM_RANGE(0x08000, 0x08fff) AM_WRITE(lockon_tza112_w)
@@ -218,17 +198,17 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( sound_prg, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_UNMAP(1) )
+	ADDRESS_MAP_UNMAP_HIGH
 	AM_RANGE(0x0000, 0x6fff) AM_ROM
 	AM_RANGE(0x7000, 0x7000) AM_WRITE(sound_vol)
-	AM_RANGE(0x7400, 0x7403) AM_READWRITE(adc_r, MWA8_NOP)
+	AM_RANGE(0x7400, 0x7403) AM_READWRITE(adc_r, SMH_NOP)
 	AM_RANGE(0x7800, 0x7fff) AM_MIRROR(0x8000) AM_RAM
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_io, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x00, 0x00) AM_READWRITE(YM2203_status_port_0_r, YM2203_control_port_0_w)
-	AM_RANGE(0x01, 0x01) AM_READWRITE(YM2203_read_port_0_r, YM2203_write_port_0_w)
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x00, 0x00) AM_READWRITE(ym2203_status_port_0_r, ym2203_control_port_0_w)
+	AM_RANGE(0x01, 0x01) AM_READWRITE(ym2203_read_port_0_r, ym2203_write_port_0_w)
 	AM_RANGE(0x02, 0x02) AM_NOP
 ADDRESS_MAP_END
 
@@ -240,7 +220,7 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( lockon )
-	PORT_START_TAG("DSW")
+	PORT_START("DSW")
 	/* DSW 1 - verified on PCB as a 8 position dipswitch block */
 	PORT_DIPNAME( 0x0003, 0x0000, DEF_STR( Lives ) ) PORT_DIPLOCATION("SW1:1,2")
 	PORT_DIPSETTING(      0x0001, "2" )
@@ -297,7 +277,7 @@ static INPUT_PORTS_START( lockon )
 	PORT_DIPSETTING(      0x4000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 
-PORT_START_TAG("YM2203")
+	PORT_START("YM2203")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN3 )
@@ -311,13 +291,16 @@ PORT_START_TAG("YM2203")
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-PORT_START_TAG("ADC_BANK")
+	PORT_START("ADC_BANK")
 	PORT_BIT( 0xff, 0x7f, IPT_AD_STICK_X ) PORT_MINMAX(0,0xff) PORT_SENSITIVITY(25) PORT_KEYDELTA(15)
-PORT_START_TAG("ADC_PITCH")
+
+	PORT_START("ADC_PITCH")
 	PORT_BIT( 0xff, 0x7f, IPT_AD_STICK_Y ) PORT_MINMAX(0,0xff) PORT_SENSITIVITY(25) PORT_KEYDELTA(15)
-PORT_START_TAG("ADC_MISSILE")
+
+	PORT_START("ADC_MISSILE")
 	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_BUTTON3 )
-PORT_START_TAG("ADC_HOVER")
+
+	PORT_START("ADC_HOVER")
 	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_BUTTON4 )
 INPUT_PORTS_END
 
@@ -359,10 +342,10 @@ static READ8_HANDLER( adc_r )
 {
 	switch (offset)
 	{
-		case 0:  return readinputportbytag("ADC_BANK");
-		case 1:  return readinputportbytag("ADC_PITCH");
-		case 2:  return readinputportbytag("ADC_MISSILE");
-		case 3:  return readinputportbytag("ADC_HOVER");
+		case 0:  return input_port_read(space->machine, "ADC_BANK");
+		case 1:  return input_port_read(space->machine, "ADC_PITCH");
+		case 2:  return input_port_read(space->machine, "ADC_MISSILE");
+		case 3:  return input_port_read(space->machine, "ADC_HOVER");
 		default: return 0;
 	}
 }
@@ -385,7 +368,7 @@ static const gfx_layout char_layout =
 };
 
 static GFXDECODE_START( lockon )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, char_layout,  0, 128 )
+	GFXDECODE_ENTRY( "gfx1", 0, char_layout,  0, 128 )
 GFXDECODE_END
 
 
@@ -441,9 +424,9 @@ static WRITE8_HANDLER( sound_vol )
 	flt_volume_set_volume(5, rgain);
 }
 
-static void ym2203_irq(int irq)
+static void ym2203_irq(running_machine *machine, int irq)
 {
-	cpunum_set_input_line(Machine, SOUND_CPU, 0, irq ? ASSERT_LINE : CLEAR_LINE );
+	cpu_set_input_line(machine->cpu[SOUND_CPU], 0, irq ? ASSERT_LINE : CLEAR_LINE );
 }
 
 static WRITE8_HANDLER( ym2203_out_b )
@@ -456,12 +439,16 @@ static WRITE8_HANDLER( ym2203_out_b )
 	set_led_status(1, !(data & 0x10));
 }
 
-static const struct YM2203interface ym2203_interface =
+static const ym2203_interface ym2203_config =
 {
-	input_port_1_r,
-	0,
-	0,
-	ym2203_out_b,
+	{
+		AY8910_LEGACY_OUTPUT,
+		AY8910_DEFAULT_LOADS,
+		input_port_1_r,
+		NULL,
+		NULL,
+		ym2203_out_b,
+	},
 	ym2203_irq
 };
 
@@ -473,23 +460,25 @@ static const struct YM2203interface ym2203_interface =
  *************************************/
 
 static MACHINE_DRIVER_START( lockon )
-	MDRV_CPU_ADD(V30, XTAL_16MHz / 2)
+	MDRV_CPU_ADD("main", V30, XTAL_16MHz / 2)
 	MDRV_CPU_PROGRAM_MAP(main_v30, 0)
 
-	MDRV_CPU_ADD(V30, XTAL_16MHz / 2)
+	MDRV_CPU_ADD("ground", V30, XTAL_16MHz / 2)
 	MDRV_CPU_PROGRAM_MAP(ground_v30, 0)
 
-	MDRV_CPU_ADD(V30, XTAL_16MHz / 2)
+	MDRV_CPU_ADD("object", V30, XTAL_16MHz / 2)
 	MDRV_CPU_PROGRAM_MAP(object_v30, 0)
 
-	MDRV_CPU_ADD(Z80, XTAL_16MHz / 4)
+	MDRV_CPU_ADD("audio", Z80, XTAL_16MHz / 4)
 	MDRV_CPU_PROGRAM_MAP(sound_prg, 0)
 	MDRV_CPU_IO_MAP(sound_io, 0)
 
-	MDRV_WATCHDOG_TIME_INIT(attotime_mul(PERIOD_OF_555_ASTABLE(10000, 4700, 10000e-12), 4096))
-	MDRV_INTERLEAVE(10)
+	MDRV_WATCHDOG_TIME_INIT(NSEC(PERIOD_OF_555_ASTABLE_NSEC(10000, 4700, 10000e-12) * 4096))
+	MDRV_QUANTUM_TIME(HZ(600))
 
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_UPDATE_AFTER_VBLANK)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_AFTER_VBLANK)
+
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_RAW_PARAMS(PIXEL_CLOCK, HTOTAL, HBEND, HBSTART, VTOTAL, VBEND, VBSTART)
 
@@ -503,8 +492,8 @@ static MACHINE_DRIVER_START( lockon )
 
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(YM2203, XTAL_16MHz / 4)
-	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ADD("ym", YM2203, XTAL_16MHz / 4)
+	MDRV_SOUND_CONFIG(ym2203_config)
 	MDRV_SOUND_ROUTE(0, "left", 0.40)
 	MDRV_SOUND_ROUTE(0, "right", 0.40)
 	MDRV_SOUND_ROUTE(1, "f2203.1l", 1.0)
@@ -514,17 +503,17 @@ static MACHINE_DRIVER_START( lockon )
 	MDRV_SOUND_ROUTE(3, "f2203.3l", 1.0)
 	MDRV_SOUND_ROUTE(3, "f2203.3r", 1.0)
 
-	MDRV_SOUND_ADD_TAG("f2203.1l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ADD("f2203.1l", FILTER_VOLUME, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
-	MDRV_SOUND_ADD_TAG("f2203.1r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ADD("f2203.1r", FILTER_VOLUME, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
-	MDRV_SOUND_ADD_TAG("f2203.2l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ADD("f2203.2l", FILTER_VOLUME, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
-	MDRV_SOUND_ADD_TAG("f2203.2r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ADD("f2203.2r", FILTER_VOLUME, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
-	MDRV_SOUND_ADD_TAG("f2203.3l", FILTER_VOLUME, 0)
+	MDRV_SOUND_ADD("f2203.3l", FILTER_VOLUME, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
-	MDRV_SOUND_ADD_TAG("f2203.3r", FILTER_VOLUME, 0)
+	MDRV_SOUND_ADD("f2203.3r", FILTER_VOLUME, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
 
@@ -538,7 +527,7 @@ MACHINE_DRIVER_END
 
 ROM_START( lockon )
 	/* TF012 V30 (Main) */
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, "main", 0 )
 	ROM_LOAD16_BYTE( "lo1_02c.89", 0x60000, 0x8000, CRC(bbf17263) SHA1(96821a0ecd6efe6764380fef094f87c1d6e1d299) )
 	ROM_LOAD16_BYTE( "lo1_03c.88", 0x60001, 0x8000, CRC(fa58fd36) SHA1(16af24027610bf6d3fdc4c3df3bf6d94c6776420) )
 
@@ -549,39 +538,39 @@ ROM_START( lockon )
 	ROM_LOAD16_BYTE( "lo1_01e.95", 0x70001, 0x8000, CRC(03f0391d) SHA1(53795eab8f1b33c86a72d2f0f1cbcf7faab0011b) )
 
 	/* TF013 V30 (Ground) */
-	ROM_REGION( 0x100000, REGION_CPU2, 0 )
+	ROM_REGION( 0x100000, "ground", 0 )
 	ROM_LOAD16_BYTE( "lo3_01a.30", 0x20000, 0x8000, CRC(3eacdb6b) SHA1(7934c36dac9253dec4d8910954f6f2ae85951fe9) )
 	ROM_LOAD16_BYTE( "lo3_03a.33", 0x20001, 0x8000, CRC(4ce96d71) SHA1(cedbc33e86a93d11d5e11c2ef18bcf6390790a88) )
 	ROM_LOAD16_BYTE( "lo3_00b.29", 0x30000, 0x8000, CRC(1835dccb) SHA1(8dfb0fea61a3e61f4da3b7f0da02cd19df2e68be) )
 	ROM_LOAD16_BYTE( "lo3_02b.32", 0x30001, 0x8000, CRC(2b8931d3) SHA1(f6f40b7857f3d47da8626450b1c1d3c46a1072ab) )
 
 	/* TF014 V30 (Object)  */
-	ROM_REGION( 0x100000, REGION_CPU3, 0 )
+	ROM_REGION( 0x100000, "object", 0 )
 	ROM_LOAD16_BYTE( "lo4_00b", 0x30000, 0x8000, CRC(5f6b5a50) SHA1(daf82cafcae86d05587c191b0ff194ca7950e130) )
 	ROM_LOAD16_BYTE( "lo4_01b", 0x30001, 0x8000, CRC(7e88bcf2) SHA1(d541458ba6178ec3bce0e9b872b9fa1d8edb107c) )
 
 	/* TF014 Z80 (Sound) */
-	ROM_REGION( 0x10000, REGION_CPU4, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "lo1_08b.24", 0x00000, 0x8000, CRC(73860ec9) SHA1(a94afa274321b9f9ac2184e133132f9829fb9485) )
 
 	/* 8x8x2 characters */
-	ROM_REGION( 0x4000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x4000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "lo1_07a", 0x00000, 0x2000, CRC(73673b79) SHA1(246b80f0c465cefb7ce1c87dc90a58f0f0ea3e0d) )
 	ROM_LOAD( "lo1_06a", 0x02000, 0x2000, CRC(c8205913) SHA1(c791ff14418873ce68b502440c3d7ccc1f9cc00e) )
 
 	/* 8x8x3 scene tiles and CLUT */
-	ROM_REGION( 0x40000, REGION_GFX2, 0 )
+	ROM_REGION( 0x40000, "gfx2", 0 )
 	ROM_LOAD( "lo3_12a.120", 0x00000, 0x10000, CRC(a34262a7) SHA1(08204a4474ab1b07b9114da8af03442737922d3b) )
 	ROM_LOAD( "lo3_11a.119", 0x10000, 0x10000, CRC(018efa36) SHA1(99eec3f06146627c7f7177b854424e7162ab7c8e) )
 	ROM_LOAD( "lo3_10a.118", 0x20000, 0x10000, CRC(d5f4a8f3) SHA1(fcfaef46ef89c4b97970418a75d110271e94d55f) )
 	ROM_LOAD( "lo3_13a.121", 0x30000, 0x10000, CRC(e44774a7) SHA1(010d95ea497690ddd2406b8fef1b0aee375a165e) )
 
 	/* 8x8x1 HUD sprites */
-	ROM_REGION( 0x2000, REGION_GFX3, 0 )
+	ROM_REGION( 0x2000, "gfx3", 0 )
 	ROM_LOAD( "lo2_00.53", 0x00000, 0x2000, CRC(8affea15) SHA1(b7bcf0abde9c933e3f2c75c1f5e2ca3417d50ca1) )
 
 	/* Ground GFX and LUTs */
-	ROM_REGION( 0x60000, REGION_GFX4, 0 )
+	ROM_REGION( 0x60000, "gfx4", 0 )
 	ROM_LOAD( "lo3_07a.94", 0x00000, 0x10000, CRC(cebc50e1) SHA1(f8b06ce576c3d41b0a8e2cc3ac60d3515d434812) )
 	ROM_LOAD( "lo3_06a.92", 0x10000, 0x10000, CRC(f6b6ebdd) SHA1(30e92da3bf83c4bb30faf00cbf01664b993f137c) )
 	ROM_LOAD( "lo3_05a.90", 0x20000, 0x10000, CRC(5b6f4c8e) SHA1(fc8b2c929c60fb0177ed3e407e3f0aacc5df8401) )
@@ -590,7 +579,7 @@ ROM_START( lockon )
 	ROM_LOAD( "lo3_04a.88", 0x50000, 0x10000, CRC(80b67ba9) SHA1(fdbef463b26cd13c43596310f585432c6e0896d0) )
 
 	/* 8x8x4 object tiles */
-	ROM_REGION( 0x100000, REGION_GFX5, 0 )
+	ROM_REGION( 0x100000, "gfx5", 0 )
 	ROM_LOAD( "lo5_28a.76", 0x00000, 0x8000, CRC(1186f9b4) SHA1(55598552dafa8cccfb423fc3b65a7fa15831d75b) )
 	ROM_LOAD( "lo5_20a.48", 0x08000, 0x8000, CRC(3c1a67b5) SHA1(399935830b32a457ad0de243dd3eb4d368d5c6a6) )
 	ROM_LOAD( "lo5_08a.58", 0x10000, 0x8000, CRC(9dedeff5) SHA1(53b0917a4fde4053182d38ea7f99f66e52543c10) )
@@ -628,17 +617,17 @@ ROM_START( lockon )
 	ROM_LOAD( "lo5_15a.23", 0xf8000, 0x8000, CRC(66f9c5db) SHA1(cc68da9312ee0a3441b62d14107e1b7de9b04de3) )
 
 	/* Object LUTs */
-	ROM_REGION( 0x10000, REGION_USER1, 0 )
+	ROM_REGION( 0x10000, "user1", 0 )
 	ROM_LOAD( "lo4_02.109", 0x0000, 0x8000, CRC(0832edde) SHA1(77f9efbe029773417dbc3836a36687e37b5bee4b) )
 	ROM_LOAD( "lo4_03.108", 0x8000, 0x8000, CRC(1efac891) SHA1(faf305a30cab1c6bf8a9d6e2682b2c3745aec956) )
 
 	/* Object chunk LUTs */
-	ROM_REGION16_LE( 0x20000, REGION_USER2, 0 )
+	ROM_REGION16_LE( 0x20000, "user2", 0 )
 	ROM_LOAD16_BYTE( "lo4_04a.119", 0x00000, 0x10000, CRC(098f4151) SHA1(cf38e3c5f3442fbfa97870d25f7c89c465f847a9) )
 	ROM_LOAD16_BYTE( "lo4_05a.118", 0x00001, 0x10000, CRC(3b21667c) SHA1(b8337f733ede35145602ee3f0de25c2d4db1b2a5) )
 
 	/* Colour PROMs */
-	ROM_REGION( 0x1800, REGION_PROMS, 0 )
+	ROM_REGION( 0x1800, "proms", 0 )
 	ROM_LOAD( "lo1a.5", 0x000, 0x400, CRC(82391f30) SHA1(d7153c1f3a3e54de4d4d6f432fbcd66449b96b6e) )
 	ROM_LOAD( "lo2a.2", 0x400, 0x400, CRC(2bfc6288) SHA1(03d293ddc0c614b606be823826a4375b3d35901f) )
 
@@ -650,7 +639,7 @@ ROM_END
 
 ROM_START( lockonc )
 	/* TF012 V30 (Main) */
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, "main", 0 )
 	ROM_LOAD16_BYTE( "lo1_02c.89", 0x60000, 0x8000, CRC(bbf17263) SHA1(96821a0ecd6efe6764380fef094f87c1d6e1d299) )
 	ROM_LOAD16_BYTE( "lo1_03c.88", 0x60001, 0x8000, CRC(fa58fd36) SHA1(16af24027610bf6d3fdc4c3df3bf6d94c6776420) )
 
@@ -661,39 +650,39 @@ ROM_START( lockonc )
 	ROM_LOAD16_BYTE( "lo1_01c.95", 0x70001, 0x8000, CRC(3e6065e0) SHA1(d870f5b466fab90d5c51dd27ecc807e7b38b5f79) )
 
 	/* TF013 V30 (Ground) */
-	ROM_REGION( 0x100000, REGION_CPU2, 0 )
+	ROM_REGION( 0x100000, "ground", 0 )
 	ROM_LOAD16_BYTE( "lo3_01a.30", 0x20000, 0x8000, CRC(3eacdb6b) SHA1(7934c36dac9253dec4d8910954f6f2ae85951fe9) )
 	ROM_LOAD16_BYTE( "lo3_03a.33", 0x20001, 0x8000, CRC(4ce96d71) SHA1(cedbc33e86a93d11d5e11c2ef18bcf6390790a88) )
 	ROM_LOAD16_BYTE( "lo3_00b.29", 0x30000, 0x8000, CRC(1835dccb) SHA1(8dfb0fea61a3e61f4da3b7f0da02cd19df2e68be) )
 	ROM_LOAD16_BYTE( "lo3_02b.32", 0x30001, 0x8000, CRC(2b8931d3) SHA1(f6f40b7857f3d47da8626450b1c1d3c46a1072ab) )
 
 	/* TF014 V30 (Object)  */
-	ROM_REGION( 0x100000, REGION_CPU3, 0 )
+	ROM_REGION( 0x100000, "object", 0 )
 	ROM_LOAD16_BYTE( "lo4_00b", 0x30000, 0x8000, CRC(5f6b5a50) SHA1(daf82cafcae86d05587c191b0ff194ca7950e130) )
 	ROM_LOAD16_BYTE( "lo4_01b", 0x30001, 0x8000, CRC(7e88bcf2) SHA1(d541458ba6178ec3bce0e9b872b9fa1d8edb107c) )
 
 	/* TF014 Z80 (Sound) */
-	ROM_REGION( 0x10000, REGION_CPU4, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "lo1_08b.24", 0x00000, 0x8000, CRC(73860ec9) SHA1(a94afa274321b9f9ac2184e133132f9829fb9485) )
 
 	/* 8x8x2 characters */
-	ROM_REGION( 0x4000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x4000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "lo1_07a", 0x00000, 0x2000, CRC(73673b79) SHA1(246b80f0c465cefb7ce1c87dc90a58f0f0ea3e0d) )
 	ROM_LOAD( "lo1_06a", 0x02000, 0x2000, CRC(c8205913) SHA1(c791ff14418873ce68b502440c3d7ccc1f9cc00e) )
 
 	/* 8x8x3 scene tiles and CLUT */
-	ROM_REGION( 0x40000, REGION_GFX2, 0 )
+	ROM_REGION( 0x40000, "gfx2", 0 )
 	ROM_LOAD( "lo3_12a.120", 0x00000, 0x10000, CRC(a34262a7) SHA1(08204a4474ab1b07b9114da8af03442737922d3b) )
 	ROM_LOAD( "lo3_11a.119", 0x10000, 0x10000, CRC(018efa36) SHA1(99eec3f06146627c7f7177b854424e7162ab7c8e) )
 	ROM_LOAD( "lo3_10a.118", 0x20000, 0x10000, CRC(d5f4a8f3) SHA1(fcfaef46ef89c4b97970418a75d110271e94d55f) )
 	ROM_LOAD( "lo3_13a.121", 0x30000, 0x10000, CRC(e44774a7) SHA1(010d95ea497690ddd2406b8fef1b0aee375a165e) )
 
 	/* 8x8x1 HUD sprites */
-	ROM_REGION( 0x2000, REGION_GFX3, 0 )
+	ROM_REGION( 0x2000, "gfx3", 0 )
 	ROM_LOAD( "lo2_00.53", 0x00000, 0x2000, CRC(8affea15) SHA1(b7bcf0abde9c933e3f2c75c1f5e2ca3417d50ca1) )
 
 	/* Ground GFX and LUTs */
-	ROM_REGION( 0x60000, REGION_GFX4, 0 )
+	ROM_REGION( 0x60000, "gfx4", 0 )
 	ROM_LOAD( "lo3_07a.94", 0x00000, 0x10000, CRC(cebc50e1) SHA1(f8b06ce576c3d41b0a8e2cc3ac60d3515d434812) )
 	ROM_LOAD( "lo3_06a.92", 0x10000, 0x10000, CRC(f6b6ebdd) SHA1(30e92da3bf83c4bb30faf00cbf01664b993f137c) )
 	ROM_LOAD( "lo3_05a.90", 0x20000, 0x10000, CRC(5b6f4c8e) SHA1(fc8b2c929c60fb0177ed3e407e3f0aacc5df8401) )
@@ -702,7 +691,7 @@ ROM_START( lockonc )
 	ROM_LOAD( "lo3_04a.88", 0x50000, 0x10000, CRC(80b67ba9) SHA1(fdbef463b26cd13c43596310f585432c6e0896d0) )
 
 	/* 8x8x4 object tiles */
-	ROM_REGION( 0x100000, REGION_GFX5, 0 )
+	ROM_REGION( 0x100000, "gfx5", 0 )
 	ROM_LOAD( "lo5_28a.76", 0x00000, 0x8000, CRC(1186f9b4) SHA1(55598552dafa8cccfb423fc3b65a7fa15831d75b) )
 	ROM_LOAD( "lo5_20a.48", 0x08000, 0x8000, CRC(3c1a67b5) SHA1(399935830b32a457ad0de243dd3eb4d368d5c6a6) )
 	ROM_LOAD( "lo5_08a.58", 0x10000, 0x8000, CRC(9dedeff5) SHA1(53b0917a4fde4053182d38ea7f99f66e52543c10) )
@@ -740,17 +729,17 @@ ROM_START( lockonc )
 	ROM_LOAD( "lo5_15a.23", 0xf8000, 0x8000, CRC(66f9c5db) SHA1(cc68da9312ee0a3441b62d14107e1b7de9b04de3) )
 
 	/* Object LUTs */
-	ROM_REGION( 0x10000, REGION_USER1, 0 )
+	ROM_REGION( 0x10000, "user1", 0 )
 	ROM_LOAD( "lo4_02.109", 0x0000, 0x8000, CRC(0832edde) SHA1(77f9efbe029773417dbc3836a36687e37b5bee4b) )
 	ROM_LOAD( "lo4_03.108", 0x8000, 0x8000, CRC(1efac891) SHA1(faf305a30cab1c6bf8a9d6e2682b2c3745aec956) )
 
 	/* Object chunk LUTs */
-	ROM_REGION16_LE( 0x20000, REGION_USER2, 0 )
+	ROM_REGION16_LE( 0x20000, "user2", 0 )
 	ROM_LOAD16_BYTE( "lo4_04a.119", 0x00000, 0x10000, CRC(098f4151) SHA1(cf38e3c5f3442fbfa97870d25f7c89c465f847a9) )
 	ROM_LOAD16_BYTE( "lo4_05a.118", 0x00001, 0x10000, CRC(3b21667c) SHA1(b8337f733ede35145602ee3f0de25c2d4db1b2a5) )
 
 	/* Colour PROMs */
-	ROM_REGION( 0x1800, REGION_PROMS, 0 )
+	ROM_REGION( 0x1800, "proms", 0 )
 	ROM_LOAD( "lo1a.5", 0x000, 0x400, CRC(82391f30) SHA1(d7153c1f3a3e54de4d4d6f432fbcd66449b96b6e) )
 	ROM_LOAD( "lo2a.2", 0x400, 0x400, CRC(2bfc6288) SHA1(03d293ddc0c614b606be823826a4375b3d35901f) )
 
