@@ -1,5 +1,6 @@
 /*
 To Do:
+- redump COP420 internal ROM
 - get sound working
 - map and test any remaining input ports
 
@@ -10,7 +11,7 @@ Looping
         TMS9995
 
     COP420 Microcontroller
-        manages CPU communnication?
+        protection
 
     Sound CPU
         TMS9980
@@ -52,11 +53,12 @@ L056-6    9A          "      "      VLI-8-4 7A         "
 */
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/tms9900/tms9900.h"
 #include "sound/ay8910.h"
 #include "sound/dac.h"
 #include "sound/5220intf.h"
 #include "video/resnet.h"
+#include "cpu/cop400/cop400.h"
 
 
 /*************************************
@@ -175,7 +177,7 @@ static VIDEO_START( looping )
 {
 	looping_state *state = machine->driver_data;
 
-	state->bg_tilemap = tilemap_create(get_tile_info, tilemap_scan_rows, TILEMAP_TYPE_PEN, 8,8, 32,32);
+	state->bg_tilemap = tilemap_create(machine, get_tile_info, tilemap_scan_rows, 8,8, 32,32);
 
 	tilemap_set_scroll_cols(state->bg_tilemap, 0x20);
 }
@@ -190,23 +192,23 @@ static VIDEO_START( looping )
 
 static WRITE8_HANDLER( flip_screen_x_w )
 {
-	looping_state *state = Machine->driver_data;
-	flip_screen_x_set(~data & 0x01);
-	tilemap_set_scrollx(state->bg_tilemap, 0, flip_screen ? 128 : 0);
+	looping_state *state = space->machine->driver_data;
+	flip_screen_x_set(space->machine, ~data & 0x01);
+	tilemap_set_scrollx(state->bg_tilemap, 0, flip_screen_get(space->machine) ? 128 : 0);
 }
 
 
 static WRITE8_HANDLER( flip_screen_y_w )
 {
-	looping_state *state = Machine->driver_data;
-	flip_screen_y_set(~data & 0x01);
-	tilemap_set_scrollx(state->bg_tilemap, 0, flip_screen ? 128 : 0);
+	looping_state *state = space->machine->driver_data;
+	flip_screen_y_set(space->machine, ~data & 0x01);
+	tilemap_set_scrollx(state->bg_tilemap, 0, flip_screen_get(space->machine) ? 128 : 0);
 }
 
 
 static WRITE8_HANDLER( looping_videoram_w )
 {
-	looping_state *state = Machine->driver_data;
+	looping_state *state = space->machine->driver_data;
 	state->videoram[offset] = data;
 	tilemap_mark_tile_dirty(state->bg_tilemap, offset);
 }
@@ -214,7 +216,7 @@ static WRITE8_HANDLER( looping_videoram_w )
 
 static WRITE8_HANDLER( looping_colorram_w )
 {
-	looping_state *state = Machine->driver_data;
+	looping_state *state = space->machine->driver_data;
 	int i;
 
 	state->colorram[offset] = data;
@@ -241,7 +243,7 @@ static WRITE8_HANDLER( looping_colorram_w )
  *
  *************************************/
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	const UINT8 *source;
 	looping_state *state = machine->driver_data;
@@ -255,13 +257,13 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 		int code  = source[1] & 0x3f;
 		int color = source[2];
 
-		if (flip_screen_x)
+		if (flip_screen_x_get(machine))
 		{
 			sx = 240 - sx;
 			flipx = !flipx;
 		}
 
-		if (flip_screen_y)
+		if (flip_screen_y_get(machine))
 		{
 			sy = 240 - sy;
 			flipy = !flipy;
@@ -274,10 +276,10 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 
 static VIDEO_UPDATE( looping )
 {
-	looping_state *state = machine->driver_data;
+	looping_state *state = screen->machine->driver_data;
 	tilemap_draw(bitmap, cliprect, state->bg_tilemap, 0, 0);
 
-	draw_sprites(machine, bitmap, cliprect);
+	draw_sprites(screen->machine, bitmap, cliprect);
 	return 0;
 }
 
@@ -292,7 +294,7 @@ static VIDEO_UPDATE( looping )
 static MACHINE_START( looping )
 {
 	looping_state *state = machine->driver_data;
-	state_save_register_global_array(state->sound);
+	state_save_register_global_array(machine, state->sound);
 }
 
 
@@ -305,41 +307,41 @@ static MACHINE_START( looping )
 
 static INTERRUPT_GEN( looping_interrupt )
 {
-	cpunum_set_input_line_and_vector(machine, 0, 0, ASSERT_LINE, 4);
+	cpu_set_input_line_and_vector(device, 0, ASSERT_LINE, 4);
 }
 
 
 static WRITE8_HANDLER( level2_irq_set )
 {
 	if (!(data & 1))
-		cpunum_set_input_line_and_vector(Machine, 0, 0, ASSERT_LINE, 4);
+		cpu_set_input_line_and_vector(space->machine->cpu[0], 0, ASSERT_LINE, 4);
 }
 
 
 static WRITE8_HANDLER( main_irq_ack_w )
 {
 	if (data == 0)
-		cpunum_set_input_line(Machine, 0, 0, CLEAR_LINE);
+		cpu_set_input_line(space->machine->cpu[0], 0, CLEAR_LINE);
 }
 
 
 static WRITE8_HANDLER( looping_souint_clr )
 {
 	if (data == 0)
-		cpunum_set_input_line(Machine, 1, 0, CLEAR_LINE);
+		cpu_set_input_line(space->machine->cpu[1], 0, CLEAR_LINE);
 }
 
 
-static void looping_spcint(int state)
+static void looping_spcint(running_machine *machine, int state)
 {
-	cpunum_set_input_line_and_vector(Machine, 1, 0, state, 6);
+	cpu_set_input_line_and_vector(machine->cpu[1], 0, state, 6);
 }
 
 
 static WRITE8_HANDLER( looping_soundlatch_w )
 {
-	soundlatch_w(offset, data);
-	cpunum_set_input_line_and_vector(Machine, 1, 0, ASSERT_LINE, 4);
+	soundlatch_w(space, offset, data);
+	cpu_set_input_line_and_vector(space->machine->cpu[1], 0, ASSERT_LINE, 4);
 }
 
 
@@ -363,9 +365,9 @@ static WRITE8_HANDLER( looping_sound_sw )
         0007 = AFA
     */
 
-	looping_state *state = Machine->driver_data;
+	looping_state *state = space->machine->driver_data;
 	state->sound[offset + 1] = data ^ 1;
-	DAC_data_w(0, ((state->sound[2] << 7) + (state->sound[3] << 6)) * state->sound[7]);
+	dac_data_w(0, ((state->sound[2] << 7) + (state->sound[3] << 6)) * state->sound[7]);
 }
 
 
@@ -410,8 +412,8 @@ static int last;
 static WRITE8_HANDLER( out_0_w ) { mame_printf_debug("out0 = %02X\n", data); }
 static WRITE8_HANDLER( out_2_w ) { mame_printf_debug("out2 = %02X\n", data); }
 
-static READ8_HANDLER( adc_r )  { mame_printf_debug("%04X:ADC read\n", activecpu_get_pc()); return 0xff; }
-static WRITE8_HANDLER( adc_w ) { mame_printf_debug("%04X:ADC write = %02X\n", activecpu_get_pc(), data); }
+static READ8_HANDLER( adc_r )  { mame_printf_debug("%04X:ADC read\n", cpu_get_pc(space->cpu)); return 0xff; }
+static WRITE8_HANDLER( adc_w ) { mame_printf_debug("%04X:ADC write = %02X\n", cpu_get_pc(space->cpu), data); }
 
 static WRITE8_HANDLER( plr2_w )
 {
@@ -461,9 +463,9 @@ static READ8_HANDLER( protection_r )
 static ADDRESS_MAP_START( looping_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 
-	AM_RANGE(0x9000, 0x93ff) AM_READWRITE(MRA8_RAM, looping_videoram_w) AM_BASE_MEMBER(looping_state, videoram)
+	AM_RANGE(0x9000, 0x93ff) AM_RAM_WRITE(looping_videoram_w) AM_BASE_MEMBER(looping_state, videoram)
 
-	AM_RANGE(0x9800, 0x983f) AM_MIRROR(0x0700) AM_READWRITE(MRA8_RAM, looping_colorram_w) AM_BASE_MEMBER(looping_state, colorram)
+	AM_RANGE(0x9800, 0x983f) AM_MIRROR(0x0700) AM_RAM_WRITE(looping_colorram_w) AM_BASE_MEMBER(looping_state, colorram)
 	AM_RANGE(0x9840, 0x987f) AM_MIRROR(0x0700) AM_RAM AM_BASE_MEMBER(looping_state, spriteram)
 	AM_RANGE(0x9880, 0x98ff) AM_MIRROR(0x0700) AM_RAM
 
@@ -472,9 +474,9 @@ static ADDRESS_MAP_START( looping_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xb007, 0xb007) AM_MIRROR(0x07f8) AM_WRITE(flip_screen_y_w)
 
 	AM_RANGE(0xe000, 0xefff) AM_RAM
-	AM_RANGE(0xf800, 0xf800) AM_MIRROR(0x03fc) AM_READWRITE(input_port_0_r, out_0_w) /* /OUT0 */
-	AM_RANGE(0xf801, 0xf801) AM_MIRROR(0x03fc) AM_READWRITE(input_port_1_r, looping_soundlatch_w) /* /OUT1 */
-	AM_RANGE(0xf802, 0xf802) AM_MIRROR(0x03fc) AM_READWRITE(input_port_2_r, out_2_w) /* /OUT2 */
+	AM_RANGE(0xf800, 0xf800) AM_MIRROR(0x03fc) AM_READ_PORT("P1") AM_WRITE(out_0_w)					/* /OUT0 */
+	AM_RANGE(0xf801, 0xf801) AM_MIRROR(0x03fc) AM_READ_PORT("P2") AM_WRITE(looping_soundlatch_w)	/* /OUT1 */
+	AM_RANGE(0xf802, 0xf802) AM_MIRROR(0x03fc) AM_READ_PORT("DSW") AM_WRITE(out_2_w)				/* /OUT2 */
 	AM_RANGE(0xf803, 0xf803) AM_MIRROR(0x03fc) AM_READWRITE(adc_r, adc_w)
 ADDRESS_MAP_END
 
@@ -494,14 +496,14 @@ ADDRESS_MAP_END
 
 /* complete memory map derived from schematics */
 static ADDRESS_MAP_START( looping_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(14) )
+	ADDRESS_MAP_GLOBAL_MASK(0x3fff)
 	AM_RANGE(0x0000, 0x37ff) AM_ROM
 	AM_RANGE(0x3800, 0x3bff) AM_RAM
-	AM_RANGE(0x3c00, 0x3c00) AM_MIRROR(0x00f4) AM_READWRITE(AY8910_read_port_0_r, AY8910_control_port_0_w)
-	AM_RANGE(0x3c02, 0x3c02) AM_MIRROR(0x00f4) AM_READWRITE(MRA8_NOP, AY8910_write_port_0_w)
+	AM_RANGE(0x3c00, 0x3c00) AM_MIRROR(0x00f4) AM_READWRITE(ay8910_read_port_0_r, ay8910_control_port_0_w)
+	AM_RANGE(0x3c02, 0x3c02) AM_MIRROR(0x00f4) AM_READWRITE(SMH_NOP, ay8910_write_port_0_w)
 	AM_RANGE(0x3c03, 0x3c03) AM_MIRROR(0x00f6) AM_NOP
-	AM_RANGE(0x3e00, 0x3e00) AM_MIRROR(0x00f4) AM_READWRITE(MRA8_NOP, tms5220_data_w)
-	AM_RANGE(0x3e02, 0x3e02) AM_MIRROR(0x00f4) AM_READWRITE(tms5220_status_r, MWA8_NOP)
+	AM_RANGE(0x3e00, 0x3e00) AM_MIRROR(0x00f4) AM_READWRITE(SMH_NOP, tms5220_data_w)
+	AM_RANGE(0x3e02, 0x3e02) AM_MIRROR(0x00f4) AM_READWRITE(tms5220_status_r, SMH_NOP)
 	AM_RANGE(0x3e03, 0x3e03) AM_MIRROR(0x00f6) AM_NOP
 ADDRESS_MAP_END
 
@@ -544,8 +546,8 @@ static const gfx_layout sprite_layout =
 
 
 static GFXDECODE_START( looping )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, gfx_8x8x2_planar, 0, 8 )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, sprite_layout,    0, 8 )
+	GFXDECODE_ENTRY( "gfx1", 0, gfx_8x8x2_planar, 0, 8 )
+	GFXDECODE_ENTRY( "gfx1", 0, sprite_layout,    0, 8 )
 GFXDECODE_END
 
 
@@ -556,17 +558,27 @@ GFXDECODE_END
  *
  *************************************/
 
-static const struct TMS5220interface tms5220_interface =
+static const tms5220_interface tms5220_config =
 {
 	looping_spcint
 };
 
-static const struct AY8910interface ay8910_interface =
+static const ay8910_interface ay8910_config =
 {
-	soundlatch_r
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
+	soundlatch_r,
+	NULL,
+	NULL,
+	NULL
 };
 
-
+static COP400_INTERFACE( looping_cop_intf )
+{
+	COP400_CKI_DIVISOR_16, // ???
+	COP400_CKO_OSCILLATOR_OUTPUT, // ???
+	COP400_MICROBUS_DISABLED
+};
 
 /*************************************
  *
@@ -578,25 +590,27 @@ static MACHINE_DRIVER_START( looping )
 	MDRV_DRIVER_DATA(looping_state)
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(TMS9995, MAIN_CPU_CLOCK)
+	MDRV_CPU_ADD("main", TMS9995, MAIN_CPU_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(looping_map,0)
 	MDRV_CPU_IO_MAP(looping_io_map,0)
-	MDRV_CPU_VBLANK_INT(looping_interrupt,1)
+	MDRV_CPU_VBLANK_INT("main", looping_interrupt)
 
-	MDRV_CPU_ADD(TMS9980, SOUND_CLOCK/4)
+	MDRV_CPU_ADD("audio", TMS9980, SOUND_CLOCK/4)
 	MDRV_CPU_PROGRAM_MAP(looping_sound_map,0)
 	MDRV_CPU_IO_MAP(looping_sound_io_map,0)
 
-	MDRV_CPU_ADD(COP420, COP_CLOCK)
+	MDRV_CPU_ADD("mcu", COP420, COP_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(looping_cop_map,0)
 	MDRV_CPU_DATA_MAP(looping_cop_data_map,0)
+	MDRV_CPU_CONFIG(looping_cop_intf)
 
 	MDRV_MACHINE_START(looping)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_RAW_PARAMS(PIXEL_CLOCK, HTOTAL, HBEND, HBSTART, VTOTAL, VBEND, VBSTART)
+
 	MDRV_GFXDECODE(looping)
 	MDRV_PALETTE_LENGTH(32)
 
@@ -607,15 +621,15 @@ static MACHINE_DRIVER_START( looping )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, SOUND_CLOCK/4)
-	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ADD("ay", AY8910, SOUND_CLOCK/4)
+	MDRV_SOUND_CONFIG(ay8910_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 
-	MDRV_SOUND_ADD(TMS5220, TMS_CLOCK)
-	MDRV_SOUND_CONFIG(tms5220_interface)
+	MDRV_SOUND_ADD("tms", TMS5220, TMS_CLOCK)
+	MDRV_SOUND_CONFIG(tms5220_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
-	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ADD("dac", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 MACHINE_DRIVER_END
 
@@ -628,7 +642,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 static INPUT_PORTS_START( looping )
-	PORT_START_TAG("IN0")
+	PORT_START("P1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_NAME("P1 Shoot")
@@ -638,7 +652,7 @@ static INPUT_PORTS_START( looping )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )
 
-	PORT_START_TAG("IN1") /* cocktail? */
+	PORT_START("P2") /* cocktail? */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_COCKTAIL
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
@@ -646,7 +660,7 @@ static INPUT_PORTS_START( looping )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("DSW0")
+	PORT_START("DSW")
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Coin_B ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) )
@@ -675,7 +689,7 @@ INPUT_PORTS_END
 static INPUT_PORTS_START( skybump )
 	PORT_INCLUDE(looping)
 
-	PORT_MODIFY("DSW0")
+	PORT_MODIFY("DSW")
 	PORT_DIPNAME( 0x60, 0x40, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x40, "3" )
 	PORT_DIPSETTING(    0x60, "5" )
@@ -692,72 +706,72 @@ INPUT_PORTS_END
  *************************************/
 
 ROM_START( looping )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 ) /* TMS9995 code */
+	ROM_REGION( 0x8000, "main", 0 ) /* TMS9995 code */
 	ROM_LOAD( "vli3.5a",		0x0000, 0x2000, CRC(1ac3ccdf) SHA1(9d1cde8bd4d0f12eaf06225b3ecc4a5c3e4f0c11) )
 	ROM_LOAD( "vli1.2a",		0x2000, 0x2000, CRC(97755fd4) SHA1(4a6ef02b0128cd516ff95083a7caaad8f3756f09) )
 	ROM_LOAD( "l056-6.9a",		0x4000, 0x2000, CRC(548afa52) SHA1(0b88ac7394feede023519c585a4084591eb9661a) )
 	ROM_LOAD( "vli9-5.8a",		0x6000, 0x2000, CRC(5d122f86) SHA1(d1c66b890142bb4d4648f3edec6567f58107dbf0) )
 
-	ROM_REGION( 0x3800, REGION_CPU2, 0 ) /* TMS9980 code */
+	ROM_REGION( 0x3800, "audio", 0 ) /* TMS9980 code */
 	ROM_LOAD( "i-o.13c",		0x0000, 0x0800, CRC(21e9350c) SHA1(f30a180309e373a17569351944f5e7982c3b3f9d) )
 	ROM_LOAD( "i-o.13a",		0x0800, 0x1000, CRC(1de29f25) SHA1(535acb132266d6137b0610ee9a9b946459ae44af) )
 	ROM_LOAD( "i-o.11a",		0x2800, 0x1000, CRC(61c74c79) SHA1(9f34d18a919446dd76857b851cea23fc1526f3c2) ) /* speech */
 
-	ROM_REGION( 0x1000, REGION_CPU3, 0 ) /* COP420 microcontroller code */
-	ROM_LOAD( "cop.bin",		0x0000, 0x1000, CRC(bbfd26d5) SHA1(5f78b32b6e7c003841ef5b635084db2cdfebf0e1) )
+	ROM_REGION( 0x1000, "mcu", 0 ) /* COP420 microcontroller code */
+	ROM_LOAD( "cop.bin",		0x0000, 0x1000, BAD_DUMP CRC(bbfd26d5) SHA1(5f78b32b6e7c003841ef5b635084db2cdfebf0e1) ) // overdumped 4 times, and starting PC is not 0
 
-	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "log2.8a",		0x0000, 0x800, CRC(ef3284ac) SHA1(8719c9df8c972a56c306b3c707aaa53092ffa2d6) )
 	ROM_LOAD( "log1-9-3.6a",	0x0800, 0x800, CRC(c434c14c) SHA1(3669aaf7adc6b250378bcf62eb8e7058f55476ef) )
 
-	ROM_REGION( 0x0020, REGION_PROMS, 0 ) /* color prom */
+	ROM_REGION( 0x0020, "proms", 0 ) /* color prom */
 	ROM_LOAD( "18s030.11b",		0x0000, 0x0020, CRC(6a0c7d87) SHA1(140335d85c67c75b65689d4e76d29863c209cf32) )
 ROM_END
 
 ROM_START( loopinga )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 ) /* TMS9995 code */
+	ROM_REGION( 0x8000, "main", 0 ) /* TMS9995 code */
 	ROM_LOAD( "vli3.5a",		0x0000, 0x2000, CRC(1ac3ccdf) SHA1(9d1cde8bd4d0f12eaf06225b3ecc4a5c3e4f0c11) )
 	ROM_LOAD( "vli-4-3",		0x2000, 0x1000, CRC(f32cae2b) SHA1(2c6ef82af438e588b56fd58b95cf969c97bb9a66) )
 	ROM_LOAD( "vli-8-4",		0x3000, 0x1000, CRC(611e1dbf) SHA1(0ab6669f1dec30c3f7bca49e158e4790a78fa308) )
 	ROM_LOAD( "l056-6.9a",		0x4000, 0x2000, CRC(548afa52) SHA1(0b88ac7394feede023519c585a4084591eb9661a) )
 	ROM_LOAD( "vli9-5.8a",		0x6000, 0x2000, CRC(5d122f86) SHA1(d1c66b890142bb4d4648f3edec6567f58107dbf0) )
 
-	ROM_REGION( 0x3800, REGION_CPU2, 0 ) /* TMS9980 code */
+	ROM_REGION( 0x3800, "audio", 0 ) /* TMS9980 code */
 	ROM_LOAD( "i-o-v2.13c",		0x0000, 0x0800, CRC(09765ebe) SHA1(93b035c3a94f2f6d5e463256e26b600a4dd5d3ea) )
     ROM_LOAD( "i-o.13a",		0x0800, 0x1000, CRC(1de29f25) SHA1(535acb132266d6137b0610ee9a9b946459ae44af) ) /* speech */
 	ROM_LOAD( "i-o.11a",		0x2800, 0x1000, CRC(61c74c79) SHA1(9f34d18a919446dd76857b851cea23fc1526f3c2) )
 
-	ROM_REGION( 0x1000, REGION_CPU3, 0 ) /* COP420 microcontroller code */
-	ROM_LOAD( "cop.bin",		0x0000, 0x1000, CRC(bbfd26d5) SHA1(5f78b32b6e7c003841ef5b635084db2cdfebf0e1) )
+	ROM_REGION( 0x1000, "mcu", 0 ) /* COP420 microcontroller code */
+	ROM_LOAD( "cop.bin",		0x0000, 0x1000, BAD_DUMP CRC(bbfd26d5) SHA1(5f78b32b6e7c003841ef5b635084db2cdfebf0e1) ) // overdumped 4 times, and starting PC is not 0
 
-	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "log2.8a",		0x0000, 0x800, CRC(ef3284ac) SHA1(8719c9df8c972a56c306b3c707aaa53092ffa2d6) )
 	ROM_LOAD( "log1-9-3.6a",	0x0800, 0x800, CRC(c434c14c) SHA1(3669aaf7adc6b250378bcf62eb8e7058f55476ef) )
 
-	ROM_REGION( 0x0020, REGION_PROMS, 0 ) /* color prom */
+	ROM_REGION( 0x0020, "proms", 0 ) /* color prom */
 	ROM_LOAD( "18s030.11b",		0x0000, 0x0020, CRC(6a0c7d87) SHA1(140335d85c67c75b65689d4e76d29863c209cf32) )
 ROM_END
 
 ROM_START( skybump )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 ) /* TMS9995 code */
+	ROM_REGION( 0x8000, "main", 0 ) /* TMS9995 code */
 	ROM_LOAD( "cpu.5a",			0x0000, 0x2000, CRC(dca38df0) SHA1(86abe04cbabf81399f842f53668fe7a3f7ed3757) )
 	ROM_LOAD( "cpu.2a",			0x2000, 0x2000, CRC(6bcc211a) SHA1(245ebae3934df9c3920743a941546d96bb2e7c03) )
 	ROM_LOAD( "cpu.9a",			0x4000, 0x2000, CRC(c7a50797) SHA1(60aa0a28ba970f12d0a0e538ae1c6807d105855c) )
 	ROM_LOAD( "cpu.8a",			0x6000, 0x2000, CRC(a718c6f2) SHA1(19afa8c353829232cb96c27b87f13b43166ab6fc) )
 
-    ROM_REGION( 0x3800, REGION_CPU2, 0 ) /* TMS9980 code */
+    ROM_REGION( 0x3800, "audio", 0 ) /* TMS9980 code */
 	ROM_LOAD( "snd.13c",		0x0000, 0x0800, CRC(21e9350c) SHA1(f30a180309e373a17569351944f5e7982c3b3f9d) )
 	ROM_LOAD( "snd.13a",		0x0800, 0x1000, CRC(1de29f25) SHA1(535acb132266d6137b0610ee9a9b946459ae44af) )
 	ROM_LOAD( "snd.11a",		0x2800, 0x1000, CRC(61c74c79) SHA1(9f34d18a919446dd76857b851cea23fc1526f3c2) )
 
-	ROM_REGION( 0x1000, REGION_CPU3, 0 ) /* COP420 microcontroller code */
-	ROM_LOAD( "cop.bin",		0x0000, 0x1000, CRC(bbfd26d5) SHA1(5f78b32b6e7c003841ef5b635084db2cdfebf0e1) )
+	ROM_REGION( 0x1000, "mcu", 0 ) /* COP420 microcontroller code */
+	ROM_LOAD( "cop.bin",		0x0000, 0x1000, BAD_DUMP CRC(bbfd26d5) SHA1(5f78b32b6e7c003841ef5b635084db2cdfebf0e1) ) // overdumped 4 times, and starting PC is not 0
 
-	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "vid.8a",			0x0000, 0x800, CRC(459ccc55) SHA1(747f6789605b48be9e22f779f9e3f6c98ad4e594) )
 	ROM_LOAD( "vid.6a",			0x0800, 0x800, CRC(12ebbe74) SHA1(0f87c81a45d1bf3b8c6a70ee5e1a014069f67755) )
 
-	ROM_REGION( 0x0020, REGION_PROMS, 0 ) /* color prom */
+	ROM_REGION( 0x0020, "proms", 0 ) /* color prom */
 	ROM_LOAD( "vid.clr",		0x0000, 0x0020, CRC(6a0c7d87) SHA1(140335d85c67c75b65689d4e76d29863c209cf32) )
 ROM_END
 
@@ -771,8 +785,8 @@ ROM_END
 
 static DRIVER_INIT( looping )
 {
-	int length = memory_region_length(REGION_CPU1);
-	UINT8 *rom = memory_region(REGION_CPU1);
+	int length = memory_region_length(machine, "main");
+	UINT8 *rom = memory_region(machine, "main");
 	int i;
 
 	/* bitswap the TMS9995 ROMs */
@@ -780,7 +794,7 @@ static DRIVER_INIT( looping )
 		rom[i] = BITSWAP8(rom[i], 0,1,2,3,4,5,6,7);
 
 	/* install protection handlers */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x7000, 0x7007, 0, 0, protection_r);
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x7000, 0x7007, 0, 0, protection_r);
 }
 
 
