@@ -74,7 +74,7 @@ static ADDRESS_MAP_START( macs_mem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xd000, 0xdfff) AM_READ(st0016_sprite2_ram_r) AM_WRITE(st0016_sprite2_ram_w)
 	AM_RANGE(0xe000, 0xe7ff) AM_RAM /* work ram ? */
 	AM_RANGE(0xe800, 0xe87f) AM_RAM AM_BASE(&macs_ram2)
-	AM_RANGE(0xe900, 0xe9ff) AM_RAM AM_WRITE(st0016_snd_w) AM_BASE(&st0016_sound_regs)
+	AM_RANGE(0xe900, 0xe9ff) AM_RAM_WRITE(st0016_snd_w) AM_BASE(&st0016_sound_regs)
 	AM_RANGE(0xea00, 0xebff) AM_READ(st0016_palette_ram_r) AM_WRITE(st0016_palette_ram_w)
 	AM_RANGE(0xec00, 0xec1f) AM_READ(st0016_character_ram_r) AM_WRITE(st0016_character_ram_w)
 	AM_RANGE(0xf000, 0xf7ff) AM_RAMBANK(3) /* common /backup ram ?*/
@@ -83,7 +83,7 @@ ADDRESS_MAP_END
 
 static WRITE8_HANDLER(rambank_w)
 {
-	memory_set_bankptr( 3, &macs_ram1[0x10000+(data&1)*0x800] );
+	memory_set_bankptr(space->machine,  3, &macs_ram1[0x10000+(data&1)*0x800] );
 }
 
 static READ8_HANDLER( macs_input_r )
@@ -95,24 +95,24 @@ static READ8_HANDLER( macs_input_r )
 			/*It's bit-wise*/
 			switch(macs_mux_data&0x0f)
 			{
-				case 0x00: return readinputportbytag("IN0");
-				case 0x01: return readinputportbytag("IN1");
-				case 0x02: return readinputportbytag("IN2");
-				case 0x04: return readinputportbytag("IN3");
-				case 0x08: return readinputportbytag("IN4");
+				case 0x00: return input_port_read(space->machine, "IN0");
+				case 0x01: return input_port_read(space->machine, "IN1");
+				case 0x02: return input_port_read(space->machine, "IN2");
+				case 0x04: return input_port_read(space->machine, "IN3");
+				case 0x08: return input_port_read(space->machine, "IN4");
 				default:
 				logerror("Unmapped mahjong panel mux data %02x\n",macs_mux_data);
 				return 0xff;
 			}
 		}
-		case 1: return readinputportbytag("SYS0");
-		case 2: return readinputportbytag("DSW0");
-		case 3: return readinputportbytag("DSW1");
-		case 4: return readinputportbytag("DSW2");
-		case 5: return readinputportbytag("DSW3");
-		case 6: return readinputportbytag("DSW4");
-		case 7: return readinputportbytag("SYS1");
-		default: 	popmessage("Unmapped I/O read at PC = %06x offset = %02x",activecpu_get_pc(),offset+0xc0);
+		case 1: return input_port_read(space->machine, "SYS0");
+		case 2: return input_port_read(space->machine, "DSW0");
+		case 3: return input_port_read(space->machine, "DSW1");
+		case 4: return input_port_read(space->machine, "DSW2");
+		case 5: return input_port_read(space->machine, "DSW3");
+		case 6: return input_port_read(space->machine, "DSW4");
+		case 7: return input_port_read(space->machine, "SYS1");
+		default: 	popmessage("Unmapped I/O read at PC = %06x offset = %02x",cpu_get_pc(space->cpu),offset+0xc0);
 	}
 
 	return 0xff;
@@ -122,14 +122,14 @@ static WRITE8_HANDLER( macs_output_w )
 {
 	switch(offset)
 	{
-		case 0: memory_set_bankptr( 2, &macs_ram1[((data&0x20)>>5)*0x1000+0x800] );break;
+		case 0: memory_set_bankptr(space->machine,  2, &macs_ram1[((data&0x20)>>5)*0x1000+0x800] );break;
 		case 2: macs_mux_data = data; break;
 
 	}
 }
 
 static ADDRESS_MAP_START( macs_io, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0xbf) AM_READ(st0016_vregs_r) AM_WRITE(st0016_vregs_w) /* video/crt regs ? */
 	AM_RANGE(0xc0, 0xc7) AM_READWRITE(macs_input_r,macs_output_w)
 	AM_RANGE(0xe0, 0xe0) AM_WRITENOP /* renju = $40, neratte = 0 */
@@ -143,12 +143,12 @@ static ADDRESS_MAP_START( macs_io, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 static GFXDECODE_START( macs )
-//  GFXDECODE_ENTRY( 0, 0, charlayout,      0, 16*4  )
+//  GFXDECODE_ENTRY( NULL, 0, charlayout,      0, 16*4  )
 GFXDECODE_END
 
 static INPUT_PORTS_START( macs )
 	/*0*/
-	PORT_START_TAG("DSW0")
+	PORT_START("DSW0")
 	PORT_DIPNAME( 0x01, 0x01, "DSW0 - BIT 1" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -175,7 +175,7 @@ static INPUT_PORTS_START( macs )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
 	/*1*/
-	PORT_START_TAG("DSW1")
+	PORT_START("DSW1")
 	PORT_DIPNAME( 0x01, 0x01, "DSW1 - BIT 1" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -202,7 +202,7 @@ static INPUT_PORTS_START( macs )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
 	/*2*/
-	PORT_START_TAG("DSW2")
+	PORT_START("DSW2")
 	PORT_DIPNAME( 0x01, 0x01, "DSW 2 - BIT 1" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -229,7 +229,7 @@ static INPUT_PORTS_START( macs )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
 	/*3*/
-	PORT_START_TAG("DSW3")
+	PORT_START("DSW3")
 	PORT_DIPNAME( 0x01, 0x01, "DSW3 - BIT 1" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -256,7 +256,7 @@ static INPUT_PORTS_START( macs )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
 	/*4 - external (printer  in cultname)*/
-	PORT_START_TAG("DSW4")
+	PORT_START("DSW4")
 	PORT_DIPNAME( 0x01, 0x01, "DSW4 - BIT 1" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -283,7 +283,7 @@ static INPUT_PORTS_START( macs )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
 	/*(COMMON) MAHJONG PANEL*/
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_LAST_CHANCE )
 	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_SCORE )
 	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_DOUBLE_UP )
@@ -292,7 +292,7 @@ static INPUT_PORTS_START( macs )
 	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_MAHJONG_SMALL )
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("IN1")
+	PORT_START("IN1")
 	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_A )
 	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_E )
 	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_I )
@@ -301,7 +301,7 @@ static INPUT_PORTS_START( macs )
 	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT(0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("IN2")
+	PORT_START("IN2")
 	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_B )
 	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_F )
 	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_J )
@@ -310,7 +310,7 @@ static INPUT_PORTS_START( macs )
 	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_MAHJONG_BET )
 	PORT_BIT(0xc0, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("IN3")
+	PORT_START("IN3")
 	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_C )
 	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_G )
 	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_K )
@@ -318,7 +318,7 @@ static INPUT_PORTS_START( macs )
 	PORT_BIT(0x10, IP_ACTIVE_LOW, IPT_MAHJONG_RON )
 	PORT_BIT( 0xe0, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("IN4")
+	PORT_START("IN4")
 	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_MAHJONG_D )
 	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_MAHJONG_H )
 	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_MAHJONG_L )
@@ -328,11 +328,11 @@ static INPUT_PORTS_START( macs )
 	/*
     Note: These could likely to be switches that are on the game board and not Dip Switches
     */
-	PORT_START_TAG("SYS0")
+	PORT_START("SYS0")
 	PORT_BIT( 0x7f, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Note In") PORT_CODE(KEYCODE_4_PAD)
 
-	PORT_START_TAG("SYS1")
+	PORT_START("SYS1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Clear Coin Counter") PORT_CODE(KEYCODE_1_PAD)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Memory Reset") PORT_CODE(KEYCODE_2_PAD)
@@ -340,30 +340,29 @@ static INPUT_PORTS_START( macs )
 	PORT_BIT( 0xf0, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
-static const struct ST0016interface st0016_interface =
+static const st0016_interface st0016_config =
 {
 	&st0016_charram
 };
 
 static MACHINE_DRIVER_START( macs )
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main",Z80,8000000) /* 8 MHz ? */
+	MDRV_CPU_ADD("main",Z80,8000000) /* 8 MHz ? */
 	MDRV_CPU_PROGRAM_MAP(macs_mem,0)
 	MDRV_CPU_IO_MAP(macs_io,0)
 
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
 	MDRV_MACHINE_RESET(macs)
 
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(128*8, 128*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 128*8-1, 0*8, 128*8-1)
+
 	MDRV_GFXDECODE(macs)
 	MDRV_PALETTE_LENGTH(16*16*4+1)
 
@@ -372,8 +371,8 @@ static MACHINE_DRIVER_START( macs )
 
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(ST0016, 0)
-	MDRV_SOUND_CONFIG(st0016_interface)
+	MDRV_SOUND_ADD("st", ST0016, 0)
+	MDRV_SOUND_CONFIG(st0016_config)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
@@ -381,89 +380,89 @@ MACHINE_DRIVER_END
 
 
 #define MACS_BIOS \
-	ROM_REGION( 0x1000000, REGION_USER1, 0 ) \
+	ROM_REGION( 0x1000000, "user1", 0 ) \
 	ROM_LOAD16_BYTE( "macsos_l.u43", 0x00000, 0x80000, CRC(0b5aed5e) SHA1(042e705017ee34656e2c6af45825bb2dd3447747) ) \
 	ROM_LOAD16_BYTE( "macsos_h.u44", 0x00001, 0x80000, CRC(538b68e4) SHA1(a0534147791e94e726f49451d0e95671ae0a87d5) ) \
 
 #define MACS2_BIOS \
-	ROM_REGION( 0x1000000, REGION_USER1, 0 ) \
+	ROM_REGION( 0x1000000, "user1", 0 ) \
 	ROM_LOAD16_BYTE( "macs2os_l.bin", 0x00000, 0x80000, NO_DUMP ) \
 	ROM_LOAD16_BYTE( "macs2os_h.bin", 0x00001, 0x80000, NO_DUMP ) \
 
 ROM_START( macsbios )
 	MACS_BIOS
-	ROM_REGION( 0x400000, REGION_USER2, ROMREGION_ERASEFF ) // Slot A
-	ROM_REGION( 0x400000, REGION_USER3, ROMREGION_ERASEFF ) // Slot B
+	ROM_REGION( 0x400000, "user2", ROMREGION_ERASEFF ) // Slot A
+	ROM_REGION( 0x400000, "user3", ROMREGION_ERASEFF ) // Slot B
 
-	ROM_REGION( 0x1000000, REGION_CPU1, 0 )
-	ROM_COPY( REGION_USER1,   0x00000, 0x010000, 0x400000 )
-	ROM_COPY( REGION_USER1,   0x00000, 0x000000, 0x0008000 )
+	ROM_REGION( 0x1000000, "main", 0 )
+	ROM_COPY( "user1",   0x00000, 0x010000, 0x400000 )
+	ROM_COPY( "user1",   0x00000, 0x000000, 0x0008000 )
 ROM_END
 
 ROM_START( mac2bios )
 	MACS2_BIOS
-	ROM_REGION( 0x400000, REGION_USER2, ROMREGION_ERASEFF ) // Slot A
-	ROM_REGION( 0x400000, REGION_USER3, ROMREGION_ERASEFF ) // Slot B
+	ROM_REGION( 0x400000, "user2", ROMREGION_ERASEFF ) // Slot A
+	ROM_REGION( 0x400000, "user3", ROMREGION_ERASEFF ) // Slot B
 
-	ROM_REGION( 0x1000000, REGION_CPU1, 0 )
-	ROM_COPY( REGION_USER1,   0x00000, 0x010000, 0x400000 )
-	ROM_COPY( REGION_USER1,   0x00000, 0x000000, 0x0008000 )
+	ROM_REGION( 0x1000000, "main", 0 )
+	ROM_COPY( "user1",   0x00000, 0x010000, 0x400000 )
+	ROM_COPY( "user1",   0x00000, 0x000000, 0x0008000 )
 ROM_END
 
 ROM_START( kisekaem )
 	MACS_BIOS
 
-	ROM_REGION( 0x400000, REGION_USER2, 0 ) // Slot A
+	ROM_REGION( 0x400000, "user2", 0 ) // Slot A
 	ROM_LOAD16_BYTE( "am-mj.u8", 0x000000, 0x100000, CRC(3cf85151) SHA1(e05400065c384730f04ef565db5ba27eb3973d15) )
 	ROM_LOAD16_BYTE( "am-mj.u7", 0x000001, 0x100000, CRC(4b645354) SHA1(1dbf9141c3724e5dff2cd8066117fb1b94671a80) )
 	ROM_LOAD16_BYTE( "am-mj.u6", 0x200000, 0x100000, CRC(23b3aa24) SHA1(bfabdb16f9b1b60230bb636a944ab46fdfda49d7) )
 	ROM_LOAD16_BYTE( "am-mj.u5", 0x200001, 0x100000, CRC(b4d53e29) SHA1(d7683fdd5531bf1aa0ef1e4e6f517b31e2d5829e) )
 
 
-	ROM_REGION( 0x400000, REGION_USER3, ROMREGION_ERASEFF ) // Slot B
+	ROM_REGION( 0x400000, "user3", ROMREGION_ERASEFF ) // Slot B
 
-	ROM_REGION( 0x1000000, REGION_CPU1, 0 )
-	ROM_COPY( REGION_USER2,   0x00000, 0x010000, 0x400000 )
-	ROM_COPY( REGION_USER2,   0x00000, 0x000000, 0x0008000 )
+	ROM_REGION( 0x1000000, "main", 0 )
+	ROM_COPY( "user2",   0x00000, 0x010000, 0x400000 )
+	ROM_COPY( "user2",   0x00000, 0x000000, 0x0008000 )
 ROM_END
 
 ROM_START( kisekaeh )
 	MACS_BIOS
 
-	ROM_REGION( 0x400000, REGION_USER2, 0 ) // Slot A
+	ROM_REGION( 0x400000, "user2", 0 ) // Slot A
 	ROM_LOAD16_BYTE( "kh-u8.bin", 0x000000, 0x100000, CRC(601b9e6a) SHA1(54508a6db3928f78897df64ce400791e4789d0f6) )
 	ROM_LOAD16_BYTE( "kh-u7.bin", 0x000001, 0x100000, CRC(8f6e4bb3) SHA1(361545189feeda0887f930727d25655309b84629) )
 	ROM_LOAD16_BYTE( "kh-u6.bin", 0x200000, 0x100000, CRC(8e700204) SHA1(876e5530d749828de077293cb109a71b67cef140) )
 	ROM_LOAD16_BYTE( "kh-u5.bin", 0x200001, 0x100000, CRC(709bf7c8) SHA1(0a93e0c4f9be22a3302a1c5d2a6ec4739b202ea8) )
 
 
-	ROM_REGION( 0x400000, REGION_USER3, ROMREGION_ERASEFF ) // Slot B
+	ROM_REGION( 0x400000, "user3", ROMREGION_ERASEFF ) // Slot B
 
-	ROM_REGION( 0x1000000, REGION_CPU1, 0 )
-	ROM_COPY( REGION_USER2,   0x00000, 0x010000, 0x400000 )
-	ROM_COPY( REGION_USER2,   0x00000, 0x000000, 0x0008000 )
+	ROM_REGION( 0x1000000, "main", 0 )
+	ROM_COPY( "user2",   0x00000, 0x010000, 0x400000 )
+	ROM_COPY( "user2",   0x00000, 0x000000, 0x0008000 )
 ROM_END
 
 ROM_START( cultname ) // uses printer - two different games ? (slot a - checks for printer, slot b - not)
 	MACS_BIOS
 
-	ROM_REGION( 0x400000, REGION_USER3, 0 ) // Slot A
+	ROM_REGION( 0x400000, "user3", 0 ) // Slot A
 	ROM_LOAD16_BYTE( "cult-d0.u8", 0x000000, 0x100000, CRC(394bc1a6) SHA1(98df5406862234815b46c7b0ac0b19e4b597d1b6) )
 	ROM_LOAD16_BYTE( "cult-d1.u7", 0x000001, 0x100000, CRC(f628133b) SHA1(f06e20212074e5d95cc7d419ac8ce98fb9be3b62) )
 	ROM_LOAD16_BYTE( "cult-d2.u6", 0x200000, 0x100000, CRC(c5521bc6) SHA1(7554b56b0201b7d81754defa2244fb7ff7452bf6) )
 	ROM_LOAD16_BYTE( "cult-d3.u5", 0x200001, 0x100000, CRC(4325b09b) SHA1(45699a0444a221f893724754c917d33041cabcb9) )
 
 
-	ROM_REGION( 0x400000, REGION_USER2, 0 ) // Slot B
+	ROM_REGION( 0x400000, "user2", 0 ) // Slot B
 	ROM_LOAD16_BYTE( "cult-g0.u8", 0x000000, 0x100000, CRC(f5ab977b) SHA1(e7ee758cc2864500b339e236b944f98df9a1c10e) )
 	ROM_LOAD16_BYTE( "cult-g1.u7", 0x000001, 0x100000, CRC(32ae15a4) SHA1(061992efec1ed5527f200bf4c111344b156e759d) )
 	ROM_LOAD16_BYTE( "cult-g2.u6", 0x200000, 0x100000, CRC(30ed056d) SHA1(71735339bb501b94402ef403b5a2a60effa39c36) )
 	ROM_LOAD16_BYTE( "cult-g3.u5", 0x200001, 0x100000, CRC(fe58b418) SHA1(512f5c544cfafaa98bd2b3791ff1cf67adecec8d) )
 
 
-	ROM_REGION( 0x1000000, REGION_CPU1, 0 )
-	ROM_COPY( REGION_USER2,   0x00000, 0x010000, 0x400000 )
-	ROM_COPY( REGION_USER2,   0x00000, 0x000000, 0x0008000 )
+	ROM_REGION( 0x1000000, "main", 0 )
+	ROM_COPY( "user2",   0x00000, 0x010000, 0x400000 )
+	ROM_COPY( "user2",   0x00000, 0x000000, 0x0008000 )
 ROM_END
 
 /* these are listed as MACS2 sub-boards, is it the same?  - it's not ;) */
@@ -471,34 +470,34 @@ ROM_END
 ROM_START( yuka )
 	MACS2_BIOS
 
-	ROM_REGION( 0x400000, REGION_USER2, 0 ) // Slot A
+	ROM_REGION( 0x400000, "user2", 0 ) // Slot A
 
 	ROM_LOAD16_BYTE( "yu-ka_2.u6", 0x000001, 0x100000, CRC(c3c5728b) SHA1(e53cdcae556f34bab45d9342fd78ec29b6543c46) )
 	ROM_LOAD16_BYTE( "yu-ka_4.u5", 0x000000, 0x100000, CRC(7e391ee6) SHA1(3a0c122c9d0e2a91df6d8039fb958b6d00997747) )
 	ROM_LOAD16_BYTE( "yu-ka_1.u8", 0x200001, 0x100000, CRC(bccd1b15) SHA1(02511f3be60c53b5f5d90f12f0648f6e184ca667) )
 	ROM_LOAD16_BYTE( "yu-ka_3.u7", 0x200000, 0x100000, CRC(45b8263e) SHA1(59e1846c91dc39a086e8306260506673eb91de0b) )
 
-	ROM_REGION( 0x400000, REGION_USER3, ROMREGION_ERASE00 ) // Slot B
+	ROM_REGION( 0x400000, "user3", ROMREGION_ERASE00 ) // Slot B
 
-	ROM_REGION( 0x1000000, REGION_CPU1, 0 )
-	ROM_COPY( REGION_USER2,   0x00000, 0x010000, 0x400000 )
-	ROM_COPY( REGION_USER2,   0x00000, 0x000000, 0x0008000 )
+	ROM_REGION( 0x1000000, "main", 0 )
+	ROM_COPY( "user2",   0x00000, 0x010000, 0x400000 )
+	ROM_COPY( "user2",   0x00000, 0x000000, 0x0008000 )
 ROM_END
 
 ROM_START( yujan )
 	MACS2_BIOS
 
-	ROM_REGION( 0x400000, REGION_USER2, 0 ) // Slot A
+	ROM_REGION( 0x400000, "user2", 0 ) // Slot A
 	ROM_LOAD16_BYTE( "yu-jan_2.u6", 0x000001, 0x100000, CRC(2f4a8d4b) SHA1(4b328a253b1980a76f46a9a98a7f486813894a33) )
 	ROM_LOAD16_BYTE( "yu-jan_4.u5", 0x000000, 0x100000, CRC(226df87b) SHA1(a887728f1ea2ef5f6b4dcd6b5b61586f5e8f267d) )
 	ROM_LOAD16_BYTE( "yu-jan_1.u8", 0x200001, 0x100000, CRC(feeeee6a) SHA1(e9613f50d6d2e62fac6b529f81486250cfe83819) )
 	ROM_LOAD16_BYTE( "yu-jan_3.u7", 0x200000, 0x100000, CRC(1c1d6997) SHA1(9b07ae6b9ef1c0b57fbaa5fd0bcf1d2d7f17351f) )
 
-	ROM_REGION( 0x400000, REGION_USER3, ROMREGION_ERASEFF ) // Slot B
+	ROM_REGION( 0x400000, "user3", ROMREGION_ERASEFF ) // Slot B
 
-	ROM_REGION( 0x1000000, REGION_CPU1, 0 )
-	ROM_COPY( REGION_USER2,   0x00000, 0x010000, 0x400000 )
-	ROM_COPY( REGION_USER2,   0x00000, 0x000000, 0x0008000 )
+	ROM_REGION( 0x1000000, "main", 0 )
+	ROM_COPY( "user2",   0x00000, 0x010000, 0x400000 )
+	ROM_COPY( "user2",   0x00000, 0x000000, 0x0008000 )
 ROM_END
 
 static const UINT8 ramdata[160]=
@@ -545,11 +544,11 @@ static MACHINE_RESET(macs)
         730E: ED B0         ldir
         ...
 */
-		memcpy(macs_ram1 + 0x0e9f, memory_region(REGION_USER1)+0x7327, 0xc7);
-		memcpy(macs_ram1 + 0x1e9f, memory_region(REGION_USER1)+0x7327, 0xc7);
+		memcpy(macs_ram1 + 0x0e9f, memory_region(machine, "user1")+0x7327, 0xc7);
+		memcpy(macs_ram1 + 0x1e9f, memory_region(machine, "user1")+0x7327, 0xc7);
 
-		memcpy(macs_ram1 + 0x0800, memory_region(REGION_USER1)+0x73fa, 0x507);
-		memcpy(macs_ram1 + 0x1800, memory_region(REGION_USER1)+0x73fa, 0x507);
+		memcpy(macs_ram1 + 0x0800, memory_region(machine, "user1")+0x73fa, 0x507);
+		memcpy(macs_ram1 + 0x1800, memory_region(machine, "user1")+0x73fa, 0x507);
 
 #define MAKEJMP(n,m) 	macs_ram2[(n) - 0xe800 + 0]=0xc3;\
 						macs_ram2[(n) - 0xe800 + 1]=(m)&0xff;\
@@ -584,9 +583,9 @@ static MACHINE_RESET(macs)
 		macs_ram1[0x0ff9]=0x07;
 		macs_ram1[0x1ff9]=0x07;
 
-		memory_set_bankptr( 1, memory_region(REGION_CPU1) + 0x10000 );
-		memory_set_bankptr( 2, macs_ram1+0x800);
-		memory_set_bankptr( 3, macs_ram1+0x10000);
+		memory_set_bankptr(machine,  1, memory_region(machine, "main") + 0x10000 );
+		memory_set_bankptr(machine,  2, macs_ram1+0x800);
+		memory_set_bankptr(machine,  3, macs_ram1+0x10000);
 }
 
 static DRIVER_INIT(macs)
