@@ -25,21 +25,32 @@
     *** Hardware notes ***
 
 
-    - CPU  1x R6502P
-    - CRTC 1x MC6845P
-    - RAMs 1x MK48Z02B-20  (2K*8)  (near prg ROM)
-           2x HM6116LP-4   (2K*8)  (near GFX ROMs)
-    - CLK  1x oscillator 10.000 MHz
+    - CPU:  1x R6502P.
 
-    - ROMs 1x AM27128      (NS3.1)
-           2x SEEQ DQ2764  (1, 2)
-           1x SGS M2764    (NS1)
-    - PLDs 1x PAL16R4A     (read protected)
+    - CRTC: 1x MC6845P.
 
+    - RAM:  1x MK48Z02B-20.  CMOS 2K*8 zeropower SRAM (NVRAM).
+            2x HM6116LP-4.   2K*8 SRAM (Video RAM, only 1st half used).
+
+    - CLK:  1x crystal @ 10.000 MHz.
+
+    - ROMs: 1x AM27128.      (NS3.1)
+            2x SEEQ DQ2764.  (1, 2)
+            1x SGS M2764.    (NS1)
+
+    - PLDs: 1x PAL16R4A.     (read protected)
+
+    - SOUND: 1x delta-sigma DAC (1-bit/Bitstream).
+             1x TDA2002 (8W. car radio audio amplifier)
+
+
+    Other components:
+
+    - 3x OUAZ SS-112D  (relay 1 pole 12v)
     - 1x 4 DIP switches
     - 1x 30x2 edge connector
     - 1x 10 pins male connector
-    - 1x trimmer (volume)
+    - 2x trimmer (audio?)
 
 
     PCB Layout:
@@ -76,28 +87,25 @@
     | | HM6116       |    ________       _________                ____|
     | | o MSM2128    |   | 74LS08 |     | 74LS174 |               ____|
     | |______________|   |________|     |_________|               ____|
-    |  ________________   __________                              ____|
-    | |                | | PAL16R4A |                             ____|
-    | |     2764       | |__________|                             ____|
-    | |________________|  __________                              ____|
+    |  ________________   __________           ______             ____|
+    | |                | | PAL16R4A |         | TDA  |-           ____|
+    | |     2764       | |__________|         | 2002 |-           ____|
+    | |________________|  __________          |______|-           ____|
     |  ________________  | 74LS166  |                             ____|
-    | |                | |__________|                            |
-    | |     2764       |  __________                             |
-    | |________________| | 74LS166  |                            |____
-    |  ________________  |__________|                               __|
-    | |                |  __________       _________               |  |
-    | |     2764       | | 74LS166  |     | 74LS05  |              |8 |  10
-    | |________________| |__________|     |_________|              |8 |  pins
-    |  ________  ______   __________       _________               |8 |  male
-    | | 74LS04 || osc. | | 74LS193  |     | 74LS86  |              |8 |  connector
-    | |________||10 MHz| |__________|     |_________|              |8 |
-    |           |______|                                           |__|
+    | |                | |__________|      _                     |
+    | |     2764       |  __________     /   \                   |
+    | |________________| | 74LS166  |   | pot |                  |____
+    |  ________________  |__________|    \ _ /                      __|
+    | |                |  __________       _________         ______|  |
+    | |     2764       | | 74LS166  |     | 74LS05  |   _   |ss112d|8 |  10
+    | |________________| |__________|     |_________| /   \ |______|8 |  pins
+    |  ________  ______   __________       _________ | pot ||ss112d|8 |  male
+    | | 74LS04 || osc. | | 74LS193  |     | 74LS86  | \ _ / |______|8 |  connector
+    | |________||10 MHz| |__________|     |_________|       |ss112d|8 |
+    |           |______|                                    |______|__|
     |_________________________________________________________________|
 
 
-    Magic Fly & 7 e Mezzo PAL16R4A Fuse Maps were converted to the new bin format and added to respective sets.
-
-
     Pinouts (from 7mezzo pinout sheet)
     ----------------------------------
 
@@ -162,7 +170,7 @@
     Memory Map (magicfly)
     ---------------------
 
-    $0000 - $00FF    RAM    ; Zero page (pointers and registers).
+    $0000 - $00FF    RAM    ; Zero page (pointers and registers) (NVRAM).
 
         ($0D)            ; Incremented each time a NMI is triggered.
         ($1D)            ; In case of 0x00, NMI do nothing and return.
@@ -182,6 +190,7 @@
         ($56 - $58)      ; Store credits value (shown in the game under "Secondi").
         ($5A - $5C)      ; Store bonus value (shown in the game under "Credits").
         ($5E - $5F)      ; Store values to be written in video and color ram, respectively.
+        ($63 - $63)      ; Store position of marker/cursor (0-4).
         ($66 - $66)      ; Store number of baloon to be risen.
         ($67 - $67)      ; Program compare the content with 0x02, 0x03, 0x04, 0x05 and 0xE1.
                          ; If 0xE1 is found here, the machine hangs showing "I/O ERROR" (see code at $C1A2).
@@ -190,13 +199,13 @@
         ($6E - $6F)      ; Balloon #3 secondi (bet).
         ($70 - $71)      ; Balloon #4 secondi (bet).
         ($72 - $73)      ; Balloon #5 secondi (bet).
-        ($94)            ; Store bit 7 of content to be ORed with $39 and written to input selector at $3000.
+        ($94)            ; Store bit 7 of contents to be ORed with $39 and written to output port ($3000).
         ($96 - $98)      ; Store values from content of $2800 (input port) & 0x80, & 0x40, & 0x10.
         ($9B - $A8)      ; Text scroll buffer.
 
-    $0100 - $01FF    RAM    ; 6502 Stack Pointer.
+    $0100 - $01FF    RAM    ; 6502 Stack Pointer (NVRAM).
 
-    $0200 - $07FF    RAM    ; General purpose RAM.
+    $0200 - $07FF    RAM    ; General purpose RAM (NVRAM).
 
     $0800 - $0801    MC6845 ; MC6845 use $0800 for register addressing and $0801 for register values (see code at $CE86).
 
@@ -210,14 +219,18 @@
     $1800 - $1BFF    Color RAM  ; Initialized in subroutine starting at $CF83, filled with value stored in $5F.
                                 ; (In 7mezzo is located at $CB13 using $64 and $65 to store video and color ram values.)
 
-    $2800 - $2800    Input port ; Multiplexed input port (code at $CE96). Only reads.
-                                ; NMI routine read from here and store new values in $003A - $003D and copy old ones to $003F - $0042.
-                                ; Code accept only bits 0-3 & 5 as valid. If another bit is activated will produce an I/O error. (code at $CD0C)
+    $2800 - $2800    Input port ; Multiplexed input port (code at $CE96).
+                                ; NMI routine read from here and store new values in $3A-$3D and copy old ones to $3F-$42.
+                                ; Code accept only bits 0-1-2-3-5 as valid inputs. For DIP switches, only bits 4-6-7 are valid.
+                                ; If an invalid bit is activated, it will produce an I/O error. (code at $CD0C)
 
-    $3000 - $3000    Input selector  ; Only writes. NMI write 0x01, 0x02, 0x04, 0x08.
-                                     ; Main code at $C152 do a complex loop with boolean operations and write 0x00/0x80 here.
+    $3000 - $3000    Output port:
 
-    $C000 - $FFFF    ROM        ; Program ROMs.
+                         Input selector,  ; NMI writes the lower 4 bits to select input.
+                         Counters.        ; Bits 4-5-6 are used for Coin1, Coin2, and Payout counters.
+                         Sound DAC,       ; Bit 7 is used to transmit DAC data.
+
+    $C000 - $FFFF    ROM space       ; Program ROMs.
 
 
 *******************************************************************************
@@ -243,6 +256,63 @@
     his boards, converting one game to another.
 
 
+*******************************************************************************
+
+
+    Game Notes
+    ----------
+
+    Settings (valid for both games):
+
+    Press F2 to enter the input test (game should be without credits).
+    In the input test, you can exit with BET + DEAL, or access the bookkeeping
+    mode pressing BET + DEAL again. In the bookkeping mode keep pressed the PAYOUT
+    key and press BET to change the percentage (all books will be erased). Press
+    again BET + DEAL to exit to a quick RAM & sound test, and then to game mode.
+
+
+    * Magic Fly
+
+    How to play...
+
+    Insert coins to get credits.
+    Choose a balloon to raise, and select it with SELECT button. Bet on other balloons
+    using the SELECT/BET key (to bet 1 credit) or BETx10 (to bet 10 credits). Once done,
+    press the DEAL/LAST BET key to start the game. All balloons will explode revealing
+    numbers. The last one to explode will be the raised one. If your number(s) are higher
+    than the one hidden in the raised balloon, you'll win!
+
+    You can repeat the last bet pressing the DEAL/LAST BET key.
+
+
+    * 7 e Mezzo
+
+    This game is a sort of blackjack, but using a spanish cards set. The objetive is
+    to get 7 and half points (as 21 in blackjack). If you got more than 7 and half,
+    you're busted.
+
+    All cards have their own value, except for 10, 11 and 12 that are half point.
+    Special hands have their own price.
+
+    Sun 7 + sun king = 100 (by credit).
+    Any 7 + any king =  16 (by credit).
+    Any 7 and half   =   8 (by credit).
+    Pass             =   2 (by credit).
+
+
+    How to play...
+
+    Insert coins to get credits.
+    Bet using the BET button. Press DEAL to get the cards.
+    You can hit a new card pressing DEAL, or stop pressing STAND. The dealer will hit
+    cards to the maximum allowed. If you beat the dealer, you'll be asked to enter the
+    double-up game. Press DOUBLE to go on, or TAKE to get the credits.
+
+    In the double-up game, a covered card should be shown. Press BIG or SMALL to get
+    your chance...
+
+
+
 *******************************************************************************
 
 
@@ -300,21 +370,35 @@
     - Cleaned up and optimized the driver.
     - Reworked/updated technical notes.
 
+    [2008-03-14]
+    - Completed the component list & PCB layout.
+    - Added technical references to register $63 (magicfly).
+    - Switched crystal to new predefined format.
+
+    [2008-10-25]
+    - Added sound support to magicfly and 7mezzo.
+    - Hooked coin counters to magicfly and 7mezzo.
+    - Inverted the graphics banks to be straight with the hardware accesses.
+    - Updated the memory map description and technical notes.
+    - Added game notes and documented the test/settings/bookkeeping modes.
+
 
     TODO:
 
     - Correct colors. (where is the palette?)
-    - Figure out the sound. (no remaining writes...)
+    - Confirm the CPU clock (there is some lag in MF controls).
     - Split the driver.
 
 
 *******************************************************************************/
 
 
-#define MASTER_CLOCK	10000000	/* 10MHz */
+#define MASTER_CLOCK	XTAL_10MHz
 
 #include "driver.h"
-#include "video/crtc6845.h"
+#include "cpu/m6502/m6502.h"
+#include "video/mc6845.h"
+#include "sound/dac.h"
 
 
 /*************************
@@ -343,15 +427,14 @@ static TILE_GET_INFO( get_magicfly_tile_info )
     ---- x---   Seems to be a kind of attribute (maybe related to color). Not totally understood yet.
     ---x ----   Tiles bank.
     -xx- ----   Aparently not used.
-    x--- ----   Mirrored from bit 3. The code check this one to boot the game.  */
+    x--- ----   Mirrored from bit 3. The code check this one to boot the game.
 
+*/
 	int attr = colorram[tile_index];
 	int code = videoram[tile_index];
 	int bank = (attr & 0x10) >> 4;   /* bit 4 switch the gfx banks */
 	int color = attr & 0x07;         /* bits 0-2 for color */
 
-	bank = bank ^ 1;    /* GFX banks are inverted */
-
     /* Seems that bit 7 is mirrored from bit 3 to have a normal boot */
     /* Boot only check the first color RAM offset */
 
@@ -363,8 +446,7 @@ static TILE_GET_INFO( get_magicfly_tile_info )
 
 static VIDEO_START(magicfly)
 {
-	bg_tilemap = tilemap_create(get_magicfly_tile_info, tilemap_scan_rows,
-		TILEMAP_TYPE_PEN, 8, 8, 32, 29);
+	bg_tilemap = tilemap_create(machine, get_magicfly_tile_info, tilemap_scan_rows, 8, 8, 32, 29);
 }
 
 static TILE_GET_INFO( get_7mezzo_tile_info )
@@ -375,15 +457,14 @@ static TILE_GET_INFO( get_7mezzo_tile_info )
     ---- x---   Seems to be a kind of attribute (maybe related to color). Not totally understood yet.
     ---x ----   Tiles bank.
     -xx- ----   Aparently not used.
-    x--- ----   Mirrored from bit 2. The code check this one to boot the game.  */
+    x--- ----   Mirrored from bit 2. The code check this one to boot the game.
 
+*/
 	int attr = colorram[tile_index];
 	int code = videoram[tile_index];
 	int bank = (attr & 0x10) >> 4;    /* bit 4 switch the gfx banks */
 	int color = attr & 0x07;          /* bits 0-2 for color */
 
-	bank = bank ^ 1;    /* GFX banks are inverted */
-
     /* Seems that bit 7 is mirrored from bit 2 to have a normal boot */
     /* Boot only check the first color RAM offset */
 
@@ -395,8 +476,7 @@ static TILE_GET_INFO( get_7mezzo_tile_info )
 
 static VIDEO_START( 7mezzo )
 {
-	bg_tilemap = tilemap_create(get_7mezzo_tile_info, tilemap_scan_rows,
-		TILEMAP_TYPE_PEN, 8, 8, 32, 29);
+	bg_tilemap = tilemap_create(machine, get_7mezzo_tile_info, tilemap_scan_rows, 8, 8, 32, 29);
 }
 
 static VIDEO_UPDATE( magicfly )
@@ -407,19 +487,24 @@ static VIDEO_UPDATE( magicfly )
 
 static PALETTE_INIT( magicfly )
 {
-    /* 1st gfx bank */
-	palette_set_color(machine, 0, MAKE_RGB(0x00, 0x00, 0x00));
-	palette_set_color(machine, 2, MAKE_RGB(0x00, 0x00, 0x00));
-	palette_set_color(machine, 4, MAKE_RGB(0x00, 0x00, 0x00));
-	palette_set_color(machine, 6, MAKE_RGB(0x00, 0x00, 0x00));
-	palette_set_color(machine, 10, MAKE_RGB(0x00, 0x00, 0x00));
-	palette_set_color(machine, 11, MAKE_RGB(0x00, 0xff, 0x00));
-	palette_set_color(machine, 12, MAKE_RGB(0x00, 0x00, 0x00));
-	palette_set_color(machine, 14, MAKE_RGB(0x00, 0x00, 0x00));
+	int i;
 
-	/* 2nd gfx bank */
-	palette_set_color(machine, 22, MAKE_RGB(0xe0, 0xe0, 0xe0));
-	palette_set_color(machine, 23, MAKE_RGB(0xff, 0xff, 0xff));
+	for (i = 0; i < 0x100; i += 0x20)
+	{
+		/* 1st gfx bank */
+		palette_set_color(machine, i + 0, MAKE_RGB(0x00, 0x00, 0x00));
+		palette_set_color(machine, i + 2, MAKE_RGB(0x00, 0x00, 0x00));
+		palette_set_color(machine, i + 4, MAKE_RGB(0x00, 0x00, 0x00));
+		palette_set_color(machine, i + 6, MAKE_RGB(0x00, 0x00, 0x00));
+		palette_set_color(machine, i + 10, MAKE_RGB(0x00, 0x00, 0x00));
+		palette_set_color(machine, i + 11, MAKE_RGB(0x00, 0xff, 0x00));
+		palette_set_color(machine, i + 12, MAKE_RGB(0x00, 0x00, 0x00));
+		palette_set_color(machine, i + 14, MAKE_RGB(0x00, 0x00, 0x00));
+
+		/* 2nd gfx bank */
+		palette_set_color(machine, i + 22, MAKE_RGB(0xe0, 0xe0, 0xe0));
+		palette_set_color(machine, i + 23, MAKE_RGB(0xff, 0xff, 0xff));
+	}
 }
 
 
@@ -427,24 +512,39 @@ static PALETTE_INIT( magicfly )
 *         R/W Handlers        *
 ******************************/
 
-static int mux_data = 0;
+static int input_selector = 0;
 
 static READ8_HANDLER( mux_port_r )
 {
-	switch( mux_data & 0x0f )	/* bits 0-3 */
+	switch( input_selector )
 	{
-		case 0x01: return input_port_0_r(0);
-		case 0x02: return input_port_1_r(0);
-		case 0x04: return input_port_2_r(0);
-		case 0x08: return input_port_3_r(0);
-		case 0x00: return input_port_4_r(0);
+		case 0x01: return input_port_read(space->machine, "IN0-0"); break;
+		case 0x02: return input_port_read(space->machine, "IN0-1"); break;
+		case 0x04: return input_port_read(space->machine, "IN0-2"); break;
+		case 0x08: return input_port_read(space->machine, "IN0-3"); break;
+		case 0x00: return input_port_read(space->machine, "DSW0"); break;
 	}
 	return 0xff;
 }
 
-static WRITE8_HANDLER( mux_w )
+static WRITE8_HANDLER( mux_port_w )
 {
-	mux_data = data;
+/*  - bits -
+    7654 3210
+    ---- xxxx   Input selector.
+    ---x ----   Coin 2.
+    --x- ----   Payout.
+    -x-- ----   Coin 1.
+    x--- ----   Sound DAC.
+
+*/
+	input_selector = data & 0x0f;	/* Input Selector */
+
+	dac_data_w(0, data & 0x80);		/* Sound DAC */
+
+	coin_counter_w(0, data & 0x40);	/* Coin1 */
+	coin_counter_w(1, data & 0x10);	/* Coin2 */
+	coin_counter_w(2, data & 0x20);	/* Payout */
 }
 
 
@@ -454,13 +554,13 @@ static WRITE8_HANDLER( mux_w )
 
 static ADDRESS_MAP_START( magicfly_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_RAM AM_BASE(&generic_nvram) AM_SIZE(&generic_nvram_size)    /* MK48Z02B NVRAM */
-	AM_RANGE(0x0800, 0x0800) AM_WRITE(crtc6845_address_w)                                   /* MC6845P register addressing */
-	AM_RANGE(0x0801, 0x0801) AM_READWRITE(crtc6845_register_r, crtc6845_register_w)         /* MC6845P register values */
-	AM_RANGE(0x1000, 0x13ff) AM_RAM AM_WRITE(magicfly_videoram_w) AM_BASE(&videoram)        /* HM6116LP #1 (2K x 8) RAM (only 1st half used) */
-	AM_RANGE(0x1800, 0x1bff) AM_RAM AM_WRITE(magicfly_colorram_w) AM_BASE(&colorram)        /* HM6116LP #2 (2K x 8) RAM (only 1st half used) */
-	AM_RANGE(0x2800, 0x2800) AM_READ(mux_port_r)  /* multiplexed input port */
-	AM_RANGE(0x3000, 0x3000) AM_WRITE(mux_w)      /* input selector */
-	AM_RANGE(0xc000, 0xffff) AM_ROM               /* ROM space */
+	AM_RANGE(0x0800, 0x0800) AM_DEVWRITE(MC6845, "crtc", mc6845_address_w)
+	AM_RANGE(0x0801, 0x0801) AM_DEVREADWRITE(MC6845, "crtc", mc6845_register_r, mc6845_register_w)
+	AM_RANGE(0x1000, 0x13ff) AM_RAM_WRITE(magicfly_videoram_w) AM_BASE(&videoram)	/* HM6116LP #1 (2K x 8) RAM (only 1st half used) */
+	AM_RANGE(0x1800, 0x1bff) AM_RAM_WRITE(magicfly_colorram_w) AM_BASE(&colorram)	/* HM6116LP #2 (2K x 8) RAM (only 1st half used) */
+	AM_RANGE(0x2800, 0x2800) AM_READ(mux_port_r)	/* multiplexed input port */
+	AM_RANGE(0x3000, 0x3000) AM_WRITE(mux_port_w)	/* output port */
+	AM_RANGE(0xc000, 0xffff) AM_ROM					/* ROM space */
 ADDRESS_MAP_END
 
 
@@ -471,7 +571,7 @@ ADDRESS_MAP_END
 static INPUT_PORTS_START( magicfly )
 /*  Multiplexed 4 x 5 bits.
     Code accept only bits 0, 1, 2, 3 and 5 as valid. */
-	PORT_START_TAG("IN0-0")
+	PORT_START("IN0-0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )	/* present in the input test */
@@ -481,7 +581,7 @@ static INPUT_PORTS_START( magicfly )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("IN0-1")
+	PORT_START("IN0-1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )	/* present in the input test */
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )	/* present in the input test */
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON5 ) PORT_NAME("Payout") PORT_CODE(KEYCODE_Q)
@@ -491,7 +591,7 @@ static INPUT_PORTS_START( magicfly )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("IN0-2")
+	PORT_START("IN0-2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )	/* present in the input test */
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )	/* present in the input test */
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_2WAY
@@ -501,7 +601,7 @@ static INPUT_PORTS_START( magicfly )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("IN0-3")
+	PORT_START("IN0-3")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_NAME("Deal / Last Bet") PORT_CODE(KEYCODE_C)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_NAME("Cancel") PORT_CODE(KEYCODE_V)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE )
@@ -511,7 +611,7 @@ static INPUT_PORTS_START( magicfly )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("DSW0")    /* Only 4 phisical DIP switches (valid bits = 4, 6, 7) */
+	PORT_START("DSW0")    /* Only 4 phisical DIP switches (valid bits = 4, 6, 7) */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNUSED )
@@ -533,7 +633,7 @@ INPUT_PORTS_END
 static INPUT_PORTS_START( 7mezzo )
 /*  Multiplexed 4 x 5 bits.
     Code accept only bits 0, 1, 2, 3 and 5 as valid. */
-	PORT_START_TAG("IN0-0")
+	PORT_START("IN0-0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )	/* present in the input test */
@@ -543,7 +643,7 @@ static INPUT_PORTS_START( 7mezzo )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("IN0-1")
+	PORT_START("IN0-1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON6 ) PORT_NAME("Big") PORT_CODE(KEYCODE_A)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON7 ) PORT_NAME("Small") PORT_CODE(KEYCODE_S)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME("Payout") PORT_CODE(KEYCODE_Q)
@@ -553,7 +653,7 @@ static INPUT_PORTS_START( 7mezzo )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("IN0-2")
+	PORT_START("IN0-2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )	/* present in the input test */
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )	/* present in the input test */
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )	/* present in the input test */
@@ -563,7 +663,7 @@ static INPUT_PORTS_START( 7mezzo )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("IN0-3")
+	PORT_START("IN0-3")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_NAME("Deal / Last Bet") PORT_CODE(KEYCODE_Z)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_NAME("Stand") PORT_CODE(KEYCODE_X)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE )
@@ -573,7 +673,7 @@ static INPUT_PORTS_START( 7mezzo )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("DSW0")    /* Only 4 phisical DIP switches (valid bits = 4, 6, 7) */
+	PORT_START("DSW0")    /* Only 4 phisical DIP switches (valid bits = 4, 6, 7) */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNUSED )
@@ -597,6 +697,17 @@ INPUT_PORTS_END
 *    Graphics Layouts    *
 *************************/
 
+static const gfx_layout tilelayout =
+{
+	8, 8,
+	256,
+	3,
+	{ 0, 0x2800*8, 0x4800*8 },	/* bitplanes are separated. */
+	{ 0, 1, 2, 3, 4, 5, 6, 7 },
+	{ 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8 },
+	8*8
+};
+
 static const gfx_layout charlayout =
 {
 	8, 8,
@@ -608,28 +719,34 @@ static const gfx_layout charlayout =
 	8*8
 };
 
-static const gfx_layout tilelayout =
-{
-	8, 8,
-	256,
-	3,
-	{ 0, (0x2800*8), (0x4800*8) },	/* bitplanes are separated. */
-	{ 0, 1, 2, 3, 4, 5, 6, 7 },
-	{ 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8 },
-	8*8
-};
-
 
 /******************************
 * Graphics Decode Information *
 ******************************/
 
 static GFXDECODE_START( magicfly )
-	GFXDECODE_ENTRY( REGION_GFX1,	0x1800,	charlayout, 0, 16 )
-	GFXDECODE_ENTRY( REGION_GFX1,	0x1000,	tilelayout, 16, 16 )
+	GFXDECODE_ENTRY( "gfx1", 0x1000, tilelayout, 16, 16 )
+	GFXDECODE_ENTRY( "gfx1", 0x1800, charlayout, 0, 16 )
 GFXDECODE_END
 
 
+/************************
+*    CRTC Interface    *
+************************/
+
+static const mc6845_interface mc6845_intf =
+{
+	"main",		/* screen we are acting on */
+	8,			/* number of pixels per video memory address */
+	NULL,		/* before pixel update callback */
+	NULL,		/* row update callback */
+	NULL,		/* after pixel update callback */
+	NULL,		/* callback for display state changes */
+	NULL,		/* HSYNC callback */
+	NULL		/* VSYNC callback */
+};
+
+
 /*************************
 *    Machine Drivers     *
 *************************/
@@ -637,36 +754,39 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( magicfly )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", M6502, MASTER_CLOCK/12)	/* guess */
+	MDRV_CPU_ADD("main", M6502, MASTER_CLOCK/12)	/* guess */
 	MDRV_CPU_PROGRAM_MAP(magicfly_map, 0)
-	MDRV_CPU_VBLANK_INT(nmi_line_pulse, 1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", nmi_line_pulse)
 
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE((39+1)*8, (31+1)*8)				/* Taken from MC6845 init, registers 00 & 04. Normally programmed with (value-1). */
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 29*8-1)	/* Taken from MC6845 init, registers 01 & 06. */
 
 	MDRV_GFXDECODE(magicfly)
-	MDRV_PALETTE_LENGTH(32)
+	MDRV_PALETTE_LENGTH(256)
 	MDRV_PALETTE_INIT(magicfly)
-	MDRV_COLORTABLE_LENGTH(256)
 
 	MDRV_VIDEO_START(magicfly)
 	MDRV_VIDEO_UPDATE(magicfly)
 
+	MDRV_MC6845_ADD("crtc", MC6845, MASTER_CLOCK/16, mc6845_intf) /* guess */
+
+	/* sound hardware */
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD("dac", DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 static MACHINE_DRIVER_START( 7mezzo )
 
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(magicfly)
-	MDRV_CPU_MODIFY("main")
 
 	/* video hardware */
 	MDRV_VIDEO_START(7mezzo)
@@ -679,29 +799,29 @@ MACHINE_DRIVER_END
 *************************/
 
 ROM_START( magicfly )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "magicfly3_3.bin",	0xc000, 0x4000, CRC(c29798d5) SHA1(bf92ac93d650398569b3ab79d01344e74a6d35be) )
 
-	ROM_REGION( 0x6000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x6000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "magicfly2.bin",	0x0000, 0x2000, CRC(3596a45b) SHA1(7ec32ec767d0883d05606beb588d8f27ba8f10a4) )
 	ROM_LOAD( "magicfly1.bin",	0x2000, 0x2000, CRC(724d330c) SHA1(cce3923ce48634b27f0e7d29979cd36e7394ab37) )
 	ROM_LOAD( "magicfly0.bin",	0x4000, 0x2000, CRC(44e3c9d6) SHA1(677d25360d261bf2400f399b8015eeb529ad405e) )
 
-	ROM_REGION( 0x0200, REGION_PLDS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0200, "plds", ROMREGION_DISPOSE )
 	ROM_LOAD( "pal16r4a-magicfly.bin",	0x0000, 0x0104, NO_DUMP )	/* PAL is read protected */
 
 ROM_END
 
 ROM_START( 7mezzo )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "ns3_1.bin",	0xc000, 0x4000, CRC(b1867b76) SHA1(eb76cffb81c865352f4767015edade54801f6155) )
 
-	ROM_REGION( 0x6000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x6000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "ns2.bin",	0x0000, 0x2000, CRC(7983a41c) SHA1(68805ea960c2738d3cd2c7490ffed84f90da029b) )    /* Renamed as ns2.bin regarding pcb location and content */
 	ROM_LOAD( "ns1.bin",	0x2000, 0x2000, CRC(a6ada872) SHA1(7f531a76e73d479161e485bdcf816eb8eb9fdc62) )
 	ROM_LOAD( "ns0.bin",	0x4000, 0x2000, CRC(e04fb210) SHA1(81e764e296fe387daf8ca67064d5eba2a4fc3c26) )    /* Renamed as ns0.bin regarding pcb location and content */
 
-	ROM_REGION( 0x0200, REGION_PLDS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0200, "plds", ROMREGION_DISPOSE )
 	ROM_LOAD( "pal16r4a-7mezzo.bin",	0x0000, 0x0104, CRC(61ac7372) SHA1(7560506468a7409075094787182ded24e2d0c0a3) )
 ROM_END
 
@@ -711,5 +831,5 @@ ROM_END
 *************************/
 
 /*    YEAR  NAME      PARENT  MACHINE   INPUT     INIT   ROT    COMPANY      FULLNAME    FLAGS... */
-GAME( 198?, magicfly, 0,      magicfly, magicfly, 0,     ROT0, "P&A Games", "Magic Fly", GAME_IMPERFECT_COLORS | GAME_NO_SOUND )
-GAME( 198?, 7mezzo,   0,      7mezzo,   7mezzo,   0,     ROT0, "Unknown",   "7 e Mezzo", GAME_IMPERFECT_COLORS | GAME_NO_SOUND )
+GAME( 198?, magicfly, 0,      magicfly, magicfly, 0,     ROT0, "P&A Games", "Magic Fly", GAME_IMPERFECT_COLORS )
+GAME( 198?, 7mezzo,   0,      7mezzo,   7mezzo,   0,     ROT0, "Unknown",   "7 e Mezzo", GAME_IMPERFECT_COLORS )
