@@ -95,8 +95,9 @@ p2 ink doesn't always light up in test mode
 */
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
 
-static mame_bitmap *tile, *obj1, *obj2;
+static bitmap_t *tile, *obj1, *obj2;
 static tilemap *tx_tilemap;
 
 static UINT8 *tx_tileram;
@@ -115,17 +116,17 @@ static WRITE8_HANDLER( tx_tileram_w )
 }
 
 static ADDRESS_MAP_START( marinedt_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x37ff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x4000, 0x43ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x4400, 0x47ff) AM_READ(MRA8_RAM)	//unused, vram mirror?
-	AM_RANGE(0x4000, 0x4bff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0000, 0x37ff) AM_READ(SMH_ROM)
+	AM_RANGE(0x4000, 0x43ff) AM_READ(SMH_RAM)
+	AM_RANGE(0x4400, 0x47ff) AM_READ(SMH_RAM)	//unused, vram mirror?
+	AM_RANGE(0x4000, 0x4bff) AM_READ(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( marinedt_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x37ff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x4000, 0x47ff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x0000, 0x37ff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x4000, 0x47ff) AM_WRITE(SMH_RAM)
 	AM_RANGE(0x4800, 0x4bff) AM_WRITE(tx_tileram_w) AM_BASE(&tx_tileram)
-	AM_RANGE(0x4c00, 0x4c00) AM_WRITE(MWA8_NOP)	//?? maybe off by one error
+	AM_RANGE(0x4c00, 0x4c00) AM_WRITE(SMH_NOP)	//?? maybe off by one error
 ADDRESS_MAP_END
 
 static READ8_HANDLER( marinedt_port1_r )
@@ -133,7 +134,7 @@ static READ8_HANDLER( marinedt_port1_r )
 //might need to be reversed for cocktail stuff
 
 	/* x/y multiplexed */
-	return readinputport(3 + ((marinedt_pf&0x08)>>3));
+	return input_port_read(space->machine, ((marinedt_pf & 0x08)>>3) ? "TRACKY" : "TRACKX");
 }
 
 static READ8_HANDLER( marinedt_coll_r )
@@ -157,7 +158,7 @@ static READ8_HANDLER( marinedt_obj1_x_r )
 	//xxxx---- unknown
 	//----xxxx x pos in tile ram
 
-	UINT8 *RAM = memory_region(REGION_CPU1);
+	UINT8 *RAM = memory_region(space->machine, "main");
 if(RAM[0x430e]) --cx; else ++cx;
 //figure out why inc/dec based on 430e?
 	return cx | (cxh<<4);
@@ -185,27 +186,14 @@ static READ8_HANDLER( marinedt_obj1_yq_r )
 	return cyq | (cyqh<<4);
 }
 
+static WRITE8_HANDLER( marinedt_obj1_a_w ) { marinedt_obj1_a = data; }
+static WRITE8_HANDLER( marinedt_obj1_x_w ) { marinedt_obj1_x = data; }
+static WRITE8_HANDLER( marinedt_obj1_y_w ) { marinedt_obj1_y = data; }
+static WRITE8_HANDLER( marinedt_obj2_a_w ) { marinedt_obj2_a = data; }
+static WRITE8_HANDLER( marinedt_obj2_x_w ) { marinedt_obj2_x = data; }
+static WRITE8_HANDLER( marinedt_obj2_y_w ) { marinedt_obj2_y = data; }
 
-static ADDRESS_MAP_START( marinedt_readport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x00, 0x00) AM_READ(input_port_0_r)		//dips coinage
-	AM_RANGE(0x01, 0x01) AM_READ(marinedt_port1_r)		//trackball xy muxed
-	AM_RANGE(0x02, 0x02) AM_READ(marinedt_obj1_x_r)
-	AM_RANGE(0x03, 0x03) AM_READ(input_port_1_r)		//buttons
-	AM_RANGE(0x04, 0x04) AM_READ(input_port_2_r)		//dips
-	AM_RANGE(0x06, 0x06) AM_READ(marinedt_obj1_yr_r)
-	AM_RANGE(0x0a, 0x0a) AM_READ(marinedt_obj1_yq_r)
-	AM_RANGE(0x0e, 0x0e) AM_READ(marinedt_coll_r)
-ADDRESS_MAP_END
-
-static WRITE8_HANDLER( marinedt_obj1_a_w ) {	marinedt_obj1_a = data; }
-static WRITE8_HANDLER( marinedt_obj1_x_w ) {	marinedt_obj1_x = data; }
-static WRITE8_HANDLER( marinedt_obj1_y_w ) {	marinedt_obj1_y = data; }
-static WRITE8_HANDLER( marinedt_obj2_a_w ) {	marinedt_obj2_a = data; }
-static WRITE8_HANDLER( marinedt_obj2_x_w ) {	marinedt_obj2_x = data; }
-static WRITE8_HANDLER( marinedt_obj2_y_w ) {	marinedt_obj2_y = data; }
-
-static WRITE8_HANDLER( marinedt_music_w ){	marinedt_music = data; }
+static WRITE8_HANDLER( marinedt_music_w ){ marinedt_music = data; }
 
 static WRITE8_HANDLER( marinedt_sound_w )
 {
@@ -278,27 +266,31 @@ static WRITE8_HANDLER( marinedt_pf_w )
 
 //if(data&0xf0)
 //  logerror("pf:%02x %d\n",marinedt_pf);
-//logerror("pd:%02x %d\n",marinedt_pd, cpu_getcurrentframe());
+//logerror("pd:%02x %d\n",marinedt_pd, video_screen_get_frame_number(space->machine->primary_screen));
 
 }
 
-static ADDRESS_MAP_START( marinedt_writeport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x02, 0x02) AM_WRITE(marinedt_obj1_a_w)
-	AM_RANGE(0x03, 0x03) AM_WRITE(marinedt_obj1_x_w)
-	AM_RANGE(0x04, 0x04) AM_WRITE(marinedt_obj1_y_w)
+
+static ADDRESS_MAP_START( marinedt_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x00, 0x00) AM_READ_PORT("DSW0")		//dips coinage
+	AM_RANGE(0x01, 0x01) AM_READ(marinedt_port1_r)	//trackball xy muxed
+	AM_RANGE(0x02, 0x02) AM_READWRITE(marinedt_obj1_x_r, marinedt_obj1_a_w)
+	AM_RANGE(0x03, 0x03) AM_READ_PORT("IN0") AM_WRITE(marinedt_obj1_x_w)
+	AM_RANGE(0x04, 0x04) AM_READ_PORT("DSW1") AM_WRITE(marinedt_obj1_y_w)
 	AM_RANGE(0x05, 0x05) AM_WRITE(marinedt_music_w)
-	AM_RANGE(0x06, 0x06) AM_WRITE(marinedt_sound_w)
+	AM_RANGE(0x06, 0x06) AM_READWRITE(marinedt_obj1_yr_r, marinedt_sound_w)
 	AM_RANGE(0x08, 0x08) AM_WRITE(marinedt_obj2_a_w)
 	AM_RANGE(0x09, 0x09) AM_WRITE(marinedt_obj2_x_w)
-	AM_RANGE(0x0a, 0x0a) AM_WRITE(marinedt_obj2_y_w)
+	AM_RANGE(0x0a, 0x0a) AM_READWRITE(marinedt_obj1_yq_r, marinedt_obj2_y_w)
 	AM_RANGE(0x0d, 0x0d) AM_WRITE(marinedt_pd_w)
-	AM_RANGE(0x0e, 0x0e) AM_WRITE(watchdog_reset_w)
+	AM_RANGE(0x0e, 0x0e) AM_READWRITE(marinedt_coll_r, watchdog_reset_w)
 	AM_RANGE(0x0f, 0x0f) AM_WRITE(marinedt_pf_w)
 ADDRESS_MAP_END
 
+
 static INPUT_PORTS_START( marinedt )
-	PORT_START	/* IN0 */
+	PORT_START("DSW0")		/* IN0 */
 	PORT_DIPNAME( 0x0f, 0x00, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x0f, DEF_STR( 9C_1C ) )
 	PORT_DIPSETTING(    0x0e, DEF_STR( 8C_1C ) )
@@ -334,7 +326,7 @@ static INPUT_PORTS_START( marinedt )
 	PORT_DIPSETTING(    0x60, DEF_STR( 1C_7C ) )
 	PORT_DIPSETTING(    0x70, DEF_STR( 1C_8C ) )
 
-	PORT_START	/* IN1 */
+	PORT_START("IN0")		/* IN1 */
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_SERVICE1 )
@@ -344,7 +336,7 @@ static INPUT_PORTS_START( marinedt )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_START2 )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_START1 )
 
-	PORT_START	/* IN2 */
+	PORT_START("DSW1")		/* IN2 */
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Bonus_Life ) )
 	PORT_DIPSETTING(    0x01, "5000" )
 	PORT_DIPSETTING(    0x00, "10000" )
@@ -354,7 +346,7 @@ static INPUT_PORTS_START( marinedt )
 	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
 //freezes the game before the reset
 //doesn't seem to be done as a dip, but what about mixing with diops like this?
-	PORT_BIT(0x04, IP_ACTIVE_HIGH, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_TOGGLE PORT_CODE(KEYCODE_F2)
+	PORT_SERVICE( 0x04, IP_ACTIVE_HIGH )
 	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Cabinet ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( Upright ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Cocktail ) )
@@ -370,11 +362,11 @@ static INPUT_PORTS_START( marinedt )
 	PORT_DIPSETTING(    0x80, "5" )
 	PORT_DIPSETTING(    0xc0, "6" )
 
-	PORT_START  /* IN3 - FAKE MUXED */
+	PORT_START("TRACKX")	/* IN3 - FAKE MUXED */
 //check all bits are used
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(25) PORT_KEYDELTA(10) PORT_REVERSE
 
-	PORT_START  /* IN4 - FAKE MUXED */
+	PORT_START("TRACKY")	/* IN4 - FAKE MUXED */
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(25) PORT_KEYDELTA(10)
 INPUT_PORTS_END
 
@@ -401,16 +393,16 @@ static const gfx_layout marinedt_objlayout =
 };
 
 static GFXDECODE_START( marinedt )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, marinedt_charlayout, 0,  4 )	//really only 1 colour set?
-	GFXDECODE_ENTRY( REGION_GFX2, 0, marinedt_objlayout,  48, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0, marinedt_objlayout,  32, 4 )
+	GFXDECODE_ENTRY( "gfx1", 0, marinedt_charlayout, 0,  4 )	//really only 1 colour set?
+	GFXDECODE_ENTRY( "gfx2", 0, marinedt_objlayout,  48, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0, marinedt_objlayout,  32, 4 )
 GFXDECODE_END
 
 static PALETTE_INIT( marinedt )
 {
 	int i,r,b,g;
 
-	for (i = 0;i < machine->drv->total_colors; i++)
+	for (i = 0;i < machine->config->total_colors; i++)
 	{
 		int bit0,bit1,bit2;
 
@@ -450,15 +442,15 @@ static TILE_GET_INFO( get_tile_info )
 
 static VIDEO_START( marinedt )
 {
-	tx_tilemap = tilemap_create(get_tile_info, tilemap_scan_rows, TILEMAP_TYPE_PEN, 8, 8,32,32);
+	tx_tilemap = tilemap_create(machine, get_tile_info, tilemap_scan_rows, 8, 8,32,32);
 
 	tilemap_set_transparent_pen(tx_tilemap, 0);
 	tilemap_set_scrolldx(tx_tilemap, 0, 4*8);
 	tilemap_set_scrolldy(tx_tilemap, 0, -4*8);
 
-	tile = auto_bitmap_alloc(32 * 8, 32 * 8, machine->screen[0].format);
-	obj1 = auto_bitmap_alloc(32,32,machine->screen[0].format);
-	obj2 = auto_bitmap_alloc(32,32,machine->screen[0].format);
+	tile = auto_bitmap_alloc(32 * 8, 32 * 8, video_screen_get_format(machine->primary_screen));
+	obj1 = auto_bitmap_alloc(32,32,video_screen_get_format(machine->primary_screen));
+	obj2 = auto_bitmap_alloc(32,32,video_screen_get_format(machine->primary_screen));
 }
 
 
@@ -479,34 +471,34 @@ static VIDEO_UPDATE( marinedt )
 {
 	int sx, sy;
 
-	fillbitmap(tile, machine->pens[0], NULL);
+	bitmap_fill(tile, NULL, 0);
 	tilemap_draw(tile, cliprect, tx_tilemap, 0, 0);
 
-	fillbitmap(obj1, machine->pens[0], NULL);
-	drawgfx(obj1, machine->gfx[1],
+	bitmap_fill(obj1, NULL, 0);
+	drawgfx(obj1, screen->machine->gfx[1],
 			OBJ_CODE(marinedt_obj1_a),
 			OBJ_COLOR(marinedt_obj1_a),
 			OBJ_FLIPX(marinedt_obj1_a), OBJ_FLIPY(marinedt_obj1_a),
 			0, 0,
 			NULL, TRANSPARENCY_PEN, 0);
 
-	fillbitmap(obj2, machine->pens[0], NULL);
-	drawgfx(obj2, machine->gfx[2],
+	bitmap_fill(obj2, NULL, 0);
+	drawgfx(obj2, screen->machine->gfx[2],
 			OBJ_CODE(marinedt_obj2_a),
 			OBJ_COLOR(marinedt_obj2_a),
 			OBJ_FLIPX(marinedt_obj2_a), OBJ_FLIPY(marinedt_obj2_a),
 			0, 0,
 			NULL, TRANSPARENCY_PEN, 0);
 
-	fillbitmap(bitmap, machine->pens[0], NULL);
+	bitmap_fill(bitmap, NULL, 0);
 
 	if (marinedt_pd & 0x02)
-		copybitmap_trans(bitmap, obj2, 0, 0, OBJ_X(marinedt_obj2_x), OBJ_Y(marinedt_obj2_y), cliprect, machine->pens[0]);
+		copybitmap_trans(bitmap, obj2, 0, 0, OBJ_X(marinedt_obj2_x), OBJ_Y(marinedt_obj2_y), cliprect, 0);
 
 	if (marinedt_pd & 0x01)
-		copybitmap_trans(bitmap, obj1, 0, 0, OBJ_X(marinedt_obj1_x), OBJ_Y(marinedt_obj1_y), cliprect, machine->pens[0]);
+		copybitmap_trans(bitmap, obj1, 0, 0, OBJ_X(marinedt_obj1_x), OBJ_Y(marinedt_obj1_y), cliprect, 0);
 
-	copybitmap_trans(bitmap, tile, 0, 0, 0, 0, cliprect, machine->pens[0]);
+	copybitmap_trans(bitmap, tile, 0, 0, 0, 0, cliprect, 0);
 
 	coll = cx = cyr = cyq = 0;
 	if (marinedt_pd & 0x01)
@@ -521,10 +513,10 @@ static VIDEO_UPDATE( marinedt )
 				 || y < cliprect->min_y || y > cliprect->max_y)
 					continue;
 
-				if (*BITMAP_ADDR16(obj1, sy, sx) == machine->pens[0])
+				if (*BITMAP_ADDR16(obj1, sy, sx) == 0)
 					continue;
 
-				if (*BITMAP_ADDR16(tile, y, x) != machine->pens[0])
+				if (*BITMAP_ADDR16(tile, y, x) != 0)
 				{
 					coll = 0x08;
 
@@ -558,10 +550,10 @@ static VIDEO_UPDATE( marinedt )
 				 || yy < 0 || yy >= 32)
 					continue;
 
-				if (*BITMAP_ADDR16(obj1, sy, sx) == machine->pens[0])
+				if (*BITMAP_ADDR16(obj1, sy, sx) == 0)
 					continue;
 
-				if (*BITMAP_ADDR16(obj2, yy, xx) != machine->pens[0])
+				if (*BITMAP_ADDR16(obj2, yy, xx) != 0)
 				{
 					collh = 0x80;
 
@@ -584,19 +576,19 @@ static VIDEO_UPDATE( marinedt )
 static MACHINE_DRIVER_START( marinedt )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80,10000000/4)
+	MDRV_CPU_ADD("main", Z80,10000000/4)
 	MDRV_CPU_PROGRAM_MAP(marinedt_readmem,marinedt_writemem)
-	MDRV_CPU_IO_MAP(marinedt_readport,marinedt_writeport)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_IO_MAP(marinedt_io_map,0)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(4*8+32*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 4*8, 32*8-1)
+
 	MDRV_GFXDECODE(marinedt)
 	MDRV_PALETTE_LENGTH(64)
 
@@ -616,7 +608,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( marinedt )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "mg01",     0x0000, 0x0800, CRC(ad09f04d) SHA1(932fc973b4a2fbbebd7e6437ed30c8444e3d4afb))
 	ROM_LOAD( "mg02",     0x0800, 0x0800, CRC(555a2b0f) SHA1(143a8953ce5070c31dc4c1f623833b2a5a2cf657))
 	ROM_LOAD( "mg03",     0x1000, 0x0800, CRC(2abc79b3) SHA1(1afb331a2c0e320b6d026bc5cb47a53ac3356c2a))
@@ -625,18 +617,18 @@ ROM_START( marinedt )
 	ROM_LOAD( "mg06",     0x2800, 0x0800, CRC(a7e2c69b) SHA1(614fc479d13c1726382fe7b4b0379c1dd4915af0) )
 	ROM_LOAD( "mg07",     0x3000, 0x0800, CRC(b85d1f9a) SHA1(4fd3e76b1816912df84477dba4655d395f5e7072) )
 
-	ROM_REGION( 0x1800, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1800, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "mg09",     0x0000, 0x0800, CRC(f4c349ca) SHA1(077f65eeac616a778d6c42bb95677fa2892ab697) )
 	ROM_LOAD( "mg10",     0x0800, 0x0800, CRC(b41251e3) SHA1(e125a971b401c78efeb4b03d0fab43e392d3fc14) )
 	ROM_LOAD( "mg11",     0x1000, 0x0800, CRC(50d66dd7) SHA1(858d1d2a75e091b0e382d964c5e4ddcd8e6f07dd))
 
-	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "mg12",     0x0000, 0x1000, CRC(7c6486d5) SHA1(a7f17a803937937f05fc90621883a0fd44b297a0) )
 
-	ROM_REGION( 0x1000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "mg13",     0x0000, 0x1000, CRC(17817044) SHA1(8c9b96620e3c414952e6d85c6e81b0df85c88e7a) )
 
-	ROM_REGION( 0x0080, REGION_PROMS, 0 )
+	ROM_REGION( 0x0080, "proms", 0 )
 	ROM_LOAD( "mg14.bpr", 0x0000, 0x0020, CRC(f75f4e3a) SHA1(36e665987f475c57435fa8c224a2a3ce0c5e672b) )	//char clr
 	ROM_LOAD( "mg15.bpr", 0x0020, 0x0020, CRC(cd3ab489) SHA1(a77478fb94d0cf8f4317f89cc9579def7c294b4f) )	//obj clr
 	ROM_LOAD( "mg16.bpr", 0x0040, 0x0020, CRC(92c868bc) SHA1(483ae6f47845ddacb701528e82bd388d7d66a0fb) )	//?? collisions
@@ -644,3 +636,4 @@ ROM_START( marinedt )
 ROM_END
 
 GAME( 1981, marinedt, 0, marinedt, marinedt, 0, ROT270, "Taito", "Marine Date", GAME_NO_SOUND )
+
