@@ -46,7 +46,7 @@ static emu_timer *mcu_timer;
 
 static READ8_HANDLER( mcu_portA_r )
 {
-	portA_in = readinputport(5) | (readinputport(4) << 4) | (readinputport(0) << 5);
+	portA_in = input_port_read(space->machine, "dsw") | (input_port_read(space->machine, "coin") << 4) | (input_port_read(space->machine, "console") << 5);
 	return (portA_in & ~ddrA) | (portA_out & ddrA);
 }
 
@@ -79,14 +79,14 @@ static WRITE8_HANDLER( mcu_portB_w )
 
 	/* clear coin interrupt */
 	if (data & 0x04)
-		cpunum_set_input_line(Machine, 1, M6805_IRQ_LINE, CLEAR_LINE );
+		cpu_set_input_line(space->machine->cpu[1], M6805_IRQ_LINE, CLEAR_LINE );
 
 	/* AUDMUTE */
 	sound_global_enable((data >> 5) & 1);
 
 	/* RES600 */
 	if (diff & 0x10)
-		cpunum_set_input_line(Machine, 0, INPUT_LINE_RESET, (data & 0x10) ? CLEAR_LINE : ASSERT_LINE);
+		cpu_set_input_line(space->machine->cpu[0], INPUT_LINE_RESET, (data & 0x10) ? CLEAR_LINE : ASSERT_LINE);
 
 	/* latch for lamps */
 	if ((diff & 0x40) && !(data & 0x40))
@@ -154,7 +154,7 @@ static TIMER_CALLBACK( mcu_timer_proc )
 		if ( (tcr & 0x40) == 0 )
 		{
 			//timer interrupt!
-			cpunum_set_input_line(machine, 1, M68705_INT_TIMER, PULSE_LINE );
+			generic_pulse_irq_line(machine->cpu[1], M68705_INT_TIMER);
 		}
 	}
 }
@@ -202,7 +202,7 @@ static WRITE8_HANDLER( mcu_tcr_w )
 		}
 
 		period = attotime_mul(ATTOTIME_IN_HZ(3579545), divider);
-		timer_adjust( mcu_timer, period, 0, period);
+		timer_adjust_periodic( mcu_timer, period, 0, period);
 	}
 }
 
@@ -212,7 +212,7 @@ static MACHINE_RESET(supervisor_board)
 	portB_in = portB_out = ddrB	= 0;
 	portC_in = portC_out = ddrC	= 0;
 	tdr = tcr = 0;
-	mcu_timer = timer_alloc( mcu_timer_proc , NULL);
+	mcu_timer = timer_alloc(machine,  mcu_timer_proc , NULL);
 
 	output_set_lamp_value(0, 0);
 	output_set_lamp_value(1, 0);
@@ -223,12 +223,10 @@ static MACHINE_RESET(supervisor_board)
 	output_set_digit_value(2, 0x00);
 }
 
-static INTERRUPT_GEN( supervisor_board_check_coin_input )
+static INPUT_CHANGED( coin_inserted )
 {
-	if ( !readinputport(4) )
-	{
-		cpunum_set_input_line(machine, 1, M6805_IRQ_LINE, HOLD_LINE );
-	}
+	if (!newval)
+		cpu_set_input_line(field->port->machine->cpu[1], M6805_IRQ_LINE, HOLD_LINE );
 }
 
 int atari_input_disabled(void)
@@ -240,7 +238,7 @@ int atari_input_disabled(void)
 
 static ADDRESS_MAP_START(a600xl_mem, ADDRESS_SPACE_PROGRAM, 8)
 	AM_RANGE(0x0000, 0x3fff) AM_RAM
-	AM_RANGE(0x5000, 0x57ff) AM_ROM AM_REGION(REGION_CPU1, 0x5000)	/* self test */
+	AM_RANGE(0x5000, 0x57ff) AM_ROM AM_REGION("main", 0x5000)	/* self test */
 	AM_RANGE(0x8000, 0xbfff) AM_ROM	/* game cartridge */
 	AM_RANGE(0xc000, 0xcfff) AM_ROM /* OS */
 	AM_RANGE(0xd000, 0xd0ff) AM_READWRITE(atari_gtia_r, atari_gtia_w)
@@ -253,7 +251,7 @@ static ADDRESS_MAP_START(a600xl_mem, ADDRESS_SPACE_PROGRAM, 8)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( mcu_mem, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(11) )
+	ADDRESS_MAP_GLOBAL_MASK(0x7ff)
 	AM_RANGE(0x0000, 0x0000) AM_READ( mcu_portA_r ) AM_WRITE( mcu_portA_w )
 	AM_RANGE(0x0001, 0x0001) AM_READ( mcu_portB_r ) AM_WRITE( mcu_portB_w )
 	AM_RANGE(0x0002, 0x0002) AM_READ( mcu_portC_r ) AM_WRITE( mcu_portC_w )
@@ -269,12 +267,12 @@ ADDRESS_MAP_END
 
 static INPUT_PORTS_START( a600xl )
 
-    PORT_START_TAG("console")  /* IN0 console keys & switch settings */
+    PORT_START("console")  /* IN0 console keys & switch settings */
 	PORT_BIT(0x04, 0x04, IPT_KEYBOARD) PORT_NAME("Option") PORT_CODE(KEYCODE_F2)
 	PORT_BIT(0x02, 0x02, IPT_KEYBOARD) PORT_NAME("Select") PORT_CODE(KEYCODE_F1)
 	PORT_BIT(0x01, 0x01, IPT_START1 )
 
-	PORT_START_TAG("djoy_0_1")	/* IN1 digital joystick #1 + #2 (PIA port A) */
+	PORT_START("djoy_0_1")	/* IN1 digital joystick #1 + #2 (PIA port A) */
 	PORT_BIT(0x01, 0x01, IPT_JOYSTICK_UP) PORT_PLAYER(1)
 	PORT_BIT(0x02, 0x02, IPT_JOYSTICK_DOWN) PORT_PLAYER(1)
 	PORT_BIT(0x04, 0x04, IPT_JOYSTICK_LEFT) PORT_PLAYER(1)
@@ -285,7 +283,7 @@ static INPUT_PORTS_START( a600xl )
 	PORT_BIT(0x40, 0x40, IPT_JOYSTICK_LEFT) PORT_PLAYER(2)
 	PORT_BIT(0x80, 0x80, IPT_JOYSTICK_RIGHT) PORT_PLAYER(2)
 
-	PORT_START_TAG("djoy_2_3")	/* IN2 digital joystick #3 + #4 (PIA port B) */
+	PORT_START("djoy_2_3")	/* IN2 digital joystick #3 + #4 (PIA port B) */
 	/* not connected */
 	PORT_BIT(0x01, 0x01, IPT_JOYSTICK_UP) PORT_PLAYER(3)
 	PORT_BIT(0x02, 0x02, IPT_JOYSTICK_DOWN) PORT_PLAYER(3)
@@ -296,7 +294,7 @@ static INPUT_PORTS_START( a600xl )
 	PORT_BIT(0x40, 0x40, IPT_JOYSTICK_LEFT) PORT_PLAYER(4)
 	PORT_BIT(0x80, 0x80, IPT_JOYSTICK_RIGHT) PORT_PLAYER(4)
 
-	PORT_START_TAG("djoy_b")	/* IN3 digital joystick buttons (GTIA button bits) */
+	PORT_START("djoy_b")	/* IN3 digital joystick buttons (GTIA button bits) */
 	PORT_BIT(0x01, 0x01, IPT_BUTTON1) PORT_PLAYER(1)
 	PORT_BIT(0x02, 0x02, IPT_BUTTON1) PORT_PLAYER(2)
 	PORT_BIT(0x04, 0x04, IPT_BUTTON1) PORT_PLAYER(3)
@@ -307,10 +305,10 @@ static INPUT_PORTS_START( a600xl )
 	PORT_BIT(0x80, 0x80, IPT_BUTTON2) PORT_PLAYER(4)
 
 	/* Max-A-Flex specific ports */
-	PORT_START	/* IN4 coin */
-	PORT_BIT(0x1, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_START("coin")	/* IN4 coin */
+	PORT_BIT(0x1, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_CHANGED(coin_inserted, 0)
 
-	PORT_START	/* IN5 DSW */
+	PORT_START("dsw")	/* IN5 DSW */
 	PORT_DIPNAME(0xf, 0x9, "Coin/Time" )
 	PORT_DIPSETTING( 0x0, "30 sec" )
 	PORT_DIPSETTING( 0x1, "60 sec" )
@@ -422,7 +420,7 @@ static PALETTE_INIT( atari )
 }
 
 
-static const struct POKEYinterface pokey_interface = {
+static const pokey_interface pokey_config = {
 	{ 0 },
 	0,
 	0,0,
@@ -431,23 +429,23 @@ static const struct POKEYinterface pokey_interface = {
 
 static MACHINE_DRIVER_START( a600xl )
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", M6502, FREQ_17_EXACT)
+	MDRV_CPU_ADD("main", M6502, FREQ_17_EXACT)
 	MDRV_CPU_PROGRAM_MAP(a600xl_mem, 0)
-	MDRV_CPU_VBLANK_INT(a800xl_interrupt, TOTAL_LINES_60HZ)
-	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MDRV_CPU_VBLANK_INT_HACK(a800xl_interrupt, TOTAL_LINES_60HZ)
 
-	MDRV_CPU_ADD(M68705, 3579545)
+	MDRV_CPU_ADD("mcu", M68705, 3579545)
 	MDRV_CPU_PROGRAM_MAP(mcu_mem,0)
-	MDRV_CPU_PERIODIC_INT( supervisor_board_check_coin_input, 10 )
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES( VIDEO_TYPE_RASTER )
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_VISIBLE_AREA(MIN_X, MAX_X, MIN_Y, MAX_Y)
-	MDRV_PALETTE_LENGTH(sizeof(atari_palette) / sizeof(atari_palette[0]))
-	MDRV_PALETTE_INIT(atari)
 	MDRV_SCREEN_REFRESH_RATE(FRAME_RATE_60HZ)
 	MDRV_SCREEN_SIZE(HWIDTH*8, TOTAL_LINES_60HZ)
+
+	MDRV_PALETTE_LENGTH(sizeof(atari_palette) / sizeof(atari_palette[0]))
+	MDRV_PALETTE_INIT(atari)
 	MDRV_DEFAULT_LAYOUT(layout_maxaflex)
 
 	MDRV_VIDEO_START(atari)
@@ -456,11 +454,11 @@ static MACHINE_DRIVER_START( a600xl )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(POKEY, FREQ_17_EXACT)
-	MDRV_SOUND_CONFIG(pokey_interface)
+	MDRV_SOUND_ADD("pokey", POKEY, FREQ_17_EXACT)
+	MDRV_SOUND_CONFIG(pokey_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_SOUND_ADD(SPEAKER, 0)
+	MDRV_SOUND_ADD("speaker", SPEAKER, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 
 	MDRV_MACHINE_START( a600xl )
@@ -472,68 +470,69 @@ static MACHINE_DRIVER_START( maxaflex )
 MACHINE_DRIVER_END
 
 ROM_START(maxaflex)
-	ROM_REGION(0x10000,REGION_CPU1,0) /* 64K for the CPU */
+	ROM_REGION(0x10000,"main",0) /* 64K for the CPU */
     ROM_LOAD("atarixl.rom", 0xc000, 0x4000, CRC(1f9cd270) SHA1(ae4f523ba08b6fd59f3cae515a2b2410bbd98f55))
 
-	ROM_REGION( 0x0800, REGION_CPU2, 0 )	/* 2k for the microcontroller */
+	ROM_REGION( 0x0800, "mcu", 0 )	/* 2k for the microcontroller */
 	ROM_LOAD("maxaflex.uc",  0x0000, 0x0800, CRC(fe9cf53c) SHA1(4b02bc2f0c8a1eab799814fac82d5812c0160206))
 
-	ROM_REGION( 0x200, REGION_PROMS, 0 )
+	ROM_REGION( 0x200, "proms", 0 )
 	ROM_LOAD("maxprom.prm", 0x0000, 0x0200, CRC(edf5c950) SHA1(9ad046ea41a61585dd8d2f2d4167a3cc39d2928f))	/* for simulating keystrokes ?*/
 ROM_END
 
 ROM_START(mf_bdash)
-	ROM_REGION(0x10000,REGION_CPU1,0) /* 64K for the CPU */
+	ROM_REGION(0x10000,"main",0) /* 64K for the CPU */
 	ROM_LOAD("bd-acs-1.rom",	0x8000, 0x2000, CRC(2b11750e) SHA1(43e9ae44eb1767621920bb94a4370ed602d81056))
 	ROM_LOAD("bd-acs-2.rom",	0xa000, 0x2000, CRC(e9ea2658) SHA1(189ede7201ef122cf2b72fc847a896b9dbe007e5))
     ROM_LOAD("atarixl.rom",		0xc000, 0x4000, CRC(1f9cd270) SHA1(ae4f523ba08b6fd59f3cae515a2b2410bbd98f55))
 
-	ROM_REGION( 0x0800, REGION_CPU2, 0 )	/* 2k for the microcontroller */
+	ROM_REGION( 0x0800, "mcu", 0 )	/* 2k for the microcontroller */
 	ROM_LOAD("maxaflex.uc",  0x0000, 0x0800, CRC(fe9cf53c) SHA1(4b02bc2f0c8a1eab799814fac82d5812c0160206))
 
-	ROM_REGION( 0x200, REGION_PROMS, 0 )
+	ROM_REGION( 0x200, "proms", 0 )
 	ROM_LOAD("maxprom.prm", 0x0000, 0x0200, CRC(edf5c950) SHA1(9ad046ea41a61585dd8d2f2d4167a3cc39d2928f))	/* for simulating keystrokes ?*/
 ROM_END
 
 ROM_START(mf_achas)
-	ROM_REGION(0x10000,REGION_CPU1,0) /* 64K for the CPU */
+	ROM_REGION(0x10000,"main",0) /* 64K for the CPU */
 	ROM_LOAD("ac.rom",			0x8000, 0x4000, CRC(18752991) SHA1(f508b89d2251c53d017cff6cb23b8e9880a0cc0b))
     ROM_LOAD("atarixl.rom",		0xc000, 0x4000, CRC(1f9cd270) SHA1(ae4f523ba08b6fd59f3cae515a2b2410bbd98f55))
 
-	ROM_REGION( 0x0800, REGION_CPU2, 0 )	/* 2k for the microcontroller */
+	ROM_REGION( 0x0800, "mcu", 0 )	/* 2k for the microcontroller */
 	ROM_LOAD("maxaflex.uc",  0x0000, 0x0800, CRC(fe9cf53c) SHA1(4b02bc2f0c8a1eab799814fac82d5812c0160206))
 
-	ROM_REGION( 0x200, REGION_PROMS, 0 )
+	ROM_REGION( 0x200, "proms", 0 )
 	ROM_LOAD("maxprom.prm", 0x0000, 0x0200, CRC(edf5c950) SHA1(9ad046ea41a61585dd8d2f2d4167a3cc39d2928f))	/* for simulating keystrokes ?*/
 ROM_END
 
 ROM_START(mf_brist)
-	ROM_REGION(0x10000,REGION_CPU1,0) /* 64K for the CPU */
+	ROM_REGION(0x10000,"main",0) /* 64K for the CPU */
 	ROM_LOAD("brist.rom",		0x8000, 0x4000, CRC(4263d64d) SHA1(80a041bceb499e1466516488013aa4439b3db6f2))
     ROM_LOAD("atarixl.rom",		0xc000, 0x4000, CRC(1f9cd270) SHA1(ae4f523ba08b6fd59f3cae515a2b2410bbd98f55))
 
-	ROM_REGION( 0x0800, REGION_CPU2, 0 )	/* 2k for the microcontroller */
+	ROM_REGION( 0x0800, "mcu", 0 )	/* 2k for the microcontroller */
 	ROM_LOAD("maxaflex.uc",  0x0000, 0x0800, CRC(fe9cf53c) SHA1(4b02bc2f0c8a1eab799814fac82d5812c0160206))
 
-	ROM_REGION( 0x200, REGION_PROMS, 0 )
+	ROM_REGION( 0x200, "proms", 0 )
 	ROM_LOAD("maxprom.prm", 0x0000, 0x0200, CRC(edf5c950) SHA1(9ad046ea41a61585dd8d2f2d4167a3cc39d2928f))	/* for simulating keystrokes ?*/
 ROM_END
 
 ROM_START(mf_flip)
-	ROM_REGION(0x10000,REGION_CPU1,0) /* 64K for the CPU */
+	ROM_REGION(0x10000,"main",0) /* 64K for the CPU */
 	ROM_LOAD("flipflop.rom",	0x8000, 0x4000, CRC(8ae057be) SHA1(ba26d6a3790ebdb754c1192b2c28f0fe93aca377))
     ROM_LOAD("atarixl.rom",		0xc000, 0x4000, CRC(1f9cd270) SHA1(ae4f523ba08b6fd59f3cae515a2b2410bbd98f55))
 
-	ROM_REGION( 0x0800, REGION_CPU2, 0 )	/* 2k for the microcontroller */
+	ROM_REGION( 0x0800, "mcu", 0 )	/* 2k for the microcontroller */
 	ROM_LOAD("maxaflex.uc",  0x0000, 0x0800, CRC(fe9cf53c) SHA1(4b02bc2f0c8a1eab799814fac82d5812c0160206))
 
-	ROM_REGION( 0x200, REGION_PROMS, 0 )
+	ROM_REGION( 0x200, "proms", 0 )
 	ROM_LOAD("maxprom.prm", 0x0000, 0x0200, CRC(edf5c950) SHA1(9ad046ea41a61585dd8d2f2d4167a3cc39d2928f))	/* for simulating keystrokes ?*/
 ROM_END
 
 static DRIVER_INIT( a600xl )
 {
-	memcpy( memory_region(REGION_CPU1) + 0x5000, memory_region(REGION_CPU1) + 0xd000, 0x800 );
+	UINT8 *rom = memory_region(machine, "main");
+	memcpy( rom + 0x5000, rom + 0xd000, 0x800 );
 }
 
 GAME( 1984, maxaflex, 0,        maxaflex, a600xl, a600xl, ROT0, "Exidy", "Max-A-Flex", GAME_IS_BIOS_ROOT )
