@@ -36,7 +36,7 @@ TO DO:
 ****************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
 #include "sound/ay8910.h"
 
 static UINT8 *cfb_ram;
@@ -100,14 +100,14 @@ static PALETTE_INIT( mazerbla )
 }
 
 
-static mame_bitmap * tmpbitmaps[4];
+static bitmap_t * tmpbitmaps[4];
 
 static VIDEO_START( mazerbla )
 {
-	tmpbitmaps[0] = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
-	tmpbitmaps[1] = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
-	tmpbitmaps[2] = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
-	tmpbitmaps[3] = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
+	tmpbitmaps[0] = video_screen_auto_bitmap_alloc(machine->primary_screen);
+	tmpbitmaps[1] = video_screen_auto_bitmap_alloc(machine->primary_screen);
+	tmpbitmaps[2] = video_screen_auto_bitmap_alloc(machine->primary_screen);
+	tmpbitmaps[3] = video_screen_auto_bitmap_alloc(machine->primary_screen);
 }
 
 #if 0
@@ -135,7 +135,7 @@ VIDEO_UPDATE( test_vcu )
 		color_base = 0x0;
 
 
-	fillbitmap(bitmap,0,NULL);
+	bitmap_fill(bitmap,NULL,0);
 //logerror("-->frame\n");
 
 
@@ -144,18 +144,18 @@ VIDEO_UPDATE( test_vcu )
 
 
 	if (planes_enabled[2])
-		copybitmap_trans(bitmap,tmpbitmaps[2],0,0,0,0,cliprect,machine->pens[color_base] );
-	fillbitmap(tmpbitmaps[2],machine->pens[color_base],NULL);
+		copybitmap_trans(bitmap,tmpbitmaps[2],0,0,0,0,cliprect,color_base);
+	bitmap_fill(tmpbitmaps[2],NULL,color_base);
 
 
 	if (planes_enabled[1])
-		copybitmap_trans(bitmap,tmpbitmaps[1],0,0,0,0,cliprect,machine->pens[color_base] );
-	fillbitmap(tmpbitmaps[1],machine->pens[color_base],NULL);
+		copybitmap_trans(bitmap,tmpbitmaps[1],0,0,0,0,cliprect,color_base);
+	bitmap_fill(tmpbitmaps[1],NULL,color_base);
 
 
 	if (planes_enabled[0])
-		copybitmap_trans(bitmap,tmpbitmaps[0],0,0,0,0,cliprect,machine->pens[color_base] );
-	fillbitmap(tmpbitmaps[0],machine->pens[color_base],NULL);
+		copybitmap_trans(bitmap,tmpbitmaps[0],0,0,0,0,cliprect,color_base);
+	bitmap_fill(tmpbitmaps[0],NULL,color_base);
 
 	if (input_code_pressed_once(KEYCODE_1))	/* plane 1 */
 	{
@@ -248,12 +248,12 @@ static VIDEO_UPDATE( greatgun )
 	if (game_id==GREATGUN)
 		color_base = 0x0;
 
-//fillbitmap(bitmap,0,NULL);
+//bitmap_fill(bitmap,NULL,0);
 
 	copybitmap      (bitmap,tmpbitmaps[3],0,0,0,0,cliprect);
-	copybitmap_trans(bitmap,tmpbitmaps[2],0,0,0,0,cliprect,machine->pens[color_base] );
-	copybitmap_trans(bitmap,tmpbitmaps[1],0,0,0,0,cliprect,machine->pens[color_base] );
-	copybitmap_trans(bitmap,tmpbitmaps[0],0,0,0,0,cliprect,machine->pens[color_base] );
+	copybitmap_trans(bitmap,tmpbitmaps[2],0,0,0,0,cliprect,color_base);
+	copybitmap_trans(bitmap,tmpbitmaps[1],0,0,0,0,cliprect,color_base);
+	copybitmap_trans(bitmap,tmpbitmaps[0],0,0,0,0,cliprect,color_base);
 	return 0;
 }
 
@@ -268,12 +268,12 @@ static VIDEO_UPDATE( mazerbla )
 	if (game_id==GREATGUN)
 		color_base = 0x0;
 
-//fillbitmap(bitmap,0,NULL);
+//bitmap_fill(bitmap,NULL,0);
 
 	copybitmap      (bitmap,tmpbitmaps[3],0,0,0,0,cliprect); //text
-	copybitmap_trans(bitmap,tmpbitmaps[2],0,0,0,0,cliprect,machine->pens[0] );
-	copybitmap_trans(bitmap,tmpbitmaps[1],0,0,0,0,cliprect,machine->pens[0] ); //haircross
-	copybitmap_trans(bitmap,tmpbitmaps[0],0,0,0,0,cliprect,machine->pens[0] ); //sprites
+	copybitmap_trans(bitmap,tmpbitmaps[2],0,0,0,0,cliprect,0);
+	copybitmap_trans(bitmap,tmpbitmaps[1],0,0,0,0,cliprect,0); //haircross
+	copybitmap_trans(bitmap,tmpbitmaps[0],0,0,0,0,cliprect,0); //sprites
 	return 0;
 }
 
@@ -284,7 +284,7 @@ static WRITE8_HANDLER( cfb_zpu_int_req_set_w )
 {
 	zpu_int_vector &= ~2;	/* clear D1 on INTA (interrupt acknowledge) */
 
-	cpunum_set_input_line(Machine, 0, 0, ASSERT_LINE);	/* main cpu interrupt (comes from CFB (generated at the start of INT routine on CFB) - vblank?) */
+	cpu_set_input_line(space->machine->cpu[0], 0, ASSERT_LINE);	/* main cpu interrupt (comes from CFB (generated at the start of INT routine on CFB) - vblank?) */
 }
 
 static READ8_HANDLER( cfb_zpu_int_req_clr )
@@ -293,13 +293,13 @@ static READ8_HANDLER( cfb_zpu_int_req_clr )
 
 	/* clear the INT line when there are no more interrupt requests */
 	if (zpu_int_vector==0xff)
-		cpunum_set_input_line(Machine, 0, 0, CLEAR_LINE);
+		cpu_set_input_line(space->machine->cpu[0], 0, CLEAR_LINE);
 
 	return 0;
 }
 
 
-static int irq_callback(int irqline)
+static IRQ_CALLBACK(irq_callback)
 {
 /* all data lines are tied to +5V via 10K resistors */
 /* D1 is set to GND when INT comes from CFB */
@@ -336,7 +336,7 @@ static UINT8 ls670_1[4];
 static READ8_HANDLER( ls670_0_r )
 {
 	/* set a timer to force synchronization after the read */
-	timer_call_after_resynch(NULL, 0, NULL);
+	timer_call_after_resynch(space->machine, NULL, 0, NULL);
 
 	return ls670_0[offset];
 }
@@ -352,7 +352,7 @@ static TIMER_CALLBACK( deferred_ls670_0_w )
 static WRITE8_HANDLER( ls670_0_w )
 {
 	/* do this on a timer to let the CPUs synchronize */
-	timer_call_after_resynch(NULL, (offset<<8) | data, deferred_ls670_0_w);
+	timer_call_after_resynch(space->machine, NULL, (offset<<8) | data, deferred_ls670_0_w);
 }
 
 
@@ -360,7 +360,7 @@ static WRITE8_HANDLER( ls670_0_w )
 static READ8_HANDLER( ls670_1_r )
 {
 	/* set a timer to force synchronization after the read */
-	timer_call_after_resynch(NULL, 0, NULL);
+	timer_call_after_resynch(space->machine, NULL, 0, NULL);
 
 	return ls670_1[offset];
 }
@@ -376,7 +376,7 @@ static TIMER_CALLBACK( deferred_ls670_1_w )
 static WRITE8_HANDLER( ls670_1_w )
 {
 	/* do this on a timer to let the CPUs synchronize */
-	timer_call_after_resynch(NULL, (offset<<8) | data, deferred_ls670_1_w);
+	timer_call_after_resynch(space->machine, NULL, (offset<<8) | data, deferred_ls670_1_w);
 }
 
 
@@ -436,11 +436,12 @@ Vertical movement of gun is Strobe 9, Bits 0-7.
 
 static READ8_HANDLER( zpu_inputs_r )
 {
+	static const char *const strobenames[] = { "ZPU", "DSW0", "DSW1", "DSW2", "DSW3", "BUTTONS", "STICK0_X", "STICK0_Y", "STICK1_X", "STICK1_Y" };
 	UINT8 ret = 0;
 
 	if (bcd_7445<10)
 	{
-		ret = readinputport( bcd_7445 );
+		ret = input_port_read(space->machine, strobenames[bcd_7445]);
 	}
 	return ret;
 }
@@ -470,34 +471,29 @@ static WRITE8_HANDLER(zpu_coin_counter_w)
 	coin_counter_w(offset, (data&0x40)>>6 );
 }
 
-static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x4c, 0x4f) AM_READ(ls670_1_r)
-	AM_RANGE(0x62, 0x62) AM_READ(zpu_inputs_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x4c, 0x4f) AM_WRITE(ls670_0_w)
+static ADDRESS_MAP_START( io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x4c, 0x4f) AM_READWRITE(ls670_1_r, ls670_0_w)
 	AM_RANGE(0x60, 0x60) AM_WRITE(zpu_bcd_decoder_w)
+	AM_RANGE(0x62, 0x62) AM_READ(zpu_inputs_r)
 	AM_RANGE(0x68, 0x68) AM_WRITE(zpu_coin_counter_w)
 	AM_RANGE(0x6a, 0x6a) AM_WRITE(zpu_lamps_w)
 	AM_RANGE(0x6e, 0x6f) AM_WRITE(zpu_led_w)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
+	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
 	AM_RANGE(0xc000, 0xc7ff) AM_READ(sharedram_CFB_ZPU_r)
 	AM_RANGE(0xd800, 0xd800) AM_READ(cfb_zpu_int_req_clr)
-	AM_RANGE(0xe000, 0xe7ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xe800, 0xefff) AM_READ(MRA8_RAM)
+	AM_RANGE(0xe000, 0xe7ff) AM_READ(SMH_RAM)
+	AM_RANGE(0xe800, 0xefff) AM_READ(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x0000, 0x7fff) AM_WRITE(SMH_ROM)
 	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(sharedram_CFB_ZPU_w)
-	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(MWA8_RAM) AM_BASE(&videoram) AM_SIZE(&videoram_size)
-	AM_RANGE(0xe800, 0xefff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(SMH_RAM) AM_BASE(&videoram) AM_SIZE(&videoram_size)
+	AM_RANGE(0xe800, 0xefff) AM_WRITE(SMH_RAM)
 ADDRESS_MAP_END
 
 
@@ -512,27 +508,22 @@ static WRITE8_HANDLER( vsb_ls273_audio_control_w )
 }
 
 
-static ADDRESS_MAP_START( readport_cpu2, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x80, 0x83) AM_READ(ls670_0_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writeport_cpu2, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+static ADDRESS_MAP_START( cpu2_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_WRITE(vsb_ls273_audio_control_w)
-	AM_RANGE(0x80, 0x83) AM_WRITE(ls670_1_w)
+	AM_RANGE(0x80, 0x83) AM_READWRITE(ls670_0_r, ls670_1_w)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readmem_cpu2, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x4000, 0x43ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x8000, 0x83ff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0000, 0x1fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x4000, 0x43ff) AM_READ(SMH_RAM)
+	AM_RANGE(0x8000, 0x83ff) AM_READ(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem_cpu2, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x4000, 0x43ff) AM_WRITE(MWA8_RAM) /* main RAM (stack) */
-	AM_RANGE(0x8000, 0x83ff) AM_WRITE(MWA8_RAM) /* waveform ???*/
+	AM_RANGE(0x0000, 0x1fff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x4000, 0x43ff) AM_WRITE(SMH_RAM) /* main RAM (stack) */
+	AM_RANGE(0x8000, 0x83ff) AM_WRITE(SMH_RAM) /* waveform ???*/
 ADDRESS_MAP_END
 
 
@@ -584,7 +575,7 @@ static WRITE8_HANDLER(cfb_backgnd_color_w)
 		bit0 = (data >> 0) & 0x01;
 		b = combine_3_weights(weights_b, bit0, bit1, bit2);
 
-		palette_set_color(Machine, 255, MAKE_RGB(r, g, b));
+		palette_set_color(space->machine, 255, MAKE_RGB(r, g, b));
 		//logerror("background color (port 01) write=%02x\n",data);
 	}
 }
@@ -605,13 +596,13 @@ static WRITE8_HANDLER(cfb_rom_bank_sel_w)	/* mazer blazer */
 {
 	gfx_rom_bank = data;
 
-	memory_set_bankptr( 1, memory_region(REGION_CPU3) + (gfx_rom_bank * 0x2000) + 0x10000 );
+	memory_set_bankptr(space->machine,  1, memory_region(space->machine, "sub2") + (gfx_rom_bank * 0x2000) + 0x10000 );
 }
 static WRITE8_HANDLER(cfb_rom_bank_sel_w_gg)	/* great guns */
 {
 	gfx_rom_bank = data>>1;
 
-	memory_set_bankptr( 1, memory_region(REGION_CPU3) + (gfx_rom_bank * 0x2000) + 0x10000 );
+	memory_set_bankptr(space->machine,  1, memory_region(space->machine, "sub2") + (gfx_rom_bank * 0x2000) + 0x10000 );
 }
 
 
@@ -623,33 +614,28 @@ static READ8_HANDLER( cfb_port_02_r )
 	return (port02_status);
 }
 
-static ADDRESS_MAP_START( readport_cpu3, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x02, 0x02) AM_READ(cfb_port_02_r)	/* VCU status ? */
-ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( writeport_cpu3_mb, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+static ADDRESS_MAP_START( cpu3_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x01, 0x01) AM_WRITE(cfb_backgnd_color_w)
-	AM_RANGE(0x02, 0x02) AM_WRITE(cfb_led_w)
+	AM_RANGE(0x02, 0x02) AM_READWRITE(cfb_port_02_r, cfb_led_w)	/* Read = VCU status ? */
 	AM_RANGE(0x03, 0x03) AM_WRITE(cfb_zpu_int_req_set_w)
 	AM_RANGE(0x04, 0x04) AM_WRITE(cfb_rom_bank_sel_w)
 	AM_RANGE(0x05, 0x05) AM_WRITE(cfb_vbank_w)	//visible/writable videopage select?
 ADDRESS_MAP_END
-
 /* Great Guns has a little different banking layout */
-static ADDRESS_MAP_START( writeport_cpu3_gg, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x00, 0x00) AM_WRITE(MWA8_NOP)
+
+static ADDRESS_MAP_START( gg_cpu3_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x00, 0x00) AM_WRITE(SMH_NOP)
 	AM_RANGE(0x01, 0x01) AM_WRITE(cfb_backgnd_color_w)
-	AM_RANGE(0x02, 0x02) AM_WRITE(cfb_led_w)
+	AM_RANGE(0x02, 0x02) AM_READWRITE(cfb_port_02_r, cfb_led_w)	/* Read = VCU status ? */
 	AM_RANGE(0x03, 0x03) AM_WRITE(cfb_zpu_int_req_set_w)
 	AM_RANGE(0x04, 0x04) AM_WRITE(cfb_rom_bank_sel_w_gg)
 	AM_RANGE(0x05, 0x05) AM_WRITE(cfb_vbank_w)	//visible/writable videopage select?
 ADDRESS_MAP_END
 
 
-
 static UINT8 VCU_video_reg[4];
 static WRITE8_HANDLER( VCU_video_reg_w )
 {
@@ -688,7 +674,7 @@ int bits = 0;
 
 UINT8 color_base=0;
 
-UINT8 * rom = memory_region(REGION_CPU3) + (gfx_rom_bank * 0x2000) + 0x10000;
+UINT8 * rom = memory_region(space->machine, "sub2") + (gfx_rom_bank * 0x2000) + 0x10000;
 
 /*
     if ((mode<=0x07) || (mode>=0x10))
@@ -853,7 +839,7 @@ int bits = 0;
 
 UINT8 color_base=0;
 
-UINT8 * rom = memory_region(REGION_CPU3) + (gfx_rom_bank * 0x2000) + 0x10000;
+UINT8 * rom = memory_region(space->machine, "sub2") + (gfx_rom_bank * 0x2000) + 0x10000;
 
 /*
     //if (0) //(mode != 0x07)
@@ -977,7 +963,7 @@ UINT8 * rom = memory_region(REGION_CPU3) + (gfx_rom_bank * 0x2000) + 0x10000;
 						b = combine_3_weights(weights_b, bit0, bit1, bit2);
 
 						if ((x+y*16)<255)//keep color 255 free for use as background color
-							palette_set_color(Machine, x+y*16, MAKE_RGB(r, g, b));
+							palette_set_color(space->machine, x+y*16, MAKE_RGB(r, g, b));
 
 						lookup_RAM[ lookup_offs + x + y*16 ] = colour;
 					}
@@ -1043,9 +1029,9 @@ UINT8 * rom = memory_region(REGION_CPU3) + (gfx_rom_bank * 0x2000) + 0x10000;
 }
 
 static ADDRESS_MAP_START( readmem_cpu3, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x37ff) AM_READ(MRA8_ROM)
+	AM_RANGE(0x0000, 0x37ff) AM_READ(SMH_ROM)
 	AM_RANGE(0x3800, 0x3fff) AM_READ(sharedram_CFB_ZPU_r)
-	AM_RANGE(0x4000, 0x5fff) AM_READ(MRA8_BANK1)				/* GFX roms */
+	AM_RANGE(0x4000, 0x5fff) AM_READ(SMH_BANK1)				/* GFX roms */
 	AM_RANGE(0x6000, 0x67ff) AM_READ(cfb_ram_r)				/* RAM for VCU commands and parameters */
 
 	AM_RANGE(0xa000, 0xa7ff) AM_READ(VCU_set_cmd_param_r)	/* VCU command and parameters LOAD */
@@ -1054,7 +1040,7 @@ static ADDRESS_MAP_START( readmem_cpu3, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem_cpu3, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x37ff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x0000, 0x37ff) AM_WRITE(SMH_ROM)
 	AM_RANGE(0x3800, 0x3fff) AM_WRITE(sharedram_CFB_ZPU_w) AM_BASE(&cfb_zpu_sharedram)
 	AM_RANGE(0x4000, 0x4003) AM_WRITE(VCU_video_reg_w)
 	AM_RANGE(0x6000, 0x67ff) AM_WRITE(cfb_ram_w) AM_BASE(&cfb_ram)
@@ -1079,46 +1065,40 @@ static TIMER_CALLBACK( delayed_sound_w )
 	soundlatch = param;
 
 	/* cause NMI on sound CPU */
-	cpunum_set_input_line(machine, 1, INPUT_LINE_NMI, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[1], INPUT_LINE_NMI, ASSERT_LINE);
 }
 
 
 static WRITE8_HANDLER( main_sound_w )
 {
-	timer_call_after_resynch(NULL, data & 0xff, delayed_sound_w);
+	timer_call_after_resynch(space->machine, NULL, data & 0xff, delayed_sound_w);
 }
 
 
-static ADDRESS_MAP_START( gg_readport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x62, 0x62) AM_READ(zpu_inputs_r)
-ADDRESS_MAP_END
-static ADDRESS_MAP_START( gg_writeport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+static ADDRESS_MAP_START( gg_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x4c, 0x4c) AM_WRITE(main_sound_w)
 	AM_RANGE(0x60, 0x60) AM_WRITE(zpu_bcd_decoder_w)
-	AM_RANGE(0x66, 0x66) AM_WRITE(MWA8_NOP)
-	AM_RANGE(0x68, 0x68) AM_WRITE(MWA8_NOP)
-
+	AM_RANGE(0x62, 0x62) AM_READ(zpu_inputs_r)
+	AM_RANGE(0x66, 0x66) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x68, 0x68) AM_WRITE(SMH_NOP)
 	AM_RANGE(0x6e, 0x6f) AM_WRITE(zpu_led_w)
 ADDRESS_MAP_END
 
 
-
-
 /* frequency is 14.318 MHz/16/16/16/16 */
 static INTERRUPT_GEN( sound_interrupt )
 {
-	cpunum_set_input_line(machine, 1, 0, ASSERT_LINE);
+	cpu_set_input_line(device, 0, ASSERT_LINE);
 }
 
 static WRITE8_HANDLER( sound_int_clear_w )
 {
-	cpunum_set_input_line(Machine, 1, 0, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[1], 0, CLEAR_LINE);
 }
 static WRITE8_HANDLER( sound_nmi_clear_w )
 {
-	cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_NMI, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( gg_led_ctrl_w )
@@ -1128,19 +1108,19 @@ static WRITE8_HANDLER( gg_led_ctrl_w )
 }
 
 static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x2000, 0x27ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x4000, 0x4000) AM_READ(AY8910_read_port_0_r)
+	AM_RANGE(0x0000, 0x1fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x2000, 0x27ff) AM_READ(SMH_RAM)
+	AM_RANGE(0x4000, 0x4000) AM_READ(ay8910_read_port_0_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x2000, 0x27ff) AM_WRITE(MWA8_RAM) /* main RAM (stack) */
+	AM_RANGE(0x0000, 0x1fff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x2000, 0x27ff) AM_WRITE(SMH_RAM) /* main RAM (stack) */
 
-	AM_RANGE(0x4000, 0x4000) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0x4001, 0x4001) AM_WRITE(AY8910_write_port_0_w)
-	AM_RANGE(0x6000, 0x6000) AM_WRITE(AY8910_control_port_1_w)
-	AM_RANGE(0x6001, 0x6001) AM_WRITE(AY8910_write_port_1_w)
+	AM_RANGE(0x4000, 0x4000) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0x4001, 0x4001) AM_WRITE(ay8910_write_port_0_w)
+	AM_RANGE(0x6000, 0x6000) AM_WRITE(ay8910_control_port_1_w)
+	AM_RANGE(0x6001, 0x6001) AM_WRITE(ay8910_write_port_1_w)
 
 	AM_RANGE(0x8000, 0x8000) AM_WRITE(sound_int_clear_w)
 	AM_RANGE(0xa000, 0xa000) AM_WRITE(sound_nmi_clear_w)
@@ -1152,7 +1132,7 @@ ADDRESS_MAP_END
 
 
 static INPUT_PORTS_START( mazerbla )
-	PORT_START	/* Strobe 0: ZPU Switches */
+	PORT_START("ZPU")	/* Strobe 0: ZPU Switches */
 	PORT_DIPNAME( 0x40, 0x40, "ZPU Switch 1" )
 	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -1160,7 +1140,7 @@ static INPUT_PORTS_START( mazerbla )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START	/* Strobe 1: Dip Switches 28-35*/
+	PORT_START("DSW0")	/* Strobe 1: Dip Switches 28-35*/
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Lives ) )
 	PORT_DIPSETTING(	0x03, "6" )
 	PORT_DIPSETTING(	0x02, "5" )
@@ -1182,7 +1162,7 @@ static INPUT_PORTS_START( mazerbla )
 	PORT_DIPSETTING(	0x40, "60000" )
 	PORT_DIPSETTING(	0x00, "70000" )
 
-	PORT_START	/* Strobe 2: Dip Switches 20-27*/
+	PORT_START("DSW1")	/* Strobe 2: Dip Switches 20-27*/
 	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x06, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( 4C_3C ) )
@@ -1219,7 +1199,7 @@ static INPUT_PORTS_START( mazerbla )
 	PORT_DIPSETTING(    0x80, "1 Coin/10 Credits" )
 	PORT_DIPSETTING(    0x70, "1 Coin/14 Credits" )
 
-	PORT_START	/* Strobe 3: Dip Switches 12-19*/
+	PORT_START("DSW2")	/* Strobe 3: Dip Switches 12-19*/
 	PORT_DIPNAME( 0x01, 0x01, "Service Index" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -1245,7 +1225,7 @@ static INPUT_PORTS_START( mazerbla )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START	/* Strobe 4: Dip Switches 4-11 */
+	PORT_START("DSW3")	/* Strobe 4: Dip Switches 4-11 */
 	PORT_DIPNAME( 0x03, 0x02, "Number of Freezes" )
 	PORT_DIPSETTING(	0x03, "4" )
 	PORT_DIPSETTING(	0x02, "3" )
@@ -1271,7 +1251,7 @@ static INPUT_PORTS_START( mazerbla )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START	/* Strobe 5: coin1&2, start1&2, fire */
+	PORT_START("BUTTONS")	/* Strobe 5: coin1&2, start1&2, fire */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_START1 )
@@ -1281,20 +1261,20 @@ static INPUT_PORTS_START( mazerbla )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	/* Strobe 6: horizontal movement of gun */
+	PORT_START("STICK0_X")	/* Strobe 6: horizontal movement of gun */
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_X ) PORT_SENSITIVITY(25) PORT_KEYDELTA(7) PORT_REVERSE PORT_PLAYER(1)
-	PORT_START	/* Strobe 7: vertical movement of gun */
+	PORT_START("STICK0_Y")	/* Strobe 7: vertical movement of gun */
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_Y ) PORT_SENSITIVITY(25) PORT_KEYDELTA(7) PORT_PLAYER(1)
 
-/* Mazer Blazer cabinet has only one gun, really */
-	PORT_START	/* Strobe 8: horizontal movement of gun */
+	/* Mazer Blazer cabinet has only one gun, really */
+	PORT_START("STICK1_X")	/* Strobe 8: horizontal movement of gun */
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_X ) PORT_SENSITIVITY(25) PORT_KEYDELTA(7) PORT_REVERSE PORT_PLAYER(2)
-	PORT_START	/* Strobe 9: vertical movement of gun */
+	PORT_START("STICK1_Y")	/* Strobe 9: vertical movement of gun */
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_Y ) PORT_SENSITIVITY(25) PORT_KEYDELTA(7) PORT_PLAYER(2)
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( greatgun )
-	PORT_START	/* Strobe 0: ZPU Switches */
+	PORT_START("ZPU")	/* Strobe 0: ZPU Switches */
 	PORT_DIPNAME( 0x40, 0x40, "ZPU Switch 1" )
 	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -1302,7 +1282,7 @@ static INPUT_PORTS_START( greatgun )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START	/* Strobe 1: Dip Switches 28-35*/
+	PORT_START("DSW0")	/* Strobe 1: Dip Switches 28-35*/
 	PORT_DIPNAME( 0x03, 0x00, "Starting Number of Bullets/Credit" )
 	PORT_DIPSETTING(	0x03, "60" )
 	PORT_DIPSETTING(	0x02, "70" )
@@ -1329,7 +1309,7 @@ static INPUT_PORTS_START( greatgun )
 	PORT_DIPSETTING(	0x80, "1" )
 	PORT_DIPSETTING(	0x00, "2" )
 
-	PORT_START	/* Strobe 2: Dip Switches 20-27*/
+	PORT_START("DSW1")	/* Strobe 2: Dip Switches 20-27*/
 	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x06, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( 4C_3C ) )
@@ -1366,7 +1346,7 @@ static INPUT_PORTS_START( greatgun )
 	PORT_DIPSETTING(    0x80, "1 Coin/10 Credits" )
 	PORT_DIPSETTING(    0x70, "1 Coin/14 Credits" )
 
-	PORT_START	/* Strobe 3: Dip Switches 12-19*/
+	PORT_START("DSW2")	/* Strobe 3: Dip Switches 12-19*/
 	PORT_DIPNAME( 0x01, 0x01, "Service Index" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -1392,7 +1372,7 @@ static INPUT_PORTS_START( greatgun )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START	/* Strobe 4: Dip Switches 4-11 */
+	PORT_START("DSW3")	/* Strobe 4: Dip Switches 4-11 */
 	PORT_DIPNAME( 0x01, 0x01, "Free game/coin return" )
 	PORT_DIPSETTING(	0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
@@ -1419,7 +1399,7 @@ static INPUT_PORTS_START( greatgun )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START	/* Strobe 5: coin1&2, start1&2, fire */
+	PORT_START("BUTTONS")	/* Strobe 5: coin1&2, start1&2, fire */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_START1 )
@@ -1429,14 +1409,14 @@ static INPUT_PORTS_START( greatgun )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON4 )
 
-	PORT_START	/* Strobe 6: horizontal movement of gun */
+	PORT_START("STICK0_X")	/* Strobe 6: horizontal movement of gun */
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_X ) PORT_SENSITIVITY(25) PORT_KEYDELTA(7) PORT_PLAYER(1)
-	PORT_START	/* Strobe 7: vertical movement of gun */
+	PORT_START("STICK0_Y")	/* Strobe 7: vertical movement of gun */
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_Y ) PORT_SENSITIVITY(25) PORT_KEYDELTA(7) PORT_PLAYER(1)
 
-	PORT_START	/* Strobe 8: horizontal movement of gun */
+	PORT_START("STICK1_X")	/* Strobe 8: horizontal movement of gun */
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_X ) PORT_SENSITIVITY(25) PORT_KEYDELTA(7) PORT_PLAYER(2)
-	PORT_START	/* Strobe 9: vertical movement of gun */
+	PORT_START("STICK1_Y")	/* Strobe 9: vertical movement of gun */
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_Y ) PORT_SENSITIVITY(25) PORT_KEYDELTA(7) PORT_PLAYER(2)
 INPUT_PORTS_END
 
@@ -1447,75 +1427,82 @@ static MACHINE_RESET( mazerbla )
 {
 	game_id = MAZERBLA;
 	zpu_int_vector = 0xff;
-	cpunum_set_irq_callback(0, irq_callback);
+	cpu_set_irq_callback(machine->cpu[0], irq_callback);
 }
 
 
 static MACHINE_RESET( greatgun )
 {
+	UINT8 *rom = memory_region(machine, "sub2");
 	game_id = GREATGUN;
 	zpu_int_vector = 0xff;
-	cpunum_set_irq_callback(0, irq_callback);
+	cpu_set_irq_callback(machine->cpu[0], irq_callback);
 
 
 //patch VCU test
 //VCU test starts at PC=0x56f
-	memory_region(REGION_CPU3)[0x05b6] = 0;
-	memory_region(REGION_CPU3)[0x05b7] = 0;
+	rom[0x05b6] = 0;
+	rom[0x05b7] = 0;
 //so we also need to patch ROM checksum test
-	memory_region(REGION_CPU3)[0x037f] = 0;
-	memory_region(REGION_CPU3)[0x0380] = 0;
+	rom[0x037f] = 0;
+	rom[0x0380] = 0;
 }
 
 
 /* only Great Guns */
-static const struct AY8910interface ay8912_interface_1 =
+static const ay8910_interface ay8912_interface_1 =
 {
-	0,
-	soundcommand_r
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
+	NULL,
+	soundcommand_r,
+	NULL,
+	NULL
 };
 
-static const struct AY8910interface ay8912_interface_2 =
+static const ay8910_interface ay8912_interface_2 =
 {
-	0,
-	0,
-	0,
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
+	NULL,
+	NULL,
+	NULL,
 	gg_led_ctrl_w
 };
 
 
 static MACHINE_DRIVER_START( mazerbla )
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80, 4000000)	/* 4 MHz, no NMI, IM2 - vectors at 0xf8, 0xfa, 0xfc */
+	MDRV_CPU_ADD("main", Z80, 4000000)	/* 4 MHz, no NMI, IM2 - vectors at 0xf8, 0xfa, 0xfc */
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_IO_MAP(readport,writeport)
+	MDRV_CPU_IO_MAP(io_map,0)
 
-	MDRV_CPU_ADD(Z80, 4000000)	/* 4 MHz, NMI, IM1 INT */
+	MDRV_CPU_ADD("sub", Z80, 4000000)	/* 4 MHz, NMI, IM1 INT */
 	MDRV_CPU_PROGRAM_MAP(readmem_cpu2,writemem_cpu2)
-	MDRV_CPU_IO_MAP(readport_cpu2,writeport_cpu2)
+	MDRV_CPU_IO_MAP(cpu2_io_map,0)
 //MDRV_CPU_PERIODIC_INT(irq0_line_hold, 400 ) /* frequency in Hz */
 
-	MDRV_CPU_ADD(Z80, 4000000)	/* 4 MHz, no  NMI, IM1 INT */
+	MDRV_CPU_ADD("sub2", Z80, 4000000)	/* 4 MHz, no  NMI, IM1 INT */
 	MDRV_CPU_PROGRAM_MAP(readmem_cpu3,writemem_cpu3)
-	MDRV_CPU_IO_MAP(readport_cpu3,writeport_cpu3_mb)
+	MDRV_CPU_IO_MAP(cpu3_io_map,0)
 /* (vblank related ??) int generated by a custom video processor
 and cleared on ANY port access.
 but handled differently for now
 */
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
 	/* synchronization forced on the fly */
 
 	MDRV_MACHINE_RESET(mazerbla)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(40*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 32*8-1)
+
 	MDRV_PALETTE_LENGTH(256)
 
 	MDRV_PALETTE_INIT(mazerbla)
@@ -1529,33 +1516,33 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( greatgun )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80, 4000000)	/* 4 MHz, no NMI, IM2 - vectors at 0xf8, 0xfa, 0xfc */
+	MDRV_CPU_ADD("main", Z80, 4000000)	/* 4 MHz, no NMI, IM2 - vectors at 0xf8, 0xfa, 0xfc */
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_IO_MAP(gg_readport,gg_writeport)
+	MDRV_CPU_IO_MAP(gg_io_map,0)
 
-	MDRV_CPU_ADD(Z80, 14318000 / 4)	/* 3.579500 MHz, NMI - caused by sound command write, periodic INT */
+	MDRV_CPU_ADD("sub", Z80, 14318000 / 4)	/* 3.579500 MHz, NMI - caused by sound command write, periodic INT */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_PERIODIC_INT(sound_interrupt, (double)14318180/16/16/16/16 )
 
-	MDRV_CPU_ADD(Z80, 4000000)	/* 4 MHz, no  NMI, IM1 INT */
+	MDRV_CPU_ADD("sub2", Z80, 4000000)	/* 4 MHz, no  NMI, IM1 INT */
 	MDRV_CPU_PROGRAM_MAP(readmem_cpu3,writemem_cpu3)
-	MDRV_CPU_IO_MAP(readport_cpu3,writeport_cpu3_gg)
+	MDRV_CPU_IO_MAP(gg_cpu3_io_map,0)
 /* (vblank related ??) int generated by a custom video processor
 and cleared on ANY port access.
 but handled differently for now
 */
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
 	MDRV_MACHINE_RESET(greatgun)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(40*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 0*8, 32*8-1)
+
 	MDRV_PALETTE_LENGTH(256)
 
 	MDRV_PALETTE_INIT(mazerbla)
@@ -1565,11 +1552,11 @@ but handled differently for now
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, 14318000 / 8)
+	MDRV_SOUND_ADD("ay1", AY8910, 14318000 / 8)
 	MDRV_SOUND_CONFIG(ay8912_interface_1)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 
-	MDRV_SOUND_ADD(AY8910, 14318000 / 8)
+	MDRV_SOUND_ADD("ay2", AY8910, 14318000 / 8)
 	MDRV_SOUND_CONFIG(ay8912_interface_2)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
@@ -1582,17 +1569,17 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( mazerbla )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )     /* 64k for main CPU (ZPU board) */
+	ROM_REGION( 0x10000, "main", 0 )     /* 64k for main CPU (ZPU board) */
 	ROM_LOAD( "mblzpu0.bin",0x0000, 0x2000, CRC(82766187) SHA1(cfc425c87cccb84180f1091998eafeaede126d9d) )
 	ROM_LOAD( "mblzpu1.bin",0x2000, 0x2000, CRC(8ba2b3f9) SHA1(1d203332e434d1d9821f98c6ac959ae65dcc51ef) )
 	ROM_LOAD( "mblzpu2.bin",0x4000, 0x2000, CRC(48e5306c) SHA1(d27cc85d24c7b6c23c5c96be4dad5cae6e8069be) )
 	ROM_LOAD( "mblzpu3.bin",0x6000, 0x2000, CRC(eba91546) SHA1(8c1da4e0d9b562dbbf7c7583dbf567c804eb670f) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )     /* 64k for sound CPU (VSB board) */
+	ROM_REGION( 0x10000, "sub", 0 )     /* 64k for sound CPU (VSB board) */
 	ROM_LOAD( "mblvsb0.bin",0x0000, 0x1000, CRC(0cf7a1c3) SHA1(af27e3a3b51d03d46c62c2797268744d0577d075) )
 	ROM_LOAD( "mblvsb1.bin",0x1000, 0x1000, CRC(0b8d0e43) SHA1(b3ddb7561e715a58ca512fe76e53cda39402a8e4) )
 
-	ROM_REGION( 0x18000, REGION_CPU3, 0 )     /* 64k for video CPU (CFB board) */
+	ROM_REGION( 0x18000, "sub2", 0 )     /* 64k for video CPU (CFB board) */
 	ROM_LOAD( "mblrom0.bin",0x0000, 0x2000, CRC(948a2c5e) SHA1(d693f1b96caf31649f600c5038bb79b0d1d16133) )
 
 	ROM_LOAD( "mblrom2.bin",0x10000,0x2000, CRC(36237058) SHA1(9db8fced37a3d40c4ea5b87ea18ac8e75d71e586) )/*banked at 0x4000 (select=0)*/
@@ -1600,7 +1587,7 @@ ROM_START( mazerbla )
 	/* empty socket??? (the *name* of next rom seems good ?) or wrong schematics ?*/
 	ROM_LOAD( "mblrom4.bin",0x16000,0x2000, CRC(1805acdc) SHA1(40b8e70e6ba69ac864af0b276e81218e63e48deb) )/*banked at 0x4000 (select=3)*/
 
-	ROM_REGION( 0x00240, REGION_PROMS, 0 )
+	ROM_REGION( 0x00240, "proms", 0 )
 	ROM_LOAD( "sndprom.8b", 0x0000, 0x0020, CRC(d558af5a) SHA1(060556beeb1f6732c4520dcfb0086c428f7b9ce3) )
 	ROM_LOAD( "sndprom.9b", 0x0020, 0x0020, CRC(0390d748) SHA1(df0f750c1df45cc7bfb9dbabfa2b94563d19172a) )
 	ROM_LOAD( "sndprom.8g", 0x0040, 0x0100, CRC(19680615) SHA1(c309eb83e66b202bae9174dc2ffce231fca40644) )
@@ -1608,17 +1595,17 @@ ROM_START( mazerbla )
 ROM_END
 
 ROM_START( mzrblzra )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )     /* 64k for main CPU (ZPU board) */
+	ROM_REGION( 0x10000, "main", 0 )     /* 64k for main CPU (ZPU board) */
 	ROM_LOAD( "zpu0",       0x0000, 0x2000, CRC(aa77705c) SHA1(ef93c3eaa66591bef495caa101ef2aff93f2de8c) )
 	ROM_LOAD( "zpu1",       0x2000, 0x2000, CRC(599e1b97) SHA1(ceeb3017d6130d4d54ff4436261f2d3f2a29f8ab) )
 	ROM_LOAD( "zpu2",       0x4000, 0x2000, CRC(e1504613) SHA1(815b56e067d60dda6c5ebed97ef8da3f6c2927ad) )
 	ROM_LOAD( "zpu3",       0x6000, 0x2000, CRC(fd27f409) SHA1(e3d49b931325c75cc0c1075944095bb48501501f) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )     /* 64k for sound CPU (VSB board) */
+	ROM_REGION( 0x10000, "sub", 0 )     /* 64k for sound CPU (VSB board) */
 	ROM_LOAD( "mblvsb0.bin",0x0000, 0x1000, CRC(0cf7a1c3) SHA1(af27e3a3b51d03d46c62c2797268744d0577d075) )
 	ROM_LOAD( "mblvsb1.bin",0x1000, 0x1000, CRC(0b8d0e43) SHA1(b3ddb7561e715a58ca512fe76e53cda39402a8e4) )
 
-	ROM_REGION( 0x18000, REGION_CPU3, 0 )     /* 64k for video CPU (CFB board) */
+	ROM_REGION( 0x18000, "sub2", 0 )     /* 64k for video CPU (CFB board) */
 	ROM_LOAD( "mblrom0.bin",0x0000, 0x2000, CRC(948a2c5e) SHA1(d693f1b96caf31649f600c5038bb79b0d1d16133) )
 
 	ROM_LOAD( "mblrom2.bin",0x10000,0x2000, CRC(36237058) SHA1(9db8fced37a3d40c4ea5b87ea18ac8e75d71e586) )/*banked at 0x4000 (select=0)*/
@@ -1626,7 +1613,7 @@ ROM_START( mzrblzra )
 	/* empty socket??? (the *name* of next rom seems good ?) or wrong schematics ?*/
 	ROM_LOAD( "mblrom4.bin",0x16000,0x2000, CRC(1805acdc) SHA1(40b8e70e6ba69ac864af0b276e81218e63e48deb) )/*banked at 0x4000 (select=3)*/
 
-	ROM_REGION( 0x00240, REGION_PROMS, 0 )
+	ROM_REGION( 0x00240, "proms", 0 )
 	ROM_LOAD( "sndprom.8b", 0x0000, 0x0020, CRC(d558af5a) SHA1(060556beeb1f6732c4520dcfb0086c428f7b9ce3) )
 	ROM_LOAD( "sndprom.9b", 0x0020, 0x0020, CRC(0390d748) SHA1(df0f750c1df45cc7bfb9dbabfa2b94563d19172a) )
 	ROM_LOAD( "sndprom.8g", 0x0040, 0x0100, CRC(19680615) SHA1(c309eb83e66b202bae9174dc2ffce231fca40644) )
@@ -1635,16 +1622,16 @@ ROM_END
 
 
 ROM_START( greatgun )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )     /* 64k for main CPU (ZPU board) */
+	ROM_REGION( 0x10000, "main", 0 )     /* 64k for main CPU (ZPU board) */
 	ROM_LOAD( "zpu0",0x0000, 0x2000, CRC(80cf2cbf) SHA1(ea24b844ea6d8fc54adb2e28be68e1f3e1184b8b) )
 	ROM_LOAD( "zpu1",0x2000, 0x2000, CRC(fc12af94) SHA1(65f5bca2853271c232bd02dfc3467e6a4f7f0a6f) )
 	ROM_LOAD( "zpu2",0x4000, 0x2000, CRC(b34cfa26) SHA1(903adc6de0d34e5bc8fb0f8d3e74ff53204d8c68) )
 	ROM_LOAD( "zpu3",0x6000, 0x2000, CRC(c142ebdf) SHA1(0b87740d26b19a05f65b811225ee0053ddb27d22) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )     /* 64k for sound CPU (PSB board) */
+	ROM_REGION( 0x10000, "sub", 0 )     /* 64k for sound CPU (PSB board) */
 	ROM_LOAD( "psba4",0x0000, 0x2000, CRC(172a793e) SHA1(3618a778af1f4a6267bf7e0786529be731ac9b76) )
 
-	ROM_REGION( 0x38000, REGION_CPU3, 0 )     /* 64k for video CPU (CFB board) */
+	ROM_REGION( 0x38000, "sub2", 0 )     /* 64k for video CPU (CFB board) */
 	ROM_LOAD( "cfb0",0x0000, 0x2000, CRC(ee372b1f) SHA1(b630fd659d59eb8c2540f18d91ae0d72e859fc4f) )
 	ROM_LOAD( "cfb1",0x2000, 0x2000, CRC(b76d9527) SHA1(8f16b850bd67d553aaaf7e176754e36aba581445) )
 
@@ -1675,3 +1662,5 @@ ROM_END
 GAME( 1983, mazerbla, 0,        mazerbla,  mazerbla, 0, ROT0, "Stern", "Mazer Blazer (set 1)", GAME_IMPERFECT_GRAPHICS |GAME_NO_SOUND | GAME_NOT_WORKING )
 GAME( 1983, mzrblzra, mazerbla, mazerbla,  mazerbla, 0, ROT0, "Stern", "Mazer Blazer (set 2)", GAME_IMPERFECT_GRAPHICS |GAME_NO_SOUND | GAME_NOT_WORKING )
 GAME( 1983, greatgun, 0,        greatgun,  greatgun, 0, ROT0, "Stern", "Great Guns", GAME_IMPERFECT_GRAPHICS )
+
+
