@@ -6,6 +6,7 @@
 
     Games supported:
         * Dead Eye
+        * 3-D Bowling
         * Gypsy Juggler
         * Inferno
 
@@ -87,7 +88,7 @@
 
     0c00..0c03  H/W input ports
     -----------------------------------------------
-            0 R sound command from CPU #0
+            0 R audio command from CPU #0
                 D0-D7   8 different sounds ???
 
             1 R ???
@@ -99,9 +100,9 @@
                 D4-D7   volume bits 0 .. 3 (bit 4 is CPU #1 flag output)
             2 W D0-D7   preset for counter, clk is 5 MHz / 32
             3 W D0      divide c02 counter by 0: 2, 1: 4
-                D1      sound enable for c02 tone generator
-                D2      sound enable for DAC
-                D3      sound enable for c01 tone generator
+                D1      audio enable for c02 tone generator
+                D2      audio enable for DAC
+                D3      audio enable for c01 tone generator
 
     0e00-0eff   RAM
 
@@ -124,6 +125,8 @@
 #include "deadeye.lh"
 #include "gypsyjug.lh"
 
+#define MASTER_CLOCK XTAL_5MHz
+
 
 
 /*************************************
@@ -132,11 +135,8 @@
  *
  *************************************/
 
-static UINT64 cycles_at_vsync;
 static UINT8 main_sense_state;
-static UINT8 sound_sense_state;
-static UINT8 coin1_state;
-static UINT8 minferno_sense;
+static UINT8 audio_sense_state;
 
 
 
@@ -148,24 +148,21 @@ static UINT8 minferno_sense;
 
 static READ8_HANDLER( hsync_chain_r )
 {
-	/* horizontal sync divider chain */
-	UINT8 val = (activecpu_gettotalcycles() - cycles_at_vsync) & 0xff;
+	UINT8 val = video_screen_get_hpos(space->machine->primary_screen);
 	return BITSWAP8(val,0,1,2,3,4,5,6,7);
 }
 
 
 static READ8_HANDLER( vsync_chain_hi_r )
 {
-	/* vertical sync divider chain */
-	UINT8 val = video_screen_get_vpos(0);
+	UINT8 val = video_screen_get_vpos(space->machine->primary_screen);
 	return ((val >> 1) & 0x08) | ((val >> 3) & 0x04) | ((val >> 5) & 0x02) | (val >> 7);
 }
 
 
 static READ8_HANDLER( vsync_chain_lo_r )
 {
-	/* vertical sync divider chain */
-	UINT8 val = video_screen_get_vpos(0);
+	UINT8 val = video_screen_get_vpos(space->machine->primary_screen);
 	return val & 0x0f;
 }
 
@@ -173,27 +170,27 @@ static READ8_HANDLER( vsync_chain_lo_r )
 
 /*************************************
  *
- *  Sound control writes
+ *  Audio control writes
  *
  *************************************/
 
-static WRITE8_HANDLER( meadows_sound_w )
+static WRITE8_HANDLER( meadows_audio_w )
 {
 	switch (offset)
 	{
 		case 0:
 			if (meadows_0c00 == data)
 				break;
-			logerror("meadows_sound_w %d $%02x\n", offset, data);
+			logerror("meadows_audio_w %d $%02x\n", offset, data);
 			meadows_0c00 = data;
             break;
 
 		case 1:
-			logerror("meadows_sound_w %d $%02x\n", offset, data);
+			logerror("meadows_audio_w %d $%02x\n", offset, data);
             break;
 
         case 2:
-			logerror("meadows_sound_w %d $%02x\n", offset, data);
+			logerror("meadows_audio_w %d $%02x\n", offset, data);
             break;
 
 		case 3:
@@ -204,6 +201,19 @@ static WRITE8_HANDLER( meadows_sound_w )
 
 
 
+/*************************************
+ *
+ *  Coin handling
+ *
+ *************************************/
+
+static INPUT_CHANGED( coin_inserted )
+{
+	cpu_set_input_line_and_vector(field->port->machine->cpu[0], 0, (newval ? ASSERT_LINE : CLEAR_LINE), 0x82);
+}
+
+
+
 /*************************************
  *
  *  Main CPU interrupt
@@ -212,24 +222,9 @@ static WRITE8_HANDLER( meadows_sound_w )
 
 static INTERRUPT_GEN( meadows_interrupt )
 {
-	/* preserve the actual cycle count */
-    cycles_at_vsync = cpunum_gettotalcycles(0);
-
     /* fake something toggling the sense input line of the S2650 */
 	main_sense_state ^= 1;
-	cpunum_set_input_line(machine, 0, 1, main_sense_state ? ASSERT_LINE : CLEAR_LINE);
-
-	/* check the fake coin input */
-	if (readinputport(3) & 0x01)
-	{
-		if (!coin1_state)
-		{
-			coin1_state = 1;
-			cpunum_set_input_line_and_vector(machine, 0, 0, PULSE_LINE, 0x82);
-		}
-	}
-	else
-		coin1_state = 0;
+	cpu_set_input_line(device, 1, main_sense_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -242,21 +237,19 @@ static INTERRUPT_GEN( meadows_interrupt )
 
 static INTERRUPT_GEN( minferno_interrupt )
 {
-	/* preserve the actual cycle count */
-	cycles_at_vsync = cpunum_gettotalcycles(0);
-	minferno_sense++;
-	cpunum_set_input_line(machine, 0, 1, (minferno_sense & 0x40) ? ASSERT_LINE : CLEAR_LINE );
+	main_sense_state++;
+	cpu_set_input_line(device, 1, (main_sense_state & 0x40) ? ASSERT_LINE : CLEAR_LINE );
 }
 
 
 
 /*************************************
  *
- *  Sound hardware output control
+ *  Audio hardware output control
  *
  *************************************/
 
-static WRITE8_HANDLER( sound_hardware_w )
+static WRITE8_HANDLER( audio_hardware_w )
 {
 	switch (offset & 3)
 	{
@@ -267,25 +260,25 @@ static WRITE8_HANDLER( sound_hardware_w )
 		case 1: /* counter clk 5 MHz / 256 */
 			if (data == meadows_0c01)
 				break;
-			logerror("sound_w ctr1 preset $%x amp %d\n", data & 15, data >> 4);
+			logerror("audio_w ctr1 preset $%x amp %d\n", data & 15, data >> 4);
 			meadows_0c01 = data;
-			meadows_sh_update();
+			meadows_sh_update(space->machine);
 			break;
 
 		case 2: /* counter clk 5 MHz / 32 (/ 2 or / 4) */
 			if (data == meadows_0c02)
                 break;
-			logerror("sound_w ctr2 preset $%02x\n", data);
+			logerror("audio_w ctr2 preset $%02x\n", data);
 			meadows_0c02 = data;
-			meadows_sh_update();
+			meadows_sh_update(space->machine);
             break;
 
-		case 3: /* sound enable */
+		case 3: /* audio enable */
 			if (data == meadows_0c03)
                 break;
-			logerror("sound_w enable ctr2/2:%d ctr2:%d dac:%d ctr1:%d\n", data&1, (data>>1)&1, (data>>2)&1, (data>>3)&1);
+			logerror("audio_w enable ctr2/2:%d ctr2:%d dac:%d ctr1:%d\n", data&1, (data>>1)&1, (data>>2)&1, (data>>3)&1);
 			meadows_0c03 = data;
-			meadows_sh_update();
+			meadows_sh_update(space->machine);
             break;
 	}
 }
@@ -294,11 +287,11 @@ static WRITE8_HANDLER( sound_hardware_w )
 
 /*************************************
  *
- *  Sound hardware read
+ *  Audio hardware read
  *
  *************************************/
 
-static READ8_HANDLER( sound_hardware_r )
+static READ8_HANDLER( audio_hardware_r )
 {
 	int data = 0;
 
@@ -319,15 +312,15 @@ static READ8_HANDLER( sound_hardware_r )
 
 /*************************************
  *
- *  Sound hardware interrupts
+ *  Audio hardware interrupts
  *
  *************************************/
 
-static INTERRUPT_GEN( sound_interrupt )
+static INTERRUPT_GEN( audio_interrupt )
 {
     /* fake something toggling the sense input line of the S2650 */
-	sound_sense_state ^= 1;
-	cpunum_set_input_line(machine, 1, 1, sound_sense_state ? ASSERT_LINE : CLEAR_LINE);
+	audio_sense_state ^= 1;
+	cpu_set_input_line(device, 1, audio_sense_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -340,8 +333,8 @@ static INTERRUPT_GEN( sound_interrupt )
 
 static PALETTE_INIT( meadows )
 {
-	palette_set_color(machine,0,MAKE_RGB(0x00,0x00,0x00)); /* BLACK */
-	palette_set_color(machine,1,MAKE_RGB(0xff,0xff,0xff)); /* WHITE */
+	palette_set_color(machine, 0, RGB_BLACK);
+	palette_set_color(machine, 1, RGB_WHITE);
 }
 
 
@@ -352,72 +345,52 @@ static PALETTE_INIT( meadows )
  *
  *************************************/
 
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x0bff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x0c00, 0x0c03) AM_WRITE(meadows_sound_w)
-	AM_RANGE(0x0d00, 0x0d0f) AM_WRITE(meadows_spriteram_w) AM_BASE(&spriteram)
-	AM_RANGE(0x0e00, 0x0eff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0x1000, 0x1bff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x1c00, 0x1fff) AM_WRITE(meadows_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
-ADDRESS_MAP_END
-
-
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x0bff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x0c00, 0x0c00) AM_READ(input_port_0_r)
-	AM_RANGE(0x0c01, 0x0c01) AM_READ(input_port_1_r)
+static ADDRESS_MAP_START( meadows_main_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x0bff) AM_ROM
+	AM_RANGE(0x0c00, 0x0c00) AM_READ_PORT("INPUTS")
+	AM_RANGE(0x0c01, 0x0c01) AM_READ_PORT("STICK")
 	AM_RANGE(0x0c02, 0x0c02) AM_READ(hsync_chain_r)
-	AM_RANGE(0x0c03, 0x0c03) AM_READ(input_port_2_r)
-	AM_RANGE(0x0e00, 0x0eff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x1000, 0x1bff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x1c00, 0x1fff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0c03, 0x0c03) AM_READ_PORT("DSW")
+	AM_RANGE(0x0c00, 0x0c03) AM_WRITE(meadows_audio_w)
+	AM_RANGE(0x0d00, 0x0d0f) AM_WRITE(meadows_spriteram_w) AM_BASE(&spriteram)
+	AM_RANGE(0x0e00, 0x0eff) AM_RAM
+	AM_RANGE(0x1000, 0x1bff) AM_ROM
+	AM_RANGE(0x1c00, 0x1fff) AM_RAM_WRITE(meadows_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( minferno_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x0bff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x1c00, 0x1eff) AM_WRITE(meadows_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
-	AM_RANGE(0x1f00, 0x1f03) AM_WRITE(meadows_sound_w)
-ADDRESS_MAP_END
-
-
-static ADDRESS_MAP_START( minferno_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x0bff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x1c00, 0x1eff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x1f00, 0x1f00) AM_READ(input_port_0_r)
-	AM_RANGE(0x1f01, 0x1f01) AM_READ(input_port_1_r)
-	AM_RANGE(0x1f02, 0x1f02) AM_READ(input_port_2_r)
-	AM_RANGE(0x1f03, 0x1f03) AM_READ(input_port_3_r)
+static ADDRESS_MAP_START( minferno_main_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x0bff) AM_ROM
+	AM_RANGE(0x1c00, 0x1eff) AM_RAM_WRITE(meadows_videoram_w) AM_BASE(&videoram) AM_SIZE(&videoram_size)
+	AM_RANGE(0x1f00, 0x1f00) AM_READ_PORT("JOY1")
+	AM_RANGE(0x1f01, 0x1f01) AM_READ_PORT("JOY2")
+	AM_RANGE(0x1f02, 0x1f02) AM_READ_PORT("BUTTONS")
+	AM_RANGE(0x1f03, 0x1f03) AM_READ_PORT("DSW1")
+	AM_RANGE(0x1f00, 0x1f03) AM_WRITE(meadows_audio_w)
 	AM_RANGE(0x1f04, 0x1f04) AM_READ(vsync_chain_hi_r)
 	AM_RANGE(0x1f05, 0x1f05) AM_READ(vsync_chain_lo_r)
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( minferno_readport, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(S2650_DATA_PORT, S2650_DATA_PORT) AM_READ(input_port_4_r)
+static ADDRESS_MAP_START( minferno_io_map, ADDRESS_SPACE_IO, 8 )
+	AM_RANGE(S2650_DATA_PORT, S2650_DATA_PORT) AM_READ_PORT("DSW2")
 ADDRESS_MAP_END
 
 
 
 /*************************************
  *
- *  Sound CPU memory handlers
+ *  Audio CPU memory handlers
  *
  *************************************/
 
-static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x0bff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x0c00, 0x0c03) AM_WRITE(sound_hardware_w)
-	AM_RANGE(0x0e00, 0x0eff) AM_WRITE(MWA8_RAM)
+static ADDRESS_MAP_START( audio_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x0bff) AM_ROM
+	AM_RANGE(0x0c00, 0x0c03) AM_READWRITE(audio_hardware_r, audio_hardware_w)
+	AM_RANGE(0x0e00, 0x0eff) AM_RAM
 ADDRESS_MAP_END
 
 
-static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x0bff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x0c00, 0x0c03) AM_READ(sound_hardware_r)
-	AM_RANGE(0x0e00, 0x0eff) AM_READ(MRA8_RAM)
-ADDRESS_MAP_END
-
 
 
 /*************************************
@@ -427,7 +400,7 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( meadows )
-	PORT_START		/* IN0 buttons */
+	PORT_START("INPUTS")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START1  )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -437,11 +410,11 @@ static INPUT_PORTS_START( meadows )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START		/* IN1 control 1 */
+	PORT_START("STICK")
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_X ) PORT_MINMAX(0x10,0xf0) PORT_SENSITIVITY(100) PORT_KEYDELTA(10)
 
-	PORT_START		/* IN2 dip switch */
-	PORT_DIPNAME( 0x07, 0x01, DEF_STR( Lives ) )
+	PORT_START("DSW")
+	PORT_DIPNAME( 0x07, 0x01, DEF_STR( Lives ) ) PORT_DIPLOCATION("DSW1:3,2,1")
 	PORT_DIPSETTING(    0x00, "2" )
 	PORT_DIPSETTING(    0x01, "3" )
 	PORT_DIPSETTING(    0x02, "4" )
@@ -450,77 +423,77 @@ static INPUT_PORTS_START( meadows )
 	PORT_DIPSETTING(    0x05, "7" )
 	PORT_DIPSETTING(    0x06, "8" )
 	PORT_DIPSETTING(    0x07, "9" )
-	PORT_DIPNAME( 0x18, 0x00, DEF_STR( Coinage ) )
+	PORT_DIPNAME( 0x18, 0x00, DEF_STR( Coinage ) ) PORT_DIPLOCATION("DSW1:5,4")
 	PORT_DIPSETTING(    0x10, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( 1C_2C ) )
 	PORT_DIPSETTING(    0x18, DEF_STR( Free_Play ) )
-	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Demo_Sounds ) )
+	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Demo_Sounds ) ) PORT_DIPLOCATION("DSW1:6")
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x20, DEF_STR( On ) )
-	PORT_DIPNAME( 0xc0, 0x40, DEF_STR( Bonus_Life ) )
+	PORT_DIPNAME( 0xc0, 0x40, DEF_STR( Bonus_Life ) ) PORT_DIPLOCATION("DSW1:8,7")
 	PORT_DIPSETTING(    0x40, "5000")
 	PORT_DIPSETTING(    0x80, "15000")
 	PORT_DIPSETTING(    0xc0, "35000")
 	PORT_DIPSETTING(    0x00, DEF_STR( None ))
 
-	PORT_START		/* FAKE coinage */
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
+	PORT_START("FAKE")
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_CHANGED(coin_inserted, 0)
 	PORT_BIT( 0x8e, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( minferno )
-	PORT_START		/* IN0 left joystick */
+	PORT_START("JOY1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(1)
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(1)
 
-	PORT_START		/* IN1 right joystick */
+	PORT_START("JOY2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(2)
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(2)
 
-	PORT_START		/* IN2 buttons */
+	PORT_START("BUTTONS")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START		/* IN3 coinage */
-	PORT_DIPNAME( 0x01, 0x01, "Coin Option" )
+	PORT_START("DSW1")
+	PORT_DIPNAME( 0x01, 0x01, "Coin Option" ) PORT_DIPLOCATION("DSW1:4")
 	PORT_DIPSETTING(    0x00, "1 Game/Coin" )
 	PORT_DIPSETTING(    0x01, "1 Player/Coin" )
-	PORT_DIPNAME( 0x02, 0x00, DEF_STR( Demo_Sounds ) )
+	PORT_DIPNAME( 0x02, 0x00, DEF_STR( Demo_Sounds ) ) PORT_DIPLOCATION("DSW1:3")
 	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_COIN1 )
 
-	PORT_START		/* IN4 dip switch */
-	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Game_Time ) )
+	PORT_START("DSW2")
+	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Game_Time ) ) PORT_DIPLOCATION("DSW1:2,1")
 	PORT_DIPSETTING(    0x00, "60s" )
 	PORT_DIPSETTING(    0x01, "90s" )
 	PORT_DIPSETTING(    0x02, "120s" )
 	PORT_DIPSETTING(    0x03, "180s" )
-	PORT_DIPNAME( 0x0c, 0x04, "Extended Play Score" )
+	PORT_DIPNAME( 0x0c, 0x04, "Extended Play Score" ) PORT_DIPLOCATION("DSW1:6,5")
 	PORT_DIPSETTING(    0x00, "3000/6000" )
 	PORT_DIPSETTING(    0x04, "4000/7000" )
 	PORT_DIPSETTING(    0x08, "5000/8000" )
 	PORT_DIPSETTING(    0x0c, "6000/9000" )
-	PORT_DIPNAME( 0x30, 0x10, "Extended Play Time" )
+	PORT_DIPNAME( 0x30, 0x10, "Extended Play Time" ) PORT_DIPLOCATION("DSW1:7,8")
 	PORT_DIPSETTING(    0x00, DEF_STR( None ) )
 	PORT_DIPSETTING(    0x10, "20s" )
 	PORT_DIPSETTING(    0x20, "40s" )
 	PORT_DIPSETTING(    0x30, "60s" )
-	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x40, DEF_STR( On ) )
-	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Unknown ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
+/*  PORT_DIPNAME( 0x40, 0x00, DEF_STR( Unused ) )
+    PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+    PORT_DIPSETTING(    0x40, DEF_STR( On ) )
+    PORT_DIPNAME( 0x80, 0x00, DEF_STR( Unused ) )
+    PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+    PORT_DIPSETTING(    0x80, DEF_STR( On ) ) */
 INPUT_PORTS_END
 
 
@@ -558,33 +531,26 @@ static const gfx_layout spritelayout =
 
 
 static GFXDECODE_START( meadows )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, charlayout,	 0, 1 )		/* character generator */
-	GFXDECODE_ENTRY( REGION_GFX2, 0, spritelayout, 0, 1 )		/* sprite prom 1 */
-	GFXDECODE_ENTRY( REGION_GFX3, 0, spritelayout, 0, 1 )		/* sprite prom 2 */
-	GFXDECODE_ENTRY( REGION_GFX4, 0, spritelayout, 0, 1 )		/* sprite prom 3 (unused) */
-	GFXDECODE_ENTRY( REGION_GFX5, 0, spritelayout, 0, 1 )		/* sprite prom 4 (unused) */
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout,	 0, 1 )		/* character generator */
+	GFXDECODE_ENTRY( "gfx2", 0, spritelayout, 0, 1 )		/* sprite prom 1 */
+	GFXDECODE_ENTRY( "gfx3", 0, spritelayout, 0, 1 )		/* sprite prom 2 */
+	GFXDECODE_ENTRY( "gfx4", 0, spritelayout, 0, 1 )		/* sprite prom 3 (unused) */
+	GFXDECODE_ENTRY( "gfx5", 0, spritelayout, 0, 1 )		/* sprite prom 4 (unused) */
 GFXDECODE_END
 
 
 static GFXDECODE_START( minferno )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, charlayout,   0, 4 )
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout,   0, 4 )
 GFXDECODE_END
 
 
 
 /*************************************
  *
- *  Sound interfaces
+ *  Audio interfaces
  *
  *************************************/
 
-static const struct Samplesinterface meadows_samples_interface =
-{
-	2,
-	NULL,
-	meadows_sh_start
-};
-
 static const char *const bowl3d_sample_names[] =
 {
 	"*bowl3d",
@@ -594,15 +560,26 @@ static const char *const bowl3d_sample_names[] =
 	"footstep.wav", /* "foot sweep" */
 	"crash.wav",    /* "crash" */
 	"cheering.wav", /* "cheering" */
-    0	/* end of array */
+    0
 };
 
-static const struct Samplesinterface bowl3d_samples_interface =
+
+static const samples_interface meadows_samples_interface =
 {
- 	1,	/* one channel */
+	2,
+	NULL,
+	meadows_sh_start
+};
+
+
+static const samples_interface bowl3d_samples_interface =
+{
+ 	1,
 	bowl3d_sample_names
 };
 
+
+
 /*************************************
  *
  *  Machine drivers
@@ -612,23 +589,23 @@ static const struct Samplesinterface bowl3d_samples_interface =
 static MACHINE_DRIVER_START( meadows )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(S2650, 5000000/8) 	/* 5MHz / 8 = 625 kHz */
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_VBLANK_INT(meadows_interrupt,1) 	/* one interrupt per frame!? */
+	MDRV_CPU_ADD("main", S2650, MASTER_CLOCK/8) 	/* 5MHz / 8 = 625 kHz */
+	MDRV_CPU_PROGRAM_MAP(meadows_main_map,0)
+	MDRV_CPU_VBLANK_INT("main", meadows_interrupt) 	/* one interrupt per frame!? */
 
-	MDRV_CPU_ADD(S2650, 5000000/8)
-	/* audio CPU */ 	/* 5MHz / 8 = 625 kHz */
-	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
-	MDRV_CPU_PERIODIC_INT(sound_interrupt, (double)5000000/131072)
+	MDRV_CPU_ADD("audio", S2650, MASTER_CLOCK/8) 	/* 5MHz / 8 = 625 kHz */
+	MDRV_CPU_PROGRAM_MAP(audio_map,0)
+	MDRV_CPU_PERIODIC_INT(audio_interrupt, (double)5000000/131072)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_INTERLEAVE(10)
+	MDRV_QUANTUM_TIME(HZ(600))
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(32*8, 30*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+
 	MDRV_GFXDECODE(meadows)
 	MDRV_PALETTE_LENGTH(2)
 
@@ -636,13 +613,13 @@ static MACHINE_DRIVER_START( meadows )
 	MDRV_VIDEO_START(meadows)
 	MDRV_VIDEO_UPDATE(meadows)
 
-	/* sound hardware */
+	/* audio hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ADD("dac", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_SOUND_ADD(SAMPLES, 0)
+	MDRV_SOUND_ADD("samples", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(meadows_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
@@ -651,18 +628,18 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( minferno )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(S2650, 5000000/8/3) 	/* 5MHz / 8 = 625 kHz */
-	MDRV_CPU_PROGRAM_MAP(minferno_readmem,minferno_writemem)
-	MDRV_CPU_IO_MAP(minferno_readport,0)
-	MDRV_CPU_VBLANK_INT(minferno_interrupt,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_CPU_ADD("main", S2650, MASTER_CLOCK/24) 	/* 5MHz / 8 / 3 = 208.33 kHz */
+	MDRV_CPU_PROGRAM_MAP(minferno_main_map,0)
+	MDRV_CPU_IO_MAP(minferno_io_map,0)
+	MDRV_CPU_VBLANK_INT("main", minferno_interrupt)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(32*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 1*8, 24*8-1)
+
 	MDRV_GFXDECODE(minferno)
 	MDRV_PALETTE_LENGTH(2)
 
@@ -670,7 +647,7 @@ static MACHINE_DRIVER_START( minferno )
 	MDRV_VIDEO_START(meadows)
 	MDRV_VIDEO_UPDATE(meadows)
 
-	/* sound hardware */
+	/* audio hardware */
 MACHINE_DRIVER_END
 
 
@@ -678,13 +655,14 @@ static MACHINE_DRIVER_START( bowl3d )
 	/* basic machine hardware */
 	MDRV_IMPORT_FROM(meadows)
 
- 	/* video hardware */
-	MDRV_SOUND_ADD(SAMPLES, 0)
+ 	/* audio hardware */
+	MDRV_SOUND_ADD("samples2", SAMPLES, 0)
 	MDRV_SOUND_CONFIG(bowl3d_samples_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
 
+
 /*************************************
  *
  *  ROM definitions
@@ -692,7 +670,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( deadeye )
-	ROM_REGION( 0x08000, REGION_CPU1, 0 )
+	ROM_REGION( 0x08000, "main", 0 )
 	ROM_LOAD( "de1.8h",       0x0000, 0x0400, CRC(bd09e4dc) SHA1(5428835f6bc3d162496fdce174fcaaaba98c09f9) )
 	ROM_LOAD( "de2.9h",       0x0400, 0x0400, CRC(b89edec3) SHA1(5ce0058f23b7e5c832029ca97d9a40d1494bf972) )
 	ROM_LOAD( "de3.10h",      0x0800, 0x0400, CRC(acf24438) SHA1(d7ea668ee19a167cb006c92e9606e20ef13d052e) )
@@ -700,26 +678,27 @@ ROM_START( deadeye )
 	ROM_LOAD( "de5.12h",      0x1400, 0x0400, CRC(7bdb535c) SHA1(7bd2e261a22f5f3ffc60ea12ca5f38c445ec0030) )
 	ROM_LOAD( "de6.13h",      0x1800, 0x0400, CRC(847f9467) SHA1(253d386b76be99a1deef9e6b4cd906efdd9cf6d9) )
 
-	ROM_REGION( 0x0400, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "de_char.15e",  0x0000, 0x0400, CRC(b032bd8d) SHA1(130614d951c440a31c1262517cca0a133ddd1545) )
 
-	ROM_REGION( 0x0400, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "de_mov1.5a",   0x0000, 0x0400, CRC(c046b4c6) SHA1(3baa47a6c8962f6f66c08847b4ee4aa91580ad1a) )
 
-	ROM_REGION( 0x0400, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "de_mov2.13a",  0x0000, 0x0400, CRC(b89c5df9) SHA1(dd0eac9d646dd24575c7b61ce141fdc66994c188) )
 
-	ROM_REGION( 0x0400, REGION_GFX4, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx4", ROMREGION_DISPOSE )
 	/* empty */
-	ROM_REGION( 0x0400, REGION_GFX5, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx5", ROMREGION_DISPOSE )
 	/* empty */
 
-	ROM_REGION( 0x08000, REGION_CPU2, 0 ) 	/* 32K for code for the sound cpu */
+	ROM_REGION( 0x08000, "audio", 0 )
 	ROM_LOAD( "de_snd",       0x0000, 0x0400, CRC(c10a1b1a) SHA1(779ea261d23360634081295a164cacbd819d8719) )
 ROM_END
 
+
 ROM_START( bowl3d )
-	ROM_REGION( 0x08000, REGION_CPU1, 0 )
+	ROM_REGION( 0x08000, "main", 0 )
 	ROM_LOAD( "b3d.h8",       0x0000, 0x0400, CRC(be38feeb) SHA1(feab3c61ce1e351c02f6ffa7f7f2ac90e62e7719) )
 	ROM_LOAD( "b3d.h9",       0x0400, 0x0400, CRC(4e8acead) SHA1(3c00f0d05b9cb80a2245bc68a45732ab6ac87b7f) )
 	ROM_LOAD( "b3d.h10",      0x0800, 0x0400, CRC(16677267) SHA1(0131f68e87d6326870f95c1ff364a97436b6c4d8) )
@@ -728,53 +707,53 @@ ROM_START( bowl3d )
 	// h13 empty
 
     /* Universal Game Logic according to schematics  */
-    ROM_REGION( 0x08000, REGION_CPU2, 0 ) 	/* 2650 CPU at j8 */
+    ROM_REGION( 0x08000, "audio", 0 ) 	/* 2650 CPU at j8 */
 	ROM_LOAD( "82s115.a6",    0x0000, 0x0001, NO_DUMP ) /* 82s115 eprom */
 	ROM_LOAD( "82s115.c6",    0x0000, 0x0001, NO_DUMP ) /* 82s115 eprom */
 
-	ROM_REGION( 0x0400, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "b3d.e15",      0x0000, 0x0400, CRC(4414e24f) SHA1(835c989143895848df7154c2d82a499dea79c1c5) )
 
-	ROM_REGION( 0x0400, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "b3d.a5",       0x0000, 0x0400, CRC(4b657f8a) SHA1(52eb90ff5048db30e9710e96793bad5e2c7ad6db) )
 
-	ROM_REGION( 0x0400, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "b3d.a13",      0x0000, 0x0400, CRC(ca7f33b9) SHA1(6c63a41be57e71d6a58112be13d77e695a0faa10) )
 
-	ROM_REGION( 0x0400, REGION_GFX4, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx4", ROMREGION_DISPOSE )
 	/* empty */
-	ROM_REGION( 0x0400, REGION_GFX5, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx5", ROMREGION_DISPOSE )
 	/* empty */
 
-	ROM_REGION( 0x0001, REGION_PROMS, 0 )
+	ROM_REGION( 0x0001, "proms", 0 )
 	ROM_LOAD( "82s123.r8",    0x0000, 0x0001, NO_DUMP ) /* 82s123 prom located on Universal Game Logic */
 ROM_END
 
 
 ROM_START( gypsyjug )
-	ROM_REGION( 0x08000, REGION_CPU1, 0 )
+	ROM_REGION( 0x08000, "main", 0 )
 	ROM_LOAD( "gj.1b",        0x0000, 0x0400, CRC(f6a71d9f) SHA1(11a86ae781297e4077a69e6809487022fed9c444) )
 	ROM_LOAD( "gj.2b",        0x0400, 0x0400, CRC(94c14455) SHA1(ed704680c2b83d1726d1a17d64f5d57925a495b2) )
 	ROM_LOAD( "gj.3b",        0x0800, 0x0400, CRC(87ee0490) SHA1(7ecca4df9755b604d179d407e7c9c04d616b689b) )
 	ROM_LOAD( "gj.4b",        0x1000, 0x0400, CRC(dca519c8) SHA1(7651aa8b2a8e53113eb08108a5b8fb20518ae185) )
 	ROM_LOAD( "gj.5b",        0x1400, 0x0400, CRC(7d83f9d0) SHA1(9aa8b281b5de7d913cf364a1159f2762fc69022d) )
 
-	ROM_REGION( 0x0400, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "gj.e15",       0x0000, 0x0400, CRC(adb25e13) SHA1(67b5a24a724310f3817a891a54d239d60fe80760) )
 
-	ROM_REGION( 0x0400, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "gj.a",         0x0000, 0x0400, CRC(d3725193) SHA1(5ea28c410a7b9532276fb98c7003b4c8f64d24c9) )
 
-	ROM_REGION( 0x0400, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0400, "gfx3", ROMREGION_DISPOSE )
 	/* empty (copied from 2) */
 
-	ROM_REGION( 0x0400, REGION_GFX4, ROMREGION_DISPOSE )
-	/* empty (filled with fake data) */
+	ROM_REGION( 0x0400, "gfx4", ROMREGION_DISPOSE )
+	ROM_LOAD( "gj.x",         0x0000, 0x0400, NO_DUMP )		/* missing */
 
-	ROM_REGION( 0x0400, REGION_GFX5, ROMREGION_DISPOSE )
-	/* empty (filled with fake data) */
+	ROM_REGION( 0x0400, "gfx5", ROMREGION_DISPOSE )
+	ROM_LOAD( "gj.y",         0x0000, 0x0400, NO_DUMP )		/* missing */
 
-	ROM_REGION( 0x08000, REGION_CPU2, 0 ) 	/* 32K for code for the sound cpu */
+	ROM_REGION( 0x08000, "audio", 0 )
 	ROM_LOAD( "gj.a4s",       0x0000, 0x0400, CRC(17a116bc) SHA1(797ba0b292afa3ba7eec985b533014acc00ed47d) )
 	ROM_LOAD( "gj.a5s",       0x0400, 0x0400, CRC(fc23ae09) SHA1(42be34a9ef8c4c8ef9f94c85ca031076f84faa96) )
 	ROM_LOAD( "gj.a6s",       0x0800, 0x0400, CRC(9e7bd71e) SHA1(e00801820c1a39cbfed124a29470da03cf8b40b4) )
@@ -782,7 +761,7 @@ ROM_END
 
 
 ROM_START( minferno )
-	ROM_REGION( 0x08000, REGION_CPU1, ROMREGION_INVERT )
+	ROM_REGION( 0x08000, "main", ROMREGION_INVERT )
 	ROM_LOAD_NIB_LOW ( "inferno.f5",	0x0000, 0x0400, CRC(58472a73) SHA1(7f8b9502c3db11219d6b765dec7b6ff3f62d6c8b) )
 	ROM_LOAD_NIB_HIGH( "inferno.e5",	0x0000, 0x0400, CRC(451942af) SHA1(0a03d74c1b98771d2170c76ca41e972300c34c3a) )
 	ROM_LOAD_NIB_LOW ( "inferno.f6",	0x0400, 0x0400, CRC(d85a195b) SHA1(8250f8e80a9bf196d7bf122af9aad0ae00dedd26) )
@@ -790,7 +769,7 @@ ROM_START( minferno )
 	ROM_LOAD_NIB_LOW ( "inferno.f7",	0x0800, 0x0400, CRC(73b4e9a3) SHA1(d9de88748a3009f3fc1f90c96bfc9732dc6a4a22) )
 	ROM_LOAD_NIB_HIGH( "inferno.e7",	0x0800, 0x0400, CRC(902d9b78) SHA1(3bebbba6c7d00bea2c687b965f59a9e55b430dfa) )
 
-	ROM_REGION( 0x00400, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x00400, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "inferno.b8",		0x0200, 0x0200, CRC(1b06466b) SHA1(aef13ab84526ee7493837eef7f48d9ede65b8e62) )
 ROM_END
 
@@ -813,13 +792,19 @@ static DRIVER_INIT( gypsyjug )
 		0x01,0x80, 0x03,0xc0, 0x03,0xc0, 0x01,0x80
 	};
 	int i;
+	UINT8 *gfx2 = memory_region(machine, "gfx2");
+	UINT8 *gfx3 = memory_region(machine, "gfx3");
+	UINT8 *gfx4 = memory_region(machine, "gfx4");
+	UINT8 *gfx5 = memory_region(machine, "gfx5");
+	int len3 = memory_region_length(machine, "gfx3");
+	int len4 = memory_region_length(machine, "gfx4");
 
-	memcpy(memory_region(REGION_GFX3),memory_region(REGION_GFX2),memory_region_length(REGION_GFX3));
+	memcpy(gfx3,gfx2,len3);
 
-	for (i = 0; i < memory_region_length(REGION_GFX4); i += 16*2)
+	for (i = 0; i < len4; i += 16*2)
 	{
-		memcpy(memory_region(REGION_GFX4) + i, ball, sizeof(ball));
-		memcpy(memory_region(REGION_GFX5) + i, ball, sizeof(ball));
+		memcpy(gfx4 + i, ball, sizeof(ball));
+		memcpy(gfx5 + i, ball, sizeof(ball));
 	}
 }
 
@@ -830,9 +815,9 @@ static DRIVER_INIT( minferno )
 	int i, length;
 	UINT8 *mem;
 
-	/* Create an inverted copy of the graphics data */
-	mem = memory_region(REGION_GFX1);
-	length = memory_region_length(REGION_GFX1);
+	/* create an inverted copy of the graphics data */
+	mem = memory_region(machine, "gfx1");
+	length = memory_region_length(machine, "gfx1");
 	for (i = 0; i < length/2; i++)
 		mem[i] = ~mem[i + length/2];
 }
@@ -846,6 +831,6 @@ static DRIVER_INIT( minferno )
  *************************************/
 
 GAMEL( 1978, deadeye,  0, meadows,  meadows,  0,        ROT0,  "Meadows", "Dead Eye", 0, layout_deadeye )
-GAME(  1978, bowl3d,   0, bowl3d,   meadows,  0,        ROT90, "Meadows", "Bowling 3D", GAME_NOT_WORKING )
-GAMEL( 1978, gypsyjug, 0, meadows,  meadows,  gypsyjug, ROT0,  "Meadows", "Gypsy Juggler", 0, layout_gypsyjug )
-GAME ( 1978, minferno, 0, minferno, minferno, minferno, ROT0,  "Meadows", "Inferno (S2650)", GAME_NO_SOUND )
+GAME ( 1978, bowl3d,   0, bowl3d,   meadows,  0,        ROT90, "Meadows", "3-D Bowling", GAME_NOT_WORKING )
+GAMEL( 1978, gypsyjug, 0, meadows,  meadows,  gypsyjug, ROT0,  "Meadows", "Gypsy Juggler", GAME_IMPERFECT_GRAPHICS, layout_gypsyjug )
+GAME ( 1978, minferno, 0, minferno, minferno, minferno, ROT0,  "Meadows", "Inferno (Meadows)", GAME_NO_SOUND )
