@@ -64,8 +64,8 @@
 */
 
 #include "driver.h"
-#include "deprecat.h"
-#include "memconv.h"
+#include "cpu/i386/i386.h"
+#include "devconv.h"
 #include "machine/8237dma.h"
 #include "machine/pic8259.h"
 #include "machine/pit8253.h"
@@ -75,7 +75,6 @@
 #include "machine/8042kbdc.h"
 #include "machine/pckeybrd.h"
 #include "machine/idectrl.h"
-#include "cpu/i386/i386.h"
 #include "sound/dmadac.h"
 
 #define SPEEDUP_HACKS	1
@@ -88,7 +87,8 @@ static UINT8 pal[768];
 static UINT32 *main_ram;
 
 static UINT32 disp_ctrl_reg[256/4];
-static int frame_width = 1, frame_height = 1;
+static int frame_width;
+static int frame_height;
 
 static UINT32 memory_ctrl_reg[256/4];
 static int pal_index = 0;
@@ -118,6 +118,14 @@ static UINT8 ad1847_regs[16];
 static UINT32 ad1847_sample_counter = 0;
 static UINT32 ad1847_sample_rate;
 
+static struct {
+	const device_config	*pit8254;
+	const device_config	*pic8259_1;
+	const device_config	*pic8259_2;
+	const device_config	*dma8237_1;
+	const device_config	*dma8237_2;
+} mediagx_devices;
+
 
 // Display controller registers
 #define DC_UNLOCK				0x00/4
@@ -148,6 +156,7 @@ static UINT32 ad1847_sample_rate;
 #define DC_CFIFO_DIAG			0x7c/4
 
 
+static void ide_interrupt(const device_config *device, int state);
 
 
 
@@ -169,7 +178,7 @@ static VIDEO_START(mediagx)
 	}
 }
 
-static void draw_char(mame_bitmap *bitmap, const rectangle *cliprect, const gfx_element *gfx, int ch, int att, int x, int y)
+static void draw_char(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, const gfx_element *gfx, int ch, int att, int x, int y)
 {
 	int i,j;
 	UINT8 *dp;
@@ -183,21 +192,17 @@ static void draw_char(mame_bitmap *bitmap, const rectangle *cliprect, const gfx_
 		{
 			UINT8 pen = dp[index++];
 			if (pen)
-			{
-				p[i] = Machine->remapped_colortable[gfx->color_base + (att & 0xf)];
-			}
+				p[i] = machine->pens[gfx->color_base + (att & 0xf)];
 			else
 			{
 				if (((att >> 4) & 7) > 0)
-				{
-					p[i] = Machine->remapped_colortable[gfx->color_base + ((att >> 4) & 0x7)];
-				}
+					p[i] = machine->pens[gfx->color_base + ((att >> 4) & 0x7)];
 			}
 		}
 	}
 }
 
-static void draw_framebuffer(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void draw_framebuffer(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	int i, j;
 	int width, height;
@@ -223,7 +228,7 @@ static void draw_framebuffer(running_machine *machine, mame_bitmap *bitmap, cons
 		visarea.min_x = visarea.min_y = 0;
 		visarea.max_x = width - 1;
 		visarea.max_y = height - 1;
-		video_screen_configure(0, width, height * 262 / 240, &visarea, machine->screen[0].refresh);
+		video_screen_configure(machine->primary_screen, width, height * 262 / 240, &visarea, video_screen_get_frame_period(machine->primary_screen).attoseconds);
 	}
 
 	if (disp_ctrl_reg[DC_OUTPUT_CFG] & 0x1)		// 8-bit mode
@@ -288,7 +293,7 @@ static void draw_framebuffer(running_machine *machine, mame_bitmap *bitmap, cons
 	}
 }
 
-static void draw_cga(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void draw_cga(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	int i, j;
 	const gfx_element *gfx = machine->gfx[0];
@@ -304,8 +309,8 @@ static void draw_cga(running_machine *machine, mame_bitmap *bitmap, const rectan
 			int att1 = (cga[index] >> 24) & 0xff;
 			int ch1 = (cga[index] >> 16) & 0xff;
 
-			draw_char(bitmap, cliprect, gfx, ch0, att0, i*8, j*8);
-			draw_char(bitmap, cliprect, gfx, ch1, att1, (i*8)+8, j*8);
+			draw_char(machine, bitmap, cliprect, gfx, ch0, att0, i*8, j*8);
+			draw_char(machine, bitmap, cliprect, gfx, ch1, att1, (i*8)+8, j*8);
 			index++;
 		}
 	}
@@ -313,13 +318,13 @@ static void draw_cga(running_machine *machine, mame_bitmap *bitmap, const rectan
 
 static VIDEO_UPDATE(mediagx)
 {
-	fillbitmap(bitmap, 0, cliprect);
+	bitmap_fill(bitmap, cliprect, 0);
 
-	draw_framebuffer(machine, bitmap, cliprect);
+	draw_framebuffer(screen->machine, bitmap, cliprect);
 
 	if (disp_ctrl_reg[DC_OUTPUT_CFG] & 0x1)	// don't show MDA text screen on 16-bit mode. this is basically a hack
 	{
-		draw_cga(machine, bitmap, cliprect);
+		draw_cga(screen->machine, bitmap, cliprect);
 	}
 	return 0;
 }
@@ -333,14 +338,12 @@ static READ32_HANDLER( disp_ctrl_r )
 		case DC_TIMING_CFG:
 			r |= 0x40000000;
 
-			if (video_screen_get_vpos(0) >= frame_height)
-			{
+			if (video_screen_get_vpos(space->machine->primary_screen) >= frame_height)
 				r &= ~0x40000000;
-			}
 
 #if SPEEDUP_HACKS
 			// wait for vblank speedup
-			cpu_spinuntil_int();
+			cpu_spinuntil_int(space->cpu);
 #endif
 			break;
 	}
@@ -354,46 +357,35 @@ static WRITE32_HANDLER( disp_ctrl_w )
 }
 
 
-static READ8_HANDLER(at_dma8237_1_r)
+static READ8_DEVICE_HANDLER(at_dma8237_2_r)
 {
-	return dma8237_1_r(offset / 2);
+	return dma8237_r(device, offset / 2);
 }
 
-static WRITE8_HANDLER(at_dma8237_1_w)
+static WRITE8_DEVICE_HANDLER(at_dma8237_2_w)
 {
-	dma8237_1_w(offset / 2, data);
-}
-
-static READ32_HANDLER(at32_dma8237_1_r)
-{
-	return read32le_with_read8_handler(at_dma8237_1_r, offset, mem_mask);
-}
-
-static WRITE32_HANDLER(at32_dma8237_1_w)
-{
-	write32le_with_write8_handler(at_dma8237_1_w, offset, data, mem_mask);
+	dma8237_w(device, offset / 2, data);
 }
 
 
-
-static READ32_HANDLER( ide0_r )
+static READ32_DEVICE_HANDLER( ide_r )
 {
-	return ide_controller32_0_r(0x1f0/4 + offset, mem_mask);
+	return ide_controller32_r(device, 0x1f0/4 + offset, mem_mask);
 }
 
-static WRITE32_HANDLER( ide0_w )
+static WRITE32_DEVICE_HANDLER( ide_w )
 {
-	ide_controller32_0_w(0x1f0/4 + offset, data, mem_mask);
+	ide_controller32_w(device, 0x1f0/4 + offset, data, mem_mask);
 }
 
-static READ32_HANDLER( fdc_r )
+static READ32_DEVICE_HANDLER( fdc_r )
 {
-	return ide_controller32_0_r(0x3f0/4 + offset, mem_mask);
+	return ide_controller32_r(device, 0x3f0/4 + offset, mem_mask);
 }
 
-static WRITE32_HANDLER( fdc_w )
+static WRITE32_DEVICE_HANDLER( fdc_w )
 {
-	ide_controller32_0_w(0x3f0/4 + offset, data, mem_mask);
+	ide_controller32_w(device, 0x3f0/4 + offset, data, mem_mask);
 }
 
 
@@ -467,71 +459,68 @@ static void mediagx_config_reg_w(UINT8 data)
 	mediagx_config_regs[mediagx_config_reg_sel] = data;
 }
 
-static READ32_HANDLER( io20_r )
+static READ8_DEVICE_HANDLER( io20_r )
 {
-	UINT32 r = 0;
-	// 0x20 - 0x21, PIC
-	if ((mem_mask & 0x0000ffff) != 0xffff)
-	{
-		r |= pic8259_32le_0_r(offset, mem_mask);
-	}
+	UINT8 r = 0;
 
 	// 0x22, 0x23, Cyrix configuration registers
-	if (!(mem_mask & 0x00ff0000))
+	if (offset == 0x02)
 	{
-
 	}
-	if (!(mem_mask & 0xff000000))
+	else if (offset == 0x03)
 	{
-		r |= mediagx_config_reg_r() << 24;
+		r = mediagx_config_reg_r();
+	}
+	else
+	{
+		r = pic8259_r(device, offset);
 	}
 	return r;
 }
 
-static WRITE32_HANDLER( io20_w )
+static WRITE8_DEVICE_HANDLER( io20_w )
 {
-	// 0x20 - 0x21, PIC
-	if ((mem_mask & 0x0000ffff) != 0xffff)
-	{
-		pic8259_32le_0_w(offset, data, mem_mask);
-	}
-
 	// 0x22, 0x23, Cyrix configuration registers
-	if (!(mem_mask & 0x00ff0000))
+	if (offset == 0x02)
 	{
-		mediagx_config_reg_sel = (data >> 16) & 0xff;
+		mediagx_config_reg_sel = data;
 	}
-	if (!(mem_mask & 0xff000000))
+	else if (offset == 0x03)
 	{
-		mediagx_config_reg_w((data >> 24) & 0xff);
+		mediagx_config_reg_w(data);
+	}
+	else
+	{
+		pic8259_w(device, offset, data);
 	}
 }
 
 static READ32_HANDLER( parallel_port_r )
 {
 	UINT32 r = 0;
+	//static const char *const portnames[] = { "IN0", "IN1", "IN2", "IN3", "IN4", "IN5", "IN6", "IN7", "IN8" }; // but parallel_pointer takes values 0 -> 23
 
-	if (!(mem_mask & 0x0000ff00))
+	if (ACCESSING_BITS_8_15)
 	{
-		UINT8 nibble = parallel_latched;//(readinputport(parallel_pointer / 3) >> (4 * (parallel_pointer % 3))) & 15;
+		UINT8 nibble = parallel_latched;//(input_port_read_safe(space->machine, portnames[parallel_pointer / 3], 0) >> (4 * (parallel_pointer % 3))) & 15;
 		r |= ((~nibble & 0x08) << 12) | ((nibble & 0x07) << 11);
-		logerror("%08X:parallel_port_r()\n", activecpu_get_pc());
+		logerror("%08X:parallel_port_r()\n", cpu_get_pc(space->cpu));
 /*      if (controls_data == 0x18)
         {
-            r |= readinputport(0) << 8;
+            r |= input_port_read(space->machine, "IN0") << 8;
         }
         else if (controls_data == 0x60)
         {
-            r |= readinputport(1) << 8;
+            r |= input_port_read(space->machine, "IN1") << 8;
         }
         else if (controls_data == 0xff ||  controls_data == 0x50)
         {
-            r |= readinputport(2) << 8;
+            r |= input_port_read(space->machine, "IN2") << 8;
         }
 
         //r |= control_read << 8;*/
 	}
-	if (!(mem_mask & 0x00ff0000))
+	if (ACCESSING_BITS_16_23)
 	{
 		r |= parport & 0xff0000;
 	}
@@ -541,9 +530,11 @@ static READ32_HANDLER( parallel_port_r )
 
 static WRITE32_HANDLER( parallel_port_w )
 {
+	static const char *const portnames[] = { "IN0", "IN1", "IN2", "IN3", "IN4", "IN5", "IN6", "IN7", "IN8" };	// but parallel_pointer takes values 0 -> 23
+
 	COMBINE_DATA( &parport );
 
-	if (!(mem_mask & 0x000000ff))
+	if (ACCESSING_BITS_0_7)
 	{
 		/*
             Controls:
@@ -560,9 +551,9 @@ static WRITE32_HANDLER( parallel_port_w )
                 7x..ff = advance pointer
         */
 
-		logerror("%08X:", activecpu_get_pc());
+		logerror("%08X:", cpu_get_pc(space->cpu));
 
-		parallel_latched = (readinputport(parallel_pointer / 3) >> (4 * (parallel_pointer % 3))) & 15;
+		parallel_latched = (input_port_read_safe(space->machine, portnames[parallel_pointer / 3], 0) >> (4 * (parallel_pointer % 3))) & 15;
 //      parallel_pointer++;
 //      logerror("[%02X] Advance pointer to %d\n", data, parallel_pointer);
 		switch (data & 0xfc)
@@ -620,7 +611,7 @@ static WRITE32_HANDLER( parallel_port_w )
 	}
 }
 
-static UINT32 cx5510_pci_r(int function, int reg, UINT32 mem_mask)
+static UINT32 cx5510_pci_r(const device_config *busdevice, const device_config *device, int function, int reg, UINT32 mem_mask)
 {
 //  mame_printf_debug("CX5510: PCI read %d, %02X, %08X\n", function, reg, mem_mask);
 
@@ -632,7 +623,7 @@ static UINT32 cx5510_pci_r(int function, int reg, UINT32 mem_mask)
 	return cx5510_regs[reg/4];
 }
 
-static void cx5510_pci_w(int function, int reg, UINT32 data, UINT32 mem_mask)
+static void cx5510_pci_w(const device_config *busdevice, const device_config *device, int function, int reg, UINT32 data, UINT32 mem_mask)
 {
 //  mame_printf_debug("CX5510: PCI write %d, %02X, %08X, %08X\n", function, reg, data, mem_mask);
 	COMBINE_DATA(cx5510_regs + (reg/4));
@@ -643,7 +634,7 @@ static void cx5510_pci_w(int function, int reg, UINT32 data, UINT32 mem_mask)
 static TIMER_CALLBACK( sound_timer_callback )
 {
 	ad1847_sample_counter = 0;
-	timer_adjust(sound_timer, ATTOTIME_IN_MSEC(10), 0, attotime_zero);
+	timer_adjust_oneshot(sound_timer, ATTOTIME_IN_MSEC(10), 0);
 
 	dmadac_transfer(0, 1, 0, 1, dacl_ptr, dacl);
 	dmadac_transfer(1, 1, 0, 1, dacr_ptr, dacr);
@@ -704,12 +695,12 @@ static WRITE32_HANDLER( ad1847_w )
 {
 	if (offset == 0)
 	{
-		if (!(mem_mask & 0xffff0000))
+		if (ACCESSING_BITS_16_31)
 		{
 			UINT16 ldata = (data >> 16) & 0xffff;
 			dacl[dacl_ptr++] = ldata;
 		}
-		if (!(mem_mask & 0x0000ffff))
+		if (ACCESSING_BITS_0_15)
 		{
 			UINT16 rdata = data & 0xffff;
 			dacr[dacr_ptr++] = rdata;
@@ -724,6 +715,108 @@ static WRITE32_HANDLER( ad1847_w )
 	}
 }
 
+
+/*************************************************************************
+ *
+ *      PC DMA stuff
+ *
+ *************************************************************************/
+
+static UINT8 dma_offset[2][4];
+static UINT8 at_pages[0x10];
+
+
+static READ8_HANDLER(at_page8_r)
+{
+	UINT8 data = at_pages[offset % 0x10];
+
+	switch(offset % 8) {
+	case 1:
+		data = dma_offset[(offset / 8) & 1][2];
+		break;
+	case 2:
+		data = dma_offset[(offset / 8) & 1][3];
+		break;
+	case 3:
+		data = dma_offset[(offset / 8) & 1][1];
+		break;
+	case 7:
+		data = dma_offset[(offset / 8) & 1][0];
+		break;
+	}
+	return data;
+}
+
+
+static WRITE8_HANDLER(at_page8_w)
+{
+	at_pages[offset % 0x10] = data;
+
+	switch(offset % 8) {
+	case 1:
+		dma_offset[(offset / 8) & 1][2] = data;
+		break;
+	case 2:
+		dma_offset[(offset / 8) & 1][3] = data;
+		break;
+	case 3:
+		dma_offset[(offset / 8) & 1][1] = data;
+		break;
+	case 7:
+		dma_offset[(offset / 8) & 1][0] = data;
+		break;
+	}
+}
+
+
+static DMA8237_MEM_READ( pc_dma_read_byte )
+{
+	const address_space *space = cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	offs_t page_offset = (((offs_t) dma_offset[0][channel]) << 16)
+		& 0xFF0000;
+
+	return memory_read_byte(space, page_offset + offset);
+}
+
+
+static DMA8237_MEM_WRITE( pc_dma_write_byte )
+{
+	const address_space *space = cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	offs_t page_offset = (((offs_t) dma_offset[0][channel]) << 16)
+		& 0xFF0000;
+
+	memory_write_byte(space, page_offset + offset, data);
+}
+
+
+static const struct dma8237_interface dma8237_1_config =
+{
+	"main",
+	1.0e-6, // 1us
+
+	pc_dma_read_byte,
+	pc_dma_write_byte,
+
+	{ 0, 0, NULL, NULL },
+	{ 0, 0, NULL, NULL },
+	NULL
+};
+
+
+static const struct dma8237_interface dma8237_2_config =
+{
+	"main",
+	1.0e-6, // 1us
+
+	NULL,
+	NULL,
+
+	{ NULL, NULL, NULL, NULL },
+	{ NULL, NULL, NULL, NULL },
+	NULL
+};
+
+
 /*****************************************************************************/
 
 static ADDRESS_MAP_START( mediagx_map, ADDRESS_SPACE_PROGRAM, 32 )
@@ -736,24 +829,24 @@ static ADDRESS_MAP_START( mediagx_map, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x40008300, 0x400083ff) AM_READWRITE(disp_ctrl_r, disp_ctrl_w)
 	AM_RANGE(0x40008400, 0x400084ff) AM_READWRITE(memory_ctrl_r, memory_ctrl_w)
 	AM_RANGE(0x40800000, 0x40bfffff) AM_RAM AM_BASE(&vram)
-	AM_RANGE(0xfffc0000, 0xffffffff) AM_ROM AM_REGION(REGION_USER1, 0)	/* System BIOS */
+	AM_RANGE(0xfffc0000, 0xffffffff) AM_ROM AM_REGION("bios", 0)	/* System BIOS */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START(mediagx_io, ADDRESS_SPACE_IO, 32)
-	AM_RANGE(0x0000, 0x001f) AM_READWRITE(dma8237_32le_0_r,			dma8237_32le_0_w)
-	AM_RANGE(0x0020, 0x0023) AM_READWRITE(io20_r, io20_w)
-	AM_RANGE(0x0040, 0x005f) AM_READWRITE(pit8253_32le_0_r,			pit8253_32le_0_w)
+	AM_RANGE(0x0000, 0x001f) AM_DEVREADWRITE8(DMA8237, "dma8237_1", dma8237_r, dma8237_w, 0xffffffff)
+	AM_RANGE(0x0020, 0x003f) AM_DEVREADWRITE8(PIC8259, "pic8259_master", io20_r, io20_w, 0xffffffff)
+	AM_RANGE(0x0040, 0x005f) AM_DEVREADWRITE8(PIT8254, "pit8254", pit8253_r, pit8253_w, 0xffffffff)
 	AM_RANGE(0x0060, 0x006f) AM_READWRITE(kbdc8042_32le_r,			kbdc8042_32le_w)
 	AM_RANGE(0x0070, 0x007f) AM_READWRITE(mc146818_port32le_r,		mc146818_port32le_w)
-	AM_RANGE(0x0080, 0x009f) AM_READWRITE(at_page32_r,				at_page32_w)
-	AM_RANGE(0x00a0, 0x00af) AM_READWRITE(pic8259_32le_1_r,			pic8259_32le_1_w)
-	AM_RANGE(0x00c0, 0x00cf) AM_READWRITE(at32_dma8237_1_r,			at32_dma8237_1_w)
+	AM_RANGE(0x0080, 0x009f) AM_READWRITE8(at_page8_r,				at_page8_w, 0xffffffff)
+	AM_RANGE(0x00a0, 0x00bf) AM_DEVREADWRITE8(PIC8259, "pic8259_slave", pic8259_r, pic8259_w, 0xffffffff)
+	AM_RANGE(0x00c0, 0x00df) AM_DEVREADWRITE8(DMA8237, "dma8237_2", at_dma8237_2_r, at_dma8237_2_w, 0xffffffff)
 	AM_RANGE(0x00e8, 0x00eb) AM_NOP		// I/O delay port
-	AM_RANGE(0x01f0, 0x01f7) AM_READWRITE(ide0_r, ide0_w)
+	AM_RANGE(0x01f0, 0x01f7) AM_DEVREADWRITE(IDE_CONTROLLER, "ide", ide_r, ide_w)
 	AM_RANGE(0x0378, 0x037b) AM_READWRITE(parallel_port_r, parallel_port_w)
-	AM_RANGE(0x03f0, 0x03ff) AM_READWRITE(fdc_r, fdc_w)
+	AM_RANGE(0x03f0, 0x03ff) AM_DEVREADWRITE(IDE_CONTROLLER, "ide", fdc_r, fdc_w)
 	AM_RANGE(0x0400, 0x04ff) AM_READWRITE(ad1847_r, ad1847_w)
-	AM_RANGE(0x0cf8, 0x0cff) AM_READWRITE(pci_32le_r,				pci_32le_w)
+	AM_RANGE(0x0cf8, 0x0cff) AM_DEVREADWRITE(PCI_BUS, "pcibus", pci_32le_r,	pci_32le_w)
 ADDRESS_MAP_END
 
 /*****************************************************************************/
@@ -774,15 +867,15 @@ static const gfx_layout CGA_charlayout =
 
 static GFXDECODE_START( CGA )
 /* Support up to four CGA fonts */
-	GFXDECODE_ENTRY( REGION_GFX1, 0x0000, CGA_charlayout,              0, 256 )   /* Font 0 */
-	GFXDECODE_ENTRY( REGION_GFX1, 0x0800, CGA_charlayout,              0, 256 )   /* Font 1 */
-	GFXDECODE_ENTRY( REGION_GFX1, 0x1000, CGA_charlayout,              0, 256 )   /* Font 2 */
-	GFXDECODE_ENTRY( REGION_GFX1, 0x1800, CGA_charlayout,              0, 256 )   /* Font 3*/
+	GFXDECODE_ENTRY( "gfx1", 0x0000, CGA_charlayout,              0, 256 )   /* Font 0 */
+	GFXDECODE_ENTRY( "gfx1", 0x0800, CGA_charlayout,              0, 256 )   /* Font 1 */
+	GFXDECODE_ENTRY( "gfx1", 0x1000, CGA_charlayout,              0, 256 )   /* Font 2 */
+	GFXDECODE_ENTRY( "gfx1", 0x1800, CGA_charlayout,              0, 256 )   /* Font 3*/
 GFXDECODE_END
 
 static INPUT_PORTS_START(mediagx)
-	PORT_START
-	PORT_BIT( 0x001, IP_ACTIVE_HIGH, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2)
+	PORT_START("IN0")
+	PORT_SERVICE_NO_TOGGLE( 0x001, IP_ACTIVE_HIGH )
 	PORT_BIT( 0x002, IP_ACTIVE_HIGH, IPT_SERVICE1 )
 	PORT_BIT( 0x004, IP_ACTIVE_HIGH, IPT_SERVICE2 )
 	PORT_BIT( 0x008, IP_ACTIVE_HIGH, IPT_VOLUME_DOWN )
@@ -795,95 +888,175 @@ static INPUT_PORTS_START(mediagx)
 	PORT_BIT( 0x400, IP_ACTIVE_HIGH, IPT_START3 )
 	PORT_BIT( 0x800, IP_ACTIVE_HIGH, IPT_START4 )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x00f, IP_ACTIVE_HIGH, IPT_BUTTON1 )
 	PORT_BIT( 0x0f0, IP_ACTIVE_HIGH, IPT_BUTTON2 )
 	PORT_BIT( 0xf00, IP_ACTIVE_HIGH, IPT_BUTTON3 )
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_BIT( 0x00f, IP_ACTIVE_HIGH, IPT_BUTTON4 )
 	PORT_BIT( 0x0f0, IP_ACTIVE_HIGH, IPT_BUTTON5 )
 	PORT_BIT( 0xf00, IP_ACTIVE_HIGH, IPT_BUTTON6 )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_BIT( 0x00f, IP_ACTIVE_HIGH, IPT_BUTTON7 )
 	PORT_BIT( 0x0f0, IP_ACTIVE_HIGH, IPT_BUTTON8 )
 	PORT_BIT( 0xf00, IP_ACTIVE_HIGH, IPT_BUTTON9 )
 
-	PORT_START
+	PORT_START("IN4")
 	PORT_BIT( 0x00f, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x0f0, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_PLAYER(2)
 	PORT_BIT( 0xf00, IP_ACTIVE_HIGH, IPT_BUTTON3 ) PORT_PLAYER(2)
 
-	PORT_START
+	PORT_START("IN5")
 	PORT_BIT( 0x00f, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(3)
 	PORT_BIT( 0x0f0, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_PLAYER(3)
 	PORT_BIT( 0xf00, IP_ACTIVE_HIGH, IPT_BUTTON3 ) PORT_PLAYER(3)
 
-	PORT_START
+	PORT_START("IN6")
 	PORT_BIT( 0x00f, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP )
 	PORT_BIT( 0x0f0, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN )
 	PORT_BIT( 0xf00, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT )
 
-	PORT_START
+	PORT_START("IN7")
 	PORT_BIT( 0x00f, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_PLAYER(2)
 	PORT_BIT( 0x0f0, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN ) PORT_PLAYER(2)
 	PORT_BIT( 0xf00, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_PLAYER(2)
 
-	PORT_START
+	PORT_START("IN8")
 	PORT_BIT( 0x00f, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_PLAYER(3)
 	PORT_BIT( 0x0f0, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN ) PORT_PLAYER(3)
 	PORT_BIT( 0xf00, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_PLAYER(3)
 INPUT_PORTS_END
 
-static int irq_callback(int irqline)
+static IRQ_CALLBACK(irq_callback)
 {
 	int r;
-	r = pic8259_acknowledge(1);
+	r = pic8259_acknowledge( mediagx_devices.pic8259_2);
 	if (r==0)
 	{
-		r = pic8259_acknowledge(0);
+		r = pic8259_acknowledge( mediagx_devices.pic8259_1);
 	}
 	return r;
 }
 
+static MACHINE_START(mediagx)
+{
+	mediagx_devices.pit8254 = device_list_find_by_tag( machine->config->devicelist, PIT8254, "pit8254" );
+	mediagx_devices.pic8259_1 = device_list_find_by_tag( machine->config->devicelist, PIC8259, "pic8259_master" );
+	mediagx_devices.pic8259_2 = device_list_find_by_tag( machine->config->devicelist, PIC8259, "pic8259_slave" );
+	mediagx_devices.dma8237_1 = device_list_find_by_tag( machine->config->devicelist, DMA8237, "dma8237_1" );
+	mediagx_devices.dma8237_2 = device_list_find_by_tag( machine->config->devicelist, DMA8237, "dma8237_2" );
+}
+
 static MACHINE_RESET(mediagx)
 {
-	UINT8 *rom = memory_region(REGION_USER1);
+	UINT8 *rom = memory_region(machine, "bios");
 
-	dma8237_reset();
-	cpunum_set_irq_callback(0, irq_callback);
+	cpu_set_irq_callback(machine->cpu[0], irq_callback);
 
 	memcpy(bios_ram, rom, 0x40000);
+	device_reset(machine->cpu[0]);
 
 	dacl = auto_malloc(65536 * sizeof(INT16));
 	dacr = auto_malloc(65536 * sizeof(INT16));
 
-	sound_timer = timer_alloc(sound_timer_callback, NULL);
-	timer_adjust(sound_timer, ATTOTIME_IN_MSEC(10), 0, attotime_zero);
+	sound_timer = timer_alloc(machine, sound_timer_callback, NULL);
+	timer_adjust_oneshot(sound_timer, ATTOTIME_IN_MSEC(10), 0);
 
 	dmadac_enable(0, 2, 1);
-	ide_controller_reset(0);
+	devtag_reset(machine, IDE_CONTROLLER, "ide");
 }
 
+/*************************************************************
+ *
+ * pic8259 configuration
+ *
+ *************************************************************/
+
+static PIC8259_SET_INT_LINE( mediagx_pic8259_1_set_int_line ) {
+	cpu_set_input_line(device->machine->cpu[0], 0, interrupt ? HOLD_LINE : CLEAR_LINE);
+}
+
+
+static PIC8259_SET_INT_LINE( mediagx_pic8259_2_set_int_line ) {
+	pic8259_set_irq_line( mediagx_devices.pic8259_1, 2, interrupt);
+}
+
+
+static const struct pic8259_interface mediagx_pic8259_1_config = {
+	mediagx_pic8259_1_set_int_line
+};
+
+
+static const struct pic8259_interface mediagx_pic8259_2_config = {
+	mediagx_pic8259_2_set_int_line
+};
+
+
+/*************************************************************
+ *
+ * pit8254 configuration
+ *
+ *************************************************************/
+
+static PIT8253_OUTPUT_CHANGED( pc_timer0_w )
+{
+	pic8259_set_irq_line( mediagx_devices.pic8259_1, 0, state);
+}
+
+
+static const struct pit8253_config mediagx_pit8254_config =
+{
+	{
+		{
+			4772720/4,				/* heartbeat IRQ */
+			pc_timer0_w
+		}, {
+			4772720/4,				/* dram refresh */
+			NULL
+		}, {
+			4772720/4,				/* pio port c pin 4, and speaker polling enough */
+			NULL
+		}
+	}
+};
+
+
 static MACHINE_DRIVER_START(mediagx)
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(MEDIAGX, 166000000)
+	MDRV_CPU_ADD("main", MEDIAGX, 166000000)
 	MDRV_CPU_PROGRAM_MAP(mediagx_map, 0)
 	MDRV_CPU_IO_MAP(mediagx_io, 0)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-
+	MDRV_MACHINE_START(mediagx)
 	MDRV_MACHINE_RESET(mediagx)
 
+	MDRV_PCI_BUS_ADD("pcibus", 0)
+	MDRV_PCI_BUS_DEVICE(18, NULL, NULL, cx5510_pci_r, cx5510_pci_w)
+
+	MDRV_PIT8254_ADD( "pit8254", mediagx_pit8254_config )
+
+	MDRV_DMA8237_ADD( "dma8237_1", dma8237_1_config )
+
+	MDRV_DMA8237_ADD( "dma8237_2", dma8237_2_config )
+
+	MDRV_PIC8259_ADD( "pic8259_master", mediagx_pic8259_1_config )
+
+	MDRV_PIC8259_ADD( "pic8259_slave", mediagx_pic8259_2_config )
+
+	MDRV_IDE_CONTROLLER_ADD("ide", ide_interrupt)
+
 	MDRV_NVRAM_HANDLER( mc146818 )
 
  	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_SIZE(640, 480)
 	MDRV_SCREEN_VISIBLE_AREA(0, 639, 0, 239)
+
 	MDRV_GFXDECODE(CGA)
 	MDRV_PALETTE_LENGTH(16)
 
@@ -893,55 +1066,49 @@ static MACHINE_DRIVER_START(mediagx)
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(DMADAC, 0)
+	MDRV_SOUND_ADD("dac1", DMADAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 1.0)
 
-	MDRV_SOUND_ADD(DMADAC, 0)
+	MDRV_SOUND_ADD("dac2", DMADAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 1.0)
 MACHINE_DRIVER_END
 
-static void set_gate_a20(int a20)
+static void set_gate_a20(running_machine *machine, int a20)
 {
-	cpunum_set_input_line(Machine, 0, INPUT_LINE_A20, a20);
+	cpu_set_input_line(machine->cpu[0], INPUT_LINE_A20, a20);
 }
 
-static void keyboard_interrupt(int state)
+static void keyboard_interrupt(running_machine *machine, int state)
 {
-	pic8259_set_irq_line(0, 1, state);
+	pic8259_set_irq_line(mediagx_devices.pic8259_1, 1, state);
 }
 
-static void ide_interrupt(int state)
+static void ide_interrupt(const device_config *device, int state)
 {
-	pic8259_set_irq_line(1, 6, state);
+	pic8259_set_irq_line(mediagx_devices.pic8259_2, 6, state);
+}
+
+static int mediagx_get_out2(running_machine *machine) {
+	return pit8253_get_output( mediagx_devices.pit8254, 2 );
 }
 
 static const struct kbdc8042_interface at8042 =
 {
-	KBDC8042_AT386, set_gate_a20, keyboard_interrupt
+	KBDC8042_AT386, set_gate_a20, keyboard_interrupt, mediagx_get_out2
 };
 
-static const struct ide_interface ide_intf =
-{
-	ide_interrupt
-};
-
-static const struct pci_device_info cx5510 =
-{
-	cx5510_pci_r,
-	cx5510_pci_w
-};
+static void mediagx_set_keyb_int(running_machine *machine, int state) {
+	pic8259_set_irq_line(mediagx_devices.pic8259_1, 1, state);
+}
 
 static void init_mediagx(running_machine *machine)
 {
-	init_pc_common(PCCOMMON_KEYBOARD_AT | PCCOMMON_DMA8237_AT | PCCOMMON_TIMER_8254);
-	mc146818_init(MC146818_STANDARD);
+	frame_width = frame_height = 1;
 
-	pci_init();
-	pci_add_device(0, 18, &cx5510);
+	init_pc_common(machine, PCCOMMON_KEYBOARD_AT,mediagx_set_keyb_int);
+	mc146818_init(machine, MC146818_STANDARD);
 
-	kbdc8042_init(&at8042);
-
-	ide_controller_init(0, &ide_intf);
+	kbdc8042_init(machine, &at8042);
 }
 
 #if SPEEDUP_HACKS
@@ -957,30 +1124,30 @@ struct _speedup_entry
 static speedup_entry *speedup_table;
 static int speedup_count;
 
-INLINE UINT32 generic_speedup(speedup_entry *entry)
+INLINE UINT32 generic_speedup(const address_space *space, speedup_entry *entry)
 {
-	if (activecpu_get_pc() == entry->pc)
+	if (cpu_get_pc(space->cpu) == entry->pc)
 	{
 		entry->hits++;
-		cpu_spinuntil_int();
+		cpu_spinuntil_int(space->cpu);
 	}
 	return main_ram[entry->offset/4];
 }
 
-static READ32_HANDLER( speedup0_r ) { return generic_speedup(&speedup_table[0]); }
-static READ32_HANDLER( speedup1_r ) { return generic_speedup(&speedup_table[1]); }
-static READ32_HANDLER( speedup2_r ) { return generic_speedup(&speedup_table[2]); }
-static READ32_HANDLER( speedup3_r ) { return generic_speedup(&speedup_table[3]); }
-static READ32_HANDLER( speedup4_r ) { return generic_speedup(&speedup_table[4]); }
-static READ32_HANDLER( speedup5_r ) { return generic_speedup(&speedup_table[5]); }
-static READ32_HANDLER( speedup6_r ) { return generic_speedup(&speedup_table[6]); }
-static READ32_HANDLER( speedup7_r ) { return generic_speedup(&speedup_table[7]); }
-static READ32_HANDLER( speedup8_r ) { return generic_speedup(&speedup_table[8]); }
-static READ32_HANDLER( speedup9_r ) { return generic_speedup(&speedup_table[9]); }
-static READ32_HANDLER( speedup10_r ) { return generic_speedup(&speedup_table[10]); }
-static READ32_HANDLER( speedup11_r ) { return generic_speedup(&speedup_table[11]); }
+static READ32_HANDLER( speedup0_r ) { return generic_speedup(space, &speedup_table[0]); }
+static READ32_HANDLER( speedup1_r ) { return generic_speedup(space, &speedup_table[1]); }
+static READ32_HANDLER( speedup2_r ) { return generic_speedup(space, &speedup_table[2]); }
+static READ32_HANDLER( speedup3_r ) { return generic_speedup(space, &speedup_table[3]); }
+static READ32_HANDLER( speedup4_r ) { return generic_speedup(space, &speedup_table[4]); }
+static READ32_HANDLER( speedup5_r ) { return generic_speedup(space, &speedup_table[5]); }
+static READ32_HANDLER( speedup6_r ) { return generic_speedup(space, &speedup_table[6]); }
+static READ32_HANDLER( speedup7_r ) { return generic_speedup(space, &speedup_table[7]); }
+static READ32_HANDLER( speedup8_r ) { return generic_speedup(space, &speedup_table[8]); }
+static READ32_HANDLER( speedup9_r ) { return generic_speedup(space, &speedup_table[9]); }
+static READ32_HANDLER( speedup10_r ) { return generic_speedup(space, &speedup_table[10]); }
+static READ32_HANDLER( speedup11_r ) { return generic_speedup(space, &speedup_table[11]); }
 
-static const read32_handler speedup_handlers[] =
+static const read32_space_func speedup_handlers[] =
 {
 	speedup0_r,		speedup1_r,		speedup2_r,		speedup3_r,
 	speedup4_r,		speedup5_r,		speedup6_r,		speedup7_r,
@@ -1007,7 +1174,7 @@ static void install_speedups(running_machine *machine, speedup_entry *entries, i
 	speedup_count = count;
 
 	for (i = 0; i < count; i++)
-		memory_install_read32_handler(0, ADDRESS_SPACE_PROGRAM, entries[i].offset, entries[i].offset + 3, 0, 0, speedup_handlers[i]);
+		memory_install_read32_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), entries[i].offset, entries[i].offset + 3, 0, 0, speedup_handlers[i]);
 
 #ifdef MAME_DEBUG
 	add_exit_callback(machine, report_speedups);
@@ -1042,13 +1209,13 @@ static DRIVER_INIT( a51site4 )
 /*****************************************************************************/
 
 ROM_START(a51site4)
-	ROM_REGION32_LE(0x40000, REGION_USER1, 0)
+	ROM_REGION32_LE(0x40000, "bios", 0)
 	ROM_LOAD("tinybios.rom", 0x00000, 0x40000, CRC(5ee189cc) SHA1(0b0d9321a4c59b1deea6854923e655a4d8c4fcfe))
 
-	ROM_REGION(0x08100, REGION_GFX1, 0)
+	ROM_REGION(0x08100, "gfx1", 0)
     ROM_LOAD("cga.chr",     0x00000, 0x01000, CRC(42009069) SHA1(ed08559ce2d7f97f68b9f540bddad5b6295294dd))
 
-	DISK_REGION( REGION_DISKS )
+	DISK_REGION( "ide" )
 	DISK_IMAGE( "a51site4", 0, MD5(be0dd1a6f0bba175c25da3d056fa426d) SHA1(49dee1b903a37b99266cc3e19227942c3cf75821) )
 ROM_END
 
