@@ -78,7 +78,7 @@ Sonic Hedgehog 2        171-6215A   837-6963-62       610-0239-62          MPR-1
 
 */
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
 #include "genesis.h"
 #include "rendlay.h"
 #include "megadriv.h"
@@ -92,24 +92,11 @@ UINT32 bios_ctrl_inputs;
 
 #define MASTER_CLOCK		53693100
 
-/* give us access to the megadriv start and update functions so that we can call them */
-VIDEO_UPDATE( megadriv );
-VIDEO_START( megadriv );
-VIDEO_EOF( megadriv );
-MACHINE_RESET( megadriv );
-
-/* in drivers/segae.c */
-VIDEO_UPDATE( megatech_bios );
-VIDEO_EOF( megatech_bios );
-MACHINE_RESET( megatech_bios );
-DRIVER_INIT( megatech_bios );
-
-
 /* not currently used */
 static INPUT_PORTS_START( megatech ) /* Genesis Input Ports */
 	PORT_INCLUDE(megadriv)
 
-	PORT_START_TAG("BIOS_IN0") // port 6
+	PORT_START("BIOS_IN0") // port 6
     PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_SERVICE2 ) PORT_NAME("Select") PORT_CODE(KEYCODE_0)
     PORT_DIPNAME( 0x0002, 0x0002, DEF_STR( Unknown ) )
     PORT_DIPSETTING(      0x0002, DEF_STR( Off ) )
@@ -129,9 +116,9 @@ static INPUT_PORTS_START( megatech ) /* Genesis Input Ports */
     PORT_DIPNAME( 0x0040, 0x0040, DEF_STR( Unknown ) )
     PORT_DIPSETTING(      0x0040, DEF_STR( Off ) )
     PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME("Test mode") PORT_CODE(KEYCODE_F2)
+	PORT_SERVICE_NO_TOGGLE( 0x80, IP_ACTIVE_LOW )
 
-	PORT_START_TAG("BIOS_IN1") // port 6
+	PORT_START("BIOS_IN1") // port 6
 	PORT_BIT(  0x01, IP_ACTIVE_LOW, IPT_COIN1 )  // a few coin inputs here
 	PORT_BIT(  0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT(  0x04, IP_ACTIVE_LOW, IPT_COIN3 )
@@ -141,7 +128,7 @@ static INPUT_PORTS_START( megatech ) /* Genesis Input Ports */
 	PORT_BIT(  0x40, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT(  0x80, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START_TAG("BIOS_DSW0")
+	PORT_START("BIOS_DSW0")
 	PORT_DIPNAME( 0x02, 0x02, "Coin slot 3" )
 	PORT_DIPSETTING (   0x00, "Inhibit" )
 	PORT_DIPSETTING (   0x02, "Accept" )
@@ -167,7 +154,7 @@ static INPUT_PORTS_START( megatech ) /* Genesis Input Ports */
 	PORT_DIPSETTING(    0xe0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x00, "Inhibit" )
 
-	PORT_START_TAG("BIOS_DSW1")
+	PORT_START("BIOS_DSW1")
 	PORT_DIPNAME( 0x0f, 0x01, "Coin Slot 1 value" )
 	PORT_DIPSETTING(    0x00, "Inhibit" )
 	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) )
@@ -204,7 +191,7 @@ static INPUT_PORTS_START( megatech ) /* Genesis Input Ports */
 	PORT_DIPSETTING(    0xf0, "0:30" )
 
 
-	PORT_START_TAG("BIOS_J1")
+	PORT_START("BIOS_J1")
     PORT_DIPNAME( 0x0001, 0x0001, "5" )
     PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
     PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -238,7 +225,7 @@ static UINT8 mt_cart_select_reg;
 
 static READ8_HANDLER( megatech_instr_r )
 {
-	UINT8* instr = memory_region(REGION_CPU3)+0x8000;
+	UINT8* instr = memory_region(space->machine, "mtbios")+0x8000;
 
 	return instr[offset/2];
 //  else
@@ -286,19 +273,18 @@ static WRITE8_HANDLER( mt_sms_standard_rom_bank_w )
 	{
 		case 0:
 			logerror("bank w %02x %02x\n", offset, data);
-			memory_install_read8_handler (1, ADDRESS_SPACE_PROGRAM, 0x0000, 0xbfff, 0, 0, MRA8_BANK5);
-			memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x0000, 0xbfff, 0, 0, MWA8_UNMAP);
+			memory_install_readwrite8_handler(space, 0x0000, 0xbfff, 0, 0, SMH_BANK5, SMH_UNMAP);
 
 			//printf("bank ram??\n");
 			break;
 		case 1:
-			memcpy(sms_rom+0x0000, memory_region(REGION_CPU1)+bank*0x4000, 0x4000);
+			memcpy(sms_rom+0x0000, memory_region(space->machine, "main")+bank*0x4000, 0x4000);
 			break;
 		case 2:
-			memcpy(sms_rom+0x4000, memory_region(REGION_CPU1)+bank*0x4000, 0x4000);
+			memcpy(sms_rom+0x4000, memory_region(space->machine, "main")+bank*0x4000, 0x4000);
 			break;
 		case 3:
-			memcpy(sms_rom+0x8000, memory_region(REGION_CPU1)+bank*0x4000, 0x4000);
+			memcpy(sms_rom+0x8000, memory_region(space->machine, "main")+bank*0x4000, 0x4000);
 			break;
 
 	}
@@ -318,60 +304,49 @@ READ8_HANDLER( md_sms_ioport_dd_r )
 
 
 
-static void megatech_set_genz80_as_sms_standard_ports(void)
+static void megatech_set_genz80_as_sms_standard_ports(running_machine *machine)
 {
 	/* INIT THE PORTS *********************************************************************************************/
-	memory_install_read8_handler (1, ADDRESS_SPACE_IO, 0x0000, 0xffff, 0, 0, z80_unmapped_port_r);
-	memory_install_write8_handler(1, ADDRESS_SPACE_IO, 0x0000, 0xffff, 0, 0, z80_unmapped_port_w);
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_IO), 0x0000, 0xffff, 0, 0, z80_unmapped_port_r, z80_unmapped_port_w);
 
-	memory_install_read8_handler (1, ADDRESS_SPACE_IO, 0x7e, 0x7e, 0, 0, md_sms_vdp_vcounter_r);
-	memory_install_write8_handler(1, ADDRESS_SPACE_IO, 0x7e, 0x7e, 0, 0, sms_sn76496_w);
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_IO), 0x7e, 0x7e, 0, 0, md_sms_vdp_vcounter_r, sms_sn76496_w);
+	memory_install_write8_handler    (cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_IO), 0x7f, 0x7f, 0, 0, sms_sn76496_w);
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_IO), 0xbe, 0xbe, 0, 0, md_sms_vdp_data_r, md_sms_vdp_data_w);
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_IO), 0xbf, 0xbf, 0, 0, md_sms_vdp_ctrl_r, md_sms_vdp_ctrl_w);
 
-	memory_install_write8_handler(1, ADDRESS_SPACE_IO, 0x7f, 0x7f, 0, 0, sms_sn76496_w);
+	memory_install_read8_handler     (cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_IO), 0x10, 0x10, 0, 0, megatech_sms_ioport_dd_r); // super tetris
 
-	memory_install_read8_handler (1, ADDRESS_SPACE_IO, 0xbe, 0xbe, 0, 0, md_sms_vdp_data_r);
-	memory_install_write8_handler(1, ADDRESS_SPACE_IO, 0xbe, 0xbe, 0, 0, md_sms_vdp_data_w);
-
-	memory_install_read8_handler (1, ADDRESS_SPACE_IO, 0xbf, 0xbf, 0, 0, md_sms_vdp_ctrl_r);
-	memory_install_write8_handler(1, ADDRESS_SPACE_IO, 0xbf, 0xbf, 0, 0, md_sms_vdp_ctrl_w);
-
-	memory_install_read8_handler (1, ADDRESS_SPACE_IO, 0x10, 0x10, 0, 0, megatech_sms_ioport_dd_r); // super tetris
-
-	memory_install_read8_handler (1, ADDRESS_SPACE_IO, 0xdc, 0xdc, 0, 0, megatech_sms_ioport_dc_r);
-	memory_install_read8_handler (1, ADDRESS_SPACE_IO, 0xdd, 0xdd, 0, 0, megatech_sms_ioport_dd_r);
-	memory_install_read8_handler (1, ADDRESS_SPACE_IO, 0xde, 0xde, 0, 0, megatech_sms_ioport_dd_r);
-	memory_install_read8_handler (1, ADDRESS_SPACE_IO, 0xdf, 0xdf, 0, 0, megatech_sms_ioport_dd_r); // adams family
+	memory_install_read8_handler     (cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_IO), 0xdc, 0xdc, 0, 0, megatech_sms_ioport_dc_r);
+	memory_install_read8_handler     (cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_IO), 0xdd, 0xdd, 0, 0, megatech_sms_ioport_dd_r);
+	memory_install_read8_handler     (cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_IO), 0xde, 0xde, 0, 0, megatech_sms_ioport_dd_r);
+	memory_install_read8_handler     (cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_IO), 0xdf, 0xdf, 0, 0, megatech_sms_ioport_dd_r); // adams family
 }
 
-static void megatech_set_genz80_as_sms_standard_map(void)
+static void megatech_set_genz80_as_sms_standard_map(running_machine *machine)
 {
 	/* INIT THE MEMMAP / BANKING *********************************************************************************/
 
 	/* catch any addresses that don't get mapped */
-	memory_install_read8_handler (1, ADDRESS_SPACE_PROGRAM, 0x0000, 0xffff, 0, 0, z80_unmapped_r);
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x0000, 0xffff, 0, 0, z80_unmapped_w);
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x0000, 0xffff, 0, 0, z80_unmapped_r, z80_unmapped_w);
 
 	/* fixed rom bank area */
 	sms_rom = auto_malloc(0x400000);
-	memory_install_read8_handler (1, ADDRESS_SPACE_PROGRAM, 0x0000, 0xbfff, 0, 0, MRA8_BANK5);
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x0000, 0xbfff, 0, 0, MWA8_UNMAP);
-	memory_set_bankptr( 5, sms_rom );
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x0000, 0xbfff, 0, 0, SMH_BANK5, SMH_UNMAP);
+	memory_set_bankptr(machine,  5, sms_rom );
 
-	memcpy(sms_rom, memory_region(REGION_CPU1), 0x400000);
+	memcpy(sms_rom, memory_region(machine, "main"), 0x400000);
 
 	/* main ram area */
 	sms_mainram = auto_malloc(0x2000); // 8kb of main ram
-	memory_install_read8_handler (1, ADDRESS_SPACE_PROGRAM, 0xc000, 0xdfff, 0, 0, MRA8_BANK6);
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0xc000, 0xdfff, 0, 0, MWA8_BANK6);
-	memory_set_bankptr( 6, sms_mainram );
-	memory_install_read8_handler (1, ADDRESS_SPACE_PROGRAM, 0xe000, 0xffff, 0, 0, MRA8_BANK7);
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0xe000, 0xffff, 0, 0, MWA8_BANK7);
-	memory_set_bankptr( 7, sms_mainram );
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0xc000, 0xdfff, 0, 0, SMH_BANK6, SMH_BANK6);
+	memory_set_bankptr(machine,  6, sms_mainram );
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0xe000, 0xffff, 0, 0, SMH_BANK7, SMH_BANK7);
+	memory_set_bankptr(machine,  7, sms_mainram );
 	memset(sms_mainram,0x00,0x2000);
 
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0xfffc, 0xffff, 0, 0, mt_sms_standard_rom_bank_w);
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0xfffc, 0xffff, 0, 0, mt_sms_standard_rom_bank_w);
 
-	megatech_set_genz80_as_sms_standard_ports();
+	megatech_set_genz80_as_sms_standard_ports(machine);
 //  smsgg_backupram = NULL;
 
 }
@@ -380,17 +355,20 @@ static void megatech_select_game(running_machine *machine, int gameno)
 {
 	UINT8* game_region;
 	UINT8* bios_region;
+	char tempname[20];
 
 	printf("game 0 selected\n");
 
-	cpunum_set_input_line(machine, 0, INPUT_LINE_RESET, ASSERT_LINE);
-	cpunum_set_input_line(machine, 1, INPUT_LINE_RESET, ASSERT_LINE);
-	cpunum_set_input_line(machine, 0, INPUT_LINE_HALT, ASSERT_LINE);
-	cpunum_set_input_line(machine, 1, INPUT_LINE_HALT, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[0], INPUT_LINE_RESET, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[1], INPUT_LINE_RESET, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[0], INPUT_LINE_HALT, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[1], INPUT_LINE_HALT, ASSERT_LINE);
 	sndti_reset(SOUND_YM2612, 0);
 
-	game_region = memory_region(REGION_USER1 + (gameno*2) + 0);
-	bios_region = memory_region(REGION_USER1 + (gameno*2) + 1);
+	sprintf(tempname, "game%d", gameno);
+	game_region = memory_region(machine, tempname);
+	sprintf(tempname, "inst%d", gameno);
+	bios_region = memory_region(machine, tempname);
 
 	megadriv_stop_scanline_timer();// stop the scanline timer for the genesis vdp... it can be restarted in video eof when needed
 	segae_md_sms_stop_scanline_timer();// stop the scanline timer for the sms vdp
@@ -399,8 +377,8 @@ static void megatech_select_game(running_machine *machine, int gameno)
 	/* if the regions exist we're fine */
 	if (game_region && bios_region)
 	{
-		memcpy(memory_region(REGION_CPU3)+0x8000, bios_region, 0x8000);
-		memcpy(memory_region(REGION_CPU1), game_region, 0x300000);
+		memcpy(memory_region(machine, "mtbios")+0x8000, bios_region, 0x8000);
+		memcpy(memory_region(machine, "main"), game_region, 0x300000);
 
 		// I store an extra byte at the end of the instruction rom region when loading
 		// to indicate if the current cart is an SMS cart.. the original hardware
@@ -409,9 +387,9 @@ static void megatech_select_game(running_machine *machine, int gameno)
 		{
 			printf("SMS cart!!, CPU not running\n");
 			current_game_is_sms = 1;
-			megatech_set_genz80_as_sms_standard_map();
-			cpunum_set_input_line(machine, 1, INPUT_LINE_HALT, CLEAR_LINE);
-			cpunum_set_input_line(machine, 1, INPUT_LINE_RESET, CLEAR_LINE);
+			megatech_set_genz80_as_sms_standard_map(machine);
+			cpu_set_input_line(machine->cpu[1], INPUT_LINE_HALT, CLEAR_LINE);
+			cpu_set_input_line(machine->cpu[1], INPUT_LINE_RESET, CLEAR_LINE);
 
 
 		}
@@ -419,9 +397,9 @@ static void megatech_select_game(running_machine *machine, int gameno)
 		{
 			printf("Genesis Cart, CPU0 running\n");
 			current_game_is_sms = 0;
-			megatech_set_megadrive_z80_as_megadrive_z80();
-			cpunum_set_input_line(machine, 0, INPUT_LINE_RESET, CLEAR_LINE);
-			cpunum_set_input_line(machine, 0, INPUT_LINE_HALT, CLEAR_LINE);
+			megatech_set_megadrive_z80_as_megadrive_z80(machine);
+			cpu_set_input_line(machine->cpu[0], INPUT_LINE_RESET, CLEAR_LINE);
+			cpu_set_input_line(machine->cpu[0], INPUT_LINE_HALT, CLEAR_LINE);
 		}
 		else
 		{
@@ -430,14 +408,14 @@ static void megatech_select_game(running_machine *machine, int gameno)
 	}
 	else
 	{
-		cpunum_set_input_line(machine, 0, INPUT_LINE_HALT, ASSERT_LINE);
-		cpunum_set_input_line(machine, 1, INPUT_LINE_HALT, ASSERT_LINE);
-	//  cpunum_set_input_line(machine, 0, INPUT_LINE_RESET, ASSERT_LINE);
-	//  cpunum_set_input_line(machine, 1, INPUT_LINE_RESET, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[0], INPUT_LINE_HALT, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[1], INPUT_LINE_HALT, ASSERT_LINE);
+	//  cpu_set_input_line(machine->cpu[0], INPUT_LINE_RESET, ASSERT_LINE);
+	//  cpu_set_input_line(machine->cpu[1], INPUT_LINE_RESET, ASSERT_LINE);
 
 		/* no cart.. */
-		memset(memory_region(REGION_CPU3)+0x8000, 0x00, 0x8000);
-		memset(memory_region(REGION_CPU1), 0x00, 0x300000);
+		memset(memory_region(machine, "mtbios")+0x8000, 0x00, 0x8000);
+		memset(memory_region(machine, "main"), 0x00, 0x300000);
 	}
 
 	return;
@@ -455,27 +433,27 @@ static WRITE8_HANDLER( megatech_cart_select_w )
 	mt_cart_select_reg = data;
 
 
-	megatech_select_game(Machine, mt_cart_select_reg);
+	megatech_select_game(space->machine, mt_cart_select_reg);
 
 /*
     if (mt_cart_select_reg==2)
     {
         printf("game 2 selected\n");
-        memcpy(memory_region(REGION_CPU3)+0x8000, memory_region(REGION_USER2), 0x8000);
+        memcpy(memory_region(space->machine, "mtbios")+0x8000, memory_region(space->machine, "inst0"), 0x8000);
     }
 //  else if (mt_cart_select_reg==0)
 //  {
 //      printf("game 0 selected\n");
-//      memcpy(memory_region(REGION_CPU3)+0x8000, memory_region(REGION_USER4), 0x8000);
+//      memcpy(memory_region(space->machine, "mtbios")+0x8000, memory_region(space->machine, "inst2"), 0x8000);
 //  }
     else if (mt_cart_select_reg==6)
     {
         printf("game 6 selected\n");
-        memcpy(memory_region(REGION_CPU3)+0x8000, memory_region(REGION_USER6), 0x8000);
+        memcpy(memory_region(space->machine, "mtbios")+0x8000, memory_region(space->machine, "user6"), 0x8000);
     }
     else
     {
-        memset(memory_region(REGION_CPU3)+0x8000, 0x00, 0x8000);
+        memset(memory_region(space->machine, "mtbios")+0x8000, 0x00, 0x8000);
     }
 */
 
@@ -503,11 +481,6 @@ static WRITE8_HANDLER( bios_ctrl_w )
 }
 
 
-static READ8_HANDLER( megaplay_r0) { return readinputportbytag("BIOS_IN0") ; }
-static READ8_HANDLER( megaplay_r1) { return readinputportbytag("BIOS_IN1") ; }
-static READ8_HANDLER( megaplay_r2) { return readinputportbytag("BIOS_DSW0") ; }
-static READ8_HANDLER( megaplay_r3) { return readinputportbytag("BIOS_DSW1") ; }
-
 static int mt_bank_bank_pos = 0;
 static int mt_bank_partial = 0;
 static int mt_bank_addr = 0;
@@ -550,11 +523,11 @@ static ADDRESS_MAP_START( megatech_bios_map, ADDRESS_SPACE_PROGRAM, 8 )
  	AM_RANGE(0x3000, 0x3fff) AM_READWRITE(megatech_banked_ram_r, megatech_banked_ram_w) // copies instruction data here at startup, must be banked
 	AM_RANGE(0x4000, 0x5fff) AM_RAM // plain ram?
 	AM_RANGE(0x6000, 0x6000) AM_WRITE( mt_z80_bank_w )
-	AM_RANGE(0x6400, 0x6400) AM_READ(megaplay_r2)
-	AM_RANGE(0x6401, 0x6401) AM_READ(megaplay_r3)
+	AM_RANGE(0x6400, 0x6400) AM_READ_PORT("BIOS_DSW0")
+	AM_RANGE(0x6401, 0x6401) AM_READ_PORT("BIOS_DSW1")
 	AM_RANGE(0x6404, 0x6404) AM_READWRITE(megatech_cart_select_r, megatech_cart_select_w) // cart select & ram bank
-	AM_RANGE(0x6800, 0x6800) AM_READ(megaplay_r0)
-	AM_RANGE(0x6801, 0x6801) AM_READ(megaplay_r1)
+	AM_RANGE(0x6800, 0x6800) AM_READ_PORT("BIOS_IN0")
+	AM_RANGE(0x6801, 0x6801) AM_READ_PORT("BIOS_IN1")
 	AM_RANGE(0x6802, 0x6807) AM_READWRITE(bios_ctrl_r, bios_ctrl_w)
 //  AM_RANGE(0x6805, 0x6805) AM_READ(input_port_8_r)
  	AM_RANGE(0x7000, 0x77ff) AM_ROM // from bios rom (0x7000-0x77ff populated in ROM)
@@ -570,7 +543,7 @@ static WRITE8_HANDLER (megatech_bios_port_ctrl_w)
 
 static READ8_HANDLER (megatech_bios_joypad_r)
 {
-	return megatech_bios_port_cc_dc_r(offset,bios_port_ctrl);
+	return megatech_bios_port_cc_dc_r(space->machine,offset,bios_port_ctrl);
 }
 
 
@@ -583,7 +556,7 @@ static WRITE8_HANDLER (megatech_bios_port_7f_w)
 
 
 static ADDRESS_MAP_START( megatech_bios_portmap, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x3f, 0x3f) AM_WRITE(megatech_bios_port_ctrl_w)
 
 	AM_RANGE(0x7f, 0x7f) AM_READWRITE(sms_vcounter_r, megatech_bios_port_7f_w)
@@ -604,19 +577,22 @@ static DRIVER_INIT(mtnew)
 
 static VIDEO_START(mtnew)
 {
-	init_for_megadrive(); // create an sms vdp too, for comptibility mode
+	init_for_megadrive(machine); // create an sms vdp too, for comptibility mode
 	VIDEO_START_CALL(megadriv);
 }
 //attotime_never
 static VIDEO_UPDATE(mtnew)
 {
-	if (screen ==0)
+	const device_config *megadriv_screen = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "megadriv");
+	const device_config *menu_screen     = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "menu");
+
+	if (screen == megadriv_screen)
 	{
 		/* if we're running an sms game then use the SMS update.. maybe this should be moved to the megadrive emulation core as compatibility mode is a feature of the chip */
 		if (!current_game_is_sms) VIDEO_UPDATE_CALL(megadriv);
 		else VIDEO_UPDATE_CALL(megatech_md_sms);
 	}
-	else if (screen ==1) VIDEO_UPDATE_CALL(megatech_bios);
+	else if (screen == menu_screen) VIDEO_UPDATE_CALL(megatech_bios);
 	return 0;
 }
 
@@ -641,7 +617,7 @@ static MACHINE_DRIVER_START( megatech )
 	MDRV_IMPORT_FROM(megadriv)
 
 	/* Megatech has an extra SMS based bios *and* an additional screen */
-	MDRV_CPU_ADD_TAG("megatech_bios", Z80, MASTER_CLOCK / 15) /* ?? */
+	MDRV_CPU_ADD("mtbios", Z80, MASTER_CLOCK / 15) /* ?? */
 	MDRV_CPU_PROGRAM_MAP(megatech_bios_map, 0)
 	MDRV_CPU_IO_MAP(megatech_bios_portmap,0)
 
@@ -653,14 +629,14 @@ static MACHINE_DRIVER_START( megatech )
 
 	MDRV_DEFAULT_LAYOUT(layout_dualhovu)
 
-	MDRV_SCREEN_ADD("menu", 0x000)
+	MDRV_SCREEN_ADD("menu", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB15)
 	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_SIZE(342,262)
 	MDRV_SCREEN_VISIBLE_AREA(0, 256-1, 0, 224-1)
 
 	/* sound hardware */
-	MDRV_SOUND_ADD(SN76496, MASTER_CLOCK/15)
+	MDRV_SOUND_ADD("sn2", SN76496, MASTER_CLOCK/15)
 	MDRV_SOUND_ROUTE(0, "left", 0.50)
 	MDRV_SOUND_ROUTE(1, "right", 0.50)
 MACHINE_DRIVER_END
@@ -681,8 +657,8 @@ MACHINE_DRIVER_END
 	ROM_FILL(0x8000, 2, FLAG) \
 
 #define MEGATECH_BIOS \
-	ROM_REGION( 0x400000, REGION_CPU1, ROMREGION_ERASEFF ) \
-	ROM_REGION( 0x10000, REGION_CPU3, 0 ) \
+	ROM_REGION( 0x400000, "main", ROMREGION_ERASEFF ) \
+	ROM_REGION( 0x10000, "mtbios", 0 ) \
 	ROM_LOAD( "epr12664.20", 0x000000, 0x8000, CRC(f71e9526) SHA1(1c7887541d02c41426992d17f8e3db9e03975953) ) \
 
 /* no games */
@@ -700,7 +676,7 @@ ROM_END
 
 ROM_START( mt_beast )
 	MEGATECH_BIOS
-	MEGATECH_GAME01(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME01("game0", "inst0")
 ROM_END
 
 /* Game 06 - Out Run (SMS) */
@@ -714,7 +690,7 @@ ROM_END
 
 ROM_START( mt_orun ) /* Outrun */
 	MEGATECH_BIOS
-	MEGATECH_GAME06(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME06("game0", "inst0")
 ROM_END
 
 /* Game 13 - Astro Warrior (SMS) */
@@ -726,7 +702,7 @@ ROM_END
 
 ROM_START( mt_astro )
 	MEGATECH_BIOS
-	MEGATECH_GAME13(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME13("game0", "inst0")
 ROM_END
 
 /* Game 21 - World Cup Soccer (Genesis) */
@@ -738,7 +714,7 @@ ROM_END
 
 ROM_START( mt_wcsoc )
 	MEGATECH_BIOS
-	MEGATECH_GAME21(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME21("game0", "inst0")
 ROM_END
 
 /* Game 23 - Ghouls and Ghosts (Genesis) */
@@ -752,7 +728,7 @@ ROM_END
 
 ROM_START( mt_gng )
 	MEGATECH_BIOS
-	MEGATECH_GAME23(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME23("game0", "inst0")
 ROM_END
 
 /* Game 24 - Super Hang On (Genesis) */
@@ -765,7 +741,7 @@ ROM_END
 
 ROM_START( mt_shang ) /* Super HangOn */
 	MEGATECH_BIOS
-	MEGATECH_GAME24(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME24("game0", "inst0")
 ROM_END
 
 /* Game 25 - Golden Axe (Genesis) */
@@ -778,7 +754,7 @@ ROM_END
 
 ROM_START( mt_gaxe )
 	MEGATECH_BIOS
-	MEGATECH_GAME25(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME25("game0", "inst0")
 ROM_END
 
 /* Game 39 - Super Monaco Grand Prix (Genesis) */
@@ -791,7 +767,7 @@ ROM_END
 
 ROM_START( mt_smgp ) /* Super Monaco Grand Prix */
 	MEGATECH_BIOS
-	MEGATECH_GAME39(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME39("game0", "inst0")
 ROM_END
 
 /* Game 52 - Sonic (Genesis) */
@@ -803,7 +779,7 @@ ROM_END
 
 ROM_START( mt_sonic )
 	MEGATECH_BIOS
-	MEGATECH_GAME52(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME52("game0", "inst0")
 ROM_END
 
 #define MEGATECH_GAME52ALT(GAME_REGION, INSTRUCTION_REGION) \
@@ -814,7 +790,7 @@ ROM_END
 
 ROM_START( mt_sonia ) /* Sonic  (alt)*/
 	MEGATECH_BIOS
-	MEGATECH_GAME52ALT(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME52ALT("game0", "inst0")
 ROM_END
 
 /* Game 57 - Golden Axe 2 (Genesis) */
@@ -826,7 +802,7 @@ ROM_END
 
 ROM_START( mt_gaxe2 ) /* Golden Axe 2 */
 	MEGATECH_BIOS
-	MEGATECH_GAME57(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME57("game0", "inst0")
 ROM_END
 
 /* Game 58 - Sports Talk Football */
@@ -838,7 +814,7 @@ ROM_END
 
 ROM_START( mt_stf ) /* Sports Talk Football */
 	MEGATECH_BIOS
-	MEGATECH_GAME58(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME58("game0", "inst0")
 ROM_END
 
 /* Game 53 - Fire Shark */
@@ -854,7 +830,7 @@ ROM_END
 
 ROM_START( mt_fshrk ) /* Fire Shark */
 	MEGATECH_BIOS
-	MEGATECH_GAME53(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME53("game0", "inst0")
 ROM_END
 
 /* Game 38 - E-Swat */
@@ -866,7 +842,7 @@ ROM_END
 
 ROM_START( mt_eswat ) /* E-Swat */
 	MEGATECH_BIOS
-	MEGATECH_GAME38(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME38("game0", "inst0")
 ROM_END
 
 /* Game 49 - Bonanza Bros */
@@ -879,7 +855,7 @@ ROM_END
 
 ROM_START( mt_bbros ) /* Bonanza Bros */
 	MEGATECH_BIOS
-	MEGATECH_GAME49(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME49("game0", "inst0")
 ROM_END
 
 /* Game 48 - Wrestle War */
@@ -892,7 +868,7 @@ ROM_END
 
 ROM_START( mt_wwar ) /* Wrestle War */
 	MEGATECH_BIOS
-	MEGATECH_GAME48(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME48("game0", "inst0")
 ROM_END
 
 /* Game 62 - Sonic 2 */
@@ -906,7 +882,7 @@ ROM_END
 
 ROM_START( mt_soni2 ) /* Sonic 2 */
 	MEGATECH_BIOS
-	MEGATECH_GAME62(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME62("game0", "inst0")
 ROM_END
 
 /* Game 59 - Mario Lemieux Hockey */
@@ -919,7 +895,7 @@ ROM_END
 
 ROM_START( mt_mlh )
 	MEGATECH_BIOS
-	MEGATECH_GAME59(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME59("game0", "inst0")
 ROM_END
 
 /* Game 60 - Kid Chameleon */
@@ -933,7 +909,7 @@ ROM_END
 
 ROM_START( mt_kcham ) /* Kid Chameleon */
 	MEGATECH_BIOS
-	MEGATECH_GAME60(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME60("game0", "inst0")
 ROM_END
 
 /* Game 20 - Last Battle */
@@ -946,7 +922,7 @@ ROM_END
 
 ROM_START( mt_lastb ) /* Last Battle */
 	MEGATECH_BIOS
-	MEGATECH_GAME20(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME20("game0", "inst0")
 ROM_END
 
 /* Game 40 - Moon Walker */
@@ -960,7 +936,7 @@ ROM_END
 
 ROM_START( mt_mwalk ) /* Moon Walker */
 	MEGATECH_BIOS
-	MEGATECH_GAME40(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME40("game0", "inst0")
 ROM_END
 
 /* Game 41 - Crackdown */
@@ -974,7 +950,7 @@ ROM_END
 
 ROM_START( mt_crack )
 	MEGATECH_BIOS
-	MEGATECH_GAME41(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME41("game0", "inst0")
 ROM_END
 
 
@@ -988,7 +964,7 @@ ROM_END
 
 ROM_START( mt_mystd ) /* Mystic Defender */
 	MEGATECH_BIOS
-	MEGATECH_GAME27(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME27("game0", "inst0")
 ROM_END
 
 /* Game 02 - Space Harrier 2 */
@@ -1001,7 +977,7 @@ ROM_END
 
 ROM_START( mt_shar2 ) /* Space Harrier 2 */
 	MEGATECH_BIOS
-	MEGATECH_GAME02(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME02("game0", "inst0")
 ROM_END
 
 /* Game 03 - Super Thunder Blade */
@@ -1014,7 +990,7 @@ ROM_END
 
 ROM_START( mt_stbld ) /* Super Thunder Blade */
 	MEGATECH_BIOS
-	MEGATECH_GAME03(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME03("game0", "inst0")
 ROM_END
 
 /* Game 22 - Tetris */
@@ -1027,7 +1003,7 @@ ROM_END
 
 ROM_START( mt_tetri ) /* Tetris */
 	MEGATECH_BIOS
-	MEGATECH_GAME22(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME22("game0", "inst0")
 ROM_END
 
 /* Game 11 - Thunder Force 2 */
@@ -1040,7 +1016,7 @@ ROM_END
 
 ROM_START( mt_tfor2 ) /* Thunder Force 2 */
 	MEGATECH_BIOS
-	MEGATECH_GAME11(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME11("game0", "inst0")
 ROM_END
 
 /* Game 35 - Tommy Lasorda Baseball */
@@ -1054,7 +1030,7 @@ ROM_END
 
 ROM_START( mt_tlbba ) /* Tommy Lasorda Baseball */
 	MEGATECH_BIOS
-	MEGATECH_GAME35(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME35("game0", "inst0")
 ROM_END
 
 /* Game 36 - Columns */
@@ -1067,7 +1043,7 @@ ROM_END
 
 ROM_START( mt_cols ) /* Columns */
 	MEGATECH_BIOS
-	MEGATECH_GAME36(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME36("game0", "inst0")
 ROM_END
 
 /* Game 04 - Great Golf (SMS) */
@@ -1081,7 +1057,7 @@ ROM_END
 
 ROM_START( mt_ggolf )
 	MEGATECH_BIOS
-	MEGATECH_GAME04(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME04("game0", "inst0")
 ROM_END
 
 /* Game 05 - Great Soccer (SMS) - bad dump */
@@ -1094,7 +1070,7 @@ ROM_END
 
 ROM_START( mt_gsocr )
 	MEGATECH_BIOS
-	MEGATECH_GAME05(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME05("game0", "inst0")
 ROM_END
 
 /* Game 07 - Alien Syndrome (SMS) */
@@ -1107,7 +1083,7 @@ ROM_END
 
 ROM_START( mt_asyn ) /* Alien Syndrome (SMS based) */
 	MEGATECH_BIOS
-	MEGATECH_GAME07(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME07("game0", "inst0")
 ROM_END
 
 /* Game 29 - Parlour Games (SMS) */
@@ -1120,7 +1096,7 @@ ROM_END
 
 ROM_START( mt_parlg ) /* Parlour Games (SMS Based)  */
 	MEGATECH_BIOS
-	MEGATECH_GAME29(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME29("game0", "inst0")
 ROM_END
 
 /* Game 08 - Shinobi (SMS) */
@@ -1133,7 +1109,7 @@ ROM_END
 
 ROM_START( mt_shnbi ) /* Shinobi. */
 	MEGATECH_BIOS
-	MEGATECH_GAME08(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME08("game0", "inst0")
 ROM_END
 
 /* Game 10 - AFterburner (SMS) */
@@ -1146,7 +1122,7 @@ ROM_END
 
 ROM_START( mt_aftrb ) /* Afterburner. */
 	MEGATECH_BIOS
-	MEGATECH_GAME10(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME10("game0", "inst0")
 ROM_END
 
 /* Game 28 - Revenge of Shinobi */
@@ -1160,7 +1136,7 @@ ROM_END
 
 ROM_START( mt_revsh ) /* The Revenge Of Shinobi. */
 	MEGATECH_BIOS
-	MEGATECH_GAME28(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME28("game0", "inst0")
 ROM_END
 
 /* Game 31 - Arnold Palmer Tournament Gold */
@@ -1174,7 +1150,7 @@ ROM_END
 
 ROM_START( mt_tgolf ) /* Arnold Palmer Tournament Golf */
 	MEGATECH_BIOS
-	MEGATECH_GAME31(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME31("game0", "inst0")
 ROM_END
 
 
@@ -1188,7 +1164,7 @@ ROM_END
 
 ROM_START( mt_astrm ) /* Alien Storm. */
 	MEGATECH_BIOS
-	MEGATECH_GAME47(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME47("game0", "inst0")
 ROM_END
 
 /* Game 44 - Arrow Flash */
@@ -1202,7 +1178,7 @@ ROM_END
 
 ROM_START( mt_arrow ) /* Arrow Flash */
 	MEGATECH_BIOS
-	MEGATECH_GAME44(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME44("game0", "inst0")
 ROM_END
 
 /* Game 32 - Super Real Basketball */
@@ -1215,7 +1191,7 @@ ROM_END
 
 ROM_START( mt_srbb ) /* Super Real Basketball */
 	MEGATECH_BIOS
-	MEGATECH_GAME32(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME32("game0", "inst0")
 ROM_END
 
 /* Game 26 - Forgotten Worlds */
@@ -1229,34 +1205,34 @@ ROM_END
 
 ROM_START( mt_fwrld ) /* Forgotten Worlds */
 	MEGATECH_BIOS
-	MEGATECH_GAME26(REGION_USER1, REGION_USER2)
+	MEGATECH_GAME26("game0", "inst0")
 ROM_END
 
 /* Compilations of games to show the multi-cart support */
 
 ROM_START( mt_comp1 )
 	MEGATECH_BIOS
-	MEGATECH_GAME01(REGION_USER1, REGION_USER2)
-	MEGATECH_GAME13(REGION_USER3, REGION_USER4)
-	MEGATECH_GAME21(REGION_USER5, REGION_USER6)
-	MEGATECH_GAME06(REGION_USER7, REGION_USER8)
-	MEGATECH_GAME08(REGION_USER9, REGION_USER10)
-	MEGATECH_GAME28(REGION_USER11, REGION_USER12)
-	MEGATECH_GAME49(REGION_USER13, REGION_USER14)
-	MEGATECH_GAME60(REGION_USER15, REGION_USER16)
+	MEGATECH_GAME01("game0", "inst0")
+	MEGATECH_GAME13("game1", "inst1")
+	MEGATECH_GAME21("game2", "inst2")
+	MEGATECH_GAME06("game3", "inst3")
+	MEGATECH_GAME08("game4", "inst4")
+	MEGATECH_GAME28("game5", "inst5")
+	MEGATECH_GAME49("game6", "inst6")
+	MEGATECH_GAME60("game7", "inst7")
 ROM_END
 
 
 ROM_START( mt_comp2 )
 	MEGATECH_BIOS
-	MEGATECH_GAME10(REGION_USER1, REGION_USER2)
-	MEGATECH_GAME39(REGION_USER3, REGION_USER4)
-	MEGATECH_GAME24(REGION_USER5, REGION_USER6)
-	MEGATECH_GAME52(REGION_USER7, REGION_USER8)
-	MEGATECH_GAME29(REGION_USER9, REGION_USER10)
-	MEGATECH_GAME36(REGION_USER11, REGION_USER12)
-	MEGATECH_GAME40(REGION_USER13, REGION_USER14)
-	MEGATECH_GAME57(REGION_USER15, REGION_USER16)
+	MEGATECH_GAME10("game0", "inst0")
+	MEGATECH_GAME39("game1", "inst1")
+	MEGATECH_GAME24("game2", "inst2")
+	MEGATECH_GAME52("game3", "inst3")
+	MEGATECH_GAME29("game4", "inst4")
+	MEGATECH_GAME36("game5", "inst5")
+	MEGATECH_GAME40("game6", "inst6")
+	MEGATECH_GAME57("game7", "inst7")
 ROM_END
 
 
@@ -1302,7 +1278,7 @@ ROM_END
 /* 37 */ // unknown
 /* 38 */ GAME( 1990, mt_eswat, megatech, megatech, megatech, mtnew, ROT0, "Sega",                  "Cyber Police ESWAT: Enhanced Special Weapons and Tactics (Mega-Tech)", GAME_NOT_WORKING )
 /* 39 */ GAME( 1990, mt_smgp,  megatech, megatech, megatech, mtnew, ROT0, "Sega",                  "Super Monaco GP (Mega-Tech)", GAME_NOT_WORKING )
-/* 40 */ GAME( 1990, mt_mwalk, megatech, megatech, megatech, mtnew, ROT0, "Sega",                  "Moonwalker (Mega-Tech)", GAME_NOT_WORKING )
+/* 40 */ GAME( 1990, mt_mwalk, megatech, megatech, megatech, mtnew, ROT0, "Sega",                  "Michael Jackson's Moonwalker (Mega-Tech)", GAME_NOT_WORKING )
 /* 41 */ GAME( 1990, mt_crack, megatech, megatech, megatech, mtnew, ROT0, "Sega",                  "Crack Down (Mega-Tech)", GAME_NOT_WORKING )
 /* 42 */ // unknown
 /* 43 */ // unknown
