@@ -22,10 +22,9 @@
 /*====================================================================*/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/m68000/m68000.h"
 #include "cpu/tms34010/tms34010.h"
-#include "cpu/tms34010/34010ops.h"
-#include "cpu/i8051/i8051.h"
+#include "cpu/mcs51/mcs51.h"
 #include "sound/2151intf.h"
 #include "sound/upd7759.h"
 #include "sound/dac.h"
@@ -93,7 +92,7 @@ static UINT8 ti_uart[9];
 static int ti_uart_mode_cycle=0;
 static int ti_uart_sync_cycle=0;
 
-static void m68901_int_gen(int source);
+static void m68901_int_gen(running_machine *machine, int source);
 
 /* 68901 */
 enum{   TMRB=0,TXERR,TBE,RXERR,RBF,TMRA,GPIP6,GPIP7,     // A Registers
@@ -106,38 +105,44 @@ enum{   RX=0,TX,STATUS,SYN1,SYN2,DLE,MODE1,MODE2,COMMAND
 
 
 /* Probably wrong and a bit crap */
-static int data_to_i8031(void)
+static int data_to_i8031(const device_config *device)
 {
-     mame_printf_debug("68k sent data: %x\n",M68681.TBB);
-     return M68681.TBB;
+	mame_printf_debug("68k sent data: %x\n",M68681.TBB);
+    M68681.SRB |=0x0400;                   // Data has been sent - TX ready for more.
+    // Write to sound board
+    if(M68681.IMR & 0x1000)
+    {
+    	cpu_set_input_line_and_vector(device->machine->cpu[0],3, HOLD_LINE, M68681.IVR);         // Generate an interrupt, if allowed.
+    }
+	return M68681.TBB;
 }
 
-static void data_from_i8031(int data)
+static void data_from_i8031(const device_config *device, int data)
 {
-     M68681.RBB  = data<<8;                         // Put into receive buffer.
-     M68681.SRB |= 0x0100;                          // Set Receiver B ready.
-     if(M68681.IMR & 0x1000)
-     {
-     	cpunum_set_input_line_and_vector(Machine, 0,3, HOLD_LINE, M68681.IVR);    // Generate a receiver interrupt.
-     	mame_printf_debug("INTERRUPT!!!\n");
-     }
-   mame_printf_debug("8031 sent data: %x\n",data);
+	M68681.RBB  = data<<8;                         // Put into receive buffer.
+	M68681.SRB |= 0x0100;                          // Set Receiver B ready.
+	if(M68681.IMR & 0x1000)
+	{
+		cpu_set_input_line_and_vector(device->machine->cpu[0],3, HOLD_LINE, M68681.IVR);    // Generate a receiver interrupt.
+		mame_printf_debug("INTERRUPT!!!\n");
+	}
+	mame_printf_debug("8031 sent data: %x\n",data);
 }
 
 
-static void changecolor_BBBBBRRRRRGGGGGG(pen_t color,int data)
+static void changecolor_BBBBBRRRRRGGGGGG(running_machine *machine,pen_t color,int data)
 {
-	palette_set_color_rgb(Machine,color,pal5bit(data >> 6),pal5bit(data >> 1),pal5bit(data >> 11));
+	palette_set_color_rgb(machine,color,pal5bit(data >> 6),pal5bit(data >> 1),pal5bit(data >> 11));
 }
 
 static WRITE16_HANDLER( paletteram16_BBBBBRRRRRGGGGGG_word_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
-	changecolor_BBBBBRRRRRGGGGGG(offset,paletteram16[offset]);
+	changecolor_BBBBBRRRRRGGGGGG(space->machine,offset,paletteram16[offset]);
 }
 
 
-static void micro3d_scanline_update(running_machine *machine, int screen, mame_bitmap *bitmap, int scanline, const tms34010_display_params *params)
+static void micro3d_scanline_update(const device_config *screen, bitmap_t *bitmap, int scanline, const tms34010_display_params *params)
 {
 	UINT16 *src = &micro3d_sprite_vram[(params->rowaddr << 8) & 0x7fe00];
 	UINT16 *dest = BITMAP_ADDR16(bitmap, scanline, 0);
@@ -164,8 +169,8 @@ static void micro3d_scanline_update(running_machine *machine, int screen, mame_b
 
 static MACHINE_RESET( micro3d )
 {
-        i8051_set_serial_tx_callback(data_from_i8031);
-        i8051_set_serial_rx_callback(data_to_i8031);
+        i8051_set_serial_tx_callback(machine->cpu[2], data_from_i8031);
+        i8051_set_serial_rx_callback(machine->cpu[2], data_to_i8031);
         ti_uart[STATUS]=1;
         M68681.SRA=0x0500;
         M68681.SRB=0x0500;
@@ -173,7 +178,7 @@ static MACHINE_RESET( micro3d )
 
 static DRIVER_INIT( stankatk )
 {
-       UINT16 *rom = (UINT16 *)memory_region(REGION_CPU1);
+       UINT16 *rom = (UINT16 *)memory_region(machine, "main");
        rom[0x1F543]=0x4E71;                                       /* 3ea86 - nop */
        rom[0x1F546]=0x4E71;                                       /* 3ea8c - nop */
        rom[0x1F596]=0x4E71;
@@ -188,7 +193,7 @@ static DRIVER_INIT( stankatk )
 
 static DRIVER_INIT( botss )
 {
-       UINT16 *rom = (UINT16 *)memory_region(REGION_CPU1);
+       UINT16 *rom = (UINT16 *)memory_region(machine, "main");
        rom[0x1FCC0]=0x4E71;         /* Eliminate startup Am29000 timeout */
        rom[0x1FBF0]=0x4E71;         /* Skip AM29k code version detect */
        rom[0x1FC88]=0x4E71;
@@ -200,24 +205,25 @@ static DRIVER_INIT( botss )
 
 static DRIVER_INIT( f15se )
 {
-//       UINT16 *rom = (UINT16 *)memory_region(REGION_CPU1);
+//       UINT16 *rom = (UINT16 *)memory_region(machine, "main");
 }
 
 static DRIVER_INIT( f15se21 )
 {
-       UINT16 *rom = (UINT16 *)memory_region(REGION_CPU1);
-
+#if 1
+       UINT16 *rom = (UINT16 *)memory_region(machine, "main");
        rom[0x2A8B3]=0x6006;                          //055166: 6606                     bne     5516e -> bra
        rom[0x2A8BF]=0x4E71;                          //05517E: 6704                     beq     55184 -> nop
        rom[0x28AD1]=0x4E71;                          //0515A2: 67F8                     beq     5159c -> nop
        rom[0x28A9E]=0x4E71;
        rom[0x28ABD]=0x4E71;
        rom[0x28C3B]=0x4E71;
+#endif
 }
 
 static INPUT_PORTS_START( stankatk )
 	/* Ports A and B */
-	PORT_START
+	PORT_START("IN0")
 	PORT_DIPNAME( 0x0001, 0x0000, DEF_STR( Unused ) )
 	PORT_DIPSETTING(	0x0001, DEF_STR(Off) )
 	PORT_DIPSETTING(	0x0000, DEF_STR(On) )
@@ -257,7 +263,7 @@ static INPUT_PORTS_START( stankatk )
 
 
 	/* C and D ports */
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_COIN3 )
@@ -279,7 +285,7 @@ static INPUT_PORTS_START( stankatk )
 //  PORT_BITX( 0x8000, IP_ACTIVE_LOW, 0, "Yellow Trigger", KEYCODE_G, IP_JOY_NONE )
 
 
-	PORT_START
+	PORT_START("VGB")
 	PORT_DIPNAME( 0x0008, 0x0008, "VGB Monitor Mode")
 	PORT_DIPSETTING(	0x0008, DEF_STR(Off) )
 	PORT_DIPSETTING(	0x0000, DEF_STR(On) )
@@ -287,7 +293,7 @@ static INPUT_PORTS_START( stankatk )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( botss )
-	PORT_START
+	PORT_START("IN0")
 	PORT_DIPNAME( 0x0001, 0x0000, DEF_STR( Unused ) )
 	PORT_DIPSETTING(	0x0001, DEF_STR(Off) )
 	PORT_DIPSETTING(	0x0000, DEF_STR(On) )
@@ -321,7 +327,7 @@ static INPUT_PORTS_START( botss )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_PLAYER(1)
 
 	/* C and D ports */
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_COIN3 )
@@ -330,7 +336,7 @@ static INPUT_PORTS_START( botss )
 //  PORT_BITX(0x0002, IP_ACTIVE_LOW, 0, "Throttle Up", KEYCODE_D, IP_JOY_NONE )
 //  PORT_BITX(0x0008, IP_ACTIVE_LOW, 0, "Throttle Down", KEYCODE_F, IP_JOY_NONE )
 
-	PORT_START
+	PORT_START("VGB")
 	PORT_DIPNAME( 0x0008, 0x0008, "VGB Monitor Mode")
 	PORT_DIPSETTING(	0x0008, DEF_STR(Off) )
 	PORT_DIPSETTING(	0x0000, DEF_STR(On) )
@@ -339,7 +345,7 @@ INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( f15se )
-	PORT_START
+	PORT_START("IN0")
 	PORT_DIPNAME( 0x0001, 0x0000, DEF_STR( Unused ) )
 	PORT_DIPSETTING(	0x0001, DEF_STR(Off) )
 	PORT_DIPSETTING(	0x0000, DEF_STR(On) )
@@ -369,7 +375,7 @@ static INPUT_PORTS_START( f15se )
 	PORT_SERVICE(0x0400, IP_ACTIVE_LOW)
 
 	/* C and D ports */
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_COIN3 )
@@ -379,25 +385,25 @@ static INPUT_PORTS_START( f15se )
 
 	/* Analogue Inputs? */
 
-	PORT_START
+	PORT_START("VGB")
 	PORT_DIPNAME( 0x0008, 0x0008, "VGB Monitor Mode")
 	PORT_DIPSETTING(	0x0008, DEF_STR(Off) )
 	PORT_DIPSETTING(	0x0000, DEF_STR(On) )
 
 	/* Sound PCB test button */
-	PORT_START
+	PORT_START("SOUND")
 	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME("Sound PCB Test") PORT_CODE(KEYCODE_F1)
 INPUT_PORTS_END
 
 
-static void tms_interrupt(int state)
+static void tms_interrupt(const device_config *device, int state)
 {
-   m68901_int_gen(GPIP4);
+   m68901_int_gen(device->machine, GPIP4);
 }
 
 static INTERRUPT_GEN( micro3d_vblank )
 {
-   m68901_int_gen(GPIP7);
+   m68901_int_gen(device->machine, GPIP7);
 }
 
 
@@ -405,36 +411,36 @@ static INTERRUPT_GEN( micro3d_vblank )
 
 static TIMER_CALLBACK( timera_int )
 {
-//      timer_set(attotime_mul(ATTOTIME_IN_HZ(M68901_CLK), ((m68901_base[0xf]>>8) & 0xff) * 200),0,timera_int);     // Set the timer again.
-        timer_set(ATTOTIME_IN_USEC(1000), NULL,0,timera_int);     // Set the timer again.
-        m68901_int_gen(TMRA);           // Fire an interrupt.
+//      timer_set(machine, attotime_mul(ATTOTIME_IN_HZ(M68901_CLK), ((m68901_base[0xf]>>8) & 0xff) * 200),0,timera_int);     // Set the timer again.
+        timer_set(machine, ATTOTIME_IN_USEC(1000), NULL,0,timera_int);     // Set the timer again.
+        m68901_int_gen(machine, TMRA);           // Fire an interrupt.
 }
 
 #ifdef UNUSED_FUNCTION
 static TIMER_CALLBACK( timerb_int )
 {
-        timer_set(attotime_mul(ATTOTIME_IN_HZ(M68901_CLK), ((m68901_base[0x10]>>8) & 0xff) * 200),0,timera_int);
-        m68901_int_gen(TMRB);           // Fire an interrupt.
+        timer_set(machine, attotime_mul(ATTOTIME_IN_HZ(M68901_CLK), ((m68901_base[0x10]>>8) & 0xff) * 200),0,timera_int);
+        m68901_int_gen(machine, TMRB);           // Fire an interrupt.
 }
 
 static TIMER_CALLBACK( timerc_int )
 {
-        timer_set(attotime_mul(ATTOTIME_IN_HZ(M68901_CLK), ((m68901_base[0x11]>>8) & 0xff) * 200),0,timera_int);
-        m68901_int_gen(TMRC);           // Fire an interrupt.
+        timer_set(machine, attotime_mul(ATTOTIME_IN_HZ(M68901_CLK), ((m68901_base[0x11]>>8) & 0xff) * 200),0,timera_int);
+        m68901_int_gen(machine, TMRC);           // Fire an interrupt.
 }
 #endif
 
 static TIMER_CALLBACK( timerd_int )
 {
-        timer_set(ATTOTIME_IN_USEC(250), NULL,0,timerd_int);
-        m68901_int_gen(TMRD);           // Fire an interrupt.
+        timer_set(machine, ATTOTIME_IN_USEC(250), NULL,0,timerd_int);
+        m68901_int_gen(machine, TMRD);           // Fire an interrupt.
 }
 
 
 /* Called by anything that generates a MFD interrupt */
 /* Requires: MFD line number */
 
-static void m68901_int_gen(int source)
+static void m68901_int_gen(running_machine *machine, int source)
 {
 // logerror("M68901 interrupt %d requested.\n",source);
 
@@ -451,7 +457,7 @@ int bit=1 << (source-8*(int)(source/8));
 
        if(m68901_base[IMASK_REG] & (bit<<8))              // If interrupt is not masked by MFD, trigger a 68k INT
        {
-                cpunum_set_input_line(Machine, 0,4, HOLD_LINE);
+                cpu_set_input_line(machine->cpu[0],4, HOLD_LINE);
             //    logerror("M68901 interrupt %d serviced.\n",source);
        }
 }
@@ -473,27 +479,25 @@ switch(offset)
                       break;
 
         case 0x0f:    mame_printf_debug("Timer A Data:%4x\n",value);                                                       // Timer A Data Register
-                     timer_set(ATTOTIME_IN_USEC(1000), NULL,0,timera_int);
+                     timer_set(space->machine, ATTOTIME_IN_USEC(1000), NULL,0,timera_int);
                       break;
 
         case 0x10:    mame_printf_debug("Timer B Data:%4x\n",value);                                                           // Timer B Data Register
-//                    timer_set(attotime_mul(ATTOTIME_IN_HZ(M68901_CLK), value * 200),0,timerb_int);
+//                    timer_set(space->machine, attotime_mul(ATTOTIME_IN_HZ(M68901_CLK), value * 200),0,timerb_int);
                       break;
 
         case 0x11:    mame_printf_debug("Timer C Data:%4x\n",value);                                                        // Timer C Data Register
-//                    timer_set(attotime_mul(ATTOTIME_IN_HZ(M68901_CLK), value * 200),0,timerc_int);
+//                    timer_set(space->machine, attotime_mul(ATTOTIME_IN_HZ(M68901_CLK), value * 200),0,timerc_int);
                       break;
 
         case 0x12:    mame_printf_debug("Timer D Data:%4x\n",value);
-                      timer_set(ATTOTIME_IN_USEC(500), NULL,0,timerd_int);                 // Timer D Data Register
+                      timer_set(space->machine, ATTOTIME_IN_USEC(500), NULL,0,timerd_int);                 // Timer D Data Register
                       break;
 
 }
 
 }
 
-
-
 /* I should really re-write all this. */
 
 static WRITE16_HANDLER( m68681_w )
@@ -513,7 +517,7 @@ switch(offset)
 
       case 0x03:        M68681.TBA = value;                   // Fill transmit buffer
                         M68681.SRA |=0x0400;                  // Data has been sent - TX ready for more.
-                        if(M68681.IMR & 1)   cpunum_set_input_line_and_vector(Machine, 0,3, HOLD_LINE, M68681.IVR);         // Generate an interrupt, if allowed.
+                        if(M68681.IMR & 1)   cpu_set_input_line_and_vector(space->machine->cpu[0],3, HOLD_LINE, M68681.IVR);         // Generate an interrupt, if allowed.
 
 #if HOST_MONITOR_DISPLAY
                         mame_printf_debug("%c",value);                    // Port A - Monitor
@@ -537,14 +541,19 @@ switch(offset)
       case 0x0a:        break;
 
       case 0x0b:        M68681.TBB = value;                   //  Fill transmit buffer
+#if 0
                         M68681.SRB |=0x0400;                   // Data has been sent - TX ready for more.
                         // Write to sound board
                         if(M68681.IMR & 0x1000)
                         {
-                        	cpunum_set_input_line_and_vector(Machine, 0,3, HOLD_LINE, M68681.IVR);         // Generate an interrupt, if allowed.
+                        	cpu_set_input_line_and_vector(space->machine->cpu[0],3, HOLD_LINE, M68681.IVR);         // Generate an interrupt, if allowed.
                         }
-                        cpunum_set_input_line(Machine, 2, I8051_RX_LINE, ASSERT_LINE);                      // Generate 8031 interrupt
-                        mame_printf_debug("Sound board TX: %4X at PC=%4X\n",value,activecpu_get_pc());
+                        cpu_set_input_line(space->machine->cpu[2], MCS51_RX_LINE, ASSERT_LINE);                      // Generate 8031 interrupt
+                        mame_printf_debug("Sound board TX: %4X at PC=%4X\n",value,cpu_get_pc(space->cpu));
+#endif
+                        M68681.SRB &=~0x0400;                   // Data has been sent - TX ready for more.
+                        cpu_set_input_line(space->machine->cpu[2], MCS51_RX_LINE, ASSERT_LINE);                      // Generate 8031 interrupt
+                        mame_printf_debug("Sound board TX: %4X at PC=%4X\n",value,cpu_get_pc(space->cpu));
                         break;
 
       case 0x0c:        //mame_printf_debug("IVR: %d",value);
@@ -557,7 +566,7 @@ switch(offset)
                         if(value & 0x20)
                         {
 //                              cpunum_set_reset_line(2 CLEAR_LINE);
-                              logerror("8031 running at:%x (val=%x).\n",activecpu_get_pc(),value);
+                              logerror("8031 running at:%x (val=%x).\n",cpu_get_pc(space->cpu),value);
                         }
                         break;
 
@@ -565,7 +574,7 @@ switch(offset)
                         if(value & 0x20)
                         {
 //                              cpunum_set_reset_line(2, ASSERT_LINE);
-                              logerror("8031 reset at:%x (val=%x).\n",activecpu_get_pc(),value);
+                              logerror("8031 reset at:%x (val=%x).\n",cpu_get_pc(space->cpu),value);
                         }
                         break;
 
@@ -588,7 +597,8 @@ switch(offset)
         case 0x09:     return M68681.SRB;                              // Status Register B
 
         case 0x0b:     mame_printf_debug("\nHost received: %x\n",M68681.RBB);
-                       M68681.SRB^=0x0100;                             // No longer have data.
+        				M68681.SRB^=0x0100;                             // No longer have data.
+        				//M68681.SRB &= ~0x0100;                             // No longer have data.
                        return M68681.RBB;
                                                                        // RX B - Monitor Port
 }
@@ -707,12 +717,12 @@ static WRITE16_HANDLER( mystery3_w )
 
 static READ16_HANDLER( tms_host_r )
 {
-	return tms34010_host_r(1, offset);
+	return tms34010_host_r(space->machine->cpu[1], offset);
 }
 
 static WRITE16_HANDLER( tms_host_w )
 {
-	tms34010_host_w(1, offset, data);
+	tms34010_host_w(space->machine->cpu[1], offset, data);
 }
 
 #ifdef UNUSED_FUNCTION
@@ -739,37 +749,37 @@ static WRITE16_HANDLER( reset_slave )
 /* Reset peripherals flip-flop MIGHT be 900000 */
 
 static ADDRESS_MAP_START( hostmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x13ffff) AM_ROM                           /* 68000 Code ROM and Dr. Math object data */
-	AM_RANGE(0x200000, 0x20ffff) AM_RAM                           /* Battery-backed SRAM (64kB) & DS1215 */
-	AM_RANGE(0x800000, 0x83ffff) AM_RAM                          /* 68000/AM29000 shared RAM (256kB) */
-	AM_RANGE(0x900000, 0x900001) AM_NOP //WRITE(mystery_w)        /* ??????? 16-bit write here. rset? */
-	AM_RANGE(0x920000, 0x920001) AM_READ(input_port_1_word_r)     /* User inputs C and D */
-	AM_RANGE(0x940000, 0x940001) AM_READ(input_port_0_word_r)     /* User inputs A and B */
-	AM_RANGE(0x960000, 0x960001) AM_NOP                           /* Lamps */
-	AM_RANGE(0x980000, 0x980001) AM_RAM                           /* ADC0844 */
-	AM_RANGE(0x9a0000, 0x9a0007) AM_READWRITE(tms_host_r, tms_host_w)  /* TMS34010 Interface */
-	AM_RANGE(0x9c0000, 0x9c0001) AM_RAM                            /* ????? Write: 80, A0 and 00 (8-bit high byte) */
-	AM_RANGE(0x9e0000, 0x9e00cf) AM_READWRITE(MRA16_RAM, m68901_w) AM_BASE(&m68901_base)  /* 68901 Multifunction Peripheral */
-	AM_RANGE(0xa00000, 0xa000cf) AM_READWRITE(m68681_r, m68681_w) AM_BASE(&m68681_base)   /* 68681 UART */
-	AM_RANGE(0xa20000, 0xa20001) AM_RAM                           /* XY joystick input - sign? */
-	AM_RANGE(0xa40002, 0xa40003) AM_RAM                           /* XY joystick input - actual values */
+	AM_RANGE(0x000000, 0x13ffff) AM_ROM					/* 68000 Code ROM and Dr. Math object data */
+	AM_RANGE(0x200000, 0x20ffff) AM_RAM					/* Battery-backed SRAM (64kB) & DS1215 */
+	AM_RANGE(0x800000, 0x83ffff) AM_RAM					/* 68000/AM29000 shared RAM (256kB) */
+	AM_RANGE(0x900000, 0x900001) AM_NOP //WRITE(mystery_w)  /* ??????? 16-bit write here. rset? */
+	AM_RANGE(0x920000, 0x920001) AM_READ_PORT("IN1")	/* User inputs C and D */
+	AM_RANGE(0x940000, 0x940001) AM_READ_PORT("IN0")	/* User inputs A and B */
+	AM_RANGE(0x960000, 0x960001) AM_NOP					/* Lamps */
+	AM_RANGE(0x980000, 0x980001) AM_RAM					/* ADC0844 */
+	AM_RANGE(0x9a0000, 0x9a0007) AM_READWRITE(tms_host_r, tms_host_w)	/* TMS34010 Interface */
+	AM_RANGE(0x9c0000, 0x9c0001) AM_RAM					/* ????? Write: 80, A0 and 00 (8-bit high byte) */
+	AM_RANGE(0x9e0000, 0x9e00cf) AM_RAM_WRITE(m68901_w) AM_BASE(&m68901_base)	/* 68901 Multifunction Peripheral */
+	AM_RANGE(0xa00000, 0xa000cf) AM_READWRITE(m68681_r, m68681_w) AM_BASE(&m68681_base)	/* 68681 UART */
+	AM_RANGE(0xa20000, 0xa20001) AM_RAM					/* XY joystick input - sign? */
+	AM_RANGE(0xa40002, 0xa40003) AM_RAM					/* XY joystick input - actual values */
 ADDRESS_MAP_END
 
 
 // 2600000: Write 1E and 9E?
 static ADDRESS_MAP_START( vgbmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x00000000, 0x007fffff) AM_RAM AM_BASE(&micro3d_sprite_vram)  // 2 Banks
-	AM_RANGE(0x00800000, 0x00bfffff) AM_RAM                         /* 512kB Main DRAM */
-	AM_RANGE(0x00c00000, 0x00c0000f) AM_READ(input_port_2_word_r)   /* TI Monitor Mode switch */
-	AM_RANGE(0x00e00000, 0x00e0000f) AM_RAM //WRITE(mystery2_w)                        /* CREGCLK ??? byte write here. */
-	AM_RANGE(0x02000000, 0x0200ffff) AM_READWRITE(MRA16_RAM, paletteram16_BBBBBRRRRRGGGGGG_word_w) AM_BASE(&paletteram16) //      AM_RANGE(0x02010000, 0x027fffff) AM_RAM                         // ??????????? Mirror of VRAM???
-	AM_RANGE(0x02600000, 0x0260000f) AM_RAM                         // XFER3dk???? 16-bit write
-	AM_RANGE(0x02c00000, 0x02c0003f) AM_READ(ti_uart_r)            /* SCN UART */
+	AM_RANGE(0x00000000, 0x007fffff) AM_RAM AM_BASE(&micro3d_sprite_vram)	/* 2 Banks */
+	AM_RANGE(0x00800000, 0x00bfffff) AM_RAM							/* 512kB Main DRAM */
+	AM_RANGE(0x00c00000, 0x00c0000f) AM_READ_PORT("VGB")			/* TI Monitor Mode switch */
+	AM_RANGE(0x00e00000, 0x00e0000f) AM_RAM //WRITE(mystery2_w)     /* CREGCLK ??? byte write here. */
+	AM_RANGE(0x02000000, 0x0200ffff) AM_RAM_WRITE(paletteram16_BBBBBRRRRRGGGGGG_word_w) AM_BASE(&paletteram16) // AM_RANGE(0x02010000, 0x027fffff) AM_RAM       /* ??????????? Mirror of VRAM??? */
+	AM_RANGE(0x02600000, 0x0260000f) AM_RAM							/* XFER3dk???? 16-bit write */
+	AM_RANGE(0x02c00000, 0x02c0003f) AM_READ(ti_uart_r)				/* SCN UART */
 	AM_RANGE(0x02e00000, 0x02e0003f) AM_WRITE(ti_uart_w)
-	AM_RANGE(0x03800000, 0x03dfffff) AM_ROM AM_REGION(REGION_GFX1, 0)                          /* 2D Graphics ROMs */
-	AM_RANGE(0x03e00000, 0x03ffffff) AM_ROM AM_REGION(REGION_USER1, 0)                         /* 128kB Program ROM */
+	AM_RANGE(0x03800000, 0x03dfffff) AM_ROM AM_REGION("gfx1", 0)		/* 2D Graphics ROMs */
+	AM_RANGE(0x03e00000, 0x03ffffff) AM_ROM AM_REGION("user1", 0)		/* 128kB Program ROM */
 	AM_RANGE(0xc0000000, 0xc00001ff) AM_READWRITE(tms34010_io_register_r, tms34010_io_register_w)
-	AM_RANGE(0xffe00000, 0xffffffff) AM_ROM AM_REGION(REGION_USER1, 0)                         /* 128kB Program ROM (Mirror - for interrupt vectors) */
+	AM_RANGE(0xffe00000, 0xffffffff) AM_ROM AM_REGION("user1", 0)		/* 128kB Program ROM (Mirror - for interrupt vectors) */
 ADDRESS_MAP_END
 
 
@@ -786,36 +796,36 @@ ADDRESS_MAP_END
 /* P1.7 = SELFTEST I         P3.7                                     */
 /*====================================================================*/
 
+static UINT8 port_latch[4];
 static WRITE8_HANDLER(sound_io_w)
 {
-
-switch(offset)
-{
-        case 0x01:  break;
-        case 0x03:  //if(data & 0x4) speech_bank=0;
-
-                    if(data & 0x10)
-                    {
-                    	upd7759_0_reset_w(0,0);
-                    }
-                    else
-                    {
-                    	upd7759_0_reset_w(0,1);
-                    }
-                    break;
-}
+	port_latch[offset] = data;
+	switch(offset)
+	{
+        case 0x01:
+        	break;
+        case 0x03:
+        	upd7759_set_bank_base(0, (data & 0x4) ? 0x20000 : 0);
+        	upd7759_0_reset_w(space,0,(data & 0x10) ? 0 : 1);
+	}
 }
 
 static READ8_HANDLER(sound_io_r)
 {
+	switch(offset)
+	{
+	        case 0x01:  return (port_latch[offset] & 0x7f) | input_port_read_safe(space->machine, "SOUND", 0);		/* Test push switch */
+	        case 0x03:  return (port_latch[offset] & 0xf7) | (upd7759_0_busy_r(space,0) ? 0x08 : 0);
+	        default:    return 0;
+	}
 
-switch(offset)
-{
-        case 0x01:  return readinputport(3);                           /* Test push switch */
-        case 0x03:  return (int)(upd7759_0_busy_r(0))<<3;
-        default:    return 0;
 }
 
+static WRITE8_HANDLER( upd7759_port_start_w)
+{
+	upd7759_0_start_w(space, offset, 0);
+	upd7759_0_port_w(space, offset, data);
+	upd7759_0_start_w(space, offset, 1);
 }
 
 static ADDRESS_MAP_START( soundmem_prg, ADDRESS_SPACE_PROGRAM, 8 )
@@ -825,30 +835,22 @@ ADDRESS_MAP_END
 
 /* FFXX - 00XX    */
 
-static ADDRESS_MAP_START( soundmem_data, ADDRESS_SPACE_DATA, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_RAM                                  /* 2Kb RAM */
-	AM_RANGE(0xfd00, 0xfd00) AM_WRITE(YM2151_register_port_0_w)
-	AM_RANGE(0xfd01, 0xfd01) AM_READWRITE(YM2151_status_port_0_r,YM2151_data_port_0_w)
-	AM_RANGE(0xfe00, 0xfe00) AM_WRITE(upd7759_0_port_w)
-	AM_RANGE(0xff00, 0xff00) AM_WRITE(DAC_0_data_w)   /* DAC A - used for S&H, special effects? */
-	AM_RANGE(0xff01, 0xff01) AM_WRITE(DAC_1_data_w)   /* DAC B - 'SPEECH' */
-ADDRESS_MAP_END
-
 static ADDRESS_MAP_START( soundmem_io, ADDRESS_SPACE_IO, 8 )
-         AM_RANGE(0x00, 0xff) AM_READWRITE(sound_io_r,sound_io_w)
+	AM_RANGE(0x0000, 0x07ff) AM_RAM                                  /* 2Kb RAM */
+	AM_RANGE(0xfd00, 0xfd00) AM_WRITE(ym2151_register_port_0_w)
+	AM_RANGE(0xfd01, 0xfd01) AM_READWRITE(ym2151_status_port_0_r,ym2151_data_port_0_w)
+	AM_RANGE(0xfe00, 0xfe00) AM_WRITE(upd7759_port_start_w)
+	AM_RANGE(0xff00, 0xff00) AM_WRITE(dac_0_data_w)   /* DAC A - used for S&H, special effects? */
+	AM_RANGE(0xff01, 0xff01) AM_WRITE(dac_1_data_w)   /* DAC B - 'SPEECH' */
+	/* ports */
+	AM_RANGE(MCS51_PORT_P0, MCS51_PORT_P3) AM_READWRITE(sound_io_r,sound_io_w)
 ADDRESS_MAP_END
 
 
-
-static const struct upd7759_interface upd7759_interface =
-{
-	REGION_SOUND1
-};
-
 static const tms34010_config vgb_config =
 {
 	FALSE,							/* halt on reset ????? - check this */
-	0,								/* the screen operated on */
+	"main",							/* the screen operated on */
 	40000000/8,						/* pixel clock */
 	4,								/* pixels per clock */
 	micro3d_scanline_update,		/* scanline updater */
@@ -859,26 +861,24 @@ static const tms34010_config vgb_config =
 
 
 static MACHINE_DRIVER_START( micro3d )
-	MDRV_CPU_ADD(M68000, 12000000 )
+	MDRV_CPU_ADD("main", M68000, 12000000 )
 	MDRV_CPU_PROGRAM_MAP(hostmem,0)
-	MDRV_CPU_VBLANK_INT(micro3d_vblank,1)
+	MDRV_CPU_VBLANK_INT("main", micro3d_vblank)
 
- 	MDRV_CPU_ADD(TMS34010, 40000000)
+ 	MDRV_CPU_ADD("vgb", TMS34010, 40000000)
 	MDRV_CPU_CONFIG(vgb_config)
 	MDRV_CPU_PROGRAM_MAP(vgbmem,0)
 
-	MDRV_CPU_ADD(I8051, 11059000)
+	MDRV_CPU_ADD("audio", I8051, 11059000)
 	MDRV_CPU_PROGRAM_MAP(soundmem_prg,0)
-	MDRV_CPU_DATA_MAP(soundmem_data,0)
 	MDRV_CPU_IO_MAP(soundmem_io,0)
 
 	MDRV_MACHINE_RESET(micro3d)
-	MDRV_INTERLEAVE(50)
+	MDRV_QUANTUM_TIME(HZ(3000))
 
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_PALETTE_LENGTH(32768)
 
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_RAW_PARAMS(40000000/8*4, 192*4, 0, 144*4, 434, 0, 400)
 
@@ -886,19 +886,18 @@ static MACHINE_DRIVER_START( micro3d )
 
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(UPD7759, UPD7759_STANDARD_CLOCK)
-	MDRV_SOUND_CONFIG(upd7759_interface)
+	MDRV_SOUND_ADD("upd", UPD7759, UPD7759_STANDARD_CLOCK)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
 
-	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_ADD("ym", YM2151, 3579545)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 
-	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ADD("dac1", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.0)	/* muted - I don't think it's directly used */
 
-	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ADD("dac2", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.15)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.15)
 MACHINE_DRIVER_END
@@ -906,7 +905,7 @@ MACHINE_DRIVER_END
 
 ROM_START( botss )
 	/* HOST PCB (MPG DW-00011C-0011-02) */
-	ROM_REGION( 0x140000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_REGION( 0x140000, "main", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "300hst.67", 0x000001, 0x20000, CRC(7f74362a) SHA1(41611ba8e6eb5d6b3dfe88e1cede7d9fb5472e40) ) // rev 1.1
 	ROM_LOAD16_BYTE( "301hst.91", 0x000000, 0x20000, CRC(a8100d1e) SHA1(69d3cac6f67563c0796560f7b874d7660720027d) ) // rev 1.1
 	ROM_LOAD16_BYTE( "302hst.68", 0x040001, 0x20000, CRC(af865ee4) SHA1(f00bce49401431bc749208399329d9f92457186b) ) // rev 1.1
@@ -919,7 +918,7 @@ ROM_START( botss )
 	ROM_LOAD16_BYTE( "109hst.95", 0x100000, 0x20000, CRC(6c595d1e) SHA1(89fdc30166ba1e9706798547195bdf6875a02e96) )
 
 	/* DR MATH PCB (MPG 010-00003-003) */
-	ROM_REGION( 0x40000, REGION_USER2, 0 )
+	ROM_REGION( 0x40000, "user2", 0 )
 	ROM_LOAD( "014dth.153", 0x000000, 0x20000, CRC(0eee0557) SHA1(8abe52cad31e59cf814fd9f64f4e42ddb4aa8c93) )
 	ROM_LOAD( "015dth.154", 0x020000, 0x20000, CRC(68564122) SHA1(410d2db74e574774b2eadd7fdf891feef5d8a93f) )
 	ROM_LOAD( "016dth.167", 0x000000, 0x20000, CRC(60c6cb26) SHA1(0e2bf65793715e12d8fd7f87fd3336a9d00ee7e6) )
@@ -933,12 +932,12 @@ ROM_START( botss )
 	ROM_LOAD( "124dth.107", 0x000000, 0x08000, CRC(220db5d3) SHA1(3bfbe0eb97282c4ce449fd44e8e141de74f08eb0) )
 	ROM_LOAD( "125dth.126", 0x020000, 0x08000, CRC(b0dccf4a) SHA1(e8bfd622c006985b724cdbd3ad14c33e9ed27c6c) )
 
-	ROM_REGION16_LE( 0x40000, REGION_USER1, 0 )
+	ROM_REGION16_LE( 0x40000, "user1", 0 )
 	ROM_LOAD16_BYTE( "101vgb.101", 0x000000, 0x20000, CRC(6aada23d) SHA1(85dbf9b20e4f17cb21922637763654d6cae80dfd) )
 	ROM_LOAD16_BYTE( "104vgb.97",  0x000001, 0x20000, CRC(715cac9d) SHA1(2aa0c563dc1fe4d02fa1ecbaed16f720f899fdc4) )
 
 	/* VGB - Video Graphics PCB  (MPG DW-010-00002-002) */
-	ROM_REGION16_LE( 0xc0000, REGION_GFX1, 0 )
+	ROM_REGION16_LE( 0xc0000, "gfx1", 0 )
 	ROM_LOAD16_BYTE( "105vgb.124", 0x000000, 0x20000, CRC(5482e0c4) SHA1(492afac1862f2899cd734d1e57ca978ed6a906d5) )
 	ROM_LOAD16_BYTE( "106vgb.121", 0x000001, 0x20000, CRC(a55e5d19) SHA1(86fbcb425103ae9fff381357339af349848fc3f2) )
 
@@ -949,16 +948,16 @@ ROM_START( botss )
 	ROM_LOAD16_BYTE( "102vgb.108", 0x080001, 0x20000, CRC(441e8490) SHA1(6cfe30cea3fa297b71e881fbddad6d65a96e4386) )
 
 	/*SND - Sound PCB           (MPG 010-00018-002) */
-	ROM_REGION( 0x10000, REGION_CPU3, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "14-001snd.2", 0x000000, 0x08000, CRC(307fcb6d) SHA1(0cf63a39ac8920be6532974311804529d7218545) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x40000, "upd", 0 )
 	ROM_LOAD( "13-001snd.17", 0x000000, 0x40000, CRC(015a0b17) SHA1(f229c9aa59f0e6b25b818f9513997a8685e33982) )
 ROM_END
 
 
 ROM_START( stankatk )
-	ROM_REGION( 0x140000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_REGION( 0x140000, "main", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "lo_u67",    0x000001, 0x20000, CRC(97aabac0) SHA1(12a0719d3332a63e912161200b0a942c27c1f5da) )
 	ROM_LOAD16_BYTE( "le_u91",    0x000000, 0x20000, CRC(977f90d9) SHA1(530fa5c32b1f28e2b90d20d98cc453cb290c0ad2) )
 //  ROM_LOAD16_BYTE( "host.u67",  0x000001, 0x20000, CRC(e79d9548) SHA1(84a4c181be81fff7d5e61faa32f6929fce8b62d0) ) // alt (bad?) rom
@@ -973,7 +972,7 @@ ROM_START( stankatk )
 	ROM_LOAD16_BYTE( "host.71",   0x100001, 0x20000, CRC(cfc0333e) SHA1(9f290769129a61189870faef45c3f061eb7b5c07) ) // same as botss
 	ROM_LOAD16_BYTE( "host.95",   0x100000, 0x20000, CRC(6c595d1e) SHA1(89fdc30166ba1e9706798547195bdf6875a02e96) ) // same as botss
 
-	ROM_REGION( 0x40000, REGION_USER2, 0 )
+	ROM_REGION( 0x40000, "user2", 0 )
 	ROM_LOAD( "pb0o_u.153", 0x000000, 0x20000, CRC(bcd7ddad) SHA1(3982756b6f0821df77918dd0d00807a90dbfb595) )
 	ROM_LOAD( "pb0e_u.154", 0x020000, 0x20000, CRC(d84e7c71) SHA1(2edb13c1f96f35c7934dad380e06035335ccbb48) )
 	ROM_LOAD( "pb1o_u.167", 0x000000, 0x20000, CRC(e4a65313) SHA1(f2df5cc87aa388d3273705562ab2d7c937a0a866) )
@@ -988,11 +987,11 @@ ROM_START( stankatk )
 	ROM_LOAD( "s00e_u.107", 0x000000, 0x08000, CRC(558918cc) SHA1(7e61639ab4af88f888f4aa481dd01db7de3829da) )
 	ROM_LOAD( "s16e_u.126", 0x020000, 0x08000, CRC(d24654cd) SHA1(88d3624f23c669dc902136c822b1f4732104c9c1) )
 
-	ROM_REGION16_LE( 0x40000, REGION_USER1, 0 )
+	ROM_REGION16_LE( 0x40000, "user1", 0 )
 	ROM_LOAD16_BYTE( "3el_u101", 0x000000, 0x20000, CRC(130e1a18) SHA1(c31af5c5a403da588142ccbea79d3aa253ac6519) )
 	ROM_LOAD16_BYTE( "3eh_u97",  0x000001, 0x20000, CRC(0fdcab16) SHA1(afc21747e1624f3ab87b289b5f4a498141062445) )
 
-	ROM_REGION16_LE( 0xC0000, REGION_GFX1, 0 )
+	ROM_REGION16_LE( 0xC0000, "gfx1", 0 )
 	ROM_LOAD16_BYTE( "38l_u124", 0x000000, 0x20000, CRC(4e084daa) SHA1(f65f51d8d7c6b46aa844b37b212dab11c786d856) )
 	ROM_LOAD16_BYTE( "38h_u121", 0x000001, 0x20000, CRC(3628c8c1) SHA1(760eda076ec46af5b954548036da5230a5c86371) )
 
@@ -1002,17 +1001,17 @@ ROM_START( stankatk )
 	ROM_LOAD16_BYTE( "3cl_u114", 0x080000, 0x20000, CRC(bc04b0e6) SHA1(d08fddd52f2c1a565a80f5d4ff8b07f1c5f01a01) )
 	ROM_LOAD16_BYTE( "3ch_u108", 0x080001, 0x20000, CRC(7cb688af) SHA1(6be495ae0ed74739f62de65386810864c9ffaaee) )
 
-	ROM_REGION( 0x08000, REGION_CPU3, 0 )
+	ROM_REGION( 0x08000, "audio", 0 )
 	ROM_LOAD( "sound.u2", 0x000000, 0x08000, CRC(77190a90) SHA1(a36a5a8457cc1c325e6318b083e5e271e163f7cb) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x40000, "upd", 0 )
 	ROM_LOAD( "sound.u17", 0x000000, 0x40000, CRC(d033ef6c) SHA1(0404473c87b5b52e39ab3824b159a2d98159bbea) )
 
 ROM_END
 
 ROM_START( f15se21 )	// rev 2.1 02/04/91
 	/* HST - Host PCB            (MPG DW-00011C-0011-01)    */
-	ROM_REGION( 0x140000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_REGION( 0x140000, "main", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "500.hst", 0x000001, 0x20000, CRC(6c26806d) SHA1(7cfd2b3b92b0fc6627c92a2013a317ca5abc66a0) )
 	ROM_LOAD16_BYTE( "501.hst", 0x000000, 0x20000, CRC(81f02bf7) SHA1(09976746fe4d9c88bd8840f6e7addb09226aa54b) )
 	ROM_LOAD16_BYTE( "502.hst", 0x040001, 0x20000, CRC(1eb945e5) SHA1(aba3ff038f2ca0f1200be5710073825ce80e3656) )
@@ -1026,14 +1025,14 @@ ROM_START( f15se21 )	// rev 2.1 02/04/91
 	ROM_LOAD16_BYTE( "009.hst", 0x100000, 0x20000, CRC(33e3b473) SHA1(66deda79ba94f0ed722b399b3fc6062dcdd1a6c9) )
 
 	/* Video Graphics PCB  (MPG DW-010-00003-001) */
-//  ROM_REGION( 0x40000, REGION_CPU2, 0 )         /* TMS34010 dummy region */
+//  ROM_REGION( 0x40000, "vgb", 0 )         /* TMS34010 dummy region */
 
 	// TI ROM version 1.0a, 28-November-90
-	ROM_REGION16_LE( 0x40000, REGION_USER1, 0 )
+	ROM_REGION16_LE( 0x40000, "user1", 0 )
 	ROM_LOAD16_BYTE( "001.vgb", 0x000000, 0x20000, CRC(810c142d) SHA1(d37e5ecd716dda65d43cec7bca524c59d3dc9803) )
 	ROM_LOAD16_BYTE( "004.vgb", 0x000001, 0x20000, CRC(b69e1260) SHA1(1a2b69ea7c96b0293b24d87ea46bd4b1d4c56a66) )
 
-	ROM_REGION16_LE( 0xC0000, REGION_GFX1, 0 )
+	ROM_REGION16_LE( 0xC0000, "gfx1", 0 )
 	ROM_LOAD16_BYTE( "005.vgb", 0x000000, 0x20000, CRC(7b1852f0) SHA1(d21525e59b3112313ea9783ac3dd988a4c1d5f87) )
 	ROM_LOAD16_BYTE( "006.vgb", 0x000001, 0x20000, CRC(9d031636) SHA1(b7c7b57d547f2ce2eeb97126e961f3b5f35823f7) )
 	ROM_LOAD16_BYTE( "007.vgb", 0x040000, 0x20000, CRC(15326070) SHA1(ec4484d4515694742d3fd3b944f342f052463988) )
@@ -1042,7 +1041,7 @@ ROM_START( f15se21 )	// rev 2.1 02/04/91
 	ROM_LOAD16_BYTE( "002.vgb", 0x080001, 0x20000, CRC(f6488e31) SHA1(d2f9304cc59f5523007592ae76ddd56107cc29e8) )
 
 	/*  DTH - Dr Math PCB         (MPG 010-00002-001) */
-	ROM_REGION32_BE( 0x80000, REGION_USER2, 0 )
+	ROM_REGION32_BE( 0x80000, "user2", 0 )
 //  ROM_LOAD("drmath.rom", 0x00000, 0x40000, CRC(28dd9107) SHA1(3d571de81109e805cc0b133eefc3ea419e6a337b) )         // Cheat
 
 	ROM_LOAD( "120.dth", 0x000000, 0x08000, CRC(5fb9836d) SHA1(d511aa9f02972a7f475c82c6f57d1f3fd4f118fa) )
@@ -1060,16 +1059,16 @@ ROM_START( f15se21 )	// rev 2.1 02/04/91
 
 
 	/* SND - Sound PCB           (MPG 010-00018-002) */
-	ROM_REGION( 0x08000, REGION_CPU3, 0 )
+	ROM_REGION( 0x08000, "audio", 0 )
 	ROM_LOAD( "4-001.snd", 0x000000, 0x08000, CRC(705685a9) SHA1(311f7cac126a19e8bd555ebf31ff4ec4680ddfa4) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x40000, "upd", 0 )
 	ROM_LOAD( "3-001.snd", 0x000000, 0x40000, CRC(af84b635) SHA1(844e5987a66e9e3ab2d2fe05b93a4da3512776bb) )
 ROM_END
 
 ROM_START( f15se )	// rev 2.2 02/25/91
 	/* HST - Host PCB            (MPG DW-00011C-0011-01)    */
-	ROM_REGION( 0x140000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_REGION( 0x140000, "main", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "host.u67", 0x000001, 0x20000, CRC(8f495ceb) SHA1(90998ad67e76928ed1a6cae56038b98d1aa2e7b0) )
 	ROM_LOAD16_BYTE( "host.u91", 0x000000, 0x20000, CRC(dfae5ec3) SHA1(29306eed5047e39a0a2350e61ab7126a84cb710b) )
 	ROM_LOAD16_BYTE( "host.u68", 0x040001, 0x20000, CRC(685fc355) SHA1(5bfe015a8deccb66e3317154d715f490f00ace74) )
@@ -1083,14 +1082,14 @@ ROM_START( f15se )	// rev 2.2 02/25/91
 	ROM_LOAD16_BYTE( "009.hst", 0x100000, 0x20000, CRC(33e3b473) SHA1(66deda79ba94f0ed722b399b3fc6062dcdd1a6c9) )
 
 	/* Video Graphics PCB  (MPG DW-010-00003-001) */
-//  ROM_REGION( 0x40000, REGION_CPU2, 0 )         /* TMS34010 dummy region */
+//  ROM_REGION( 0x40000, "vgb", 0 )         /* TMS34010 dummy region */
 
 	// TI ROM version 1.0c, 28-November-90
-	ROM_REGION16_LE( 0x40000, REGION_USER1, 0 )
+	ROM_REGION16_LE( 0x40000, "user1", 0 )
 	ROM_LOAD16_BYTE( "vgb_u101.bin", 0x000000, 0x20000, CRC(e99fac71) SHA1(98d1d2134fabc1bad637cbe42cbe9cdc20b32126) )
 	ROM_LOAD16_BYTE( "vgb_u097.bin", 0x000001, 0x20000, CRC(78b9b7c7) SHA1(4bce993dd3aea126e3a9d42ee8c68b8ab47fdba7) )
 
-	ROM_REGION16_LE( 0xC0000, REGION_GFX1, 0 )
+	ROM_REGION16_LE( 0xC0000, "gfx1", 0 )
 	ROM_LOAD16_BYTE( "005.vgb", 0x000000, 0x20000, CRC(7b1852f0) SHA1(d21525e59b3112313ea9783ac3dd988a4c1d5f87) )
 	ROM_LOAD16_BYTE( "006.vgb", 0x000001, 0x20000, CRC(9d031636) SHA1(b7c7b57d547f2ce2eeb97126e961f3b5f35823f7) )
 	ROM_LOAD16_BYTE( "007.vgb", 0x040000, 0x20000, CRC(15326070) SHA1(ec4484d4515694742d3fd3b944f342f052463988) )
@@ -1099,7 +1098,7 @@ ROM_START( f15se )	// rev 2.2 02/25/91
 	ROM_LOAD16_BYTE( "002.vgb", 0x080001, 0x20000, CRC(f6488e31) SHA1(d2f9304cc59f5523007592ae76ddd56107cc29e8) )
 
 	/*  DTH - Dr Math PCB         (MPG 010-00002-001) */
-	ROM_REGION32_BE( 0x80000, REGION_USER2, 0 )
+	ROM_REGION32_BE( 0x80000, "user2", 0 )
 //  ROM_LOAD("drmath.rom", 0x00000, 0x40000, CRC(28dd9107) SHA1(3d571de81109e805cc0b133eefc3ea419e6a337b) )         // Cheat
 
 	ROM_LOAD( "120.dth", 0x000000, 0x08000, CRC(5fb9836d) SHA1(d511aa9f02972a7f475c82c6f57d1f3fd4f118fa) )
@@ -1117,10 +1116,10 @@ ROM_START( f15se )	// rev 2.2 02/25/91
 
 
 	/* SND - Sound PCB           (MPG 010-00018-002) */
-	ROM_REGION( 0x08000, REGION_CPU3, 0 )
+	ROM_REGION( 0x08000, "audio", 0 )
 	ROM_LOAD( "4-001.snd", 0x000000, 0x08000, CRC(705685a9) SHA1(311f7cac126a19e8bd555ebf31ff4ec4680ddfa4) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x40000, "upd", 0 )
 	ROM_LOAD( "3-001.snd", 0x000000, 0x40000, CRC(af84b635) SHA1(844e5987a66e9e3ab2d2fe05b93a4da3512776bb) )
 ROM_END
 
