@@ -46,6 +46,7 @@
 *************************************************************************************************************/
 
 #include "driver.h"
+#include "cpu/m68000/m68000.h"
 #include "sound/ymz280b.h"
 #include "machine/eeprom.h"
 
@@ -66,13 +67,13 @@ static TILE_GET_INFO( get_tile_info )
 
 static VIDEO_START( livequiz )
 {
-	tmap = tilemap_create(	get_tile_info, tilemap_scan_cols,
-							TILEMAP_TYPE_PEN, 8,8, 0x80,0x20	);
+	tmap = tilemap_create(	machine, get_tile_info, tilemap_scan_cols,
+							8,8, 0x80,0x20	);
 
 	tilemap_set_transparent_pen(tmap, 0);
 }
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	UINT16 *s		=	livequiz_gfxram + 0x8000;
 	UINT16 *codes	=	livequiz_gfxram;
@@ -170,31 +171,26 @@ static VIDEO_UPDATE( livequiz )
 	}
 #endif
 
-	fillbitmap(bitmap,machine->pens[4095],cliprect);
+	bitmap_fill(bitmap,cliprect,4095);
 
-	if (layers_ctrl & 2)	draw_sprites(machine, bitmap,cliprect);
+	if (layers_ctrl & 2)	draw_sprites(screen->machine, bitmap,cliprect);
 	if (layers_ctrl & 1)	tilemap_draw(bitmap,cliprect, tmap, 0, 0);
 
 	return 0;
 }
 
-static READ16_HANDLER( livequiz_eeprom_r )
-{
-	return readinputport(2) | (EEPROM_read_bit() << 3);
-}
-
 static WRITE16_HANDLER( livequiz_eeprom_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		// latch the bit
-		EEPROM_write_bit(data & 0x04);
+		eeprom_write_bit(data & 0x04);
 
 		// reset line asserted: reset.
-		EEPROM_set_cs_line((data & 0x01) ? CLEAR_LINE : ASSERT_LINE );
+		eeprom_set_cs_line((data & 0x01) ? CLEAR_LINE : ASSERT_LINE );
 
 		// clock line asserted: write latch or select next bit to read
-		EEPROM_set_clock_line((data & 0x02) ? ASSERT_LINE : CLEAR_LINE );
+		eeprom_set_clock_line((data & 0x02) ? ASSERT_LINE : CLEAR_LINE );
 	}
 }
 
@@ -225,16 +221,16 @@ static WRITE16_HANDLER( livequiz_gfxregs_w )
 static ADDRESS_MAP_START( mem_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x1fffff) AM_ROM
 
-	AM_RANGE(0x900000, 0x900001) AM_READ( input_port_5_word_r )
-	AM_RANGE(0x920000, 0x920001) AM_READ( livequiz_eeprom_r )
-	AM_RANGE(0x940000, 0x940001) AM_READ( input_port_0_word_r )
-	AM_RANGE(0x980000, 0x980001) AM_READ( input_port_1_word_r )
+	AM_RANGE(0x900000, 0x900001) AM_READ_PORT("IN5")
+	AM_RANGE(0x920000, 0x920001) AM_READ_PORT("IN2")
+	AM_RANGE(0x940000, 0x940001) AM_READ_PORT("IN0")
+	AM_RANGE(0x980000, 0x980001) AM_READ_PORT("IN1")
 
 	AM_RANGE(0x9a0000, 0x9a0001) AM_WRITE( livequiz_eeprom_w )
 
 	AM_RANGE(0x9c0000, 0x9c0005) AM_WRITE( livequiz_gfxregs_w ) AM_BASE( &livequiz_gfxregs )
 
-	AM_RANGE(0xa00000, 0xa3ffff) AM_READWRITE( MRA16_RAM, paletteram16_xrgb_word_be_w ) AM_BASE( &paletteram16 )
+	AM_RANGE(0xa00000, 0xa3ffff) AM_READWRITE( SMH_RAM, paletteram16_xrgb_word_be_w ) AM_BASE( &paletteram16 )
 	AM_RANGE(0xa40000, 0xa7ffff) AM_RAM
 
 	AM_RANGE(0xb00000, 0xb00001) AM_READ( ret_ffff )
@@ -242,11 +238,11 @@ static ADDRESS_MAP_START( mem_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0xb40000, 0xb40001) AM_READ( ret_ffff )
 	AM_RANGE(0xb60000, 0xb60001) AM_READ( ret_ffff )
 
-	AM_RANGE(0xb80008, 0xb80009) AM_WRITE( YMZ280B_register_0_lsb_w )
-	AM_RANGE(0xb8000a, 0xb8000b) AM_READWRITE( YMZ280B_status_0_lsb_r, YMZ280B_data_0_lsb_w )
+	AM_RANGE(0xb80008, 0xb80009) AM_WRITE( ymz280b_register_0_lsb_w )
+	AM_RANGE(0xb8000a, 0xb8000b) AM_READWRITE( ymz280b_status_0_lsb_r, ymz280b_data_0_lsb_w )
 
-	AM_RANGE(0xba0000, 0xba0001) AM_READ( input_port_4_word_r )
-	AM_RANGE(0xbc0000, 0xbc0001) AM_READ( input_port_3_word_r )
+	AM_RANGE(0xba0000, 0xba0001) AM_READ_PORT("IN4")
+	AM_RANGE(0xbc0000, 0xbc0001) AM_READ_PORT("IN3")
 
 	AM_RANGE(0xd00000, 0xd1ffff) AM_RAM
 
@@ -286,14 +282,14 @@ static const gfx_layout layout8x8_2 =
 };
 
 static GFXDECODE_START( midas )
-	GFXDECODE_ENTRY( REGION_GFX1, 0x000000, layout16x16,  0, 0x100 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x000000, layout8x8_2,  0, 0x80 )
+	GFXDECODE_ENTRY( "gfx1", 0x000000, layout16x16,  0, 0x100 )
+	GFXDECODE_ENTRY( "gfx2", 0x000000, layout8x8_2,  0, 0x80 )
 GFXDECODE_END
 
 
 static INPUT_PORTS_START( livequiz )
 
-	PORT_START	// IN0
+	PORT_START("IN0")	// IN0
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -312,7 +308,7 @@ static INPUT_PORTS_START( livequiz )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN1
+	PORT_START("IN1")	// IN1
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -331,11 +327,11 @@ static INPUT_PORTS_START( livequiz )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN2
+	PORT_START("IN2")	// IN2
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW,  IPT_COIN1   )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW,  IPT_UNKNOWN )
-	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_SPECIAL ) // EEPROM
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(eeprom_bit_r, NULL)	// EEPROM
 	PORT_BIT( 0x0010, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x0020, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_SERVICE_NO_TOGGLE( 0x0040,   IP_ACTIVE_LOW )
@@ -350,7 +346,7 @@ static INPUT_PORTS_START( livequiz )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN3
+	PORT_START("IN3")	// IN3
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(3)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(3)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(3)
@@ -369,7 +365,7 @@ static INPUT_PORTS_START( livequiz )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN4
+	PORT_START("IN4")	// IN4
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_START3  )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -388,7 +384,7 @@ static INPUT_PORTS_START( livequiz )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN5 - 900000
+	PORT_START("IN5")	// IN5 - 900000
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(	0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
@@ -426,34 +422,33 @@ static INPUT_PORTS_START( livequiz )
 INPUT_PORTS_END
 
 
-static void livequiz_irqhandler (int state)
+static void livequiz_irqhandler(running_machine *machine, int state)
 {
 	logerror("YMZ280 is generating an interrupt. State=%08x\n",state);
 }
 
-static const struct YMZ280Binterface ymz280b_interface =
+static const ymz280b_interface ymz280b_config =
 {
-	REGION_SOUND1,
 	livequiz_irqhandler
 };
 
 static MACHINE_DRIVER_START( livequiz )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000, 24000000 / 2)
+	MDRV_CPU_ADD("main", M68000, 24000000 / 2)
 	MDRV_CPU_PROGRAM_MAP(mem_map,0)
-	MDRV_CPU_VBLANK_INT(irq1_line_hold,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", irq1_line_hold)
 
 	MDRV_NVRAM_HANDLER(93C46)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(320, 256)
 	MDRV_SCREEN_VISIBLE_AREA(0, 320-1, 16, 256-16-1)
+
 	MDRV_GFXDECODE(midas)
 	MDRV_PALETTE_LENGTH(0x10000)
 
@@ -462,8 +457,8 @@ static MACHINE_DRIVER_START( livequiz )
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
-	MDRV_SOUND_ADD(YMZ280B, 16934400)
-	MDRV_SOUND_CONFIG(ymz280b_interface)
+	MDRV_SOUND_ADD("ymz", YMZ280B, 16934400)
+	MDRV_SOUND_CONFIG(ymz280b_config)
 	MDRV_SOUND_ROUTE(0, "left", 0.80)
 	MDRV_SOUND_ROUTE(1, "right", 0.80)
 MACHINE_DRIVER_END
@@ -558,29 +553,29 @@ Notes:
 ***************************************************************************************/
 
 ROM_START( livequiz )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 )
+	ROM_REGION( 0x200000, "main", 0 )
 	ROM_LOAD16_WORD_SWAP( "flash.u1", 0x000000, 0x200000, CRC(8ec44493) SHA1(a987886cb87ac0a744f01f2e4a7cc6d12efeaa04) )
 
-	ROM_REGION( 0x200000, REGION_USER1, 0 )
+	ROM_REGION( 0x200000, "user1", 0 )
 	ROM_LOAD( "main_pic12c508a.u27", 0x000000, 0x000400, CRC(a84f0a7e) SHA1(fb27c05fb27b98ca603697e1be214dc6c8d5f884) )
 	ROM_LOAD( "sub_pic12c508a.u4",   0x000000, 0x000400, CRC(e52ebdc4) SHA1(0f3af66b5ea184e49188e74a873699324a3930f1) )
 
-	ROM_REGION( 0x800000, REGION_GFX1, 0 )
+	ROM_REGION( 0x800000, "gfx1", 0 )
 	ROM_LOAD( "flash.u15", 0x000000, 0x200000, CRC(d6eb56f1) SHA1(52d67bb25dd968c79eccb05159a578516b27e557) )
 	ROM_LOAD( "flash.u16", 0x200000, 0x200000, CRC(4c9fd873) SHA1(6e185304ce29771265d3c48b0ef0e840d8bed02d) )
 	ROM_LOAD( "flash.u19", 0x400000, 0x200000, CRC(daa81532) SHA1(9e66bb4639b92c3d76b7918535f55883f22f24b2) )
 	ROM_LOAD( "flash.u20", 0x600000, 0x200000, CRC(b540a8c7) SHA1(25b9b30c7d5ff1e410ea30580017e45590542561) )
 
-	ROM_REGION( 0x080000, REGION_GFX2, 0 )
+	ROM_REGION( 0x080000, "gfx2", 0 )
 	ROM_LOAD( "27c4096.u23", 0x000000, 0x080000, CRC(25121de8) SHA1(edf24d87551639b871baf3243b452a4e2ba84107) )
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x200000, "ymz", 0 )
 	ROM_LOAD( "flash.u5", 0x000000, 0x200000, CRC(dc062792) SHA1(ec415c918c47ce9d181f014cde317af5717600e4) )
 ROM_END
 
 static DRIVER_INIT( livequiz )
 {
-	UINT16 *rom = (UINT16 *) memory_region(REGION_CPU1);
+	UINT16 *rom = (UINT16 *) memory_region(machine, "main");
 
 	// PROTECTION CHECKS
 	rom[0x13345a/2]	=	0x4e75;
