@@ -11,11 +11,12 @@
 ***************************************************************************/
 
 #include "driver.h"
+#include "cpu/i8085/i8085.h"
 #include "includes/n8080.h"
 
 static unsigned shift_data;
 static unsigned shift_bits;
-
+static int inte;
 
 static WRITE8_HANDLER( n8080_shift_bits_w )
 {
@@ -32,18 +33,8 @@ static READ8_HANDLER( n8080_shift_r )
 	return shift_data >> (8 - shift_bits);
 }
 
-
-static INTERRUPT_GEN( interrupt )
-{
-	if (video_screen_get_vblank(0))
-		cpunum_set_input_line_and_vector(machine, 0, 0, PULSE_LINE, 0xcf);  /* RST $08 */
-	else
-		cpunum_set_input_line_and_vector(machine, 0, 0, PULSE_LINE, 0xd7);  /* RST $10 */
-}
-
-
 static ADDRESS_MAP_START( main_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(15) )
+	ADDRESS_MAP_GLOBAL_MASK(0x7fff)
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x7fff) AM_RAM AM_BASE(&videoram)
 ADDRESS_MAP_END
@@ -55,14 +46,13 @@ static ADDRESS_MAP_START( helifire_main_cpu_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xc000, 0xdfff) AM_RAM AM_BASE(&colorram)
 ADDRESS_MAP_END
 
-
 static ADDRESS_MAP_START( main_io_map, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(3) )
-	AM_RANGE(0x00, 0x00) AM_READ(input_port_0_r)
-	AM_RANGE(0x01, 0x01) AM_READ(input_port_1_r)
-	AM_RANGE(0x02, 0x02) AM_READ(input_port_2_r)
+	ADDRESS_MAP_GLOBAL_MASK(0x7)
+	AM_RANGE(0x00, 0x00) AM_READ_PORT("IN0")
+	AM_RANGE(0x01, 0x01) AM_READ_PORT("IN1")
+	AM_RANGE(0x02, 0x02) AM_READ_PORT("IN2")
 	AM_RANGE(0x03, 0x03) AM_READ(n8080_shift_r)
-	AM_RANGE(0x04, 0x04) AM_READ(input_port_3_r)
+	AM_RANGE(0x04, 0x04) AM_READ_PORT("IN3")
 
 	AM_RANGE(0x02, 0x02) AM_WRITE(n8080_shift_bits_w)
 	AM_RANGE(0x03, 0x03) AM_WRITE(n8080_shift_data_w)
@@ -71,27 +61,69 @@ static ADDRESS_MAP_START( main_io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x06, 0x06) AM_WRITE(n8080_video_control_w)
 ADDRESS_MAP_END
 
+/* Interrupts */
+
+static TIMER_DEVICE_CALLBACK( rst1_tick )
+{
+	int state = inte ? ASSERT_LINE : CLEAR_LINE;
+
+	/* V7 = 1, V6 = 0 */
+	cputag_set_input_line_and_vector(timer->machine, "main", INPUT_LINE_IRQ0, state, 0xcf);
+}
+
+static TIMER_DEVICE_CALLBACK( rst2_tick )
+{
+	int state = inte ? ASSERT_LINE : CLEAR_LINE;
+
+	/* vblank */
+	cputag_set_input_line_and_vector(timer->machine, "main", INPUT_LINE_IRQ0, state, 0xd7);
+}
+
+static void n8080_inte_callback(const device_config *device, int state)
+{
+	inte = state;
+}
+
+static void n8080_status_callback(const device_config *device, UINT8 status)
+{
+	if (BIT(status, 0))
+	{
+		/* interrupt acknowledge */
+		cpu_set_input_line(device, INPUT_LINE_IRQ0, CLEAR_LINE);
+	}
+}
+
+static const i8085_config n8080_cpu_config =
+{
+	n8080_inte_callback,	/* INTE changed callback */
+	n8080_status_callback,	/* STATUS changed callback */
+	NULL,					/* SOD changed callback (8085A only) */
+	NULL,					/* SID changed callback (8085A only) */
+};
 
 static MACHINE_DRIVER_START( spacefev )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(8080, 20160000 / 10)
+	MDRV_CPU_ADD("main", 8080, 20160000 / 10)
+	MDRV_CPU_CONFIG(n8080_cpu_config)
 	MDRV_CPU_PROGRAM_MAP(main_cpu_map, 0)
 	MDRV_CPU_IO_MAP(main_io_map, 0)
-	MDRV_CPU_VBLANK_INT(interrupt, 2)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 256)
 	MDRV_SCREEN_VISIBLE_AREA(0, 255, 16, 239)
+
 	MDRV_PALETTE_LENGTH(8)
 	MDRV_PALETTE_INIT(n8080)
 	MDRV_VIDEO_START(spacefev)
 	MDRV_VIDEO_UPDATE(spacefev)
 
+	MDRV_TIMER_ADD_SCANLINE("rst1", rst1_tick, "main", 128, 256)
+	MDRV_TIMER_ADD_SCANLINE("rst2", rst2_tick, "main", 240, 256)
+
 	/* sound hardware */
 	MDRV_IMPORT_FROM( spacefev_sound )
 MACHINE_DRIVER_END
@@ -100,23 +132,26 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( sheriff )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(8080, 20160000 / 10)
+	MDRV_CPU_ADD("main", 8080, 20160000 / 10)
+	MDRV_CPU_CONFIG(n8080_cpu_config)
 	MDRV_CPU_PROGRAM_MAP(main_cpu_map, 0)
 	MDRV_CPU_IO_MAP(main_io_map, 0)
-	MDRV_CPU_VBLANK_INT(interrupt, 2)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 256)
 	MDRV_SCREEN_VISIBLE_AREA(0, 255, 16, 239)
+
 	MDRV_PALETTE_LENGTH(8)
 	MDRV_PALETTE_INIT(n8080)
 	MDRV_VIDEO_START(sheriff)
 	MDRV_VIDEO_UPDATE(sheriff)
 
+	MDRV_TIMER_ADD_SCANLINE("rst1", rst1_tick, "main", 128, 256)
+	MDRV_TIMER_ADD_SCANLINE("rst2", rst2_tick, "main", 240, 256)
+
 	/* sound hardware */
 	MDRV_IMPORT_FROM( sheriff_sound )
 MACHINE_DRIVER_END
@@ -125,31 +160,34 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( helifire )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(8080, 20160000 / 10)
+	MDRV_CPU_ADD("main", 8080, 20160000 / 10)
+	MDRV_CPU_CONFIG(n8080_cpu_config)
 	MDRV_CPU_PROGRAM_MAP(helifire_main_cpu_map, 0)
 	MDRV_CPU_IO_MAP(main_io_map, 0)
-	MDRV_CPU_VBLANK_INT(interrupt, 2)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 256)
 	MDRV_SCREEN_VISIBLE_AREA(0, 255, 16, 239)
+
 	MDRV_PALETTE_LENGTH(8 + 0x400)
 	MDRV_PALETTE_INIT(helifire)
 	MDRV_VIDEO_START(helifire)
 	MDRV_VIDEO_UPDATE(helifire)
 	MDRV_VIDEO_EOF(helifire)
 
+	MDRV_TIMER_ADD_SCANLINE("rst1", rst1_tick, "main", 128, 256)
+	MDRV_TIMER_ADD_SCANLINE("rst2", rst2_tick, "main", 240, 256)
+
 	/* sound hardware */
 	MDRV_IMPORT_FROM( helifire_sound )
 MACHINE_DRIVER_END
 
 
 static INPUT_PORTS_START( spacefev )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY
@@ -159,7 +197,7 @@ static INPUT_PORTS_START( spacefev )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_COIN1 )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY PORT_PLAYER(2)
@@ -169,7 +207,7 @@ static INPUT_PORTS_START( spacefev )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED ) /* enables diagnostic ROM at $1c00 */
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Lives ))
 	PORT_DIPSETTING(    0x00, "3" )
 	PORT_DIPSETTING(    0x01, "4" )
@@ -194,13 +232,13 @@ static INPUT_PORTS_START( spacefev )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ))
 	PORT_DIPSETTING(    0x00, DEF_STR( On ))
 
-	PORT_START
+	PORT_START("IN3")
 
 INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( highsplt )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY
@@ -210,7 +248,7 @@ static INPUT_PORTS_START( highsplt )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_COIN1 )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY PORT_PLAYER(2)
@@ -220,7 +258,7 @@ static INPUT_PORTS_START( highsplt )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED ) /* enables diagnostic ROM at $2000 */
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Lives ))
 	PORT_DIPSETTING(    0x00, "3" )
 	PORT_DIPSETTING(    0x01, "4" )
@@ -244,13 +282,13 @@ static INPUT_PORTS_START( highsplt )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ))
 	PORT_DIPSETTING(    0x00, DEF_STR( On ))
 
-	PORT_START
+	PORT_START("IN3")
 
 INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( spacelnc )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY
@@ -260,7 +298,7 @@ static INPUT_PORTS_START( spacelnc )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_COIN1 )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY PORT_PLAYER(2)
@@ -270,7 +308,7 @@ static INPUT_PORTS_START( spacelnc )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED ) /* enables diagnostic ROM at $2000 */
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Lives ))
 	PORT_DIPSETTING(    0x00, "3" )
 	PORT_DIPSETTING(    0x01, "4" )
@@ -294,13 +332,13 @@ static INPUT_PORTS_START( spacelnc )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ))
 	PORT_DIPSETTING(    0x00, DEF_STR( On ))
 
-	PORT_START
+	PORT_START("IN3")
 
 INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( sheriff )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICKLEFT_RIGHT )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICKLEFT_LEFT )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICKLEFT_UP )
@@ -310,7 +348,7 @@ static INPUT_PORTS_START( sheriff )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_JOYSTICKRIGHT_UP )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_JOYSTICKRIGHT_DOWN )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICKLEFT_RIGHT ) PORT_COCKTAIL
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICKLEFT_LEFT ) PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICKLEFT_UP ) PORT_COCKTAIL
@@ -320,7 +358,7 @@ static INPUT_PORTS_START( sheriff )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_JOYSTICKRIGHT_UP ) PORT_COCKTAIL
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_JOYSTICKRIGHT_DOWN ) PORT_COCKTAIL
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_START1 )
@@ -330,7 +368,7 @@ static INPUT_PORTS_START( sheriff )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED ) /* EXP3 enables diagnostic ROM at $2400 */
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_COIN1 )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Lives ))	PORT_DIPLOCATION("SW1:1,2")
 	PORT_DIPSETTING(    0x00, "3" )
 	PORT_DIPSETTING(    0x01, "4" )
@@ -348,7 +386,7 @@ INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( bandido )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICKLEFT_RIGHT )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICKLEFT_LEFT )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICKLEFT_UP )
@@ -358,9 +396,9 @@ static INPUT_PORTS_START( bandido )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_JOYSTICKRIGHT_UP )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_JOYSTICKRIGHT_DOWN )
 
-	PORT_START
+	PORT_START("IN1")
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_BUTTON1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_START1 )
@@ -370,7 +408,7 @@ static INPUT_PORTS_START( bandido )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED ) /* EXP3 enables diagnostic ROM at $2400 */
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_COIN1 )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Lives ))
 	PORT_DIPSETTING(    0x00, "3" )
 	PORT_DIPSETTING(    0x01, "4" )
@@ -398,7 +436,7 @@ INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( helifire )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP )
@@ -408,7 +446,7 @@ static INPUT_PORTS_START( helifire )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_COCKTAIL
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP ) PORT_COCKTAIL
@@ -418,7 +456,7 @@ static INPUT_PORTS_START( helifire )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_START1 )
@@ -428,7 +466,7 @@ static INPUT_PORTS_START( helifire )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED ) /* EXP3 */
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_COIN1 )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_DIPNAME( 0x03, 0x00, DEF_STR( Lives ))
 	PORT_DIPSETTING(    0x00, "3" )
 	PORT_DIPSETTING(    0x01, "4" )
@@ -448,7 +486,7 @@ static INPUT_PORTS_START( helifire )
 
 	/* potentiometers */
 
-	PORT_START	/* 04 */
+	PORT_START("POT0")	/* 04 */
 	PORT_DIPNAME( 0xff, 0x50, "VR1 sun brightness" )
 	PORT_DIPSETTING(    0x00, "00" )
 	PORT_DIPSETTING(    0x10, "10" )
@@ -459,7 +497,7 @@ static INPUT_PORTS_START( helifire )
 	PORT_DIPSETTING(    0x60, "60" )
 	PORT_DIPSETTING(    0x70, "70" )
 
-	PORT_START	/* 05 */
+	PORT_START("POT1")	/* 05 */
 	PORT_DIPNAME( 0xff, 0x00, "VR2 sea brightness" )
 	PORT_DIPSETTING(    0x00, "00" )
 	PORT_DIPSETTING(    0x10, "10" )
@@ -473,8 +511,122 @@ static INPUT_PORTS_START( helifire )
 INPUT_PORTS_END
 
 
+/*
+Space Fever (3 sets, Space Fever?, High Splitter?, Space Launcher?)
+Nintendo, 1979
+
+Note: These are all simple ROM swaps on a standard b/w Space Fever PCB.
+
+
+PCB Layouts
+-----------
+
+Top Board (Sound PCB)
+
+TSF-SOU
+|----------------------------------------------------|
+|                                 VR3    VR2    VR1  |
+|  8035                    74123                     |
+|                 74275                              |
+|  6MHz                                              |
+|                          74123         SN76477     |
+|  SF_SOUND.IC2   74275                              |
+|                                                    |
+|                          7405                      |
+|                                                    |
+|----------------------------------------------------|
+Notes:
+      All IC's shown.
+      There is no AMP on the PCB, sound amplification is done via a small external AMP board.
+      ROM IC2 is a 2708 EPROM.
+      VR1: master volume
+      VR2: shoot volume
+      VR3: music volume
+      8035 clocks: pins 2 and 3 measure 6.000MHz
+                   pin 9 measures 399.256kHz
+                   pin 12 measures 200.0kHz
+                   pin 13 measures 105.0kHz
+                   pin 21 measures 399.4Khz
+                   pin 22 measures 400.0kHz
+                   pin 23 measures 399.3kHz
+                   pin 24 measures 399.3kHz
+                   pin 39 measures 61.5627Hz
+
+
+Middle board
+------------
+
+TSF-I/O  PI-500803
+|----------------------------------------------------|
+|                                                    |
+|     VR1                                            |
+|                     20.160MHz                      |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                     DSW1(8)                        |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|----------------------------------------------------|
+Notes:
+      VR1: adjusts brightness
+      Board contains mostly logic ICs (not shown)
+      Video output is b/w, the harness is wired to a JAMMA fingerboard but only blue is used.
+
+
+Bottom board
+------------
+
+TSF-CPU  PI-500802
+|----------------------------------------------------|
+|                                                    |
+|                                                    |
+|                                                    |
+|             SF_F1.F1  SF_G1.G1  SF_H1.H1  SF_I1.I1 |
+|                                                    |
+|   8080                                             |
+|                                                    |
+|             SF_F2.F2  SF_G2.G2  SF_H2.H2  SF_I2.I2 |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|                                                    |
+|     4116  4116  4116  4116  4116  4116  4116  4116 |
+|----------------------------------------------------|
+Notes:
+      All ROMs are 2708, 1K x8
+      4116: 2K x8 DRAM
+      8080 clock: 2.0160MHz (20.160 / 10)
+      Sync: no V reading, H is 15.57kHz
+
+      Set 1 is on the PCB and is complete.
+      Some ROMs in set1 match the current sfeverbw set.
+
+      The other two sets were supplied as just EPROMs.
+      Set2 (maybe High Splitter) is missing the ROM at location I2. Might be missing, or maybe
+      just the program is smaller and the extra ROM was not required.
+*/
+
 ROM_START( spacefev )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "sf.f1",    0x0000, 0x0400, CRC(35f295bd) SHA1(34d1df25fcdea598ca1191cecc2125e6f63dbce3) )
 	ROM_LOAD( "sf.f2",    0x0400, 0x0400, CRC(0c633f4c) SHA1(a551ddbf21670fb1f000404b92da87a97f7ba157) )
 	ROM_LOAD( "sf.g1",    0x0800, 0x0400, CRC(f3d851cb) SHA1(535c52a56e54a064aa3d1c48a129f714234a1007) )
@@ -483,15 +635,15 @@ ROM_START( spacefev )
 	ROM_LOAD( "sf.h2",    0x1400, 0x0400, CRC(a163e800) SHA1(e8817f3e17f099a0dc66213d2d3d3fdeb117b10e) )
 	ROM_LOAD( "sf.i1",    0x1800, 0x0400, CRC(00027be2) SHA1(551a779a2e5a6455b7a348d246731c094e0ec709) )
 
-	ROM_REGION( 0x0400, REGION_CPU2, 0 )
+	ROM_REGION( 0x0400, "audio", 0 )
 	ROM_LOAD( "sf.snd",   0x0000, 0x0400, CRC(95c2c1ee) SHA1(42a3a382fc7d2782052372d71f6d0e8a153e74d0) )
 
-	ROM_REGION( 0x0020, REGION_PROMS, 0 )
+	ROM_REGION( 0x0020, "proms", 0 )
 	ROM_LOAD( "sf.prm",   0x0000, 0x0020, CRC(c5914ec1) SHA1(198875fcab36d09c8726bb21e2fdff9882f6721a) )
 ROM_END
 
 ROM_START( spacefva )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "sf-a.f1",  0x0000, 0x0400, CRC(7fa305e8) SHA1(cda9fc9c76f57800de25ddf65f69fef19fd28481) )
 	ROM_LOAD( "sf-a.f2",  0x0400, 0x0400, CRC(7c1429aa) SHA1(8d8e0a4fc09fb1ecbfb86c67c20000ef30ab3fac) )
 	ROM_LOAD( "sf-a.g1",  0x0800, 0x0400, CRC(75f6efc1) SHA1(286bc75e35e8ad6277e9db7377e90731b9c2ec97) )
@@ -500,15 +652,15 @@ ROM_START( spacefva )
 	ROM_LOAD( "sf-a.h2",  0x1400, 0x0400, CRC(bddbc94f) SHA1(f90cbc3cd0f695cbb9ae03b608f4bf5a4a000c64) )
 	ROM_LOAD( "sf-a.i1",  0x1800, 0x0400, CRC(437786c5) SHA1(2ccdb0d48dbbfe47ae82e970ca37970602405cf6) )
 
-	ROM_REGION( 0x0400, REGION_CPU2, 0 )
+	ROM_REGION( 0x0400, "audio", 0 )
 	ROM_LOAD( "sf.snd",   0x0000, 0x0400, CRC(95c2c1ee) SHA1(42a3a382fc7d2782052372d71f6d0e8a153e74d0) )
 
-	ROM_REGION( 0x0020, REGION_PROMS, 0 )
+	ROM_REGION( 0x0020, "proms", 0 )
 	ROM_LOAD( "sf.prm",   0x0000, 0x0020, CRC(c5914ec1) SHA1(198875fcab36d09c8726bb21e2fdff9882f6721a) )
 ROM_END
 
 ROM_START( highsplt )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "hs.f1",    0x0000, 0x0400, CRC(b8887351) SHA1(ccd49937f1cbd7a157b3715474ccc3e8fdcea2b2) )
 	ROM_LOAD( "hs.f2",    0x0400, 0x0400, CRC(cda933a7) SHA1(a0447c8c98e24674081c9bf4b1ef07dc186c6e2b) )
 	ROM_LOAD( "hs.g1",    0x0800, 0x0400, CRC(de17578a) SHA1(d9d5dbf38331f212d2a566c60756a788e169104d) )
@@ -518,15 +670,15 @@ ROM_START( highsplt )
 	ROM_LOAD( "hs.i1",    0x1800, 0x0400, CRC(41e18df9) SHA1(2212c836313775e7c507a875672c0b3635825e02) )
 	ROM_LOAD( "hs.i2",    0x1c00, 0x0400, CRC(eff9f82d) SHA1(5004e52dfa652ceefca9ed4210c0fa8f0591dc08) )
 
-	ROM_REGION( 0x0400, REGION_CPU2, 0 )
+	ROM_REGION( 0x0400, "audio", 0 )
 	ROM_LOAD( "hs.snd",   0x0000, 0x0400, CRC(939e01d4) SHA1(7c9ccd24e5da03831cd0aa821da17e3b81cd8381) )
 
-	ROM_REGION( 0x0020, REGION_PROMS, 0 )
+	ROM_REGION( 0x0020, "proms", 0 )
 	ROM_LOAD( "sf.prm",   0x0000, 0x0020, CRC(c5914ec1) SHA1(198875fcab36d09c8726bb21e2fdff9882f6721a) )
 ROM_END
 
 ROM_START( highspla )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "hs.f1",    0x0000, 0x0400, CRC(b8887351) SHA1(ccd49937f1cbd7a157b3715474ccc3e8fdcea2b2) )
 	ROM_LOAD( "hs.f2",    0x0400, 0x0400, CRC(cda933a7) SHA1(a0447c8c98e24674081c9bf4b1ef07dc186c6e2b) )
 	ROM_LOAD( "hs.g1",    0x0800, 0x0400, CRC(de17578a) SHA1(d9d5dbf38331f212d2a566c60756a788e169104d) )
@@ -536,15 +688,15 @@ ROM_START( highspla )
 	ROM_LOAD( "hs-a.i1",  0x1800, 0x0400, CRC(aa36b25d) SHA1(28f555aab27b206a8c6f550b6caa938cece6e204) )
 	ROM_LOAD( "hs.i2",    0x1c00, 0x0400, CRC(eff9f82d) SHA1(5004e52dfa652ceefca9ed4210c0fa8f0591dc08) )
 
-	ROM_REGION( 0x0400, REGION_CPU2, 0 )
+	ROM_REGION( 0x0400, "audio", 0 )
 	ROM_LOAD( "hs.snd",   0x0000, 0x0400, CRC(939e01d4) SHA1(7c9ccd24e5da03831cd0aa821da17e3b81cd8381) )
 
-	ROM_REGION( 0x0020, REGION_PROMS, 0 )
+	ROM_REGION( 0x0020, "proms", 0 )
 	ROM_LOAD( "sf.prm",   0x0000, 0x0020, CRC(c5914ec1) SHA1(198875fcab36d09c8726bb21e2fdff9882f6721a) )
 ROM_END
 
 ROM_START( spacelnc )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "sl.f1",    0x0000, 0x0400, CRC(6ad59e40) SHA1(d416f7e6f5f55178df5c390548cd299650853022) )
 	ROM_LOAD( "sl.f2",    0x0400, 0x0400, CRC(2de568e2) SHA1(f13740d3d9bf7434b7760e9286ef6e2ede40845f) )
 	ROM_LOAD( "sl.g1",    0x0800, 0x0400, CRC(06d0ab36) SHA1(bf063100b065dbf511d6f32da169fb461568d15d) )
@@ -554,15 +706,15 @@ ROM_START( spacelnc )
 	ROM_LOAD( "sl.i1",    0x1800, 0x0400, CRC(d30007a3) SHA1(9e5905df8f7822385daef159a07f0e8257cb862a) )
 	ROM_LOAD( "sl.i2",    0x1c00, 0x0400, CRC(640ffd2f) SHA1(65c21396c39dc99ec263f66f400a8e4c7712b20a) )
 
-	ROM_REGION( 0x0400, REGION_CPU2, 0 )
+	ROM_REGION( 0x0400, "audio", 0 )
 	ROM_LOAD( "sl.snd",   0x0000, 0x0400, CRC(8e1ff929) SHA1(5c7da97b05fb8fff242158978199f5d35b234426) )
 
-	ROM_REGION( 0x0020, REGION_PROMS, 0 )
+	ROM_REGION( 0x0020, "proms", 0 )
 	ROM_LOAD( "sf.prm",   0x0000, 0x0020, CRC(c5914ec1) SHA1(198875fcab36d09c8726bb21e2fdff9882f6721a) )
 ROM_END
 
 ROM_START( sheriff )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "sh.f1",    0x0000, 0x0400, CRC(e79df6e8) SHA1(908176de9bfc3d48e2da9af6ba7ebdee698ec2de) )
 	ROM_LOAD( "sh.f2",    0x0400, 0x0400, CRC(da67721a) SHA1(ee6a5fb98da1d1fcfad0ef27af300473a637f578) )
 	ROM_LOAD( "sh.g1",    0x0800, 0x0400, CRC(3fb7888e) SHA1(2c2d6b27d577d5ccf759e451e53c2e3314af40f6) )
@@ -573,15 +725,15 @@ ROM_START( sheriff )
 	ROM_LOAD( "sh.i2",    0x1c00, 0x0400, CRC(5c5f3f86) SHA1(25c64ccb7d0e136f67d6e1da7927ae6d89e0ceb9) )
 	ROM_LOAD( "sh.j1",    0x2000, 0x0400, CRC(0aa8b79a) SHA1(aed139e8c8ba912823c57fe4cc7231b2d638f479) )
 
-	ROM_REGION( 0x0400, REGION_CPU2, 0 )
+	ROM_REGION( 0x0400, "audio", 0 )
 	ROM_LOAD( "sh.snd",   0x0000, 0x0400, CRC(75731745) SHA1(538a63c9c60f1886fca4caf3eb1e0bada2d3f162) )
 
-	ROM_REGION( 0x0400, REGION_PROMS, 0 )
+	ROM_REGION( 0x0400, "proms", 0 )
 	ROM_LOAD( "82s137.3l", 0x0000, 0x0400, CRC(820f8cdd) SHA1(197eeb008c140558e7c1ab2b2bd0f6a27096877c) )
 ROM_END
 
 ROM_START( bandido )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "sh-a.f1",  0x0000, 0x0400, CRC(aec94829) SHA1(aa6d241670ea061bac4a71dff82dfa832095eae6) )
 	ROM_LOAD( "sh.f2",    0x0400, 0x0400, CRC(da67721a) SHA1(ee6a5fb98da1d1fcfad0ef27af300473a637f578) )
 	ROM_LOAD( "sh.g1",    0x0800, 0x0400, CRC(3fb7888e) SHA1(2c2d6b27d577d5ccf759e451e53c2e3314af40f6) )
@@ -593,15 +745,15 @@ ROM_START( bandido )
 	ROM_LOAD( "sh.j1",    0x2000, 0x0400, CRC(0aa8b79a) SHA1(aed139e8c8ba912823c57fe4cc7231b2d638f479) )
 	ROM_LOAD( "sh-a.j2",  0x2400, 0x0400, CRC(a10b848a) SHA1(c045f1f6a11cbf49a1bae06c701b659d587292a3) )
 
-	ROM_REGION( 0x0400, REGION_CPU2, 0 )
+	ROM_REGION( 0x0400, "audio", 0 )
 	ROM_LOAD( "sh.snd",   0x0000, 0x0400, CRC(75731745) SHA1(538a63c9c60f1886fca4caf3eb1e0bada2d3f162) )
 
-	ROM_REGION( 0x0400, REGION_PROMS, 0 )
+	ROM_REGION( 0x0400, "proms", 0 )
 	ROM_LOAD( "82s137.3l", 0x0000, 0x0400, CRC(820f8cdd) SHA1(197eeb008c140558e7c1ab2b2bd0f6a27096877c) )
 ROM_END
 
 ROM_START( helifire )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "hf.f1",    0x0000, 0x0400, CRC(032f89ca) SHA1(63b0310875ed78a6385e44eea781ddcc4a63557c) )
 	ROM_LOAD( "hf.f2",    0x0400, 0x0400, CRC(2774e70f) SHA1(98d845e80db61799493dbebe8db801567277432c) )
 	ROM_LOAD( "hf.g1",    0x0800, 0x0400, CRC(b5ad6e8a) SHA1(1eb4931e85bd6a559e85a2b978d383216d3988a7) )
@@ -613,12 +765,12 @@ ROM_START( helifire )
 	ROM_LOAD( "hf.j1",    0x2000, 0x0400, CRC(98ef24db) SHA1(70ad8dd6e1e8f4bf4ce431737ca1856eecc03d53) )
 	ROM_LOAD( "hf.j2",    0x2400, 0x0400, CRC(5e2b5877) SHA1(f7c747e8a1d9fe2dda71ee6304636cf3cdf727a7) )
 
-	ROM_REGION( 0x0400, REGION_CPU2, 0 )
+	ROM_REGION( 0x0400, "audio", 0 )
 	ROM_LOAD( "hf.snd",   0x0000, 0x0400, CRC(9d77a31f) SHA1(36db9b5087b6661de88042854874bc247c92d985) )
 ROM_END
 
 ROM_START( helifira )
-	ROM_REGION( 0x8000, REGION_CPU1, 0 )
+	ROM_REGION( 0x8000, "main", 0 )
 	ROM_LOAD( "hf-a.f1",  0x0000, 0x0400, CRC(92c9d6c1) SHA1(860a7b3980e9e11d48769fad347c965e04ed3f89) )
 	ROM_LOAD( "hf-a.f2",  0x0400, 0x0400, CRC(a264dde8) SHA1(48f972ad5af6c2ab61117f60d9244df6df6d313c) )
 	ROM_LOAD( "hf.g1",    0x0800, 0x0400, CRC(b5ad6e8a) SHA1(1eb4931e85bd6a559e85a2b978d383216d3988a7) )
@@ -630,7 +782,7 @@ ROM_START( helifira )
 	ROM_LOAD( "hf.j1",    0x2000, 0x0400, CRC(98ef24db) SHA1(70ad8dd6e1e8f4bf4ce431737ca1856eecc03d53) )
 	ROM_LOAD( "hf.j2",    0x2400, 0x0400, CRC(5e2b5877) SHA1(f7c747e8a1d9fe2dda71ee6304636cf3cdf727a7) )
 
-	ROM_REGION( 0x0400, REGION_CPU2, 0 )
+	ROM_REGION( 0x0400, "audio", 0 )
 	ROM_LOAD( "hf.snd",   0x0000, 0x0400, CRC(9d77a31f) SHA1(36db9b5087b6661de88042854874bc247c92d985) )
 ROM_END
 
@@ -639,8 +791,8 @@ GAME( 1979, spacefev, 0,        spacefev, spacefev, 0, ROT270, "Nintendo", "Spac
 GAME( 1979, spacefva, spacefev, spacefev, spacefev, 0, ROT270, "Nintendo", "Space Fever (set 2)", 0 )
 GAME( 1979, highsplt, 0,        spacefev, highsplt, 0, ROT270, "Nintendo", "Space Fever High Splitter (set 1)", 0 )
 GAME( 1979, highspla, highsplt, spacefev, highsplt, 0, ROT270, "Nintendo", "Space Fever High Splitter (set 2)", 0 )
-GAME( 1979, spacelnc, 0,        spacefev, spacelnc, 0, ROT270, "Nintendo", "Space Launcher", 0 )
+GAME( 1979, spacelnc, 0,        spacefev, spacelnc, 0, ROT270, "Nintendo", "Space Launcher", GAME_NOT_WORKING )
 GAME( 1979, sheriff,  0,        sheriff,  sheriff,  0, ROT270, "Nintendo", "Sheriff", 0 )
 GAME( 1980, bandido,  sheriff,  sheriff,  bandido,  0, ROT270, "Exidy",    "Bandido", 0 )
-GAME( 1980, helifire, 0,        helifire, helifire, 0, ROT270, "Nintendo", "HeliFire (set 1)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS | GAME_NO_COCKTAIL )
-GAME( 1980, helifira, helifire, helifire, helifire, 0, ROT270, "Nintendo", "HeliFire (set 2)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS | GAME_NO_COCKTAIL )
+GAME( 1980, helifire, 0,        helifire, helifire, 0, ROT270, "Nintendo", "HeliFire (set 1)", GAME_NOT_WORKING | GAME_NO_COCKTAIL )
+GAME( 1980, helifira, helifire, helifire, helifire, 0, ROT270, "Nintendo", "HeliFire (set 2)", GAME_NOT_WORKING | GAME_NO_COCKTAIL )
