@@ -52,6 +52,40 @@ SYSTEM-FL MAIN PCB 8636960100 (8636970100)
        |25  24  23  22  21  20  19  18  17  16  15  14  13  12  11  10  9  8  7  6  5  4  3  2  1   |
        |--------------------------------------------------------------------------------------------|
 
+RAM
+---
+4Y : CY7C199-25PC
+4Z : CY7C199-25PC
+5A : TC514256BZ-60
+5P : LH528256N-70LL
+6A : TC514256BZ-60
+7A : TC514256BZ-60
+7P : LH528256N-70LL
+8A : TC514256BZ-60
+8P : LH528256N-70LL
+9A : TC514256BZ-60
+10A: TC514256BZ-60
+10P: LH528256N-70LL
+11A: TC514256BZ-60
+12A: TC514256BZ-60
+12U: TC511632FL-70
+12Y: TC511632FL-70
+13U: TC511632FL-70
+13Y: TC511632FL-70
+14U: TC511632FL-70
+14Y: TC511632FL-70
+16U: TC511632FL-70
+16Y: TC511632FL-70
+19Y: M5M5178AFP-25
+20Y: M5M5178AFP-25
+21A: 65256BLFP-10T
+21Y: M5M5178AFP-25
+22A: 65256BLFP-10T
+22T: LH528256N-70LL
+22U: LH528256N-70LL
+23E: M5M5256BFP-70LL
+23F: M5M5256BFP-70LL
+
 CUSTOM
 ------
 4X : NAMCO C355 (sprite chip)
@@ -122,6 +156,7 @@ OSC3: 48.384MHz
 */
 
 #include "driver.h"
+#include "deprecat.h"
 #include "machine/eeprom.h"
 #include "namconb1.h"
 #include "namcos2.h"
@@ -158,17 +193,17 @@ static READ32_HANDLER( namcofl_sysreg_r )
 
 static WRITE32_HANDLER( namcofl_sysreg_w )
 {
-	if ((offset == 2) && !(mem_mask & 0xff))  // address space configuration
+	if ((offset == 2) && ACCESSING_BITS_0_7)  // address space configuration
 	{
 		if (data == 0)	// RAM at 00000000, ROM at 10000000
 		{
-			memory_set_bankptr( 1, namcofl_workram );
-			memory_set_bankptr( 2, memory_region(REGION_CPU1) );
+			memory_set_bankptr(space->machine,  1, namcofl_workram );
+			memory_set_bankptr(space->machine,  2, memory_region(space->machine, "main") );
 		}
 		else		// ROM at 00000000, RAM at 10000000
 		{
-			memory_set_bankptr( 1, memory_region(REGION_CPU1) );
-			memory_set_bankptr( 2, namcofl_workram );
+			memory_set_bankptr(space->machine,  1, memory_region(space->machine, "main") );
+			memory_set_bankptr(space->machine,  2, namcofl_workram );
 		}
 	}
 }
@@ -177,26 +212,26 @@ static WRITE32_HANDLER( namcofl_paletteram_w )
 {
 	COMBINE_DATA(&paletteram32[offset]);
 
-	if ((offset == 0x1808/4) && ACCESSING_MSW32)
+	if ((offset == 0x1808/4) && ACCESSING_BITS_16_31)
 	{
 		UINT16 v = paletteram32[offset] >> 16;
 		UINT16 triggerscanline=(((v>>8)&0xff)|((v&0xff)<<8))-(32+1);
 
-		timer_adjust(raster_interrupt_timer, video_screen_get_time_until_pos(0, triggerscanline, 0), 0, attotime_zero);
+		timer_adjust_oneshot(raster_interrupt_timer, video_screen_get_time_until_pos(space->machine->primary_screen, triggerscanline, 0), 0);
 	}
 }
 
 
 static ADDRESS_MAP_START( namcofl_mem, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x00000000, 0x000fffff) AM_READWRITE(MRA32_BANK1, MWA32_BANK1)
-	AM_RANGE(0x10000000, 0x100fffff) AM_READWRITE(MRA32_BANK2, MWA32_BANK2)
-	AM_RANGE(0x20000000, 0x201fffff) AM_ROM AM_REGION(REGION_USER1, 0)	/* data */
+	AM_RANGE(0x00000000, 0x000fffff) AM_READWRITE(SMH_BANK1, SMH_BANK1)
+	AM_RANGE(0x10000000, 0x100fffff) AM_READWRITE(SMH_BANK2, SMH_BANK2)
+	AM_RANGE(0x20000000, 0x201fffff) AM_ROM AM_REGION("user1", 0)	/* data */
 	AM_RANGE(0x30000000, 0x30001fff) AM_RAM	AM_BASE(&generic_nvram32) AM_SIZE(&generic_nvram_size) /* nvram */
 	AM_RANGE(0x30100000, 0x30100003) AM_WRITE(namcofl_spritebank_w)
 	AM_RANGE(0x30284000, 0x3028bfff) AM_RAM	AM_BASE(&namcofl_mcuram) /* shared RAM with C75 MCU */
 	AM_RANGE(0x30300000, 0x30303fff) AM_RAM /* COMRAM */
 	AM_RANGE(0x30380000, 0x303800ff) AM_READ( fl_network_r )	/* network registers */
-	AM_RANGE(0x30400000, 0x3040ffff) AM_READWRITE(MRA32_RAM, namcofl_paletteram_w) AM_BASE(&paletteram32)
+	AM_RANGE(0x30400000, 0x3040ffff) AM_RAM_WRITE(namcofl_paletteram_w) AM_BASE(&paletteram32)
 	AM_RANGE(0x30800000, 0x3080ffff) AM_READWRITE(namco_tilemapvideoram32_le_r, namco_tilemapvideoram32_le_w )
 	AM_RANGE(0x30a00000, 0x30a0003f) AM_READWRITE(namco_tilemapcontrol32_le_r, namco_tilemapcontrol32_le_w )
 	AM_RANGE(0x30c00000, 0x30c1ffff) AM_READWRITE(namco_rozvideoram32_le_r,namco_rozvideoram32_le_w)
@@ -208,17 +243,17 @@ static ADDRESS_MAP_START( namcofl_mem, ADDRESS_SPACE_PROGRAM, 32 )
 ADDRESS_MAP_END
 
 static INPUT_PORTS_START( namcofl )
-	PORT_START
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_UNKNOWN )
-	PORT_BIT(0x04, IP_ACTIVE_HIGH, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_TOGGLE PORT_CODE(KEYCODE_F2)
+	PORT_SERVICE( 0x04, IP_ACTIVE_HIGH )
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_SERVICE1 )
 	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )	// C75 status
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_UNKNOWN )
@@ -228,7 +263,7 @@ static INPUT_PORTS_START( namcofl )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_BUTTON2 )	// button B
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_START1 )
 
-	PORT_START
+	PORT_START("IN2")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_UNKNOWN )
@@ -238,7 +273,7 @@ static INPUT_PORTS_START( namcofl )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_UNKNOWN )
@@ -248,13 +283,13 @@ static INPUT_PORTS_START( namcofl )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("ACCEL")
 	PORT_BIT( 0xff, 0x00, IPT_PEDAL ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10)
 
-	PORT_START
+	PORT_START("BRAKE")
 	PORT_BIT( 0xff, 0x00, IPT_PEDAL2 ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10)
 
-	PORT_START
+	PORT_START("WHEEL")
 	PORT_BIT( 0xff, 0x80, IPT_PADDLE ) PORT_SENSITIVITY(100) PORT_KEYDELTA(10)
 INPUT_PORTS_END
 
@@ -307,64 +342,63 @@ static const gfx_layout roz_layout =
 static GFXDECODE_START( 2 )
 	GFXDECODE_ENTRY( NAMCONB1_TILEGFXREGION,	0, tile_layout,	0x1000, 0x08 )
 	GFXDECODE_ENTRY( NAMCONB1_SPRITEGFXREGION,	0, obj_layout,		0x0000, 0x10 )
-	GFXDECODE_ENTRY( NAMCONB1_ROTGFXREGION,	0, roz_layout,		0x1800, 0x08 )
+	GFXDECODE_ENTRY( NAMCONB1_ROTGFXREGION,	    0, roz_layout,		0x1800, 0x08 )
 GFXDECODE_END
 
 
 static TIMER_CALLBACK( network_interrupt_callback )
 {
-	cpunum_set_input_line(machine, 0, I960_IRQ0, ASSERT_LINE);
-	timer_set(video_screen_get_frame_period(0), NULL, 0, network_interrupt_callback);
+	cpu_set_input_line(machine->cpu[0], I960_IRQ0, ASSERT_LINE);
+	timer_set(machine, video_screen_get_frame_period(machine->primary_screen), NULL, 0, network_interrupt_callback);
 }
 
 
 static TIMER_CALLBACK( vblank_interrupt_callback )
 {
-	cpunum_set_input_line(machine, 0, I960_IRQ2, ASSERT_LINE);
-	timer_set(video_screen_get_frame_period(0), NULL, 0, vblank_interrupt_callback);
+	cpu_set_input_line(machine->cpu[0], I960_IRQ2, ASSERT_LINE);
+	timer_set(machine, video_screen_get_frame_period(machine->primary_screen), NULL, 0, vblank_interrupt_callback);
 }
 
 
 static TIMER_CALLBACK( raster_interrupt_callback )
 {
-	video_screen_update_partial(0, video_screen_get_vpos(0));
-	cpunum_set_input_line(machine, 0, I960_IRQ1, ASSERT_LINE);
-	timer_adjust(raster_interrupt_timer, video_screen_get_frame_period(0), 0, attotime_zero);
+	video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
+	cpu_set_input_line(machine->cpu[0], I960_IRQ1, ASSERT_LINE);
+	timer_adjust_oneshot(raster_interrupt_timer, video_screen_get_frame_period(machine->primary_screen), 0);
 }
 
 
 static MACHINE_START( namcofl )
 {
-	raster_interrupt_timer = timer_alloc(raster_interrupt_callback, NULL);
+	raster_interrupt_timer = timer_alloc(machine, raster_interrupt_callback, NULL);
 }
 
 
 static MACHINE_RESET( namcofl )
 {
-	timer_set(video_screen_get_time_until_pos(0, machine->screen[0].visarea.max_y + 3, 0), NULL, 0, network_interrupt_callback);
-	timer_set(video_screen_get_time_until_pos(0, machine->screen[0].visarea.max_y + 1, 0), NULL, 0, vblank_interrupt_callback);
+	timer_set(machine, video_screen_get_time_until_pos(machine->primary_screen, video_screen_get_visible_area(machine->primary_screen)->max_y + 3, 0), NULL, 0, network_interrupt_callback);
+	timer_set(machine, video_screen_get_time_until_pos(machine->primary_screen, video_screen_get_visible_area(machine->primary_screen)->max_y + 1, 0), NULL, 0, vblank_interrupt_callback);
 }
 
 
 
-NAMCO_C7X_HARDWARE
-
 static MACHINE_DRIVER_START( namcofl )
-	MDRV_CPU_ADD(I960, 20000000)	// i80960KA-20 == 20 MHz part
+	MDRV_CPU_ADD("main", I960, 20000000)	// i80960KA-20 == 20 MHz part
 	MDRV_CPU_PROGRAM_MAP(namcofl_mem, 0)
 
 	NAMCO_C7X_MCU_SHARED( 16384000 )
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-
 	MDRV_MACHINE_START(namcofl)
 	MDRV_MACHINE_RESET(namcofl)
 	MDRV_NVRAM_HANDLER(generic_1fill)
 
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB15)
+
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_SIZE(NAMCONB1_HTOTAL, NAMCONB1_VTOTAL)
 	MDRV_SCREEN_VISIBLE_AREA(0, NAMCONB1_HBSTART-1, 0, NAMCONB1_VBSTART-1)
+
 	MDRV_PALETTE_LENGTH(8192)
 
 	MDRV_GFXDECODE(2)
@@ -376,11 +410,11 @@ static MACHINE_DRIVER_START( namcofl )
 MACHINE_DRIVER_END
 
 ROM_START( speedrcr )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 ) // i960 program
+	ROM_REGION( 0x200000, "main", 0 ) // i960 program
 	ROM_LOAD32_WORD("se2mpea4.19a",   0x000000, 0x080000, CRC(95ab3fd7) SHA1(273a536f8512f3c55260ac1b78533bc35b8390ed) )
 	ROM_LOAD32_WORD("se2mpoa4.18a",   0x000002, 0x080000, CRC(5b5ef1eb) SHA1(3e9e4abb1a32269baef772079de825dfe1ea230c) )
 
-	ROM_REGION( 0x200000, REGION_USER1, 0 ) // Data
+	ROM_REGION( 0x200000, "user1", 0 ) // Data
 	ROM_LOAD32_BYTE("se1_dat0.13a",   0x000000, 0x080000, CRC(cc5d6ff5) SHA1(6fad40a1fac75bc64d3b7a7562cf7ce2a3abd36a) )
 	ROM_LOAD32_BYTE("se1_dat1.14a",   0x000001, 0x080000, CRC(ddc8b306) SHA1(f169d521b800c108deffdef9fc6b0058621ee909) )
 	ROM_LOAD32_BYTE("se1_dat2.15a",   0x000002, 0x080000, CRC(2a29abbb) SHA1(945419ed61e9a656a340214a63a01818396fbe98) )
@@ -408,20 +442,27 @@ ROM_START( speedrcr )
 	ROM_REGION( 0x100000, NAMCONB1_TILEMASKREGION, 0 ) // "SSHAPE" (mask for other tiles?)
 	ROM_LOAD("se1_ssh.18u",    0x000000, 0x100000, CRC(7a8e0bda) SHA1(f6a508d90274d0205fec0c46f5f783a2715c0c6e) )
 
-	ROM_REGION( 0x100000, REGION_USER4, 0 ) /* sound data and MCU BIOS */
+	ROM_REGION( 0x100000, "c7x", 0 ) /* sound data and MCU BIOS */
 	ROM_LOAD("se1_spr.21l",   0x000000,  0x80000, CRC(850a27ac) SHA1(7d5db840ec67659a1f2e69a62cdb03ce6ee0b47b) )
 	NAMCO_C7X_BIOS
 
-	ROM_REGION( 0x400000, REGION_SOUND1, 0 ) // Samples
+	ROM_REGION( 0x400000, "c352", 0 ) // Samples
 	ROM_LOAD("se1_voi.23s",   0x000000, 0x400000, CRC(b95e2ffb) SHA1(7669232d772caa9afa4c7593d018e8b6e534114a) )
+
+    ROM_REGION( 0x000005, "pals", 0) /* PAL's */
+    ROM_LOAD( "sysfl-1.bin",  0x000000, 0x000001, NO_DUMP ) /* PAL16L8BCN at 2S */
+    ROM_LOAD( "sysfl-2.bin",  0x000000, 0x000001, NO_DUMP ) /* PAL16L8BCN at 3L */
+    ROM_LOAD( "sysfl-3.bin",  0x000000, 0x000001, NO_DUMP ) /* PALCE16V8H-15PC/4 at 12S */
+    ROM_LOAD( "sysfl-4.bin",  0x000000, 0x000001, NO_DUMP ) /* PAL20L8BCNS at 20N */
+    ROM_LOAD( "sysfl-5.bin",  0x000000, 0x000001, NO_DUMP ) /* PALCE16V8H-15PC/4 at 19D */
 ROM_END
 
 ROM_START( finalapb )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 ) // i960 program
+	ROM_REGION( 0x200000, "main", 0 ) // i960 program
 	ROM_LOAD32_WORD("flr2mpeb.19a",   0x000000, 0x080000, CRC(8bfe615f) SHA1(7b867eb261268a83177f1f873689f77d1b6c47ca) )
 	ROM_LOAD32_WORD("flr2mpob.18a",   0x000002, 0x080000, CRC(91c14e4f) SHA1(934a86daaef0e3e2c2b3066f4677ccb3aaab6eaf) )
 
-	ROM_REGION( 0x200000, REGION_USER1, ROMREGION_ERASEFF ) // Data
+	ROM_REGION( 0x200000, "user1", ROMREGION_ERASEFF ) // Data
 
 	ROM_REGION( 0x200000, NAMCONB1_ROTGFXREGION, 0 )	// "RCHAR" (roz characters)
 	ROM_LOAD("flr1rch0.19j",   0x000000, 0x100000, CRC(f413f50d) SHA1(cdd8073dda4feaea78e3b94520cf20a9799fd04d) )
@@ -445,20 +486,20 @@ ROM_START( finalapb )
 	ROM_REGION( 0x80000, NAMCONB1_TILEMASKREGION, 0 ) // "SSHAPE" (mask for other tiles?)
 	ROM_LOAD("flr1ssh.18u",    0x000000, 0x080000, CRC(f70cb2bf) SHA1(dbddda822287783a43415172b81d0382a8ac43d8) )
 
-	ROM_REGION( 0x100000, REGION_USER4, 0 ) /* sound data and MCU BIOS */
+	ROM_REGION( 0x100000, "c7x", 0 ) /* sound data and MCU BIOS */
 	ROM_LOAD("flr1spr.21l",   0x000000,  0x20000, CRC(69bb0f5e) SHA1(6831d618de42a165e508ad37db594d3aa290c530) )
 	NAMCO_C7X_BIOS
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 ) // Samples
+	ROM_REGION( 0x200000, "c352", 0 ) // Samples
 	ROM_LOAD("flr1voi.23s",   0x000000, 0x200000, CRC(ff6077cd) SHA1(73c289125ddeae3e43153e4c570549ca04501262) )
 ROM_END
 
 ROM_START( finalapo )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 ) // i960 program
+	ROM_REGION( 0x200000, "main", 0 ) // i960 program
 	ROM_LOAD32_WORD("flr2mpe.19a",   0x000000, 0x080000, CRC(cc8961ae) SHA1(08ce4d27a723101370d1c536b26256ce0d8a1b6c) )
 	ROM_LOAD32_WORD("flr2mpo.18a",   0x000002, 0x080000, CRC(8118f465) SHA1(c4b79878a82fd36b5707e92aa893f69c2b942d57) )
 
-	ROM_REGION( 0x200000, REGION_USER1, ROMREGION_ERASEFF ) // Data
+	ROM_REGION( 0x200000, "user1", ROMREGION_ERASEFF ) // Data
 
 	ROM_REGION( 0x200000, NAMCONB1_ROTGFXREGION, 0 )	// "RCHAR" (roz characters)
 	ROM_LOAD("flr1rch0.19j",   0x000000, 0x100000, CRC(f413f50d) SHA1(cdd8073dda4feaea78e3b94520cf20a9799fd04d) )
@@ -482,20 +523,20 @@ ROM_START( finalapo )
 	ROM_REGION( 0x80000, NAMCONB1_TILEMASKREGION, 0 ) // "SSHAPE" (mask for other tiles?)
 	ROM_LOAD("flr1ssh.18u",    0x000000, 0x080000, CRC(f70cb2bf) SHA1(dbddda822287783a43415172b81d0382a8ac43d8) )
 
-	ROM_REGION( 0x100000, REGION_USER4, 0 ) /* sound data and MCU BIOS */
+	ROM_REGION( 0x100000, "c7x", 0 ) /* sound data and MCU BIOS */
 	ROM_LOAD("flr1spr.21l",   0x000000,  0x20000, CRC(69bb0f5e) SHA1(6831d618de42a165e508ad37db594d3aa290c530) )
 	NAMCO_C7X_BIOS
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 ) // Samples
+	ROM_REGION( 0x200000, "c352", 0 ) // Samples
 	ROM_LOAD("flr1voi.23s",   0x000000, 0x200000, CRC(ff6077cd) SHA1(73c289125ddeae3e43153e4c570549ca04501262) )
 ROM_END
 
 ROM_START( finalapr )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 ) // i960 program
+	ROM_REGION( 0x200000, "main", 0 ) // i960 program
         ROM_LOAD32_WORD("flr1_mpec.19a", 0x000000, 0x080000, CRC(52735494) SHA1(db9873cb39bcfdd3dbe2e5079249fecac2c46df9) )
         ROM_LOAD32_WORD("flr1_mpoc.18a", 0x000002, 0x080000, CRC(b11fe577) SHA1(70b51a1e66a3bb92f027aad7ba0f358c0e139b3c) )
 
-	ROM_REGION( 0x200000, REGION_USER1, ROMREGION_ERASEFF ) // Data
+	ROM_REGION( 0x200000, "user1", ROMREGION_ERASEFF ) // Data
 
 	ROM_REGION( 0x200000, NAMCONB1_ROTGFXREGION, 0 )	// "RCHAR" (roz characters)
 	ROM_LOAD("flr1rch0.19j",   0x000000, 0x100000, CRC(f413f50d) SHA1(cdd8073dda4feaea78e3b94520cf20a9799fd04d) )
@@ -519,34 +560,34 @@ ROM_START( finalapr )
 	ROM_REGION( 0x80000, NAMCONB1_TILEMASKREGION, 0 ) // "SSHAPE" (mask for other tiles?)
 	ROM_LOAD("flr1ssh.18u",    0x000000, 0x080000, CRC(f70cb2bf) SHA1(dbddda822287783a43415172b81d0382a8ac43d8) )
 
-	ROM_REGION( 0x100000, REGION_USER4, 0 ) /* sound data and MCU BIOS */
+	ROM_REGION( 0x100000, "c7x", 0 ) /* sound data and MCU BIOS */
 	ROM_LOAD("flr1spr.21l",   0x000000,  0x20000, CRC(69bb0f5e) SHA1(6831d618de42a165e508ad37db594d3aa290c530) )
 	NAMCO_C7X_BIOS
 
-	ROM_REGION( 0x200000, REGION_SOUND1, 0 ) // Samples
+	ROM_REGION( 0x200000, "c352", 0 ) // Samples
 	ROM_LOAD("flr1voi.23s",   0x000000, 0x200000, CRC(ff6077cd) SHA1(73c289125ddeae3e43153e4c570549ca04501262) )
 ROM_END
 
-static void namcofl_common_init(void)
+static void namcofl_common_init(running_machine *machine)
 {
 	namcofl_workram = auto_malloc(0x100000);
 
-	memory_set_bankptr( 1, memory_region(REGION_CPU1) );
-	memory_set_bankptr( 2, namcofl_workram );
+	memory_set_bankptr(machine,  1, memory_region(machine, "main") );
+	memory_set_bankptr(machine,  2, namcofl_workram );
 
-	namcoc7x_on_driver_init();
+	namcoc7x_on_driver_init(machine);
 	namcoc7x_set_host_ram(namcofl_mcuram);
 }
 
 static DRIVER_INIT(speedrcr)
 {
-	namcofl_common_init();
+	namcofl_common_init(machine);
 	namcos2_gametype = NAMCOFL_SPEED_RACER;
 }
 
 static DRIVER_INIT(finalapr)
 {
-	namcofl_common_init();
+	namcofl_common_init(machine);
 	namcos2_gametype = NAMCOFL_FINAL_LAP_R;
 }
 
