@@ -80,7 +80,7 @@
 ****************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/m68000/m68000.h"
 #include "neogeo.h"
 #include "machine/pd4990a.h"
 #include "cpu/z80/z80.h"
@@ -141,7 +141,7 @@ static UINT8 led2_value;
  *************************************/
 
 static void calendar_clock(void);
-static void set_output_latch(UINT8 data);
+static void set_output_latch(running_machine *machine, UINT8 data);
 static void set_output_data(UINT8 data);
 
 
@@ -158,14 +158,14 @@ static void set_output_data(UINT8 data);
 #define IRQ2CTRL_AUTOLOAD_REPEAT	(0x80)
 
 
-static void adjust_display_position_interrupt_timer(void)
+static void adjust_display_position_interrupt_timer(running_machine *machine)
 {
 	if ((display_counter + 1) != 0)
 	{
 		attotime period = attotime_mul(ATTOTIME_IN_HZ(NEOGEO_PIXEL_CLOCK), display_counter + 1);
-		if (LOG_VIDEO_SYSTEM) logerror("adjust_display_position_interrupt_timer  current y: %02x  current x: %02x   target y: %x  target x: %x\n", video_screen_get_vpos(0), video_screen_get_hpos(0), (display_counter + 1) / NEOGEO_HTOTAL, (display_counter + 1) % NEOGEO_HTOTAL);
+		if (LOG_VIDEO_SYSTEM) logerror("adjust_display_position_interrupt_timer  current y: %02x  current x: %02x   target y: %x  target x: %x\n", video_screen_get_vpos(machine->primary_screen), video_screen_get_hpos(machine->primary_screen), (display_counter + 1) / NEOGEO_HTOTAL, (display_counter + 1) % NEOGEO_HTOTAL);
 
-		timer_adjust(display_position_interrupt_timer, period, 0, attotime_zero);
+		timer_adjust_oneshot(display_position_interrupt_timer, period, 0);
 	}
 }
 
@@ -176,61 +176,52 @@ void neogeo_set_display_position_interrupt_control(UINT16 data)
 }
 
 
-void neogeo_set_display_counter_msb(UINT16 data)
+void neogeo_set_display_counter_msb(const address_space *space, UINT16 data)
 {
 	display_counter = (display_counter & 0x0000ffff) | ((UINT32)data << 16);
 
-	if (LOG_VIDEO_SYSTEM) logerror("PC %06x: set_display_counter %08x\n", activecpu_get_pc(), display_counter);
+	if (LOG_VIDEO_SYSTEM) logerror("PC %06x: set_display_counter %08x\n", cpu_get_pc(space->cpu), display_counter);
 }
 
 
-void neogeo_set_display_counter_lsb(UINT16 data)
+void neogeo_set_display_counter_lsb(const address_space *space, UINT16 data)
 {
 	display_counter = (display_counter & 0xffff0000) | data;
 
-	if (LOG_VIDEO_SYSTEM) logerror("PC %06x: set_display_counter %08x\n", activecpu_get_pc(), display_counter);
+	if (LOG_VIDEO_SYSTEM) logerror("PC %06x: set_display_counter %08x\n", cpu_get_pc(space->cpu), display_counter);
 
 	if (display_position_interrupt_control & IRQ2CTRL_LOAD_RELATIVE)
 	{
 		if (LOG_VIDEO_SYSTEM) logerror("AUTOLOAD_RELATIVE ");
- 		adjust_display_position_interrupt_timer();
+ 		adjust_display_position_interrupt_timer(space->machine);
 	}
 }
 
 
 static void update_interrupts(running_machine *machine)
 {
-	int level = 0;
-
-	/* determine which interrupt is active - order implies priority */
-	if (vblank_interrupt_pending) level = 1;
-	if (display_position_interrupt_pending) level = 2;
-	if (irq3_pending) level = 3;
-
-	/* either set or clear the appropriate lines */
-	if (level)
-		cpunum_set_input_line(machine, 0, level, ASSERT_LINE);
-	else
-		cpunum_set_input_line(machine, 0, 7, CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], 1, vblank_interrupt_pending ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], 2, display_position_interrupt_pending ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], 3, irq3_pending ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
-void neogeo_acknowledge_interrupt(UINT16 data)
+void neogeo_acknowledge_interrupt(running_machine *machine, UINT16 data)
 {
 	if (data & 0x01) irq3_pending = 0;
 	if (data & 0x02) display_position_interrupt_pending = 0;
 	if (data & 0x04) vblank_interrupt_pending = 0;
 
-	update_interrupts(Machine);
+	update_interrupts(machine);
 }
 
 
 static TIMER_CALLBACK( display_position_interrupt_callback )
 {
-	if (LOG_VIDEO_SYSTEM) logerror("--- Scanline @ %d,%d\n", video_screen_get_vpos(0), video_screen_get_hpos(0));
+	if (LOG_VIDEO_SYSTEM) logerror("--- Scanline @ %d,%d\n", video_screen_get_vpos(machine->primary_screen), video_screen_get_hpos(machine->primary_screen));
 	if (display_position_interrupt_control & IRQ2CTRL_ENABLE)
 	{
-		if (LOG_VIDEO_SYSTEM) logerror("*** Scanline interrupt (IRQ2) ***  y: %02x  x: %02x\n", video_screen_get_vpos(0), video_screen_get_hpos(0));
+		if (LOG_VIDEO_SYSTEM) logerror("*** Scanline interrupt (IRQ2) ***  y: %02x  x: %02x\n", video_screen_get_vpos(machine->primary_screen), video_screen_get_hpos(machine->primary_screen));
 		display_position_interrupt_pending = 1;
 
 		update_interrupts(machine);
@@ -239,7 +230,7 @@ static TIMER_CALLBACK( display_position_interrupt_callback )
 	if (display_position_interrupt_control & IRQ2CTRL_AUTOLOAD_REPEAT)
 	{
 		if (LOG_VIDEO_SYSTEM) logerror("AUTOLOAD_REPEAT ");
-		adjust_display_position_interrupt_timer();
+		adjust_display_position_interrupt_timer(machine);
 	}
 }
 
@@ -249,17 +240,17 @@ static TIMER_CALLBACK( display_position_vblank_callback )
 	if (display_position_interrupt_control & IRQ2CTRL_AUTOLOAD_VBLANK)
 	{
 		if (LOG_VIDEO_SYSTEM) logerror("AUTOLOAD_VBLANK ");
-		adjust_display_position_interrupt_timer();
+		adjust_display_position_interrupt_timer(machine);
 	}
 
 	/* set timer for next screen */
-	timer_adjust(display_position_vblank_timer, video_screen_get_time_until_pos(0, NEOGEO_VBSTART, NEOGEO_VBLANK_RELOAD_HPOS), 0, attotime_zero);
+	timer_adjust_oneshot(display_position_vblank_timer, video_screen_get_time_until_pos(machine->primary_screen, NEOGEO_VBSTART, NEOGEO_VBLANK_RELOAD_HPOS), 0);
 }
 
 
 static TIMER_CALLBACK( vblank_interrupt_callback )
 {
-	if (LOG_VIDEO_SYSTEM) logerror("+++ VBLANK @ %d,%d\n", video_screen_get_vpos(0), video_screen_get_hpos(0));
+	if (LOG_VIDEO_SYSTEM) logerror("+++ VBLANK @ %d,%d\n", video_screen_get_vpos(machine->primary_screen), video_screen_get_hpos(machine->primary_screen));
 
 	/* add a timer tick to the pd4990a */
 	calendar_clock();
@@ -269,22 +260,22 @@ static TIMER_CALLBACK( vblank_interrupt_callback )
 	update_interrupts(machine);
 
 	/* set timer for next screen */
-	timer_adjust(vblank_interrupt_timer, video_screen_get_time_until_pos(0, NEOGEO_VBSTART, 0), 0, attotime_zero);
+	timer_adjust_oneshot(vblank_interrupt_timer, video_screen_get_time_until_pos(machine->primary_screen, NEOGEO_VBSTART, 0), 0);
 }
 
 
-static void create_interrupt_timers(void)
+static void create_interrupt_timers(running_machine *machine)
 {
-	display_position_interrupt_timer = timer_alloc(display_position_interrupt_callback, NULL);
-	display_position_vblank_timer = timer_alloc(display_position_vblank_callback, NULL);
-	vblank_interrupt_timer = timer_alloc(vblank_interrupt_callback, NULL);
+	display_position_interrupt_timer = timer_alloc(machine, display_position_interrupt_callback, NULL);
+	display_position_vblank_timer = timer_alloc(machine, display_position_vblank_callback, NULL);
+	vblank_interrupt_timer = timer_alloc(machine, vblank_interrupt_callback, NULL);
 }
 
 
-static void start_interrupt_timers(void)
+static void start_interrupt_timers(running_machine *machine)
 {
-	timer_adjust(vblank_interrupt_timer, video_screen_get_time_until_pos(0, NEOGEO_VBSTART, 0), 0, attotime_zero);
-	timer_adjust(display_position_vblank_timer, video_screen_get_time_until_pos(0, NEOGEO_VBSTART, NEOGEO_VBLANK_RELOAD_HPOS), 0, attotime_zero);
+	timer_adjust_oneshot(vblank_interrupt_timer, video_screen_get_time_until_pos(machine->primary_screen, NEOGEO_VBSTART, 0), 0);
+	timer_adjust_oneshot(display_position_vblank_timer, video_screen_get_time_until_pos(machine->primary_screen, NEOGEO_VBSTART, NEOGEO_VBLANK_RELOAD_HPOS), 0);
 }
 
 
@@ -295,21 +286,21 @@ static void start_interrupt_timers(void)
  *
  *************************************/
 
-static void audio_cpu_irq(int assert)
+static void audio_cpu_irq(running_machine *machine, int assert)
 {
-	cpunum_set_input_line(Machine, 1, 0, assert ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[1], 0, assert ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
-static void audio_cpu_assert_nmi(void)
+static void audio_cpu_assert_nmi(running_machine *machine)
 {
-	cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[1], INPUT_LINE_NMI, ASSERT_LINE);
 }
 
 
 static WRITE8_HANDLER( audio_cpu_clear_nmi_w )
 {
-	cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_NMI, CLEAR_LINE);
 }
 
 
@@ -328,11 +319,11 @@ static void select_controller(UINT8 data)
 
 static CUSTOM_INPUT( multiplexed_controller_r )
 {
-	char tag[6];
+	char tag[40];
 
 	sprintf(tag, "IN%s-%d", (const char *)param, controller_select & 0x01);
 
-	return readinputportbytag(tag);
+	return input_port_read(field->port->machine, tag);
 }
 
 
@@ -351,10 +342,10 @@ cpu #0 (PC=00C18C40): unmapped memory word write to 00380000 = 0000 & 00FF
 	{
 	default:
 	case 0x00: ret = 0x0000; break; /* nothing? */
-	case 0x09: ret = readinputportbytag("MAHJONG1"); break;
-	case 0x12: ret = readinputportbytag("MAHJONG2"); break;
-	case 0x1b: ret = readinputportbytag("MAHJONG3"); break; /* player 1 normal inputs? */
-	case 0x24: ret = readinputportbytag("MAHJONG4"); break;
+	case 0x09: ret = input_port_read(field->port->machine, "MAHJONG1"); break;
+	case 0x12: ret = input_port_read(field->port->machine, "MAHJONG2"); break;
+	case 0x1b: ret = input_port_read(field->port->machine, "MAHJONG3"); break; /* player 1 normal inputs? */
+	case 0x24: ret = input_port_read(field->port->machine, "MAHJONG4"); break;
 	}
 
 	return ret;
@@ -366,16 +357,16 @@ static WRITE16_HANDLER( io_control_w )
 	switch (offset)
 	{
 	case 0x00: select_controller(data & 0x00ff); break;
-	case 0x18: set_output_latch(data & 0x00ff); break;
+	case 0x18: set_output_latch(space->machine, data & 0x00ff); break;
 	case 0x20: set_output_data(data & 0x00ff); break;
-	case 0x28: pd4990a_control_16_w(0, data, mem_mask); break;
+	case 0x28: pd4990a_control_16_w(space, 0, data, mem_mask); break;
 //  case 0x30: break; // coin counters
 //  case 0x31: break; // coin counters
 //  case 0x32: break; // coin lockout
 //  case 0x33: break; // coui lockout
 
 	default:
-		logerror("PC: %x  Unmapped I/O control write.  Offset: %x  Data: %x\n", activecpu_get_pc(), offset, data);
+		logerror("PC: %x  Unmapped I/O control write.  Offset: %x  Data: %x\n", cpu_get_pc(space->cpu), offset, data);
 		break;
 	}
 }
@@ -402,7 +393,7 @@ READ16_HANDLER( neogeo_unmapped_r )
 	else
 	{
 		recurse = 1;
-		ret = program_read_word(activecpu_get_pc());
+		ret = memory_read_word(space, cpu_get_pc(space->cpu));
 		recurse = 0;
 	}
 
@@ -444,7 +435,8 @@ static void calendar_clock(void)
 
 static CUSTOM_INPUT( get_calendar_status )
 {
-	return (pd4990a_databit_r(0) << 1) | pd4990a_testbit_r(0);
+	const address_space *space = cpu_get_address_space(field->port->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	return (pd4990a_databit_r(space, 0) << 1) | pd4990a_testbit_r(space, 0);
 }
 
 
@@ -524,7 +516,7 @@ static READ16_HANDLER( memcard_r )
 
 static WRITE16_HANDLER( memcard_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		if (memcard_present() != -1)
 			memcard_data[offset] = data;
@@ -562,28 +554,28 @@ static MEMCARD_HANDLER( neogeo )
 static WRITE16_HANDLER( audio_command_w )
 {
 	/* accessing the LSB only is not mapped */
-	if (mem_mask != 0xff00)
+	if (mem_mask != 0x00ff)
 	{
-		soundlatch_w(0, data >> 8);
+		soundlatch_w(space, 0, data >> 8);
 
-		audio_cpu_assert_nmi();
+		audio_cpu_assert_nmi(space->machine);
 
 		/* boost the interleave to let the audio CPU read the command */
-		cpu_boost_interleave(attotime_zero, ATTOTIME_IN_USEC(50));
+		cpuexec_boost_interleave(space->machine, attotime_zero, ATTOTIME_IN_USEC(50));
 
-		if (LOG_CPU_COMM) logerror("MAIN CPU PC %06x: audio_command_w %04x - %04x\n", activecpu_get_pc(), data, mem_mask);
+		if (LOG_CPU_COMM) logerror("MAIN CPU PC %06x: audio_command_w %04x - %04x\n", cpu_get_pc(space->cpu), data, mem_mask);
 	}
 }
 
 
 static READ8_HANDLER( audio_command_r )
 {
-	UINT8 ret = soundlatch_r(0);
+	UINT8 ret = soundlatch_r(space, 0);
 
-	if (LOG_CPU_COMM) logerror(" AUD CPU PC   %04x: audio_command_r %02x\n", activecpu_get_pc(), ret);
+	if (LOG_CPU_COMM) logerror(" AUD CPU PC   %04x: audio_command_r %02x\n", cpu_get_pc(space->cpu), ret);
 
 	/* this is a guess */
-	audio_cpu_clear_nmi_w(0, 0);
+	audio_cpu_clear_nmi_w(space, 0, 0);
 
 	return ret;
 }
@@ -591,7 +583,7 @@ static READ8_HANDLER( audio_command_r )
 
 static WRITE8_HANDLER( audio_result_w )
 {
-	if (LOG_CPU_COMM && (audio_result != data)) logerror(" AUD CPU PC   %04x: audio_result_w %02x\n", activecpu_get_pc(), data);
+	if (LOG_CPU_COMM && (audio_result != data)) logerror(" AUD CPU PC   %04x: audio_result_w %02x\n", cpu_get_pc(space->cpu), data);
 
 	audio_result = data;
 }
@@ -601,7 +593,7 @@ static CUSTOM_INPUT( get_audio_result )
 {
 	UINT32 ret = audio_result;
 
-//  if (LOG_CPU_COMM && (cpu_getactivecpu() >= 0)) logerror("MAIN CPU PC %06x: audio_result_r %02x\n", activecpu_get_pc(), ret);
+//  if (LOG_CPU_COMM) logerror("MAIN CPU PC %06x: audio_result_r %02x\n", cpu_get_pc(field->port->machine->cpu[0]), ret);
 
 	return ret;
 }
@@ -614,68 +606,71 @@ static CUSTOM_INPUT( get_audio_result )
  *
  *************************************/
 
-static void _set_main_cpu_vector_table_source(void)
+static void _set_main_cpu_vector_table_source(running_machine *machine)
 {
-	memory_set_bank(NEOGEO_BANK_VECTORS, main_cpu_vector_table_source);
+	memory_set_bank(machine, NEOGEO_BANK_VECTORS, main_cpu_vector_table_source);
 }
 
 
-static void set_main_cpu_vector_table_source(UINT8 data)
+static void set_main_cpu_vector_table_source(running_machine *machine, UINT8 data)
 {
 	main_cpu_vector_table_source = data;
 
-	_set_main_cpu_vector_table_source();
+	_set_main_cpu_vector_table_source(machine);
 }
 
 
-static void _set_main_cpu_bank_address(void)
+static void _set_main_cpu_bank_address(running_machine *machine)
 {
-	memory_set_bankptr(NEOGEO_BANK_CARTRIDGE, &memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE)[main_cpu_bank_address]);
+	memory_set_bankptr(machine, NEOGEO_BANK_CARTRIDGE, &memory_region(machine, "main")[main_cpu_bank_address]);
 }
 
 
-void neogeo_set_main_cpu_bank_address(UINT32 bank_address)
+void neogeo_set_main_cpu_bank_address(const address_space *space, UINT32 bank_address)
 {
-	if (LOG_MAIN_CPU_BANKING) logerror("MAIN CPU PC %06x: neogeo_set_main_cpu_bank_address %06x\n", safe_activecpu_get_pc(), bank_address);
+	if (LOG_MAIN_CPU_BANKING) logerror("MAIN CPU PC %06x: neogeo_set_main_cpu_bank_address %06x\n", cpu_get_pc(space->cpu), bank_address);
 
 	main_cpu_bank_address = bank_address;
 
-	_set_main_cpu_bank_address();
+	_set_main_cpu_bank_address(space->machine);
 }
 
 
 static WRITE16_HANDLER( main_cpu_bank_select_w )
 {
 	UINT32 bank_address;
+	UINT32 len = memory_region_length(space->machine, "main");
 
-	if ((memory_region_length(NEOGEO_REGION_MAIN_CPU_CARTRIDGE) <= 0x100000) && (data & 0x07))
-		logerror("PC %06x: warning: bankswitch to %02x but no banks available\n", activecpu_get_pc(), data);
+	if ((len <= 0x100000) && (data & 0x07))
+		logerror("PC %06x: warning: bankswitch to %02x but no banks available\n", cpu_get_pc(space->cpu), data);
 	else
 	{
 		bank_address = ((data & 0x07) + 1) * 0x100000;
 
-		if (bank_address >= memory_region_length(NEOGEO_REGION_MAIN_CPU_CARTRIDGE))
+		if (bank_address >= len)
 		{
-			logerror("PC %06x: warning: bankswitch to empty bank %02x\n", activecpu_get_pc(), data);
+			logerror("PC %06x: warning: bankswitch to empty bank %02x\n", cpu_get_pc(space->cpu), data);
 			bank_address = 0x100000;
 		}
 
-		neogeo_set_main_cpu_bank_address(bank_address);
+		neogeo_set_main_cpu_bank_address(space, bank_address);
 	}
 }
 
 
-static void main_cpu_banking_init(void)
+static void main_cpu_banking_init(running_machine *machine)
 {
+	const address_space *mainspace = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 	/* create vector banks */
-	memory_configure_bank(NEOGEO_BANK_VECTORS, 0, 1, memory_region(NEOGEO_REGION_MAIN_CPU_BIOS), 0);
-	memory_configure_bank(NEOGEO_BANK_VECTORS, 1, 1, memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE), 0);
+	memory_configure_bank(machine, NEOGEO_BANK_VECTORS, 0, 1, memory_region(machine, "mainbios"), 0);
+	memory_configure_bank(machine, NEOGEO_BANK_VECTORS, 1, 1, memory_region(machine, "main"), 0);
 
 	/* set initial main CPU bank */
-	if (memory_region_length(NEOGEO_REGION_MAIN_CPU_CARTRIDGE) > 0x100000)
-		neogeo_set_main_cpu_bank_address(0x100000);
+	if (memory_region_length(machine, "main") > 0x100000)
+		neogeo_set_main_cpu_bank_address(mainspace, 0x100000);
 	else
-		neogeo_set_main_cpu_bank_address(0x000000);
+		neogeo_set_main_cpu_bank_address(mainspace, 0x000000);
 }
 
 
@@ -686,28 +681,28 @@ static void main_cpu_banking_init(void)
  *
  *************************************/
 
-static void set_audio_cpu_banking(void)
+static void set_audio_cpu_banking(running_machine *machine)
 {
 	int region;
 
 	for (region = 0; region < 4; region++)
-		memory_set_bank(NEOGEO_BANK_AUDIO_CPU_CART_BANK + region, audio_cpu_banks[region]);
+		memory_set_bank(machine, NEOGEO_BANK_AUDIO_CPU_CART_BANK + region, audio_cpu_banks[region]);
 }
 
 
-static void audio_cpu_bank_select(int region, UINT8 bank)
+static void audio_cpu_bank_select(const address_space *space, int region, UINT8 bank)
 {
-	if (LOG_AUDIO_CPU_BANKING) logerror("Audio CPU PC %03x: audio_cpu_bank_select: Region: %d   Bank: %02x\n", safe_activecpu_get_pc(), region, bank);
+	if (LOG_AUDIO_CPU_BANKING) logerror("Audio CPU PC %03x: audio_cpu_bank_select: Region: %d   Bank: %02x\n", cpu_get_pc(space->cpu), region, bank);
 
 	audio_cpu_banks[region] = bank;
 
-	set_audio_cpu_banking();
+	set_audio_cpu_banking(space->machine);
 }
 
 
 static READ8_HANDLER( audio_cpu_bank_select_f000_f7ff_r )
 {
-	audio_cpu_bank_select(0, offset >> 8);
+	audio_cpu_bank_select(space, 0, offset >> 8);
 
 	return 0;
 }
@@ -715,7 +710,7 @@ static READ8_HANDLER( audio_cpu_bank_select_f000_f7ff_r )
 
 static READ8_HANDLER( audio_cpu_bank_select_e000_efff_r )
 {
-	audio_cpu_bank_select(1, offset >> 8);
+	audio_cpu_bank_select(space, 1, offset >> 8);
 
 	return 0;
 }
@@ -723,7 +718,7 @@ static READ8_HANDLER( audio_cpu_bank_select_e000_efff_r )
 
 static READ8_HANDLER( audio_cpu_bank_select_c000_dfff_r )
 {
-	audio_cpu_bank_select(2, offset >> 8);
+	audio_cpu_bank_select(space, 2, offset >> 8);
 
 	return 0;
 }
@@ -731,59 +726,61 @@ static READ8_HANDLER( audio_cpu_bank_select_c000_dfff_r )
 
 static READ8_HANDLER( audio_cpu_bank_select_8000_bfff_r )
 {
-	audio_cpu_bank_select(3, offset >> 8);
+	audio_cpu_bank_select(space, 3, offset >> 8);
 
 	return 0;
 }
 
 
-static void _set_audio_cpu_rom_source(void)
+static void _set_audio_cpu_rom_source(const address_space *space)
 {
-/*  if (!memory_region(NEOGEO_REGION_AUDIO_CPU_BIOS))   */
+/*  if (!memory_region(machine, "audiobios"))   */
 		audio_cpu_rom_source = 1;
 
-	memory_set_bank(NEOGEO_BANK_AUDIO_CPU_MAIN_BANK, audio_cpu_rom_source);
+	memory_set_bank(space->machine, NEOGEO_BANK_AUDIO_CPU_MAIN_BANK, audio_cpu_rom_source);
 
 	/* reset CPU if the source changed -- this is a guess */
 	if (audio_cpu_rom_source != audio_cpu_rom_source_last)
 	{
 		audio_cpu_rom_source_last = audio_cpu_rom_source;
 
-		cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, PULSE_LINE);
+		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, PULSE_LINE);
 
-		if (LOG_AUDIO_CPU_BANKING) logerror("Audio CPU PC %03x: selectign %s ROM\n", safe_activecpu_get_pc(), audio_cpu_rom_source ? "CARTRIDGE" : "BIOS");
+		if (LOG_AUDIO_CPU_BANKING) logerror("Audio CPU PC %03x: selectign %s ROM\n", cpu_get_pc(space->cpu), audio_cpu_rom_source ? "CARTRIDGE" : "BIOS");
 	}
 }
 
 
-static void set_audio_cpu_rom_source(UINT8 data)
+static void set_audio_cpu_rom_source(const address_space *space, UINT8 data)
 {
 	audio_cpu_rom_source = data;
 
-	_set_audio_cpu_rom_source();
+	_set_audio_cpu_rom_source(space);
 }
 
 
-static void audio_cpu_banking_init(void)
+static void audio_cpu_banking_init(running_machine *machine)
 {
 	int region;
 	int bank;
+	UINT8 *rgn;
 	UINT32 address_mask;
 
 	/* audio bios/cartridge selection */
- 	if (memory_region(NEOGEO_REGION_AUDIO_CPU_BIOS))
-		memory_configure_bank(NEOGEO_BANK_AUDIO_CPU_MAIN_BANK, 0, 1, memory_region(NEOGEO_REGION_AUDIO_CPU_BIOS), 0);
-	memory_configure_bank(NEOGEO_BANK_AUDIO_CPU_MAIN_BANK, 1, 1, memory_region(NEOGEO_REGION_AUDIO_CPU_CARTRIDGE), 0);
+ 	if (memory_region(machine, "audiobios"))
+		memory_configure_bank(machine, NEOGEO_BANK_AUDIO_CPU_MAIN_BANK, 0, 1, memory_region(machine, "audiobios"), 0);
+	memory_configure_bank(machine, NEOGEO_BANK_AUDIO_CPU_MAIN_BANK, 1, 1, memory_region(machine, "audio"), 0);
 
 	/* audio banking */
-	address_mask = memory_region_length(NEOGEO_REGION_AUDIO_CPU_CARTRIDGE) - 0x10000 - 1;
+	address_mask = memory_region_length(machine, "audio") - 0x10000 - 1;
 
+	rgn = memory_region(machine, "audio");
 	for (region = 0; region < 4; region++)
 	{
 		for (bank = 0; bank < 0x100; bank++)
 		{
 			UINT32 bank_address = 0x10000 + (((bank << (11 + region)) & 0x3ffff) & address_mask);
-			memory_configure_bank(NEOGEO_BANK_AUDIO_CPU_CART_BANK + region, bank, 1, &memory_region(NEOGEO_REGION_AUDIO_CPU_CARTRIDGE)[bank_address], 0);
+			memory_configure_bank(machine, NEOGEO_BANK_AUDIO_CPU_CART_BANK + region, bank, 1, &rgn[bank_address], 0);
 		}
 	}
 
@@ -794,10 +791,10 @@ static void audio_cpu_banking_init(void)
 	audio_cpu_banks[2] = 0x06;
 	audio_cpu_banks[3] = 0x02;
 
-	set_audio_cpu_banking();
+	set_audio_cpu_banking(machine);
 
 	audio_cpu_rom_source_last = 0;
-	set_audio_cpu_rom_source(0);
+	set_audio_cpu_rom_source(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0);
 }
 
 
@@ -810,29 +807,29 @@ static void audio_cpu_banking_init(void)
 
 static WRITE16_HANDLER( system_control_w )
 {
-	if ((mem_mask & 0x00ff) != 0x00ff)
+	if (ACCESSING_BITS_0_7)
 	{
 		UINT8 bit = (offset >> 3) & 0x01;
 
 		switch (offset & 0x07)
 		{
 		default:
-		case 0x00: neogeo_set_screen_dark(bit); break;
-		case 0x01: set_main_cpu_vector_table_source(bit);
-				   set_audio_cpu_rom_source(bit); /* this is a guess */
+		case 0x00: neogeo_set_screen_dark(space->machine, bit); break;
+		case 0x01: set_main_cpu_vector_table_source(space->machine, bit);
+				   set_audio_cpu_rom_source(space, bit); /* this is a guess */
 				   break;
 		case 0x05: neogeo_set_fixed_layer_source(bit); break;
 		case 0x06: set_save_ram_unlock(bit); break;
-		case 0x07: neogeo_set_palette_bank(bit); break;
+		case 0x07: neogeo_set_palette_bank(space->machine, bit); break;
 
 		case 0x02: /* unknown - HC32 middle pin 1 */
 		case 0x03: /* unknown - uPD4990 pin ? */
 		case 0x04: /* unknown - HC32 middle pin 10 */
-			logerror("PC: %x  Unmapped system control write.  Offset: %x  Data: %x\n", safe_activecpu_get_pc(), offset & 0x07, bit);
+			logerror("PC: %x  Unmapped system control write.  Offset: %x  Data: %x\n", cpu_get_pc(space->cpu), offset & 0x07, bit);
 			break;
 		}
 
-		if (LOG_VIDEO_SYSTEM && ((offset & 0x07) != 0x06)) logerror("PC: %x  System control write.  Offset: %x  Data: %x\n", safe_activecpu_get_pc(), offset & 0x07, bit);
+		if (LOG_VIDEO_SYSTEM && ((offset & 0x07) != 0x06)) logerror("PC: %x  System control write.  Offset: %x  Data: %x\n", cpu_get_pc(space->cpu), offset & 0x07, bit);
 	}
 }
 
@@ -875,9 +872,9 @@ static WRITE16_HANDLER( system_control_w )
 static WRITE16_HANDLER( watchdog_w )
 {
 	/* only an LSB write resets the watchdog */
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
-		watchdog_reset16_w(offset, data, mem_mask);
+		watchdog_reset16_w(space, offset, data, mem_mask);
 	}
 }
 
@@ -907,7 +904,7 @@ static void set_outputs(void)
 }
 
 
-static void set_output_latch(UINT8 data)
+static void set_output_latch(running_machine *machine, UINT8 data)
 {
 	/* looks like the LEDs are set on the
        falling edge */
@@ -923,7 +920,7 @@ static void set_output_latch(UINT8 data)
     	led2_value = ~output_data;
 
   	if (falling_bits & 0xc7)
-		logerror("PC: %x  Unmaped LED write.  Data: %x\n", activecpu_get_pc(), falling_bits);
+		logerror("%s  Unmaped LED write.  Data: %x\n", cpuexec_describe_context(machine), falling_bits);
 
 	output_latch = data;
 
@@ -944,18 +941,27 @@ static void set_output_data(UINT8 data)
  *
  *************************************/
 
+static STATE_POSTLOAD( neogeo_postload )
+{
+	_set_main_cpu_bank_address(machine);
+	_set_main_cpu_vector_table_source(machine);
+	set_audio_cpu_banking(machine);
+	_set_audio_cpu_rom_source(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM));
+	set_outputs();
+}
+
 static MACHINE_START( neogeo )
 {
 	/* set the BIOS bank */
-	memory_set_bankptr(NEOGEO_BANK_BIOS, memory_region(NEOGEO_REGION_MAIN_CPU_BIOS));
+	memory_set_bankptr(machine, NEOGEO_BANK_BIOS, memory_region(machine, "mainbios"));
 
 	/* set the initial main CPU bank */
-	main_cpu_banking_init();
+	main_cpu_banking_init(machine);
 
 	/* set the initial audio CPU ROM banks */
-	audio_cpu_banking_init();
+	audio_cpu_banking_init(machine);
 
-	create_interrupt_timers();
+	create_interrupt_timers(machine);
 
 	/* initialize the celander IC to 'right now' */
 	calendar_init(machine);
@@ -967,31 +973,27 @@ static MACHINE_START( neogeo )
 	irq3_pending = 1;
 
 	/* register state save */
-	state_save_register_global(display_position_interrupt_control);
-	state_save_register_global(display_counter);
-	state_save_register_global(vblank_interrupt_pending);
-	state_save_register_global(display_position_interrupt_pending);
-	state_save_register_global(irq3_pending);
-	state_save_register_global(audio_result);
-	state_save_register_global(controller_select);
-	state_save_register_global(main_cpu_bank_address);
-	state_save_register_global(main_cpu_vector_table_source);
-	state_save_register_global_array(audio_cpu_banks);
-	state_save_register_global(audio_cpu_rom_source);
-	state_save_register_global(audio_cpu_rom_source_last);
-	state_save_register_global(save_ram_unlocked);
-	state_save_register_global_pointer(memcard_data, 0x800);
-	state_save_register_global(output_data);
-	state_save_register_global(output_latch);
-	state_save_register_global(el_value);
-	state_save_register_global(led1_value);
-	state_save_register_global(led2_value);
+	state_save_register_global(machine, display_position_interrupt_control);
+	state_save_register_global(machine, display_counter);
+	state_save_register_global(machine, vblank_interrupt_pending);
+	state_save_register_global(machine, display_position_interrupt_pending);
+	state_save_register_global(machine, irq3_pending);
+	state_save_register_global(machine, audio_result);
+	state_save_register_global(machine, controller_select);
+	state_save_register_global(machine, main_cpu_bank_address);
+	state_save_register_global(machine, main_cpu_vector_table_source);
+	state_save_register_global_array(machine, audio_cpu_banks);
+	state_save_register_global(machine, audio_cpu_rom_source);
+	state_save_register_global(machine, audio_cpu_rom_source_last);
+	state_save_register_global(machine, save_ram_unlocked);
+	state_save_register_global_pointer(machine, memcard_data, 0x800);
+	state_save_register_global(machine, output_data);
+	state_save_register_global(machine, output_latch);
+	state_save_register_global(machine, el_value);
+	state_save_register_global(machine, led1_value);
+	state_save_register_global(machine, led2_value);
 
-	state_save_register_func_postload(_set_main_cpu_bank_address);
-	state_save_register_func_postload(_set_main_cpu_vector_table_source);
-	state_save_register_func_postload(set_audio_cpu_banking);
-	state_save_register_func_postload(_set_audio_cpu_rom_source);
-	state_save_register_func_postload(set_outputs);
+	state_save_register_postload(machine, neogeo_postload, NULL);
 }
 
 
@@ -1005,14 +1007,16 @@ static MACHINE_START( neogeo )
 static MACHINE_RESET( neogeo )
 {
 	offs_t offs;
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 
 	/* reset system control registers */
 	for (offs = 0; offs < 8; offs++)
-		system_control_w(offs, 0, 0xff00);
+		system_control_w(space, offs, 0, 0x00ff);
+	device_reset(machine->cpu[0]);
 
 	neogeo_reset_rng();
 
-	start_interrupt_timers();
+	start_interrupt_timers(machine);
 
 	/* trigger the IRQ3 that was set by MACHINE_START */
 	update_interrupts(machine);
@@ -1048,7 +1052,7 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x400000, 0x401fff) AM_MIRROR(0x3fe000) AM_READWRITE(neogeo_paletteram_r, neogeo_paletteram_w)
 	AM_RANGE(0x800000, 0x800fff) AM_READWRITE(memcard_r, memcard_w)
 	AM_RANGE(0xc00000, 0xc1ffff) AM_MIRROR(0x0e0000) AM_ROMBANK(NEOGEO_BANK_BIOS)
-	AM_RANGE(0xd00000, 0xd0ffff) AM_MIRROR(0x0f0000) AM_READWRITE(MRA16_RAM, save_ram_w) AM_BASE(&save_ram)
+	AM_RANGE(0xd00000, 0xd0ffff) AM_MIRROR(0x0f0000) AM_RAM_WRITE(save_ram_w) AM_BASE(&save_ram)
 	AM_RANGE(0xe00000, 0xffffff) AM_READ(neogeo_unmapped_r)
 ADDRESS_MAP_END
 
@@ -1080,15 +1084,15 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( auido_io_map, ADDRESS_SPACE_IO, 8 )
   /*AM_RANGE(0x00, 0x00) AM_MIRROR(0xff00) AM_READWRITE(audio_command_r, audio_cpu_clear_nmi_w);*/  /* may not and NMI clear */
 	AM_RANGE(0x00, 0x00) AM_MIRROR(0xff00) AM_READ(audio_command_r)
-	AM_RANGE(0x04, 0x04) AM_MIRROR(0xff00) AM_READWRITE(YM2610_status_port_0_A_r, YM2610_control_port_0_A_w)
-	AM_RANGE(0x05, 0x05) AM_MIRROR(0xff00) AM_READWRITE(YM2610_read_port_0_r, YM2610_data_port_0_A_w)
-	AM_RANGE(0x06, 0x06) AM_MIRROR(0xff00) AM_READWRITE(YM2610_status_port_0_B_r, YM2610_control_port_0_B_w)
-	AM_RANGE(0x07, 0x07) AM_MIRROR(0xff00) AM_WRITE(YM2610_data_port_0_B_w)
+	AM_RANGE(0x04, 0x04) AM_MIRROR(0xff00) AM_READWRITE(ym2610_status_port_0_a_r, ym2610_control_port_0_a_w)
+	AM_RANGE(0x05, 0x05) AM_MIRROR(0xff00) AM_READWRITE(ym2610_read_port_0_r, ym2610_data_port_0_a_w)
+	AM_RANGE(0x06, 0x06) AM_MIRROR(0xff00) AM_READWRITE(ym2610_status_port_0_b_r, ym2610_control_port_0_b_w)
+	AM_RANGE(0x07, 0x07) AM_MIRROR(0xff00) AM_WRITE(ym2610_data_port_0_b_w)
 	AM_RANGE(0x08, 0x08) AM_MIRROR(0xff00) /* write - NMI enable / acknowledge? (the data written doesn't matter) */
-	AM_SPACE(0x08, 0x0f) AM_READ(audio_cpu_bank_select_f000_f7ff_r)
-	AM_SPACE(0x09, 0x0f) AM_READ(audio_cpu_bank_select_e000_efff_r)
-	AM_SPACE(0x0a, 0x0f) AM_READ(audio_cpu_bank_select_c000_dfff_r)
-	AM_SPACE(0x0b, 0x0f) AM_READ(audio_cpu_bank_select_8000_bfff_r)
+	AM_RANGE(0x08, 0x08) AM_MIRROR(0xfff0) AM_MASK(0xfff0) AM_READ(audio_cpu_bank_select_f000_f7ff_r)
+	AM_RANGE(0x09, 0x09) AM_MIRROR(0xfff0) AM_MASK(0xfff0) AM_READ(audio_cpu_bank_select_e000_efff_r)
+	AM_RANGE(0x0a, 0x0a) AM_MIRROR(0xfff0) AM_MASK(0xfff0) AM_READ(audio_cpu_bank_select_c000_dfff_r)
+	AM_RANGE(0x0b, 0x0b) AM_MIRROR(0xfff0) AM_MASK(0xfff0) AM_READ(audio_cpu_bank_select_8000_bfff_r)
 	AM_RANGE(0x0c, 0x0c) AM_MIRROR(0xff00) AM_WRITE(audio_result_w)
 	AM_RANGE(0x18, 0x18) AM_MIRROR(0xff00) /* write - NMI disable? (the data written doesn't matter) */
 ADDRESS_MAP_END
@@ -1101,11 +1105,9 @@ ADDRESS_MAP_END
  *
  *************************************/
 
-static struct YM2610interface ym2610_interface =
+static ym2610_interface ym2610_config =
 {
-	audio_cpu_irq,
-	-1,	 /* this will be set by DRIVER_INIT */
-	NEOGEO_REGION_AUDIO_DATA_1
+	audio_cpu_irq
 };
 
 
@@ -1142,7 +1144,7 @@ static struct YM2610interface ym2610_interface =
 
 
 #define STANDARD_IN0														\
-	PORT_START_TAG("IN0")													\
+	PORT_START("IN0")													\
 	STANDARD_DIPS															\
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)		\
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)		\
@@ -1155,7 +1157,7 @@ static struct YM2610interface ym2610_interface =
 
 
 #define STANDARD_IN1														\
-	PORT_START_TAG("IN1")													\
+	PORT_START("IN1")														\
 	PORT_BIT( 0x00ff, IP_ACTIVE_LOW, IPT_UNUSED )							\
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(2)		\
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(2)		\
@@ -1168,30 +1170,30 @@ static struct YM2610interface ym2610_interface =
 
 
 #define STANDARD_IN2																				\
-	PORT_START_TAG("IN2")																			\
+	PORT_START("IN2")																				\
 	PORT_BIT( 0x00ff, IP_ACTIVE_LOW, IPT_UNUSED )													\
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_START1 )   												\
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Next Game") PORT_CODE(KEYCODE_7)		\
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_START2 )   												\
 	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Previous Game") PORT_CODE(KEYCODE_8)	\
-	PORT_BIT( 0x7000, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(get_memcard_status, 0)				\
+	PORT_BIT( 0x7000, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(get_memcard_status, NULL)			\
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
 
 #define STANDARD_IN3																				\
-	PORT_START_TAG("IN3")																			\
+	PORT_START("IN3")																				\
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN1 )													\
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_COIN2 )													\
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_SERVICE1 )													\
 	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* having this ACTIVE_HIGH causes you to start with 2 credits using USA bios roms */	\
 	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_UNKNOWN ) /* having this ACTIVE_HIGH causes you to start with 2 credits using USA bios roms */	\
 	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_SPECIAL ) /* what is this? */ 								\
-	PORT_BIT( 0x00c0, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(get_calendar_status, 0)				\
-	PORT_BIT( 0xff00, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(get_audio_result, 0)
+	PORT_BIT( 0x00c0, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(get_calendar_status, NULL)			\
+	PORT_BIT( 0xff00, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(get_audio_result, NULL)
 
 
 #define STANDARD_IN4																			\
-	PORT_START_TAG("IN4")																		\
+	PORT_START("IN4")																			\
 	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_UNKNOWN )												\
 	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_UNKNOWN )												\
 	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_UNKNOWN )												\
@@ -1226,14 +1228,14 @@ INPUT_PORTS_END
 static MACHINE_DRIVER_START( neogeo )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", M68000, NEOGEO_MAIN_CPU_CLOCK)
+	MDRV_CPU_ADD("main", M68000, NEOGEO_MAIN_CPU_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(main_map,0)
 
-	MDRV_CPU_ADD(Z80, NEOGEO_AUDIO_CPU_CLOCK)
+	MDRV_CPU_ADD("audio", Z80, NEOGEO_AUDIO_CPU_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(audio_map,0)
 	MDRV_CPU_IO_MAP(auido_io_map,0)
 
-	MDRV_WATCHDOG_TIME_INIT(ATTOTIME_IN_USEC(128762))
+	MDRV_WATCHDOG_TIME_INIT(USEC(128762))
 
 	MDRV_MACHINE_START(neogeo)
 	MDRV_MACHINE_RESET(neogeo)
@@ -1241,21 +1243,20 @@ static MACHINE_DRIVER_START( neogeo )
 	MDRV_MEMCARD_HANDLER(neogeo)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
 	MDRV_VIDEO_START(neogeo)
 	MDRV_VIDEO_RESET(neogeo)
 	MDRV_VIDEO_UPDATE(neogeo)
 	MDRV_DEFAULT_LAYOUT(layout_neogeo)
 
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_RAW_PARAMS(NEOGEO_PIXEL_CLOCK, NEOGEO_HTOTAL, NEOGEO_HBEND, NEOGEO_HBSTART, NEOGEO_VTOTAL, NEOGEO_VBEND, NEOGEO_VBSTART)
 
 	/* audio hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(YM2610, NEOGEO_YM2610_CLOCK)
-	MDRV_SOUND_CONFIG(ym2610_interface)
+	MDRV_SOUND_ADD("ym", YM2610, NEOGEO_YM2610_CLOCK)
+	MDRV_SOUND_CONFIG(ym2610_config)
 	MDRV_SOUND_ROUTE(0, "left",  0.60)
 	MDRV_SOUND_ROUTE(0, "right", 0.60)
 	MDRV_SOUND_ROUTE(1, "left",  1.0)
@@ -1270,8 +1271,6 @@ MACHINE_DRIVER_END
 
 static DRIVER_INIT( neogeo )
 {
-	/* set the Delta-T sample region */
-	ym2610_interface.pcmromb = memory_region(NEOGEO_REGION_AUDIO_DATA_2) ? NEOGEO_REGION_AUDIO_DATA_2 : NEOGEO_REGION_AUDIO_DATA_1;
 }
 
 
