@@ -62,11 +62,10 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "rescap.h"
-#include "deprecat.h"
+#include "machine/rescap.h"
 #include "machine/6821pia.h"
 #include "machine/74123.h"
-#include "video/crtc6845.h"
+#include "video/mc6845.h"
 #include "cpu/m6800/m6800.h"
 #include "cpu/m6809/m6809.h"
 #include "sound/ay8910.h"
@@ -112,17 +111,17 @@ static WRITE8_HANDLER( audio_2_command_w );
  *
  *************************************/
 
-static void main_cpu_irq(int state)
+static void main_cpu_irq(running_machine *machine, int state)
 {
 	int combined_state = pia_get_irq_a(1) | pia_get_irq_b(1) | pia_get_irq_b(2);
 
-	cpunum_set_input_line(Machine, 0, M6809_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], M6809_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
-static void main_cpu_firq(int state)
+static void main_cpu_firq(running_machine *machine, int state)
 {
-	cpunum_set_input_line(Machine, 0, M6809_FIRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], M6809_FIRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -135,16 +134,17 @@ static void main_cpu_firq(int state)
 
 static INTERRUPT_GEN( update_pia_1 )
 {
+	const address_space *space = cpu_get_address_space(device, ADDRESS_SPACE_PROGRAM);
 	/* update the different PIA pins from the input ports */
 
 	/* CA1 - copy of PA0 (COIN1) */
-	pia_1_ca1_w(0, input_port_0_r(0) & 0x01);
+	pia_1_ca1_w(space, 0, input_port_read(device->machine, "IN0") & 0x01);
 
 	/* CA2 - copy of PA1 (SERVICE1) */
-	pia_1_ca2_w(0, input_port_0_r(0) & 0x02);
+	pia_1_ca2_w(space, 0, input_port_read(device->machine, "IN0") & 0x02);
 
 	/* CB1 - (crosshatch) */
-	pia_1_cb1_w(0, input_port_5_r(0));
+	pia_1_cb1_w(space, 0, input_port_read(device->machine, "CROSS"));
 
 	/* CB2 - NOT CONNECTED */
 }
@@ -180,7 +180,7 @@ static WRITE8_HANDLER( pia_2_port_b_w )
 	star_enable = data & 0x10;
 
 	/* bits 5-7 go to the music board connector */
-	audio_2_command_w(0, data & 0xe0);
+	audio_2_command_w(space, 0, data & 0xe0);
 }
 
 
@@ -205,13 +205,14 @@ static const pia6821_interface pia_2_intf =
  *
  *************************************/
 
-static void ic48_1_74123_output_changed(int output)
+static WRITE8_DEVICE_HANDLER(ic48_1_74123_output_changed)
 {
-	pia_2_ca1_w(0, output);
+	const address_space *space = cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	pia_2_ca1_w(space, 0, data);
 }
 
 
-static const TTL74123_interface ic48_1_intf =
+static const ttl74123_config ic48_1_config =
 {
 	TTL74123_GROUNDED,	/* the hook up type */
 	RES_K(22),			/* resistor connected to RCext */
@@ -232,16 +233,14 @@ static const TTL74123_interface ic48_1_intf =
 
 static MACHINE_START( nyny )
 {
-	pia_config(1, &pia_1_intf);
-	pia_config(2, &pia_2_intf);
-
-	TTL74123_config(0, &ic48_1_intf);
+	pia_config(machine, 1, &pia_1_intf);
+	pia_config(machine, 2, &pia_2_intf);
 
 	/* setup for save states */
-	state_save_register_global(flipscreen);
-	state_save_register_global(star_enable);
-	state_save_register_global(star_delay_counter);
-	state_save_register_global(star_shift_reg);
+	state_save_register_global(machine, flipscreen);
+	state_save_register_global(machine, star_enable);
+	state_save_register_global(machine, star_delay_counter);
+	state_save_register_global(machine, star_shift_reg);
 }
 
 
@@ -255,7 +254,6 @@ static MACHINE_START( nyny )
 static MACHINE_RESET( nyny )
 {
 	pia_reset();
-	TTL74123_reset(0);
 }
 
 
@@ -275,8 +273,7 @@ static WRITE8_HANDLER( flipscreen_w )
 }
 
 
-static void *nyny_begin_update(running_machine *machine, int screen,
-							   mame_bitmap *bitmap, const rectangle *cliprect)
+static MC6845_BEGIN_UPDATE( begin_update )
 {
 	/* create the pens */
 	offs_t i;
@@ -291,8 +288,7 @@ static void *nyny_begin_update(running_machine *machine, int screen,
 }
 
 
-static void nyny_update_row(mame_bitmap *bitmap, const rectangle *cliprect,
-							UINT16 ma, UINT8 ra, UINT16 y, UINT8 x_count, void *param)
+static MC6845_UPDATE_ROW( update_row )
 {
 	UINT8 cx;
 
@@ -361,9 +357,9 @@ INLINE void shift_star_generator(void)
 }
 
 
-static void nyny_end_update(mame_bitmap *bitmap, const rectangle *cliprect, void *param)
+static MC6845_END_UPDATE( end_update )
 {
-	/* the the star field into the bitmap */
+	/* draw the star field into the bitmap */
 	int y;
 
 	pen_t *pens = (pen_t *)param;
@@ -397,28 +393,31 @@ static void nyny_end_update(mame_bitmap *bitmap, const rectangle *cliprect, void
 }
 
 
-static void nyny_display_enable_changed(int display_enabled)
+static MC6845_ON_DE_CHANGED( display_enable_changed )
 {
-	TTL74123_A_w(0, display_enabled);
+	ttl74123_a_w(devtag_get_device(device->machine, TTL74123, "ic48_1"), 0, display_enabled);
 }
 
 
-static const crtc6845_interface crtc6845_intf =
+static const mc6845_interface mc6845_intf =
 {
-	0,							/* screen we are acting on */
-	CRTC_CLOCK, 				/* the clock (pin 21) of the chip */
-	8,							/* number of pixels per video memory address */
-	nyny_begin_update,			/* before pixel update callback */
-	nyny_update_row,			/* row update callback */
-	nyny_end_update,			/* after pixel update callback */
-	nyny_display_enable_changed	/* call back for display state changes */
+	"main",					/* screen we are acting on */
+	8,						/* number of pixels per video memory address */
+	begin_update,			/* before pixel update callback */
+	update_row,				/* row update callback */
+	end_update,				/* after pixel update callback */
+	display_enable_changed,	/* callback for display state changes */
+	NULL,					/* HSYNC callback */
+	NULL					/* VSYNC callback */
 };
 
 
-static VIDEO_START( nyny )
+static VIDEO_UPDATE( nyny )
 {
-	/* configure the CRT controller */
-	crtc6845_config(0, &crtc6845_intf);
+	const device_config *mc6845 = device_list_find_by_tag(screen->machine->config->devicelist, MC6845, "crtc");
+	mc6845_update(mc6845, bitmap, cliprect);
+
+	return 0;
 }
 
 
@@ -431,15 +430,15 @@ static VIDEO_START( nyny )
 
 static WRITE8_HANDLER( audio_1_command_w )
 {
-	soundlatch_w(0, data);
-	cpunum_set_input_line(Machine, 1, M6802_IRQ_LINE, HOLD_LINE);
+	soundlatch_w(space, 0, data);
+	cpu_set_input_line(space->machine->cpu[1], M6800_IRQ_LINE, HOLD_LINE);
 }
 
 
 static WRITE8_HANDLER( audio_1_answer_w )
 {
-	soundlatch3_w(0, data);
-	cpunum_set_input_line(Machine, 0, M6809_IRQ_LINE, HOLD_LINE);
+	soundlatch3_w(space, 0, data);
+	cpu_set_input_line(space->machine->cpu[0], M6809_IRQ_LINE, HOLD_LINE);
 }
 
 
@@ -447,29 +446,35 @@ static WRITE8_HANDLER( nyny_ay8910_37_port_a_w )
 {
 	/* not sure what this does */
 
-	/*logerror("%x PORT A write %x at  Y=%x X=%x\n", safe_activecpu_get_pc(), data, video_screen_get_vpos(0),  video_screen_get_hpos(0));*/
+	/*logerror("%x PORT A write %x at  Y=%x X=%x\n", cpu_get_pc(space->cpu), data, video_screen_get_vpos(space->machine->primary_screen), video_screen_get_hpos(space->machine->primary_screen));*/
 }
 
 
 static WRITE8_HANDLER( nyny_ay8910_37_port_b_w )
 {
-	DAC_data_w(0, data);
+	dac_data_w(0, data);
 }
 
 
-static const struct AY8910interface ay8910_37_interface =
+static const ay8910_interface ay8910_37_interface =
 {
-	0,
-	0,
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
+	NULL,
+	NULL,
 	nyny_ay8910_37_port_a_w,
 	nyny_ay8910_37_port_b_w
 };
 
 
-static const struct AY8910interface ay8910_64_interface =
+static const ay8910_interface ay8910_64_interface =
 {
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
 	input_port_3_r,
-	input_port_2_r
+	input_port_2_r,
+	NULL,
+	NULL
 };
 
 
@@ -482,8 +487,8 @@ static const struct AY8910interface ay8910_64_interface =
 
 static WRITE8_HANDLER( audio_2_command_w )
 {
-	soundlatch2_w(0, (data & 0x60) >> 5);
-	cpunum_set_input_line(Machine, 2, M6802_IRQ_LINE, (data & 0x80) ? CLEAR_LINE : ASSERT_LINE);
+	soundlatch2_w(space, 0, (data & 0x60) >> 5);
+	cpu_set_input_line(space->machine->cpu[2], M6800_IRQ_LINE, (data & 0x80) ? CLEAR_LINE : ASSERT_LINE);
 }
 
 
@@ -499,8 +504,8 @@ static READ8_HANDLER( nyny_pia_1_2_r )
 	UINT8 ret = 0;
 
 	/* the address bits are directly connected to the chip selects */
-	if (offset & 0x04)  ret = pia_1_r(offset & 0x03);
-	if (offset & 0x08)  ret = pia_2_alt_r(offset & 0x03);
+	if (offset & 0x04)  ret = pia_1_r(space, offset & 0x03);
+	if (offset & 0x08)  ret = pia_2_alt_r(space, offset & 0x03);
 
 	return ret;
 }
@@ -509,8 +514,8 @@ static READ8_HANDLER( nyny_pia_1_2_r )
 static WRITE8_HANDLER( nyny_pia_1_2_w )
 {
 	/* the address bits are directly connected to the chip selects */
-	if (offset & 0x04)  pia_1_w(offset & 0x03, data);
-	if (offset & 0x08)  pia_2_alt_w(offset & 0x03, data);
+	if (offset & 0x04)  pia_1_w(space, offset & 0x03, data);
+	if (offset & 0x08)  pia_2_alt_w(space, offset & 0x03, data);
 }
 
 
@@ -521,8 +526,8 @@ static ADDRESS_MAP_START( nyny_main_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x6000, 0x7fff) AM_RAM AM_BASE(&nyny_colorram_2)
 	AM_RANGE(0x8000, 0x9fff) AM_RAM
 	AM_RANGE(0xa000, 0xa0ff) AM_RAM AM_BASE(&generic_nvram) AM_SIZE(&generic_nvram_size) /* SRAM (coin counter, shown when holding F2) */
-	AM_RANGE(0xa100, 0xa100) AM_MIRROR(0x00fe) AM_WRITE(crtc6845_address_w)
-	AM_RANGE(0xa101, 0xa101) AM_MIRROR(0x00fe) AM_WRITE(crtc6845_register_w)
+	AM_RANGE(0xa100, 0xa100) AM_MIRROR(0x00fe) AM_DEVWRITE(MC6845, "crtc", mc6845_address_w)
+	AM_RANGE(0xa101, 0xa101) AM_MIRROR(0x00fe) AM_DEVWRITE(MC6845, "crtc", mc6845_register_w)
 	AM_RANGE(0xa200, 0xa20f) AM_MIRROR(0x00f0) AM_READWRITE(nyny_pia_1_2_r, nyny_pia_1_2_w)
 	AM_RANGE(0xa300, 0xa300) AM_MIRROR(0x00ff) AM_READWRITE(soundlatch3_r, audio_1_command_w)
 	AM_RANGE(0xa400, 0xa7ff) AM_NOP
@@ -533,15 +538,15 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( nyny_audio_1_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(15) )
+	ADDRESS_MAP_GLOBAL_MASK(0x7fff)
 	AM_RANGE(0x0000, 0x007f) AM_RAM		/* internal RAM */
 	AM_RANGE(0x0080, 0x0fff) AM_NOP
 	AM_RANGE(0x1000, 0x1000) AM_MIRROR(0x0fff) AM_READWRITE(soundlatch_r, audio_1_answer_w)
-	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x0fff) AM_READ(input_port_4_r)
-	AM_RANGE(0x3000, 0x3000) AM_MIRROR(0x0ffc) AM_READWRITE(AY8910_read_port_0_r, AY8910_write_port_0_w)
-	AM_RANGE(0x3001, 0x3001) AM_MIRROR(0x0ffc) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0x3002, 0x3002) AM_MIRROR(0x0ffc) AM_READWRITE(AY8910_read_port_1_r, AY8910_write_port_1_w)
-	AM_RANGE(0x3003, 0x3003) AM_MIRROR(0x0ffc) AM_WRITE(AY8910_control_port_1_w)
+	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x0fff) AM_READ_PORT("SW3")
+	AM_RANGE(0x3000, 0x3000) AM_MIRROR(0x0ffc) AM_READWRITE(ay8910_read_port_0_r, ay8910_write_port_0_w)
+	AM_RANGE(0x3001, 0x3001) AM_MIRROR(0x0ffc) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0x3002, 0x3002) AM_MIRROR(0x0ffc) AM_READWRITE(ay8910_read_port_1_r, ay8910_write_port_1_w)
+	AM_RANGE(0x3003, 0x3003) AM_MIRROR(0x0ffc) AM_WRITE(ay8910_control_port_1_w)
 	AM_RANGE(0x4000, 0x4fff) AM_NOP
 	AM_RANGE(0x5000, 0x57ff) AM_MIRROR(0x0800) AM_ROM
 	AM_RANGE(0x6000, 0x67ff) AM_MIRROR(0x0800) AM_ROM
@@ -550,12 +555,12 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( nyny_audio_2_map, ADDRESS_SPACE_PROGRAM, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(15) )
+	ADDRESS_MAP_GLOBAL_MASK(0x7fff)
 	AM_RANGE(0x0000, 0x007f) AM_RAM		/* internal RAM */
 	AM_RANGE(0x0080, 0x0fff) AM_NOP
 	AM_RANGE(0x1000, 0x1000) AM_MIRROR(0x0fff) AM_READ(soundlatch2_r)
-	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x0ffe) AM_READWRITE(AY8910_read_port_2_r, AY8910_write_port_2_w)
-	AM_RANGE(0x2001, 0x2001) AM_MIRROR(0x0ffe) AM_WRITE(AY8910_control_port_2_w)
+	AM_RANGE(0x2000, 0x2000) AM_MIRROR(0x0ffe) AM_READWRITE(ay8910_read_port_2_r, ay8910_write_port_2_w)
+	AM_RANGE(0x2001, 0x2001) AM_MIRROR(0x0ffe) AM_WRITE(ay8910_control_port_2_w)
 	AM_RANGE(0x3000, 0x6fff) AM_NOP
 	AM_RANGE(0x7000, 0x77ff) AM_MIRROR(0x0800) AM_ROM
 ADDRESS_MAP_END
@@ -569,7 +574,7 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( nyny )
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )     /* PIA0 PA0 */
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_SERVICE1 )  /* PIA0 PA1 */
 	PORT_SERVICE_NO_TOGGLE(0x04, IP_ACTIVE_HIGH)	/* PIA0 PA2 */
@@ -579,14 +584,14 @@ static INPUT_PORTS_START( nyny )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_START2 )	/* PIA0 PA6 */
     PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START_TAG("IN1")
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY PORT_COCKTAIL /* PIA0 PB0 */
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY PORT_COCKTAIL /* PIA0 PB1 */
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY	/* PIA0 PB2 */
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY	/* PIA0 PB3 */
     PORT_BIT( 0xf0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START_TAG("SW1")	/* port 2 */
+	PORT_START("SW1")	/* port 2 */
 	PORT_DIPNAME( 0x03, 0x03, "Bombs from UFO (Screens 3+)" ) PORT_DIPLOCATION("SW1:1,2")
 	PORT_DIPSETTING(	0x01, "3" )
 	PORT_DIPSETTING(	0x00, "6" )
@@ -599,7 +604,7 @@ static INPUT_PORTS_START( nyny )
 	PORT_DIPSETTING(	0x00, DEF_STR( Low ) )
 	PORT_DIPSETTING(	0x80, DEF_STR( High ) )
 
-	PORT_START_TAG("SW2")	/* port 3 */
+	PORT_START("SW2")	/* port 3 */
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Coin_A ) ) PORT_DIPLOCATION("SW2:1,2")
 	PORT_DIPSETTING(	0x02, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(	0x03, DEF_STR( 1C_1C ) )
@@ -617,7 +622,7 @@ static INPUT_PORTS_START( nyny )
 	PORT_DIPSETTING(	0x00, DEF_STR( No ) )
 	PORT_DIPSETTING(	0x80, DEF_STR( Yes ) )
 
-	PORT_START_TAG("SW3")	/* port 4 */
+	PORT_START("SW3")	/* port 4 */
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Flip_Screen ) ) PORT_DIPLOCATION("SW3:1")
 	PORT_DIPSETTING(	0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(	0x01, DEF_STR( On ) )
@@ -641,7 +646,7 @@ static INPUT_PORTS_START( nyny )
 	PORT_DIPSETTING(	0x40, "+2" )
 	PORT_DIPSETTING(	0x20, "+3" )
 
-    PORT_START      /* connected to PIA1 CB1 input */
+    PORT_START("CROSS")		/* connected to PIA1 CB1 input */
     PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("PS1 (Crosshatch)") PORT_CODE(KEYCODE_F1)
 
 INPUT_PORTS_END
@@ -657,14 +662,14 @@ INPUT_PORTS_END
 static MACHINE_DRIVER_START( nyny )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M6809, 1400000)	/* 1.40 MHz? The clock signal is generated by analog chips */
+	MDRV_CPU_ADD("main", M6809, 1400000)	/* 1.40 MHz? The clock signal is generated by analog chips */
 	MDRV_CPU_PROGRAM_MAP(nyny_main_map,0)
 	MDRV_CPU_PERIODIC_INT(update_pia_1, 25)
 
-	MDRV_CPU_ADD(M6802, AUDIO_CPU_1_CLOCK)
+	MDRV_CPU_ADD("audio", M6802, AUDIO_CPU_1_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(nyny_audio_1_map,0)
 
-	MDRV_CPU_ADD(M6802, AUDIO_CPU_2_CLOCK)
+	MDRV_CPU_ADD("audio2", M6802, AUDIO_CPU_2_CLOCK)
 	MDRV_CPU_PROGRAM_MAP(nyny_audio_2_map,0)
 
 	MDRV_MACHINE_START(nyny)
@@ -672,29 +677,33 @@ static MACHINE_DRIVER_START( nyny )
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
-	MDRV_VIDEO_START(nyny)
-	MDRV_VIDEO_UPDATE(crtc6845)
+	MDRV_VIDEO_UPDATE(nyny)
 
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_RAW_PARAMS(PIXEL_CLOCK, 256, 0, 256, 256, 0, 256)	/* temporary, CRTC will configure screen */
 
+	MDRV_MC6845_ADD("crtc", MC6845, CRTC_CLOCK, mc6845_intf)
+
+	/* 74LS123 */
+
+	MDRV_TTL74123_ADD("ic48_1", ic48_1_config)
+
 	/* audio hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, AUDIO_CPU_1_CLOCK)
+	MDRV_SOUND_ADD("ay1", AY8910, AUDIO_CPU_1_CLOCK)
 	MDRV_SOUND_CONFIG(ay8910_37_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD(AY8910, AUDIO_CPU_1_CLOCK)
+	MDRV_SOUND_ADD("ay2", AY8910, AUDIO_CPU_1_CLOCK)
 	MDRV_SOUND_CONFIG(ay8910_64_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD(AY8910, AUDIO_CPU_2_CLOCK)
+	MDRV_SOUND_ADD("ay3", AY8910, AUDIO_CPU_2_CLOCK)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.03)
 
-	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ADD("dac", DAC, 0)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
@@ -707,7 +716,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( nyny )
-	ROM_REGION(0x10000, REGION_CPU1, 0)	/* main CPU */
+	ROM_REGION(0x10000, "main", 0)	/* main CPU */
 	ROM_LOAD( "nyny01s.100",  0xa800, 0x0800, CRC(a2b76eca) SHA1(e46717e6ad330be4c4e7d9fab4f055f89aa31bcc) )
 	ROM_LOAD( "nyny02s.099",  0xb000, 0x0800, CRC(ef2d4dae) SHA1(718c0ecf7770a780aebb1dc8bf4ca86ea0a5ea28) )
 	ROM_LOAD( "nyny03s.098",  0xb800, 0x0800, CRC(2734c229) SHA1(b028d057d26838bae50b8ddb90a3755b5315b4ee) )
@@ -716,18 +725,18 @@ ROM_START( nyny )
 	ROM_LOAD( "nyny06s.095",  0xf000, 0x0800, CRC(8c073052) SHA1(0ce103ac0e79124ac9f1e097dda1a0664b92b89b) )
 	ROM_LOAD( "nyny07s.094",  0xf800, 0x0800, CRC(d49d7429) SHA1(c12eaae7ba0b1d44c45a584232db03c5731c046a) )
 
-	ROM_REGION(0x10000, REGION_CPU2, 0)	/* first audio CPU */
+	ROM_REGION(0x10000, "audio", 0)	/* first audio CPU */
 	ROM_LOAD( "nyny08.093",   0x5000, 0x0800, CRC(19ddb6c3) SHA1(0097fad542f9a33849565093c2fb106d90007b1a) )
 	ROM_LOAD( "nyny09.092",   0x6000, 0x0800, CRC(a359c6f1) SHA1(1bc7b487581399908c3cec823733810fb6d944ce) )
 	ROM_LOAD( "nyny10.091",   0x7000, 0x0800, CRC(a72a70fa) SHA1(deed7dec9cc43fa1d6c4854ba18169c894c9a2f0) )
 
-	ROM_REGION(0x10000, REGION_CPU3, 0) /* second audio CPU */
+	ROM_REGION(0x10000, "audio2", 0) /* second audio CPU */
 	ROM_LOAD( "nyny11.snd",   0x7000, 0x0800, CRC(650450fc) SHA1(214693df394ca05eff5dbe1e800107d326ba80f6) )
 ROM_END
 
 
 ROM_START( nynyg )
-	ROM_REGION(0x10000, REGION_CPU1, 0)	/* main CPU */
+	ROM_REGION(0x10000, "main", 0)	/* main CPU */
 	ROM_LOAD( "gny1.cpu",     0xa800, 0x0800, CRC(fb5b8f17) SHA1(2202325451dfd4e7c16cba93f0fade46929ffa72) )
 	ROM_LOAD( "gny2.cpu",     0xb000, 0x0800, CRC(d248dd93) SHA1(0c4579698f8917332041c08af6902b8f8acd7d62) )
 	ROM_LOAD( "gny3.cpu",     0xb800, 0x0800, CRC(223a9d09) SHA1(c2b12270d375587489208d6a1b37a4e3ec87bc20) )
@@ -736,12 +745,12 @@ ROM_START( nynyg )
 	ROM_LOAD( "gny6.cpu",     0xf000, 0x0800, CRC(4839d4d2) SHA1(cfd6f2f252ee2f6a4d881496a017c02d7dd77944) )
 	ROM_LOAD( "gny7.cpu",     0xf800, 0x0800, CRC(b7564c5b) SHA1(e1d8fe7f37aa7aa98f18c538fe6e688675cc2de1) )
 
-	ROM_REGION(0x10000, REGION_CPU2, 0)	/* first audio CPU */
+	ROM_REGION(0x10000, "audio", 0)	/* first audio CPU */
 	ROM_LOAD( "gny8.cpu",     0x5000, 0x0800, CRC(e0bf7d00) SHA1(7afca3affa413179f4f59ce2cad89525cfa5efbc) )
 	ROM_LOAD( "gny9.cpu",     0x6000, 0x0800, CRC(639bc81a) SHA1(91819d49099e438ac8c70920a787aeaed3ed82e9) )
 	ROM_LOAD( "gny10.cpu",    0x7000, 0x0800, CRC(73764021) SHA1(bb2f62130142487afbd8d2540e2d4fe5bb67c4ee) )
 
-	ROM_REGION(0x10000, REGION_CPU3, 0) /* second audio CPU */
+	ROM_REGION(0x10000, "audio2", 0) /* second audio CPU */
 	/* The original dump of this ROM was bad [FIXED BITS (x1xxxxxx)] */
 	/* Since what's left is identical to the Sigma version, I'm assuming it's the same. */
 	ROM_LOAD( "nyny11.snd",   0x7000, 0x0800, CRC(650450fc) SHA1(214693df394ca05eff5dbe1e800107d326ba80f6) )
@@ -749,7 +758,7 @@ ROM_END
 
 
 ROM_START( arcadia )
-	ROM_REGION(0x10000, REGION_CPU1, 0)	/* main CPU */
+	ROM_REGION(0x10000, "main", 0)	/* main CPU */
 	ROM_LOAD( "ar-01",        0xa800, 0x0800, CRC(7b7e8f27) SHA1(2bb1d07d87ad5b952de9460c840d7e8b59ed1b4a) )
 	ROM_LOAD( "ar-02",        0xb000, 0x0800, CRC(81d9e172) SHA1(4279582f1edf54f0974fa277565d8ade6d9faa50) )
 	ROM_LOAD( "ar-03",        0xb800, 0x0800, CRC(2c5feb05) SHA1(6f8952e7744ba7d7b8b345d67f546b504f7a3b30) )
@@ -758,12 +767,12 @@ ROM_START( arcadia )
 	ROM_LOAD( "ar-06",        0xf000, 0x0800, CRC(27b79cc0) SHA1(2c5c3a9a09069751c5e9c23d0840ee4996006c0b) )
 	ROM_LOAD( "ar-07",        0xf800, 0x0800, CRC(be77a477) SHA1(817c069855634dd844f0068d64bfbf1862980d6b) )
 
-	ROM_REGION(0x10000, REGION_CPU2, 0)	/* first audio CPU */
+	ROM_REGION(0x10000, "audio", 0)	/* first audio CPU */
 	ROM_LOAD( "ar-08",        0x5000, 0x0800, CRC(38569b25) SHA1(887a9afaa65d0961097f7fb5f1ae390d40e9c164) )
 	ROM_LOAD( "nyny09.092",   0x6000, 0x0800, CRC(a359c6f1) SHA1(1bc7b487581399908c3cec823733810fb6d944ce) )
 	ROM_LOAD( "nyny10.091",   0x7000, 0x0800, CRC(a72a70fa) SHA1(deed7dec9cc43fa1d6c4854ba18169c894c9a2f0) )
 
-	ROM_REGION(0x10000, REGION_CPU3, 0) /* second audio CPU */
+	ROM_REGION(0x10000, "audio2", 0) /* second audio CPU */
 	ROM_LOAD( "ar-11",        0x7000, 0x0800, CRC(208f4488) SHA1(533f8942e1c964cc88253e9dc4ec711f77607e4c) )
 ROM_END
 
