@@ -217,7 +217,7 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
 #include "video/vector.h"
 #include "video/avgdvg.h"
 #include "sound/ay8910.h"
@@ -234,8 +234,9 @@
 
 static MACHINE_RESET( omegrace )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	/* Omega Race expects the vector processor to be ready. */
-	avgdvg_reset_w (0, 0);
+	avgdvg_reset_w(space, 0, 0);
 }
 
 
@@ -248,18 +249,11 @@ static MACHINE_RESET( omegrace )
 
 static READ8_HANDLER( omegrace_vg_go_r )
 {
-	avgdvg_go_w(0,0);
+	avgdvg_go_w(space,0,0);
 	return 0;
 }
 
 
-static READ8_HANDLER( omegrace_vg_status_r )
-{
-	return avgdvg_done() ? 0x00 : 0x80;
-}
-
-
-
 /*************************************
  *
  *  Input handlers
@@ -293,7 +287,7 @@ static const UINT8 spinnerTable[64] =
 
 static READ8_HANDLER( omegrace_spinner1_r )
 {
-	return (spinnerTable[readinputport(4) & 0x3f]);
+	return (spinnerTable[input_port_read(space->machine, "SPIN0") & 0x3f]);
 }
 
 
@@ -322,8 +316,8 @@ static WRITE8_HANDLER( omegrace_leds_w )
 
 static WRITE8_HANDLER( omegrace_soundlatch_w )
 {
-	soundlatch_w (offset, data);
-	cpunum_set_input_line(Machine, 1, 0, HOLD_LINE);
+	soundlatch_w (space, offset, data);
+	cpu_set_input_line(space->machine->cpu[1], 0, HOLD_LINE);
 }
 
 
@@ -338,25 +332,25 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x4bff) AM_RAM
 	AM_RANGE(0x5c00, 0x5cff) AM_RAM AM_BASE(&generic_nvram) AM_SIZE(&generic_nvram_size) /* NVRAM */
-	AM_RANGE(0x8000, 0x8fff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size) AM_REGION(REGION_CPU1, 0x8000) /* vector ram */
+	AM_RANGE(0x8000, 0x8fff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size) AM_REGION("main", 0x8000) /* vector ram */
 	AM_RANGE(0x9000, 0x9fff) AM_ROM /* vector rom */
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( port_map, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x08, 0x08) AM_READ(omegrace_vg_go_r)
 	AM_RANGE(0x09, 0x09) AM_READ(watchdog_reset_r)
 	AM_RANGE(0x0a, 0x0a) AM_WRITE(avgdvg_reset_w)
-	AM_RANGE(0x0b, 0x0b) AM_READ(omegrace_vg_status_r) /* vg_halt */
-	AM_RANGE(0x10, 0x10) AM_READ(input_port_0_r) /* DIP SW C4 */
-	AM_RANGE(0x17, 0x17) AM_READ(input_port_1_r) /* DIP SW C6 */
-	AM_RANGE(0x11, 0x11) AM_READ(input_port_2_r) /* Player 1 input */
-	AM_RANGE(0x12, 0x12) AM_READ(input_port_3_r) /* Player 2 input */
-	AM_RANGE(0x13, 0x13) AM_WRITE(omegrace_leds_w) /* coin counters, leds, flip screen */
-	AM_RANGE(0x14, 0x14) AM_WRITE(omegrace_soundlatch_w) /* Sound command */
-	AM_RANGE(0x15, 0x15) AM_READ(omegrace_spinner1_r) /* 1st controller */
-	AM_RANGE(0x16, 0x16) AM_READ(input_port_5_r) /* 2nd controller (cocktail) */
+	AM_RANGE(0x0b, 0x0b) AM_READ_PORT("AVGDVG")				/* vg_halt */
+	AM_RANGE(0x10, 0x10) AM_READ_PORT("DSW1")				/* DIP SW C4 */
+	AM_RANGE(0x17, 0x17) AM_READ_PORT("DSW2")				/* DIP SW C6 */
+	AM_RANGE(0x11, 0x11) AM_READ_PORT("IN0")				/* Player 1 input */
+	AM_RANGE(0x12, 0x12) AM_READ_PORT("IN1")				/* Player 2 input */
+	AM_RANGE(0x13, 0x13) AM_WRITE(omegrace_leds_w)			/* coin counters, leds, flip screen */
+	AM_RANGE(0x14, 0x14) AM_WRITE(omegrace_soundlatch_w)	/* Sound command */
+	AM_RANGE(0x15, 0x15) AM_READ(omegrace_spinner1_r)		/* 1st controller */
+	AM_RANGE(0x16, 0x16) AM_READ_PORT("SPIN1")				/* 2nd controller (cocktail) */
 ADDRESS_MAP_END
 
 
@@ -373,11 +367,11 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( sound_port, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x00, 0x00) AM_READWRITE(soundlatch_r, AY8910_control_port_0_w)
-	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_write_port_0_w)
-	AM_RANGE(0x02, 0x02) AM_WRITE(AY8910_control_port_1_w)
-	AM_RANGE(0x03, 0x03) AM_WRITE(AY8910_write_port_1_w)
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x00, 0x00) AM_READWRITE(soundlatch_r, ay8910_control_port_0_w)
+	AM_RANGE(0x01, 0x01) AM_WRITE(ay8910_write_port_0_w)
+	AM_RANGE(0x02, 0x02) AM_WRITE(ay8910_control_port_1_w)
+	AM_RANGE(0x03, 0x03) AM_WRITE(ay8910_write_port_1_w)
 ADDRESS_MAP_END
 
 
@@ -389,80 +383,83 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( omegrace )
-	PORT_START /* SW0 */
-	PORT_DIPNAME( 0x03, 0x03, "1st Bonus Life" )	PORT_DIPLOCATION("SW1:1,2")
-	PORT_DIPSETTING (   0x00, "40k" )
-	PORT_DIPSETTING (   0x01, "50k" )
-	PORT_DIPSETTING (   0x02, "70k" )
-	PORT_DIPSETTING (   0x03, "100k" )
+	PORT_START("DSW1")
+	PORT_DIPNAME( 0x03, 0x03, "1st Bonus Life" )		PORT_DIPLOCATION("SW1:1,2")
+	PORT_DIPSETTING(	0x00, "40k" )
+	PORT_DIPSETTING(	0x01, "50k" )
+	PORT_DIPSETTING(	0x02, "70k" )
+	PORT_DIPSETTING(	0x03, "100k" )
 	PORT_DIPNAME( 0x0c, 0x0c, "2nd & 3rd Bonus Life" )	PORT_DIPLOCATION("SW1:3,4")
-	PORT_DIPSETTING (   0x00, "150k 250k" )
-	PORT_DIPSETTING (   0x04, "250k 500k" )
-	PORT_DIPSETTING (   0x08, "500k 750k" )
-	PORT_DIPSETTING (   0x0c, "750k 1500k" )
-	PORT_DIPNAME( 0x30, 0x30, "Credit(s)/Ships" )	PORT_DIPLOCATION("SW1:5,6")
-	PORT_DIPSETTING (   0x00, "1C/2S 2C/4S" )
-	PORT_DIPSETTING (   0x10, "1C/2S 2C/5S" )
-	PORT_DIPSETTING (   0x20, "1C/3S 2C/6S" )
-	PORT_DIPSETTING (   0x30, "1C/3S 2C/7S" )
-	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unused ) )	PORT_DIPLOCATION("SW1:7")
-	PORT_DIPSETTING (   0x00, DEF_STR( Off ) )
-	PORT_DIPSETTING (   0x40, DEF_STR( On ) )
-	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unused ) )	PORT_DIPLOCATION("SW1:8")
-	PORT_DIPSETTING (   0x00, DEF_STR( Off ) )
-	PORT_DIPSETTING (   0x80, DEF_STR( On ) )
+	PORT_DIPSETTING(	0x00, "150k 250k" )
+	PORT_DIPSETTING(	0x04, "250k 500k" )
+	PORT_DIPSETTING(	0x08, "500k 750k" )
+	PORT_DIPSETTING(	0x0c, "750k 1500k" )
+	PORT_DIPNAME( 0x30, 0x30, "Credit(s)/Ships" )		PORT_DIPLOCATION("SW1:5,6")
+	PORT_DIPSETTING(	0x00, "1C/2S 2C/4S" )
+	PORT_DIPSETTING(	0x10, "1C/2S 2C/5S" )
+	PORT_DIPSETTING(	0x20, "1C/3S 2C/6S" )
+	PORT_DIPSETTING(	0x30, "1C/3S 2C/7S" )
+	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unused ) )		PORT_DIPLOCATION("SW1:7")
+	PORT_DIPSETTING(	0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(	0x40, DEF_STR( On ) )
+	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unused ) )		PORT_DIPLOCATION("SW1:8")
+	PORT_DIPSETTING(	0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(	0x80, DEF_STR( On ) )
 
-	PORT_START /* SW1 */
-	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coin_A ) )	PORT_DIPLOCATION("SW2:1,2,3")
-	PORT_DIPSETTING (   0x06, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING (   0x07, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING (   0x03, DEF_STR( 4C_5C ) )
-	PORT_DIPSETTING (   0x04, DEF_STR( 3C_4C ) )
-	PORT_DIPSETTING (   0x05, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING (   0x00, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING (   0x01, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING (   0x02, DEF_STR( 1C_5C ) )
-	PORT_DIPNAME( 0x38, 0x38, DEF_STR( Coin_B ) )	PORT_DIPLOCATION("SW2:4,5,6")
-	PORT_DIPSETTING (   0x30, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING (   0x38, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING (   0x18, DEF_STR( 4C_5C ) )
-	PORT_DIPSETTING (   0x20, DEF_STR( 3C_4C ) )
-	PORT_DIPSETTING (   0x28, DEF_STR( 2C_3C ) )
-	PORT_DIPSETTING (   0x00, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING (   0x08, DEF_STR( 1C_3C ) )
-	PORT_DIPSETTING (   0x10, DEF_STR( 1C_5C ) )
+	PORT_START("DSW2")
+	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coin_A ) )		PORT_DIPLOCATION("SW2:1,2,3")
+	PORT_DIPSETTING(	0x06, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(	0x07, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(	0x03, DEF_STR( 4C_5C ) )
+	PORT_DIPSETTING(	0x04, DEF_STR( 3C_4C ) )
+	PORT_DIPSETTING(	0x05, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(	0x00, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(	0x01, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(	0x02, DEF_STR( 1C_5C ) )
+	PORT_DIPNAME( 0x38, 0x38, DEF_STR( Coin_B ) )		PORT_DIPLOCATION("SW2:4,5,6")
+	PORT_DIPSETTING(	0x30, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(	0x38, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(	0x18, DEF_STR( 4C_5C ) )
+	PORT_DIPSETTING(	0x20, DEF_STR( 3C_4C ) )
+	PORT_DIPSETTING(	0x28, DEF_STR( 2C_3C ) )
+	PORT_DIPSETTING(	0x00, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(	0x08, DEF_STR( 1C_3C ) )
+	PORT_DIPSETTING(	0x10, DEF_STR( 1C_5C ) )
 	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Free_Play ) )	PORT_DIPLOCATION("SW2:7")
-	PORT_DIPSETTING (   0x00, DEF_STR( Off ) )
-	PORT_DIPSETTING (   0x40, DEF_STR( On ) )
-	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Cabinet ) )	PORT_DIPLOCATION("SW2:8")
-	PORT_DIPSETTING (   0x00, DEF_STR( Upright ) )
-	PORT_DIPSETTING (   0x80, DEF_STR( Cocktail ) )
+	PORT_DIPSETTING(	0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(	0x40, DEF_STR( On ) )
+	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Cabinet ) )		PORT_DIPLOCATION("SW2:8")
+	PORT_DIPSETTING(	0x00, DEF_STR( Upright ) )
+	PORT_DIPSETTING(	0x80, DEF_STR( Cocktail ) )
 
-	PORT_START /* IN2 - port 0x11 */
-	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT ( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_TILT )
-	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 )
-	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_BUTTON1 )
+	PORT_START("IN0")		/* port 0x11 */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_TILT )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_SERVICE( 0x80, IP_ACTIVE_LOW )
 
-	PORT_START /* IN3 - port 0x12 */
-	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
-	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
+	PORT_START("IN1")		/* port 0x12 */
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_START2 ) PORT_NAME("2 Players Start (1 credit)")
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_START4 ) PORT_NAME("2 Players Start (2 credits)")
-	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_START1 ) PORT_NAME("1 Player Start (1 credit)")
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_START3 ) PORT_NAME("1 Player Start (2 credits)")
 
-	PORT_START /* IN4 - port 0x15 - spinner */
-	PORT_BIT(0x3f, 0x00, IPT_DIAL ) PORT_SENSITIVITY(12) PORT_KEYDELTA(10)
+	PORT_START("SPIN0")		/* port 0x15 - spinner */
+	PORT_BIT( 0x3f, 0x00, IPT_DIAL ) PORT_SENSITIVITY(12) PORT_KEYDELTA(10)
 
-	PORT_START /* IN5 - port 0x16 - second spinner */
-	PORT_BIT(0x3f, 0x00, IPT_DIAL ) PORT_SENSITIVITY(12) PORT_KEYDELTA(10) PORT_COCKTAIL
+	PORT_START("SPIN1")		/* port 0x16 - second spinner */
+	PORT_BIT( 0x3f, 0x00, IPT_DIAL ) PORT_SENSITIVITY(12) PORT_KEYDELTA(10) PORT_COCKTAIL
+
+	PORT_START("AVGDVG")	/* port 0x0b */
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SPECIAL ) PORT_CUSTOM(avgdvg_done_r, NULL)
 INPUT_PORTS_END
 
 
@@ -480,7 +477,7 @@ static MACHINE_DRIVER_START( omegrace )
 	/* main CPU */
 	/* XTAL101 Crystal @ 12mhz */
 	/* through 74LS161, Pin 13 = divide by 4 */
-	MDRV_CPU_ADD(Z80,12000000/4)
+	MDRV_CPU_ADD("main", Z80,12000000/4)
 	MDRV_CPU_PROGRAM_MAP(main_map, 0)
 	MDRV_CPU_IO_MAP(port_map, 0)
 	MDRV_CPU_PERIODIC_INT(irq0_line_hold,250)
@@ -489,23 +486,19 @@ static MACHINE_DRIVER_START( omegrace )
 	/* XTAL101 Crystal @ 12mhz */
 	/* through 74LS161, Pin 12 = divide by 8 */
 	/* Fed to CPU as 1.5mhz though line J4-D */
-	MDRV_CPU_ADD(Z80,12000000/8)
+	MDRV_CPU_ADD("audio", Z80,12000000/8)
 	MDRV_CPU_PROGRAM_MAP(sound_map, 0)
 	MDRV_CPU_IO_MAP(sound_port, 0)
 	MDRV_CPU_PERIODIC_INT(nmi_line_pulse,250)
 
-	MDRV_SCREEN_REFRESH_RATE(40)
-	MDRV_SCREEN_VBLANK_TIME(0)
-
 	MDRV_MACHINE_RESET(omegrace)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_VECTOR )
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB15)
+	MDRV_SCREEN_ADD("main", VECTOR)
+	MDRV_SCREEN_REFRESH_RATE(40)
 	MDRV_SCREEN_SIZE(400, 300)
 	MDRV_SCREEN_VISIBLE_AREA(522, 1566, 522, 1566)
-	MDRV_PALETTE_LENGTH(32768)
 
 	MDRV_VIDEO_START(dvg)
 	MDRV_VIDEO_UPDATE(vector)
@@ -515,10 +508,10 @@ static MACHINE_DRIVER_START( omegrace )
 
 	/* XTAL101 Crystal @ 12mhz */
 	/* through 74LS92, Pin 8 = divide by 12 */
-	MDRV_SOUND_ADD(AY8912, 12000000/12)
+	MDRV_SOUND_ADD("ay1", AY8912, 12000000/12)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 
-	MDRV_SOUND_ADD(AY8912, 12000000/12)
+	MDRV_SOUND_ADD("ay2", AY8912, 12000000/12)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.25)
 MACHINE_DRIVER_END
 
@@ -531,7 +524,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( omegrace )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "omega.m7",     0x0000, 0x1000, CRC(0424d46e) SHA1(cc1ac6c06ba6f6e8466fa08286a0c70b5335af33) )
 	ROM_LOAD( "omega.l7",     0x1000, 0x1000, CRC(edcd7a7d) SHA1(5d142de2f48b01d563578a54fd5540e5d0ac8f4c) )
 	ROM_LOAD( "omega.k7",     0x2000, 0x1000, CRC(6d10f197) SHA1(9609a0cbeeef2efa10d49cde9f0afdca96e9c2f8) )
@@ -539,16 +532,16 @@ ROM_START( omegrace )
 	ROM_LOAD( "omega.e1",     0x9000, 0x0800, CRC(1d0fdf3a) SHA1(3333397a9745874cea1dd6a1bda783cc59393b55) )
 	ROM_LOAD( "omega.f1",     0x9800, 0x0800, CRC(d44c0814) SHA1(2f216ee6de88bbe09775619003aee2d5aa8c554d) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "sound.k5",     0x0000, 0x0800, CRC(7d426017) SHA1(370f0fb5608819de873c845f6010cbde75a9818e) )
 
 	/* DVG PROM */
-	ROM_REGION( 0x100, REGION_USER1, 0 )
-	ROM_LOAD( "01-34602.bin",	0x0000, 0x0100, BAD_DUMP CRC(97953db8) SHA1(8cbded64d1dd35b18c4d5cece00f77e7b2cab2ad) )
+	ROM_REGION( 0x100, "user1", 0 )
+	ROM_LOAD( "dvgprom.bin",	0x0000, 0x0100, CRC(d481e958) SHA1(d8790547dc539e25984807573097b61ec3ffe614) )
 ROM_END
 
 ROM_START( deltrace )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "omega.m7",     0x0000, 0x1000, CRC(0424d46e) SHA1(cc1ac6c06ba6f6e8466fa08286a0c70b5335af33) )
 	ROM_LOAD( "omega.l7",     0x1000, 0x1000, CRC(edcd7a7d) SHA1(5d142de2f48b01d563578a54fd5540e5d0ac8f4c) )
 	ROM_LOAD( "omega.k7",     0x2000, 0x1000, CRC(6d10f197) SHA1(9609a0cbeeef2efa10d49cde9f0afdca96e9c2f8) )
@@ -556,15 +549,35 @@ ROM_START( deltrace )
 	ROM_LOAD( "omega.e1",     0x9000, 0x0800, CRC(1d0fdf3a) SHA1(3333397a9745874cea1dd6a1bda783cc59393b55) )
 	ROM_LOAD( "omega.f1",     0x9800, 0x0800, CRC(d44c0814) SHA1(2f216ee6de88bbe09775619003aee2d5aa8c554d) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "sound.k5",     0x0000, 0x0800, CRC(7d426017) SHA1(370f0fb5608819de873c845f6010cbde75a9818e) )
 
 	/* DVG PROM */
-	ROM_REGION( 0x100, REGION_USER1, 0 )
-	ROM_LOAD( "01-34602.bin",	0x0000, 0x0100, BAD_DUMP CRC(97953db8) SHA1(8cbded64d1dd35b18c4d5cece00f77e7b2cab2ad) )
+	ROM_REGION( 0x100, "user1", 0 )
+	ROM_LOAD( "dvgprom.bin",	0x0000, 0x0100, CRC(d481e958) SHA1(d8790547dc539e25984807573097b61ec3ffe614) )
 ROM_END
 
 
+/*************************************
+ *
+ *  Game specific initalization
+ *
+ *************************************/
+
+static DRIVER_INIT( omegrace )
+{
+	int i, len = memory_region_length(machine, "user1");
+	UINT8 *prom = memory_region(machine, "user1");
+
+	/* Omega Race has two pairs of the state PROM output
+     * lines swapped before going into the decoder.
+     * Since all other avg/dvg games connect the PROM
+     * in a consistent way to the decoder, we swap the bits
+     * here. */
+	for (i=0; i<len; i++)
+		prom[i] = BITSWAP8(prom[i],7,6,5,4,1,0,3,2);
+}
+
 
 /*************************************
  *
@@ -572,5 +585,5 @@ ROM_END
  *
  *************************************/
 
-GAMEL(1981, omegrace, 0,        omegrace, omegrace, 0, ROT0, "Midway",         "Omega Race", GAME_NO_COCKTAIL, layout_hoffe457 )
-GAMEL(1981, deltrace, omegrace, omegrace, omegrace, 0, ROT0, "Allied Leisure", "Delta Race", GAME_NO_COCKTAIL, layout_hoffe457 )
+GAMEL(1981, omegrace, 0,        omegrace, omegrace, omegrace, ROT0, "Midway",         "Omega Race", GAME_NO_COCKTAIL, layout_hoffe457 )
+GAMEL(1981, deltrace, omegrace, omegrace, omegrace, omegrace, ROT0, "Allied Leisure", "Delta Race", GAME_NO_COCKTAIL, layout_hoffe457 )
