@@ -44,19 +44,17 @@ static INT32 gp2_irq_control;
  *
  *************************************/
 
-static READ16_HANDLER( i_port1_r )
+static CUSTOM_INPUT( inputs_r )
 {
-	if (control & 0x0080)
-		return input_port_0_word_r(0,0);
-	else
-		return input_port_1_word_r(0,0);
+	const char *tag1 = param;
+	const char *tag2 = tag1 + strlen(tag1) + 1;
+	return input_port_read(field->port->machine, (control & 0x0080) ? tag1 : tag2);
 }
 
-static READ16_HANDLER( i_port2_r )
+static CUSTOM_INPUT( battery_sensor_r )
 {
 	/* bit 0-1  battery power sensor: 3=good, 2=low, other=bad */
-
-	return (input_port_2_word_r(0,0) & 0xfffc) | 0x0003;
+	return 0x0003;
 }
 
 
@@ -91,7 +89,7 @@ static WRITE16_HANDLER( gp_control_w )
 			double gain = vol / 90.0;
 
 			for (i=0; i<8; i++)
-				K054539_set_gain(0, i, gain);
+				k054539_set_gain(0, i, gain);
 		}
 	}
 }
@@ -120,7 +118,7 @@ static WRITE16_HANDLER( gp2_control_w )
 			double gain = vol / 90.0;
 
 			for (i=0; i<8; i++)
-				K054539_set_gain(0, i, gain);
+				k054539_set_gain(0, i, gain);
 		}
 	}
 }
@@ -128,8 +126,8 @@ static WRITE16_HANDLER( gp2_control_w )
 
 static READ16_HANDLER( v_rom_r )
 {
-	UINT8 *mem8 = memory_region(REGION_GFX1);
-	int bank = K056832_word_r(0x34/2, 0xffff);
+	UINT8 *mem8 = memory_region(space->machine, "gfx1");
+	int bank = K056832_word_r(space, 0x34/2, 0xffff);
 
 	offset += bank * 0x800 * 4;
 
@@ -143,33 +141,33 @@ static READ16_HANDLER( v_rom_r )
 static READ16_HANDLER( gp2_vram_r )
 {
 	if (offset < 0x1000/2)
-		return K056832_ram_word_r(offset*2+1, mem_mask);
+		return K056832_ram_word_r(space, offset*2+1, mem_mask);
 	else
-		return K056832_ram_word_r((offset-0x1000/2)*2, mem_mask);
+		return K056832_ram_word_r(space, (offset-0x1000/2)*2, mem_mask);
 }
 
 static READ16_HANDLER( gp2_vram_mirror_r )
 {
 	if (offset < 0x1000/2)
-		return K056832_ram_word_r(offset*2, mem_mask);
+		return K056832_ram_word_r(space, offset*2, mem_mask);
 	else
-		return K056832_ram_word_r((offset-0x1000/2)*2+1, mem_mask);
+		return K056832_ram_word_r(space, (offset-0x1000/2)*2+1, mem_mask);
 }
 
 static WRITE16_HANDLER( gp2_vram_w )
 {
 	if (offset < 0x1000/2)
-		K056832_ram_word_w(offset*2+1, data, mem_mask);
+		K056832_ram_word_w(space, offset*2+1, data, mem_mask);
 	else
-		K056832_ram_word_w((offset-0x1000/2)*2, data, mem_mask);
+		K056832_ram_word_w(space, (offset-0x1000/2)*2, data, mem_mask);
 }
 
 static WRITE16_HANDLER( gp2_vram_mirror_w )
 {
 	if (offset < 0x1000/2)
-		K056832_ram_word_w(offset*2, data, mem_mask);
+		K056832_ram_word_w(space, offset*2, data, mem_mask);
 	else
-		K056832_ram_word_w((offset-0x1000/2)*2+1, data, mem_mask);
+		K056832_ram_word_w(space, (offset-0x1000/2)*2+1, data, mem_mask);
 }
 
 
@@ -177,7 +175,7 @@ static WRITE16_HANDLER( gp2_vram_mirror_w )
 
 static READ16_HANDLER( sndram_r )
 {
-	if (ACCESSING_LSB16)
+	if (ACCESSING_BITS_0_7)
 			return sndram[offset];
 
 	return 0;
@@ -185,7 +183,7 @@ static READ16_HANDLER( sndram_r )
 
 static WRITE16_HANDLER( sndram_w )
 {
-	if (ACCESSING_LSB16)
+	if (ACCESSING_BITS_0_7)
 	{
 		sndram[offset] = data & 0xff;
 		if (offset >= 0x40000)
@@ -195,16 +193,16 @@ static WRITE16_HANDLER( sndram_w )
 
 static READ16_HANDLER( k054539_word_r )
 {
-	if (ACCESSING_LSB16)
-		return K054539_0_r(offset);
+	if (ACCESSING_BITS_0_7)
+		return k054539_0_r(space, offset);
 
 	return 0;
 }
 
 static WRITE16_HANDLER( k054539_word_w )
 {
-	if (ACCESSING_LSB16)
-		K054539_0_w(offset, data);
+	if (ACCESSING_BITS_0_7)
+		k054539_0_w(space, offset, data);
 }
 
 /*************/
@@ -212,47 +210,48 @@ static WRITE16_HANDLER( k054539_word_w )
 #define IDE_STD_OFFSET	(0x1f0/2)
 #define IDE_ALT_OFFSET	(0x3f6/2)
 
-static READ16_HANDLER( ide_std_r )
+static READ16_DEVICE_HANDLER( ide_std_r )
 {
 	if (offset & 0x01)
-		return ide_controller16_0_r(IDE_STD_OFFSET + offset/2, 0x00ff) >> 8;
+		return ide_controller16_r(device, IDE_STD_OFFSET + offset/2, 0xff00) >> 8;
 	else
-		return ide_controller16_0_r(IDE_STD_OFFSET + offset/2, 0x0000);
+		return ide_controller16_r(device, IDE_STD_OFFSET + offset/2, 0xffff);
 }
 
-static WRITE16_HANDLER( ide_std_w )
+static WRITE16_DEVICE_HANDLER( ide_std_w )
 {
 	if (offset & 0x01)
-		ide_controller16_0_w(IDE_STD_OFFSET + offset/2, data << 8, 0x00ff);
+		ide_controller16_w(device, IDE_STD_OFFSET + offset/2, data << 8, 0xff00);
 	else
-		ide_controller16_0_w(IDE_STD_OFFSET + offset/2, data, 0x0000);
+		ide_controller16_w(device, IDE_STD_OFFSET + offset/2, data, 0xffff);
 }
 
-static READ16_HANDLER( ide_alt_r )
+static READ16_DEVICE_HANDLER( ide_alt_r )
 {
 	if (offset == 0)
-		return ide_controller16_0_r(IDE_ALT_OFFSET, 0xff00);
+		return ide_controller16_r(device, IDE_ALT_OFFSET, 0x00ff);
 
 	return 0;
 }
 
-static WRITE16_HANDLER( ide_alt_w )
+static WRITE16_DEVICE_HANDLER( ide_alt_w )
 {
 	if (offset == 0)
-		ide_controller16_0_w(IDE_ALT_OFFSET, data, 0xff00);
+		ide_controller16_w(device, IDE_ALT_OFFSET, data, 0x00ff);
 }
 
 
 static READ16_HANDLER( gp2_ide_std_r )
 {
+	const device_config *device = devtag_get_device(space->machine, IDE_CONTROLLER, "ide");
 	if (offset & 0x01)
 	{
 		if (offset == 0x07)
 		{
-			switch (activecpu_get_previouspc())
+			switch (cpu_get_previouspc(space->cpu))
 			{
 				case 0xdb4c:
-					if ((workram[0x5fa4/2] - activecpu_get_reg(M68K_D0)) <= 0x10)
+					if ((workram[0x5fa4/2] - cpu_get_reg(space->cpu, M68K_D0)) <= 0x10)
 						gp2_irq_control = 1;
 					break;
 				case 0xdec2:
@@ -261,9 +260,9 @@ static READ16_HANDLER( gp2_ide_std_r )
 					break;
 			}
 		}
-		return ide_controller16_0_r(IDE_STD_OFFSET + offset/2, 0x00ff) >> 8;
+		return ide_controller16_r(device, IDE_STD_OFFSET + offset/2, 0xff00) >> 8;
 	} else {
-		return ide_controller16_0_r(IDE_STD_OFFSET + offset/2, 0x0000);
+		return ide_controller16_r(device, IDE_STD_OFFSET + offset/2, 0xffff);
 	}
 }
 
@@ -276,29 +275,29 @@ static READ16_HANDLER( gp2_ide_std_r )
 
 static INTERRUPT_GEN(qdrmfgp_interrupt)
 {
-	switch (cpu_getiloops())
+	switch (cpu_getiloops(device))
 	{
 		case 0:
 			if (control & 0x0001)
-				cpunum_set_input_line(machine, 0, 1, HOLD_LINE);
+				cpu_set_input_line(device, 1, HOLD_LINE);
 			break;
 
 		case 1:
 			/* trigger V-blank interrupt */
 			if (control & 0x0004)
-				cpunum_set_input_line(machine, 0, 3, HOLD_LINE);
+				cpu_set_input_line(device, 3, HOLD_LINE);
 			break;
 	}
 }
 
-static void ide_interrupt(int state)
+static void ide_interrupt(const device_config *device, int state)
 {
 	if (control & 0x0008)
 	{
 		if (state != CLEAR_LINE)
-			cpunum_set_input_line(Machine, 0, 4, HOLD_LINE);
+			cpu_set_input_line(device->machine->cpu[0], 4, HOLD_LINE);
 		else
-			cpunum_set_input_line(Machine, 0, 4, CLEAR_LINE);
+			cpu_set_input_line(device->machine->cpu[0], 4, CLEAR_LINE);
 	}
 }
 
@@ -307,17 +306,17 @@ static void ide_interrupt(int state)
 static TIMER_CALLBACK( gp2_timer_callback )
 {
 	if (control & 0x0004)
-		cpunum_set_input_line(machine, 0, 3, HOLD_LINE);
+		cpu_set_input_line(machine->cpu[0], 3, HOLD_LINE);
 }
 
 static INTERRUPT_GEN(qdrmfgp2_interrupt)
 {
 	/* trigger V-blank interrupt */
 	if (control & 0x0008)
-		cpunum_set_input_line(machine, 0, 4, HOLD_LINE);
+		cpu_set_input_line(device, 4, HOLD_LINE);
 }
 
-static void gp2_ide_interrupt(int state)
+static void gp2_ide_interrupt(const device_config *device, int state)
 {
 	if (control & 0x0010)
 	{
@@ -326,9 +325,9 @@ static void gp2_ide_interrupt(int state)
 			if (gp2_irq_control)
 				gp2_irq_control = 0;
 			else
-				cpunum_set_input_line(Machine, 0, 5, HOLD_LINE);
+				cpu_set_input_line(device->machine->cpu[0], 5, HOLD_LINE);
 		} else {
-			cpunum_set_input_line(Machine, 0, 5, CLEAR_LINE);
+			cpu_set_input_line(device->machine->cpu[0], 5, CLEAR_LINE);
 		}
 	}
 }
@@ -341,75 +340,75 @@ static void gp2_ide_interrupt(int state)
  *************************************/
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x100000, 0x10ffff) AM_READ(MRA16_RAM)				/* work ram */
-	AM_RANGE(0x180000, 0x183fff) AM_READ(MRA16_RAM)				/* backup ram */
-	AM_RANGE(0x280000, 0x280fff) AM_READ(MRA16_RAM)				/* color ram */
+	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM)
+	AM_RANGE(0x100000, 0x10ffff) AM_READ(SMH_RAM)				/* work ram */
+	AM_RANGE(0x180000, 0x183fff) AM_READ(SMH_RAM)				/* backup ram */
+	AM_RANGE(0x280000, 0x280fff) AM_READ(SMH_RAM)				/* color ram */
 	AM_RANGE(0x320000, 0x32001f) AM_READ(K053252_word_r)		/* ccu */
-	AM_RANGE(0x330000, 0x330001) AM_READ(i_port2_r)				/* battery power & service sw */
-	AM_RANGE(0x340000, 0x340001) AM_READ(i_port1_r)				/* inputport */
+	AM_RANGE(0x330000, 0x330001) AM_READ_PORT("SENSOR")			/* battery power & service sw */
+	AM_RANGE(0x340000, 0x340001) AM_READ_PORT("340000")			/* inputport */
 	AM_RANGE(0x800000, 0x80045f) AM_READ(k054539_word_r)		/* sound regs */
 	AM_RANGE(0x880000, 0x881fff) AM_READ(K056832_ram_word_r)	/* vram */
 	AM_RANGE(0x882000, 0x883fff) AM_READ(K056832_ram_word_r)	/* vram (mirror) */
 	AM_RANGE(0x900000, 0x901fff) AM_READ(v_rom_r)				/* gfxrom through */
-	AM_RANGE(0xa00000, 0xa0000f) AM_READ(ide_std_r)				/* IDE control regs */
-	AM_RANGE(0xa4000c, 0xa4000f) AM_READ(ide_alt_r)				/* IDE status control reg */
+	AM_RANGE(0xa00000, 0xa0000f) AM_DEVREAD(IDE_CONTROLLER, "ide", ide_std_r)				/* IDE control regs */
+	AM_RANGE(0xa4000c, 0xa4000f) AM_DEVREAD(IDE_CONTROLLER, "ide", ide_alt_r)				/* IDE status control reg */
 	AM_RANGE(0xc00000, 0xcbffff) AM_READ(sndram_r)				/* sound ram */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(MWA16_ROM)
-	AM_RANGE(0x100000, 0x10ffff) AM_WRITE(MWA16_RAM) AM_BASE(&workram) 	/* work ram */
-	AM_RANGE(0x180000, 0x183fff) AM_WRITE(MWA16_RAM) AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)	/* backup ram */
+	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x100000, 0x10ffff) AM_WRITE(SMH_RAM) AM_BASE(&workram) 	/* work ram */
+	AM_RANGE(0x180000, 0x183fff) AM_WRITE(SMH_RAM) AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)	/* backup ram */
 	AM_RANGE(0x280000, 0x280fff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x300000, 0x30003f) AM_WRITE(K056832_word_w)		/* video reg */
 	AM_RANGE(0x320000, 0x32001f) AM_WRITE(K053252_word_w)		/* ccu */
-	AM_RANGE(0x350000, 0x350001) AM_WRITE(MWA16_NOP)			/* unknown */
-	AM_RANGE(0x360000, 0x360001) AM_WRITE(MWA16_NOP)			/* unknown */
+	AM_RANGE(0x350000, 0x350001) AM_WRITE(SMH_NOP)			/* unknown */
+	AM_RANGE(0x360000, 0x360001) AM_WRITE(SMH_NOP)			/* unknown */
 	AM_RANGE(0x370000, 0x370001) AM_WRITE(gp_control_w)			/* control reg */
-	AM_RANGE(0x380000, 0x380001) AM_WRITE(MWA16_NOP)			/* Watchdog */
+	AM_RANGE(0x380000, 0x380001) AM_WRITE(SMH_NOP)			/* Watchdog */
 	AM_RANGE(0x800000, 0x80045f) AM_WRITE(k054539_word_w)		/* sound regs */
 	AM_RANGE(0x880000, 0x881fff) AM_WRITE(K056832_ram_word_w)	/* vram */
 	AM_RANGE(0x882000, 0x883fff) AM_WRITE(K056832_ram_word_w)	/* vram (mirror) */
-	AM_RANGE(0xa00000, 0xa0000f) AM_WRITE(ide_std_w)			/* IDE control regs */
-	AM_RANGE(0xa4000c, 0xa4000f) AM_WRITE(ide_alt_w)			/* IDE status control reg */
+	AM_RANGE(0xa00000, 0xa0000f) AM_DEVWRITE(IDE_CONTROLLER, "ide", ide_std_w)			/* IDE control regs */
+	AM_RANGE(0xa4000c, 0xa4000f) AM_DEVWRITE(IDE_CONTROLLER, "ide", ide_alt_w)			/* IDE status control reg */
 	AM_RANGE(0xc00000, 0xcbffff) AM_WRITE(sndram_w)				/* sound ram */
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( gp2_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x100000, 0x110fff) AM_READ(MRA16_RAM)				/* work ram */
-	AM_RANGE(0x180000, 0x183fff) AM_READ(MRA16_RAM)				/* backup ram */
-	AM_RANGE(0x280000, 0x280fff) AM_READ(MRA16_RAM)				/* color ram */
+	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM)
+	AM_RANGE(0x100000, 0x110fff) AM_READ(SMH_RAM)				/* work ram */
+	AM_RANGE(0x180000, 0x183fff) AM_READ(SMH_RAM)				/* backup ram */
+	AM_RANGE(0x280000, 0x280fff) AM_READ(SMH_RAM)				/* color ram */
 	AM_RANGE(0x320000, 0x32001f) AM_READ(K053252_word_r)		/* ccu */
-	AM_RANGE(0x330000, 0x330001) AM_READ(i_port2_r)				/* battery power & service */
-	AM_RANGE(0x340000, 0x340001) AM_READ(i_port1_r)				/* inputport */
+	AM_RANGE(0x330000, 0x330001) AM_READ_PORT("SENSOR")			/* battery power & service */
+	AM_RANGE(0x340000, 0x340001) AM_READ_PORT("340000")			/* inputport */
 	AM_RANGE(0x800000, 0x80045f) AM_READ(k054539_word_r)		/* sound regs */
 	AM_RANGE(0x880000, 0x881fff) AM_READ(gp2_vram_r)			/* vram */
 	AM_RANGE(0x89f000, 0x8a0fff) AM_READ(gp2_vram_mirror_r)		/* vram (mirror) */
 	AM_RANGE(0x900000, 0x901fff) AM_READ(v_rom_r)				/* gfxrom through */
 	AM_RANGE(0xa00000, 0xa0000f) AM_READ(gp2_ide_std_r)			/* IDE control regs */
-	AM_RANGE(0xa4000c, 0xa4000f) AM_READ(ide_alt_r)				/* IDE status control reg */
+	AM_RANGE(0xa4000c, 0xa4000f) AM_DEVREAD(IDE_CONTROLLER, "ide", ide_alt_r)				/* IDE status control reg */
 	AM_RANGE(0xc00000, 0xcbffff) AM_READ(sndram_r)				/* sound ram */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( gp2_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(MWA16_ROM)
-	AM_RANGE(0x100000, 0x110fff) AM_WRITE(MWA16_RAM) AM_BASE(&workram)	/* work ram */
-	AM_RANGE(0x180000, 0x183fff) AM_WRITE(MWA16_RAM) AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)	/* backup ram */
+	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x100000, 0x110fff) AM_WRITE(SMH_RAM) AM_BASE(&workram)	/* work ram */
+	AM_RANGE(0x180000, 0x183fff) AM_WRITE(SMH_RAM) AM_BASE(&generic_nvram16) AM_SIZE(&generic_nvram_size)	/* backup ram */
 	AM_RANGE(0x280000, 0x280fff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x300000, 0x30003f) AM_WRITE(K056832_word_w)		/* video reg */
 	AM_RANGE(0x320000, 0x32001f) AM_WRITE(K053252_word_w)		/* ccu */
-	AM_RANGE(0x350000, 0x350001) AM_WRITE(MWA16_NOP)			/* unknown */
-	AM_RANGE(0x360000, 0x360001) AM_WRITE(MWA16_NOP)			/* unknown */
+	AM_RANGE(0x350000, 0x350001) AM_WRITE(SMH_NOP)			/* unknown */
+	AM_RANGE(0x360000, 0x360001) AM_WRITE(SMH_NOP)			/* unknown */
 	AM_RANGE(0x370000, 0x370001) AM_WRITE(gp2_control_w)		/* control reg */
-	AM_RANGE(0x380000, 0x380001) AM_WRITE(MWA16_NOP)			/* Watchdog */
+	AM_RANGE(0x380000, 0x380001) AM_WRITE(SMH_NOP)			/* Watchdog */
 	AM_RANGE(0x800000, 0x80045f) AM_WRITE(k054539_word_w)		/* sound regs */
 	AM_RANGE(0x880000, 0x881fff) AM_WRITE(gp2_vram_w)			/* vram */
 	AM_RANGE(0x89f000, 0x8a0fff) AM_WRITE(gp2_vram_mirror_w)	/* vram (mirror) */
-	AM_RANGE(0xa00000, 0xa0000f) AM_WRITE(ide_std_w)			/* IDE control regs */
-	AM_RANGE(0xa4000c, 0xa4000f) AM_WRITE(ide_alt_w)			/* IDE status control reg */
+	AM_RANGE(0xa00000, 0xa0000f) AM_DEVWRITE(IDE_CONTROLLER, "ide", ide_std_w)			/* IDE control regs */
+	AM_RANGE(0xa4000c, 0xa4000f) AM_DEVWRITE(IDE_CONTROLLER, "ide", ide_alt_w)			/* IDE status control reg */
 	AM_RANGE(0xc00000, 0xcbffff) AM_WRITE(sndram_w)				/* sound ram */
 ADDRESS_MAP_END
 
@@ -421,7 +420,10 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( qdrmfgp )
-	PORT_START
+	PORT_START("340000")
+	PORT_BIT( 0xffff, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(inputs_r, "INPUTS\0DSW")
+
+	PORT_START("INPUTS")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_BUTTON5 ) PORT_PLAYER(1)	/* 1P STOP */
@@ -438,11 +440,11 @@ static INPUT_PORTS_START( qdrmfgp )
 	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(2)
 
 	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_SERVICE1 )	/* SERVICE */
-	PORT_BIT(0x2000, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2)	/* TEST SW */
+	PORT_SERVICE_NO_TOGGLE( 0x2000, IP_ACTIVE_LOW )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_TILT )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_COIN1 )
 
-	PORT_START
+	PORT_START("DSW")
 	PORT_BIT( 0x0003, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_DIPNAME( 0x0004, 0x0004, "Extended Service Menu" )		/* and skipped initial checks. */
 	PORT_DIPSETTING(    0x0004, DEF_STR( Off ) )
@@ -493,15 +495,18 @@ static INPUT_PORTS_START( qdrmfgp )
 	PORT_DIPSETTING(      0x8000, DEF_STR( Hard ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Very_Hard ) )
 
-	PORT_START
-	PORT_BIT( 0x0003, IP_ACTIVE_LOW, IPT_SPECIAL )		/* battery power sensor */
+	PORT_START("SENSOR")
+	PORT_BIT( 0x0003, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(battery_sensor_r, NULL)	/* battery power sensor */
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_SERVICE2 )
 	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_SERVICE3 )
 	PORT_BIT( 0xfff0, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( qdrmfgp2 )
-	PORT_START
+	PORT_START("340000")
+	PORT_BIT( 0xffff, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(inputs_r, "INPUTS\0DSW")
+
+	PORT_START("INPUTS")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_BUTTON5 ) PORT_PLAYER(1)	/* 1P STOP */
@@ -518,11 +523,11 @@ static INPUT_PORTS_START( qdrmfgp2 )
 	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(2)
 
 	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_SERVICE1 )	/* SERVICE */
-	PORT_BIT(0x2000, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2)	/* TEST */
+	PORT_SERVICE_NO_TOGGLE( 0x2000, IP_ACTIVE_LOW )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_TILT )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_COIN1 )
 
-	PORT_START
+	PORT_START("DSW")
 	PORT_BIT( 0x0003, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_DIPNAME( 0x0004, 0x0004, "Extended Service Menu & None Sounds Mode" )		/* and skipped initial checks. */
 	PORT_DIPSETTING(    0x0004, DEF_STR( Off ) )
@@ -573,8 +578,8 @@ static INPUT_PORTS_START( qdrmfgp2 )
 	PORT_DIPSETTING(      0x8000, DEF_STR( Hard ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( Very_Hard ) )
 
-	PORT_START
-	PORT_BIT( 0x0003, IP_ACTIVE_LOW, IPT_SPECIAL )		/* battery power sensor */
+	PORT_START("SENSOR")
+	PORT_BIT( 0x0003, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(battery_sensor_r, NULL)	/* battery power sensor */
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_SERVICE2 )
 	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_SERVICE3 )
 	PORT_BIT( 0xfff0, IP_ACTIVE_LOW, IPT_UNUSED )
@@ -588,47 +593,25 @@ INPUT_PORTS_END
  *************************************/
 
 
-/*************************************
- *
- *  IDE interfaces
- *
- *************************************/
-
-static const struct ide_interface ide_intf =
-{
-	ide_interrupt,
-};
-
-static const struct ide_interface gp2_ide_intf =
-{
-	gp2_ide_interrupt,
-};
-
-
 /*************************************
  *
  *  Sound interfaces
  *
  *************************************/
 
-static void sound_irq(void)
+static void sound_irq(running_machine *machine)
 {
 	if (control & 0x0001)
-		cpunum_set_input_line(Machine, 0, 1, HOLD_LINE);
+		cpu_set_input_line(machine->cpu[0], 1, HOLD_LINE);
 }
 
-static const struct K054539interface k054539_interface =
+static const k054539_interface k054539_config =
 {
-	REGION_SOUND1,
+	NULL,
 	NULL,
 	sound_irq
 };
 
-static const struct K054539interface gp2_k054539_interface =
-{
-	REGION_SOUND1
-};
-
 
 /*************************************
  *
@@ -638,30 +621,30 @@ static const struct K054539interface gp2_k054539_interface =
 
 static MACHINE_START( qdrmfgp )
 {
-	state_save_register_global(control);
-	state_save_register_global(qdrmfgp_pal);
-	state_save_register_global(gp2_irq_control);
+	state_save_register_global(machine, control);
+	state_save_register_global(machine, qdrmfgp_pal);
+	state_save_register_global(machine, gp2_irq_control);
 }
 
 static MACHINE_RESET( qdrmfgp )
 {
-	sndram = memory_region(REGION_SOUND1) + 0x100000;
+	sndram = memory_region(machine, "konami") + 0x100000;
 
 	/* reset the IDE controller */
 	gp2_irq_control = 0;
-	ide_controller_reset(0);
+	devtag_reset(machine, IDE_CONTROLLER, "ide");
 }
 
 static MACHINE_RESET( qdrmfgp2 )
 {
-	sndram = memory_region(REGION_SOUND1) + 0x100000;
+	sndram = memory_region(machine, "konami") + 0x100000;
 
 	/* sound irq (CCU? 240Hz) */
-	timer_pulse(ATTOTIME_IN_HZ(18432000/76800), NULL, 0, gp2_timer_callback);
+	timer_pulse(machine, ATTOTIME_IN_HZ(18432000/76800), NULL, 0, gp2_timer_callback);
 
 	/* reset the IDE controller */
 	gp2_irq_control = 0;
-	ide_controller_reset(0);
+	devtag_reset(machine, IDE_CONTROLLER, "ide");
 }
 
 
@@ -674,22 +657,24 @@ static MACHINE_RESET( qdrmfgp2 )
 static MACHINE_DRIVER_START( qdrmfgp )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000, 32000000/2)	/*  16.000 MHz */
+	MDRV_CPU_ADD("main", M68000, 32000000/2)	/*  16.000 MHz */
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_VBLANK_INT(qdrmfgp_interrupt, 2)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT_HACK(qdrmfgp_interrupt, 2)
 
 	MDRV_MACHINE_START(qdrmfgp)
 	MDRV_MACHINE_RESET(qdrmfgp)
 	MDRV_NVRAM_HANDLER(generic_1fill)
 
+	MDRV_IDE_CONTROLLER_ADD("ide", ide_interrupt)
+
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(40, 40+384-1, 16, 16+224-1)
+
 	MDRV_PALETTE_LENGTH(2048)
 
 	MDRV_VIDEO_START(qdrmfgp)
@@ -698,8 +683,8 @@ static MACHINE_DRIVER_START( qdrmfgp )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(K054539, 18432000/384)
-	MDRV_SOUND_CONFIG(k054539_interface)
+	MDRV_SOUND_ADD("konami", K054539, 18432000/384)
+	MDRV_SOUND_CONFIG(k054539_config)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
@@ -707,22 +692,24 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( qdrmfgp2 )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000, 32000000/2)	/*  16.000 MHz */
+	MDRV_CPU_ADD("main", M68000, 32000000/2)	/*  16.000 MHz */
 	MDRV_CPU_PROGRAM_MAP(gp2_readmem,gp2_writemem)
-	MDRV_CPU_VBLANK_INT(qdrmfgp2_interrupt, 1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", qdrmfgp2_interrupt)
 
 	MDRV_MACHINE_START(qdrmfgp)
 	MDRV_MACHINE_RESET(qdrmfgp2)
 	MDRV_NVRAM_HANDLER(generic_1fill)
 
+	MDRV_IDE_CONTROLLER_ADD("ide", gp2_ide_interrupt)
+
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(40, 40+384-1, 16, 16+224-1)
+
 	MDRV_PALETTE_LENGTH(2048)
 
 	MDRV_VIDEO_START(qdrmfgp2)
@@ -731,8 +718,7 @@ static MACHINE_DRIVER_START( qdrmfgp2 )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(K054539, 18432000/384)
-	MDRV_SOUND_CONFIG(gp2_k054539_interface)
+	MDRV_SOUND_ADD("konami", K054539, 18432000/384)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
@@ -745,58 +731,40 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( qdrmfgp )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, "main", 0 )
 	ROM_LOAD16_WORD_SWAP( "gq_460_b04.20e", 0x000000, 0x80000, CRC(293d8174) SHA1(cf507d0b29dab161190f0160c05c640f16306bae) )
 	ROM_LOAD16_WORD_SWAP( "gq_460_a05.22e", 0x080000, 0x80000, CRC(4128cb3c) SHA1(4a16d85a66934a20afd074546de362c40a1ea785) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, 0 )		/* TILEMAP */
+	ROM_REGION( 0x100000, "gfx1", 0 )		/* TILEMAP */
 	ROM_LOAD( "gq_460_a01.15e", 0x000000, 0x80000, CRC(6536b700) SHA1(47ffe0cfbf80810179560150b23d825fe1a5c5ca) )
 	ROM_LOAD( "gq_460_a02.17e", 0x080000, 0x80000, CRC(ac01d675) SHA1(bf66433ace95f4ef14699d03add7cbc2e5d90eea) )
 
-	ROM_REGION( 0x460000, REGION_SOUND1, 0)		/* SE SAMPLES + space for additional RAM */
+	ROM_REGION( 0x460000, "konami", 0)		/* SE SAMPLES + space for additional RAM */
 	ROM_LOAD( "gq_460_a07.14h", 0x000000, 0x80000, CRC(67d8ea6b) SHA1(11af1b5a33de2a6e24823964d210bef193ecefe4) )
 	ROM_LOAD( "gq_460_a06.12h", 0x080000, 0x80000, CRC(97ed5a77) SHA1(68600fd8d914451284cf181fb4bd5872860fb9ad) )
 
-	DISK_REGION( REGION_DISKS )			/* IDE HARD DRIVE */
+	DISK_REGION( "ide" )			/* IDE HARD DRIVE */
 	DISK_IMAGE( "gq460a08", 0, MD5(b79eebad38782e6713ab0bd7560817a2) SHA1(0cae7769fbb603d3c3e3627dde84a6c5a9b1062d) )
 ROM_END
 
 ROM_START( qdrmfgp2 )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, "main", 0 )
 	ROM_LOAD16_WORD_SWAP( "ge_557_c05.20e", 0x000000, 0x80000, CRC(336df99f) SHA1(46fb36d40371761be0cfa17b34f28cc893a44a22) )
 	ROM_LOAD16_WORD_SWAP( "ge_557_a06.22e", 0x080000, 0x80000, CRC(ad77e10f) SHA1(4a762a59fe3096d48e3cbf0da3bb0d75c5087e78) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, 0 )		/* TILEMAP */
+	ROM_REGION( 0x100000, "gfx1", 0 )		/* TILEMAP */
 	ROM_LOAD( "ge_557_a01.13e", 0x000000, 0x80000, CRC(c301d406) SHA1(5fad8cc611edd83380972abf37ec80561b9317a6) )
 	ROM_LOAD( "ge_557_a02.15e", 0x080000, 0x80000, CRC(3bfe1e56) SHA1(9e4df512a804a96fcb545d4e0eb58b5421d65ea4) )
 
-	ROM_REGION( 0x460000, REGION_SOUND1, 0)		/* SE SAMPLES + space for additional RAM */
+	ROM_REGION( 0x460000, "konami", 0)		/* SE SAMPLES + space for additional RAM */
 	ROM_LOAD( "ge_557_a07.19h", 0x000000, 0x80000, CRC(7491e0c8) SHA1(6459ab5e7af052ef7a1c4ce01cd844c0f4319f2e) )
 	ROM_LOAD( "ge_557_a08.19k", 0x080000, 0x80000, CRC(3da2b20c) SHA1(fdc2cdc27f3299f541944a78ce36ed33a7926056) )
 
-	DISK_REGION( REGION_DISKS )			/* IDE HARD DRIVE */
+	DISK_REGION( "ide" )			/* IDE HARD DRIVE */
 	DISK_IMAGE( "ge557a09", 0, MD5(df5039dc4e9dbb1f02ec408d839a42db) SHA1(5e836dbace34c9c1b107cce6a50071a4205a1534) )
 ROM_END
 
 
-/*************************************
- *
- *  Driver-specific init
- *
- *************************************/
-
-static DRIVER_INIT( qdrmfgp )
-{
-	/* spin up the hard disk */
-	ide_controller_init(0, &ide_intf);
-}
-
-static DRIVER_INIT( qdrmfgp2 )
-{
-	/* spin up the hard disk */
-	ide_controller_init(0, &gp2_ide_intf);
-}
-
 /*************************************
  *
  *  Game drivers
@@ -804,5 +772,5 @@ static DRIVER_INIT( qdrmfgp2 )
  *************************************/
 
 /*     year  rom       clone     machine   inputs    init */
-GAME(  1994, qdrmfgp,  0,        qdrmfgp,  qdrmfgp,  qdrmfgp,  ROT0, "Konami", "Quiz Do Re Mi Fa Grand Prix (Japan)", 0 )
-GAME(  1995, qdrmfgp2, 0,        qdrmfgp2, qdrmfgp2, qdrmfgp2, ROT0, "Konami", "Quiz Do Re Mi Fa Grand Prix2 - Shin-Kyoku Nyuukadayo (Japan)", 0 )
+GAME(  1994, qdrmfgp,  0,        qdrmfgp,  qdrmfgp,  0,        ROT0, "Konami", "Quiz Do Re Mi Fa Grand Prix (Japan)", 0 )
+GAME(  1995, qdrmfgp2, 0,        qdrmfgp2, qdrmfgp2, 0,        ROT0, "Konami", "Quiz Do Re Mi Fa Grand Prix2 - Shin-Kyoku Nyuukadayo (Japan)", 0 )
