@@ -9,6 +9,7 @@ Quiz Gekiretsu Scramble (Gakuen Paradise 2) (c) 1993 Face
 *****************************************************************************/
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
 #include "sound/2203intf.h"
 #include "sound/okim6295.h"
 
@@ -28,96 +29,97 @@ WRITE8_HANDLER( paletteram_xBGR_RRRR_GGGG_BBBB_w );
 
 static WRITE8_HANDLER( quizdna_rombank_w )
 {
-	UINT8 *ROM = memory_region(REGION_CPU1);
-	memory_set_bankptr(1,&ROM[0x10000+0x4000*(data & 0x3f)]);
+	UINT8 *ROM = memory_region(space->machine, "main");
+	memory_set_bankptr(space->machine, 1,&ROM[0x10000+0x4000*(data & 0x3f)]);
 }
 
 static WRITE8_HANDLER( gekiretu_rombank_w )
 {
-	UINT8 *ROM = memory_region(REGION_CPU1);
-	memory_set_bankptr(1,&ROM[0x10000+0x4000*((data & 0x3f) ^ 0x0a)]);
+	UINT8 *ROM = memory_region(space->machine, "main");
+	memory_set_bankptr(space->machine, 1,&ROM[0x10000+0x4000*((data & 0x3f) ^ 0x0a)]);
 }
 
 /****************************************************************************/
 
 static ADDRESS_MAP_START( quizdna_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(MRA8_BANK1)
-	AM_RANGE(0xc000, 0xffff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_BANK1)
+	AM_RANGE(0xc000, 0xffff) AM_READ(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( quizdna_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x0000, 0x7fff) AM_WRITE(SMH_ROM)
 	AM_RANGE(0x8000, 0x9fff) AM_WRITE(quizdna_fg_ram_w)
 	AM_RANGE(0xa000, 0xbfff) AM_WRITE(quizdna_bg_ram_w)
-	AM_RANGE(0xc000, 0xdfff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xe000, 0xe1ff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0xe200, 0xefff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0xc000, 0xdfff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0xe000, 0xe1ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+	AM_RANGE(0xe200, 0xefff) AM_WRITE(SMH_RAM)
 	AM_RANGE(0xf000, 0xffff) AM_WRITE(paletteram_xBGR_RRRR_GGGG_BBBB_w) AM_BASE(&paletteram)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( gekiretu_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x0000, 0x7fff) AM_WRITE(SMH_ROM)
 	AM_RANGE(0x8000, 0x9fff) AM_WRITE(quizdna_fg_ram_w)
 	AM_RANGE(0xa000, 0xbfff) AM_WRITE(quizdna_bg_ram_w)
-	AM_RANGE(0xc000, 0xdfff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0xc000, 0xdfff) AM_WRITE(SMH_RAM)
 	AM_RANGE(0xe000, 0xefff) AM_WRITE(paletteram_xBGR_RRRR_GGGG_BBBB_w) AM_BASE(&paletteram)
-	AM_RANGE(0xf000, 0xf1ff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0xf200, 0xffff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0xf000, 0xf1ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+	AM_RANGE(0xf200, 0xffff) AM_WRITE(SMH_RAM)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( quizdna_readport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x80, 0x80) AM_READ(input_port_2_r)
-	AM_RANGE(0x81, 0x81) AM_READ(input_port_3_r)
-	AM_RANGE(0x90, 0x90) AM_READ(input_port_4_r)
-	AM_RANGE(0x91, 0x91) AM_READ(input_port_5_r)
-	AM_RANGE(0xe0, 0xe0) AM_READ(YM2203_status_port_0_r)
-	AM_RANGE(0xe1, 0xe1) AM_READ(YM2203_read_port_0_r)
-	AM_RANGE(0xf0, 0xf0) AM_READ(OKIM6295_status_0_r)
-
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( quizdna_writeport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+static ADDRESS_MAP_START( quizdna_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x02, 0x03) AM_WRITE(quizdna_bg_xscroll_w)
 	AM_RANGE(0x04, 0x04) AM_WRITE(quizdna_bg_yscroll_w)
-	AM_RANGE(0x05, 0x06) AM_WRITE(MWA8_NOP) /* unknown */
+	AM_RANGE(0x05, 0x06) AM_WRITE(SMH_NOP) /* unknown */
+	AM_RANGE(0x80, 0x80) AM_READ_PORT("P1")
+	AM_RANGE(0x81, 0x81) AM_READ_PORT("P2")
+	AM_RANGE(0x90, 0x90) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0x91, 0x91) AM_READ_PORT("SERVICE")
 	AM_RANGE(0xc0, 0xc0) AM_WRITE(quizdna_rombank_w)
 	AM_RANGE(0xd0, 0xd0) AM_WRITE(quizdna_screen_ctrl_w)
-	AM_RANGE(0xe0, 0xe0) AM_WRITE(YM2203_control_port_0_w)
-	AM_RANGE(0xe1, 0xe1) AM_WRITE(YM2203_write_port_0_w)
-	AM_RANGE(0xf0, 0xf0) AM_WRITE(OKIM6295_data_0_w)
+	AM_RANGE(0xe0, 0xe0) AM_READWRITE(ym2203_status_port_0_r, ym2203_control_port_0_w)
+	AM_RANGE(0xe1, 0xe1) AM_READWRITE(ym2203_read_port_0_r, ym2203_write_port_0_w)
+	AM_RANGE(0xf0, 0xf0) AM_READWRITE(okim6295_status_0_r, okim6295_data_0_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( gakupara_writeport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+static ADDRESS_MAP_START( gakupara_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x01) AM_WRITE(quizdna_bg_xscroll_w)
 	AM_RANGE(0x02, 0x02) AM_WRITE(quizdna_bg_yscroll_w)
-	AM_RANGE(0x03, 0x04) AM_WRITE(MWA8_NOP) /* unknown */
+	AM_RANGE(0x03, 0x04) AM_WRITE(SMH_NOP) /* unknown */
+	AM_RANGE(0x80, 0x80) AM_READ_PORT("P1")
+	AM_RANGE(0x81, 0x81) AM_READ_PORT("P2")
+	AM_RANGE(0x90, 0x90) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0x91, 0x91) AM_READ_PORT("SERVICE")
 	AM_RANGE(0xc0, 0xc0) AM_WRITE(quizdna_rombank_w)
 	AM_RANGE(0xd0, 0xd0) AM_WRITE(quizdna_screen_ctrl_w)
-	AM_RANGE(0xe0, 0xe0) AM_WRITE(YM2203_control_port_0_w)
-	AM_RANGE(0xe1, 0xe1) AM_WRITE(YM2203_write_port_0_w)
-	AM_RANGE(0xf0, 0xf0) AM_WRITE(OKIM6295_data_0_w)
+	AM_RANGE(0xe0, 0xe0) AM_READWRITE(ym2203_status_port_0_r, ym2203_control_port_0_w)
+	AM_RANGE(0xe1, 0xe1) AM_READWRITE(ym2203_read_port_0_r, ym2203_write_port_0_w)
+	AM_RANGE(0xf0, 0xf0) AM_READWRITE(okim6295_status_0_r, okim6295_data_0_w)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( gekiretu_writeport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+static ADDRESS_MAP_START( gekiretu_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x02, 0x03) AM_WRITE(quizdna_bg_xscroll_w)
 	AM_RANGE(0x04, 0x04) AM_WRITE(quizdna_bg_yscroll_w)
-	AM_RANGE(0x05, 0x06) AM_WRITE(MWA8_NOP) /* unknown */
+	AM_RANGE(0x05, 0x06) AM_WRITE(SMH_NOP) /* unknown */
+	AM_RANGE(0x80, 0x80) AM_READ_PORT("P1")
+	AM_RANGE(0x81, 0x81) AM_READ_PORT("P2")
+	AM_RANGE(0x90, 0x90) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0x91, 0x91) AM_READ_PORT("SERVICE")
 	AM_RANGE(0xc0, 0xc0) AM_WRITE(gekiretu_rombank_w)
 	AM_RANGE(0xd0, 0xd0) AM_WRITE(quizdna_screen_ctrl_w)
-	AM_RANGE(0xe0, 0xe0) AM_WRITE(YM2203_control_port_0_w)
-	AM_RANGE(0xe1, 0xe1) AM_WRITE(YM2203_write_port_0_w)
-	AM_RANGE(0xf0, 0xf0) AM_WRITE(OKIM6295_data_0_w)
+	AM_RANGE(0xe0, 0xe0) AM_READWRITE(ym2203_status_port_0_r, ym2203_control_port_0_w)
+	AM_RANGE(0xe1, 0xe1) AM_READWRITE(ym2203_read_port_0_r, ym2203_write_port_0_w)
+	AM_RANGE(0xf0, 0xf0) AM_READWRITE(okim6295_status_0_r, okim6295_data_0_w)
 ADDRESS_MAP_END
 
+
 /****************************************************************************/
 
 static INPUT_PORTS_START( quizdna )
-	PORT_START  /* sw2 */
+	PORT_START("DSW2")
 	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coinage ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( 9C_1C ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( 8C_1C ) )
@@ -146,7 +148,7 @@ static INPUT_PORTS_START( quizdna )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_SERVICE( 0x80, IP_ACTIVE_LOW )
 
-	PORT_START  /* sw3 */
+	PORT_START("DSW3")
 	PORT_DIPNAME( 0x03, 0x02, "Timer" )
 	PORT_DIPSETTING(    0x03, "Slow" )
 	PORT_DIPSETTING(    0x02, DEF_STR( Normal ) )
@@ -169,7 +171,7 @@ static INPUT_PORTS_START( quizdna )
 	PORT_DIPSETTING(    0x00, DEF_STR( No ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( Yes ) )
 
-	PORT_START
+	PORT_START("P1")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON3 )
@@ -179,7 +181,7 @@ static INPUT_PORTS_START( quizdna )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("P2")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
@@ -189,7 +191,7 @@ static INPUT_PORTS_START( quizdna )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("SYSTEM")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -199,7 +201,7 @@ static INPUT_PORTS_START( quizdna )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START
+	PORT_START("SERVICE")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -211,7 +213,7 @@ static INPUT_PORTS_START( quizdna )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( gakupara )
-    PORT_START  /* sw2 */
+    PORT_START("DSW2")
 	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coinage ) )
 	PORT_DIPSETTING(    0x00, "10 Coins/1 Credit" )
 	PORT_DIPSETTING(    0x01, DEF_STR( 9C_1C ) )
@@ -241,7 +243,7 @@ static INPUT_PORTS_START( gakupara )
 	PORT_DIPSETTING(    0x40, "Fast" )
 	PORT_DIPSETTING(    0x00, "Very Fast" )
 
-	PORT_START  /* sw3 */
+	PORT_START("DSW3")
 	PORT_SERVICE( 0x01, IP_ACTIVE_LOW )
 	PORT_DIPNAME( 0x02, 0x02, "Unknown 3-2" )
 	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
@@ -265,7 +267,7 @@ static INPUT_PORTS_START( gakupara )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("P1")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON3 )
@@ -275,7 +277,7 @@ static INPUT_PORTS_START( gakupara )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("P2")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
@@ -285,7 +287,7 @@ static INPUT_PORTS_START( gakupara )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("SYSTEM")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -295,7 +297,7 @@ static INPUT_PORTS_START( gakupara )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START
+	PORT_START("SERVICE")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -307,7 +309,7 @@ static INPUT_PORTS_START( gakupara )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( gekiretu )
-	PORT_START  /* dsw2 */
+	PORT_START("DSW2")
 	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coinage ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( 9C_1C ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( 8C_1C ) )
@@ -336,7 +338,7 @@ static INPUT_PORTS_START( gekiretu )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_SERVICE( 0x80, IP_ACTIVE_LOW )
 
-	PORT_START  /* dsw3 */
+	PORT_START("DSW3")
 	PORT_DIPNAME( 0x03, 0x03, "Timer" )
 	PORT_DIPSETTING(    0x03, "Slow" )
 	PORT_DIPSETTING(    0x02, DEF_STR( Normal ) )
@@ -360,7 +362,7 @@ static INPUT_PORTS_START( gekiretu )
 	PORT_DIPSETTING(    0x00, DEF_STR( No ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( Yes ) )
 
-	PORT_START
+	PORT_START("P1")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON3 )
@@ -370,7 +372,7 @@ static INPUT_PORTS_START( gekiretu )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("P2")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
@@ -380,7 +382,7 @@ static INPUT_PORTS_START( gekiretu )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("SYSTEM")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -390,7 +392,7 @@ static INPUT_PORTS_START( gekiretu )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START
+	PORT_START("SERVICE")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -437,35 +439,42 @@ static const gfx_layout objlayout =
 };
 
 static GFXDECODE_START( quizdna )
-	GFXDECODE_ENTRY( REGION_GFX1, 0x0000, fglayout,  0x7e0,  16 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x0000, bglayout,  0x000, 128 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x0000, objlayout, 0x600,  32 )
+	GFXDECODE_ENTRY( "gfx1", 0x0000, fglayout,  0x7e0,  16 )
+	GFXDECODE_ENTRY( "gfx2", 0x0000, bglayout,  0x000, 128 )
+	GFXDECODE_ENTRY( "gfx3", 0x0000, objlayout, 0x600,  32 )
 GFXDECODE_END
 
 
-static const struct YM2203interface ym2203_interface =
+static const ym2203_interface ym2203_config =
 {
-	input_port_1_r,
-	input_port_0_r
+	{
+		AY8910_LEGACY_OUTPUT,
+		AY8910_DEFAULT_LOADS,
+		input_port_1_r,
+		input_port_0_r,
+		NULL,
+		NULL
+	},
+	NULL
 };
 
 
 static MACHINE_DRIVER_START( quizdna )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", Z80, MCLK/2) /* 8.000 MHz */
+	MDRV_CPU_ADD("main", Z80, MCLK/2) /* 8.000 MHz */
 	MDRV_CPU_PROGRAM_MAP(quizdna_readmem,quizdna_writemem)
-	MDRV_CPU_IO_MAP(quizdna_readport,quizdna_writeport)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_CPU_IO_MAP(quizdna_io_map,0)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(8*8, 56*8-1, 2*8, 30*8-1)
+
 	MDRV_GFXDECODE(quizdna)
 	MDRV_PALETTE_LENGTH(2048)
 
@@ -475,15 +484,15 @@ static MACHINE_DRIVER_START( quizdna )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM2203, MCLK/4)
-	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ADD("ym", YM2203, MCLK/4)
+	MDRV_SOUND_CONFIG(ym2203_config)
 	MDRV_SOUND_ROUTE(0, "mono", 0.10)
 	MDRV_SOUND_ROUTE(1, "mono", 0.10)
 	MDRV_SOUND_ROUTE(2, "mono", 0.10)
 	MDRV_SOUND_ROUTE(3, "mono", 0.40)
 
-	MDRV_SOUND_ADD(OKIM6295, (MCLK/1024)*132)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high) // clock frequency & pin 7 not verified
+	MDRV_SOUND_ADD("oki", OKIM6295, (MCLK/1024)*132)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // clock frequency & pin 7 not verified
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 MACHINE_DRIVER_END
 
@@ -493,7 +502,7 @@ static MACHINE_DRIVER_START( gakupara )
 	MDRV_IMPORT_FROM(quizdna)
 
 	MDRV_CPU_MODIFY("main")
-	MDRV_CPU_IO_MAP(quizdna_readport,gakupara_writeport)
+	MDRV_CPU_IO_MAP(gakupara_io_map,0)
 
 MACHINE_DRIVER_END
 
@@ -504,7 +513,7 @@ static MACHINE_DRIVER_START( gekiretu )
 
 	MDRV_CPU_MODIFY("main")
 	MDRV_CPU_PROGRAM_MAP(quizdna_readmem,gekiretu_writemem)
-	MDRV_CPU_IO_MAP(quizdna_readport,gekiretu_writeport)
+	MDRV_CPU_IO_MAP(gekiretu_io_map,0)
 
 MACHINE_DRIVER_END
 
@@ -512,81 +521,78 @@ MACHINE_DRIVER_END
 /****************************************************************************/
 
 ROM_START( quizdna )
-	ROM_REGION( 0xd0000, REGION_CPU1, 0 ) /* CPU */
+	ROM_REGION( 0xd0000, "main", 0 ) /* CPU */
 	ROM_LOAD( "quiz2-pr.28",  0x00000,  0x08000, CRC(a428ede4) SHA1(cdca3bd84b2ea421fb05502ea29e9eb605e574eb) )
 	ROM_CONTINUE(             0x18000,  0x78000 ) /* banked */
 	/* empty */
 
-	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE ) /* fg */
+	ROM_REGION( 0x40000, "gfx1", ROMREGION_DISPOSE ) /* fg */
 	ROM_LOAD( "quiz2.102",    0x00000,  0x20000, CRC(62402ac9) SHA1(bf52d22b119d54410dad4949b0687bb0edf3e143) )
 	/* empty */
 
-	ROM_REGION( 0x108000, REGION_GFX2, ROMREGION_DISPOSE ) /* bg */
+	ROM_REGION( 0x108000, "gfx2", ROMREGION_DISPOSE ) /* bg */
 	ROM_LOAD( "quiz2-bg.100", 0x000000,  0x100000, CRC(f1d0cac2) SHA1(26d25c1157d1916dfe4496c6cf119c4a9339e31c) )
 	/* empty */
 
-	ROM_REGION( 0x108000, REGION_GFX3, ROMREGION_DISPOSE ) /* obj */
+	ROM_REGION( 0x108000, "gfx3", ROMREGION_DISPOSE ) /* obj */
 	ROM_LOAD( "quiz2-ob.98",  0x000000,  0x100000, CRC(682f19a6) SHA1(6b8e6e583f423cf8ef9095f2c300201db7d7b8b3) )
 	ROM_LOAD( "quiz2ob2.97",  0x100000,  0x008000, CRC(03736b1a) SHA1(bc42ac293260f58a8a138702d890f69aec99c05e) )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 ) /* samples */
+	ROM_REGION( 0x80000, "oki", 0 ) /* samples */
 	ROM_LOAD( "quiz2-sn.32",  0x000000,  0x040000, CRC(1c044637) SHA1(dc749295e149f968495272f1a3ec27c6b719be8e) )
 
-	ROM_REGION( 0x00020, REGION_USER1, 0 ) /* fg control */
+	ROM_REGION( 0x00020, "user1", 0 ) /* fg control */
 	ROM_LOAD( "quiz2.148",    0x000000,  0x000020, CRC(91267e8a) SHA1(ae5bd8efea5322c4d9986d06680a781392f9a642) )
-
 ROM_END
 
 ROM_START( gakupara )
-	ROM_REGION( 0xd0000, REGION_CPU1, 0 ) /* CPU */
+	ROM_REGION( 0xd0000, "main", 0 ) /* CPU */
 	ROM_LOAD( "u28.bin",  0x00000,  0x08000, CRC(72124bb8) SHA1(e734acff7e9d6b8c6a95c76860732320a2e3a828) )
 	ROM_CONTINUE(         0x18000,  0x78000 )             /* banked */
 	ROM_LOAD( "u29.bin",  0x90000,  0x40000, CRC(09f4948e) SHA1(21ccf5af6935cf40c0cf73fbee14bff3c4e1d23d) ) /* banked */
 
-	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE ) /* fg */
+	ROM_REGION( 0x40000, "gfx1", ROMREGION_DISPOSE ) /* fg */
 	ROM_LOAD( "u102.bin", 0x00000,  0x20000, CRC(62402ac9) SHA1(bf52d22b119d54410dad4949b0687bb0edf3e143) )
 	ROM_LOAD( "u103.bin", 0x20000,  0x20000, CRC(38644251) SHA1(ebfdc43c38e1380709ed08575c346b2467ad1592) )
 
-	ROM_REGION( 0x108000, REGION_GFX2, ROMREGION_DISPOSE ) /* bg */
+	ROM_REGION( 0x108000, "gfx2", ROMREGION_DISPOSE ) /* bg */
 	ROM_LOAD( "u100.bin", 0x000000,  0x100000, CRC(f9d886ea) SHA1(d7763f54a165af720216b96e601a66fbc59e3568) )
 	ROM_LOAD( "u99.bin",  0x100000,  0x008000, CRC(ac224d0a) SHA1(f187c3b74bc18606d0fe638f6a829f71c109998d) )
 
-	ROM_REGION( 0x108000, REGION_GFX3, ROMREGION_DISPOSE ) /* obj */
+	ROM_REGION( 0x108000, "gfx3", ROMREGION_DISPOSE ) /* obj */
 	ROM_LOAD( "u98.bin",  0x000000,  0x100000, CRC(a6e8cb56) SHA1(2fc85c1769513cc7aa5e23afaf0c99c38de9b855) )
 	ROM_LOAD( "u97.bin",  0x100000,  0x008000, CRC(9dacd5c9) SHA1(e40211059e71408be3d67807463304f4d4ecae37) )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 ) /* samples */
+	ROM_REGION( 0x80000, "oki", 0 ) /* samples */
 	ROM_LOAD( "u32.bin",  0x000000,  0x040000, CRC(eb03c535) SHA1(4d6c749ccab4681eee0a1fb243e9f3dbe61b9f94) )
 
-	ROM_REGION( 0x00020, REGION_USER1, 0 ) /* fg control */
+	ROM_REGION( 0x00020, "user1", 0 ) /* fg control */
 	ROM_LOAD( "u148.bin", 0x000000,  0x000020, CRC(971df9d2) SHA1(280f5b386922b9902ca9211c719642c2bd0ba899) )
-
 ROM_END
 
 ROM_START( gekiretu )
-	ROM_REGION( 0xd0000, REGION_CPU1, 0 ) /* CPU */
+	ROM_REGION( 0xd0000, "main", 0 ) /* CPU */
 	ROM_LOAD( "quiz3-pr.28",  0x00000,  0x08000, CRC(a761e86f) SHA1(85331ef53598491e78c2d123b1ebd358aff46436) )
 	ROM_CONTINUE(             0x18000,  0x78000 ) /* banked */
 	/* empty */
 
-	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE ) /* fg */
+	ROM_REGION( 0x40000, "gfx1", ROMREGION_DISPOSE ) /* fg */
 	ROM_LOAD( "quiz3.102",    0x00000,  0x20000, CRC(62402ac9) SHA1(bf52d22b119d54410dad4949b0687bb0edf3e143) )
 	/* empty */
 
-	ROM_REGION( 0x108000, REGION_GFX2, ROMREGION_DISPOSE ) /* bg */
+	ROM_REGION( 0x108000, "gfx2", ROMREGION_DISPOSE ) /* bg */
 	ROM_LOAD( "quiz3-bg.100", 0x000000,  0x100000, CRC(cb9272fd) SHA1(cfc1ff93d1fdc7d144e161a77e534cea75d7f181) )
 	/* empty */
 
-	ROM_REGION( 0x108000, REGION_GFX3, ROMREGION_DISPOSE ) /* obj */
+	ROM_REGION( 0x108000, "gfx3", ROMREGION_DISPOSE ) /* obj */
 	ROM_LOAD( "quiz3-ob.98",  0x000000,  0x100000, CRC(01bed020) SHA1(5cc56c8823ee5e538371debe1cbeb57c4976677b) )
 	/* empty */
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 ) /* samples */
+	ROM_REGION( 0x80000, "oki", 0 ) /* samples */
 	ROM_LOAD( "quiz3-sn.32",  0x000000,  0x040000, CRC(36dca582) SHA1(2607602e942244cfaae931da2ad36da9a8f855f7) )
 
-	ROM_REGION( 0x00020, REGION_USER1, 0 ) /* fg control */
+	ROM_REGION( 0x00020, "user1", 0 ) /* fg control */
 	ROM_LOAD( "quiz3.148",    0x000000,  0x000020, CRC(91267e8a) SHA1(ae5bd8efea5322c4d9986d06680a781392f9a642) )
-
 ROM_END
 
 GAME( 1991, gakupara, 0, gakupara, gakupara, 0, ROT0, "NMK",  "Quiz Gakuen Paradise (Japan)", 0 )
