@@ -21,7 +21,7 @@ TODO:
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
 
 
 extern WRITE8_HANDLER( redclash_videoram_w );
@@ -45,37 +45,37 @@ extern VIDEO_EOF( redclash );
 */
 static INTERRUPT_GEN( redclash_interrupt )
 {
-	if (readinputport(4) & 1)	/* Left Coin */
-		cpunum_set_input_line(machine, 0,0,ASSERT_LINE);
-	else if (readinputport(4) & 2)	/* Right Coin */
-		cpunum_set_input_line(machine, 0, INPUT_LINE_NMI, PULSE_LINE);
+	if (input_port_read(device->machine, "FAKE") & 1)	/* Left Coin */
+		cpu_set_input_line(device,0,ASSERT_LINE);
+	else if (input_port_read(device->machine, "FAKE") & 2)	/* Right Coin */
+		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 }
 
 static WRITE8_HANDLER( irqack_w )
 {
-	cpunum_set_input_line(Machine, 0,0,CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[0],0,CLEAR_LINE);
 }
 
 
 
 static ADDRESS_MAP_START( zero_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x2fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x3000, 0x37ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x4800, 0x4800) AM_READ(input_port_0_r) /* IN0 */
-	AM_RANGE(0x4801, 0x4801) AM_READ(input_port_1_r) /* IN1 */
-	AM_RANGE(0x4802, 0x4802) AM_READ(input_port_2_r) /* DSW0 */
-	AM_RANGE(0x4803, 0x4803) AM_READ(input_port_3_r) /* DSW1 */
-	AM_RANGE(0x4000, 0x43ff) AM_READ(MRA8_RAM)  /* video RAM */
+	AM_RANGE(0x0000, 0x2fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x3000, 0x37ff) AM_READ(SMH_RAM)
+	AM_RANGE(0x4800, 0x4800) AM_READ_PORT("IN0")	/* IN0 */
+	AM_RANGE(0x4801, 0x4801) AM_READ_PORT("IN1")	/* IN1 */
+	AM_RANGE(0x4802, 0x4802) AM_READ_PORT("DSW1")	/* DSW0 */
+	AM_RANGE(0x4803, 0x4803) AM_READ_PORT("DSW2")	/* DSW1 */
+	AM_RANGE(0x4000, 0x43ff) AM_READ(SMH_RAM)		/* video RAM */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( zero_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x2fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x3000, 0x37ff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0x3800, 0x3bff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+	AM_RANGE(0x0000, 0x2fff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x3000, 0x37ff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0x3800, 0x3bff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
 	AM_RANGE(0x4000, 0x43ff) AM_WRITE(redclash_videoram_w) AM_BASE(&videoram)
-	AM_RANGE(0x5000, 0x5007) AM_WRITE(MWA8_NOP)	/* to sound board */
+	AM_RANGE(0x5000, 0x5007) AM_WRITE(SMH_NOP)	/* to sound board */
 	AM_RANGE(0x5800, 0x5800) AM_WRITE(redclash_star0_w)
-	AM_RANGE(0x5801, 0x5804) AM_WRITE(MWA8_NOP)	/* to sound board */
+	AM_RANGE(0x5801, 0x5804) AM_WRITE(SMH_NOP)	/* to sound board */
 	AM_RANGE(0x5805, 0x5805) AM_WRITE(redclash_star1_w)
 	AM_RANGE(0x5806, 0x5806) AM_WRITE(redclash_star2_w)
 	AM_RANGE(0x5807, 0x5807) AM_WRITE(redclash_flipscreen_w)
@@ -84,28 +84,28 @@ static ADDRESS_MAP_START( zero_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x2fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x4800, 0x4800) AM_READ(input_port_0_r) /* IN0 */
-	AM_RANGE(0x4801, 0x4801) AM_READ(input_port_1_r) /* IN1 */
-	AM_RANGE(0x4802, 0x4802) AM_READ(input_port_2_r) /* DSW0 */
-	AM_RANGE(0x4803, 0x4803) AM_READ(input_port_3_r) /* DSW1 */
-	AM_RANGE(0x4000, 0x43ff) AM_READ(MRA8_RAM)  /* video RAM */
-	AM_RANGE(0x6000, 0x67ff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0000, 0x2fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x4800, 0x4800) AM_READ_PORT("IN0")	/* IN0 */
+	AM_RANGE(0x4801, 0x4801) AM_READ_PORT("IN1")	/* IN1 */
+	AM_RANGE(0x4802, 0x4802) AM_READ_PORT("DSW1")	/* DSW0 */
+	AM_RANGE(0x4803, 0x4803) AM_READ_PORT("DSW2")	/* DSW1 */
+	AM_RANGE(0x4000, 0x43ff) AM_READ(SMH_RAM)		/* video RAM */
+	AM_RANGE(0x6000, 0x67ff) AM_READ(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x2fff) AM_WRITE(MWA8_ROM)
-//  AM_RANGE(0x3000, 0x3000) AM_WRITE(MWA8_NOP)
-//  AM_RANGE(0x3800, 0x3800) AM_WRITE(MWA8_NOP)
+	AM_RANGE(0x0000, 0x2fff) AM_WRITE(SMH_ROM)
+//  AM_RANGE(0x3000, 0x3000) AM_WRITE(SMH_NOP)
+//  AM_RANGE(0x3800, 0x3800) AM_WRITE(SMH_NOP)
 	AM_RANGE(0x4000, 0x43ff) AM_WRITE(redclash_videoram_w) AM_BASE(&videoram)
-	AM_RANGE(0x5000, 0x5007) AM_WRITE(MWA8_NOP)	/* to sound board */
+	AM_RANGE(0x5000, 0x5007) AM_WRITE(SMH_NOP)	/* to sound board */
 	AM_RANGE(0x5800, 0x5800) AM_WRITE(redclash_star0_w)
 	AM_RANGE(0x5801, 0x5801) AM_WRITE(redclash_gfxbank_w)
 	AM_RANGE(0x5805, 0x5805) AM_WRITE(redclash_star1_w)
 	AM_RANGE(0x5806, 0x5806) AM_WRITE(redclash_star2_w)
 	AM_RANGE(0x5807, 0x5807) AM_WRITE(redclash_flipscreen_w)
-	AM_RANGE(0x6000, 0x67ff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0x6800, 0x6bff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+	AM_RANGE(0x6000, 0x67ff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0x6800, 0x6bff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
 	AM_RANGE(0x7000, 0x7000) AM_WRITE(redclash_star_reset_w)
 	AM_RANGE(0x7800, 0x7800) AM_WRITE(irqack_w)
 ADDRESS_MAP_END
@@ -113,7 +113,7 @@ ADDRESS_MAP_END
 
 
 static INPUT_PORTS_START( redclash )
-	PORT_START	/* IN0 */
+	PORT_START("IN0")	/* IN0 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
@@ -123,7 +123,7 @@ static INPUT_PORTS_START( redclash )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	/* IN1 */
+	PORT_START("IN1")	/* IN1 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
@@ -135,7 +135,7 @@ static INPUT_PORTS_START( redclash )
 	/* them this way is enough to get the game running. */
 	PORT_BIT( 0xc0, 0x40, IPT_VBLANK )
 
-	PORT_START	/* DSW0 */
+	PORT_START("DSW1")	/* DSW0 */
 	PORT_DIPNAME( 0x03, 0x03, "Difficulty?" )
 	PORT_DIPSETTING(    0x03, "Easy?" )
 	PORT_DIPSETTING(    0x02, "Medium?" )
@@ -159,7 +159,7 @@ static INPUT_PORTS_START( redclash )
 	PORT_DIPSETTING(    0x80, "5" )
 	PORT_DIPSETTING(    0x40, "7" )
 
-	PORT_START	/* DSW1 */
+	PORT_START("DSW2")	/* DSW1 */
 	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( 6C_1C ) )
 	PORT_DIPSETTING(    0x05, DEF_STR( 5C_1C ) )
@@ -195,7 +195,7 @@ static INPUT_PORTS_START( redclash )
 	PORT_DIPSETTING(    0x10, DEF_STR( 1C_8C ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_9C ) )
 
-	PORT_START	/* FAKE */
+	PORT_START("FAKE")	/* FAKE */
 	/* The coin slots are not memory mapped. Coin Left causes a NMI, */
 	/* Coin Right an IRQ. This fake input port is used by the interrupt */
 	/* handler to be notified of coin insertions. We use IMPULSE to */
@@ -206,7 +206,7 @@ static INPUT_PORTS_START( redclash )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( zerohour )
-	PORT_START	/* IN0 */
+	PORT_START("IN0")	/* IN0 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
@@ -216,7 +216,7 @@ static INPUT_PORTS_START( zerohour )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	/* IN1 */
+	PORT_START("IN1")	/* IN1 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
@@ -228,7 +228,7 @@ static INPUT_PORTS_START( zerohour )
 	/* them this way is enough to get the game running. */
 	PORT_BIT( 0xc0, 0x40, IPT_VBLANK )
 
-	PORT_START	/* DSW0 */
+	PORT_START("DSW1")	/* DSW0 */
 	PORT_DIPUNUSED_DIPLOC( 0x01, 0x01, "SW1:8" ) 	/* Switches 6-8 are not used */
 	PORT_DIPUNUSED_DIPLOC( 0x02, 0x02, "SW1:7" )
 	PORT_DIPUNUSED_DIPLOC( 0x04, 0x04, "SW1:6" )
@@ -246,7 +246,7 @@ static INPUT_PORTS_START( zerohour )
 	PORT_DIPSETTING(    0x80, "4" )
 	PORT_DIPSETTING(    0x40, "5" )
 
-	PORT_START	/* DSW1 */
+	PORT_START("DSW2")	/* DSW1 */
 	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coin_A ) ) PORT_DIPLOCATION("SW2:4,3,2,1")
 	PORT_DIPSETTING(    0x06, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x08, DEF_STR( 3C_1C ) )
@@ -270,7 +270,7 @@ static INPUT_PORTS_START( zerohour )
 	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_4C ) )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
 
-	PORT_START	/* FAKE */
+	PORT_START("FAKE")	/* FAKE */
 	/* The coin slots are not memory mapped. Coin Left causes a NMI, */
 	/* Coin Right an IRQ. This fake input port is used by the interrupt */
 	/* handler to be notified of coin insertions. We use IMPULSE to */
@@ -336,12 +336,12 @@ static const gfx_layout spritelayout16x16bis =
 };
 
 static GFXDECODE_START( redclash )
-	GFXDECODE_ENTRY( REGION_GFX1, 0x0000, charlayout,          0,  8 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x0000, spritelayout8x8,   4*8, 16 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x0000, spritelayout16x16, 4*8, 16 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x0000, spritelayout24x24, 4*8, 16 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x0000, spritelayout16x16bis, 4*8, 16 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x0004, spritelayout16x16bis, 4*8, 16 )
+	GFXDECODE_ENTRY( "gfx1", 0x0000, charlayout,          0,  8 )
+	GFXDECODE_ENTRY( "gfx3", 0x0000, spritelayout8x8,   4*8, 16 )
+	GFXDECODE_ENTRY( "gfx2", 0x0000, spritelayout16x16, 4*8, 16 )
+	GFXDECODE_ENTRY( "gfx2", 0x0000, spritelayout24x24, 4*8, 16 )
+	GFXDECODE_ENTRY( "gfx2", 0x0000, spritelayout16x16bis, 4*8, 16 )
+	GFXDECODE_ENTRY( "gfx2", 0x0004, spritelayout16x16bis, 4*8, 16 )
 GFXDECODE_END
 
 
@@ -349,21 +349,20 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( zerohour )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80, 4000000)  /* 4 MHz */
+	MDRV_CPU_ADD("main", Z80, 4000000)  /* 4 MHz */
 	MDRV_CPU_PROGRAM_MAP(zero_readmem,zero_writemem)
-	MDRV_CPU_VBLANK_INT(redclash_interrupt,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", redclash_interrupt)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(32*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 4*8, 28*8-1)
+
 	MDRV_GFXDECODE(redclash)
-	MDRV_PALETTE_LENGTH(64)
-	MDRV_COLORTABLE_LENGTH(4*24)
+	MDRV_PALETTE_LENGTH(4*8+4*16+32)
 
 	MDRV_PALETTE_INIT(redclash)
 	MDRV_VIDEO_START(redclash)
@@ -377,21 +376,20 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( redclash )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80, 4000000)  /* 4 MHz */
+	MDRV_CPU_ADD("main", Z80, 4000000)  /* 4 MHz */
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_VBLANK_INT(redclash_interrupt,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", redclash_interrupt)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(32*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 4*8, 28*8-1)
+
 	MDRV_GFXDECODE(redclash)
-	MDRV_PALETTE_LENGTH(64)
-	MDRV_COLORTABLE_LENGTH(4*24)
+	MDRV_PALETTE_LENGTH(4*8+4*16+32)
 
 	MDRV_PALETTE_INIT(redclash)
 	MDRV_VIDEO_START(redclash)
@@ -408,7 +406,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( zerohour )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "zerohour.1",   0x0000, 0x0800, CRC(0dff4b48) SHA1(4911255f953851d0e5c2b66090b95254ac59ac9e) )
 	ROM_LOAD( "zerohour.2",   0x0800, 0x0800, CRC(cf41b6ac) SHA1(263794e6be22c20e2b10fe9099e475097475df7b) )
 	ROM_LOAD( "zerohour.3",	  0x1000, 0x0800, CRC(5ef48b67) SHA1(ae291aa84b109e6a51eebdd5526abca1d901b7b9) )
@@ -416,72 +414,72 @@ ROM_START( zerohour )
 	ROM_LOAD( "zerohour.5",	  0x2000, 0x0800, CRC(d7ce3add) SHA1(d8dd7ad98e7a0a4f35de181549b2e88a9e0a73d6) )
 	ROM_LOAD( "zerohour.6",	  0x2800, 0x0800, CRC(8a93ae6e) SHA1(a66f05bb27e67b755c64ac8b68fa38ffe4cd961c) )
 
-	ROM_REGION( 0x0800, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0800, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "zerohour.9",   0x0000, 0x0800, CRC(17ae6f13) SHA1(ce7a02f4e1aa2e5292d3807a0cfed6d92752fc7a) )
 
-	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "zerohour.7",	  0x0000, 0x0800, CRC(4c12f59d) SHA1(b99a21415bff0e59b6130df60182f05b1a5d0811) )
 	ROM_LOAD( "zerohour.8",	  0x0800, 0x0800, CRC(6b9a6b6e) SHA1(f80d893b1b26c75c297e1da1c20db04e7129c92a) )
 
-	ROM_REGION( 0x1000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1000, "gfx3", ROMREGION_DISPOSE )
 	/* gfx data will be rearranged here for 8x8 sprites */
 
-	ROM_REGION( 0x0600, REGION_PROMS, 0 )
+	ROM_REGION( 0x0600, "proms", 0 )
 	ROM_LOAD( "zerohour.ic2", 0x0000, 0x0020, CRC(b55aee56) SHA1(33e4767c8afbb7b3af67517ea1dfd69bf692cac7) ) /* palette */
 	ROM_LOAD( "zerohour.n2",  0x0020, 0x0020, CRC(9adabf46) SHA1(f3538fdbc4280b6be46a4d7ebb4c34bd1a1ce2b7) ) /* sprite color lookup table */
 	ROM_LOAD( "zerohour.u6",  0x0040, 0x0020, CRC(27fa3a50) SHA1(7cf59b7a37c156640d6ea91554d1c4276c1780e0) ) /* ?? */
 ROM_END
 
 ROM_START( redclash )
-	ROM_REGION(0x10000, REGION_CPU1, 0 )
+	ROM_REGION(0x10000, "main", 0 )
 	ROM_LOAD( "11.11c",       0x0000, 0x1000, CRC(695e070e) SHA1(8d0451a05572f62e0f282ab96bdd26d08b77a6c9) )
 	ROM_LOAD( "13.7c",        0x1000, 0x1000, CRC(c2090318) SHA1(71725cdf51aedf5f29fa1dd1a41ad5e62c9a580d) )
 	ROM_LOAD( "12.9c",        0x2000, 0x1000, CRC(b60e5ada) SHA1(37440f382c5e8852d804fa9837c36cc1e9d94d1d) )
 
-	ROM_REGION(0x0800, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION(0x0800, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "6.12a",        0x0000, 0x0800, CRC(da9bbcc2) SHA1(4cbe03c7f5e99cc2f124e0089ea3c392156b5d92) )
 
-	ROM_REGION( 0x2000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "14.3e",        0x0000, 0x0800, CRC(483a1293) SHA1(e7812475c7509389bcf8fee35598e9894428eb37) )
 	ROM_CONTINUE(             0x1000, 0x0800 )
 	ROM_LOAD( "15.3d",        0x0800, 0x0800, CRC(c45d9601) SHA1(2f156ad61161d65284df0cc55eb1b3b990eb41cb) )
 	ROM_CONTINUE(             0x1800, 0x0800 )
 
-	ROM_REGION( 0x2000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx3", ROMREGION_DISPOSE )
 	/* gfx data will be rearranged here for 8x8 sprites */
 
-	ROM_REGION( 0x0060, REGION_PROMS, 0 )
+	ROM_REGION( 0x0060, "proms", 0 )
 	ROM_LOAD( "1.12f",        0x0000, 0x0020, CRC(43989681) SHA1(0d471e6f499294f2f62f27392b8370e2af8e38a3) ) /* palette */
 	ROM_LOAD( "2.4a",         0x0020, 0x0020, CRC(9adabf46) SHA1(f3538fdbc4280b6be46a4d7ebb4c34bd1a1ce2b7) ) /* sprite color lookup table */
 	ROM_LOAD( "3.11e",        0x0040, 0x0020, CRC(27fa3a50) SHA1(7cf59b7a37c156640d6ea91554d1c4276c1780e0) ) /* ?? */
 ROM_END
 
 ROM_START( redclsha )
-	ROM_REGION(0x10000, REGION_CPU1, 0 )
+	ROM_REGION(0x10000, "main", 0 )
 	ROM_LOAD( "rc1.11c",      0x0000, 0x1000, CRC(5b62ff5a) SHA1(981d3c72f28b7d136a0bad9243d39fd1ba3abc97) )
 	ROM_LOAD( "rc3.7c",       0x1000, 0x1000, CRC(409c4ee7) SHA1(15c03a4093d7695751a143aa749229fcb7721f46) )
 	ROM_LOAD( "rc2.9c",       0x2000, 0x1000, CRC(5f215c9a) SHA1(c305f7be19f6a052c08feb0b63a0326b6a1bd808) )
 
-	ROM_REGION(0x0800, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION(0x0800, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "rc6.12a",      0x0000, 0x0800, CRC(da9bbcc2) SHA1(4cbe03c7f5e99cc2f124e0089ea3c392156b5d92) )
 
-	ROM_REGION( 0x2000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "rc4.3e",       0x0000, 0x0800, CRC(64ca8b63) SHA1(5fd1ca9b81f66b4d2041674900718dc8c94c2a97) )
 	ROM_CONTINUE(             0x1000, 0x0800 )
 	ROM_LOAD( "rc5.3d",       0x0800, 0x0800, CRC(fce610a2) SHA1(0be829c6f6f5c3a19056ba1594141c1965c7aa2a) )
 	ROM_CONTINUE(             0x1800, 0x0800 )
 
-	ROM_REGION( 0x2000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx3", ROMREGION_DISPOSE )
 	/* gfx data will be rearranged here for 8x8 sprites */
 
-	ROM_REGION( 0x0060, REGION_PROMS, 0 )
+	ROM_REGION( 0x0060, "proms", 0 )
 	ROM_LOAD( "1.12f",        0x0000, 0x0020, CRC(43989681) SHA1(0d471e6f499294f2f62f27392b8370e2af8e38a3) ) /* palette */
 	ROM_LOAD( "2.4a",         0x0020, 0x0020, CRC(9adabf46) SHA1(f3538fdbc4280b6be46a4d7ebb4c34bd1a1ce2b7) ) /* sprite color lookup table */
 	ROM_LOAD( "3.11e",        0x0040, 0x0020, CRC(27fa3a50) SHA1(7cf59b7a37c156640d6ea91554d1c4276c1780e0) ) /* ?? */
 ROM_END
 
 ROM_START( redclask )
-	ROM_REGION(0x10000, REGION_CPU1, 0 )
+	ROM_REGION(0x10000, "main", 0 )
 	ROM_LOAD( "rc1.8c",       0x0000, 0x0800, CRC(fd90622a) SHA1(a65a32d519e7fee89b160f8152322df20b6af4ea) )
 	ROM_LOAD( "rc2.7c",       0x0800, 0x0800, CRC(c8f33440) SHA1(60d1faee415faa13102b8e744f444f1480b8bd73) )
 	ROM_LOAD( "rc3.6c",       0x1000, 0x0800, CRC(2172b1e9) SHA1(b6f7ee8924bda9f8da13baaa2db3ffb7d623236c) )
@@ -489,19 +487,19 @@ ROM_START( redclask )
 	ROM_LOAD( "rc5.4c",       0x2000, 0x0800, CRC(744b5261) SHA1(6c5de2f91f57c463230e0ea04b336347840161a3) )
 	ROM_LOAD( "rc6.3c",       0x2800, 0x0800, CRC(fa507e17) SHA1(dd0e27b08e902b91c5e9552351206c671ed2f3c0) )
 
-	ROM_REGION( 0x0800, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0800, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "rc6.12a",      0x0000, 0x0800, CRC(da9bbcc2) SHA1(4cbe03c7f5e99cc2f124e0089ea3c392156b5d92) ) /* rc9.7m */
 
-	ROM_REGION( 0x2000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "rc4.4m",       0x0000, 0x0800, CRC(483a1293) SHA1(e7812475c7509389bcf8fee35598e9894428eb37) )
 	ROM_CONTINUE(             0x1000, 0x0800 )
 	ROM_LOAD( "rc5.5m",       0x0800, 0x0800, CRC(c45d9601) SHA1(2f156ad61161d65284df0cc55eb1b3b990eb41cb) )
 	ROM_CONTINUE(             0x1800, 0x0800 )
 
-	ROM_REGION( 0x2000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx3", ROMREGION_DISPOSE )
 	/* gfx data will be rearranged here for 8x8 sprites */
 
-	ROM_REGION( 0x0060, REGION_PROMS, 0 )
+	ROM_REGION( 0x0060, "proms", 0 )
 	ROM_LOAD( "1.12f",        0x0000, 0x0020, CRC(43989681) SHA1(0d471e6f499294f2f62f27392b8370e2af8e38a3) ) /* 6331.7e */
 	ROM_LOAD( "2.4a",         0x0020, 0x0020, CRC(9adabf46) SHA1(f3538fdbc4280b6be46a4d7ebb4c34bd1a1ce2b7) ) /* 6331.2r */
 	ROM_LOAD( "3.11e",        0x0040, 0x0020, CRC(27fa3a50) SHA1(7cf59b7a37c156640d6ea91554d1c4276c1780e0) ) /* 6331.6w */
@@ -510,12 +508,15 @@ ROM_END
 static DRIVER_INIT( redclash )
 {
 	int i,j;
+	const UINT8 *src = memory_region(machine, "gfx2");
+	UINT8 *dst = memory_region(machine, "gfx3");
+	int len = memory_region_length(machine, "gfx3");
 
 	/* rearrange the sprite graphics */
-	for (i = 0;i < memory_region_length(REGION_GFX3);i++)
+	for (i = 0;i < len;i++)
 	{
 		j = (i & ~0x003e) | ((i & 0x0e) << 2) | ((i & 0x30) >> 3);
-		memory_region(REGION_GFX3)[i] = memory_region(REGION_GFX2)[j];
+		dst[i] = src[j];
 	}
 }
 
