@@ -138,7 +138,7 @@ static struct renegade_adpcm_state
 	UINT8 *base;
 } renegade_adpcm;
 
-static void renegade_adpcm_callback(void *param, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+static STREAM_UPDATE( renegade_adpcm_callback )
 {
 	struct renegade_adpcm_state *state = param;
 	stream_sample_t *dest = outputs[0];
@@ -165,12 +165,13 @@ static void renegade_adpcm_callback(void *param, stream_sample_t **inputs, strea
 	}
 }
 
-static void *renegade_adpcm_start(int clock, const struct CustomSound_interface *config)
+static CUSTOM_START( renegade_adpcm_start )
 {
+	running_machine *machine = device->machine;
 	struct renegade_adpcm_state *state = &renegade_adpcm;
 	state->playing = 0;
-	state->stream = stream_create(0, 1, clock, state, renegade_adpcm_callback);
-	state->base = memory_region(REGION_SOUND1);
+	state->stream = stream_create(device, 0, 1, clock, state, renegade_adpcm_callback);
+	state->base = memory_region(machine, "adpcm");
 	reset_adpcm(&state->adpcm);
 	return state;
 }
@@ -200,8 +201,8 @@ static WRITE8_HANDLER( adpcm_play_w )
 
 static WRITE8_HANDLER( sound_w )
 {
-	soundlatch_w(offset, data);
-	cpunum_set_input_line(Machine, 1, M6809_IRQ_LINE, HOLD_LINE);
+	soundlatch_w(space, offset, data);
+	cpu_set_input_line(space->machine->cpu[1], M6809_IRQ_LINE, HOLD_LINE);
 }
 
 /********************************************************************************************/
@@ -237,21 +238,26 @@ static const UINT8 kuniokun_xor_table[0x2a] =
 	0x68, 0x60
 };
 
-static void setbank(void)
+static void setbank(running_machine *machine)
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
-	memory_set_bankptr(1, &RAM[bank ? 0x10000 : 0x4000]);
+	UINT8 *RAM = memory_region(machine, "main");
+	memory_set_bankptr(machine, 1, &RAM[bank ? 0x10000 : 0x4000]);
+}
+
+static STATE_POSTLOAD( renegade_postload )
+{
+	setbank(machine);
 }
 
 static MACHINE_START( renegade )
 {
-	state_save_register_global_array(mcu_buffer);
-	state_save_register_global(mcu_input_size);
-	state_save_register_global(mcu_output_byte);
-	state_save_register_global(mcu_key);
+	state_save_register_global_array(machine, mcu_buffer);
+	state_save_register_global(machine, mcu_input_size);
+	state_save_register_global(machine, mcu_output_byte);
+	state_save_register_global(machine, mcu_key);
 
-	state_save_register_global(bank);
-	state_save_register_func_postload(setbank);
+	state_save_register_global(machine, bank);
+	state_save_register_postload(machine, renegade_postload, NULL);
 }
 
 static DRIVER_INIT( kuniokun )
@@ -481,7 +487,7 @@ static WRITE8_HANDLER( bankswitch_w )
 	if ((data & 1) != bank)
 	{
 		bank = data & 1;
-		setbank();
+		setbank(space->machine);
 	}
 }
 
@@ -489,7 +495,7 @@ static INTERRUPT_GEN( renegade_interrupt )
 {
 /*
     static int coin;
-    int port = readinputport(1) & 0xc0;
+    int port = input_port_read(machine, "IN1") & 0xc0;
     if (port != 0xc0)
     {
         if (coin == 0)
@@ -501,12 +507,10 @@ static INTERRUPT_GEN( renegade_interrupt )
     else coin = 0;
 */
 
-	static int count;
-	count = !count;
-	if (count)
-		cpunum_set_input_line(machine, 0, INPUT_LINE_NMI, PULSE_LINE);
+	if (cpu_getiloops(device))
+		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 	else
-		cpunum_set_input_line(machine, 0, 0, HOLD_LINE);
+		cpu_set_input_line(device, 0, HOLD_LINE);
 }
 
 static WRITE8_HANDLER( renegade_coin_counter_w )
@@ -518,21 +522,21 @@ static WRITE8_HANDLER( renegade_coin_counter_w )
 /********************************************************************************************/
 
 static ADDRESS_MAP_START( main_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x37ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x3800, 0x3800) AM_READ(input_port_0_r) /* Player#1 controls, P1,P2 start */
-	AM_RANGE(0x3801, 0x3801) AM_READ(input_port_1_r) /* Player#2 controls, coin triggers */
-	AM_RANGE(0x3802, 0x3802) AM_READ(input_port_2_r) /* DIP2  various IO ports */
-	AM_RANGE(0x3803, 0x3803) AM_READ(input_port_3_r) /* DIP1 */
+	AM_RANGE(0x0000, 0x37ff) AM_READ(SMH_RAM)
+	AM_RANGE(0x3800, 0x3800) AM_READ_PORT("IN0")		/* Player#1 controls, P1,P2 start */
+	AM_RANGE(0x3801, 0x3801) AM_READ_PORT("IN1")		/* Player#2 controls, coin triggers */
+	AM_RANGE(0x3802, 0x3802) AM_READ_PORT("DSW2")	/* DIP2  various IO ports */
+	AM_RANGE(0x3803, 0x3803) AM_READ_PORT("DSW1")	/* DIP1 */
 	AM_RANGE(0x3804, 0x3804) AM_READ(mcu_r)
 	AM_RANGE(0x3805, 0x3805) AM_READ(mcu_reset_r)
-	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_BANK1)
-	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_ROM)
+	AM_RANGE(0x4000, 0x7fff) AM_READ(SMH_BANK1)
+	AM_RANGE(0x8000, 0xffff) AM_READ(SMH_ROM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( main_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x17ff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x0000, 0x17ff) AM_WRITE(SMH_RAM)
 	AM_RANGE(0x1800, 0x1fff) AM_WRITE(renegade_videoram2_w) AM_BASE(&renegade_videoram2)
-	AM_RANGE(0x2000, 0x27ff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram)
+	AM_RANGE(0x2000, 0x27ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram)
 	AM_RANGE(0x2800, 0x2fff) AM_WRITE(renegade_videoram_w) AM_BASE(&videoram)
 	AM_RANGE(0x3000, 0x30ff) AM_WRITE(paletteram_xxxxBBBBGGGGRRRR_split1_w) AM_BASE(&paletteram)
 	AM_RANGE(0x3100, 0x31ff) AM_WRITE(paletteram_xxxxBBBBGGGGRRRR_split2_w) AM_BASE(&paletteram_2)
@@ -542,33 +546,33 @@ static ADDRESS_MAP_START( main_writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x3803, 0x3803) AM_WRITE(renegade_flipscreen_w)
 	AM_RANGE(0x3804, 0x3804) AM_WRITE(mcu_w)
 	AM_RANGE(0x3805, 0x3805) AM_WRITE(bankswitch_w)
-	AM_RANGE(0x3806, 0x3806) AM_WRITE(MWA8_NOP) // ?? watchdog
+	AM_RANGE(0x3806, 0x3806) AM_WRITE(SMH_NOP) // ?? watchdog
 	AM_RANGE(0x3807, 0x3807) AM_WRITE(renegade_coin_counter_w)
-	AM_RANGE(0x4000, 0x7fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x8000, 0xffff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x4000, 0x7fff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x8000, 0xffff) AM_WRITE(SMH_ROM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x0fff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0000, 0x0fff) AM_READ(SMH_RAM)
 	AM_RANGE(0x1000, 0x1000) AM_READ(soundlatch_r)
-	AM_RANGE(0x2801, 0x2801) AM_READ(YM3526_status_port_0_r)
-	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_ROM)
+	AM_RANGE(0x2801, 0x2801) AM_READ(ym3526_status_port_0_r)
+	AM_RANGE(0x8000, 0xffff) AM_READ(SMH_ROM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x0fff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0x1800, 0x1800) AM_WRITE(MWA8_NOP) // this gets written the same values as 0x2000
+	AM_RANGE(0x0000, 0x0fff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0x1800, 0x1800) AM_WRITE(SMH_NOP) // this gets written the same values as 0x2000
 	AM_RANGE(0x2000, 0x2000) AM_WRITE(adpcm_play_w)
-	AM_RANGE(0x2800, 0x2800) AM_WRITE(YM3526_control_port_0_w)
-	AM_RANGE(0x2801, 0x2801) AM_WRITE(YM3526_write_port_0_w)
-	AM_RANGE(0x3000, 0x3000) AM_WRITE(MWA8_NOP) /* adpcm related? stereo pan? */
-	AM_RANGE(0x8000, 0xffff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x2800, 0x2800) AM_WRITE(ym3526_control_port_0_w)
+	AM_RANGE(0x2801, 0x2801) AM_WRITE(ym3526_write_port_0_w)
+	AM_RANGE(0x3000, 0x3000) AM_WRITE(SMH_NOP) /* adpcm related? stereo pan? */
+	AM_RANGE(0x8000, 0xffff) AM_WRITE(SMH_ROM)
 ADDRESS_MAP_END
 
 
 
 static INPUT_PORTS_START( renegade )
-	PORT_START	/* IN0 */
+	PORT_START("IN0")	/* IN0 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT )  PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )    PORT_8WAY PORT_PLAYER(1)
@@ -578,7 +582,7 @@ static INPUT_PORTS_START( renegade )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START	/* IN1 */
+	PORT_START("IN1")	/* IN1 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT )  PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP )    PORT_8WAY PORT_PLAYER(2)
@@ -588,7 +592,7 @@ static INPUT_PORTS_START( renegade )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )
 
-	PORT_START /* DIP2 */
+	PORT_START("DSW2")	/* DIP2 */
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(	0x02, DEF_STR( Easy ) )
 	PORT_DIPSETTING(	0x03, DEF_STR( Normal ) )
@@ -602,7 +606,7 @@ static INPUT_PORTS_START( renegade )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_VBLANK )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE1 )
 
-	PORT_START /* DIP1 */
+	PORT_START("DSW1")	/* DIP1 */
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) )
@@ -722,55 +726,55 @@ static const gfx_layout tileslayout4 =
 
 static GFXDECODE_START( renegade )
 	/* 8x8 text, 8 colors */
-	GFXDECODE_ENTRY( REGION_GFX1, 0x00000, charlayout,	 0, 4 )	/* colors   0- 32 */
+	GFXDECODE_ENTRY( "gfx1", 0x00000, charlayout,	 0, 4 )	/* colors   0- 32 */
 
 	/* 16x16 background tiles, 8 colors */
-	GFXDECODE_ENTRY( REGION_GFX2, 0x00000, tileslayout1, 192, 8 )	/* colors 192-255 */
-	GFXDECODE_ENTRY( REGION_GFX2, 0x00000, tileslayout2, 192, 8 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x00000, tileslayout3, 192, 8 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x00000, tileslayout4, 192, 8 )
+	GFXDECODE_ENTRY( "gfx2", 0x00000, tileslayout1, 192, 8 )	/* colors 192-255 */
+	GFXDECODE_ENTRY( "gfx2", 0x00000, tileslayout2, 192, 8 )
+	GFXDECODE_ENTRY( "gfx2", 0x00000, tileslayout3, 192, 8 )
+	GFXDECODE_ENTRY( "gfx2", 0x00000, tileslayout4, 192, 8 )
 
-	GFXDECODE_ENTRY( REGION_GFX2, 0x18000, tileslayout1, 192, 8 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x18000, tileslayout2, 192, 8 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x18000, tileslayout3, 192, 8 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x18000, tileslayout4, 192, 8 )
+	GFXDECODE_ENTRY( "gfx2", 0x18000, tileslayout1, 192, 8 )
+	GFXDECODE_ENTRY( "gfx2", 0x18000, tileslayout2, 192, 8 )
+	GFXDECODE_ENTRY( "gfx2", 0x18000, tileslayout3, 192, 8 )
+	GFXDECODE_ENTRY( "gfx2", 0x18000, tileslayout4, 192, 8 )
 
 	/* 16x16 sprites, 8 colors */
-	GFXDECODE_ENTRY( REGION_GFX3, 0x00000, tileslayout1, 128, 4 )	/* colors 128-159 */
-	GFXDECODE_ENTRY( REGION_GFX3, 0x00000, tileslayout2, 128, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x00000, tileslayout3, 128, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x00000, tileslayout4, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x00000, tileslayout1, 128, 4 )	/* colors 128-159 */
+	GFXDECODE_ENTRY( "gfx3", 0x00000, tileslayout2, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x00000, tileslayout3, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x00000, tileslayout4, 128, 4 )
 
-	GFXDECODE_ENTRY( REGION_GFX3, 0x18000, tileslayout1, 128, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x18000, tileslayout2, 128, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x18000, tileslayout3, 128, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x18000, tileslayout4, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x18000, tileslayout1, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x18000, tileslayout2, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x18000, tileslayout3, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x18000, tileslayout4, 128, 4 )
 
-	GFXDECODE_ENTRY( REGION_GFX3, 0x30000, tileslayout1, 128, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x30000, tileslayout2, 128, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x30000, tileslayout3, 128, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x30000, tileslayout4, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x30000, tileslayout1, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x30000, tileslayout2, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x30000, tileslayout3, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x30000, tileslayout4, 128, 4 )
 
-	GFXDECODE_ENTRY( REGION_GFX3, 0x48000, tileslayout1, 128, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x48000, tileslayout2, 128, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x48000, tileslayout3, 128, 4 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x48000, tileslayout4, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x48000, tileslayout1, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x48000, tileslayout2, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x48000, tileslayout3, 128, 4 )
+	GFXDECODE_ENTRY( "gfx3", 0x48000, tileslayout4, 128, 4 )
 GFXDECODE_END
 
 
 
 /* handler called by the 3526 emulator when the internal timers cause an IRQ */
-static void irqhandler(int linestate)
+static void irqhandler(running_machine *machine, int linestate)
 {
-	cpunum_set_input_line(Machine, 1, M6809_FIRQ_LINE, linestate);
+	cpu_set_input_line(machine->cpu[1], M6809_FIRQ_LINE, linestate);
 }
 
-static const struct YM3526interface ym3526_interface =
+static const ym3526_interface ym3526_config =
 {
 	irqhandler
 };
 
-static const struct CustomSound_interface adpcm_interface =
+static const custom_sound_interface adpcm_interface =
 {
 	renegade_adpcm_start
 };
@@ -779,45 +783,45 @@ static const struct CustomSound_interface adpcm_interface =
 static MACHINE_RESET( renegade )
 {
 	bank = 0;
-	setbank();
+	setbank(machine);
 }
 
 
 static MACHINE_DRIVER_START( renegade )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M6502, 12000000/8)	/* 1.5 MHz (measured) */
+	MDRV_CPU_ADD("main", M6502, 12000000/8)	/* 1.5 MHz (measured) */
 	MDRV_CPU_PROGRAM_MAP(main_readmem,main_writemem)
-	MDRV_CPU_VBLANK_INT(renegade_interrupt,2)
+	MDRV_CPU_VBLANK_INT_HACK(renegade_interrupt,2)
 
-	MDRV_CPU_ADD(M6809, 12000000/8)
-	/* audio CPU */
+	MDRV_CPU_ADD("audio", M6809, 12000000/8)
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 								/* IRQs are caused by the main CPU */
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION*2)
 	MDRV_MACHINE_START(renegade)
 	MDRV_MACHINE_RESET(renegade)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 0, 30*8-1)
-	MDRV_GFXDECODE(renegade)
-	MDRV_PALETTE_LENGTH(256)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */*2)
+    MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+    MDRV_SCREEN_SIZE(32*8, 32*8)
+    MDRV_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 0, 30*8-1)
 
-	MDRV_VIDEO_START(renegade)
-	MDRV_VIDEO_UPDATE(renegade)
+    MDRV_GFXDECODE(renegade)
+    MDRV_PALETTE_LENGTH(256)
 
-	/* sound hardware */
+    MDRV_VIDEO_START(renegade)
+    MDRV_VIDEO_UPDATE(renegade)
+
+    /* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM3526, 12000000/4)
-	MDRV_SOUND_CONFIG(ym3526_interface)
+	MDRV_SOUND_ADD("ym", YM3526, 12000000/4)
+	MDRV_SOUND_CONFIG(ym3526_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_SOUND_ADD(CUSTOM, 8000)
+	MDRV_SOUND_ADD("adpcm", CUSTOM, 8000)
 	MDRV_SOUND_CONFIG(adpcm_interface)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
@@ -825,21 +829,21 @@ MACHINE_DRIVER_END
 
 
 ROM_START( renegade )
-	ROM_REGION( 0x14000, REGION_CPU1, 0 )	/* 64k for code + bank switched ROM */
+	ROM_REGION( 0x14000, "main", 0 )	/* 64k for code + bank switched ROM */
 	ROM_LOAD( "nb-5.bin",     0x08000, 0x8000, CRC(ba683ddf) SHA1(7516fac1c4fd14cbf43481e94c0c26c662c4cd28) )
 	ROM_LOAD( "na-5.bin",     0x04000, 0x4000, CRC(de7e7df4) SHA1(7d26ac29e0b5858d9a0c0cdc86c864e464145260) )
 	ROM_CONTINUE(		  0x10000, 0x4000 )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* audio CPU (M6809) */
+	ROM_REGION( 0x10000, "audio", 0 ) /* audio CPU (M6809) */
 	ROM_LOAD( "n0-5.bin",     0x8000, 0x8000, CRC(3587de3b) SHA1(f82e758254b21eb0c5a02469c72adb86d9577065) )
 
-	ROM_REGION( 0x10000, REGION_CPU3, 0 ) /* mcu (missing) */
+	ROM_REGION( 0x10000, "cpu2", 0 ) /* mcu (missing) */
 	ROM_LOAD( "mcu",          0x8000, 0x8000, NO_DUMP )
 
-	ROM_REGION( 0x08000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x08000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "nc-5.bin",     0x0000, 0x8000, CRC(9adfaa5d) SHA1(7bdb7bd4387b49e0489f9539161e1ed9d8f9f6a0) )  /* characters */
 
-	ROM_REGION( 0x30000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x30000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "n1-5.bin",     0x00000, 0x8000, CRC(4a9f47f3) SHA1(01c94bc4c85314f1e0caa3afe91705875d118c13) ) /* tiles */
 	ROM_LOAD( "n6-5.bin",     0x08000, 0x8000, CRC(d62a0aa8) SHA1(a0b55cd3eee352fb91d9bb8c6c4f4f55b2df83e9) )
 	ROM_LOAD( "n7-5.bin",     0x10000, 0x8000, CRC(7ca5a532) SHA1(1110aa1c7562805dd4b298ab2860c66a6cc2685b) )
@@ -847,7 +851,7 @@ ROM_START( renegade )
 	ROM_LOAD( "n8-5.bin",     0x20000, 0x8000, CRC(0dba31d3) SHA1(8fe250787debe07e4f6c0002a9f799869b13a5fd) )
 	ROM_LOAD( "n9-5.bin",     0x28000, 0x8000, CRC(5b621b6a) SHA1(45c6a688a5b4e9da71133c43cc48eea568557be3) )
 
-	ROM_REGION( 0x60000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x60000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "nh-5.bin",     0x00000, 0x8000, CRC(dcd7857c) SHA1(eb530ccc939f2fa42b3c743605d5398f4afe7d7a) ) /* sprites */
 	ROM_LOAD( "nd-5.bin",     0x08000, 0x8000, CRC(2de1717c) SHA1(af5a994348301fa888092ae65d08cfb6ad124407) )
 	ROM_LOAD( "nj-5.bin",     0x10000, 0x8000, CRC(0f96a18e) SHA1(1f7e11e11d5031b4942d9d05161bcb9466514af8) )
@@ -861,28 +865,28 @@ ROM_START( renegade )
 	ROM_LOAD( "ng-5.bin",     0x50000, 0x8000, CRC(a8ee3720) SHA1(df3d40015b16fa7a9bf05f0ed5741c22f7f152c7) )
 	ROM_LOAD( "nm-5.bin",     0x58000, 0x8000, CRC(c100258e) SHA1(0e2124e642b9742a9a0045f460974025048bc2dd) )
 
-	ROM_REGION( 0x20000, REGION_SOUND1, 0 ) /* adpcm */
+	ROM_REGION( 0x20000, "adpcm", 0 ) /* adpcm */
 	ROM_LOAD( "n5-5.bin",     0x00000, 0x8000, CRC(7ee43a3c) SHA1(36b14b886096177cdd0bd0c99cbcfcc362b2bc30) )
 	ROM_LOAD( "n4-5.bin",     0x10000, 0x8000, CRC(6557564c) SHA1(b3142be9d48eacb43786079a7ae012010f6afabb) )
 	ROM_LOAD( "n3-5.bin",     0x18000, 0x8000, CRC(78fd6190) SHA1(995df0e88f5c34946e0634b50bda8c1cc621afaa) )
 ROM_END
 
 ROM_START( kuniokun )
-	ROM_REGION( 0x14000, REGION_CPU1, 0 )	/* 64k for code + bank switched ROM */
+	ROM_REGION( 0x14000, "main", 0 )	/* 64k for code + bank switched ROM */
 	ROM_LOAD( "nb-01.bin",    0x08000, 0x8000, CRC(93fcfdf5) SHA1(51cdb9377544ae17895e427f21d150ce195ab8e7) ) // original
 	ROM_LOAD( "ta18-11.bin",  0x04000, 0x4000, CRC(f240f5cd) SHA1(ed6875e8ad2988e88389d4f63ff448d0823c195f) )
 	ROM_CONTINUE(		  0x10000, 0x4000 )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* audio CPU (M6809) */
+	ROM_REGION( 0x10000, "audio", 0 ) /* audio CPU (M6809) */
 	ROM_LOAD( "n0-5.bin",     0x8000, 0x8000, CRC(3587de3b) SHA1(f82e758254b21eb0c5a02469c72adb86d9577065) )
 
-	ROM_REGION( 0x10000, REGION_CPU3, 0 ) /* mcu (missing) */
+	ROM_REGION( 0x10000, "cpu2", 0 ) /* mcu (missing) */
 	ROM_LOAD( "mcu",          0x8000, 0x8000, NO_DUMP )
 
-	ROM_REGION( 0x08000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x08000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "ta18-25.bin",  0x0000, 0x8000, CRC(9bd2bea3) SHA1(fa79c9d4c71c1dbbf0e14cb8d6870f1f94b9af88) )  /* characters */
 
-	ROM_REGION( 0x30000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x30000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "ta18-01.bin",  0x00000, 0x8000, CRC(daf15024) SHA1(f37de97275f52dfbbad7bf8c82f8108e84bcf63e) ) /* tiles */
 	ROM_LOAD( "ta18-06.bin",  0x08000, 0x8000, CRC(1f59a248) SHA1(8ab70aa8f0dccbe94240c96835a43b0900d52120) )
 	ROM_LOAD( "n7-5.bin",     0x10000, 0x8000, CRC(7ca5a532) SHA1(1110aa1c7562805dd4b298ab2860c66a6cc2685b) )
@@ -890,7 +894,7 @@ ROM_START( kuniokun )
 	ROM_LOAD( "ta18-04.bin",  0x20000, 0x8000, CRC(55b9e8aa) SHA1(26c91030c53a022c1f1f3131768e8f7ba613168d) )
 	ROM_LOAD( "ta18-03.bin",  0x28000, 0x8000, CRC(0475c99a) SHA1(36b7b856e728c68e0dd3ecb844033369a5117270) )
 
-	ROM_REGION( 0x60000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x60000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "ta18-20.bin",  0x00000, 0x8000, CRC(c7d54139) SHA1(f76d237a6ee8bbcbf344145d31e532834da7c131) ) /* sprites */
 	ROM_LOAD( "ta18-24.bin",  0x08000, 0x8000, CRC(84677d45) SHA1(cb7fe69e13d2d696acbc464b7584c7514cfc7f85) )
 	ROM_LOAD( "ta18-18.bin",  0x10000, 0x8000, CRC(1c770853) SHA1(4fe6051265729a9d36b6d3dd826c3f6dcb4a7a25) )
@@ -904,25 +908,25 @@ ROM_START( kuniokun )
 	ROM_LOAD( "ta18-21.bin",  0x50000, 0x8000, CRC(c95e009b) SHA1(d45a247d4ebf8587a2cd30c83444cc7bd17a3534) )
 	ROM_LOAD( "ta18-15.bin",  0x58000, 0x8000, CRC(a5d61d01) SHA1(9bf1f0b8296667db31ff1c34e28c8eda3ce9f7c3) )
 
-	ROM_REGION( 0x20000, REGION_SOUND1, 0 ) /* adpcm */
+	ROM_REGION( 0x20000, "adpcm", 0 ) /* adpcm */
 	ROM_LOAD( "ta18-07.bin",  0x00000, 0x8000, CRC(02e3f3ed) SHA1(ab09b3af2c4ab9a36eb1273bcc7c788350048554) )
 	ROM_LOAD( "ta18-08.bin",  0x10000, 0x8000, CRC(c9312613) SHA1(fbbdf7c56c34cbee42984e41fcf2a21da2b87a31) )
 	ROM_LOAD( "ta18-09.bin",  0x18000, 0x8000, CRC(07ed4705) SHA1(6fd4b78ca846fa602504f06f3105b2da03bcd00c) )
 ROM_END
 
 ROM_START( kuniokub )
-	ROM_REGION( 0x14000, REGION_CPU1, 0 )	/* 64k for code + bank switched ROM */
+	ROM_REGION( 0x14000, "main", 0 )	/* 64k for code + bank switched ROM */
 	ROM_LOAD( "ta18-10.bin",  0x08000, 0x8000, CRC(a90cf44a) SHA1(6d63d9c29da7b8c5bc391e074b6b8fe6ae3892ae) ) // bootleg
 	ROM_LOAD( "ta18-11.bin",  0x04000, 0x4000, CRC(f240f5cd) SHA1(ed6875e8ad2988e88389d4f63ff448d0823c195f) )
 	ROM_CONTINUE(		  0x10000, 0x4000 )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* audio CPU (M6809) */
+	ROM_REGION( 0x10000, "audio", 0 ) /* audio CPU (M6809) */
 	ROM_LOAD( "n0-5.bin",     0x8000, 0x8000, CRC(3587de3b) SHA1(f82e758254b21eb0c5a02469c72adb86d9577065) )
 
-	ROM_REGION( 0x08000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x08000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "ta18-25.bin",  0x0000, 0x8000, CRC(9bd2bea3) SHA1(fa79c9d4c71c1dbbf0e14cb8d6870f1f94b9af88) )  /* characters */
 
-	ROM_REGION( 0x30000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x30000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "ta18-01.bin",  0x00000, 0x8000, CRC(daf15024) SHA1(f37de97275f52dfbbad7bf8c82f8108e84bcf63e) ) /* tiles */
 	ROM_LOAD( "ta18-06.bin",  0x08000, 0x8000, CRC(1f59a248) SHA1(8ab70aa8f0dccbe94240c96835a43b0900d52120) )
 	ROM_LOAD( "n7-5.bin",     0x10000, 0x8000, CRC(7ca5a532) SHA1(1110aa1c7562805dd4b298ab2860c66a6cc2685b) )
@@ -930,7 +934,7 @@ ROM_START( kuniokub )
 	ROM_LOAD( "ta18-04.bin",  0x20000, 0x8000, CRC(55b9e8aa) SHA1(26c91030c53a022c1f1f3131768e8f7ba613168d) )
 	ROM_LOAD( "ta18-03.bin",  0x28000, 0x8000, CRC(0475c99a) SHA1(36b7b856e728c68e0dd3ecb844033369a5117270) )
 
-	ROM_REGION( 0x60000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x60000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "ta18-20.bin",  0x00000, 0x8000, CRC(c7d54139) SHA1(f76d237a6ee8bbcbf344145d31e532834da7c131) ) /* sprites */
 	ROM_LOAD( "ta18-24.bin",  0x08000, 0x8000, CRC(84677d45) SHA1(cb7fe69e13d2d696acbc464b7584c7514cfc7f85) )
 	ROM_LOAD( "ta18-18.bin",  0x10000, 0x8000, CRC(1c770853) SHA1(4fe6051265729a9d36b6d3dd826c3f6dcb4a7a25) )
@@ -944,7 +948,7 @@ ROM_START( kuniokub )
 	ROM_LOAD( "ta18-21.bin",  0x50000, 0x8000, CRC(c95e009b) SHA1(d45a247d4ebf8587a2cd30c83444cc7bd17a3534) )
 	ROM_LOAD( "ta18-15.bin",  0x58000, 0x8000, CRC(a5d61d01) SHA1(9bf1f0b8296667db31ff1c34e28c8eda3ce9f7c3) )
 
-	ROM_REGION( 0x20000, REGION_SOUND1, 0 ) /* adpcm */
+	ROM_REGION( 0x20000, "adpcm", 0 ) /* adpcm */
 	ROM_LOAD( "ta18-07.bin",  0x00000, 0x8000, CRC(02e3f3ed) SHA1(ab09b3af2c4ab9a36eb1273bcc7c788350048554) )
 	ROM_LOAD( "ta18-08.bin",  0x10000, 0x8000, CRC(c9312613) SHA1(fbbdf7c56c34cbee42984e41fcf2a21da2b87a31) )
 	ROM_LOAD( "ta18-09.bin",  0x18000, 0x8000, CRC(07ed4705) SHA1(6fd4b78ca846fa602504f06f3105b2da03bcd00c) )
