@@ -29,6 +29,7 @@ TODO:
 ***************************************************************************/
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
 #include "sound/ay8910.h"
 #include "sound/msm5205.h"
 
@@ -58,13 +59,13 @@ static TILE_GET_INFO( get_bg_tile_info )
 
 static VIDEO_START( rmhaihai )
 {
-	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_rows,
-		TILEMAP_TYPE_PEN, 8, 8, 64, 32);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows,
+		8, 8, 64, 32);
 }
 
 static VIDEO_UPDATE( rmhaihai )
 {
-	tilemap_draw(bitmap, &machine->screen[0].visarea, bg_tilemap, 0, 0);
+	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
 	return 0;
 }
 
@@ -74,8 +75,10 @@ static int keyboard_cmd;
 
 static READ8_HANDLER( keyboard_r )
 {
-logerror("%04x: keyboard_r\n",activecpu_get_pc());
-	switch(activecpu_get_pc())
+	static const char *const keynames[] = { "KEY0", "KEY1" };
+
+	logerror("%04x: keyboard_r\n",cpu_get_pc(space->cpu));
+	switch(cpu_get_pc(space->cpu))
 	{
 		/* read keyboard */
 		case 0x0aba:	// rmhaihai, rmhaisei
@@ -85,11 +88,11 @@ logerror("%04x: keyboard_r\n",activecpu_get_pc());
 		{
 			int i;
 
-			for (i = 0;i < 31;i++)
+			for (i = 0; i < 31; i++)
 			{
-				if (readinputport(2 + i/16) & (1<<(i&15))) return i+1;
+				if (input_port_read(space->machine, keynames[i/16]) & (1 << (i & 15))) return i+1;
 			}
-			if (readinputport(3) & 0x8000) return 0x80;	// coin
+			if (input_port_read(space->machine, "KEY1") & 0x8000) return 0x80;	// coin
 			return 0;
 		}
 		case 0x5c7b:	// rmhaihai, rmhaisei, rmhaijin
@@ -122,25 +125,25 @@ logerror("%04x: keyboard_r\n",activecpu_get_pc());
 
 static WRITE8_HANDLER( keyboard_w )
 {
-logerror("%04x: keyboard_w %02x\n",activecpu_get_pc(),data);
+logerror("%04x: keyboard_w %02x\n",cpu_get_pc(space->cpu),data);
 	keyboard_cmd = data;
 }
 
 static READ8_HANDLER( samples_r )
 {
-	return memory_region(REGION_SOUND1)[offset];
+	return memory_region(space->machine, "adpcm")[offset];
 }
 
 static WRITE8_HANDLER( adpcm_w )
 {
-	MSM5205_data_w(0,data);         /* bit0..3  */
-	MSM5205_reset_w(0,(data>>5)&1); /* bit 5    */
-	MSM5205_vclk_w (0,(data>>4)&1); /* bit4     */
+	msm5205_data_w(0,data);         /* bit0..3  */
+	msm5205_reset_w(0,(data>>5)&1); /* bit 5    */
+	msm5205_vclk_w (0,(data>>4)&1); /* bit4     */
 }
 
 static WRITE8_HANDLER( ctrl_w )
 {
-	flip_screen_set(data & 0x01);
+	flip_screen_set(space->machine, data & 0x01);
 
 	// (data & 0x02) is switched on and off in service mode
 
@@ -154,83 +157,152 @@ static WRITE8_HANDLER( ctrl_w )
 
 static WRITE8_HANDLER( themj_rombank_w )
 {
-	UINT8 *rom = memory_region(REGION_CPU1) + 0x10000;
+	UINT8 *rom = memory_region(space->machine, "main") + 0x10000;
 	int bank = data & 0x03;
 logerror("banksw %d\n",bank);
-	memory_set_bankptr(1, rom + bank*0x4000);
-	memory_set_bankptr(2, rom + bank*0x4000 + 0x2000);
+	memory_set_bankptr(space->machine, 1, rom + bank*0x4000);
+	memory_set_bankptr(space->machine, 2, rom + bank*0x4000 + 0x2000);
 }
 
 static MACHINE_RESET( themj )
 {
-	themj_rombank_w(0,0);
+	themj_rombank_w(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_IO),0,0);
 }
 
 
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x9fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xa000, 0xa7ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xa800, 0xb7ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xc000, 0xdfff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xe000, 0xffff) AM_READ(MRA8_ROM)	/* rmhaisei only */
+	AM_RANGE(0x0000, 0x9fff) AM_READ(SMH_ROM)
+	AM_RANGE(0xa000, 0xa7ff) AM_READ(SMH_RAM)
+	AM_RANGE(0xa800, 0xb7ff) AM_READ(SMH_RAM)
+	AM_RANGE(0xc000, 0xdfff) AM_READ(SMH_ROM)
+	AM_RANGE(0xe000, 0xffff) AM_READ(SMH_ROM)	/* rmhaisei only */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( themj_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0x9fff) AM_READ(MRA8_BANK1)
-	AM_RANGE(0xa000, 0xa7ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xa800, 0xb7ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xc000, 0xdfff) AM_READ(MRA8_BANK2)
-	AM_RANGE(0xe000, 0xffff) AM_READ(MRA8_ROM)
+	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x8000, 0x9fff) AM_READ(SMH_BANK1)
+	AM_RANGE(0xa000, 0xa7ff) AM_READ(SMH_RAM)
+	AM_RANGE(0xa800, 0xb7ff) AM_READ(SMH_RAM)
+	AM_RANGE(0xc000, 0xdfff) AM_READ(SMH_BANK2)
+	AM_RANGE(0xe000, 0xffff) AM_READ(SMH_ROM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x9fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xa000, 0xa7ff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x0000, 0x9fff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0xa000, 0xa7ff) AM_WRITE(SMH_RAM)
 	AM_RANGE(0xa800, 0xafff) AM_WRITE(rmhaihai_colorram_w) AM_BASE(&colorram)
 	AM_RANGE(0xb000, 0xb7ff) AM_WRITE(rmhaihai_videoram_w) AM_BASE(&videoram)
-	AM_RANGE(0xb83c, 0xb83c) AM_WRITE(MWA8_NOP)	// ??
-	AM_RANGE(0xbc00, 0xbc00) AM_WRITE(MWA8_NOP)	// ??
-	AM_RANGE(0xc000, 0xdfff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xe000, 0xffff) AM_WRITE(MWA8_ROM)	/* rmhaisei only */
+	AM_RANGE(0xb83c, 0xb83c) AM_WRITE(SMH_NOP)	// ??
+	AM_RANGE(0xbc00, 0xbc00) AM_WRITE(SMH_NOP)	// ??
+	AM_RANGE(0xc000, 0xdfff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0xe000, 0xffff) AM_WRITE(SMH_ROM)	/* rmhaisei only */
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( readport, ADDRESS_SPACE_IO, 8 )
+static ADDRESS_MAP_START( io_map, ADDRESS_SPACE_IO, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_READ(samples_r)
-	AM_RANGE(0x8000, 0x8000) AM_READ(keyboard_r)
-	AM_RANGE(0x8001, 0x8001) AM_READ(MRA8_NOP)	// ??
-	AM_RANGE(0x8020, 0x8020) AM_READ(AY8910_read_port_0_r)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writeport, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x8000, 0x8000) AM_WRITE(MWA8_NOP)	// ??
-	AM_RANGE(0x8001, 0x8001) AM_WRITE(keyboard_w)
-	AM_RANGE(0x8020, 0x8020) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0x8021, 0x8021) AM_WRITE(AY8910_write_port_0_w)
+	AM_RANGE(0x8000, 0x8000) AM_READWRITE(keyboard_r, SMH_NOP)	// ??
+	AM_RANGE(0x8001, 0x8001) AM_READWRITE(SMH_NOP, keyboard_w)	// ??
+	AM_RANGE(0x8020, 0x8020) AM_READWRITE(ay8910_read_port_0_r, ay8910_control_port_0_w)
+	AM_RANGE(0x8021, 0x8021) AM_WRITE(ay8910_write_port_0_w)
 	AM_RANGE(0x8040, 0x8040) AM_WRITE(adpcm_w)
 	AM_RANGE(0x8060, 0x8060) AM_WRITE(ctrl_w)
-	AM_RANGE(0x8080, 0x8080) AM_WRITE(MWA8_NOP)	// ??
-	AM_RANGE(0xbc04, 0xbc04) AM_WRITE(MWA8_NOP)	// ??
-	AM_RANGE(0xbc0c, 0xbc0c) AM_WRITE(MWA8_NOP)	// ??
+	AM_RANGE(0x8080, 0x8080) AM_WRITE(SMH_NOP)	// ??
+	AM_RANGE(0xbc04, 0xbc04) AM_WRITE(SMH_NOP)	// ??
+	AM_RANGE(0xbc0c, 0xbc0c) AM_WRITE(SMH_NOP)	// ??
 ADDRESS_MAP_END
 
-
-static ADDRESS_MAP_START( themj_writeport, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x8000, 0x8000) AM_WRITE(MWA8_NOP)	// ??
-	AM_RANGE(0x8001, 0x8001) AM_WRITE(keyboard_w)
-	AM_RANGE(0x8020, 0x8020) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0x8021, 0x8021) AM_WRITE(AY8910_write_port_0_w)
+static ADDRESS_MAP_START( themj_io_map, ADDRESS_SPACE_IO, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_READ(samples_r)
+	AM_RANGE(0x8000, 0x8000) AM_READWRITE(keyboard_r, SMH_NOP)	// ??
+	AM_RANGE(0x8001, 0x8001) AM_READWRITE(SMH_NOP, keyboard_w)	// ??
+	AM_RANGE(0x8020, 0x8020) AM_READWRITE(ay8910_read_port_0_r, ay8910_control_port_0_w)
+	AM_RANGE(0x8021, 0x8021) AM_WRITE(ay8910_write_port_0_w)
 	AM_RANGE(0x8040, 0x8040) AM_WRITE(adpcm_w)
 	AM_RANGE(0x8060, 0x8060) AM_WRITE(ctrl_w)
-	AM_RANGE(0x8080, 0x8080) AM_WRITE(MWA8_NOP)	// ??
+	AM_RANGE(0x8080, 0x8080) AM_WRITE(SMH_NOP)	// ??
 	AM_RANGE(0x80a0, 0x80a0) AM_WRITE(themj_rombank_w)
-	AM_RANGE(0xbc04, 0xbc04) AM_WRITE(MWA8_NOP)	// ??
-	AM_RANGE(0xbc0c, 0xbc0c) AM_WRITE(MWA8_NOP)	// ??
+	AM_RANGE(0xbc04, 0xbc04) AM_WRITE(SMH_NOP)	// ??
+	AM_RANGE(0xbc0c, 0xbc0c) AM_WRITE(SMH_NOP)	// ??
 ADDRESS_MAP_END
 
+static INPUT_PORTS_START( mjctrl )
+	PORT_START("KEY0")		// fake, handled by keyboard_r()
+	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_SMALL )
+	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_DOUBLE_UP )
+	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_MAHJONG_BIG )
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_SCORE )
+	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_FLIP_FLOP )
+	PORT_BIT( 0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_LAST_CHANCE )
+	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_K )
+	PORT_BIT( 0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_RON )
+	PORT_BIT( 0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_G )
+	PORT_BIT( 0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_CHI )
+	PORT_BIT( 0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_C )
+	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_L )
+	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_MAHJONG_H )
+
+	PORT_START("KEY1")	// fake, handled by keyboard_r()
+	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_PON )
+	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_D )
+	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_START1 )
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_I )
+	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_KAN )
+	PORT_BIT( 0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_E )
+	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_MAHJONG_M )
+	PORT_BIT( 0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_A )
+	PORT_BIT( 0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_BET )
+	PORT_BIT( 0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_J )
+	PORT_BIT( 0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_REACH )
+	PORT_BIT( 0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_F )
+	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_MAHJONG_N )
+	PORT_BIT( 0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_B )
+	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
+
+	PORT_START("KEY2")	// fake, handled by keyboard_r()
+	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_SMALL ) PORT_PLAYER(2)
+	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_DOUBLE_UP ) PORT_PLAYER(2)
+	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_MAHJONG_BIG ) PORT_PLAYER(2)
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_SCORE ) PORT_PLAYER(2)
+	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_FLIP_FLOP ) PORT_PLAYER(2)
+	PORT_BIT( 0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_LAST_CHANCE ) PORT_PLAYER(2)
+	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_K ) PORT_PLAYER(2)
+	PORT_BIT( 0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_RON ) PORT_PLAYER(2)
+	PORT_BIT( 0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_G ) PORT_PLAYER(2)
+	PORT_BIT( 0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_CHI ) PORT_PLAYER(2)
+	PORT_BIT( 0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_C ) PORT_PLAYER(2)
+	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_L ) PORT_PLAYER(2)
+	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_MAHJONG_H ) PORT_PLAYER(2)
+
+
+	PORT_START("KEY3")	// fake, handled by keyboard_r()
+	PORT_BIT( 0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_PON ) PORT_PLAYER(2)
+	PORT_BIT( 0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_D ) PORT_PLAYER(2)
+	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_START2 )
+	PORT_BIT( 0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_I ) PORT_PLAYER(2)
+	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_KAN ) PORT_PLAYER(2)
+	PORT_BIT( 0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_E ) PORT_PLAYER(2)
+	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_MAHJONG_M ) PORT_PLAYER(2)
+	PORT_BIT( 0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_A ) PORT_PLAYER(2)
+	PORT_BIT( 0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_BET ) PORT_PLAYER(2)
+	PORT_BIT( 0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_J ) PORT_PLAYER(2)
+	PORT_BIT( 0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_REACH ) PORT_PLAYER(2)
+	PORT_BIT( 0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_F ) PORT_PLAYER(2)
+	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_MAHJONG_N ) PORT_PLAYER(2)
+	PORT_BIT( 0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_B ) PORT_PLAYER(2)
+	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_IMPULSE(1)
+INPUT_PORTS_END
+
 static INPUT_PORTS_START( rmhaihai )
-	PORT_START  /* dsw2 */
+	PORT_START("DSW2")  /* dsw2 */
 	PORT_DIPNAME( 0x01, 0x01, "Unknown 2-1" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -244,7 +316,7 @@ static INPUT_PORTS_START( rmhaihai )
 	PORT_DIPSETTING(    0xfa, "7" )
 	PORT_DIPSETTING(    0xfc, "8 (Difficult)" )
 
-    PORT_START  /* dsw1 */
+    PORT_START("DSW1")  /* dsw1 */
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Free_Play ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -267,82 +339,11 @@ static INPUT_PORTS_START( rmhaihai )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START	// fake, handled by keyboard_r()
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_SMALL )
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_DOUBLE_UP )
-	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_MAHJONG_BIG )
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_SCORE )
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_FLIP_FLOP )
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_LAST_CHANCE )
-	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_K )
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_RON )
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_G )
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_CHI )
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_C )
-	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_L )
-	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_MAHJONG_H )
-
-	PORT_START	// fake, handled by keyboard_r()
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_PON )
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_D )
-	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_START1 )
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_I )
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_KAN )
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_E )
-	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_MAHJONG_M )
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_A )
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_BET )
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_J )
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_REACH )
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_F )
-	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_MAHJONG_N )
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_B )
-	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
-
-	PORT_START	// fake, handled by keyboard_r()
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_SMALL )PORT_PLAYER(2)
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_DOUBLE_UP )PORT_PLAYER(2)
-	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_MAHJONG_BIG )PORT_PLAYER(2)
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_SCORE )PORT_PLAYER(2)
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_FLIP_FLOP )PORT_PLAYER(2)
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_LAST_CHANCE )PORT_PLAYER(2)
-	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_K )PORT_PLAYER(2)
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_RON )PORT_PLAYER(2)
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_G )PORT_PLAYER(2)
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_CHI )PORT_PLAYER(2)
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_C )PORT_PLAYER(2)
-	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_L )PORT_PLAYER(2)
-	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_MAHJONG_H )PORT_PLAYER(2)
-
-
-	PORT_START	// fake, handled by keyboard_r()
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_PON )PORT_PLAYER(2)
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_D )PORT_PLAYER(2)
-	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_START2 )
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_I )PORT_PLAYER(2)
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_KAN )PORT_PLAYER(2)
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_E )PORT_PLAYER(2)
-	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_MAHJONG_M )PORT_PLAYER(2)
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_A )PORT_PLAYER(2)
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_BET )PORT_PLAYER(2)
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_J )PORT_PLAYER(2)
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_REACH )PORT_PLAYER(2)
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_F )PORT_PLAYER(2)
-	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_MAHJONG_N )PORT_PLAYER(2)
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_B )PORT_PLAYER(2)
-	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_IMPULSE(1)
+	PORT_INCLUDE( mjctrl )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( rmhaihib )
-	PORT_START  /* dsw2 */
+	PORT_START("DSW2")  /* dsw2 */
 	PORT_DIPNAME( 0x01, 0x01, "Unknown 2-1" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -367,7 +368,7 @@ static INPUT_PORTS_START( rmhaihib )
 	PORT_DIPSETTING(    0x20, "30%" )
 	PORT_DIPSETTING(    0x00, "20%" )
 
-	PORT_START  /* dsw1 */
+	PORT_START("DSW1")  /* dsw1 */
 	PORT_DIPNAME( 0x03, 0x03, "Bet Max" )
 	PORT_DIPSETTING(    0x01, "1" )
 	PORT_DIPSETTING(    0x00, "2" )
@@ -391,79 +392,9 @@ static INPUT_PORTS_START( rmhaihib )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START	// fake, handled by keyboard_r()
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_SMALL )
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_DOUBLE_UP )
-	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_MAHJONG_BIG )
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_SCORE )
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_FLIP_FLOP )
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_LAST_CHANCE )
-	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_K )
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_RON )
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_G )
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_CHI )
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_C )
-	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_L )
-	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_MAHJONG_H )
+	PORT_INCLUDE( mjctrl )
 
-	PORT_START	// fake, handled by keyboard_r()
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_PON )
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_D )
-	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_START1 )
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_I )
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_KAN )
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_E )
-	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_MAHJONG_M )
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_A )
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_BET )
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_J )
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_REACH )
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_F )
-	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_MAHJONG_N )
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_B )
-	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_COIN1 ) PORT_IMPULSE(1)
-
-	PORT_START	// fake, handled by keyboard_r()
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_SMALL )PORT_PLAYER(2)
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_DOUBLE_UP )PORT_PLAYER(2)
-	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_MAHJONG_BIG )PORT_PLAYER(2)
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_SCORE )PORT_PLAYER(2)
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_FLIP_FLOP )PORT_PLAYER(2)
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_LAST_CHANCE )PORT_PLAYER(2)
-	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_K )PORT_PLAYER(2)
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_RON )PORT_PLAYER(2)
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_G )PORT_PLAYER(2)
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_CHI )PORT_PLAYER(2)
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_C )PORT_PLAYER(2)
-	PORT_BIT( 0x1000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_L )PORT_PLAYER(2)
-	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_MAHJONG_H )PORT_PLAYER(2)
-
-	PORT_START	// fake, handled by keyboard_r()
-	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_MAHJONG_PON )PORT_PLAYER(2)
-	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_MAHJONG_D )PORT_PLAYER(2)
-	PORT_BIT( 0x0004, IP_ACTIVE_HIGH, IPT_START2 )
-	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_MAHJONG_I )PORT_PLAYER(2)
-	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_MAHJONG_KAN )PORT_PLAYER(2)
-	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_MAHJONG_E )PORT_PLAYER(2)
-	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_MAHJONG_M )PORT_PLAYER(2)
-	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_MAHJONG_A )PORT_PLAYER(2)
-	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_MAHJONG_BET )PORT_PLAYER(2)
-	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_MAHJONG_J )PORT_PLAYER(2)
-	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_MAHJONG_REACH )PORT_PLAYER(2)
-	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_MAHJONG_F )PORT_PLAYER(2)
-	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_MAHJONG_N )PORT_PLAYER(2)
-	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_MAHJONG_B )PORT_PLAYER(2)
-	PORT_BIT( 0x4000, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT( 0x8000, IP_ACTIVE_HIGH, IPT_COIN2 ) PORT_IMPULSE(1)
-
-//  PORT_START // 11
+//  PORT_START("EXTRA") // 11
 //  PORT_BIT(    0x01, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("Pay Out") PORT_CODE(KEYCODE_3)
 //  PORT_BIT(     0x02, IP_ACTIVE_LOW, IPT_SERVICE4 ) /* RAM clear */
 //  PORT_SERVICE( 0x04, IP_ACTIVE_LOW )
@@ -485,22 +416,24 @@ static const gfx_layout charlayout =
 };
 
 static GFXDECODE_START( 1 )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, charlayout, 0, 32 )
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout, 0, 32 )
 GFXDECODE_END
 
 static GFXDECODE_START( 2 )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, charlayout, 0, 64 )
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout, 0, 64 )
 GFXDECODE_END
 
 
 
-static const struct AY8910interface ay8910_interface =
+static const ay8910_interface ay8910_config =
 {
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
 	input_port_0_r,
 	input_port_1_r
 };
 
-static const struct MSM5205interface msm5205_interface =
+static const msm5205_interface msm5205_config =
 {
 	0,				/* interrupt function */
 	MSM5205_SEX_4B	/* vclk input mode    */
@@ -511,19 +444,19 @@ static const struct MSM5205interface msm5205_interface =
 static MACHINE_DRIVER_START( rmhaihai )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main",Z80,20000000/4)	/* 5 MHz ??? */
+	MDRV_CPU_ADD("main",Z80,20000000/4)	/* 5 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_IO_MAP(readport,writeport)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_IO_MAP(io_map,0)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(4*8, 60*8-1, 2*8, 30*8-1)
+
 	MDRV_GFXDECODE(1)
 	MDRV_PALETTE_LENGTH(0x100)
 
@@ -534,12 +467,12 @@ static MACHINE_DRIVER_START( rmhaihai )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, 20000000/16)
-	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ADD("ay", AY8910, 20000000/16)
+	MDRV_SOUND_CONFIG(ay8910_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 
-	MDRV_SOUND_ADD(MSM5205, 500000)
-	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ADD("msm", MSM5205, 500000)
+	MDRV_SOUND_CONFIG(msm5205_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -560,7 +493,7 @@ static MACHINE_DRIVER_START( themj )
 
 	MDRV_CPU_MODIFY("main")
 	MDRV_CPU_PROGRAM_MAP(themj_readmem,writemem)
-	MDRV_CPU_IO_MAP(readport,themj_writeport)
+	MDRV_CPU_IO_MAP(themj_io_map,0)
 
 	MDRV_MACHINE_RESET(themj)
 
@@ -578,7 +511,7 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( rmhaihai )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "s3-6.11g",     0x00000, 0x2000, CRC(e7af7ba2) SHA1(1b0f87a16006a96e5b59e055966addac3e2ca926) )
 	ROM_CONTINUE(             0x06000, 0x2000 )
 	ROM_LOAD( "s3-4.8g",      0x04000, 0x2000, CRC(f849e75c) SHA1(4636bcaa7cddb9bc012212098a25f3c57cfc6b51) )
@@ -586,7 +519,7 @@ ROM_START( rmhaihai )
 	ROM_LOAD( "s3-2.6g",      0x08000, 0x2000, CRC(d614532b) SHA1(99911c679ff6f990ae493bfc0b71a2fff0ef1796) )
 	ROM_CONTINUE(             0x0c000, 0x2000 )
 
-	ROM_REGION( 0x20000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x20000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "s0-10.8a",     0x00000, 0x4000, CRC(797c63d1) SHA1(2ff9c3c61b28c34de97c0117b7eadb409d79df46) )
 	ROM_LOAD( "s0-9.7a",      0x04000, 0x4000, CRC(b2526747) SHA1(73d0a19a5bb83e8977e94a47abbb65f9c7788c78) )
 	ROM_LOAD( "s0-8.6a",      0x08000, 0x4000, CRC(146eaa31) SHA1(0e38aab52ff9bf0d42fea24caeee6ca90d63ace2) )
@@ -595,17 +528,17 @@ ROM_START( rmhaihai )
 	ROM_LOAD( "s1-11.10a",    0x14000, 0x4000, CRC(029ef909) SHA1(fd867b8e1ccd5b88f18409ff17939ec8420c6131) )
 	/* 0x18000-0x1ffff empty space filled by the init function */
 
-	ROM_REGION( 0x0300, REGION_PROMS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0300, "proms", ROMREGION_DISPOSE )
 	ROM_LOAD( "s2.13b",       0x0000, 0x0100, CRC(911d32a5) SHA1(36f2b62009918862c13f3eda05a21403b4d9607f) )
 	ROM_LOAD( "s1.13a",       0x0100, 0x0100, CRC(e9be978a) SHA1(50c7ca7a7496cb6fe5e8ce0db693ccb82dbbb8c6) )
 	ROM_LOAD( "s3.13c",       0x0200, 0x0100, CRC(609775a6) SHA1(70a787aec0852e106216a4ca9891d36aef60b189) )
 
-	ROM_REGION( 0x8000, REGION_SOUND1, 0 )	/* ADPCM samples, read directly by the main CPU */
+	ROM_REGION( 0x8000, "adpcm", 0 )	/* ADPCM samples, read directly by the main CPU */
 	ROM_LOAD( "s0-1.5g",      0x00000, 0x8000, CRC(65e55b7e) SHA1(3852fb3b37eccdcddff05d8ef4a742fcb8b63473) )
 ROM_END
 
 ROM_START( rmhaihib )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "s-30-6.11g",   0x00000,  0x2000, CRC(f3e13cc8) SHA1(7eb9b17ea9efb5b2891ec40a9ff9744e84c0511c) )
 	ROM_CONTINUE(             0x06000,  0x2000 )
 	ROM_LOAD( "s-30-4.8g",    0x04000,  0x2000, CRC(f6642584) SHA1(5160baf267fd5dd8385ea5a9ff82e9c220fee342) )
@@ -613,7 +546,7 @@ ROM_START( rmhaihib )
 	ROM_LOAD( "s-30-2.6g",    0x08000,  0x2000, CRC(e5959703) SHA1(15552d90296d0b6790642f554d08e79e827a16ee) )
 	ROM_CONTINUE(             0x0c000,  0x2000 )
 
-	ROM_REGION( 0x20000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x20000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "s0-10.8a",     0x00000, 0x4000, CRC(797c63d1) SHA1(2ff9c3c61b28c34de97c0117b7eadb409d79df46) )
 	ROM_LOAD( "s0-9.7a",      0x04000, 0x4000, CRC(b2526747) SHA1(73d0a19a5bb83e8977e94a47abbb65f9c7788c78) )
 	ROM_LOAD( "s0-8.6a",      0x08000, 0x4000, CRC(146eaa31) SHA1(0e38aab52ff9bf0d42fea24caeee6ca90d63ace2) )
@@ -622,17 +555,17 @@ ROM_START( rmhaihib )
 	ROM_LOAD( "s1-11.10a",    0x14000, 0x4000, CRC(029ef909) SHA1(fd867b8e1ccd5b88f18409ff17939ec8420c6131) )
 	/* 0x18000-0x1ffff empty space filled by the init function */
 
-	ROM_REGION( 0x0300, REGION_PROMS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0300, "proms", ROMREGION_DISPOSE )
 	ROM_LOAD( "s2.13b",       0x0000, 0x0100, CRC(911d32a5) SHA1(36f2b62009918862c13f3eda05a21403b4d9607f) )
 	ROM_LOAD( "s1.13a",       0x0100, 0x0100, CRC(e9be978a) SHA1(50c7ca7a7496cb6fe5e8ce0db693ccb82dbbb8c6) )
 	ROM_LOAD( "s3.13c",       0x0200, 0x0100, CRC(609775a6) SHA1(70a787aec0852e106216a4ca9891d36aef60b189) )
 
-	ROM_REGION( 0x8000, REGION_SOUND1, 0 )	/* ADPCM samples, read directly by the main CPU */
+	ROM_REGION( 0x8000, "adpcm", 0 )	/* ADPCM samples, read directly by the main CPU */
 	ROM_LOAD( "s0-1.5g",      0x00000, 0x8000, CRC(65e55b7e) SHA1(3852fb3b37eccdcddff05d8ef4a742fcb8b63473) )
 ROM_END
 
 ROM_START( rmhaijin )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "s-4-6.11g",    0x00000, 0x2000, CRC(474c9ace) SHA1(9161a5c64054f079d57676f3d7f61ca149018f61) )
 	ROM_CONTINUE(             0x06000, 0x2000 )
 	ROM_LOAD( "s-4-4.8g",     0x04000, 0x2000, CRC(c76ab584) SHA1(7d76fa6166108d6a511d5311c0d34b55364afec1) )
@@ -640,7 +573,7 @@ ROM_START( rmhaijin )
 	ROM_LOAD( "s-4-2.6g",     0x08000, 0x2000, CRC(77b16f5b) SHA1(5e91b6b34ab8196a246c428b98f47a5b167dca76) )
 	ROM_CONTINUE(             0x0c000, 0x2000 )
 
-	ROM_REGION( 0x20000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x20000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "s-1-10.8a",    0x00000, 0x4000, CRC(797c63d1) SHA1(2ff9c3c61b28c34de97c0117b7eadb409d79df46) )
 	ROM_LOAD( "s-1-9.7a",     0x04000, 0x4000, CRC(5d3793d4) SHA1(43665d44ab2db42a28243c269ca451c90fe60abc) )
 	ROM_LOAD( "s-1-8.6a",     0x08000, 0x4000, CRC(6fcd990b) SHA1(c7e35c6d9d75cd743d23a78de5dab63e034e33a8) )
@@ -649,17 +582,17 @@ ROM_START( rmhaijin )
 	ROM_LOAD( "s-2-11.10a",   0x14000, 0x4000, CRC(9ebbc607) SHA1(8ab707f2a197772bae94e9129eb3f40d408c88bf) )
 	/* 0x18000-0x1ffff empty space filled by the init function */
 
-	ROM_REGION( 0x0300, REGION_PROMS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0300, "proms", ROMREGION_DISPOSE )
 	ROM_LOAD( "s5.13b",       0x0000, 0x0100, CRC(153aa7bf) SHA1(945db334e27be431a34670b2d94de639f67038d1) )
 	ROM_LOAD( "s4.13a",       0x0100, 0x0100, CRC(5d643e6e) SHA1(df34be9d4cb0129069c2ed40c916c84674b62bb3) )
 	ROM_LOAD( "s6.13c",       0x0200, 0x0100, CRC(fd6ff344) SHA1(cd00985f8bbff1ab5a149a00320d861ac8655bf8) )
 
-	ROM_REGION( 0x8000, REGION_SOUND1, 0 )	/* ADPCM samples, read directly by the main CPU */
+	ROM_REGION( 0x8000, "adpcm", 0 )	/* ADPCM samples, read directly by the main CPU */
 	ROM_LOAD( "s-0-1.5g",     0x00000, 0x8000, CRC(65e55b7e) SHA1(3852fb3b37eccdcddff05d8ef4a742fcb8b63473) )
 ROM_END
 
 ROM_START( rmhaisei )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "sei-11.h11",   0x00000, 0x2000, CRC(7c35692b) SHA1(8890ca90ae84c63bfd2b4857bbdd02bd9a2f29a9) )
 	ROM_CONTINUE(             0x06000, 0x2000 )
 	ROM_LOAD( "sei-10.h8",    0x04000, 0x2000, CRC(cbd58124) SHA1(562eb13c2dc441294b1b7dafe37ac27a9b7bba2b) )
@@ -668,7 +601,7 @@ ROM_START( rmhaisei )
 	ROM_CONTINUE(             0x0c000, 0x2000 )
 	ROM_LOAD( "sei-9.h7",     0x0e000, 0x2000, CRC(9132368d) SHA1(ca0924399cdd1554fc0407719c74d492743db156) )
 
-	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x40000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "sei-4.a8",     0x00000, 0x8000, CRC(6a0234bf) SHA1(ad6642aa6fca84a22625265a7c82f50e307ba2f9) )
 	ROM_LOAD( "sei-3.a7",     0x08000, 0x8000, CRC(c48bc39f) SHA1(de5aca9f72b437b7e7559bbd4b22c1b3ab70e450) )
 	ROM_LOAD( "sei-2.a6",     0x10000, 0x8000, CRC(e479ba47) SHA1(b2bda054cd70181e223fe33d63924b029d196676) )
@@ -677,17 +610,17 @@ ROM_START( rmhaisei )
 	ROM_LOAD( "sei-5.a9",     0x28000, 0x8000, CRC(8bf780bc) SHA1(5ef72ee3f45f1cdde06131797faf26a9776f6a13) )
 	/* 0x30000-0x3ffff empty space filled by the init function */
 
-	ROM_REGION( 0x0600, REGION_PROMS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0600, "proms", ROMREGION_DISPOSE )
 	ROM_LOAD( "2.bpr",        0x0000, 0x0200, CRC(9ad2afcd) SHA1(6cd4cd5f693ee882a98598e8f86ee2baf3b105bf) )
 	ROM_LOAD( "1.bpr",        0x0200, 0x0200, CRC(9b036f82) SHA1(4b14084e5a6674e69bd4bbc3a483c277bfc73808) )
 	ROM_LOAD( "3.bpr",        0x0400, 0x0200, CRC(0fa1a50a) SHA1(9e8a2c9554a61bfdacb434f8c22c1085b1c93aa1) )
 
-	ROM_REGION( 0x8000, REGION_SOUND1, 0 )	/* ADPCM samples, read directly by the main CPU */
+	ROM_REGION( 0x8000, "adpcm", 0 )	/* ADPCM samples, read directly by the main CPU */
 	ROM_LOAD( "sei-7.h5",     0x00000, 0x8000, CRC(3e412c1a) SHA1(bc5e324ea26b8dd1e37c4e8b0d7ba712c1222bc7) )
 ROM_END
 
 ROM_START( themj )
-	ROM_REGION( 0x20000, REGION_CPU1, 0 ) /* CPU */
+	ROM_REGION( 0x20000, "main", 0 ) /* CPU */
 	ROM_LOAD( "t7.bin",       0x00000,  0x02000, CRC(a58563c3) SHA1(53faeb66606214eb97ef8ff9affe68705e18a0b3) )
 	ROM_CONTINUE(             0x06000,  0x02000 )
 	ROM_LOAD( "t8.bin",       0x04000,  0x02000, CRC(bdf29475) SHA1(6296561da9c3a299d69bba8a98362c40b677ea9a) )
@@ -695,7 +628,7 @@ ROM_START( themj )
 	ROM_LOAD( "t9.bin",       0x0e000,  0x02000, CRC(d5537d03) SHA1(ba27e83fcc9b6962373e2f723fc681481ec76864) )
 	ROM_LOAD( "no1.bin",      0x10000,  0x10000, CRC(a67dd977) SHA1(835648c5df51053c883d90d7309e53232b945ceb) ) /* banked */
 
-	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE ) /* gfx */
+	ROM_REGION( 0x40000, "gfx1", ROMREGION_DISPOSE ) /* gfx */
 	ROM_LOAD( "t3.bin",       0x00000,  0x8000, CRC(f0735c62) SHA1(5ff0da7fc72512797ec59ee57467fa81abcfdb8b) )
 	ROM_LOAD( "t4.bin",       0x08000,  0x8000, CRC(952227fa) SHA1(7c2b5fe18bbaa482d93ab99a8f886838b596df8d) )
 	ROM_LOAD( "t5.bin",       0x10000,  0x8000, CRC(3deea9b4) SHA1(e445b545a8d293f6a5724e6c484cb1062c631bcc) )
@@ -704,20 +637,20 @@ ROM_START( themj )
 	ROM_LOAD( "t2.bin",       0x28000,  0x8000, CRC(4702375f) SHA1(9e824007e3e26ad6fb2ccbbcf35aa7cfdf5c469e) )
 	/* 0x30000-0x3ffff empty space filled by the init function */
 
-	ROM_REGION( 0x0600, REGION_PROMS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0600, "proms", ROMREGION_DISPOSE )
 	ROM_LOAD( "5.bin",        0x0000,  0x0200, CRC(062fb055) SHA1(20a6d236e3ab1df8c471cccca31ec05442595c82) )
 	ROM_LOAD( "4.bin",        0x0200,  0x0200, CRC(9f81a6d7) SHA1(2735815c0c922d0c81559d792fcaa39bd9615536) )
 	ROM_LOAD( "6.bin",        0x0400,  0x0200, CRC(61373ec7) SHA1(73861914aae29e3996f9991f324c358a29c46969) )
 
-	ROM_REGION( 0x8000, REGION_SOUND1, 0 )	/* ADPCM samples, read directly by the main CPU */
+	ROM_REGION( 0x8000, "adpcm", 0 )	/* ADPCM samples, read directly by the main CPU */
 	ROM_LOAD( "t0.bin",       0x00000,  0x8000, CRC(3e412c1a) SHA1(bc5e324ea26b8dd1e37c4e8b0d7ba712c1222bc7) )
 ROM_END
 
 
 static DRIVER_INIT( rmhaihai )
 {
-	UINT8 *rom = memory_region(REGION_GFX1);
-	int size = memory_region_length(REGION_GFX1);
+	UINT8 *rom = memory_region(machine, "gfx1");
+	int size = memory_region_length(machine, "gfx1");
 	int a,b;
 
 	size /= 2;
