@@ -36,7 +36,6 @@
 */
 
 #include "driver.h"
-#include "deprecat.h"
 
 #include "video/konamiic.h"
 #include "cpu/m68000/m68000.h"
@@ -58,7 +57,7 @@ static int init_eeprom_count;
 static int rng_z80_control;
 static int rng_sound_status;
 
-static const struct EEPROM_interface eeprom_interface =
+static const eeprom_interface eeprom_intf =
 {
 	7,			/* address bits */
 	8,			/* data bits */
@@ -72,15 +71,15 @@ static const struct EEPROM_interface eeprom_interface =
 static NVRAM_HANDLER( rungun )
 {
 	if (read_or_write)
-		EEPROM_save(file);
+		eeprom_save(file);
 	else
 	{
-		EEPROM_init(&eeprom_interface);
+		eeprom_init(machine, &eeprom_intf);
 
 		if (file)
 		{
 			init_eeprom_count = 0;
-			EEPROM_load(file);
+			eeprom_load(file);
 		}
 		else
 			init_eeprom_count = 10;
@@ -94,21 +93,21 @@ static READ16_HANDLER( rng_sysregs_r )
 	switch (offset)
 	{
 		case 0x00/2:
-			if (readinputport(1) & 0x20)
-				return(readinputport(2) | readinputport(4)<<8);
+			if (input_port_read(space->machine, "DSW") & 0x20)
+				return(input_port_read(space->machine, "P1") | input_port_read(space->machine, "P3")<<8);
 			else
 			{
-				data = readinputport(2) & readinputport(4);
+				data = input_port_read(space->machine, "P1") & input_port_read(space->machine, "P3");
 				return(data<<8 | data);
 			}
 		break;
 
 		case 0x02/2:
-			if (readinputport(1) & 0x20)
-				return(readinputport(3) | readinputport(5)<<8);
+			if (input_port_read(space->machine, "DSW") & 0x20)
+				return(input_port_read(space->machine, "P2") | input_port_read(space->machine, "P4")<<8);
 			else
 			{
-				data = readinputport(3) & readinputport(5);
+				data = input_port_read(space->machine, "P2") & input_port_read(space->machine, "P4");
 				return(data<<8 | data);
 			}
 		break;
@@ -119,13 +118,13 @@ static READ16_HANDLER( rng_sysregs_r )
                 bit8 : freeze
                 bit9 : joysticks layout(auto detect???)
             */
-			return(input_port_0_word_r(0, 0));
+			return input_port_read(space->machine, "SYSTEM");
 		break;
 
 		case 0x06/2:
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 			{
-				data = readinputport(1) | EEPROM_read_bit();
+				data = input_port_read(space->machine, "DSW");
 
 				if (init_eeprom_count)
 				{
@@ -148,22 +147,22 @@ static WRITE16_HANDLER( rng_sysregs_w )
 	{
 		case 0x08/2:
 			/*
-                bit0  : EEPROM_write_bit
-                bit1  : EEPROM_set_cs_line
-                bit2  : EEPROM_set_clock_line
+                bit0  : eeprom_write_bit
+                bit1  : eeprom_set_cs_line
+                bit2  : eeprom_set_clock_line
                 bit3  : coin counter?
                 bit7  : set before massive memory writes
                 bit10 : IRQ5 ACK
             */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 			{
-				EEPROM_write_bit((data & 0x01) ? 1 : 0);
-				EEPROM_set_cs_line((data & 0x02) ? CLEAR_LINE : ASSERT_LINE);
-				EEPROM_set_clock_line((data & 0x04) ? ASSERT_LINE : CLEAR_LINE);
+				eeprom_write_bit((data & 0x01) ? 1 : 0);
+				eeprom_set_cs_line((data & 0x02) ? CLEAR_LINE : ASSERT_LINE);
+				eeprom_set_clock_line((data & 0x04) ? ASSERT_LINE : CLEAR_LINE);
 			}
 
 			if (!(data & 0x40))
-				cpunum_set_input_line(Machine, 0, MC68000_IRQ_5, CLEAR_LINE);
+				cpu_set_input_line(space->machine->cpu[0], M68K_IRQ_5, CLEAR_LINE);
 		break;
 
 		case 0x0c/2:
@@ -180,25 +179,25 @@ static WRITE16_HANDLER( rng_sysregs_w )
 
 static WRITE16_HANDLER( sound_cmd1_w )
 {
-	if (ACCESSING_MSB)
-		soundlatch_w(0, data>>8);
+	if (ACCESSING_BITS_8_15)
+		soundlatch_w(space, 0, data>>8);
 }
 
 static WRITE16_HANDLER( sound_cmd2_w )
 {
-	if (ACCESSING_MSB)
-		soundlatch2_w(0, data>>8);
+	if (ACCESSING_BITS_8_15)
+		soundlatch2_w(space, 0, data>>8);
 }
 
 static WRITE16_HANDLER( sound_irq_w )
 {
-	if (ACCESSING_MSB)
-		cpunum_set_input_line(Machine, 1, 0, HOLD_LINE);
+	if (ACCESSING_BITS_8_15)
+		cpu_set_input_line(space->machine->cpu[1], 0, HOLD_LINE);
 }
 
 static READ16_HANDLER( sound_status_msb_r )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 		return(rng_sound_status<<8);
 
 	return(0);
@@ -207,23 +206,23 @@ static READ16_HANDLER( sound_status_msb_r )
 static INTERRUPT_GEN(rng_interrupt)
 {
 	if (rng_sysreg[0x0c/2] & 0x09)
-		cpunum_set_input_line(machine, 0, MC68000_IRQ_5, ASSERT_LINE);
+		cpu_set_input_line(device, M68K_IRQ_5, ASSERT_LINE);
 }
 
 static ADDRESS_MAP_START( rngreadmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x2fffff) AM_READ(MRA16_ROM)		// main program + data
-	AM_RANGE(0x300000, 0x3007ff) AM_READ(MRA16_RAM)		// palette RAM
-	AM_RANGE(0x380000, 0x39ffff) AM_READ(MRA16_RAM)		// work RAM
-	AM_RANGE(0x400000, 0x43ffff) AM_READ(MRA16_NOP)		// K053936_0_rom_r }, // '936 ROM readback window
+	AM_RANGE(0x000000, 0x2fffff) AM_READ(SMH_ROM)		// main program + data
+	AM_RANGE(0x300000, 0x3007ff) AM_READ(SMH_RAM)		// palette RAM
+	AM_RANGE(0x380000, 0x39ffff) AM_READ(SMH_RAM)		// work RAM
+	AM_RANGE(0x400000, 0x43ffff) AM_READ(SMH_NOP)		// K053936_0_rom_r }, // '936 ROM readback window
 	AM_RANGE(0x480000, 0x48001f) AM_READ(rng_sysregs_r)
 	AM_RANGE(0x4c0000, 0x4c001f) AM_READ(K053252_word_r)	// CCU (for scanline and vblank polling)
 	AM_RANGE(0x580014, 0x580015) AM_READ(sound_status_msb_r)
-	AM_RANGE(0x580000, 0x58001f) AM_READ(MRA16_RAM)		// sound regs read fall-through
+	AM_RANGE(0x580000, 0x58001f) AM_READ(SMH_RAM)		// sound regs read fall-through
 	AM_RANGE(0x5c0000, 0x5c000d) AM_READ(K053246_word_r)	// 246A ROM readback window
 	AM_RANGE(0x600000, 0x600fff) AM_READ(K053247_word_r)	// OBJ RAM
-	AM_RANGE(0x601000, 0x601fff) AM_READ(MRA16_RAM)		// communication? second monitor buffer?
-	AM_RANGE(0x6c0000, 0x6cffff) AM_READ(MRA16_RAM)		// PSAC2 render RAM
-	AM_RANGE(0x700000, 0x7007ff) AM_READ(MRA16_RAM)		// PSAC2 line effect
+	AM_RANGE(0x601000, 0x601fff) AM_READ(SMH_RAM)		// communication? second monitor buffer?
+	AM_RANGE(0x6c0000, 0x6cffff) AM_READ(SMH_RAM)		// PSAC2 render RAM
+	AM_RANGE(0x700000, 0x7007ff) AM_READ(SMH_RAM)		// PSAC2 line effect
 	AM_RANGE(0x740000, 0x741fff) AM_READ(rng_ttl_ram_r)		// text plane RAM
 #if RNG_DEBUG
 	AM_RANGE(0x5c0010, 0x5c001f) AM_READ(K053247_reg_word_r)
@@ -232,24 +231,24 @@ static ADDRESS_MAP_START( rngreadmem, ADDRESS_SPACE_PROGRAM, 16 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( rngwritemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x2fffff) AM_WRITE(MWA16_ROM)
+	AM_RANGE(0x000000, 0x2fffff) AM_WRITE(SMH_ROM)
 	AM_RANGE(0x300000, 0x3007ff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)
-	AM_RANGE(0x380000, 0x39ffff) AM_WRITE(MWA16_RAM)		// work RAM
+	AM_RANGE(0x380000, 0x39ffff) AM_WRITE(SMH_RAM)		// work RAM
 	AM_RANGE(0x480000, 0x48001f) AM_WRITE(rng_sysregs_w) AM_BASE(&rng_sysreg)
 	AM_RANGE(0x4c0000, 0x4c001f) AM_WRITE(K053252_word_w)	// CCU
 	AM_RANGE(0x540000, 0x540001) AM_WRITE(sound_irq_w)
 	AM_RANGE(0x58000c, 0x58000d) AM_WRITE(sound_cmd1_w)
 	AM_RANGE(0x58000e, 0x58000f) AM_WRITE(sound_cmd2_w)
-	AM_RANGE(0x580000, 0x58001f) AM_WRITE(MWA16_RAM)		// sound regs write fall-through
+	AM_RANGE(0x580000, 0x58001f) AM_WRITE(SMH_RAM)		// sound regs write fall-through
 	AM_RANGE(0x5c0010, 0x5c001f) AM_WRITE(K053247_reg_word_w)
 	AM_RANGE(0x600000, 0x600fff) AM_WRITE(K053247_word_w)	// OBJ RAM
-	AM_RANGE(0x601000, 0x601fff) AM_WRITE(MWA16_RAM)		// communication? second monitor buffer?
+	AM_RANGE(0x601000, 0x601fff) AM_WRITE(SMH_RAM)		// communication? second monitor buffer?
 	AM_RANGE(0x640000, 0x640007) AM_WRITE(K053246_word_w)	// '246A registers
-	AM_RANGE(0x680000, 0x68001f) AM_WRITE(MWA16_RAM) AM_BASE(&K053936_0_ctrl)				// '936 registers
+	AM_RANGE(0x680000, 0x68001f) AM_WRITE(SMH_RAM) AM_BASE(&K053936_0_ctrl)				// '936 registers
 	AM_RANGE(0x6c0000, 0x6cffff) AM_WRITE(rng_936_videoram_w) AM_BASE(&rng_936_videoram)	// PSAC2 ('936) RAM (34v + 35v)
-	AM_RANGE(0x700000, 0x7007ff) AM_WRITE(MWA16_RAM) AM_BASE(&K053936_0_linectrl)			// "Line RAM"
+	AM_RANGE(0x700000, 0x7007ff) AM_WRITE(SMH_RAM) AM_BASE(&K053936_0_linectrl)			// "Line RAM"
 	AM_RANGE(0x740000, 0x741fff) AM_WRITE(rng_ttl_ram_w)		// text plane RAM
-	AM_RANGE(0x7c0000, 0x7c0001) AM_WRITE(MWA16_NOP)		// watchdog
+	AM_RANGE(0x7c0000, 0x7c0001) AM_WRITE(SMH_NOP)		// watchdog
 ADDRESS_MAP_END
 
 /**********************************************************************************/
@@ -263,48 +262,48 @@ static WRITE8_HANDLER( z80ctrl_w )
 {
 	rng_z80_control = data;
 
-	memory_set_bankptr(2, memory_region(REGION_CPU2) + 0x10000 + (data & 0x07) * 0x4000);
+	memory_set_bankptr(space->machine, 2, memory_region(space->machine, "sound") + 0x10000 + (data & 0x07) * 0x4000);
 
 	if (data & 0x10)
-		cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, CLEAR_LINE);
+		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_NMI, CLEAR_LINE);
 }
 
 static INTERRUPT_GEN(audio_interrupt)
 {
 	if (rng_z80_control & 0x80) return;
 
-	cpunum_set_input_line(machine, 1, INPUT_LINE_NMI, ASSERT_LINE);
+	cpu_set_input_line(device, INPUT_LINE_NMI, ASSERT_LINE);
 }
 
 /* sound (this should be split into audio/xexex.c or pregx.c or so someday) */
 
 static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(MRA8_BANK2)
-	AM_RANGE(0xc000, 0xdfff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xe000, 0xe22f) AM_READ(K054539_0_r)
-	AM_RANGE(0xe230, 0xe3ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xe400, 0xe62f) AM_READ(K054539_1_r)
-	AM_RANGE(0xe630, 0xe7ff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_BANK2)
+	AM_RANGE(0xc000, 0xdfff) AM_READ(SMH_RAM)
+	AM_RANGE(0xe000, 0xe22f) AM_READ(k054539_0_r)
+	AM_RANGE(0xe230, 0xe3ff) AM_READ(SMH_RAM)
+	AM_RANGE(0xe400, 0xe62f) AM_READ(k054539_1_r)
+	AM_RANGE(0xe630, 0xe7ff) AM_READ(SMH_RAM)
 	AM_RANGE(0xf002, 0xf002) AM_READ(soundlatch_r)
 	AM_RANGE(0xf003, 0xf003) AM_READ(soundlatch2_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xc000, 0xdfff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xe000, 0xe22f) AM_WRITE(K054539_0_w)
-	AM_RANGE(0xe230, 0xe3ff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xe400, 0xe62f) AM_WRITE(K054539_1_w)
-	AM_RANGE(0xe630, 0xe7ff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x0000, 0xbfff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0xc000, 0xdfff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0xe000, 0xe22f) AM_WRITE(k054539_0_w)
+	AM_RANGE(0xe230, 0xe3ff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0xe400, 0xe62f) AM_WRITE(k054539_1_w)
+	AM_RANGE(0xe630, 0xe7ff) AM_WRITE(SMH_RAM)
 	AM_RANGE(0xf000, 0xf000) AM_WRITE(sound_status_w)
 	AM_RANGE(0xf800, 0xf800) AM_WRITE(z80ctrl_w)
-	AM_RANGE(0xfff0, 0xfff3) AM_WRITE(MWA8_NOP)
+	AM_RANGE(0xfff0, 0xfff3) AM_WRITE(SMH_NOP)
 ADDRESS_MAP_END
 
-static const struct K054539interface k054539_interface =
+static const k054539_interface k054539_config =
 {
-	REGION_SOUND1
+	"shared"
 };
 
 /**********************************************************************************/
@@ -323,24 +322,21 @@ static const gfx_layout bglayout =
 };
 
 static GFXDECODE_START( rungun )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, bglayout, 0x0000, 64 )
+	GFXDECODE_ENTRY( "gfx1", 0, bglayout, 0x0000, 64 )
 GFXDECODE_END
 
 static MACHINE_DRIVER_START( rng )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", M68000, 16000000)
+	MDRV_CPU_ADD("main", M68000, 16000000)
 	MDRV_CPU_PROGRAM_MAP(rngreadmem,rngwritemem)
-	MDRV_CPU_VBLANK_INT(rng_interrupt,1)
+	MDRV_CPU_VBLANK_INT("main", rng_interrupt)
 
-	MDRV_CPU_ADD_TAG("sound", Z80, 10000000) // 8Mhz (10Mhz is much safer in self-test due to heavy sync)
-	/* audio CPU */
+	MDRV_CPU_ADD("sound", Z80, 10000000) // 8Mhz (10Mhz is much safer in self-test due to heavy sync)
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 	MDRV_CPU_PERIODIC_INT(audio_interrupt, 480)
 
-	MDRV_INTERLEAVE(100) // higher if sound stutters
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_QUANTUM_TIME(HZ(6000)) // higher if sound stutters
 
 	MDRV_GFXDECODE(rungun)
 
@@ -348,10 +344,15 @@ static MACHINE_DRIVER_START( rng )
 	MDRV_NVRAM_HANDLER(rungun)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS | VIDEO_HAS_HIGHLIGHTS | VIDEO_UPDATE_BEFORE_VBLANK)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS | VIDEO_HAS_HIGHLIGHTS | VIDEO_UPDATE_BEFORE_VBLANK)
+
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(88, 88+384-1, 24, 24+224-1)
+
 	MDRV_PALETTE_LENGTH(1024)
 
 	MDRV_VIDEO_START(rng)
@@ -360,19 +361,19 @@ static MACHINE_DRIVER_START( rng )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(K054539, 48000)
-	MDRV_SOUND_CONFIG(k054539_interface)
+	MDRV_SOUND_ADD("konami1", K054539, 48000)
+	MDRV_SOUND_CONFIG(k054539_config)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 
-	MDRV_SOUND_ADD(K054539, 48000)
-	MDRV_SOUND_CONFIG(k054539_interface)
+	MDRV_SOUND_ADD("konami2", K054539, 48000)
+	MDRV_SOUND_CONFIG(k054539_config)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 static INPUT_PORTS_START( rng )
-	PORT_START
+	PORT_START("SYSTEM")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 )
@@ -388,10 +389,10 @@ static INPUT_PORTS_START( rng )
 	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
-	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SPECIAL )	/* EEPROM data */
+	PORT_START("DSW")
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(eeprom_bit_r, NULL)	/* EEPROM data */
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SPECIAL )	/* EEPROM ready (always 1) */
-	PORT_BIT(0x08, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2)
+	PORT_SERVICE_NO_TOGGLE( 0x08, IP_ACTIVE_LOW )
 	PORT_DIPNAME( 0x10, 0x00, "Monitors" )
 	PORT_DIPSETTING(    0x00, "1" )
 	PORT_DIPSETTING(    0x10, "2" )
@@ -408,7 +409,7 @@ static INPUT_PORTS_START( rng )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("P1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
@@ -418,7 +419,7 @@ static INPUT_PORTS_START( rng )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START1 )
 
-	PORT_START
+	PORT_START("P2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
@@ -428,7 +429,7 @@ static INPUT_PORTS_START( rng )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START
+	PORT_START("P3")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(3)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(3)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(3)
@@ -438,7 +439,7 @@ static INPUT_PORTS_START( rng )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(3)
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START3 )
 
-	PORT_START
+	PORT_START("P4")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(4)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(4)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(4)
@@ -453,7 +454,7 @@ INPUT_PORTS_END
 
 ROM_START( rungun )
 	/* main program Europe Version AA  1993, 10.8 */
-	ROM_REGION( 0x300000, REGION_CPU1, 0)
+	ROM_REGION( 0x300000, "main", 0)
 	ROM_LOAD16_BYTE( "247eaa03.bin", 0x000000, 0x80000, CRC(f5c91ec0) SHA1(298926ea30472fa8d2c0578dfeaf9a93509747ef) )
 	ROM_LOAD16_BYTE( "247eaa04.bin", 0x000001, 0x80000, CRC(0e62471f) SHA1(2861b7a4e78ff371358d318a1b13a6488c0ac364) )
 
@@ -464,34 +465,34 @@ ROM_START( rungun )
 	ROM_CONTINUE(                  0x100001, 0x80000)
 
 	/* sound program */
-	ROM_REGION( 0x030000, REGION_CPU2, 0 )
+	ROM_REGION( 0x030000, "sound", 0 )
 	ROM_LOAD("247a05",  0x000000, 0x20000, CRC(64e85430) SHA1(542919c3be257c8f118fc21d3835d7b6426a22ed) )
 	ROM_RELOAD(         0x010000, 0x20000 )
 
 	/* '936 tiles */
-	ROM_REGION( 0x400000, REGION_GFX1, 0)
+	ROM_REGION( 0x400000, "gfx1", 0)
 	ROM_LOAD( "247-a13", 0x000000, 0x200000, CRC(cc194089) SHA1(b5af94f5f583d282ac1499b371bbaac8b2fedc03) )
 
 	/* sprites */
-	ROM_REGION( 0x800000, REGION_GFX2, 0)
+	ROM_REGION( 0x800000, "gfx2", 0)
 	ROM_LOAD64_WORD( "247-a11", 0x000000, 0x200000, CRC(c3f60854) SHA1(cbee7178ab9e5aa6a5aeed0511e370e29001fb01) )	// 5y
 	ROM_LOAD64_WORD( "247-a08", 0x000002, 0x200000, CRC(3e315eef) SHA1(898bc4d5ad244e5f91cbc87820b5d0be99ef6662) )	// 2u
 	ROM_LOAD64_WORD( "247-a09", 0x000004, 0x200000, CRC(5ca7bc06) SHA1(83c793c68227399f93bd1ed167dc9ed2aaac4167) )	// 2y
 	ROM_LOAD64_WORD( "247-a10", 0x000006, 0x200000, CRC(a5ccd243) SHA1(860b88ade1a69f8b6c5b8206424814b386343571) )	// 5u
 
 	/* TTL text plane ("fix layer") */
-	ROM_REGION( 0x20000, REGION_GFX3, 0)
+	ROM_REGION( 0x20000, "gfx3", 0)
 	ROM_LOAD( "247-a12", 0x000000, 0x20000, CRC(57a8d26e) SHA1(0431d10b76d77c26a1f6f2b55d9dbcfa959e1cd0) )
 
 	/* sound data */
-	ROM_REGION( 0x400000, REGION_SOUND1, 0)
+	ROM_REGION( 0x400000, "shared", 0)
 	ROM_LOAD( "247-a06", 0x000000, 0x200000, CRC(b8b2a67e) SHA1(a873d32f4b178c714743664fa53c0dca29cb3ce4) )
 	ROM_LOAD( "247-a07", 0x200000, 0x200000, CRC(0108142d) SHA1(4dc6a36d976dad9c0da5a5b1f01f2eb3b369c99d) )
 ROM_END
 
 ROM_START( runguna )
 	/* main program Europe Version AA 1993, 10.4 */
-	ROM_REGION( 0x300000, REGION_CPU1, 0)
+	ROM_REGION( 0x300000, "main", 0)
 	ROM_LOAD16_BYTE( "247eaa03.rom", 0x000000, 0x80000, CRC(fec3e1d6) SHA1(cd89dc32ad06308134d277f343a7e8b5fe381f69) )
 	ROM_LOAD16_BYTE( "247eaa04.rom", 0x000001, 0x80000, CRC(1b556af9) SHA1(c8351ebd595307d561d089c66cd6ed7f6111d996) )
 
@@ -502,34 +503,34 @@ ROM_START( runguna )
 	ROM_CONTINUE(                  0x100001, 0x80000)
 
 	/* sound program */
-	ROM_REGION( 0x030000, REGION_CPU2, 0 )
+	ROM_REGION( 0x030000, "sound", 0 )
 	ROM_LOAD("1.13g",  0x000000, 0x20000, CRC(c0b35df9) SHA1(a0c73d993eb32bd0cd192351b5f86794efd91949) )
 	ROM_RELOAD(         0x010000, 0x20000 )
 
 	/* '936 tiles */
-	ROM_REGION( 0x400000, REGION_GFX1, 0)
+	ROM_REGION( 0x400000, "gfx1", 0)
 	ROM_LOAD( "247-a13", 0x000000, 0x200000, CRC(cc194089) SHA1(b5af94f5f583d282ac1499b371bbaac8b2fedc03) )
 
 	/* sprites */
-	ROM_REGION( 0x800000, REGION_GFX2, 0)
+	ROM_REGION( 0x800000, "gfx2", 0)
 	ROM_LOAD64_WORD( "247-a11", 0x000000, 0x200000, CRC(c3f60854) SHA1(cbee7178ab9e5aa6a5aeed0511e370e29001fb01) )	// 5y
 	ROM_LOAD64_WORD( "247-a08", 0x000002, 0x200000, CRC(3e315eef) SHA1(898bc4d5ad244e5f91cbc87820b5d0be99ef6662) )	// 2u
 	ROM_LOAD64_WORD( "247-a09", 0x000004, 0x200000, CRC(5ca7bc06) SHA1(83c793c68227399f93bd1ed167dc9ed2aaac4167) )	// 2y
 	ROM_LOAD64_WORD( "247-a10", 0x000006, 0x200000, CRC(a5ccd243) SHA1(860b88ade1a69f8b6c5b8206424814b386343571) )	// 5u
 
 	/* TTL text plane ("fix layer") */
-	ROM_REGION( 0x20000, REGION_GFX3, 0)
+	ROM_REGION( 0x20000, "gfx3", 0)
 	ROM_LOAD( "247-a12", 0x000000, 0x20000, CRC(57a8d26e) SHA1(0431d10b76d77c26a1f6f2b55d9dbcfa959e1cd0) )
 
 	/* sound data */
-	ROM_REGION( 0x400000, REGION_SOUND1, 0)
+	ROM_REGION( 0x400000, "shared", 0)
 	ROM_LOAD( "247-a06", 0x000000, 0x200000, CRC(b8b2a67e) SHA1(a873d32f4b178c714743664fa53c0dca29cb3ce4) )
 	ROM_LOAD( "247-a07", 0x200000, 0x200000, CRC(0108142d) SHA1(4dc6a36d976dad9c0da5a5b1f01f2eb3b369c99d) )
 ROM_END
 
 ROM_START( rungunu )
 	/* main program US Version AB 1993 10.12 */
-	ROM_REGION( 0x300000, REGION_CPU1, 0)
+	ROM_REGION( 0x300000, "main", 0)
 	ROM_LOAD16_BYTE( "247uab03.bin", 0x000000, 0x80000, CRC(f259fd11) SHA1(60381a3fa7f78022dcb3e2f3d13ea32a10e4e36e) )
 	ROM_LOAD16_BYTE( "247uab04.bin", 0x000001, 0x80000, CRC(b918cf5a) SHA1(4314c611ef600ec081f409c78218de1639f8b463) )
 
@@ -538,34 +539,34 @@ ROM_START( rungunu )
 	ROM_LOAD16_BYTE( "247a02", 0x100001, 0x80000, CRC(f5ef3f45) SHA1(2e1d8f672c130dbfac4365dc1301b47beee10161) )
 
 	/* sound program */
-	ROM_REGION( 0x030000, REGION_CPU2, 0 )
+	ROM_REGION( 0x030000, "sound", 0 )
 	ROM_LOAD("247a05", 0x000000, 0x20000, CRC(64e85430) SHA1(542919c3be257c8f118fc21d3835d7b6426a22ed) )
 	ROM_RELOAD(        0x010000, 0x20000 )
 
 	/* '936 tiles */
-	ROM_REGION( 0x400000, REGION_GFX1, 0)
+	ROM_REGION( 0x400000, "gfx1", 0)
 	ROM_LOAD( "247a13", 0x000000, 0x200000, CRC(c5a8ef29) SHA1(23938b8093bc0b9eef91f6d38127ca7acbdc06a6) )
 
 	/* sprites */
-	ROM_REGION( 0x800000, REGION_GFX2, 0)
+	ROM_REGION( 0x800000, "gfx2", 0)
 	ROM_LOAD64_WORD( "247-a11", 0x000000, 0x200000, CRC(c3f60854) SHA1(cbee7178ab9e5aa6a5aeed0511e370e29001fb01) )	// 5y
 	ROM_LOAD64_WORD( "247-a08", 0x000002, 0x200000, CRC(3e315eef) SHA1(898bc4d5ad244e5f91cbc87820b5d0be99ef6662) )	// 2u
 	ROM_LOAD64_WORD( "247-a09", 0x000004, 0x200000, CRC(5ca7bc06) SHA1(83c793c68227399f93bd1ed167dc9ed2aaac4167) )	// 2y
 	ROM_LOAD64_WORD( "247-a10", 0x000006, 0x200000, CRC(a5ccd243) SHA1(860b88ade1a69f8b6c5b8206424814b386343571) )	// 5u
 
 	/* TTL text plane ("fix layer") */
-	ROM_REGION( 0x20000, REGION_GFX3, 0)
+	ROM_REGION( 0x20000, "gfx3", 0)
 	ROM_LOAD( "247-a12", 0x000000, 0x20000, CRC(57a8d26e) SHA1(0431d10b76d77c26a1f6f2b55d9dbcfa959e1cd0) )
 
 	/* sound data */
-	ROM_REGION( 0x400000, REGION_SOUND1, 0)
+	ROM_REGION( 0x400000, "shared", 0)
 	ROM_LOAD( "247-a06", 0x000000, 0x200000, CRC(b8b2a67e) SHA1(a873d32f4b178c714743664fa53c0dca29cb3ce4) )
 	ROM_LOAD( "247-a07", 0x200000, 0x200000, CRC(0108142d) SHA1(4dc6a36d976dad9c0da5a5b1f01f2eb3b369c99d) )
 ROM_END
 
 ROM_START( rungunua )
 	/* main program US Version BA 1993 10.8 */
-	ROM_REGION( 0x300000, REGION_CPU1, 0)
+	ROM_REGION( 0x300000, "main", 0)
 	ROM_LOAD16_BYTE( "247uba03.bin", 0x000000, 0x80000, CRC(c24d7500) SHA1(38e6ae9fc00bf8f85549be4733992336c46fe1f3) )
 	ROM_LOAD16_BYTE( "247uba04.bin", 0x000001, 0x80000, CRC(3f255a4a) SHA1(3a4d50ecec8546933ad8dabe21682ba0951eaad0) )
 
@@ -576,34 +577,34 @@ ROM_START( rungunua )
 	ROM_CONTINUE(                  0x100001, 0x80000)
 
 	/* sound program */
-	ROM_REGION( 0x030000, REGION_CPU2, 0 )
+	ROM_REGION( 0x030000, "sound", 0 )
 	ROM_LOAD("247a05", 0x000000, 0x20000, CRC(64e85430) SHA1(542919c3be257c8f118fc21d3835d7b6426a22ed) )
 	ROM_RELOAD(        0x010000, 0x20000 )
 
 	/* '936 tiles */
-	ROM_REGION( 0x400000, REGION_GFX1, 0)
+	ROM_REGION( 0x400000, "gfx1", 0)
 	ROM_LOAD( "247a13", 0x000000, 0x200000, CRC(c5a8ef29) SHA1(23938b8093bc0b9eef91f6d38127ca7acbdc06a6) )
 
 	/* sprites */
-	ROM_REGION( 0x800000, REGION_GFX2, 0)
+	ROM_REGION( 0x800000, "gfx2", 0)
 	ROM_LOAD64_WORD( "247-a11", 0x000000, 0x200000, CRC(c3f60854) SHA1(cbee7178ab9e5aa6a5aeed0511e370e29001fb01) )	// 5y
 	ROM_LOAD64_WORD( "247-a08", 0x000002, 0x200000, CRC(3e315eef) SHA1(898bc4d5ad244e5f91cbc87820b5d0be99ef6662) )	// 2u
 	ROM_LOAD64_WORD( "247-a09", 0x000004, 0x200000, CRC(5ca7bc06) SHA1(83c793c68227399f93bd1ed167dc9ed2aaac4167) )	// 2y
 	ROM_LOAD64_WORD( "247-a10", 0x000006, 0x200000, CRC(a5ccd243) SHA1(860b88ade1a69f8b6c5b8206424814b386343571) )	// 5u
 
 	/* TTL text plane ("fix layer") */
-	ROM_REGION( 0x20000, REGION_GFX3, 0)
+	ROM_REGION( 0x20000, "gfx3", 0)
 	ROM_LOAD( "247-a12", 0x000000, 0x20000, CRC(57a8d26e) SHA1(0431d10b76d77c26a1f6f2b55d9dbcfa959e1cd0) )
 
 	/* sound data */
-	ROM_REGION( 0x400000, REGION_SOUND1, 0)
+	ROM_REGION( 0x400000, "shared", 0)
 	ROM_LOAD( "247-a06", 0x000000, 0x200000, CRC(b8b2a67e) SHA1(a873d32f4b178c714743664fa53c0dca29cb3ce4) )
 	ROM_LOAD( "247-a07", 0x200000, 0x200000, CRC(0108142d) SHA1(4dc6a36d976dad9c0da5a5b1f01f2eb3b369c99d) )
 ROM_END
 
 ROM_START( slmdunkj )
 	/* main program Japan Version AA 1993 10.8 */
-	ROM_REGION( 0x300000, REGION_CPU1, 0)
+	ROM_REGION( 0x300000, "main", 0)
 	ROM_LOAD16_BYTE( "247jaa03.bin", 0x000000, 0x20000, CRC(87572078) SHA1(cfa784eb40ed8b3bda9d57abb6022bbe92056206) )
 	ROM_LOAD16_BYTE( "247jaa04.bin", 0x000001, 0x20000, CRC(aa105e00) SHA1(617ac14535048b6e0da43cc98c4b67c8e306bef1) )
 
@@ -614,27 +615,27 @@ ROM_START( slmdunkj )
 	ROM_CONTINUE(                  0x100001, 0x80000)
 
 	/* sound program */
-	ROM_REGION( 0x030000, REGION_CPU2, 0 )
+	ROM_REGION( 0x030000, "sound", 0 )
 	ROM_LOAD("247a05",  0x000000, 0x20000, CRC(64e85430) SHA1(542919c3be257c8f118fc21d3835d7b6426a22ed) )
 	ROM_RELOAD(         0x010000, 0x20000 )
 
 	/* '936 tiles */
-	ROM_REGION( 0x400000, REGION_GFX1, 0)
+	ROM_REGION( 0x400000, "gfx1", 0)
 	ROM_LOAD( "247-a13", 0x000000, 0x200000, CRC(cc194089) SHA1(b5af94f5f583d282ac1499b371bbaac8b2fedc03) )
 
 	/* sprites */
-	ROM_REGION( 0x800000, REGION_GFX2, 0)
+	ROM_REGION( 0x800000, "gfx2", 0)
 	ROM_LOAD64_WORD( "247-a11", 0x000000, 0x200000, CRC(c3f60854) SHA1(cbee7178ab9e5aa6a5aeed0511e370e29001fb01) )	// 5y
 	ROM_LOAD64_WORD( "247-a08", 0x000002, 0x200000, CRC(3e315eef) SHA1(898bc4d5ad244e5f91cbc87820b5d0be99ef6662) )	// 2u
 	ROM_LOAD64_WORD( "247-a09", 0x000004, 0x200000, CRC(5ca7bc06) SHA1(83c793c68227399f93bd1ed167dc9ed2aaac4167) )	// 2y
 	ROM_LOAD64_WORD( "247-a10", 0x000006, 0x200000, CRC(a5ccd243) SHA1(860b88ade1a69f8b6c5b8206424814b386343571) )	// 5u
 
 	/* TTL text plane ("fix layer") */
-	ROM_REGION( 0x20000, REGION_GFX3, 0)
+	ROM_REGION( 0x20000, "gfx3", 0)
 	ROM_LOAD( "247-a12", 0x000000, 0x20000, CRC(57a8d26e) SHA1(0431d10b76d77c26a1f6f2b55d9dbcfa959e1cd0) )
 
 	/* sound data */
-	ROM_REGION( 0x400000, REGION_SOUND1, 0)
+	ROM_REGION( 0x400000, "shared", 0)
 	ROM_LOAD( "247-a06", 0x000000, 0x200000, CRC(b8b2a67e) SHA1(a873d32f4b178c714743664fa53c0dca29cb3ce4) )
 	ROM_LOAD( "247-a07", 0x200000, 0x200000, CRC(0108142d) SHA1(4dc6a36d976dad9c0da5a5b1f01f2eb3b369c99d) )
 ROM_END
@@ -645,7 +646,7 @@ static DRIVER_INIT( rng )
 
 static MACHINE_RESET( rng )
 {
-	K054539_init_flags(0, K054539_REVERSE_STEREO);
+	k054539_init_flags(0, K054539_REVERSE_STEREO);
 
 	memset(rng_sysreg, 0, 0x20);
 
