@@ -1,11 +1,78 @@
-/* Sand Scorpian
+/*
 
-    Sand Scorpion (by Face)                MCU protection (collision detection etc.)
+    Sand Scorpion
+
+(C) 1992 FACE
+
+PCB Number: Z03VA-001
+
+      CPU: TMP68HC000N-12
+Sound CPU: Z8400AB1 (Z80A)
+    Sound: OKI6295, YM2203C & Y3014B
+      OSC: 16.000mhz & 12.000mhz
+     Dips: Two 8-way dipswitch banks
+
+Kaneko custom (surfaced scratched):
+   PX79C480FP-3 PANDORA-CHIP (160pin PQFP)  <- Sprites
+   VIEW2-CHIP (144pin PQFP)                 <- Tilemaps
+   HELP1-CHIP (64pin PQFP)
+   CALC1-CHIP (40pin DIP)                   <- Collision Detection etc.
+
+
++-------------------------------------+
+|  VOL   M6295 7.IC55   Z80A   HELP1  |
+|        Y3014B YM2203C 8.IC51        |
+|            DSW1 DSW2 LH5168D  4.IC32|
+|        12MHz 16MHz   LH5168D  3.IC33|
+|J                     LH5168D   IC30*|
+|A                       VIEW2   IC31*|
+|M       LH5116D             M51257AL |
+|M       LH5116D        PAL  M51257AL |
+|A                               2.IC5|
+|         PAL                    1.IC4|
+|         IC15*       PANDORA    68000|
+|  IC14* 5.IC16   M41464 M41464  CALC1|
+|  IC18* 6.IC17   M41464 M41464       |
++-------------------------------------+
+
+IC18 unpopulated 28 pin socket (silkscreened EPROM)
+IC14 & IC15 unpopulated 32 pin socket (silkscreened MASK)
+IC30 & IC31 unpopulated 42 pin socket (silkscreened MASK)
+
+RAM:
+ OKI M41464C-10 (x4)
+ OKI M51257AL-10 (x2)
+ Sharp LH5116D-10 (x2)
+ Sharp LH5168D-10L (x3)
+
+PALS:
+ AMI 18CV8PC-25 (Stamped IC25D located at IC25)
+ AMI 18CV8PC-25 (Stamped IC26 located at IC26)
+
+Chips simply labeled 1 through 8
+
+ROM ID    ROM Type
+===================
+1.ic4     27C2001
+2.ic5     27C2001
+3.ic33    27C040
+4.ic32    27C040
+5.ic16    27C040
+6.ic17    27C040
+7.ic55    27C2001
+8.ic51    27C1001
+
+Alternate Program roms:
+11.ic4    27C2001
+12.ic5    27C2001
+
+Is there another alt program rom set labeled 9 & 10?
 
 */
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
+#include "cpu/m68000/m68000.h"
 #include "machine/eeprom.h"
 #include "includes/kaneko16.h"
 #include "sound/2203intf.h"
@@ -35,12 +102,12 @@ static UINT8 vblank_irq;
 
 
 /* Update the IRQ state based on all possible causes */
-static void update_irq_state(void)
+static void update_irq_state(running_machine *machine)
 {
 	if (vblank_irq || sprite_irq || unknown_irq)
-		cpunum_set_input_line(Machine, 0, 1, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[0], 1, ASSERT_LINE);
 	else
-		cpunum_set_input_line(Machine, 0, 1, CLEAR_LINE);
+		cpu_set_input_line(machine->cpu[0], 1, CLEAR_LINE);
 }
 
 
@@ -49,14 +116,14 @@ static void update_irq_state(void)
 static INTERRUPT_GEN( sandscrp_interrupt )
 {
 	vblank_irq = 1;
-	update_irq_state();
+	update_irq_state(device->machine);
 }
 
 
 static VIDEO_EOF( sandscrp )
 {
 	sprite_irq = 1;
-	update_irq_state();
+	update_irq_state(machine);
 	pandora_eof(machine);
 }
 
@@ -72,7 +139,7 @@ static READ16_HANDLER( sandscrp_irq_cause_r )
 /* Clear the cause of the interrupt */
 static WRITE16_HANDLER( sandscrp_irq_cause_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		kaneko16_sprite_flipx	=	data & 1;
 		kaneko16_sprite_flipy	=	data & 1;
@@ -82,7 +149,7 @@ static WRITE16_HANDLER( sandscrp_irq_cause_w )
 		if (data & 0x20)	vblank_irq  = 0;
 	}
 
-	update_irq_state();
+	update_irq_state(space->machine);
 }
 
 
@@ -93,7 +160,7 @@ static WRITE16_HANDLER( sandscrp_irq_cause_w )
 
 static WRITE16_HANDLER( sandscrp_coin_counter_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		coin_counter_w(0,   data  & 0x0001);
 		coin_counter_w(1,   data  & 0x0002);
@@ -111,7 +178,7 @@ static READ16_HANDLER( sandscrp_latchstatus_word_r )
 
 static WRITE16_HANDLER( sandscrp_latchstatus_word_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		latch1_full = data & 0x80;
 		latch2_full = data & 0x40;
@@ -121,17 +188,17 @@ static WRITE16_HANDLER( sandscrp_latchstatus_word_w )
 static READ16_HANDLER( sandscrp_soundlatch_word_r )
 {
 	latch2_full = 0;
-	return soundlatch2_r(0);
+	return soundlatch2_r(space,0);
 }
 
 static WRITE16_HANDLER( sandscrp_soundlatch_word_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		latch1_full = 1;
-		soundlatch_w(0, data & 0xff);
-		cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, PULSE_LINE);
-		cpu_spinuntil_time(ATTOTIME_IN_USEC(100));	// Allow the other cpu to reply
+		soundlatch_w(space, 0, data & 0xff);
+		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_NMI, PULSE_LINE);
+		cpu_spinuntil_time(space->cpu, ATTOTIME_IN_USEC(100));	// Allow the other cpu to reply
 	}
 }
 
@@ -141,18 +208,18 @@ static ADDRESS_MAP_START( sandscrp, ADDRESS_SPACE_PROGRAM, 16 )
 
 	AM_RANGE(0x700000, 0x70ffff) AM_RAM		// RAM
 	AM_RANGE(0x200000, 0x20001f) AM_READWRITE(galpanib_calc_r,galpanib_calc_w)	// Protection
-	AM_RANGE(0x300000, 0x30000f) AM_READWRITE(MRA16_RAM, kaneko16_layers_0_regs_w) AM_BASE(&kaneko16_layers_0_regs)	// Layers 0 Regs
-	AM_RANGE(0x400000, 0x400fff) AM_READWRITE(MRA16_RAM, kaneko16_vram_1_w) AM_BASE(&kaneko16_vram_1)	// Layers 0
-	AM_RANGE(0x401000, 0x401fff) AM_READWRITE(MRA16_RAM, kaneko16_vram_0_w) AM_BASE(&kaneko16_vram_0)	//
+	AM_RANGE(0x300000, 0x30000f) AM_RAM_WRITE(kaneko16_layers_0_regs_w) AM_BASE(&kaneko16_layers_0_regs)	// Layers 0 Regs
+	AM_RANGE(0x400000, 0x400fff) AM_RAM_WRITE(kaneko16_vram_1_w) AM_BASE(&kaneko16_vram_1)	// Layers 0
+	AM_RANGE(0x401000, 0x401fff) AM_RAM_WRITE(kaneko16_vram_0_w) AM_BASE(&kaneko16_vram_0)	//
 	AM_RANGE(0x402000, 0x402fff) AM_RAM AM_BASE(&kaneko16_vscroll_1)									//
 	AM_RANGE(0x403000, 0x403fff) AM_RAM AM_BASE(&kaneko16_vscroll_0)									//
 	AM_RANGE(0x500000, 0x501fff) AM_READWRITE(pandora_spriteram_LSB_r, pandora_spriteram_LSB_w ) // sprites
-	AM_RANGE(0x600000, 0x600fff) AM_READWRITE(MRA16_RAM, paletteram16_xGGGGGRRRRRBBBBB_word_w) AM_BASE(&paletteram16)	// Palette
+	AM_RANGE(0x600000, 0x600fff) AM_RAM_WRITE(paletteram16_xGGGGGRRRRRBBBBB_word_w) AM_BASE(&paletteram16)	// Palette
 	AM_RANGE(0xa00000, 0xa00001) AM_WRITE(sandscrp_coin_counter_w)	// Coin Counters (Lockout unused)
-	AM_RANGE(0xb00000, 0xb00001) AM_READ(input_port_0_word_r)	// Inputs
-	AM_RANGE(0xb00002, 0xb00003) AM_READ(input_port_1_word_r)	//
-	AM_RANGE(0xb00004, 0xb00005) AM_READ(input_port_2_word_r)	//
-	AM_RANGE(0xb00006, 0xb00007) AM_READ(input_port_3_word_r)	//
+	AM_RANGE(0xb00000, 0xb00001) AM_READ_PORT("P1")
+	AM_RANGE(0xb00002, 0xb00003) AM_READ_PORT("P2")
+	AM_RANGE(0xb00004, 0xb00005) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0xb00006, 0xb00007) AM_READ_PORT("UNK")
 	AM_RANGE(0xec0000, 0xec0001) AM_READ(watchdog_reset16_r)	//
 	AM_RANGE(0x800000, 0x800001) AM_READ(sandscrp_irq_cause_r)	// IRQ Cause
 	AM_RANGE(0xe00000, 0xe00001) AM_READWRITE(sandscrp_soundlatch_word_r, sandscrp_soundlatch_word_w)	// From/To Sound CPU
@@ -167,15 +234,15 @@ ADDRESS_MAP_END
 
 static WRITE8_HANDLER( sandscrp_bankswitch_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
+	UINT8 *RAM = memory_region(space->machine, "main");
 	int bank = data & 0x07;
 
-	if ( bank != data )	logerror("CPU #1 - PC %04X: Bank %02X\n",activecpu_get_pc(),data);
+	if ( bank != data )	logerror("CPU #1 - PC %04X: Bank %02X\n",cpu_get_pc(space->cpu),data);
 
 	if (bank < 3)	RAM = &RAM[0x4000 * bank];
 	else			RAM = &RAM[0x4000 * (bank-3) + 0x10000];
 
-	memory_set_bankptr(1, RAM);
+	memory_set_bankptr(space->machine, 1, RAM);
 }
 
 static READ8_HANDLER( sandscrp_latchstatus_r )
@@ -187,27 +254,27 @@ static READ8_HANDLER( sandscrp_latchstatus_r )
 static READ8_HANDLER( sandscrp_soundlatch_r )
 {
 	latch1_full = 0;
-	return soundlatch_r(0);
+	return soundlatch_r(space,0);
 }
 
 static WRITE8_HANDLER( sandscrp_soundlatch_w )
 {
 	latch2_full = 1;
-	soundlatch2_w(0,data);
+	soundlatch2_w(space,0,data);
 }
 
 static ADDRESS_MAP_START( sandscrp_soundmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM		// ROM
-	AM_RANGE(0x8000, 0xbfff) AM_READWRITE(MRA8_BANK1, MWA8_ROM)	// Banked ROM
+	AM_RANGE(0x8000, 0xbfff) AM_READWRITE(SMH_BANK1, SMH_ROM)	// Banked ROM
 	AM_RANGE(0xc000, 0xdfff) AM_RAM		// RAM
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sandscrp_soundport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_WRITE(sandscrp_bankswitch_w)	// ROM Bank
-	AM_RANGE(0x02, 0x02) AM_READWRITE(YM2203_status_port_0_r, YM2203_control_port_0_w)	// YM2203
-	AM_RANGE(0x03, 0x03) AM_READWRITE(YM2203_read_port_0_r, YM2203_write_port_0_w)		// PORTA/B read
-	AM_RANGE(0x04, 0x04) AM_WRITE(OKIM6295_data_0_w)		// OKIM6295
+	AM_RANGE(0x02, 0x02) AM_READWRITE(ym2203_status_port_0_r, ym2203_control_port_0_w)	// YM2203
+	AM_RANGE(0x03, 0x03) AM_READWRITE(ym2203_read_port_0_r, ym2203_write_port_0_w)		// PORTA/B read
+	AM_RANGE(0x04, 0x04) AM_WRITE(okim6295_data_0_w)		// OKIM6295
 	AM_RANGE(0x06, 0x06) AM_WRITE(sandscrp_soundlatch_w)	//
 	AM_RANGE(0x07, 0x07) AM_READ(sandscrp_soundlatch_r)		//
 	AM_RANGE(0x08, 0x08) AM_READ(sandscrp_latchstatus_r)	//
@@ -219,7 +286,7 @@ ADDRESS_MAP_END
 ***************************************************************************/
 
 static INPUT_PORTS_START( sandscrp )
-	PORT_START	// IN0 - $b00000.w
+	PORT_START("P1")	/* $b00000.w */
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN	 ) PORT_PLAYER(1)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(1)
@@ -228,10 +295,9 @@ static INPUT_PORTS_START( sandscrp )
 	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
 	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
 	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN1 - $b00002.w
+	PORT_START("P2")	/* $b00002.w */
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(2)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN	 ) PORT_PLAYER(2)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(2)
@@ -240,10 +306,9 @@ static INPUT_PORTS_START( sandscrp )
 	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
 	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN )
-
 	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN2 - $b00004.w
+	PORT_START("SYSTEM")	/* $b00004.w */
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_START1   )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_START2   )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_COIN1    )
@@ -252,13 +317,12 @@ static INPUT_PORTS_START( sandscrp )
 	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_UNKNOWN  )
 	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_SERVICE1 )
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN  )
-
 	PORT_BIT( 0xff00, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN3 - $b00006.w
+	PORT_START("UNK")	/* $b00006.w */
 	PORT_BIT( 0xffff, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	// IN4 - DSW 1 read by the Z80 through the sound chip
+	PORT_START("DSW1")	/* read by the Z80 through the sound chip */
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x02, "1" )
 	PORT_DIPSETTING(    0x01, "2" )
@@ -280,7 +344,7 @@ static INPUT_PORTS_START( sandscrp )
 	PORT_DIPSETTING(    0x40, "500K, 1000K" )
 	PORT_DIPSETTING(    0x00, "1000K, 3000K" )
 
-	PORT_START	// IN5 - DSW 2 read by the Z80 through the sound chip
+	PORT_START("DSW2")	/* read by the Z80 through the sound chip */
 	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coinage ) )
 	PORT_DIPSETTING(    0x0a, DEF_STR( 6C_1C ) )
 	PORT_DIPSETTING(    0x0b, DEF_STR( 5C_1C ) )
@@ -337,8 +401,8 @@ static const gfx_layout layout_16x16x4 =
 
 
 static GFXDECODE_START( sandscrp )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, layout_16x16x4,   0x000, 0x10 ) // [0] Sprites
-	GFXDECODE_ENTRY( REGION_GFX2, 0, layout_16x16x4_2, 0x400, 0x40 ) // [1] Layers
+	GFXDECODE_ENTRY( "gfx1", 0, layout_16x16x4,   0x000, 0x10 ) // [0] Sprites
+	GFXDECODE_ENTRY( "gfx2", 0, layout_16x16x4_2, 0x400, 0x40 ) // [1] Layers
 GFXDECODE_END
 
 
@@ -349,17 +413,21 @@ GFXDECODE_END
 
 /* YM3014B + YM2203C */
 
-static void irq_handler(int irq)
+static void irq_handler(running_machine *machine, int irq)
 {
-	cpunum_set_input_line(Machine, 1,0,irq ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[1],0,irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
-static const struct YM2203interface ym2203_intf_sandscrp =
+static const ym2203_interface ym2203_intf_sandscrp =
 {
-	input_port_4_r,	/* Port A Read - DSW 1 */
-	input_port_5_r,	/* Port B Read - DSW 2 */
-	0,	/* Port A Write */
-	0,	/* Port B Write */
+	{
+		AY8910_LEGACY_OUTPUT,
+		AY8910_DEFAULT_LOADS,
+		input_port_4_r,	/* Port A Read - DSW 1 */
+		input_port_5_r,	/* Port B Read - DSW 2 */
+		NULL,	/* Port A Write */
+		NULL,	/* Port B Write */
+	},
 	irq_handler	/* IRQ handler */
 };
 
@@ -367,25 +435,26 @@ static const struct YM2203interface ym2203_intf_sandscrp =
 static MACHINE_DRIVER_START( sandscrp )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000,12000000)	/* TMP68HC000N-12 */
+	MDRV_CPU_ADD("main", M68000,12000000)	/* TMP68HC000N-12 */
 	MDRV_CPU_PROGRAM_MAP(sandscrp,0)
-	MDRV_CPU_VBLANK_INT(sandscrp_interrupt,1)
+	MDRV_CPU_VBLANK_INT("main", sandscrp_interrupt)
 
-	MDRV_CPU_ADD(Z80,4000000)	/* Z8400AB1, Reads the DSWs: it can't be disabled */
+	MDRV_CPU_ADD("audio", Z80,4000000)	/* Z8400AB1, Reads the DSWs: it can't be disabled */
 	MDRV_CPU_PROGRAM_MAP(sandscrp_soundmem,0)
 	MDRV_CPU_IO_MAP(sandscrp_soundport,0)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME( DEFAULT_REAL_60HZ_VBLANK_DURATION )
-	MDRV_WATCHDOG_VBLANK_INIT(DEFAULT_60HZ_3S_VBLANK_WATCHDOG)
+	MDRV_WATCHDOG_TIME_INIT(SEC(3))	/* a guess, and certainly wrong */
 
 	MDRV_MACHINE_RESET(sandscrp)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME( ATTOSECONDS_IN_USEC(2500) /* not accurate */ )
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 256)
 	MDRV_SCREEN_VISIBLE_AREA(0, 256-1, 0+16, 256-16-1)
+
 	MDRV_GFXDECODE(sandscrp)
 	MDRV_PALETTE_LENGTH(2048)
 
@@ -396,12 +465,12 @@ static MACHINE_DRIVER_START( sandscrp )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(OKIM6295, 12000000/6)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high)
+	MDRV_SOUND_ADD("oki", OKIM6295, 12000000/6)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.25)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.25)
 
-	MDRV_SOUND_ADD(YM2203, 4000000)
+	MDRV_SOUND_ADD("ym", YM2203, 4000000)
 	MDRV_SOUND_CONFIG(ym2203_intf_sandscrp)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.25)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.25)
@@ -413,64 +482,71 @@ MACHINE_DRIVER_END
 
                                 Sand Scorpion
 
-(C) FACE
-68HC000N-12
-Z8400AB1
-OKI6295, YM2203C
-OSC:  16.000mhz,   12.000mhz
-
-SANDSC03.BIN     27C040
-SANDSC04.BIN     27C040
-SANDSC05.BIN     27C040
-SANDSC06.BIN     27C040
-SANDSC07.BIN     27C2001
-SANDSC08.BIN     27C1001
-SANDSC11.BIN     27C2001
-SANDSC12.BIN     27C2001
-
 ***************************************************************************/
 
-ROM_START( sandscrp )
-	ROM_REGION( 0x080000, REGION_CPU1, 0 )		/* 68000 Code */
-	ROM_LOAD16_BYTE( "sandsc11.bin", 0x000000, 0x040000, CRC(9b24ab40) SHA1(3187422dbe8b15d8053be4cb20e56d3e6afbd5f2) )
-	ROM_LOAD16_BYTE( "sandsc12.bin", 0x000001, 0x040000, CRC(ad12caee) SHA1(83267445b89c3cf4dc317106aa68763d2f29eff7) )
+ROM_START( sandscrp ) /* Z03VA-003 PCB */
+	ROM_REGION( 0x080000, "main", 0 )		/* 68000 Code */
+	ROM_LOAD16_BYTE( "11.bin", 0x000000, 0x040000, CRC(9b24ab40) SHA1(3187422dbe8b15d8053be4cb20e56d3e6afbd5f2) ) /* Location is IC4 */
+	ROM_LOAD16_BYTE( "12.bin", 0x000001, 0x040000, CRC(ad12caee) SHA1(83267445b89c3cf4dc317106aa68763d2f29eff7) ) /* Location is IC5 */
 
-	ROM_REGION( 0x24000, REGION_CPU2, 0 )		/* Z80 Code */
-	ROM_LOAD( "sandsc08.bin", 0x00000, 0x0c000, CRC(6f3e9db1) SHA1(06a04fa17f44319986913bff70433510c89e38f1) )
-	ROM_CONTINUE(             0x10000, 0x14000             )
+	ROM_REGION( 0x24000, "audio", 0 )		/* Z80 Code */
+	ROM_LOAD( "8.ic51", 0x00000, 0x0c000, CRC(6f3e9db1) SHA1(06a04fa17f44319986913bff70433510c89e38f1) )
+	ROM_CONTINUE(       0x10000, 0x14000 )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )	/* Sprites */
-	ROM_LOAD( "sandsc05.bin", 0x000000, 0x080000, CRC(9bb675f6) SHA1(c3f6768cfd99a0e19ca2224fff9aa4e27ec0da24) )
-	ROM_LOAD( "sandsc06.bin", 0x080000, 0x080000, CRC(7df2f219) SHA1(e2a59e201bfededa92d6c86f8dc1b212527ef66f) )
+	ROM_REGION( 0x100000, "gfx1", ROMREGION_DISPOSE )	/* Sprites */
+	ROM_LOAD( "5.ic16", 0x000000, 0x080000, CRC(9bb675f6) SHA1(c3f6768cfd99a0e19ca2224fff9aa4e27ec0da24) )
+	ROM_LOAD( "6.ic17", 0x080000, 0x080000, CRC(7df2f219) SHA1(e2a59e201bfededa92d6c86f8dc1b212527ef66f) )
 
-	ROM_REGION( 0x100000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layers */
-	ROM_LOAD16_BYTE( "sandsc04.bin", 0x000000, 0x080000, CRC(b9222ff2) SHA1(a445da3f7f5dea5ff64bb0b048f624f947875a39) )
-	ROM_LOAD16_BYTE( "sandsc03.bin", 0x000001, 0x080000, CRC(adf20fa0) SHA1(67a7a2be774c86916cbb97e4c9b16c2e48125780) )
+	ROM_REGION( 0x100000, "gfx2", ROMREGION_DISPOSE )	/* Layers */
+	ROM_LOAD16_BYTE( "4.ic32", 0x000000, 0x080000, CRC(b9222ff2) SHA1(a445da3f7f5dea5ff64bb0b048f624f947875a39) )
+	ROM_LOAD16_BYTE( "3.ic33", 0x000001, 0x080000, CRC(adf20fa0) SHA1(67a7a2be774c86916cbb97e4c9b16c2e48125780) )
 
-	ROM_REGION( 0x040000, REGION_SOUND1, 0 )	/* Samples */
-	ROM_LOAD( "sandsc07.bin", 0x000000, 0x040000, CRC(9870ab12) SHA1(5ea3412cbc57bfaa32a1e2552b2eb46f4ceb5fa8) )
+	ROM_REGION( 0x040000, "oki", 0 )	/* Samples */
+	ROM_LOAD( "7.ic55", 0x000000, 0x040000, CRC(9870ab12) SHA1(5ea3412cbc57bfaa32a1e2552b2eb46f4ceb5fa8) )
+ROM_END
+
+ROM_START( sandscra ) /* Z03VA-003 PCB, earlier program version */
+	ROM_REGION( 0x080000, "main", 0 )		/* 68000 Code */
+	ROM_LOAD16_BYTE( "1.ic4", 0x000000, 0x040000, CRC(c0943ae2) SHA1(04dac4e1f116cd96d6292daa61ef40efc7eba919) )
+	ROM_LOAD16_BYTE( "2.ic5", 0x000001, 0x040000, CRC(6a8e0012) SHA1(2350b11c9bd545c8ba4b3c25cd6547ba2ad474b5) )
+
+	ROM_REGION( 0x24000, "audio", 0 )		/* Z80 Code */
+	ROM_LOAD( "8.ic51", 0x00000, 0x0c000, CRC(6f3e9db1) SHA1(06a04fa17f44319986913bff70433510c89e38f1) )
+	ROM_CONTINUE(       0x10000, 0x14000 )
+
+	ROM_REGION( 0x100000, "gfx1", ROMREGION_DISPOSE )	/* Sprites */
+	ROM_LOAD( "5.ic16", 0x000000, 0x080000, CRC(9bb675f6) SHA1(c3f6768cfd99a0e19ca2224fff9aa4e27ec0da24) )
+	ROM_LOAD( "6.ic17", 0x080000, 0x080000, CRC(7df2f219) SHA1(e2a59e201bfededa92d6c86f8dc1b212527ef66f) )
+
+	ROM_REGION( 0x100000, "gfx2", ROMREGION_DISPOSE )	/* Layers */
+	ROM_LOAD16_BYTE( "4.ic32", 0x000000, 0x080000, CRC(b9222ff2) SHA1(a445da3f7f5dea5ff64bb0b048f624f947875a39) )
+	ROM_LOAD16_BYTE( "3.ic33", 0x000001, 0x080000, CRC(adf20fa0) SHA1(67a7a2be774c86916cbb97e4c9b16c2e48125780) )
+
+	ROM_REGION( 0x040000, "oki", 0 )	/* Samples */
+	ROM_LOAD( "7.ic55", 0x000000, 0x040000, CRC(9870ab12) SHA1(5ea3412cbc57bfaa32a1e2552b2eb46f4ceb5fa8) )
 ROM_END
 
 
-ROM_START( sandscra )
-	ROM_REGION( 0x080000, REGION_CPU1, 0 )		/* 68000 Code */
+ROM_START( sandscrb ) /* Different rev PCB */
+	ROM_REGION( 0x080000, "main", 0 )		/* 68000 Code */
 	ROM_LOAD16_BYTE( "11.ic4", 0x000000, 0x040000, CRC(80020cab) SHA1(4f1f4d8ea07ad745f2d6d3f800686f07fe4bf20f) )
 	ROM_LOAD16_BYTE( "12.ic5", 0x000001, 0x040000, CRC(8df1d42f) SHA1(2a9db5c4b99a8a3f62bffa9ddd96a95e2042602b) )
 
-	ROM_REGION( 0x24000, REGION_CPU2, 0 )		/* Z80 Code */
-	ROM_LOAD( "sandsc08.bin", 0x00000, 0x0c000, CRC(6f3e9db1) SHA1(06a04fa17f44319986913bff70433510c89e38f1) )
-	ROM_CONTINUE(             0x10000, 0x14000             )
+	ROM_REGION( 0x24000, "audio", 0 )		/* Z80 Code */
+	ROM_LOAD( "8.ic51", 0x00000, 0x0c000, CRC(6f3e9db1) SHA1(06a04fa17f44319986913bff70433510c89e38f1) )
+	ROM_CONTINUE(       0x10000, 0x14000 )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )	/* Sprites */
+	ROM_REGION( 0x100000, "gfx1", ROMREGION_DISPOSE )	/* Sprites */
 	ROM_LOAD( "ss502.ic16", 0x000000, 0x100000, CRC(d8012ebb) SHA1(975bbb3b57a09e41d2257d4fa3a64097144de554) )
 
-	ROM_REGION( 0x100000, REGION_GFX2, ROMREGION_DISPOSE )	/* Layers */
+	ROM_REGION( 0x100000, "gfx2", ROMREGION_DISPOSE )	/* Layers */
 	ROM_LOAD16_WORD_SWAP( "ss501.ic30", 0x000000, 0x100000, CRC(0cf9f99d) SHA1(47f7f120d2bc075bedaff0a44306a8f46a1d848c) )
 
-	ROM_REGION( 0x040000, REGION_SOUND1, 0 )	/* Samples */
-	ROM_LOAD( "sandsc07.bin", 0x000000, 0x040000, CRC(9870ab12) SHA1(5ea3412cbc57bfaa32a1e2552b2eb46f4ceb5fa8) )
+	ROM_REGION( 0x040000, "oki", 0 )	/* Samples */
+	ROM_LOAD( "7.ic55", 0x000000, 0x040000, CRC(9870ab12) SHA1(5ea3412cbc57bfaa32a1e2552b2eb46f4ceb5fa8) )
 ROM_END
 
 
-GAME( 1992, sandscrp, 0,        sandscrp, sandscrp, 0,          ROT90, "Face",   "Sand Scorpion (set 1)", 0 )
-GAME( 1992, sandscra, sandscrp, sandscrp, sandscrp, 0,          ROT90, "Face",   "Sand Scorpion (set 2)", 0 )
+GAME( 1992, sandscrp, 0,        sandscrp, sandscrp, 0,          ROT90, "Face",   "Sand Scorpion", 0 )
+GAME( 1992, sandscra, sandscrp, sandscrp, sandscrp, 0,          ROT90, "Face",   "Sand Scorpion (Earlier)", 0 )
+GAME( 1992, sandscrb, sandscrp, sandscrp, sandscrp, 0,          ROT90, "Face",   "Sand Scorpion (Revised Hardware)", 0 )
