@@ -9,14 +9,15 @@ Stephh's notes :
   - As for some other M68000 Technos games (or games running on similar hardware
     such as 'mugsmash'), the Inputs and the Dip Switches are mangled, so you need
     a specific read handler so end-uers can see them in a "standard" order.
-    IMO you should set the USE_SHADFRCE_FAKE_INPUT_PORTS macro to 1.
-  - Why do "Coin 2" and "Service 1" buttons only work in "test mode" ?
 
- To Do:
+ 01-Sept-2008 - Pierpaolo Prazzoli
+ - Added irqs ack
+ - Implemented raster irq
+ - Fixed coin2 and service input not working during the game
+ - Added watchdog
+ - Fixed visible area
+ - Added video enable and irqs enable flags
 
- Graphic Glitches
-  Spurious sprite at the top right of the title screen. Visible area too large?
- Other Interrupt?
 
 *******************************************************************************
 
@@ -67,9 +68,9 @@ Samples:
 
 /*
 68k interrupts
-lev 1 : 0x64 : 0004 fd00 - ?
-lev 2 : 0x68 : 0000 1f32 - vblank?
-lev 3 : 0x6c : 0000 10f4 - ?
+lev 1 : 0x64 : 0004 fd00 - raster irq
+lev 2 : 0x68 : 0000 1f32 - inputs irq (reads inputs, ...)
+lev 3 : 0x6c : 0000 10f4 - vblank irq
 lev 4 : 0x70 : 0000 11d0 - just rte
 lev 5 : 0x74 : 0000 11d0 - just rte
 lev 6 : 0x78 : 0000 11d0 - just rte
@@ -77,12 +78,16 @@ lev 7 : 0x7c : 0000 11d0 - just rte
 */
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
+#include "cpu/m68000/m68000.h"
 #include "sound/2151intf.h"
 #include "sound/okim6295.h"
 
+#define MASTER_CLOCK		XTAL_28MHz
+#define CPU_CLOCK			MASTER_CLOCK / 2
+#define PIXEL_CLOCK		MASTER_CLOCK / 4
+
 UINT16 *shadfrce_fgvideoram, *shadfrce_bg0videoram,  *shadfrce_bg1videoram,   *shadfrce_spvideoram;
-/* UINT16 *shadfrce_videoregs; */
 
 /* in video */
 WRITE16_HANDLER ( shadfrce_bg0scrollx_w );
@@ -96,10 +101,16 @@ WRITE16_HANDLER( shadfrce_fgvideoram_w );
 WRITE16_HANDLER( shadfrce_bg0videoram_w );
 WRITE16_HANDLER( shadfrce_bg1videoram_w );
 
+int shadfrce_video_enable = 0;
+static int shadfrce_irqs_enable = 0;
+static int raster_scanline = 0;
+static int raster_irq_enable = 0;
+static int vblank = 0;
+
 
 static WRITE16_HANDLER( shadfrce_flip_screen )
 {
-	flip_screen_set(data & 0x01);
+	flip_screen_set(space->machine, data & 0x01);
 }
 
 
@@ -181,9 +192,7 @@ static WRITE16_HANDLER( shadfrce_flip_screen )
 
 */
 
-#define USE_SHADFRCE_FAKE_INPUT_PORTS	1
 
-#if USE_SHADFRCE_FAKE_INPUT_PORTS
 static READ16_HANDLER( shadfrce_input_ports_r )
 {
 	UINT16 data = 0xffff;
@@ -191,29 +200,29 @@ static READ16_HANDLER( shadfrce_input_ports_r )
 	switch (offset)
 	{
 		case 0 :
-			data = (readinputport(0) & 0xff) | ((readinputport(7) & 0xc0) << 6) | ((readinputport(4) & 0x0f) << 8);
+			data = (input_port_read(space->machine, "P1") & 0xff) | ((input_port_read(space->machine, "DSW2") & 0xc0) << 6) | ((input_port_read(space->machine, "SYSTEM") & 0x0f) << 8);
 			break;
 		case 1 :
-			data = (readinputport(1) & 0xff) | ((readinputport(7) & 0x3f) << 8);
+			data = (input_port_read(space->machine, "P2") & 0xff) | ((input_port_read(space->machine, "DSW2") & 0x3f) << 8);
 			break;
 		case 2 :
-			data = (readinputport(2) & 0xff) | ((readinputport(6) & 0x3f) << 8);
+			data = (input_port_read(space->machine, "EXTRA") & 0xff) | ((input_port_read(space->machine, "DSW1") & 0x3f) << 8);
 			break;
 		case 3 :
-			data = (readinputport(3) & 0xff) | ((readinputport(6) & 0xc0) << 2) | ((readinputport(5) & 0x3c) << 8);
+			data = (input_port_read(space->machine, "OTHER") & 0xff) | ((input_port_read(space->machine, "DSW1") & 0xc0) << 2) | ((input_port_read(space->machine, "MISC") & 0x38) << 8) | (vblank << 8);
 			break;
 	}
 
 	return (data);
 }
-#endif
+
 
 static WRITE16_HANDLER ( shadfrce_sound_brt_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
-		soundlatch_w(1,data >> 8);
-		cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, PULSE_LINE );
+		soundlatch_w(space,1,data >> 8);
+		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_NMI, PULSE_LINE );
 	}
 	else
 	{
@@ -221,89 +230,139 @@ static WRITE16_HANDLER ( shadfrce_sound_brt_w )
 		double brt = (data & 0xff) / 255.0;
 
 		for (i = 0; i < 0x4000; i++)
-			palette_set_brightness(Machine,i,brt);
+			palette_set_pen_contrast(space->machine,i,brt);
 	}
 }
 
-/* Memory Maps - ToDo, Work Out Unknowns */
+static WRITE16_HANDLER( shadfrce_irq_ack_w )
+{
+	cpu_set_input_line(space->machine->cpu[0], offset ^ 3, CLEAR_LINE);
+}
 
-static ADDRESS_MAP_START( shadfrce_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x100000, 0x100fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x101000, 0x101fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x102000, 0x1027ff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x102800, 0x103fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x140000, 0x141fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x142000, 0x143fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x180000, 0x187fff) AM_READ(MRA16_RAM)
-	/* inputs, dipswitches etc. */
-	AM_RANGE(0x1c000a, 0x1c000b) AM_READ(MRA16_NOP) /* ?? */
-	AM_RANGE(0x1d000c, 0x1d000d) AM_READ(MRA16_NOP) /* ?? */
-#if USE_SHADFRCE_FAKE_INPUT_PORTS
-	AM_RANGE(0x1d0020, 0x1d0027) AM_READ(shadfrce_input_ports_r)
-#else
-	AM_RANGE(0x1d0020, 0x1d0021) AM_READ(input_port_0_word_r)
-	AM_RANGE(0x1d0022, 0x1d0023) AM_READ(input_port_1_word_r)
-	AM_RANGE(0x1d0024, 0x1d0025) AM_READ(input_port_2_word_r)
-	AM_RANGE(0x1d0026, 0x1d0027) AM_READ(input_port_3_word_r)
-#endif
-	AM_RANGE(0x1F0000, 0x1FFFFF) AM_READ(MRA16_RAM)
-ADDRESS_MAP_END
+static WRITE16_HANDLER( shadfrce_irq_w )
+{
+	static int prev_value = 0;
 
-static ADDRESS_MAP_START( shadfrce_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(MWA16_ROM)
-	AM_RANGE(0x100000, 0x100fff) AM_WRITE(shadfrce_bg0videoram_w) AM_BASE(&shadfrce_bg0videoram) /* video */
-	AM_RANGE(0x101000, 0x101fff) AM_WRITE(MWA16_RAM)
-	AM_RANGE(0x102000, 0x1027ff) AM_WRITE(shadfrce_bg1videoram_w) AM_BASE(&shadfrce_bg1videoram) /* bg 2 */
-	AM_RANGE(0x102800, 0x103fff) AM_WRITE(MWA16_RAM)
-	AM_RANGE(0x140000, 0x141fff) AM_WRITE(shadfrce_fgvideoram_w) AM_BASE(&shadfrce_fgvideoram)
-	AM_RANGE(0x142000, 0x143fff) AM_WRITE(MWA16_RAM) AM_BASE(&shadfrce_spvideoram) AM_SIZE(&spriteram_size) /* sprites */
-	AM_RANGE(0x180000, 0x187fff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16) /* ?? */
-	/* probably video registers etc. */
-//  AM_RANGE(0x1c0000, 0x1d000d) AM_WRITE(MWA16_RAM) AM_BASE(&shadfrce_videoregs)
+	shadfrce_irqs_enable = data & 1;	/* maybe, it's set/unset inside every trap instruction which is executed */
+	shadfrce_video_enable = data & 8;	/* probably */
+
+	/* check if there's a high transition to enable the raster IRQ */
+	if((~prev_value & 4) && (data & 4))
+	{
+		raster_irq_enable = 1;
+	}
+
+	/* check if there's a low transition to disable the raster IRQ */
+	if((prev_value & 4) && (~data & 4))
+	{
+		raster_irq_enable = 0;
+	}
+
+	prev_value = data;
+}
+
+static WRITE16_HANDLER( shadfrce_scanline_w )
+{
+	raster_scanline = data; 	/* guess, 0 is always written */
+}
+
+static TIMER_DEVICE_CALLBACK( shadfrce_scanline )
+{
+	int scanline = param;
+
+	/* Vblank is lowered on scanline 0 */
+	if (scanline == 0)
+	{
+		vblank = 0;
+	}
+	/* Hack */
+	else if (scanline == (248-1))		/* -1 is an hack needed to avoid deadlocks */
+	{
+		vblank = 4;
+	}
+
+	/* Raster interrupt - Perform raster effect on given scanline */
+	if (raster_irq_enable)
+	{
+		if (scanline == raster_scanline)
+		{
+			raster_scanline = (raster_scanline + 1) % 240;
+			if (raster_scanline > 0)
+				video_screen_update_partial(timer->machine->primary_screen, raster_scanline - 1);
+			cpu_set_input_line(timer->machine->cpu[0], 1, ASSERT_LINE);
+		}
+	}
+
+	/* An interrupt is generated every 16 scanlines */
+	if (shadfrce_irqs_enable)
+	{
+		if (scanline % 16 == 0)
+		{
+			if (scanline > 0)
+				video_screen_update_partial(timer->machine->primary_screen, scanline - 1);
+			cpu_set_input_line(timer->machine->cpu[0], 2, ASSERT_LINE);
+		}
+	}
+
+	/* Vblank is raised on scanline 248 */
+	if (shadfrce_irqs_enable)
+	{
+		if (scanline == 248)
+		{
+			video_screen_update_partial(timer->machine->primary_screen, scanline - 1);
+			cpu_set_input_line(timer->machine->cpu[0], 3, ASSERT_LINE);
+		}
+	}
+}
+
+
+
+/* Memory Maps */
+
+static ADDRESS_MAP_START( shadfrce_map, ADDRESS_SPACE_PROGRAM, 16 )
+	AM_RANGE(0x000000, 0x0fffff) AM_ROM
+	AM_RANGE(0x100000, 0x100fff) AM_RAM_WRITE(shadfrce_bg0videoram_w) AM_BASE(&shadfrce_bg0videoram) /* video */
+	AM_RANGE(0x101000, 0x101fff) AM_RAM
+	AM_RANGE(0x102000, 0x1027ff) AM_RAM_WRITE(shadfrce_bg1videoram_w) AM_BASE(&shadfrce_bg1videoram) /* bg 2 */
+	AM_RANGE(0x102800, 0x103fff) AM_RAM
+	AM_RANGE(0x140000, 0x141fff) AM_RAM_WRITE(shadfrce_fgvideoram_w) AM_BASE(&shadfrce_fgvideoram)
+	AM_RANGE(0x142000, 0x143fff) AM_RAM AM_BASE(&shadfrce_spvideoram) AM_SIZE(&spriteram_size) /* sprites */
+	AM_RANGE(0x180000, 0x187fff) AM_RAM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x1c0000, 0x1c0001) AM_WRITE(shadfrce_bg0scrollx_w) /* SCROLL X */
 	AM_RANGE(0x1c0002, 0x1c0003) AM_WRITE(shadfrce_bg0scrolly_w) /* SCROLL Y */
 	AM_RANGE(0x1c0004, 0x1c0005) AM_WRITE(shadfrce_bg1scrollx_w) /* SCROLL X */
 	AM_RANGE(0x1c0006, 0x1c0007) AM_WRITE(shadfrce_bg1scrolly_w) /* SCROLL Y */
-	AM_RANGE(0x1c0008, 0x1c0009) AM_WRITE(MWA16_NOP) /* ?? */
-	AM_RANGE(0x1c000a, 0x1c000b) AM_WRITE(shadfrce_flip_screen)
-	AM_RANGE(0x1c000c, 0x1c000d) AM_WRITE(MWA16_NOP) /* ?? */
-	AM_RANGE(0x1d0000, 0x1d0001) AM_WRITE(MWA16_NOP) /* ?? */
-	AM_RANGE(0x1d0002, 0x1d0003) AM_WRITE(MWA16_NOP) /* ?? */
-	AM_RANGE(0x1d0006, 0x1d0007) AM_WRITE(MWA16_NOP) /* ?? */
-	AM_RANGE(0x1d0008, 0x1d0009) AM_WRITE(MWA16_NOP) /* ?? */
-	AM_RANGE(0x1d000c, 0x1d000d) AM_WRITE(shadfrce_sound_brt_w)	/* sound command + screen brightness */
-	AM_RANGE(0x1d0010, 0x1d0011) AM_WRITE(MWA16_NOP) /* ?? */
-	AM_RANGE(0x1d0012, 0x1d0013) AM_WRITE(MWA16_NOP) /* ?? */
-	AM_RANGE(0x1d0014, 0x1d0015) AM_WRITE(MWA16_NOP) /* ?? */
-	AM_RANGE(0x1d0016, 0x1d0017) AM_WRITE(MWA16_NOP) /* ?? */
-	AM_RANGE(0x1f0000, 0x1fffff) AM_WRITE(MWA16_RAM)
+	AM_RANGE(0x1c0008, 0x1c0009) AM_WRITENOP /* ?? */
+	AM_RANGE(0x1c000a, 0x1c000b) AM_READNOP AM_WRITE(shadfrce_flip_screen)
+	AM_RANGE(0x1c000c, 0x1c000d) AM_WRITENOP /* ?? */
+	AM_RANGE(0x1d0000, 0x1d0005) AM_WRITE(shadfrce_irq_ack_w)
+	AM_RANGE(0x1d0006, 0x1d0007) AM_WRITE(shadfrce_irq_w)
+	AM_RANGE(0x1d0008, 0x1d0009) AM_WRITE(shadfrce_scanline_w)
+	AM_RANGE(0x1d000c, 0x1d000d) AM_READNOP AM_WRITE(shadfrce_sound_brt_w)	/* sound command + screen brightness */
+	AM_RANGE(0x1d0010, 0x1d0011) AM_WRITENOP /* ?? */
+	AM_RANGE(0x1d0012, 0x1d0013) AM_WRITENOP /* ?? */
+	AM_RANGE(0x1d0014, 0x1d0015) AM_WRITENOP /* ?? */
+	AM_RANGE(0x1d0016, 0x1d0017) AM_WRITE(watchdog_reset16_w)
+	AM_RANGE(0x1d0020, 0x1d0027) AM_READ(shadfrce_input_ports_r)
+	AM_RANGE(0x1f0000, 0x1fffff) AM_RAM
 ADDRESS_MAP_END
 
 /* and the sound cpu */
 
 static WRITE8_HANDLER( oki_bankswitch_w )
 {
-	OKIM6295_set_bank_base(0, (data & 1) * 0x40000);
+	okim6295_set_bank_base(0, (data & 1) * 0x40000);
 }
 
-static ADDRESS_MAP_START( readmem_sound, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xc801, 0xc801) AM_READ(YM2151_status_port_0_r)
-	AM_RANGE(0xd800, 0xd800) AM_READ(OKIM6295_status_0_r)
+static ADDRESS_MAP_START( shadfrce_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0xbfff) AM_ROM
+	AM_RANGE(0xc000, 0xc7ff) AM_RAM
+	AM_RANGE(0xc800, 0xc800) AM_WRITE(ym2151_register_port_0_w)
+	AM_RANGE(0xc801, 0xc801) AM_READWRITE(ym2151_status_port_0_r, ym2151_data_port_0_w)
+	AM_RANGE(0xd800, 0xd800) AM_READWRITE(okim6295_status_0_r, okim6295_data_0_w)
 	AM_RANGE(0xe000, 0xe000) AM_READ(soundlatch_r)
-	AM_RANGE(0xf000, 0xffff) AM_READ(MRA8_RAM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writemem_sound, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xbfff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xc800, 0xc800) AM_WRITE(YM2151_register_port_0_w)
-	AM_RANGE(0xc801, 0xc801) AM_WRITE(YM2151_data_port_0_w)
-	AM_RANGE(0xd800, 0xd800) AM_WRITE(OKIM6295_data_0_w)
 	AM_RANGE(0xe800, 0xe800) AM_WRITE(oki_bankswitch_w)
-	AM_RANGE(0xf000, 0xffff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0xf000, 0xffff) AM_RAM
 ADDRESS_MAP_END
 
 
@@ -321,15 +380,14 @@ ADDRESS_MAP_END
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, start )
 
 
-#if USE_SHADFRCE_FAKE_INPUT_PORTS
 static INPUT_PORTS_START( shadfrce )
-	PORT_START	/* Fake IN0 (player 1 inputs) */
+	PORT_START("P1")		/* Fake IN0 (player 1 inputs) */
 	SHADFRCE_PLAYER_INPUT( 1, IPT_START1 )
 
-	PORT_START	/* Fake IN1 (player 2 inputs) */
+	PORT_START("P2")		/* Fake IN1 (player 2 inputs) */
 	SHADFRCE_PLAYER_INPUT( 2, IPT_START2 )
 
-	PORT_START	/* Fake IN2 (players 1 & 2 extra inputs */
+	PORT_START("EXTRA")	/* Fake IN2 (players 1 & 2 extra inputs */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(1)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON5 ) PORT_PLAYER(1)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON6 ) PORT_PLAYER(1)
@@ -339,21 +397,21 @@ static INPUT_PORTS_START( shadfrce )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	/* Fake IN3 (other extra inputs ?) */
+	PORT_START("OTHER")	/* Fake IN3 (other extra inputs ?) */
 	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	/* Fake IN4 (system inputs) */
+	PORT_START("SYSTEM")	/* Fake IN4 (system inputs) */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )                   /* only in "test mode" ? */
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )                /* only in "test mode" ? */
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )			/* only in "test mode" ? */
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )			/* only in "test mode" ? */
 	PORT_BIT( 0xf8, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	/* Fake IN5 (misc) */
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_VBLANK )                  /* guess */
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )                 /* must be ACTIVE_LOW or 'shadfrcj' jumps to the end (code at 0x04902e) */
-	PORT_BIT( 0xec, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_START("MISC")	/* Fake IN5 (misc) */
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SPECIAL )			/* guess */
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )			/* must be ACTIVE_LOW or 'shadfrcj' jumps to the end (code at 0x04902e) */
+	PORT_BIT( 0xeb, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	/* Fake IN6 (DIP1) */
+	PORT_START("DSW1")	/* Fake IN6 (DIP1) */
 	PORT_DIPNAME( 0x01, 0x01, "Unused DIP 1-1" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -376,7 +434,7 @@ static INPUT_PORTS_START( shadfrce )
 	PORT_DIPSETTING(    0x40, DEF_STR( On ) )
 	PORT_SERVICE( 0x80, IP_ACTIVE_LOW )
 
-	PORT_START	/* Fake IN7 (DIP2) */
+	PORT_START("DSW2")	/* Fake IN7 (DIP2) */
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Easy ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( Normal ) )
@@ -400,94 +458,6 @@ static INPUT_PORTS_START( shadfrce )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 INPUT_PORTS_END
-#else
-static INPUT_PORTS_START( shadfrce )
-	PORT_START	/* IN0 - $1d0020.w */
-	SHADFRCE_PLAYER_INPUT( 1, IPT_START1 )
-	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_COIN2 )                 /* only in "test mode" ? */
-	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_SERVICE1 )              /* only in "test mode" ? */
-	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_DIPNAME( 0x1000, 0x1000, "Unused DIP 2-7" )
-	PORT_DIPSETTING(      0x1000, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x2000, 0x2000, "Unused DIP 2-8" )
-	PORT_DIPSETTING(      0x2000, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNUSED )
-
-	PORT_START	/* IN1 - $1d0022.w */
-	SHADFRCE_PLAYER_INPUT( 2, IPT_START2 )
-	PORT_DIPNAME( 0x0300, 0x0300, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(      0x0100, DEF_STR( Easy ) )
-	PORT_DIPSETTING(      0x0300, DEF_STR( Normal ) )
-	PORT_DIPSETTING(      0x0200, DEF_STR( Hard ) )              /* "Advanced" */
-	PORT_DIPSETTING(      0x0000, DEF_STR( Hardest ) )           /* "Expert" */
-	PORT_DIPNAME( 0x0c00, 0x0c00, "Stage Clear Energy Regain" )
-	PORT_DIPSETTING(      0x0400, "50%" )
-	PORT_DIPSETTING(      0x0c00, "25%" )
-	PORT_DIPSETTING(      0x0800, "10%" )
-	PORT_DIPSETTING(      0x0000, "0%" )
-	PORT_DIPNAME( 0x1000, 0x1000, "Unused DIP 2-5" )
-	PORT_DIPSETTING(      0x1000, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x2000, 0x2000, "Unused DIP 2-6" )
-	PORT_DIPSETTING(      0x2000, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNUSED )
-
-	PORT_START	/* IN2 - $1d0024.w */
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(1)
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_BUTTON5 ) PORT_PLAYER(1)
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_BUTTON6 ) PORT_PLAYER(1)
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_BUTTON4 ) PORT_PLAYER(2)
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_BUTTON5 ) PORT_PLAYER(2)
-	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_BUTTON6 ) PORT_PLAYER(2)
-	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_DIPNAME( 0x0100, 0x0100, "Unused DIP 1-1" )
-	PORT_DIPSETTING(      0x0100, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0600, 0x0600, DEF_STR( Coinage ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( 3C_1C ) )
-	PORT_DIPSETTING(      0x0200, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING(      0x0600, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING(      0x0400, DEF_STR( 1C_2C ) )
-	PORT_DIPNAME( 0x0800, 0x0800, DEF_STR( Continue_Price ) )
-	PORT_DIPSETTING(      0x0800, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x1000, 0x1000, DEF_STR( Free_Play ) )
-	PORT_DIPSETTING(      0x1000, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x2000, 0x2000, DEF_STR( Flip_Screen ) )
-	PORT_DIPSETTING(      0x2000, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNUSED )
-
-	PORT_START	/* IN3 - $1d0026.w */
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_DIPNAME( 0x0100, 0x0100, DEF_STR( Demo_Sounds ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0100, DEF_STR( On ) )
-	PORT_SERVICE( 0x0200, IP_ACTIVE_LOW )
-	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_VBLANK )                /* guess */
-	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_UNKNOWN )               /* must be ACTIVE_LOW or 'shadfrcj' jumps to the end (code at 0x04902e) */
-	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNUSED )
-INPUT_PORTS_END
-#endif
 
 /* Graphic Decoding */
 
@@ -525,50 +495,36 @@ static const gfx_layout bg16x16x6_layout =
 };
 
 static GFXDECODE_START( shadfrce )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, fg8x8x4_layout,   0x0000, 256 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0, sp16x16x5_layout, 0x1000, 128 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0, bg16x16x6_layout, 0x2000, 128 )
+	GFXDECODE_ENTRY( "gfx1", 0, fg8x8x4_layout,   0x0000, 256 )
+	GFXDECODE_ENTRY( "gfx2", 0, sp16x16x5_layout, 0x1000, 128 )
+	GFXDECODE_ENTRY( "gfx3", 0, bg16x16x6_layout, 0x2000, 128 )
 GFXDECODE_END
 
 /* Machine Driver Bits */
 
-static void irq_handler(int irq)
+static void irq_handler(running_machine *machine, int irq)
 {
-	cpunum_set_input_line(Machine, 1, 0, irq ? ASSERT_LINE : CLEAR_LINE );
+	cpu_set_input_line(machine->cpu[1], 0, irq ? ASSERT_LINE : CLEAR_LINE );
 }
 
-static const struct YM2151interface ym2151_interface =
+static const ym2151_interface ym2151_config =
 {
 	irq_handler
 };
 
-static INTERRUPT_GEN( shadfrce_interrupt ) {
-	if( cpu_getiloops() == 0 )
-		cpunum_set_input_line(machine, 0, 3, HOLD_LINE);
-	else
-		cpunum_set_input_line(machine, 0, 2, HOLD_LINE);
-}
-
-
 static MACHINE_DRIVER_START( shadfrce )
-	MDRV_CPU_ADD(M68000, 28000000/2) /* ? Guess - CPU is rated for 16MHz */
-	MDRV_CPU_PROGRAM_MAP(shadfrce_readmem,shadfrce_writemem)
-	MDRV_CPU_VBLANK_INT(shadfrce_interrupt,2)
+	MDRV_CPU_ADD("main", M68000, CPU_CLOCK) 			/* verified on pcb */
+	MDRV_CPU_PROGRAM_MAP(shadfrce_map,0)
+	MDRV_TIMER_ADD_SCANLINE("scantimer", shadfrce_scanline, "main", 0, 1)
 
-	MDRV_CPU_ADD(Z80, 3579545)
-	/* audio CPU */
-	MDRV_CPU_PROGRAM_MAP(readmem_sound,writemem_sound)
+	MDRV_CPU_ADD("audio", Z80, XTAL_3_579545MHz) 		/* verified on pcb */
+	MDRV_CPU_PROGRAM_MAP(shadfrce_sound_map,0)
 
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
+	MDRV_SCREEN_RAW_PARAMS(PIXEL_CLOCK, 432, 0, 320, 272, 8, 248)	/* HTOTAL and VTOTAL are guessed */
 
 	MDRV_GFXDECODE(shadfrce)
-
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(64*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 40*8-1, 0*8, 32*8-1)
 	MDRV_PALETTE_LENGTH(0x4000)
 
 	MDRV_VIDEO_START(shadfrce)
@@ -578,13 +534,13 @@ static MACHINE_DRIVER_START( shadfrce )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(YM2151, 3579545)
-	MDRV_SOUND_CONFIG(ym2151_interface)
+	MDRV_SOUND_ADD("ym", YM2151, XTAL_3_579545MHz) 		/* verified on pcb */
+	MDRV_SOUND_CONFIG(ym2151_config)
 	MDRV_SOUND_ROUTE(0, "left", 0.50)
 	MDRV_SOUND_ROUTE(1, "right", 0.50)
 
-	MDRV_SOUND_ADD(OKIM6295, 1584000)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high) // clock frequency & pin 7 not verified
+	MDRV_SOUND_ADD("oki", OKIM6295, XTAL_13_4952MHz/8) 	/* verified on pcb */
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) 		/* verified on pcb, pin7 is at 2.4v */
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.50)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.50)
 MACHINE_DRIVER_END
@@ -592,60 +548,60 @@ MACHINE_DRIVER_END
 /* Rom Defs. */
 
 ROM_START( shadfrce )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_REGION( 0x100000, "main", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "32a12-01.34", 0x00001, 0x40000, CRC(04501198) SHA1(50f981c13f9ed19d681d494376018ba86464ea13) )
 	ROM_LOAD16_BYTE( "32a13-01.26", 0x00000, 0x40000, CRC(b8f8a05c) SHA1(bd9d4218a7cf57b56aec1f7e710e02af8471f9d7) )
 	ROM_LOAD16_BYTE( "32a14-0.33",  0x80001, 0x40000, CRC(08279be9) SHA1(1833526b23feddb58b21874070ad2bf3b6be8dca) )
 	ROM_LOAD16_BYTE( "32a15-0.14",  0x80000, 0x40000, CRC(bfcadfea) SHA1(1caa9fc30d8622ce4c7221039c446e99cc8f5346) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* Z80 Code */
+	ROM_REGION( 0x10000, "audio", 0 ) /* Z80 Code */
 	ROM_LOAD( "32j10-0.42",  0x00000, 0x10000, CRC(65daf475) SHA1(7144332b2d17af8645e22e1926b33113db0d20e2) )
 
-	ROM_REGION( 0x020000, REGION_GFX1, ROMREGION_DISPOSE ) /* Chars */
+	ROM_REGION( 0x020000, "gfx1", ROMREGION_DISPOSE ) /* Chars */
 	ROM_LOAD( "32a11-0.55",  0x00000, 0x20000, CRC(cfaf5e77) SHA1(eab76e085f695c74cc868aaf95f04ff2acf66ee9) )
 
-	ROM_REGION( 0xa00000, REGION_GFX2, ROMREGION_DISPOSE ) /* Sprite Tiles */
+	ROM_REGION( 0xa00000, "gfx2", ROMREGION_DISPOSE ) /* Sprite Tiles */
 	ROM_LOAD( "32j4-0.12",  0x000000, 0x200000, CRC(1ebea5b6) SHA1(35bd49dda9ad75326d45ffb10c87d83fc4f1b7a8) )
 	ROM_LOAD( "32j5-0.13",  0x200000, 0x200000, CRC(600026b5) SHA1(5641246300d7e20dcff1eae004647faaee6cd1c6) )
 	ROM_LOAD( "32j6-0.24",  0x400000, 0x200000, CRC(6cde8ebe) SHA1(750933798235951fe24b2e667c33f692612c0aa0) )
 	ROM_LOAD( "32j7-0.25",  0x600000, 0x200000, CRC(bcb37922) SHA1(f3eee73c8b9f4873a7f1cc42e334e7502eaee3c8) )
 	ROM_LOAD( "32j8-0.32",  0x800000, 0x200000, CRC(201bebf6) SHA1(c89d2895ea5b19daea1f88542419f4e10f437c73) )
 
-	ROM_REGION( 0x300000, REGION_GFX3, ROMREGION_DISPOSE ) /* BG Tiles */
+	ROM_REGION( 0x300000, "gfx3", ROMREGION_DISPOSE ) /* BG Tiles */
 	ROM_LOAD( "32j1-0.4",  0x000000, 0x100000, CRC(f1cca740) SHA1(339079b95ca137e66b4f032ad67a0adf58cca100) )
 	ROM_LOAD( "32j2-0.5",  0x100000, 0x100000, CRC(5fac3e01) SHA1(20c30f4c76e303285ae37e596afe86aa4812c3b9) )
 	ROM_LOAD( "32j3-0.6",  0x200000, 0x100000, CRC(d297925e) SHA1(5bc4d37bf0dc54114884c816b94a64ef1ccfeda5) )
 
-	ROM_REGION( 0x080000, REGION_SOUND1, 0 ) /* Samples */
+	ROM_REGION( 0x080000, "oki", 0 ) /* Samples */
 	ROM_LOAD( "32j9-0.76",  0x000000, 0x080000, CRC(16001e81) SHA1(67928d2024f963aee91f1498b6f4c76101d2f3b8) )
 ROM_END
 
 ROM_START( shadfrcj )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_REGION( 0x100000, "main", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "32j12-01.ic34", 0x00001, 0x40000, CRC(38fdbe1d) SHA1(476d8ef2c0d2a8c568ce44631f93f8c730f91b08) )
 	ROM_LOAD16_BYTE( "32j13-01.ic26", 0x00000, 0x40000, CRC(6e1df6f1) SHA1(c165553fe967b437413dd7ddc87a267548dd0ca9) )
 	ROM_LOAD16_BYTE( "32j14-01.ic33", 0x80001, 0x40000, CRC(89e3fb60) SHA1(90de38558d63215a0079079030e8b1097599c9e5) )
 	ROM_LOAD16_BYTE( "32j15-01.ic14", 0x80000, 0x40000, CRC(3dc3a84a) SHA1(166ad91b93192d94e3f6d2fe6dde02f59d334f75) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* Z80 Code */
+	ROM_REGION( 0x10000, "audio", 0 ) /* Z80 Code */
 	ROM_LOAD( "32j10-0.42",  0x00000, 0x10000, CRC(65daf475) SHA1(7144332b2d17af8645e22e1926b33113db0d20e2) )
 
-	ROM_REGION( 0x020000, REGION_GFX1, ROMREGION_DISPOSE ) /* Chars */
+	ROM_REGION( 0x020000, "gfx1", ROMREGION_DISPOSE ) /* Chars */
 	ROM_LOAD( "32j11-0.ic55",  0x00000, 0x20000, CRC(7252d993) SHA1(43f7de381841039aa290486aafb98e2cf3b8579b) )
 
-	ROM_REGION( 0xa00000, REGION_GFX2, ROMREGION_DISPOSE ) /* Sprite Tiles */
+	ROM_REGION( 0xa00000, "gfx2", ROMREGION_DISPOSE ) /* Sprite Tiles */
 	ROM_LOAD( "32j4-0.12",  0x000000, 0x200000, CRC(1ebea5b6) SHA1(35bd49dda9ad75326d45ffb10c87d83fc4f1b7a8) )
 	ROM_LOAD( "32j5-0.13",  0x200000, 0x200000, CRC(600026b5) SHA1(5641246300d7e20dcff1eae004647faaee6cd1c6) )
 	ROM_LOAD( "32j6-0.24",  0x400000, 0x200000, CRC(6cde8ebe) SHA1(750933798235951fe24b2e667c33f692612c0aa0) )
 	ROM_LOAD( "32j7-0.25",  0x600000, 0x200000, CRC(bcb37922) SHA1(f3eee73c8b9f4873a7f1cc42e334e7502eaee3c8) )
 	ROM_LOAD( "32j8-0.32",  0x800000, 0x200000, CRC(201bebf6) SHA1(c89d2895ea5b19daea1f88542419f4e10f437c73) )
 
-	ROM_REGION( 0x300000, REGION_GFX3, ROMREGION_DISPOSE ) /* BG Tiles */
+	ROM_REGION( 0x300000, "gfx3", ROMREGION_DISPOSE ) /* BG Tiles */
 	ROM_LOAD( "32j1-0.4",  0x000000, 0x100000, CRC(f1cca740) SHA1(339079b95ca137e66b4f032ad67a0adf58cca100) )
 	ROM_LOAD( "32j2-0.5",  0x100000, 0x100000, CRC(5fac3e01) SHA1(20c30f4c76e303285ae37e596afe86aa4812c3b9) )
 	ROM_LOAD( "32j3-0.6",  0x200000, 0x100000, CRC(d297925e) SHA1(5bc4d37bf0dc54114884c816b94a64ef1ccfeda5) )
 
-	ROM_REGION( 0x080000, REGION_SOUND1, 0 ) /* Samples */
+	ROM_REGION( 0x080000, "oki", 0 ) /* Samples */
 	ROM_LOAD( "32j9-0.76",  0x000000, 0x080000, CRC(16001e81) SHA1(67928d2024f963aee91f1498b6f4c76101d2f3b8) )
 ROM_END
 
