@@ -20,7 +20,7 @@ blocken:
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/m68000/m68000.h"
 #include "cpu/z80/z80.h"
 #include "sound/ay8910.h"
 #include "sound/okim6295.h"
@@ -56,19 +56,19 @@ static READ16_HANDLER( shangha3_prot_r )
 	static int count;
 	static const int result[] = { 0x0,0x1,0x3,0x7,0xf,0xe,0xc,0x8,0x0};
 
-logerror("PC %04x: read 20004e\n",activecpu_get_pc());
+logerror("PC %04x: read 20004e\n",cpu_get_pc(space->cpu));
 
 	return result[count++ % 9];
 }
 static WRITE16_HANDLER( shangha3_prot_w )
 {
-logerror("PC %04x: write %02x to 20004e\n",activecpu_get_pc(),data);
+logerror("PC %04x: write %02x to 20004e\n",cpu_get_pc(space->cpu),data);
 }
 
 
 static READ16_HANDLER( heberpop_gfxrom_r )
 {
-	UINT8 *ROM = memory_region(REGION_GFX1);
+	UINT8 *ROM = memory_region(space->machine, "gfx1");
 
 	return ROM[2*offset] | (ROM[2*offset+1] << 8);
 }
@@ -77,7 +77,7 @@ static READ16_HANDLER( heberpop_gfxrom_r )
 
 static WRITE16_HANDLER( shangha3_coinctrl_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		coin_lockout_w(0,~data & 0x0400);
 		coin_lockout_w(1,~data & 0x0400);
@@ -88,10 +88,24 @@ static WRITE16_HANDLER( shangha3_coinctrl_w )
 
 static WRITE16_HANDLER( heberpop_coinctrl_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		/* the sound ROM bank is selected by the main CPU! */
-		OKIM6295_set_bank_base(0,(data & 0x08) ? 0x40000 : 0x00000);
+		okim6295_set_bank_base(0,(data & 0x08) ? 0x40000 : 0x00000);
+
+		coin_lockout_w(0,~data & 0x04);
+		coin_lockout_w(1,~data & 0x04);
+		coin_counter_w(0,data & 0x01);
+		coin_counter_w(1,data & 0x02);
+	}
+}
+
+static WRITE16_HANDLER( blocken_coinctrl_w )
+{
+	if (ACCESSING_BITS_0_7)
+	{
+		/* the sound ROM bank is selected by the main CPU! */
+		okim6295_set_bank_base(0, ((data >> 4) & 3) * 0x40000);
 
 		coin_lockout_w(0,~data & 0x04);
 		coin_lockout_w(1,~data & 0x04);
@@ -103,117 +117,111 @@ static WRITE16_HANDLER( heberpop_coinctrl_w )
 
 static WRITE16_HANDLER( heberpop_sound_command_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
-		soundlatch_w(0,data & 0xff);
-		cpunum_set_input_line_and_vector(Machine, 1,0,HOLD_LINE,0xff);	/* RST 38h */
+		soundlatch_w(space,0,data & 0xff);
+		cpu_set_input_line_and_vector(space->machine->cpu[1],0,HOLD_LINE,0xff);	/* RST 38h */
 	}
 }
 
 
 
 static ADDRESS_MAP_START( shangha3_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x100000, 0x100fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x200000, 0x200001) AM_READ(input_port_0_word_r)
-	AM_RANGE(0x200002, 0x200003) AM_READ(input_port_1_word_r)
-	AM_RANGE(0x20001e, 0x20001f) AM_READ(AY8910_read_port_0_lsb_r)
+	AM_RANGE(0x000000, 0x07ffff) AM_READ(SMH_ROM)
+	AM_RANGE(0x100000, 0x100fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x200000, 0x200001) AM_READ_PORT("INPUTS")
+	AM_RANGE(0x200002, 0x200003) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0x20001e, 0x20001f) AM_READ(ay8910_read_port_0_lsb_r)
 	AM_RANGE(0x20004e, 0x20004f) AM_READ(shangha3_prot_r)
-	AM_RANGE(0x20006e, 0x20006f) AM_READ(OKIM6295_status_0_lsb_r)
-	AM_RANGE(0x300000, 0x30ffff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x20006e, 0x20006f) AM_READ(okim6295_status_0_lsb_r)
+	AM_RANGE(0x300000, 0x30ffff) AM_READ(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( shangha3_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(MWA16_ROM)
+	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(SMH_ROM)
 	AM_RANGE(0x100000, 0x100fff) AM_WRITE(paletteram16_RRRRRGGGGGBBBBBx_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x200008, 0x200009) AM_WRITE(shangha3_blitter_go_w)
-	AM_RANGE(0x20000a, 0x20000b) AM_WRITE(MWA16_NOP)	/* irq ack? */
+	AM_RANGE(0x20000a, 0x20000b) AM_WRITE(SMH_NOP)	/* irq ack? */
 	AM_RANGE(0x20000c, 0x20000d) AM_WRITE(shangha3_coinctrl_w)
-	AM_RANGE(0x20002e, 0x20002f) AM_WRITE(AY8910_write_port_0_lsb_w)
-	AM_RANGE(0x20003e, 0x20003f) AM_WRITE(AY8910_control_port_0_lsb_w)
+	AM_RANGE(0x20002e, 0x20002f) AM_WRITE(ay8910_write_port_0_lsb_w)
+	AM_RANGE(0x20003e, 0x20003f) AM_WRITE(ay8910_control_port_0_lsb_w)
 	AM_RANGE(0x20004e, 0x20004f) AM_WRITE(shangha3_prot_w)
-	AM_RANGE(0x20006e, 0x20006f) AM_WRITE(OKIM6295_data_0_lsb_w)
-	AM_RANGE(0x300000, 0x30ffff) AM_WRITE(MWA16_RAM) AM_BASE(&shangha3_ram) AM_SIZE(&shangha3_ram_size)	/* gfx & work ram */
+	AM_RANGE(0x20006e, 0x20006f) AM_WRITE(okim6295_data_0_lsb_w)
+	AM_RANGE(0x300000, 0x30ffff) AM_WRITE(SMH_RAM) AM_BASE(&shangha3_ram) AM_SIZE(&shangha3_ram_size)	/* gfx & work ram */
 	AM_RANGE(0x340000, 0x340001) AM_WRITE(shangha3_flipscreen_w)
 	AM_RANGE(0x360000, 0x360001) AM_WRITE(shangha3_gfxlist_addr_w)
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( heberpop_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x100000, 0x100fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x200000, 0x200001) AM_READ(input_port_0_word_r)
-	AM_RANGE(0x200002, 0x200003) AM_READ(input_port_1_word_r)
-	AM_RANGE(0x200004, 0x200005) AM_READ(input_port_2_word_r)
-	AM_RANGE(0x300000, 0x30ffff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM)
+	AM_RANGE(0x100000, 0x100fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x200000, 0x200001) AM_READ_PORT("INPUTS")
+	AM_RANGE(0x200002, 0x200003) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0x200004, 0x200005) AM_READ_PORT("DSW")
+	AM_RANGE(0x300000, 0x30ffff) AM_READ(SMH_RAM)
 	AM_RANGE(0x800000, 0xb7ffff) AM_READ(heberpop_gfxrom_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( heberpop_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(MWA16_ROM)
+	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(SMH_ROM)
 	AM_RANGE(0x100000, 0x100fff) AM_WRITE(paletteram16_RRRRRGGGGGBBBBBx_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x200008, 0x200009) AM_WRITE(shangha3_blitter_go_w)
-	AM_RANGE(0x20000a, 0x20000b) AM_WRITE(MWA16_NOP)	/* irq ack? */
+	AM_RANGE(0x20000a, 0x20000b) AM_WRITE(SMH_NOP)	/* irq ack? */
 	AM_RANGE(0x20000c, 0x20000d) AM_WRITE(heberpop_coinctrl_w)
 	AM_RANGE(0x20000e, 0x20000f) AM_WRITE(heberpop_sound_command_w)
-	AM_RANGE(0x300000, 0x30ffff) AM_WRITE(MWA16_RAM) AM_BASE(&shangha3_ram) AM_SIZE(&shangha3_ram_size)	/* gfx & work ram */
+	AM_RANGE(0x300000, 0x30ffff) AM_WRITE(SMH_RAM) AM_BASE(&shangha3_ram) AM_SIZE(&shangha3_ram_size)	/* gfx & work ram */
 	AM_RANGE(0x340000, 0x340001) AM_WRITE(shangha3_flipscreen_w)
 	AM_RANGE(0x360000, 0x360001) AM_WRITE(shangha3_gfxlist_addr_w)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( blocken_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x100000, 0x100001) AM_READ(input_port_0_word_r)
-	AM_RANGE(0x100002, 0x100003) AM_READ(input_port_1_word_r)
-	AM_RANGE(0x100004, 0x100005) AM_READ(input_port_2_word_r)
-	AM_RANGE(0x200000, 0x200fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x300000, 0x30ffff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x000000, 0x0fffff) AM_READ(SMH_ROM)
+	AM_RANGE(0x100000, 0x100001) AM_READ_PORT("INPUTS")
+	AM_RANGE(0x100002, 0x100003) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0x100004, 0x100005) AM_READ_PORT("DSW")
+	AM_RANGE(0x200000, 0x200fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x300000, 0x30ffff) AM_READ(SMH_RAM)
 	AM_RANGE(0x800000, 0xb7ffff) AM_READ(heberpop_gfxrom_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( blocken_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(MWA16_ROM)
+	AM_RANGE(0x000000, 0x0fffff) AM_WRITE(SMH_ROM)
 	AM_RANGE(0x100008, 0x100009) AM_WRITE(shangha3_blitter_go_w)
-	AM_RANGE(0x10000a, 0x10000b) AM_WRITE(MWA16_NOP)	/* irq ack? */
-	AM_RANGE(0x10000c, 0x10000d) AM_WRITE(heberpop_coinctrl_w)
+	AM_RANGE(0x10000a, 0x10000b) AM_WRITE(SMH_NOP)	/* irq ack? */
+	AM_RANGE(0x10000c, 0x10000d) AM_WRITE(blocken_coinctrl_w)
 	AM_RANGE(0x10000e, 0x10000f) AM_WRITE(heberpop_sound_command_w)
 	AM_RANGE(0x200000, 0x200fff) AM_WRITE(paletteram16_RRRRRGGGGGBBBBBx_word_w) AM_BASE(&paletteram16)
-	AM_RANGE(0x300000, 0x30ffff) AM_WRITE(MWA16_RAM) AM_BASE(&shangha3_ram) AM_SIZE(&shangha3_ram_size)	/* gfx & work ram */
+	AM_RANGE(0x300000, 0x30ffff) AM_WRITE(SMH_RAM) AM_BASE(&shangha3_ram) AM_SIZE(&shangha3_ram_size)	/* gfx & work ram */
 	AM_RANGE(0x340000, 0x340001) AM_WRITE(shangha3_flipscreen_w)
 	AM_RANGE(0x360000, 0x360001) AM_WRITE(shangha3_gfxlist_addr_w)
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( heberpop_sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xf7ff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xf800, 0xffff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0000, 0xf7ff) AM_READ(SMH_ROM)
+	AM_RANGE(0xf800, 0xffff) AM_READ(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( heberpop_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xf7ff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xf800, 0xffff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x0000, 0xf7ff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0xf800, 0xffff) AM_WRITE(SMH_RAM)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( heberpop_sound_readport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x00, 0x00) AM_READ(YM3438_status_port_0_A_r)
-	AM_RANGE(0x80, 0x80) AM_READ(OKIM6295_status_0_r)
+
+static ADDRESS_MAP_START( heberpop_sound_io_map, ADDRESS_SPACE_IO, 8 )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x00, 0x00) AM_READWRITE(ym3438_status_port_0_a_r, ym3438_control_port_0_a_w)
+	AM_RANGE(0x01, 0x01) AM_WRITE(ym3438_data_port_0_a_w)
+	AM_RANGE(0x02, 0x02) AM_WRITE(ym3438_control_port_0_b_w)
+	AM_RANGE(0x03, 0x03) AM_WRITE(ym3438_data_port_0_b_w)
+	AM_RANGE(0x80, 0x80) AM_READWRITE(okim6295_status_0_r, okim6295_data_0_w)
 	AM_RANGE(0xc0, 0xc0) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( heberpop_sound_writeport, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x00, 0x00) AM_WRITE(YM3438_control_port_0_A_w)
-	AM_RANGE(0x01, 0x01) AM_WRITE(YM3438_data_port_0_A_w)
-	AM_RANGE(0x02, 0x02) AM_WRITE(YM3438_control_port_0_B_w)
-	AM_RANGE(0x03, 0x03) AM_WRITE(YM3438_data_port_0_B_w)
-	AM_RANGE(0x80, 0x80) AM_WRITE(OKIM6295_data_0_w)
-ADDRESS_MAP_END
-
-
 
 static INPUT_PORTS_START( shangha3 )
-	PORT_START_TAG("IN0")
+	PORT_START("INPUTS")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
@@ -231,7 +239,7 @@ static INPUT_PORTS_START( shangha3 )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("IN1")
+	PORT_START("SYSTEM")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_SERVICE1 )
@@ -241,7 +249,7 @@ static INPUT_PORTS_START( shangha3 )
 	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_VBLANK )
 
-	PORT_START_TAG("DSW1")
+	PORT_START("DSW1")
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Easy ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( Normal ) )
@@ -264,7 +272,7 @@ static INPUT_PORTS_START( shangha3 )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START_TAG("DSW2")
+	PORT_START("DSW2")
 	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 5C_1C ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( 4C_1C ) )
@@ -292,7 +300,7 @@ static INPUT_PORTS_START( shangha3 )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( heberpop )
-	PORT_START_TAG("IN0")
+	PORT_START("INPUTS")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
@@ -310,7 +318,7 @@ static INPUT_PORTS_START( heberpop )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_VBLANK )	/* vblank?? has to toggle */
 
-	PORT_START_TAG("IN1")
+	PORT_START("SYSTEM")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_SERVICE1 )
@@ -320,7 +328,7 @@ static INPUT_PORTS_START( heberpop )
 	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("DSW")
+	PORT_START("DSW")
 	PORT_DIPNAME( 0x0003, 0x0003, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(      0x0002, DEF_STR( Very_Easy) )
 	PORT_DIPSETTING(      0x0001, DEF_STR( Easy ) )
@@ -371,7 +379,7 @@ static INPUT_PORTS_START( heberpop )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( blocken )
-	PORT_START_TAG("IN0")
+	PORT_START("INPUTS")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
@@ -389,7 +397,7 @@ static INPUT_PORTS_START( blocken )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_VBLANK )	/* vblank?? has to toggle */
 
-	PORT_START_TAG("IN1")
+	PORT_START("SYSTEM")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_SERVICE1 )
@@ -399,7 +407,7 @@ static INPUT_PORTS_START( blocken )
 	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("DSW")
+	PORT_START("DSW")
 	PORT_SERVICE( 0x0001, IP_ACTIVE_LOW )
 	PORT_DIPNAME( 0x0006, 0x0006, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(      0x0004, DEF_STR( Easy ) )
@@ -472,23 +480,27 @@ static const gfx_layout charlayout =
 };
 
 static GFXDECODE_START( shangha3 )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, charlayout, 0, 128 )
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout, 0, 128 )
 GFXDECODE_END
 
 
 
-static const struct AY8910interface ay8910_interface =
+static const ay8910_interface ay8910_config =
 {
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
 	input_port_3_r,
-	input_port_2_r
+	input_port_2_r,
+	NULL,
+	NULL
 };
 
-static void irqhandler(int linestate)
+static void irqhandler(running_machine *machine, int linestate)
 {
-	cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, linestate);
+	cpu_set_input_line(machine->cpu[1], INPUT_LINE_NMI, linestate);
 }
 
-static const struct YM3438interface ym3438_interface =
+static const ym3438_interface ym3438_config =
 {
 	irqhandler
 };
@@ -497,18 +509,20 @@ static const struct YM3438interface ym3438_interface =
 static MACHINE_DRIVER_START( shangha3 )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000, 8000000)
+	MDRV_CPU_ADD("main", M68000, 8000000)
 	MDRV_CPU_PROGRAM_MAP(shangha3_readmem,shangha3_writemem)
-	MDRV_CPU_VBLANK_INT(irq4_line_hold,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", irq4_line_hold)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS )
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS )
+
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(24*16, 16*16)
 	MDRV_SCREEN_VISIBLE_AREA(0*16, 24*16-1, 1*16, 15*16-1)
+
 	MDRV_GFXDECODE(shangha3)
 	MDRV_PALETTE_LENGTH(2048)
 
@@ -518,12 +532,12 @@ static MACHINE_DRIVER_START( shangha3 )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, 1500000)
-	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ADD("ay", AY8910, 1500000)
+	MDRV_SOUND_CONFIG(ay8910_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.30)
 
-	MDRV_SOUND_ADD(OKIM6295, 1056000)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high) // clock frequency & pin 7 not verified
+	MDRV_SOUND_ADD("oki", OKIM6295, 1056000)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // clock frequency & pin 7 not verified
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -531,22 +545,24 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( heberpop )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000, 8000000)
+	MDRV_CPU_ADD("main", M68000, 8000000)
 	MDRV_CPU_PROGRAM_MAP(heberpop_readmem,heberpop_writemem)
-	MDRV_CPU_VBLANK_INT(irq4_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq4_line_hold)
 
-	MDRV_CPU_ADD(Z80, 6000000)	/* 6 MHz ??? */
+	MDRV_CPU_ADD("audio", Z80, 6000000)	/* 6 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(heberpop_sound_readmem,heberpop_sound_writemem)
-	MDRV_CPU_IO_MAP(heberpop_sound_readport,heberpop_sound_writeport)
-								/* NMI triggered by YM3438 */
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_CPU_IO_MAP(heberpop_sound_io_map,0)	/* NMI triggered by YM3438 */
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS )
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
+
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(24*16, 16*16)
 	MDRV_SCREEN_VISIBLE_AREA(0*16, 24*16-1, 1*16, 15*16-1)
+
 	MDRV_GFXDECODE(shangha3)
 	MDRV_PALETTE_LENGTH(2048)
 
@@ -556,13 +572,13 @@ static MACHINE_DRIVER_START( heberpop )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM3438, 8000000)
-	MDRV_SOUND_CONFIG(ym3438_interface)
+	MDRV_SOUND_ADD("ym", YM3438, 8000000)
+	MDRV_SOUND_CONFIG(ym3438_config)
 	MDRV_SOUND_ROUTE(0, "mono", 0.40)
 	MDRV_SOUND_ROUTE(1, "mono", 0.40)
 
-	MDRV_SOUND_ADD(OKIM6295, 1056000)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high) // clock frequency & pin 7 not verified
+	MDRV_SOUND_ADD("oki", OKIM6295, 1056000)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // clock frequency & pin 7 not verified
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -570,22 +586,24 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( blocken )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000, 8000000)
+	MDRV_CPU_ADD("main", M68000, 8000000)
 	MDRV_CPU_PROGRAM_MAP(blocken_readmem,blocken_writemem)
-	MDRV_CPU_VBLANK_INT(irq4_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq4_line_hold)
 
-	MDRV_CPU_ADD(Z80, 6000000)	/* 6 MHz ??? */
+	MDRV_CPU_ADD("audio", Z80, 6000000)	/* 6 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(heberpop_sound_readmem,heberpop_sound_writemem)
-	MDRV_CPU_IO_MAP(heberpop_sound_readport,heberpop_sound_writeport)
-								/* NMI triggered by YM3438 */
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	MDRV_CPU_IO_MAP(heberpop_sound_io_map,0)	/* NMI triggered by YM3438 */
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_HAS_SHADOWS)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_HAS_SHADOWS)
+
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(24*16, 16*16)
 	MDRV_SCREEN_VISIBLE_AREA(0*16, 24*16-1, 1*16, 15*16-1)
+
 	MDRV_GFXDECODE(shangha3)
 	MDRV_PALETTE_LENGTH(2048)
 
@@ -595,13 +613,13 @@ static MACHINE_DRIVER_START( blocken )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM3438, 8000000)
-	MDRV_SOUND_CONFIG(ym3438_interface)
+	MDRV_SOUND_ADD("ym", YM3438, 8000000)
+	MDRV_SOUND_CONFIG(ym3438_config)
 	MDRV_SOUND_ROUTE(0, "mono", 0.40)
 	MDRV_SOUND_ROUTE(1, "mono", 0.40)
 
-	MDRV_SOUND_ADD(OKIM6295, 1056000)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high) // clock frequency & pin 7 not verified
+	MDRV_SOUND_ADD("oki", OKIM6295, 1056000)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // clock frequency & pin 7 not verified
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -614,26 +632,26 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( shangha3 )
-	ROM_REGION( 0x80000, REGION_CPU1, 0 )
+	ROM_REGION( 0x80000, "main", 0 )
 	ROM_LOAD16_BYTE( "s3j_ic3.v11",  0x0000, 0x40000, CRC(e98ce9c8) SHA1(359e117aebb644d7b235add7e71ed6891243d451) )
 	ROM_LOAD16_BYTE( "s3j_ic2.v11",  0x0001, 0x40000, CRC(09174620) SHA1(1d1639c07895f715facfe153fbdb6ae0f3cdd876) )
 
-	ROM_REGION( 0x200000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x200000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "s3j_ic43.chr", 0x0000, 0x200000, CRC(2dbf9d17) SHA1(dd94ddc4bb02ab544aa3f89b614afc46678cc48d) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )	/* samples for M6295 */
+	ROM_REGION( 0x40000, "oki", 0 )	/* samples for M6295 */
 	ROM_LOAD( "s3j_ic75.v10", 0x0000, 0x40000, CRC(f0cdc86a) SHA1(b1017a9841a56e0f5d2714f550f64ed1f4e238e6) )
 ROM_END
 
 ROM_START( heberpop )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, "main", 0 )
 	ROM_LOAD16_BYTE( "hbpic31.bin",  0x0000, 0x80000, CRC(c430d264) SHA1(4be12b1fa90da09047db3a31171ffda8ab8bd851) )
 	ROM_LOAD16_BYTE( "hbpic32.bin",  0x0001, 0x80000, CRC(bfa555a8) SHA1(754f581554022b98ba8e78ee96f846faa2cedc69) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "hbpic34.bin",  0x0000, 0x10000, CRC(0cf056c6) SHA1(9992cd3879d9a57fcb784fc1e11d6b6d87e5a366) )
 
-	ROM_REGION( 0x380000, REGION_GFX1, 0 )	/* don't dispose, read during tests */
+	ROM_REGION( 0x380000, "gfx1", 0 )	/* don't dispose, read during tests */
 	ROM_LOAD( "hbpic98.bin",  0x000000, 0x80000, CRC(a599100a) SHA1(f2e517256a42b3fa4a047bbe742d714f568cc117) )
 	ROM_LOAD( "hbpic99.bin",  0x080000, 0x80000, CRC(fb8bb12f) SHA1(78c1fec1371d312e113d92803dd59acc36604989) )
 	ROM_LOAD( "hbpic100.bin", 0x100000, 0x80000, CRC(05a0f765) SHA1(4f44cf367c3697eb6c245297c9d05160d7d94e24) )
@@ -642,27 +660,39 @@ ROM_START( heberpop )
 	ROM_LOAD( "hbpic103.bin", 0x280000, 0x80000, CRC(efa0e745) SHA1(fc1d52d35b3c902d8b25403b0e13f86a04039bc4) )
 	ROM_LOAD( "hbpic104.bin", 0x300000, 0x80000, CRC(bb896bbb) SHA1(4311876628beb82cbacdab4d055c3738e74241b0) )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )	/* samples for M6295 */
+	ROM_REGION( 0x80000, "oki", 0 )	/* samples for M6295 */
 	ROM_LOAD( "hbpic53.bin",  0x0000, 0x80000, CRC(a4483aa0) SHA1(be301d8ac6d69f5c3fdbcb85bd557090e46da1ff) )
 ROM_END
 
 ROM_START( blocken )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 )
+	ROM_REGION( 0x100000, "main", 0 )
 	ROM_LOAD16_BYTE( "ic31j.bin",    0x0000, 0x20000, CRC(ec8de2a3) SHA1(09a6b8c1b656b17ab3d1fc057902487e4f94cf02) )
 	ROM_LOAD16_BYTE( "ic32j.bin",    0x0001, 0x20000, CRC(79b96240) SHA1(c1246bd4b91fa45c581a8fdf90cc6beb85adf8ec) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "ic34.bin",     0x0000, 0x10000, CRC(23e446ff) SHA1(82c03b45b337696b0f8293c446544d7ee080d415) )
 
-	ROM_REGION( 0x380000, REGION_GFX1, 0 )	/* don't dispose, read during tests */
+	ROM_REGION( 0x380000, "gfx1", 0 )	/* don't dispose, read during tests */
 	ROM_LOAD( "ic98j.bin",    0x000000, 0x80000, CRC(35dda273) SHA1(95850d12ca1557c14bc471ddf925aaf423313ff0) )
 	ROM_LOAD( "ic99j.bin",    0x080000, 0x80000, CRC(ce43762b) SHA1(e1c51ea0b54b5febdee127619e15f1cda650cb4c) )
 	/* 100000-1fffff empty */
 	ROM_LOAD( "ic100j.bin",   0x200000, 0x80000, CRC(a34786fd) SHA1(7d4879cbaa055c2ddbe6d20dd946bf0e3e069d4d) )
 	/* 280000-37ffff empty */
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )	/* samples for M6295 */
-	ROM_LOAD( "ic53.bin",     0x0000, 0x80000, CRC(86108c56) SHA1(aa405fa2eec5cc178ef6226f229a12dac09504f0) )
+	ROM_REGION( 0x80000, "samples", 0 )	/* samples for M6295 */
+ 	ROM_LOAD( "ic53.bin",     0x0000, 0x80000, CRC(86108c56) SHA1(aa405fa2eec5cc178ef6226f229a12dac09504f0) )
+
+	ROM_REGION( 0x100000, "oki", 0 )
+	/* $00000-$20000 stays the same in all sound banks, */
+	/* the second half of the bank is what gets switched */
+	ROM_COPY( "samples", 0x000000, 0x000000, 0x020000)
+	ROM_COPY( "samples", 0x000000, 0x020000, 0x020000)
+	ROM_COPY( "samples", 0x000000, 0x040000, 0x020000)
+	ROM_COPY( "samples", 0x020000, 0x060000, 0x020000)
+	ROM_COPY( "samples", 0x000000, 0x080000, 0x020000)
+	ROM_COPY( "samples", 0x040000, 0x0a0000, 0x020000)
+	ROM_COPY( "samples", 0x000000, 0x0c0000, 0x020000)
+	ROM_COPY( "samples", 0x060000, 0x0e0000, 0x020000)
 ROM_END
 
 
@@ -679,3 +709,4 @@ static DRIVER_INIT( heberpop )
 GAME( 1993, shangha3, 0, shangha3, shangha3, shangha3, ROT0, "Sunsoft", "Shanghai III (Japan)", 0 )
 GAME( 1994, heberpop, 0, heberpop, heberpop, heberpop, ROT0, "Sunsoft / Atlus", "Hebereke no Popoon (Japan)", 0 )
 GAME( 1994, blocken,  0, blocken,  blocken,  heberpop, ROT0, "KID / Visco", "Blocken (Japan)", 0 )
+
