@@ -1,5 +1,5 @@
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/m68000/m68000.h"
 #include "sound/2151intf.h"
 #include "sound/okim6295.h"
 
@@ -142,93 +142,81 @@ VIDEO_UPDATE(silkroad);
 static WRITE32_HANDLER( paletteram32_xRRRRRGGGGGBBBBB_dword_w )
 {
 	COMBINE_DATA(&paletteram32[offset]);
-	palette_set_color_rgb(Machine,offset,pal5bit(paletteram32[offset] >> (10+16)),pal5bit(paletteram32[offset] >> (5+16)),pal5bit(paletteram32[offset] >> (0+16)));
-}
-
-/* player inputs */
-static READ32_HANDLER(io32_r)
-{
-	return ((readinputport(0) << 16) |  (readinputport(1) << 0));
-}
-
-/* dipswitches */
-static READ32_HANDLER(io32_1_r)
-{
-	return readinputport(2)<<16;
+	palette_set_color_rgb(space->machine,offset,pal5bit(paletteram32[offset] >> (10+16)),pal5bit(paletteram32[offset] >> (5+16)),pal5bit(paletteram32[offset] >> (0+16)));
 }
 
 /* sound I/O */
 
 static READ32_HANDLER(silk_6295_0_r)
 {
-	return OKIM6295_status_0_r(0)<<16;
+	return okim6295_status_0_r(space, 0)<<16;
 }
 
 static WRITE32_HANDLER(silk_6295_0_w)
 {
-	if (!(mem_mask & 0x00ff0000))
+	if (ACCESSING_BITS_16_23)
 	{
 		logerror("OKI0: write %x mem_mask %8x\n", data>>16, mem_mask);
-		OKIM6295_data_0_w(0, (data>>16) & 0xff);
+		okim6295_data_0_w(space, 0, (data>>16) & 0xff);
 	}
 }
 
 static READ32_HANDLER(silk_6295_1_r)
 {
-	return OKIM6295_status_1_r(0)<<16;
+	return okim6295_status_1_r(space, 0)<<16;
 }
 
 static WRITE32_HANDLER(silk_6295_1_w)
 {
-	if (!(mem_mask & 0x00ff0000))
+	if (ACCESSING_BITS_16_23)
 	{
 		logerror("OKI1: write %x mem_mask %8x\n", data>>16, mem_mask);
-		OKIM6295_data_1_w(0, (data>>16) & 0xff);
+		okim6295_data_1_w(space, 0, (data>>16) & 0xff);
 	}
 }
 
 static READ32_HANDLER(silk_ym_r)
 {
-	return YM2151_status_port_0_r(0)<<16;
+	return ym2151_status_port_0_r(space, 0)<<16;
 }
 
 static WRITE32_HANDLER(silk_ym_regport_w)
 {
-	if (!(mem_mask & 0x00ff0000))
+	if (ACCESSING_BITS_16_23)
 	{
-		YM2151_register_port_0_w(0, (data>>16) & 0xff);
+		ym2151_register_port_0_w(space, 0, (data>>16) & 0xff);
 	}
 }
 
 static WRITE32_HANDLER(silk_ym_dataport_w)
 {
-	if (!(mem_mask & 0x00ff0000))
+	if (ACCESSING_BITS_16_23)
 	{
-		YM2151_data_port_0_w(0, (data>>16) & 0xff);
+		ym2151_data_port_0_w(space, 0, (data>>16) & 0xff);
 	}
 }
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x1fffff) AM_READ(MRA32_ROM)
-	AM_RANGE(0x40c000, 0x40cfff) AM_READ(MRA32_RAM)
-	AM_RANGE(0x600000, 0x603fff) AM_READ(MRA32_RAM)
+	AM_RANGE(0x000000, 0x1fffff) AM_READ(SMH_ROM)
+	AM_RANGE(0x40c000, 0x40cfff) AM_READ(SMH_RAM)
+	AM_RANGE(0x600000, 0x603fff) AM_READ(SMH_RAM)
 
-	AM_RANGE(0x800000, 0x803fff) AM_READ(MRA32_RAM)
-	AM_RANGE(0x804000, 0x807fff) AM_READ(MRA32_RAM)
-	AM_RANGE(0x808000, 0x80bfff) AM_READ(MRA32_RAM)
+	AM_RANGE(0x800000, 0x803fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x804000, 0x807fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x808000, 0x80bfff) AM_READ(SMH_RAM)
 
-	AM_RANGE(0xC00000, 0xC00003) AM_READ(io32_r)	// player inputs
-	AM_RANGE(0xC00004, 0xC00007) AM_READ(io32_1_r) // dip switches
+	AM_RANGE(0xC00000, 0xC00003) AM_READ_PORT("INPUTS")
+	AM_RANGE(0xC00004, 0xC00007) AM_READ_PORT("DSW")
 	AM_RANGE(0xC00024, 0xC00027) AM_READ(silk_6295_0_r)
 	AM_RANGE(0xC0002C, 0xC0002f) AM_READ(silk_ym_r)
 	AM_RANGE(0xC00030, 0xC00033) AM_READ(silk_6295_1_r)
 
-	AM_RANGE(0xfe0000, 0xffffff) AM_READ(MRA32_RAM)
+	AM_RANGE(0xfe0000, 0xffffff) AM_READ(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 32 )
-	AM_RANGE(0x000000, 0x1fffff) AM_WRITE(MWA32_ROM)
-	AM_RANGE(0x40c000, 0x40cfff) AM_WRITE(MWA32_RAM) AM_BASE(&silkroad_sprram) // sprites
+	AM_RANGE(0x000000, 0x1fffff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x40c000, 0x40cfff) AM_WRITE(SMH_RAM) AM_BASE(&silkroad_sprram) // sprites
 	AM_RANGE(0x600000, 0x603fff) AM_WRITE(paletteram32_xRRRRRGGGGGBBBBB_dword_w) AM_BASE(&paletteram32) // palette
 
 	AM_RANGE(0x800000, 0x803fff) AM_WRITE(silkroad_fgram_w) AM_BASE(&silkroad_vidram)  // lower Layer
@@ -243,110 +231,108 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 32 )
 
 	// C00038 appears to be the coin counter, bit 0 is pulsed when a coin is inserted
 /*
-    AM_RANGE(0xC00034, 0xC00037) AM_WRITE(MWA32_NOP)
+    AM_RANGE(0xC00034, 0xC00037) AM_WRITE(SMH_NOP)
 */
 
-	AM_RANGE(0xC0010c, 0xC00123) AM_WRITE(MWA32_RAM) AM_BASE(&silkroad_regs)
+	AM_RANGE(0xC0010c, 0xC00123) AM_WRITE(SMH_RAM) AM_BASE(&silkroad_regs)
 /*
-    AM_RANGE(0xC0010C, 0xC0010f) AM_WRITE(MWA32_NOP) // 0
-    AM_RANGE(0xC00110, 0xC00113) AM_WRITE(MWA32_NOP) // 1
-    AM_RANGE(0xC00114, 0xC00117) AM_WRITE(MWA32_NOP) // 2
+    AM_RANGE(0xC0010C, 0xC0010f) AM_WRITE(SMH_NOP) // 0
+    AM_RANGE(0xC00110, 0xC00113) AM_WRITE(SMH_NOP) // 1
+    AM_RANGE(0xC00114, 0xC00117) AM_WRITE(SMH_NOP) // 2
 
-    AM_RANGE(0xC0011c, 0xC0011f) AM_WRITE(MWA32_NOP) // 4
-    AM_RANGE(0xC00120, 0xC00123) AM_WRITE(MWA32_NOP) // 5
+    AM_RANGE(0xC0011c, 0xC0011f) AM_WRITE(SMH_NOP) // 4
+    AM_RANGE(0xC00120, 0xC00123) AM_WRITE(SMH_NOP) // 5
 */
-	AM_RANGE(0xfe0000, 0xffffff) AM_WRITE(MWA32_RAM)
+	AM_RANGE(0xfe0000, 0xffffff) AM_WRITE(SMH_RAM)
 ADDRESS_MAP_END
 
 
 static INPUT_PORTS_START( silkroad )
-	PORT_START	/* Players inputs */
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
-	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
-	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
-	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
-	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
-	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
+	PORT_START("INPUTS")
+	PORT_BIT( 0x00000001, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x00000002, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT( 0x00000004, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x00000008, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0x00000010, IP_ACTIVE_LOW, IPT_SERVICE1 )
+	PORT_SERVICE_NO_TOGGLE( 0x00000020, IP_ACTIVE_LOW )
+	PORT_BIT( 0x00000040, IP_ACTIVE_LOW, IPT_SERVICE2 )	/* Not mentioned in the "test mode" */
+	PORT_BIT( 0x00000080, IP_ACTIVE_LOW, IPT_SPECIAL )	/* See notes - Stephh*/
+	PORT_BIT( 0x00000100, IP_ACTIVE_LOW, IPT_UNKNOWN )	// this input makes the 020 lock up...- RB
+	PORT_BIT( 0x00000200, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x00000400, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x00000800, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x00001000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x00002000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x00004000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x00008000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x00010000, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x00020000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
+	PORT_BIT( 0x00040000, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
+	PORT_BIT( 0x00080000, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT( 0x00100000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x00200000, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x00400000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x00800000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x01000000, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_BIT( 0x02000000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
+	PORT_BIT( 0x04000000, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
+	PORT_BIT( 0x08000000, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
+	PORT_BIT( 0x10000000, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x20000000, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x40000000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x80000000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
 
-	PORT_START	/* System inputs */
-	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_START2 )
-	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT(0x0020, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2)
-	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_SERVICE2 )	/* Not mentioned in the "test mode" */
-	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_SPECIAL )	/* See notes - Stephh*/
-	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_UNKNOWN )	// this input makes the 020 lock up...- RB
-	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x0400, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x0800, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x1000, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x2000, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_START("DSW")
+	PORT_DIPNAME( 0x00010000, 0x00000000, DEF_STR( Lives ) )
+	PORT_DIPSETTING(          0x00010000, "1" )
+	PORT_DIPSETTING(          0x00000000, "2" )
+	PORT_DIPNAME( 0x00020000, 0x00000000, "Special Effect" )
+	PORT_DIPSETTING(          0x00020000, DEF_STR( Off ) )
+	PORT_DIPSETTING(          0x00000000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x00040000, 0x00040000, "Unused DIP A-2" )
+	PORT_DIPSETTING(          0x00040000, DEF_STR( Off ) )
+	PORT_DIPSETTING(          0x00000000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x00080000, 0x00080000, "Unused DIP A-3" )
+	PORT_DIPSETTING(          0x00080000, DEF_STR( Off ) )
+	PORT_DIPSETTING(          0x00000000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x00100000, 0x00100000, "Unused DIP A-4" )
+	PORT_DIPSETTING(          0x00100000, DEF_STR( Off ) )
+	PORT_DIPSETTING(          0x00000000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x00e00000, 0x00000000, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(          0x00600000, DEF_STR( Easiest ) )			// "1"
+	PORT_DIPSETTING(          0x00400000, DEF_STR( Easier ) )			// "2"
+	PORT_DIPSETTING(          0x00200000, DEF_STR( Easy ) )				// "3"
+	PORT_DIPSETTING(          0x00000000, DEF_STR( Normal ) )			// "4"
+	PORT_DIPSETTING(          0x00e00000, DEF_STR( Medium ) )			// "5"
+	PORT_DIPSETTING(          0x00c00000, DEF_STR( Hard ) )				// "6"
+	PORT_DIPSETTING(          0x00a00000, DEF_STR( Harder ) )			// "7"
+	PORT_DIPSETTING(          0x00800000, DEF_STR( Hardest ) )			// "8"
+	PORT_DIPNAME( 0x01000000, 0x01000000, "Unused DIP B-0" )
+	PORT_DIPSETTING(          0x01000000, DEF_STR( Off ) )
+	PORT_DIPSETTING(          0x00000000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02000000, 0x02000000, DEF_STR( Free_Play ) )
+	PORT_DIPSETTING(          0x02000000, DEF_STR( Off ) )
+	PORT_DIPSETTING(          0x00000000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x04000000, 0x04000000, "Unused DIP B-2" )
+	PORT_DIPSETTING(          0x04000000, DEF_STR( Off ) )
+	PORT_DIPSETTING(          0x00000000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x08000000, 0x00000000, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(          0x08000000, DEF_STR( Off ) )
+	PORT_DIPSETTING(          0x00000000, DEF_STR( On ) )
+	PORT_DIPNAME( 0x10000000, 0x10000000, "Chute Type" )		    	// "Coin Box"
+	PORT_DIPSETTING(          0x10000000, DEF_STR( Single ) )			// "1"
+	PORT_DIPSETTING(          0x00000000, "Multi" )			            // "2"
+	PORT_DIPNAME( 0xe0000000, 0xe0000000, DEF_STR( Coin_A ) )
+	PORT_DIPSETTING(          0x00000000, DEF_STR(5C_1C))
+	PORT_DIPSETTING(          0x20000000, DEF_STR(4C_1C))
+	PORT_DIPSETTING(          0x40000000, DEF_STR(3C_1C))
+	PORT_DIPSETTING(          0x60000000, DEF_STR(2C_1C))
+	PORT_DIPSETTING(          0xe0000000, DEF_STR(1C_1C))
+	PORT_DIPSETTING(          0xc0000000, DEF_STR(1C_2C))
+	PORT_DIPSETTING(          0xa0000000, DEF_STR(1C_3C))
+	PORT_DIPSETTING(          0x80000000, DEF_STR(1C_4C))
 
-	PORT_START	/* DSW */
-	PORT_DIPNAME( 0x0001, 0x0000, DEF_STR( Lives ) )
-	PORT_DIPSETTING(      0x0001, "1" )
-	PORT_DIPSETTING(      0x0000, "2" )
-	PORT_DIPNAME( 0x0002, 0x0000, "Special Effect" )
-	PORT_DIPSETTING(      0x0002, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0004, 0x0004, "Unused DIP A-2" )
-	PORT_DIPSETTING(      0x0004, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0008, 0x0008, "Unused DIP A-3" )
-	PORT_DIPSETTING(      0x0008, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0010, 0x0010, "Unused DIP A-4" )
-	PORT_DIPSETTING(      0x0010, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x00e0, 0x0000, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(      0x0060, DEF_STR( Easiest ) )			// "1"
-	PORT_DIPSETTING(      0x0040, DEF_STR( Easier ) )			// "2"
-	PORT_DIPSETTING(      0x0020, DEF_STR( Easy ) )				// "3"
-	PORT_DIPSETTING(      0x0000, DEF_STR( Normal ) )			// "4"
-	PORT_DIPSETTING(      0x00e0, DEF_STR( Medium ) )			// "5"
-	PORT_DIPSETTING(      0x00c0, DEF_STR( Hard ) )				// "6"
-	PORT_DIPSETTING(      0x00a0, DEF_STR( Harder ) )			// "7"
-	PORT_DIPSETTING(      0x0080, DEF_STR( Hardest ) )			// "8"
-	PORT_DIPNAME( 0x0100, 0x0100, "Unused DIP B-0" )
-	PORT_DIPSETTING(      0x0100, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0200, 0x0200, DEF_STR( Free_Play ) )
-	PORT_DIPSETTING(      0x0200, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0400, 0x0400, "Unused DIP B-2" )
-	PORT_DIPSETTING(      0x0400, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x0800, 0x0000, DEF_STR( Demo_Sounds ) )
-	PORT_DIPSETTING(      0x0800, DEF_STR( Off ) )
-	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-	PORT_DIPNAME( 0x1000, 0x1000, "Chute Type" )		    	// "Coin Box"
-	PORT_DIPSETTING(      0x1000, DEF_STR( Single ) )			// "1"
-	PORT_DIPSETTING(      0x0000, "Multi" )			            // "2"
-	PORT_DIPNAME( 0xe000, 0xe000, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING( 0x0000, DEF_STR(5C_1C))
-	PORT_DIPSETTING( 0x2000, DEF_STR(4C_1C))
-	PORT_DIPSETTING( 0x4000, DEF_STR(3C_1C))
-	PORT_DIPSETTING( 0x6000, DEF_STR(2C_1C))
-	PORT_DIPSETTING( 0xe000, DEF_STR(1C_1C))
-	PORT_DIPSETTING( 0xc000, DEF_STR(1C_2C))
-	PORT_DIPSETTING( 0xa000, DEF_STR(1C_3C))
-	PORT_DIPSETTING( 0x8000, DEF_STR(1C_4C))
-
-//  PORT_START  /* Misc inputs */
+//  PORT_START("MISC")  /* Misc inputs */
 //  PORT_BIT( 0x0080, IP_ACTIVE_HIGH, IPT_SPECIAL ) /* VBLANK ? */
 //  PORT_BIT( 0xff7f, IP_ACTIVE_LOW, IPT_UNUSED ) /* unknown / unused */
 INPUT_PORTS_END
@@ -365,24 +351,24 @@ static const gfx_layout tiles16x16x6_layout =
 };
 
 static GFXDECODE_START( silkroad )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, tiles16x16x6_layout,  0x0000, 256 )
+	GFXDECODE_ENTRY( "gfx1", 0, tiles16x16x6_layout,  0x0000, 256 )
 GFXDECODE_END
 
 static MACHINE_DRIVER_START( silkroad )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68EC020, 16000000)
+	MDRV_CPU_ADD("main", M68EC020, 16000000)
 	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_VBLANK_INT(irq4_line_hold,1)
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", irq4_line_hold)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(6*8+2, 64*8-1-(10*8)-2, 2*8, 32*8-1-(2*8))
+
 	MDRV_GFXDECODE(silkroad)
 	MDRV_PALETTE_LENGTH(0x2000)
 
@@ -392,17 +378,17 @@ static MACHINE_DRIVER_START( silkroad )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_ADD("ym", YM2151, 3579545)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 
-	MDRV_SOUND_ADD(OKIM6295, 1056000)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high) // clock frequency & pin 7 not verified
+	MDRV_SOUND_ADD("oki1", OKIM6295, 1056000)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // clock frequency & pin 7 not verified
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.45)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.45)
 
-	MDRV_SOUND_ADD(OKIM6295, 2112000)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_2_pin7high) // clock frequency & pin 7 not verified
+	MDRV_SOUND_ADD("oki2", OKIM6295, 2112000)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // clock frequency & pin 7 not verified
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.45)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.45)
 MACHINE_DRIVER_END
@@ -420,7 +406,7 @@ static DRIVER_INIT( silkroad )
        verified as correct... problem with the original which the gfx
        hardware didn't care about? */
 
-	UINT8 *src = memory_region(REGION_GFX1)+0x1000000;
+	UINT8 *src = memory_region(machine, "gfx1")+0x1000000;
 	int len = 0x0200000;
 	UINT8 *buffer;
 
@@ -439,11 +425,11 @@ static DRIVER_INIT( silkroad )
 }
 
 ROM_START( silkroad )
-	ROM_REGION( 0x200000, REGION_CPU1, 0 )
+	ROM_REGION( 0x200000, "main", 0 )
 	ROM_LOAD32_WORD_SWAP( "rom02.bin", 0x000000, 0x100000, CRC(4e5200fc) SHA1(4d4cab03a6ec4ad825001e1e92193940646141e5) )
 	ROM_LOAD32_WORD_SWAP( "rom03.bin", 0x000002, 0x100000, CRC(73ccc78c) SHA1(2ac17aa8d7dac8636d29a4e4228a556334b51f1a) )
 
-	ROM_REGION( 0x1800000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
+	ROM_REGION( 0x1800000, "gfx1", ROMREGION_DISPOSE | ROMREGION_INVERT )
 	/* Sprites */
 	ROM_LOAD( "rom12.bin",	0x0000000, 0x0200000, CRC(96393d04) SHA1(f512bb8603510d39e649f4ec1c5e2d0e4bf3a2cc) ) // 0
 	ROM_LOAD( "rom08.bin",	0x0800000, 0x0200000, CRC(23f1d462) SHA1(6ca8052b16ccc1fe59716e03f66bd33af5145b37) ) // 0
@@ -460,10 +446,10 @@ ROM_START( silkroad )
 	ROM_LOAD( "rom11.bin",	0x0e00000, 0x0200000, CRC(11abaf1c) SHA1(19e86f3ebfec518a96c0520f36cfc1b525e7e55c) ) // 3
 	ROM_LOAD( "rom15.bin",	0x1600000, 0x0200000, CRC(26a3b168) SHA1(a4b7955cc4d4fbec7c975a9456f2219ef33f1166) ) // 3
 
-	ROM_REGION( 0x080000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x080000, "oki1", 0 )
 	ROM_LOAD( "rom00.bin", 0x000000, 0x080000, CRC(b10ba7ab) SHA1(a6a3ae71b803af9c31d7e97dc86cfcc123ee9a40) )
 
-	ROM_REGION( 0x080000, REGION_SOUND2, 0 )
+	ROM_REGION( 0x080000, "oki2", 0 )
 	ROM_LOAD( "rom01.bin", 0x000000, 0x040000, CRC(db8cb455) SHA1(6723b4018208d554bd1bf1e0640b72d2f4f47302) )
 ROM_END
 
