@@ -65,9 +65,10 @@ Notes:
 */
 
 #include "driver.h"
+#include "cpu/m68000/m68000.h"
 #include "deprecat.h"
 #include "sound/okim6295.h"
-#include "cpu/i8051/i8051.h"
+#include "cpu/mcs51/mcs51.h"
 
 #define FIFO_SIZE 1024
 #define IO_SIZE 	0x100
@@ -80,7 +81,7 @@ static UINT16 io_reg[IO_SIZE];
 static UINT16 fifo[FIFO_SIZE];
 static UINT16 fptr;
 
-static int jpeg_addr=-1;
+static int jpeg_addr;
 static UINT16 jpeg1,jpeg2;
 static int jpeg_h=0;
 static int jpeg_w=0;
@@ -89,8 +90,8 @@ static int jpeg_y=0;
 static int tmp_counter;
 static int clr_offset=0;
 
-static mame_bitmap *sliver_bitmap_fg;
-static mame_bitmap *sliver_bitmap_bg;
+static bitmap_t *sliver_bitmap_fg;
+static bitmap_t *sliver_bitmap_bg;
 
 static UINT16 tempbuf[8];
 
@@ -253,9 +254,11 @@ static WRITE16_HANDLER( fifo_data_w )
 	}
 }
 
-static void blit_gfx(void)
+static void blit_gfx(running_machine *machine)
 {
 	int tmpptr=0;
+	const UINT8 *rom = memory_region(machine, "user1");
+
 	while(tmpptr<fptr)
 	{
 		int x,y,romdata;
@@ -271,7 +274,7 @@ static void blit_gfx(void)
 			{
 				for (x=0;x<w;x++)
 				{
-					romdata = memory_region(REGION_USER1)[romoffs&0x1fffff];
+					romdata = rom[romoffs&0x1fffff];
 					if(romdata)
 					{
 						plot_pixel_pal(fifo[tmpptr+5]+fifo[tmpptr+3]-x, fifo[tmpptr+6]+fifo[tmpptr+4]-y, romdata);
@@ -286,14 +289,14 @@ static void blit_gfx(void)
 
 static WRITE16_HANDLER( fifo_clear_w )
 {
-		fillbitmap(sliver_bitmap_fg, 0,0);
+		bitmap_fill(sliver_bitmap_fg, 0,0);
 		fptr=0;
 		tmp_counter=0;
 }
 
 static WRITE16_HANDLER( fifo_flush_w )
 {
-		blit_gfx();
+		blit_gfx(space->machine);
 }
 
 
@@ -302,20 +305,23 @@ static WRITE16_HANDLER( jpeg1_w )
 		COMBINE_DATA(&jpeg1);
 }
 
-static void render_jpeg(void)
+static void render_jpeg(running_machine *machine)
 {
 	int x,y;
 	int addr=jpeg_addr;
-	fillbitmap(sliver_bitmap_bg, 0,0);
+	UINT8 *rom;
+
+	bitmap_fill(sliver_bitmap_bg, 0,0);
 	if(jpeg_addr<0)
 	{
 		return;
 	}
+	rom = memory_region(machine, "user3");
 	for (y=0;y<jpeg_h;y++)
 	{
 		for (x=0;x<jpeg_w;x++)
 		{
-			plot_pixel_rgb(x-x_offset+jpeg_x,jpeg_h-y-y_offset-jpeg_y,memory_region(REGION_USER3)[addr],memory_region(REGION_USER3)[addr+1],memory_region(REGION_USER3)[addr+2]);
+			plot_pixel_rgb(x-x_offset+jpeg_x,jpeg_h-y-y_offset-jpeg_y,rom[addr],rom[addr+1],rom[addr+2]);
 			addr+=3;
 		}
 	}
@@ -346,7 +352,7 @@ static WRITE16_HANDLER( jpeg2_w )
 				jpeg_addr=gfxlookup[idx][0];
 				jpeg_w=gfxlookup[idx][2];
 				jpeg_h=gfxlookup[idx][3];
-				render_jpeg();
+				render_jpeg(space->machine);
 		}
 		else
 			{
@@ -374,7 +380,7 @@ static WRITE16_HANDLER(io_data_w)
 		{
 			jpeg_x=tmpx;
 			jpeg_y=tmpy;
-			render_jpeg();
+			render_jpeg(space->machine);
 		}
 	}
 	else
@@ -385,8 +391,8 @@ static WRITE16_HANDLER(io_data_w)
 
 static WRITE16_HANDLER(sound_w)
 {
-		soundlatch_w(0,data & 0xff);
-		cpunum_set_input_line(Machine, 1, I8051_INT0_LINE, HOLD_LINE);
+		soundlatch_w(space,0,data & 0xff);
+		cpu_set_input_line(space->machine->cpu[1], MCS51_INT0_LINE, HOLD_LINE);
 }
 
 static ADDRESS_MAP_START( sliver_map, ADDRESS_SPACE_PROGRAM, 16 )
@@ -394,16 +400,16 @@ static ADDRESS_MAP_START( sliver_map, ADDRESS_SPACE_PROGRAM, 16 )
 
 	AM_RANGE(0x100000, 0x100001) AM_WRITE(sliver_RAMDAC_offset_w)
 	AM_RANGE(0x100002, 0x100003) AM_WRITE(sliver_RAMDAC_color_w)
-	AM_RANGE(0x100004, 0x100005) AM_WRITE(MWA16_NOP)//RAMDAC
+	AM_RANGE(0x100004, 0x100005) AM_WRITE(SMH_NOP)//RAMDAC
 
 	AM_RANGE(0x300002, 0x300003) AM_NOP // bit 0 tested, writes 0xe0 and 0xc0 - both r and w at the end of interrupt code
 
 	AM_RANGE(0x300004, 0x300005) AM_WRITE(io_offset_w) //unknown i/o device
 	AM_RANGE(0x300006, 0x300007) AM_WRITE(io_data_w)
 
-	AM_RANGE(0x400000, 0x400001) AM_READ(input_port_0_word_r)
-	AM_RANGE(0x400002, 0x400003) AM_READ(input_port_1_word_r)
-	AM_RANGE(0x400004, 0x400005) AM_READ(input_port_2_word_r)
+	AM_RANGE(0x400000, 0x400001) AM_READ_PORT("P1_P2")
+	AM_RANGE(0x400002, 0x400003) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0x400004, 0x400005) AM_READ_PORT("DSW")
 	AM_RANGE(0x400006, 0x400007) AM_WRITE(fifo_data_w)
 	AM_RANGE(0x400008, 0x400009) AM_WRITE(fifo_clear_w)
 	AM_RANGE(0x40000a, 0x40000b) AM_WRITE(fifo_flush_w)
@@ -421,7 +427,7 @@ ADDRESS_MAP_END
 
 static WRITE8_HANDLER(oki_setbank)
 {
-	UINT8 *sound = memory_region(REGION_SOUND1);
+	UINT8 *sound = memory_region(space->machine, "oki");
 	int bank=(data^0xff)&3; //xor or not ?
 	memcpy(sound+0x20000, sound+0x100000+0x20000*bank, 0x20000);
 }
@@ -430,19 +436,17 @@ static ADDRESS_MAP_START( soundmem_prg, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( soundmem_data, ADDRESS_SPACE_DATA, 8 )
-	AM_RANGE(0x0100, 0x0100) AM_READWRITE( OKIM6295_status_0_r, OKIM6295_data_0_w )
-	AM_RANGE(0x0101, 0x0101) AM_READ(soundlatch_r)
-ADDRESS_MAP_END
-
 static ADDRESS_MAP_START( soundmem_io, ADDRESS_SPACE_IO, 8 )
-	AM_RANGE(0x0001, 0x0001) AM_WRITE( oki_setbank )
+	AM_RANGE(0x0100, 0x0100) AM_READWRITE( okim6295_status_0_r, okim6295_data_0_w )
+	AM_RANGE(0x0101, 0x0101) AM_READ(soundlatch_r)
+	/* ports */
+	AM_RANGE(MCS51_PORT_P1, MCS51_PORT_P1) AM_WRITE( oki_setbank )
 ADDRESS_MAP_END
 
 static VIDEO_START(sliver)
 {
-	sliver_bitmap_bg = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
-	sliver_bitmap_fg = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
+	sliver_bitmap_bg = video_screen_auto_bitmap_alloc(machine->primary_screen);
+	sliver_bitmap_fg = video_screen_auto_bitmap_alloc(machine->primary_screen);
 }
 
 static VIDEO_UPDATE(sliver)
@@ -453,8 +457,7 @@ static VIDEO_UPDATE(sliver)
 }
 
 static INPUT_PORTS_START( sliver )
-
-	PORT_START
+	PORT_START("P1_P2")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_PLAYER(1)
@@ -472,7 +475,7 @@ static INPUT_PORTS_START( sliver )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(2)
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
+	PORT_START("SYSTEM")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_COIN2 )
@@ -480,7 +483,7 @@ static INPUT_PORTS_START( sliver )
 	PORT_BIT( 0x0040, IP_ACTIVE_HIGH, IPT_UNKNOWN ) //jpeg ready flag
 	PORT_BIT( 0xffa4, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START("DSW")
 	PORT_DIPNAME( 0x000f, 0x000f, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(	0x000f, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(	0x000e, DEF_STR( 1C_2C ) )
@@ -521,31 +524,28 @@ static INPUT_PORTS_START( sliver )
 	PORT_DIPNAME( 0x8000, 0x8000, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(      0x8000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-
 INPUT_PORTS_END
 
 static INTERRUPT_GEN( sliver_int )
 {
 	//valid interrupts are 2,3,4
-	cpunum_set_input_line(machine, 0, 2+cpu_getiloops(), HOLD_LINE);
+	cpu_set_input_line(device, 2+cpu_getiloops(device), HOLD_LINE);
 }
 
 static MACHINE_DRIVER_START( sliver )
-	MDRV_CPU_ADD_TAG("main", M68000, 12000000)
+	MDRV_CPU_ADD("main", M68000, 12000000)
 	MDRV_CPU_PROGRAM_MAP(sliver_map,0)
-	MDRV_CPU_VBLANK_INT(sliver_int,3)
+	MDRV_CPU_VBLANK_INT_HACK(sliver_int,3)
 
-	MDRV_CPU_ADD(I8051, 8000000)
+	MDRV_CPU_ADD("audio", I8051, 8000000)
 	MDRV_CPU_PROGRAM_MAP(soundmem_prg,0)
-	MDRV_CPU_DATA_MAP(soundmem_data,0)
 	MDRV_CPU_IO_MAP(soundmem_io,0)
 
+
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-
 	MDRV_SCREEN_SIZE(64*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 384-1-16, 0*8, 240-1)
 
@@ -554,41 +554,42 @@ static MACHINE_DRIVER_START( sliver )
 
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(OKIM6295, 1000000)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high)
+	MDRV_SOUND_ADD("oki", OKIM6295, 1000000)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "left", 0.6)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "right", 0.6)
 MACHINE_DRIVER_END
 
 ROM_START( sliver )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_REGION( 0x100000, "main", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "ka-4.bin", 0x00001, 0x20000, CRC(4906367f) SHA1(cc030930ffe7018ba6c362cab136798d027db7d8) )
 	ROM_LOAD16_BYTE( "ka-5.bin", 0x00000, 0x20000, CRC(f260dabc) SHA1(3727cb8aa652809386075b39a1d85d5b20973702) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 8031 */
+	ROM_REGION( 0x10000, "audio", 0 ) /* 8031 */
 	ROM_LOAD( "ka-1.bin", 0x000000, 0x10000, CRC(56e616a2) SHA1(f8952aba62ae0410e300d99e95dc8b752543af1e) )
 
-	ROM_REGION( 0x180000, REGION_SOUND1, 0 ) /* Samples */
+	ROM_REGION( 0x180000, "oki", 0 ) /* Samples */
 	ROM_LOAD( "ka-2.bin", 0x000000, 0x20000, CRC(3df96eb0) SHA1(ec3dfc29da08f6525a1c708839f83094a6784f72) )
 	ROM_LOAD( "ka-3.bin", 0x100000, 0x80000, CRC(33ee929c) SHA1(a652ad68c547248ef5fa1ed8006b7ac7aef76383) )
 
-	ROM_REGION( 0x200000, REGION_USER1, 0 ) /* Graphics (not tiles) */
+	ROM_REGION( 0x200000, "user1", 0 ) /* Graphics (not tiles) */
 	ROM_LOAD16_BYTE( "ka-8.bin", 0x000000, 0x80000, CRC(dbfd7489) SHA1(4a7b07d041dce04a8d8d6688698164f988baefc9) )
 	ROM_LOAD16_BYTE( "ka-6.bin", 0x000001, 0x80000, CRC(bd182316) SHA1(a22db9f73a2865f59630183c14201aeede821642) )
 	ROM_LOAD16_BYTE( "ka-9.bin", 0x100000, 0x40000, CRC(71f044ba) SHA1(bd88bfaa0249de9fd8eb8bd25eae0126744a9046) )
 	ROM_LOAD16_BYTE( "ka-7.bin", 0x100001, 0x40000, CRC(1c5d6fb9) SHA1(372533264eb41a5f57b2a59eb039adb6334f36c5) )
 
-	ROM_REGION( 0x180000, REGION_USER2, 0 ) /* JPEG(!) compressed GFX */
+	ROM_REGION( 0x180000, "user2", 0 ) /* JPEG(!) compressed GFX */
 	ROM_LOAD( "ka-10.bin", 0x000000, 0x80000, CRC(a6824271) SHA1(2eefa4e61491f7b72ccde744fa6f88a1a3c60c92) )
 	ROM_LOAD( "ka-11.bin", 0x080000, 0x80000, CRC(4ae121ff) SHA1(ece7cc07483801a0d436def977d72dc7b1a07c8f) )
 	ROM_LOAD( "ka-12.bin", 0x100000, 0x80000, CRC(0901e142) SHA1(68ebd38beeedf53414a831c01813881feee33446) )
 
-	ROM_REGION( 0x2000000, REGION_USER3, 0 ) /* decompressed GFX  - temporary!*/
+	ROM_REGION( 0x2000000, "user3", 0 ) /* decompressed GFX  - temporary!*/
 	ROM_LOAD( "gfx.bin", 0x000000, 0x2000000, BAD_DUMP CRC(706f264e) SHA1(dbcc8dbf30bd65d86bcde7d6db1b08af4242a253) )
 ROM_END
 
 static DRIVER_INIT(sliver)
 {
+	jpeg_addr = -1;
 	colorram=auto_malloc(256*3);
 }
 
