@@ -126,7 +126,8 @@ cpu #0 (PC=00001A1A): unmapped memory word write to 00090030 = 00F7 & 00FF
 *******************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
+#include "cpu/m68000/m68000.h"
 #include "sound/okim6295.h"
 #include "sound/3812intf.h"
 
@@ -137,87 +138,87 @@ VIDEO_UPDATE( spbactn );
 
 static WRITE16_HANDLER( soundcommand_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
-		soundlatch_w(offset,data & 0xff);
-		cpunum_set_input_line(Machine, 1,INPUT_LINE_NMI,PULSE_LINE);
+		soundlatch_w(space,offset,data & 0xff);
+		cpu_set_input_line(space->machine->cpu[1],INPUT_LINE_NMI,PULSE_LINE);
 	}
 }
 
 static ADDRESS_MAP_START( spbactn_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x00000, 0x3ffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x40000, 0x43fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x50000, 0x50fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x60000, 0x67fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x70000, 0x77fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x80000, 0x82fff) AM_READ(MRA16_RAM)
-	AM_RANGE(0x90000, 0x90001) AM_READ(input_port_0_word_r)
-	AM_RANGE(0x90010, 0x90011) AM_READ(input_port_1_word_r)
-	AM_RANGE(0x90020, 0x90021) AM_READ(input_port_2_word_r)
-	AM_RANGE(0x90030, 0x90031) AM_READ(input_port_4_word_r)
-	AM_RANGE(0x90040, 0x90041) AM_READ(input_port_3_word_r)
+	AM_RANGE(0x00000, 0x3ffff) AM_READ(SMH_ROM)
+	AM_RANGE(0x40000, 0x43fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x50000, 0x50fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x60000, 0x67fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x70000, 0x77fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x80000, 0x82fff) AM_READ(SMH_RAM)
+	AM_RANGE(0x90000, 0x90001) AM_READ_PORT("IN0")
+	AM_RANGE(0x90010, 0x90011) AM_READ_PORT("IN1")
+	AM_RANGE(0x90020, 0x90021) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0x90030, 0x90031) AM_READ_PORT("DSW1")
+	AM_RANGE(0x90040, 0x90041) AM_READ_PORT("DSW2")
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( spbactn_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x00000, 0x3ffff) AM_WRITE(MWA16_ROM)
-	AM_RANGE(0x40000, 0x43fff) AM_WRITE(MWA16_RAM)	// main ram
-	AM_RANGE(0x50000, 0x50fff) AM_WRITE(MWA16_RAM) AM_BASE(&spbactn_spvideoram)
-	AM_RANGE(0x60000, 0x67fff) AM_WRITE(MWA16_RAM) AM_BASE(&spbactn_fgvideoram)
-	AM_RANGE(0x70000, 0x77fff) AM_WRITE(MWA16_RAM) AM_BASE(&spbactn_bgvideoram)
+	AM_RANGE(0x00000, 0x3ffff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x40000, 0x43fff) AM_WRITE(SMH_RAM)	// main ram
+	AM_RANGE(0x50000, 0x50fff) AM_WRITE(SMH_RAM) AM_BASE(&spbactn_spvideoram)
+	AM_RANGE(0x60000, 0x67fff) AM_WRITE(SMH_RAM) AM_BASE(&spbactn_fgvideoram)
+	AM_RANGE(0x70000, 0x77fff) AM_WRITE(SMH_RAM) AM_BASE(&spbactn_bgvideoram)
 	AM_RANGE(0x80000, 0x827ff) AM_WRITE(paletteram16_xxxxBBBBGGGGRRRR_word_w) AM_BASE(&paletteram16)
 
 	/* this is an awful lot of unknowns */
-	AM_RANGE(0x90000, 0x90001) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0x90000, 0x90001) AM_WRITE(SMH_NOP)
 	AM_RANGE(0x90010, 0x90011) AM_WRITE(soundcommand_w)
 //  AM_RANGE(0x90020, 0x90021) AM_WRITE(soundcommand_w)
-	AM_RANGE(0x90030, 0x90031) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0x90030, 0x90031) AM_WRITE(SMH_NOP)
 
-	AM_RANGE(0x90080, 0x90081) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x90090, 0x90091) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x900a0, 0x900a1) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x900b0, 0x900b1) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x900c0, 0x900c1) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x900d0, 0x900d1) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x900e0, 0x900e1) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x900f0, 0x900f1) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0x90080, 0x90081) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x90090, 0x90091) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x900a0, 0x900a1) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x900b0, 0x900b1) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x900c0, 0x900c1) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x900d0, 0x900d1) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x900e0, 0x900e1) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x900f0, 0x900f1) AM_WRITE(SMH_NOP)
 
-	AM_RANGE(0xa0000, 0xa0001) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xa0004, 0xa0005) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xa0008, 0xa0009) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xa000c, 0xa000d) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xa0010, 0xa0011) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0xa0000, 0xa0001) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa0004, 0xa0005) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa0008, 0xa0009) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa000c, 0xa000d) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa0010, 0xa0011) AM_WRITE(SMH_NOP)
 
-	AM_RANGE(0xa0100, 0xa0101) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xa0104, 0xa0105) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xa0108, 0xa0109) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xa010c, 0xa010d) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xa0110, 0xa0111) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0xa0100, 0xa0101) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa0104, 0xa0105) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa0108, 0xa0109) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa010c, 0xa010d) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa0110, 0xa0111) AM_WRITE(SMH_NOP)
 
-	AM_RANGE(0xa0200, 0xa0201) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xa0202, 0xa0203) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xa0204, 0xa0205) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0xa0206, 0xa0207) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0xa0200, 0xa0201) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa0202, 0xa0203) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa0204, 0xa0205) AM_WRITE(SMH_NOP)
+	AM_RANGE(0xa0206, 0xa0207) AM_WRITE(SMH_NOP)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xefff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xf000, 0xf7ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xf800, 0xf800) AM_READ(OKIM6295_status_0_r)
-	AM_RANGE(0xfc00, 0xfc00) AM_READ(MRA8_NOP)	/* irq ack ?? */
+	AM_RANGE(0x0000, 0xefff) AM_READ(SMH_ROM)
+	AM_RANGE(0xf000, 0xf7ff) AM_READ(SMH_RAM)
+	AM_RANGE(0xf800, 0xf800) AM_READ(okim6295_status_0_r)
+	AM_RANGE(0xfc00, 0xfc00) AM_READ(SMH_NOP)	/* irq ack ?? */
 	AM_RANGE(0xfc20, 0xfc20) AM_READ(soundlatch_r)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xefff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xf000, 0xf7ff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xf800, 0xf800) AM_WRITE(OKIM6295_data_0_w)
-	AM_RANGE(0xf810, 0xf810) AM_WRITE(YM3812_control_port_0_w)
-	AM_RANGE(0xf811, 0xf811) AM_WRITE(YM3812_write_port_0_w)
-	AM_RANGE(0xfc00, 0xfc00) AM_WRITE(MWA8_NOP)	/* irq ack ?? */
+	AM_RANGE(0x0000, 0xefff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0xf000, 0xf7ff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0xf800, 0xf800) AM_WRITE(okim6295_data_0_w)
+	AM_RANGE(0xf810, 0xf810) AM_WRITE(ym3812_control_port_0_w)
+	AM_RANGE(0xf811, 0xf811) AM_WRITE(ym3812_write_port_0_w)
+	AM_RANGE(0xfc00, 0xfc00) AM_WRITE(SMH_NOP)	/* irq ack ?? */
 ADDRESS_MAP_END
 
 static INPUT_PORTS_START( spbactn )
-	PORT_START	/* IN0 */
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -227,7 +228,7 @@ static INPUT_PORTS_START( spbactn )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	/* IN1 */
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -237,7 +238,7 @@ static INPUT_PORTS_START( spbactn )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	/* IN2 */
+	PORT_START("SYSTEM")
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_START1 )		// Press mulitple times for multiple players
@@ -247,7 +248,7 @@ static INPUT_PORTS_START( spbactn )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	/* DSW1 */
+	PORT_START("DSW1")
 	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( 3C_1C ) )
@@ -272,7 +273,7 @@ static INPUT_PORTS_START( spbactn )
 	PORT_DIPSETTING(    0x80, "4" )
 	PORT_DIPSETTING(    0x40, "5" )
 
-	PORT_START	/* DSW2 */
+	PORT_START("DSW2")
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( Easy ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( Normal ) )
@@ -337,39 +338,38 @@ static const gfx_layout spritelayout =
 };
 
 static GFXDECODE_START( spbactn )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, fgtilelayout,   0x0200, 16384  )
-	GFXDECODE_ENTRY( REGION_GFX2, 0, bgtilelayout,   0x0300, 16384  )
-	GFXDECODE_ENTRY( REGION_GFX3, 0, spritelayout,   0x0000, 16384  )
+	GFXDECODE_ENTRY( "gfx1", 0, fgtilelayout,   0x0200, 16 + 240 )
+	GFXDECODE_ENTRY( "gfx2", 0, bgtilelayout,   0x0300, 16 + 128 )
+	GFXDECODE_ENTRY( "gfx3", 0, spritelayout,   0x0000, 16 + 384 )
 GFXDECODE_END
 
-static void irqhandler(int linestate)
+static void irqhandler(running_machine *machine, int linestate)
 {
-	cpunum_set_input_line(Machine, 1,0,linestate);
+	cpu_set_input_line(machine->cpu[1],0,linestate);
 }
 
-static const struct YM3812interface ym3812_interface =
+static const ym3812_interface ym3812_config =
 {
 	irqhandler
 };
 
 static MACHINE_DRIVER_START( spbactn )
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000, 12000000)
+	MDRV_CPU_ADD("main", M68000, 12000000)
 	MDRV_CPU_PROGRAM_MAP(spbactn_readmem,spbactn_writemem)
-	MDRV_CPU_VBLANK_INT(irq3_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq3_line_hold)
 
-	MDRV_CPU_ADD(Z80, 4000000)
-	/* audio CPU */	/* 4 MHz ??? */
+	MDRV_CPU_ADD("audio", Z80, 4000000)	/* 4 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER )
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_SIZE(64*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 64*8-1, 2*8, 30*8-1)
+
 	MDRV_GFXDECODE(spbactn)
 	MDRV_PALETTE_LENGTH(0x2800/2)
 
@@ -379,63 +379,63 @@ static MACHINE_DRIVER_START( spbactn )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM3812, 3579545)
-	MDRV_SOUND_CONFIG(ym3812_interface)
+	MDRV_SOUND_ADD("ym", YM3812, 3579545)
+	MDRV_SOUND_CONFIG(ym3812_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 
-	MDRV_SOUND_ADD(OKIM6295, 1056000)
-	MDRV_SOUND_CONFIG(okim6295_interface_region_1_pin7high) // clock frequency & pin 7 not verified
+	MDRV_SOUND_ADD("oki", OKIM6295, 1056000)
+	MDRV_SOUND_CONFIG(okim6295_interface_pin7high) // clock frequency & pin 7 not verified
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
 ROM_START( spbactn )
 	/* Board 9002-A (CPU Board) */
-	ROM_REGION( 0x40000, REGION_CPU1, 0 )
+	ROM_REGION( 0x40000, "main", 0 )
 	ROM_LOAD16_BYTE( "rom1.bin", 0x00000, 0x20000, CRC(6741bd3f) SHA1(844eb6465a15d339043fd6d2b6ba20ba216de493) )
 	ROM_LOAD16_BYTE( "rom2.bin", 0x00001, 0x20000, CRC(488cc511) SHA1(41b4a01f35e0e93634b4843dbb894ab9840807bf) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "a-u14.3", 0x00000, 0x10000, CRC(57f4c503) SHA1(e5ddc63a43ba824bcaa4340eeba25a0d3f26cad9) )
 
-	ROM_REGION( 0x20000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x20000, "oki", 0 )
 	ROM_LOAD( "a-u19",   0x00000, 0x20000,  CRC(87427d7d) SHA1(f76b0dc3f0d87deb0f0c81084aff9756b236e867) )
 
 	/* Board 9002-B (GFX Board) */
-	ROM_REGION( 0x080000, REGION_GFX1, 0 ) /* 16x8 FG Tiles */
+	ROM_REGION( 0x080000, "gfx1", 0 ) /* 16x8 FG Tiles */
 	ROM_LOAD( "b-u98",   0x00000, 0x40000, CRC(315eab4d) SHA1(6f812c85981dc649caca8b4635e3b8fd3a3c054d) )
 	ROM_LOAD( "b-u99",   0x40000, 0x40000, CRC(7b76efd9) SHA1(9f23460aebe12cb5c4193776bf876d6044892979) )
 
-	ROM_REGION( 0x080000, REGION_GFX2, 0 ) /* 16x8 BG Tiles */
+	ROM_REGION( 0x080000, "gfx2", 0 ) /* 16x8 BG Tiles */
 	ROM_LOAD( "b-u104",  0x00000, 0x40000, CRC(b648a40a) SHA1(1fb756dcd027a5702596e33bbe8a0beeb3ceb22b) )
 	ROM_LOAD( "b-u105",  0x40000, 0x40000, CRC(0172d79a) SHA1(7ee1faa65c85860bd81988329df516bc34940ef5) )
 
-	ROM_REGION( 0x080000, REGION_GFX3, 0 ) /* 8x8 Sprite Tiles */
+	ROM_REGION( 0x080000, "gfx3", 0 ) /* 8x8 Sprite Tiles */
 	ROM_LOAD( "b-u110",  0x00000, 0x40000, CRC(862ebacd) SHA1(05732e8524c50256c1db29317625d0edc19b87d2) )
 	ROM_LOAD( "b-u111",  0x40000, 0x40000, CRC(1cc1379a) SHA1(44fdab8cb5ab1488688f1ac52f005454e835efee) )
 ROM_END
 
 ROM_START( spbactnj )
 	/* Board 9002-A (CPU Board) */
-	ROM_REGION( 0x40000, REGION_CPU1, 0 )
+	ROM_REGION( 0x40000, "main", 0 )
 	ROM_LOAD16_BYTE( "a-u68.1", 0x00000, 0x20000, CRC(b5b2d824) SHA1(be04ca370a381d7396f39e31fb2680973193daee) )
 	ROM_LOAD16_BYTE( "a-u67.2", 0x00001, 0x20000, CRC(9577b48b) SHA1(291d890a9d0e434455f183eb12ae6edf3156688d) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "a-u14.3", 0x00000, 0x10000, CRC(57f4c503) SHA1(e5ddc63a43ba824bcaa4340eeba25a0d3f26cad9) )
 
-	ROM_REGION( 0x20000, REGION_SOUND1, 0 )
+	ROM_REGION( 0x20000, "oki", 0 )
 	ROM_LOAD( "a-u19",   0x00000, 0x20000,  CRC(87427d7d) SHA1(f76b0dc3f0d87deb0f0c81084aff9756b236e867) )
 
 	/* Board 9002-B (GFX Board) */
-	ROM_REGION( 0x080000, REGION_GFX1, 0 ) /* 16x8 FG Tiles */
+	ROM_REGION( 0x080000, "gfx1", 0 ) /* 16x8 FG Tiles */
 	ROM_LOAD( "b-u98",   0x00000, 0x40000, CRC(315eab4d) SHA1(6f812c85981dc649caca8b4635e3b8fd3a3c054d) )
 	ROM_LOAD( "b-u99",   0x40000, 0x40000, CRC(7b76efd9) SHA1(9f23460aebe12cb5c4193776bf876d6044892979) )
 
-	ROM_REGION( 0x080000, REGION_GFX2, 0 ) /* 16x8 BG Tiles */
+	ROM_REGION( 0x080000, "gfx2", 0 ) /* 16x8 BG Tiles */
 	ROM_LOAD( "b-u104",  0x00000, 0x40000, CRC(b648a40a) SHA1(1fb756dcd027a5702596e33bbe8a0beeb3ceb22b) )
 	ROM_LOAD( "b-u105",  0x40000, 0x40000, CRC(0172d79a) SHA1(7ee1faa65c85860bd81988329df516bc34940ef5) )
 
-	ROM_REGION( 0x080000, REGION_GFX3, 0 ) /* 8x8 Sprite Tiles */
+	ROM_REGION( 0x080000, "gfx3", 0 ) /* 8x8 Sprite Tiles */
 	ROM_LOAD( "b-u110",  0x00000, 0x40000, CRC(862ebacd) SHA1(05732e8524c50256c1db29317625d0edc19b87d2) )
 	ROM_LOAD( "b-u111",  0x40000, 0x40000, CRC(1cc1379a) SHA1(44fdab8cb5ab1488688f1ac52f005454e835efee) )
 ROM_END
