@@ -21,7 +21,7 @@
     $0000-$1bff Video Memory (bit0)
     $4000-$5bff Video Memory (bit1)
     $8000-$9bff Video Memory (bit2)
-    $c000-$c001 6845 CRT Controller (crtc6845)
+    $c000-$c001 6845 CRT Controller (mc6845)
     $c020-$c027 NVRAM
     $c044-$c047 MC6821 PIA 1 (Control input port - all input)
     $c048-$c04b MC6821 PIA 2 (Sprite data port - see machine/spiders.c)
@@ -36,7 +36,7 @@
     $0000-$1bff Video Memory (bit0)
     $4000-$5bff Video Memory (bit1)
     $8000-$9bff Video Memory (bit2)
-    $c000-$c001 6845 CRT Controller (crtc6845)
+    $c000-$c001 6845 CRT Controller (mc6845)
     $c044-$c047 MC6821 PIA 1
     $c048-$c04b MC6821 PIA 2 (Video port)
     $c050-$c053 MC6821 PIA 3
@@ -188,11 +188,10 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "rescap.h"
-#include "deprecat.h"
+#include "machine/rescap.h"
 #include "cpu/m6800/m6800.h"
 #include "cpu/m6809/m6809.h"
-#include "video/crtc6845.h"
+#include "video/mc6845.h"
 #include "machine/6821pia.h"
 #include "machine/74123.h"
 #include "spiders.h"
@@ -230,25 +229,25 @@ static READ8_HANDLER( gfx_rom_r );
  *
  *************************************/
 
-static void main_cpu_irq(int state)
+static void main_cpu_irq(running_machine *machine, int state)
 {
 	int combined_state = pia_get_irq_a(1) | pia_get_irq_b(1) |
 						 					pia_get_irq_b(2) |
 						 pia_get_irq_a(3) | pia_get_irq_b(3);
 
-	cpunum_set_input_line(Machine, 0, M6809_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], M6809_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
-static void main_cpu_firq(int state)
+static void main_cpu_firq(running_machine *machine, int state)
 {
-	cpunum_set_input_line(Machine, 0, M6809_FIRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], M6809_FIRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
-static void audio_cpu_irq(int state)
+static void audio_cpu_irq(running_machine *machine, int state)
 {
-	cpunum_set_input_line(Machine, 1, M6802_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[1], M6800_IRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -269,16 +268,17 @@ static const pia6821_interface pia_1_intf =
 
 static INTERRUPT_GEN( update_pia_1 )
 {
+	const address_space *space = cpu_get_address_space(device, ADDRESS_SPACE_PROGRAM);
 	/* update the different PIA pins from the input ports */
 
 	/* CA1 - copy of PA1 (COIN1) */
-	pia_1_ca1_w(0, input_port_0_r(0) & 0x02);
+	pia_1_ca1_w(space, 0, input_port_read(device->machine, "IN0") & 0x02);
 
 	/* CA2 - copy of PA0 (SERVICE1) */
-	pia_1_ca2_w(0, input_port_0_r(0) & 0x01);
+	pia_1_ca2_w(space, 0, input_port_read(device->machine, "IN0") & 0x01);
 
 	/* CB1 - (crosshatch) */
-	pia_1_cb1_w(0, input_port_5_r(0));
+	pia_1_cb1_w(space, 0, input_port_read(device->machine, "XHATCH"));
 
 	/* CB2 - NOT CONNECTED */
 }
@@ -342,13 +342,14 @@ static const pia6821_interface pia_4_intf =
  *
  *************************************/
 
-static void ic60_74123_output_changed(int output)
+static WRITE8_DEVICE_HANDLER( ic60_74123_output_changed)
 {
-	pia_2_ca1_w(0, output);
+	const address_space *space = cpu_get_address_space(device->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	pia_2_ca1_w(space, 0, data);
 }
 
 
-static const TTL74123_interface ic60_intf =
+static const ttl74123_config ic60_intf =
 {
 	TTL74123_GROUNDED,	/* the hook up type */
 	RES_K(22),			/* resistor connected to RCext */
@@ -369,19 +370,17 @@ static const TTL74123_interface ic60_intf =
 
 static MACHINE_START( spiders )
 {
-	pia_config(1, &pia_1_intf);
-	pia_config(2, &pia_2_intf);
-	pia_config(3, &pia_3_intf);
-	pia_config(4, &pia_4_intf);
-
-	TTL74123_config(0, &ic60_intf);
+	pia_config(machine, 1, &pia_1_intf);
+	pia_config(machine, 2, &pia_2_intf);
+	pia_config(machine, 3, &pia_3_intf);
+	pia_config(machine, 4, &pia_4_intf);
 
 	/* setup for save states */
-	state_save_register_global(flipscreen);
-	state_save_register_global(gfx_rom_address);
-	state_save_register_global(gfx_rom_ctrl_mode);
-	state_save_register_global(gfx_rom_ctrl_latch);
-	state_save_register_global(gfx_rom_ctrl_data);
+	state_save_register_global(machine, flipscreen);
+	state_save_register_global(machine, gfx_rom_address);
+	state_save_register_global(machine, gfx_rom_ctrl_mode);
+	state_save_register_global(machine, gfx_rom_ctrl_latch);
+	state_save_register_global(machine, gfx_rom_ctrl_data);
 }
 
 
@@ -395,7 +394,6 @@ static MACHINE_START( spiders )
 static MACHINE_RESET( spiders )
 {
 	pia_reset();
-	TTL74123_reset(0);
 }
 
 
@@ -415,8 +413,7 @@ static WRITE8_HANDLER( flipscreen_w )
 }
 
 
-static void *begin_update(running_machine *machine, int screen,
-						  mame_bitmap *bitmap, const rectangle *cliprect)
+static MC6845_BEGIN_UPDATE( begin_update )
 {
 	/* create the pens */
 	offs_t i;
@@ -431,8 +428,7 @@ static void *begin_update(running_machine *machine, int screen,
 }
 
 
-static void update_row(mame_bitmap *bitmap, const rectangle *cliprect,
-					   UINT16 ma, UINT8 ra, UINT16 y, UINT8 x_count, void *param)
+static MC6845_UPDATE_ROW( update_row )
 {
 	UINT8 cx;
 
@@ -491,28 +487,31 @@ static void update_row(mame_bitmap *bitmap, const rectangle *cliprect,
 }
 
 
-static void display_enable_changed(int display_enabled)
+static MC6845_ON_DE_CHANGED( display_enable_changed )
 {
-	TTL74123_A_w(0, display_enabled);
+	ttl74123_a_w(devtag_get_device(device->machine, TTL74123, "ic60"), 0, display_enabled);
 }
 
 
-static const crtc6845_interface crtc6845_intf =
+static const mc6845_interface mc6845_intf =
 {
-	0,						/* screen we are acting on */
-	CRTC_CLOCK, 			/* the clock (pin 21) of the chip */
+	"main",					/* screen we are acting on */
 	8,						/* number of pixels per video memory address */
 	begin_update,			/* before pixel update callback */
 	update_row,				/* row update callback */
 	0,						/* after pixel update callback */
-	display_enable_changed	/* call back for display state changes */
+	display_enable_changed,	/* callback for display state changes */
+	NULL,					/* HSYNC callback */
+	NULL					/* VSYNC callback */
 };
 
 
-static VIDEO_START( spiders )
+static VIDEO_UPDATE( spiders )
 {
-	/* configure the CRT controller */
-	crtc6845_config(0, &crtc6845_intf);
+	const device_config *mc6845 = device_list_find_by_tag(screen->machine->config->devicelist, MC6845, "crtc");
+	mc6845_update(mc6845, bitmap, cliprect);
+
+	return 0;
 }
 
 
@@ -538,7 +537,7 @@ static READ8_HANDLER( gfx_rom_r )
 
 	if (gfx_rom_ctrl_mode)
 	{
-		UINT8 *rom = memory_region(REGION_GFX1);
+		UINT8 *rom = memory_region(space->machine, "gfx1");
 
 		ret = rom[gfx_rom_address];
 
@@ -565,15 +564,15 @@ static READ8_HANDLER( gfx_rom_r )
 
 static ADDRESS_MAP_START( spiders_main_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_RAM AM_BASE(&spiders_ram)
-	AM_RANGE(0xc000, 0xc000) AM_WRITE(crtc6845_address_w)
-	AM_RANGE(0xc001, 0xc001) AM_READWRITE(crtc6845_register_r, crtc6845_register_w)
+	AM_RANGE(0xc000, 0xc000) AM_DEVWRITE(MC6845, "crtc", mc6845_address_w)
+	AM_RANGE(0xc001, 0xc001) AM_DEVREADWRITE(MC6845, "crtc", mc6845_register_r, mc6845_register_w)
 	AM_RANGE(0xc020, 0xc027) AM_RAM AM_BASE(&generic_nvram) AM_SIZE(&generic_nvram_size)
 	AM_RANGE(0xc044, 0xc047) AM_READWRITE(pia_1_r, pia_1_w)
 	AM_RANGE(0xc048, 0xc04b) AM_READWRITE(pia_2_alt_r, pia_2_alt_w)
 	AM_RANGE(0xc050, 0xc053) AM_READWRITE(pia_3_r, pia_3_w)
-	AM_RANGE(0xc060, 0xc060) AM_READ(input_port_2_r)
-	AM_RANGE(0xc080, 0xc080) AM_READ(input_port_3_r)
-	AM_RANGE(0xc0a0, 0xc0a0) AM_READ(input_port_4_r)
+	AM_RANGE(0xc060, 0xc060) AM_READ_PORT("DSW1")
+	AM_RANGE(0xc080, 0xc080) AM_READ_PORT("DSW2")
+	AM_RANGE(0xc0a0, 0xc0a0) AM_READ_PORT("DSW3")
 	AM_RANGE(0xc100, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
@@ -594,10 +593,10 @@ ADDRESS_MAP_END
 
 static INPUT_PORTS_START( spiders )
     /* PIA1 PA0 - PA7 */
-    PORT_START      /* IN0 */
+    PORT_START("IN0")	/* IN0 */
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_SERVICE1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN1 )
-	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_SERVICE ) PORT_NAME( DEF_STR( Service_Mode )) PORT_CODE(KEYCODE_F2)
+	PORT_SERVICE_NO_TOGGLE( 0x04, IP_ACTIVE_HIGH )
     PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(1)
 	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON1 ) PORT_PLAYER(2)
     PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_START1 )
@@ -605,14 +604,14 @@ static INPUT_PORTS_START( spiders )
     PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_SERVICE2 )
 
 	/* PIA1 PB0 - PB7 */
-    PORT_START      /* IN1 */
+    PORT_START("IN1")	/* IN1 */
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT  ) PORT_2WAY PORT_PLAYER(2)
     PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY PORT_PLAYER(2)
     PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_2WAY PORT_PLAYER(1)
     PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_2WAY PORT_PLAYER(1)
     PORT_BIT( 0xf0, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-    PORT_START  /* IN2, DSW1 */
+    PORT_START("DSW1")	/* IN2, DSW1 */
     PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coinage ) )	PORT_DIPLOCATION("SW1:1,2,3")
     PORT_DIPSETTING(    0x01, DEF_STR( 2C_1C ) )
     PORT_DIPSETTING(    0x07, DEF_STR( 1C_1C ) )
@@ -622,7 +621,7 @@ static INPUT_PORTS_START( spiders )
     PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
     PORT_BIT( 0xf8, IP_ACTIVE_LOW, IPT_UNUSED )
 
-    PORT_START  /* IN3, DSW2 */
+    PORT_START("DSW2")	/* IN3, DSW2 */
     PORT_DIPNAME( 0x03, 0x03, "Play Mode" ) PORT_DIPLOCATION("SW2:1,2")
     PORT_DIPSETTING(    0x00, "A A'" )
     PORT_DIPSETTING(    0x01, "A B'" )
@@ -645,7 +644,7 @@ static INPUT_PORTS_START( spiders )
     PORT_DIPSETTING(    0x00, "First Screen" )
     PORT_DIPSETTING(    0x80, "Every Screen" )
 
-    PORT_START  /* IN4, DSW3 */
+    PORT_START("DSW3")	/* IN4, DSW3 */
     PORT_DIPNAME( 0x01, 0x00, DEF_STR( Flip_Screen ) ) PORT_DIPLOCATION("SW3:1")
     PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
     PORT_DIPSETTING(    0x01, DEF_STR( On ) )
@@ -671,7 +670,7 @@ static INPUT_PORTS_START( spiders )
     PORT_DIPSETTING(    0xc0, "6" )
     PORT_DIPSETTING(    0xe0, "7" )
 
-    PORT_START      /* connected to PIA1 CB1 input */
+    PORT_START("XHATCH")	/* connected to PIA1 CB1 input */
     PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_OTHER ) PORT_NAME("PS1 (Crosshatch)") PORT_CODE(KEYCODE_F1)
 
 INPUT_PORTS_END
@@ -687,12 +686,11 @@ INPUT_PORTS_END
 static MACHINE_DRIVER_START( spiders )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M6809, 2800000)
+	MDRV_CPU_ADD("main", M6809, 2800000)
 	MDRV_CPU_PROGRAM_MAP(spiders_main_map,0)
 	MDRV_CPU_PERIODIC_INT(update_pia_1, 25)
 
-	/* audio CPU */
-	MDRV_CPU_ADD(M6802, 3000000)
+	MDRV_CPU_ADD("audio", M6802, 3000000)
 	MDRV_CPU_PROGRAM_MAP(spiders_audio_map,0)
 
 	MDRV_MACHINE_START(spiders)
@@ -700,14 +698,18 @@ static MACHINE_DRIVER_START( spiders )
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
-	MDRV_VIDEO_START(spiders)
-	MDRV_VIDEO_UPDATE(crtc6845)
+	MDRV_VIDEO_UPDATE(spiders)
 
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_RAW_PARAMS(PIXEL_CLOCK, 256, 0, 256, 256, 0, 256)	/* temporary, CRTC will configure screen */
 
+	MDRV_MC6845_ADD("crtc", MC6845, CRTC_CLOCK, mc6845_intf)
+
+	/* 74LS123 */
+
+	MDRV_TTL74123_ADD("ic60", ic60_intf)
+
 	/* audio hardware */
 	MDRV_IMPORT_FROM(spiders_audio)
 
@@ -722,16 +724,16 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( spiders )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "sp-ic74",      0xc000, 0x1000, CRC(6a2578f6) SHA1(ddfe4fb2ccc925df7ae97821f8681b32e47630b4) )
 	ROM_LOAD( "sp-ic73",      0xd000, 0x1000, CRC(d69b2f21) SHA1(ea2b07d19bd50c3b57da8fd8e13b8ab0e8ca3084) )
 	ROM_LOAD( "sp-ic72",      0xe000, 0x1000, CRC(464125da) SHA1(94e9edd52e8bd72bbb5dc91b0aa11955e940799c) )
 	ROM_LOAD( "sp-ic71",      0xf000, 0x1000, CRC(a9539b18) SHA1(2d02343a78a4a65e5a1798552cd015f16ad5423a) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "sp-ic3",       0xf800, 0x0800, CRC(944d761e) SHA1(23b1f9234e0de678e96d1a6876d8d0a341150385) )
 
-	ROM_REGION( 0x10000, REGION_GFX1, 0 )
+	ROM_REGION( 0x10000, "gfx1", 0 )
 	ROM_LOAD( "sp-ic33",      0x0000, 0x1000, CRC(b6731baa) SHA1(b551030df417b40f4a8488fc82a8b5809d3d32f6) )
 	ROM_LOAD( "sp-ic25",      0x1000, 0x1000, CRC(baec64e7) SHA1(beb45e2e6270607c14cdf964c08fe320ce8236a0) )
 	ROM_LOAD( "sp-ic24",      0x2000, 0x1000, CRC(a40a5517) SHA1(3f524c7dbbfe8aad7860d15c38d2702732895681) )
@@ -743,16 +745,16 @@ ROM_END
 
 
 ROM_START( spiders2 )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "sp-ic74",      0xc000, 0x1000, CRC(6a2578f6) SHA1(ddfe4fb2ccc925df7ae97821f8681b32e47630b4) )
 	ROM_LOAD( "sp2.bin",      0xd000, 0x1000, CRC(cf71d12b) SHA1(369e91f637e8cd898354ddee04e24d4894968f79) )
 	ROM_LOAD( "sp-ic72",      0xe000, 0x1000, CRC(464125da) SHA1(94e9edd52e8bd72bbb5dc91b0aa11955e940799c) )
 	ROM_LOAD( "sp4.bin",      0xf000, 0x1000, CRC(f3d126bb) SHA1(ecc9156a7da661fa7543d7656aa7da77274e0842) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "sp-ic3",       0xf800, 0x0800, CRC(944d761e) SHA1(23b1f9234e0de678e96d1a6876d8d0a341150385) )
 
-	ROM_REGION( 0x10000, REGION_GFX1, 0 )
+	ROM_REGION( 0x10000, "gfx1", 0 )
 	ROM_LOAD( "sp-ic33",      0x0000, 0x1000, CRC(b6731baa) SHA1(b551030df417b40f4a8488fc82a8b5809d3d32f6) )
 	ROM_LOAD( "sp-ic25",      0x1000, 0x1000, CRC(baec64e7) SHA1(beb45e2e6270607c14cdf964c08fe320ce8236a0) )
 	ROM_LOAD( "sp-ic24",      0x2000, 0x1000, CRC(a40a5517) SHA1(3f524c7dbbfe8aad7860d15c38d2702732895681) )
@@ -764,16 +766,16 @@ ROM_END
 
 
 ROM_START( spinner )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_REGION( 0x10000, "main", 0 )
 	ROM_LOAD( "sp01-100.r1",  0xc000, 0x1000, CRC(e85faa36) SHA1(ef1c479d503ef6a833ae1f9d5a260f9e50c1f2d4) )
 	ROM_LOAD( "sp02-99.s1",   0xd000, 0x1000, CRC(4bcd2b35) SHA1(dff3c6e68cc5384863a123661422d929e7406dee) )
 	ROM_LOAD( "sp03-98.t1",   0xe000, 0x1000, CRC(fdabc5df) SHA1(a3276eb1f09f6a3c406721f89993a39c92fb7728) )
 	ROM_LOAD( "sp04-97.v1",   0xf000, 0x1000, CRC(62798f96) SHA1(1407a2ccb2b8f998f2ee494f52a471b627895dbe) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "sp41-28.d9",   0xf800, 0x0800, CRC(944d761e) SHA1(23b1f9234e0de678e96d1a6876d8d0a341150385) )
 
-	ROM_REGION( 0x10000, REGION_GFX1, 0 )
+	ROM_REGION( 0x10000, "gfx1", 0 )
 	ROM_LOAD( "sp05-25.k8",   0x0000, 0x1000, CRC(ccc696ee) SHA1(1d41e9eb0cae73b221327d7b6e02450275d056c6) )
 	ROM_LOAD( "sp06-17.k9",   0x1000, 0x1000, CRC(d3d06722) SHA1(da510ed162e5c310945123c9ce6d5648c7b0ae48) )
 	ROM_LOAD( "sp07-16.l9",   0x2000, 0x1000, CRC(a40a5517) SHA1(3f524c7dbbfe8aad7860d15c38d2702732895681) )
