@@ -28,7 +28,9 @@ SX008-14.BIN ; /
 
 */
 
+
 #include "driver.h"
+#include "cpu/z80/z80.h"
 #include "cpu/mips/r3000.h"
 #include "sound/st0016.h"
 #include "st0016.h"
@@ -66,8 +68,9 @@ static VIDEO_UPDATE( srmp5 )
 	UINT16 *sprite_list=sprram;
 	UINT16 *sprite_list_end=&sprram[0x1000]; //guess
 	UINT8 *pixels=(UINT8 *)tileram;
+	const rectangle *visarea = video_screen_get_visible_area(screen);
 
-	fillbitmap(bitmap,0,&machine->screen[0].visarea);
+	bitmap_fill(bitmap,cliprect,0);
 
 	while((sprite_list[SUBLIST_OFFSET]&SPRITE_LIST_END_MARKER)==0 && sprite_list<sprite_list_end)
 	{
@@ -104,7 +107,7 @@ static VIDEO_UPDATE( srmp5 )
 
 		 						if(pen)
 		 						{
-		 							if(xb+xs<=machine->screen[0].visarea.max_x && xb+xs>=machine->screen[0].visarea.min_x && yb+ys<=machine->screen[0].visarea.max_y && yb+ys>=machine->screen[0].visarea.min_y )
+		 							if(xb+xs<=visarea->max_x && xb+xs>=visarea->min_x && yb+ys<=visarea->max_y && yb+ys>=visarea->min_y )
 		 							{
 		 								UINT32 pixdata=paletteram32[pen+((sprite_sublist[SPRITE_PALETTE]&0xff)<<8)];
 		 								*BITMAP_ADDR32(bitmap, yb+ys, xb+xs) = ((pixdata&0x7c00)>>7) | ((pixdata&0x3e0)<<6) | ((pixdata&0x1f)<<19);
@@ -155,21 +158,22 @@ static WRITE32_HANDLER(spr_w)
 static READ32_HANDLER(data_r)
 {
 	UINT32 data;
+	const UINT8 *usr = memory_region(space->machine, "user2");
 	data=((databank>>4)&0xf)*0x100000; //guess
-	data=memory_region(REGION_USER2)[data+offset*2]+memory_region(REGION_USER2)[data+offset*2+1]*256;
+	data=usr[data+offset*2]+usr[data+offset*2+1]*256;
 	return data|(data<<16);
 }
 
 static ADDRESS_MAP_START( srmp5_mem, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x00000000, 0x000fffff) AM_RAM //maybe 0 - 2fffff ?
 	AM_RANGE(0x002f0000, 0x002f7fff) AM_RAM
-	AM_RANGE(0x01000000, 0x01000003) AM_WRITE(MWA32_RAM)  // 0xaa .. watchdog ?
-	AM_RANGE(0x01800004, 0x01800007) AM_READ(input_port_0_dword_r)
-	AM_RANGE(0x01800008, 0x0180000b) AM_READ(input_port_1_dword_r)
+	AM_RANGE(0x01000000, 0x01000003) AM_WRITE(SMH_RAM)  // 0xaa .. watchdog ?
+	AM_RANGE(0x01800004, 0x01800007) AM_READ_PORT("IN0")
+	AM_RANGE(0x01800008, 0x0180000b) AM_READ_PORT("IN1")
 	AM_RANGE(0x0180000c, 0x0180000f) AM_WRITE(bank_w)
-	AM_RANGE(0x01800010, 0x01800013) AM_READ(input_port_2_dword_r) //multiplexed controls (selected by writes to 1c)
-	AM_RANGE(0x01800014, 0x01800017) AM_READ(input_port_3_dword_r)
-	AM_RANGE(0x0180001c, 0x0180001f) AM_WRITE(MWA32_RAM)//c1 c2 c4 c8 => mahjong inputs (at $10) - bits 0-3
+	AM_RANGE(0x01800010, 0x01800013) AM_READ_PORT("IN2") //multiplexed controls (selected by writes to 1c)
+	AM_RANGE(0x01800014, 0x01800017) AM_READ_PORT("IN3")
+	AM_RANGE(0x0180001c, 0x0180001f) AM_WRITE(SMH_RAM)//c1 c2 c4 c8 => mahjong inputs (at $10) - bits 0-3
 	AM_RANGE(0x01800200, 0x0180020f) AM_RAM  //sound related ? only few writes after boot
 	AM_RANGE(0x01a00000, 0x01bfffff) AM_READ(data_r)
 
@@ -177,10 +181,10 @@ static ADDRESS_MAP_START( srmp5_mem, ADDRESS_SPACE_PROGRAM, 32 )
 	AM_RANGE(0x0a100000, 0x0a1fffff) AM_RAM AM_BASE(&paletteram32)
 	AM_RANGE(0x0a200000, 0x0a3fffff) AM_READWRITE(tileram_r, tileram_w) AM_BASE(&videoram32)
 
-	AM_RANGE(0x1eff0000, 0x1eff001f) AM_WRITE(MWA32_RAM)
+	AM_RANGE(0x1eff0000, 0x1eff001f) AM_WRITE(SMH_RAM)
 	AM_RANGE(0x1eff003c, 0x1eff003f) AM_READNOP
-	AM_RANGE(0x1fc00000, 0x1fdfffff) AM_READ(MRA32_ROM) AM_WRITE(MWA32_ROM) AM_REGION(REGION_USER1, 0)
-	AM_RANGE(0x2fc00000, 0x2fdfffff) AM_READ(MRA32_ROM) AM_WRITE(MWA32_ROM) AM_REGION(REGION_USER1, 0)
+	AM_RANGE(0x1fc00000, 0x1fdfffff) AM_READ(SMH_ROM) AM_WRITE(SMH_ROM) AM_REGION("user1", 0)
+	AM_RANGE(0x2fc00000, 0x2fdfffff) AM_READ(SMH_ROM) AM_WRITE(SMH_ROM) AM_REGION("user1", 0)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( st0016_mem, ADDRESS_SPACE_PROGRAM, 8 )
@@ -190,7 +194,7 @@ static ADDRESS_MAP_START( st0016_mem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xd000, 0xdfff) AM_READ(st0016_sprite2_ram_r) AM_WRITE(st0016_sprite2_ram_w)
 	AM_RANGE(0xe000, 0xe7ff) AM_RAM
 	AM_RANGE(0xe800, 0xe87f) AM_RAM
-	AM_RANGE(0xe900, 0xe9ff) AM_RAM AM_WRITE(st0016_snd_w) AM_BASE(&st0016_sound_regs)
+	AM_RANGE(0xe900, 0xe9ff) AM_RAM_WRITE(st0016_snd_w) AM_BASE(&st0016_sound_regs)
 	AM_RANGE(0xea00, 0xebff) AM_READ(st0016_palette_ram_r) AM_WRITE(st0016_palette_ram_w)
 	AM_RANGE(0xec00, 0xec1f) AM_READ(st0016_character_ram_r) AM_WRITE(st0016_character_ram_w)
 	AM_RANGE(0xf000, 0xffff) AM_RAM
@@ -199,7 +203,7 @@ ADDRESS_MAP_END
 READ8_HANDLER(st0016_dma_r);
 
 static ADDRESS_MAP_START( st0016_io, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0xbf) AM_READ(st0016_vregs_r) AM_WRITE(st0016_vregs_w)
 	AM_RANGE(0xc0, 0xc3) AM_NOP // data from other cpu ?
 	AM_RANGE(0xe0, 0xe0) AM_WRITENOP
@@ -213,15 +217,8 @@ static ADDRESS_MAP_START( st0016_io, ADDRESS_SPACE_IO, 8 )
 ADDRESS_MAP_END
 
 
-static const struct r3000_config config =
-{
-	1,	/* 1 if we have an FPU, 0 otherwise */
-	4096,	/* code cache size */
-	4096	/* data cache size */
-};
-
 static INPUT_PORTS_START( srmp5 )
-	PORT_START
+	PORT_START("IN0")
 	PORT_DIPNAME( 0x0001, 0x0001, "0-0" )
 	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -264,7 +261,7 @@ static INPUT_PORTS_START( srmp5 )
 	PORT_DIPNAME( 0x2000, 0x2000, "0-d" )
 	PORT_DIPSETTING(      0x2000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-  PORT_DIPNAME( 0x4000, 0x4000, "0-e" )
+	PORT_DIPNAME( 0x4000, 0x4000, "0-e" )
 	PORT_DIPSETTING(      0x4000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 	PORT_DIPNAME( 0x8000, 0x8000, "0-f" )
@@ -312,14 +309,14 @@ static INPUT_PORTS_START( srmp5 )
 	PORT_DIPNAME( 0x20000000, 0x20000000, "0-1d" )
 	PORT_DIPSETTING(      0x20000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x00000000, DEF_STR( On ) )
-  PORT_DIPNAME( 0x40000000, 0x40000000, "0-1e" )
+	PORT_DIPNAME( 0x40000000, 0x40000000, "0-1e" )
 	PORT_DIPSETTING(      0x40000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x00000000, DEF_STR( On ) )
 	PORT_DIPNAME( 0x80000000, 0x80000000, "0-1f" )
 	PORT_DIPSETTING(      0x80000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x00000000, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN1")
 	PORT_DIPNAME( 0x0001, 0x0001, "1-0" )
 	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -362,7 +359,7 @@ static INPUT_PORTS_START( srmp5 )
 	PORT_DIPNAME( 0x2000, 0x2000, "1-d" )
 	PORT_DIPSETTING(      0x2000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-  PORT_DIPNAME( 0x4000, 0x4000, "1-e" )
+	PORT_DIPNAME( 0x4000, 0x4000, "1-e" )
 	PORT_DIPSETTING(      0x4000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 	PORT_DIPNAME( 0x8000, 0x8000, "1-f" )
@@ -411,14 +408,14 @@ static INPUT_PORTS_START( srmp5 )
 	PORT_DIPNAME( 0x20000000, 0x20000000, "1-1d" )
 	PORT_DIPSETTING(      0x20000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x00000000, DEF_STR( On ) )
-  PORT_DIPNAME( 0x40000000, 0x40000000, "1-1e" )
+	PORT_DIPNAME( 0x40000000, 0x40000000, "1-1e" )
 	PORT_DIPSETTING(      0x40000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x00000000, DEF_STR( On ) )
 	PORT_DIPNAME( 0x80000000, 0x80000000, "1-1f" )
 	PORT_DIPSETTING(      0x80000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x00000000, DEF_STR( On ) )
 
-PORT_START
+	PORT_START("IN2")
 	PORT_DIPNAME( 0x0001, 0x0001, "2-0" )
 	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -458,14 +455,13 @@ PORT_START
 	PORT_DIPNAME( 0x2000, 0x2000, "2-d" )
 	PORT_DIPSETTING(      0x2000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-  PORT_DIPNAME( 0x4000, 0x4000, "2-e" )
+	PORT_DIPNAME( 0x4000, 0x4000, "2-e" )
 	PORT_DIPSETTING(      0x4000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 	PORT_DIPNAME( 0x8000, 0x8000, "2-f" )
 	PORT_DIPSETTING(      0x8000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 
-
 	PORT_DIPNAME( 0x00010000, 0x00010000, "2-10" )
 	PORT_DIPSETTING(      0x00010000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -508,14 +504,14 @@ PORT_START
 	PORT_DIPNAME( 0x20000000, 0x20000000, "2-1d" )
 	PORT_DIPSETTING(      0x20000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x00000000, DEF_STR( On ) )
-  PORT_DIPNAME( 0x40000000, 0x40000000, "2-1e" )
+	PORT_DIPNAME( 0x40000000, 0x40000000, "2-1e" )
 	PORT_DIPSETTING(      0x40000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x00000000, DEF_STR( On ) )
 	PORT_DIPNAME( 0x80000000, 0x80000000, "2-1f" )
 	PORT_DIPSETTING(      0x80000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x00000000, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START("IN3")
 	PORT_DIPNAME( 0x0001, 0x0001, "3-0" )
 	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -558,7 +554,7 @@ PORT_START
 	PORT_DIPNAME( 0x2000, 0x2000, "3-d" )
 	PORT_DIPSETTING(      0x2000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
-  PORT_DIPNAME( 0x4000, 0x4000, "3-e" )
+	PORT_DIPNAME( 0x4000, 0x4000, "3-e" )
 	PORT_DIPSETTING(      0x4000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 	PORT_DIPNAME( 0x8000, 0x8000, "3-f" )
@@ -607,7 +603,7 @@ PORT_START
 	PORT_DIPNAME( 0x20000000, 0x20000000, "3-1d" )
 	PORT_DIPSETTING(      0x20000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x00000000, DEF_STR( On ) )
-  PORT_DIPNAME( 0x40000000, 0x40000000, "3-1e" )
+	PORT_DIPNAME( 0x40000000, 0x40000000, "3-1e" )
 	PORT_DIPSETTING(      0x40000000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x00000000, DEF_STR( On ) )
 	PORT_DIPNAME( 0x80000000, 0x80000000, "3-1f" )
@@ -615,29 +611,45 @@ PORT_START
 	PORT_DIPSETTING(      0x00000000, DEF_STR( On ) )
 INPUT_PORTS_END
 
-static const struct ST0016interface st0016_interface =
+static const st0016_interface st0016_config =
 {
 	&st0016_charram
 };
 
+ static INTERRUPT_GEN( irq4_gen )
+{
+	cpu_set_input_line(device, R3000_IRQ4, ASSERT_LINE);
+}
+
+static const r3000_cpu_core config =
+{
+	1,	/* 1 if we have an FPU, 0 otherwise */
+	4096,	/* code cache size */
+	4096	/* data cache size */
+};
+
 static MACHINE_DRIVER_START( srmp5 )
-	MDRV_CPU_ADD_TAG("main",Z80,8000000)
+	/* basic machine hardware */
+	MDRV_CPU_ADD("main",Z80,8000000)
 	MDRV_CPU_PROGRAM_MAP(st0016_mem,0)
 	MDRV_CPU_IO_MAP(st0016_io,0)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_hold)
 
-  MDRV_CPU_ADD(R3000LE, 40000000)
+	MDRV_CPU_ADD("sub", R3000LE, 25000000)
 	MDRV_CPU_CONFIG(config)
-	MDRV_CPU_VBLANK_INT(irq4_line_hold,2)
 	MDRV_CPU_PROGRAM_MAP(srmp5_mem,0)
+	MDRV_CPU_VBLANK_INT("main", irq4_gen)
 
+	MDRV_QUANTUM_TIME(HZ(6000))
+
+	/* video hardware */
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
-	MDRV_SCREEN_SIZE(64*8, 64*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 350, 30, 280)
+	MDRV_SCREEN_SIZE(512, 512)
+	MDRV_SCREEN_VISIBLE_AREA(4, 339, 32, 271)
+
 	MDRV_PALETTE_LENGTH(16*16*4+1)
 
 	MDRV_VIDEO_START(st0016)
@@ -645,25 +657,25 @@ static MACHINE_DRIVER_START( srmp5 )
 
 	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
 
-	MDRV_SOUND_ADD(ST0016, 0)
-	MDRV_SOUND_CONFIG(st0016_interface)
+	MDRV_SOUND_ADD("st", ST0016, 0)
+	MDRV_SOUND_CONFIG(st0016_config)
 	MDRV_SOUND_ROUTE(0, "left", 1.0)
 	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 ROM_START( srmp5 )
-	ROM_REGION( 0x410000, REGION_CPU1, 0 )
+	ROM_REGION( 0x410000, "main", 0 )
 	ROM_LOAD( "sx008-08.bin",   0x010000, 0x200000,   CRC(d4ac54f4) SHA1(c3dc76cd71485796a0b6a960294ea96eae8c946e) )
-	ROM_LOAD( "sx008-09.bin",   0x200000, 0x200000,   CRC(5a3e6560) SHA1(92ea398f3c5e3035869f0ca5dfe7b05c90095318) )
-	ROM_COPY( REGION_CPU1,  0x10000, 0x00000, 0x08000 )
+	ROM_LOAD( "sx008-09.bin",   0x210000, 0x200000,   CRC(5a3e6560) SHA1(92ea398f3c5e3035869f0ca5dfe7b05c90095318) )
+	ROM_COPY( "main",  0x10000, 0x00000, 0x08000 )
 
-	ROM_REGION32_BE( 0x200000, REGION_USER1, 0 )
+	ROM_REGION32_BE( 0x200000, "user1", 0 )
 	ROM_LOAD32_BYTE( "sx008-14.bin",   0x00000, 0x80000,   CRC(b5c55120) SHA1(0a41351c9563b2c6a00709189a917757bd6e0a24) )
 	ROM_LOAD32_BYTE( "sx008-13.bin",   0x00001, 0x80000,   CRC(0af475e8) SHA1(24cddffa0f8c81832ae8870823d772e3b7493194) )
 	ROM_LOAD32_BYTE( "sx008-12.bin",   0x00002, 0x80000,   CRC(43e9bb98) SHA1(e46dd98d2e1babfa12ddf2fa9b31377e8691d3a1) )
 	ROM_LOAD32_BYTE( "sx008-11.bin",   0x00003, 0x80000,   CRC(ca15ff45) SHA1(5ee610e0bb835568c36898210a6f8394902d5b54) )
 
-	ROM_REGION( 0x200000*8, REGION_USER2,0) /* gfx ? */
+	ROM_REGION( 0xf00000, "user2",0) /* gfx ? */
 	ROM_LOAD( "sx008-01.bin",   0x000000, 0x200000,   CRC(82dabf48) SHA1(c53e9ed0056c431eab13ab362936c25d3cc5abba) )
 	ROM_LOAD( "sx008-02.bin",   0x200000, 0x200000,   CRC(cfd2be0f) SHA1(a21f2928e08047c97443123aceba7ff4e95c6d3d) )
 	ROM_LOAD( "sx008-03.bin",   0x400000, 0x200000,   CRC(d7323b10) SHA1(94ecc17b6b8b071cf2c61bbef4aec2c6c7693c62) )
