@@ -20,7 +20,7 @@ according prg ROM (offset $0fff80):
     V1.00
 
 TODO:
- - sound emulation (appears to be really close to st0016)
+ - fix sound emulation
  - fix DMA operations
  - fix video emulation
 
@@ -67,7 +67,9 @@ Dumped 06/15/2000
 
 
 #include "driver.h"
+#include "cpu/m68000/m68000.h"
 #include "deprecat.h"
+#include "sound/nile.h"
 
 static UINT16* tileram;
 static UINT8* dirty_tileram;
@@ -91,7 +93,7 @@ static const gfx_layout tiles8x8_layout =
 	8*64
 };
 
-static void update_palette(void)
+static void update_palette(running_machine *machine)
 {
 	INT8 r, g ,b;
 	int brg = brightness - 0x60;
@@ -119,15 +121,15 @@ static void update_palette(void)
 			b += ((0x1F - b) * brg) >> 5;
 			if(b > 0x1F) b = 0x1F;
 		}
-		palette_set_color(Machine, i, MAKE_RGB(r << 3, g << 3, b << 3));
+		palette_set_color(machine, i, MAKE_RGB(r << 3, g << 3, b << 3));
 	}
 }
 
 static VIDEO_START(srmp6)
 {
 	/* create the char set (gfx will then be updated dynamically from RAM) */
-	machine->gfx[0] = allocgfx(&tiles8x8_layout);
-	machine->gfx[0]->total_colors = machine->drv->total_colors / 256;
+	machine->gfx[0] = allocgfx(machine, &tiles8x8_layout);
+	machine->gfx[0]->total_colors = machine->config->total_colors / 256;
 	machine->gfx[0]->color_granularity=256;
 
 	tileram = auto_malloc(0x100000*16);
@@ -146,14 +148,14 @@ static VIDEO_START(srmp6)
 
 /* Debug code */
 #ifdef UNUSED_FUNCTION
-static void srmp6_decode_charram(void)
+static void srmp6_decode_charram(running_machine *machine)
 {
 	if(input_code_pressed_once(KEYCODE_Z))
 	{
 		int i;
 		for (i=0;i<(0x100000*16)/0x40;i++)
 		{
-			decodechar(Machine->gfx[0], i, (UINT8*)tileram);
+			decodechar(machine->gfx[0], i, (UINT8*)tileram);
 			dirty_tileram[i] = 0;
 		}
 	}
@@ -177,11 +179,11 @@ static VIDEO_UPDATE(srmp6)
 		UINT16 b;
 	} temp;
 
-	fillbitmap(bitmap,0,&machine->screen[0].visarea);
+	bitmap_fill(bitmap,cliprect,0);
 
 #if 0
 	/* debug */
-	srmp6_decode_charram();
+	srmp6_decode_charram(screen->machine);
 
 
 
@@ -273,11 +275,11 @@ static VIDEO_UPDATE(srmp6)
 
 						if (dirty_tileram[tileno])
 						{
-							decodechar(machine->gfx[0], tileno, (UINT8*)tileram);
+							decodechar(screen->machine->gfx[0], tileno, (UINT8*)tileram);
 							dirty_tileram[tileno] = 0;
 						}
 
-						drawgfx(bitmap,machine->gfx[0],tileno,global_pal,flip_x,flip_y,xb,yb,cliprect,trans,0);
+						drawgfx(bitmap,screen->machine->gfx[0],tileno,global_pal,flip_x,flip_y,xb,yb,cliprect,trans,0);
 						tileno++;
 		 			}
 				}
@@ -290,50 +292,18 @@ static VIDEO_UPDATE(srmp6)
 	}
 
 	memcpy(sprram_old, sprram, 0x80000);
+
+	if(input_code_pressed_once(KEYCODE_Q))
+	{
+		FILE *p=fopen("tileram.bin","wb");
+		fwrite(tileram,1,0x100000*16,p);
+		fclose(p);
+	}
+
+
 	return 0;
 }
 
-/***************************************************************************
-    audio - VERY preliminary
-
-    TODO: watch similarities with st0016
-***************************************************************************/
-
-/*
-cpu #0 (PC=00011F7C): unmapped program memory word write to 004E0002 = 0000 & FFFF  0?
-cpu #0 (PC=00011F84): unmapped program memory word write to 004E0004 = 0D50 & FFFF  lo word \ sample start
-cpu #0 (PC=00011F8A): unmapped program memory word write to 004E0006 = 0070 & FFFF  hi word / address?
-
-cpu #0 (PC=00011FBA): unmapped program memory word write to 004E000A = 0000 & FFFF  0?
-cpu #0 (PC=00011FC2): unmapped program memory word write to 004E0018 = 866C & FFFF  lo word \ sample stop
-cpu #0 (PC=00011FC8): unmapped program memory word write to 004E001A = 00AA & FFFF  hi word / address?
-
-cpu #0 (PC=00011FD0): unmapped program memory word write to 004E000C = 0FFF & FFFF
-cpu #0 (PC=00011FD8): unmapped program memory word write to 004E001C = FFFF & FFFF
-cpu #0 (PC=00011FDC): unmapped program memory word write to 004E001E = FFFF & FFFF
-
-cpu #0 (PC=00026EFA): unmapped program memory word write to 004E0100 = 0001 & FFFF  ctrl word r/w: bit 7-0 = voice 8-1 (1=play,0=stop)
-
-voice #1: $4E0000-$4E001F
-voice #2: $4E0020-$4E003F
-voice #3: $4E0040-$4E005F
-...
-voice #8: $4E00E0-$4E00FF
-
-voice regs:
-offset  description
-+00
-+02     always 0?
-+04     lo-word \ sample
-+06     hi-word / counter ?
-+0A
-+18 \
-+1A /
-+1C \
-+1E /
-
-*/
-
 /***************************************************************************
     Main CPU memory handlers
 ***************************************************************************/
@@ -348,14 +318,14 @@ static WRITE16_HANDLER( srmp6_input_select_w )
 static READ16_HANDLER( srmp6_inputs_r )
 {
 	if (offset == 0)			// DSW
-		return readinputport(4);
+		return input_port_read(space->machine, "DSW");
 
 	switch(srmp6_input_select)	// inputs
 	{
-		case 1<<0: return readinputport(0);
-		case 1<<1: return readinputport(1);
-		case 1<<2: return readinputport(2);
-		case 1<<3: return readinputport(3);
+		case 1<<0: return input_port_read(space->machine, "KEY0");
+		case 1<<1: return input_port_read(space->machine, "KEY1");
+		case 1<<2: return input_port_read(space->machine, "KEY2");
+		case 1<<3: return input_port_read(space->machine, "KEY3");
 	}
 
 	return 0;
@@ -372,7 +342,7 @@ static WRITE16_HANDLER( video_regs_w )
 		case 0x5e/2: // bank switch, used by ROM check
 			LOG(("%x\n",data));
 
-			memory_set_bankptr(1,(UINT16 *)(memory_region(REGION_USER2) + (data & 0x0f)*0x200000));
+			memory_set_bankptr(space->machine, 1,(UINT16 *)(memory_region(space->machine, "nile") + (data & 0x0f)*0x200000));
 			break;
 
 		// set by IT4
@@ -381,7 +351,7 @@ static WRITE16_HANDLER( video_regs_w )
 			data = (!data)?0x60:(data == 0x5e)?0x60:data;
 			if(brightness != data) {
 				brightness = data;
-				update_palette();
+				update_palette(space->machine);
 			}
 			break;
 
@@ -396,7 +366,7 @@ static WRITE16_HANDLER( video_regs_w )
 		case 0x56/2: // written 8,9,8,9 successively
 
 		default:
-			logerror("video_regs_w (PC=%06X): %04x = %04x & %04x\n", activecpu_get_previouspc(), offset*2, data, mem_mask);
+			logerror("video_regs_w (PC=%06X): %04x = %04x & %04x\n", cpu_get_previouspc(space->cpu), offset*2, data, mem_mask);
 			break;
 	}
 	COMBINE_DATA(&video_regs[offset]);
@@ -404,7 +374,7 @@ static WRITE16_HANDLER( video_regs_w )
 
 static READ16_HANDLER( video_regs_r )
 {
-	logerror("video_regs_r (PC=%06X): %04x\n", activecpu_get_previouspc(), offset*2);
+	logerror("video_regs_r (PC=%06X): %04x\n", cpu_get_previouspc(space->cpu), offset*2);
 	return video_regs[offset];
 }
 
@@ -455,6 +425,7 @@ static WRITE16_HANDLER(srmp6_dma_w)
 	COMBINE_DATA(&dmaram[offset]);
 	if(offset==13 && dmaram[offset]==0x40)
 	{
+		const UINT8 *rom = memory_region(space->machine, "nile");
 		UINT32 srctab=2*((((UINT32)dmaram[5])<<16)|dmaram[4]);
 		UINT32 srcdata=2*((((UINT32)dmaram[11])<<16)|dmaram[10]);
 		UINT32 len=4*(((((UINT32)dmaram[7]&3)<<16)|dmaram[6])+1); //??? WRONG!
@@ -485,19 +456,19 @@ static WRITE16_HANDLER(srmp6_dma_w)
 		while(1)
 		{
 			int i;
-			UINT8 ctrl=memory_region(REGION_USER2)[srcdata];
+			UINT8 ctrl=rom[srcdata];
  			++srcdata;
 
 			for(i=0;i<8;++i)
 			{
-				UINT8 p=memory_region(REGION_USER2)[srcdata];
+				UINT8 p=rom[srcdata];
 
 				if(ctrl&0x80)
 				{
 					UINT8 real_byte;
-					real_byte = memory_region(REGION_USER2)[srctab+p*2];
+					real_byte = rom[srctab+p*2];
 					tempidx+=process(real_byte,tempidx);
-					real_byte = memory_region(REGION_USER2)[srctab+p*2+1];//px[DMA_XOR((current_table_address+p*2+1))];
+					real_byte = rom[srctab+p*2+1];//px[DMA_XOR((current_table_address+p*2+1))];
 					tempidx+=process(real_byte,tempidx);
  				}
  				else
@@ -535,7 +506,7 @@ static WRITE16_HANDLER(tileram_w)
 	if (offset >= 0xfff00/2 && offset <= 0xfff1a/2 )
 	{
 		offset &=0x1f;
-		srmp6_dma_w(offset,data,mem_mask);
+		srmp6_dma_w(space,offset,data,mem_mask);
 	}
 }
 
@@ -544,7 +515,7 @@ static WRITE16_HANDLER(paletteram_w)
 	INT8 r, g, b;
 	int brg = brightness - 0x60;
 
-	paletteram16_xBBBBBGGGGGRRRRR_word_w(offset, data, mem_mask);
+	paletteram16_xBBBBBGGGGGRRRRR_word_w(space, offset, data, mem_mask);
 
 	if(brg)
 	{
@@ -569,18 +540,18 @@ static WRITE16_HANDLER(paletteram_w)
 			if(b > 0x1F) b = 0x1F;
 		}
 
-		palette_set_color(Machine, offset, MAKE_RGB(r << 3, g << 3, b << 3));
+		palette_set_color(space->machine, offset, MAKE_RGB(r << 3, g << 3, b << 3));
 	}
 }
 
 static ADDRESS_MAP_START( srmp6, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x0fffff) AM_ROM
 	AM_RANGE(0x200000, 0x23ffff) AM_RAM					// work RAM
-	AM_RANGE(0x600000, 0x7fffff) AM_READ(MRA16_BANK1)	// banked ROM (used by ROM check)
-	AM_RANGE(0x800000, 0x9fffff) AM_ROM AM_REGION(REGION_USER1, 0)
+	AM_RANGE(0x600000, 0x7fffff) AM_READ(SMH_BANK1)		// banked ROM (used by ROM check)
+	AM_RANGE(0x800000, 0x9fffff) AM_ROM AM_REGION("user1", 0)
 
 	AM_RANGE(0x300000, 0x300005) AM_READWRITE(srmp6_inputs_r, srmp6_input_select_w)		// inputs
-	AM_RANGE(0x480000, 0x480fff) AM_READWRITE(MRA16_RAM, paletteram_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x480000, 0x480fff) AM_RAM_WRITE(paletteram_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x4d0000, 0x4d0001) AM_READWRITE(watchdog_reset16_r, watchdog_reset16_w)	// watchdog
 
 	// OBJ RAM: checked [$400000-$47dfff]
@@ -591,8 +562,8 @@ static ADDRESS_MAP_START( srmp6, ADDRESS_SPACE_PROGRAM, 16 )
 //  AM_RANGE(0x5fff00, 0x5fffff) AM_WRITE(dma_w) AM_BASE(&dmaram)
 
 	AM_RANGE(0x4c0000, 0x4c006f) AM_READWRITE(video_regs_r, video_regs_w) AM_BASE(&video_regs)	// ? gfx regs ST-0026 NiLe
-//  AM_RANGE(0x4e0000, 0x4e00ff) AM_READWRITE(sound_regs_r, sound_regs_w) AM_BASE(&sound_regs)  // ? sound regs (data) ST-0026 NiLe
-//  AM_RANGE(0x4e0100, 0x4e0101) AM_READWRITE(sndctrl_reg_r, sndctrl_reg_w)                     // ? sound reg  (ctrl) ST-0026 NiLe
+  	AM_RANGE(0x4e0000, 0x4e00ff) AM_READWRITE(nile_snd_r, nile_snd_w) AM_BASE(&nile_sound_regs)
+  	AM_RANGE(0x4e0100, 0x4e0101) AM_READWRITE(nile_sndctrl_r, nile_sndctrl_w)
 //  AM_RANGE(0x4e0110, 0x4e0111) AM_NOP // ? accessed once ($268dc, written $b.w)
 //  AM_RANGE(0x5fff00, 0x5fff1f) AM_RAM // ? see routine $5ca8, video_regs related ???
 
@@ -608,44 +579,44 @@ ADDRESS_MAP_END
 
 static INPUT_PORTS_START( srmp6 )
 
-	PORT_START
-	PORT_BIT ( 0xfe01, IP_ACTIVE_LOW, IPT_UNUSED ) // explicitely discarded
-	PORT_BIT ( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_A )
-	PORT_BIT ( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_E )
-	PORT_BIT ( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_I )
-	PORT_BIT ( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_M )
-	PORT_BIT ( 0x0020, IP_ACTIVE_LOW, IPT_MAHJONG_KAN )
-	PORT_BIT ( 0x0040, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT ( 0x0080, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(2)
-	PORT_BIT ( 0x0100, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME(DEF_STR( Test )) PORT_CODE(KEYCODE_F2)
+	PORT_START("KEY0")
+	PORT_BIT( 0xfe01, IP_ACTIVE_LOW, IPT_UNUSED ) // explicitely discarded
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_A )
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_E )
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_I )
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_M )
+	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_MAHJONG_KAN )
+	PORT_BIT( 0x0040, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x0080, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(2)
+	PORT_SERVICE_NO_TOGGLE( 0x0100, IP_ACTIVE_LOW )
 
-	PORT_START
-	PORT_BIT ( 0xfe41, IP_ACTIVE_LOW, IPT_UNUSED ) // explicitely discarded
-	PORT_BIT ( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_B )
-	PORT_BIT ( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_F )
-	PORT_BIT ( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_J )
-	PORT_BIT ( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_N )
-	PORT_BIT ( 0x0020, IP_ACTIVE_LOW, IPT_MAHJONG_REACH )
-	PORT_BIT ( 0x0180, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_START("KEY1")
+	PORT_BIT( 0xfe41, IP_ACTIVE_LOW, IPT_UNUSED ) // explicitely discarded
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_B )
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_F )
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_J )
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_N )
+	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_MAHJONG_REACH )
+	PORT_BIT( 0x0180, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
-	PORT_BIT ( 0xfe41, IP_ACTIVE_LOW, IPT_UNUSED ) // explicitely discarded
-	PORT_BIT ( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_C )
-	PORT_BIT ( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_G )
-	PORT_BIT ( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_K )
-	PORT_BIT ( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_CHI )
-	PORT_BIT ( 0x0020, IP_ACTIVE_LOW, IPT_MAHJONG_RON )
-	PORT_BIT ( 0x0180, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_START("KEY2")
+	PORT_BIT( 0xfe41, IP_ACTIVE_LOW, IPT_UNUSED ) // explicitely discarded
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_C )
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_G )
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_K )
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_CHI )
+	PORT_BIT( 0x0020, IP_ACTIVE_LOW, IPT_MAHJONG_RON )
+	PORT_BIT( 0x0180, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START
-	PORT_BIT ( 0xfe61, IP_ACTIVE_LOW, IPT_UNUSED ) // explicitely discarded
-	PORT_BIT ( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_D )
-	PORT_BIT ( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_H )
-	PORT_BIT ( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_L )
-	PORT_BIT ( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_PON )
-	PORT_BIT ( 0x0180, IP_ACTIVE_LOW, IPT_UNUSED )
+	PORT_START("KEY3")
+	PORT_BIT( 0xfe61, IP_ACTIVE_LOW, IPT_UNUSED ) // explicitely discarded
+	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_MAHJONG_D )
+	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_MAHJONG_H )
+	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_MAHJONG_L )
+	PORT_BIT( 0x0010, IP_ACTIVE_LOW, IPT_MAHJONG_PON )
+	PORT_BIT( 0x0180, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	/* 16-bit DSW1+DSW2 */
+	PORT_START("DSW")	/* 16-bit DSW1+DSW2 */
 	PORT_DIPNAME( 0x0007, 0x0007, DEF_STR( Coinage ) )		// DSW1
 	PORT_DIPSETTING(      0x0000, DEF_STR( 5C_1C ) )
 	PORT_DIPSETTING(      0x0001, DEF_STR( 4C_1C ) )
@@ -700,60 +671,53 @@ INPUT_PORTS_END
 
 static INTERRUPT_GEN(srmp6_interrupt)
 {
-	if(!cpu_getiloops())
-		cpunum_set_input_line(machine, 0,3,HOLD_LINE);
+	if(!cpu_getiloops(device))
+		cpu_set_input_line(device,3,HOLD_LINE);
 	else
-		cpunum_set_input_line(machine, 0,4,HOLD_LINE);
+		cpu_set_input_line(device,4,HOLD_LINE);
 }
 
 static MACHINE_DRIVER_START( srmp6 )
-	MDRV_CPU_ADD(M68000, 16000000)
+	MDRV_CPU_ADD("main", M68000, 16000000)
 	MDRV_CPU_PROGRAM_MAP(srmp6,0)
-	MDRV_CPU_VBLANK_INT(srmp6_interrupt,2)
+	MDRV_CPU_VBLANK_INT_HACK(srmp6_interrupt,2)
 
+
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_SIZE(64*8, 64*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 42*8-1, 0*8, 30*8-1)
+
 	MDRV_PALETTE_LENGTH(0x800)
 
 	MDRV_VIDEO_START(srmp6)
 	MDRV_VIDEO_UPDATE(srmp6)
 
 	/* sound hardware */
+	MDRV_SPEAKER_STANDARD_STEREO("left", "right")
+
+	MDRV_SOUND_ADD("nile", NILE, 0)
+	MDRV_SOUND_ROUTE(0, "left", 1.0)
+	MDRV_SOUND_ROUTE(1, "right", 1.0)
 MACHINE_DRIVER_END
 
 
 /***************************************************************************
     ROM definition(s)
 ***************************************************************************/
-/*
-CHR?
-    sx011-05.18 '00':[23a640,300000[
-    sx011-04.19
-    sx011-03.20
-    sx011-02.21
-    sx011-01.22 '00':[266670,400000[ (end)
 
-most are 8 bits unsigned PCM 16/32KHz if stereo/mono
-some voices in 2nd rom have lower sample rate
-    sx011-08.15 <- samples: instruments, musics, sound FXs, voices
-    sx011-07.16 <- samples: voices (cont'd), sound FXs, music, theme music
-    sx011-06.17 <- samples: theme music (cont'd)
-*/
 ROM_START( srmp6 )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_REGION( 0x100000, "main", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "sx011-10.4", 0x000001, 0x080000, CRC(8f4318a5) SHA1(44160968cca027b3d42805f2dd42662d11257ef6) )
 	ROM_LOAD16_BYTE( "sx011-11.5", 0x000000, 0x080000, CRC(7503d9cf) SHA1(03ab35f13b6166cb362aceeda18e6eda8d3abf50) )
 
-	ROM_REGION( 0x200000, REGION_USER1, 0 ) /* 68000 Data */
+	ROM_REGION( 0x200000, "user1", 0 ) /* 68000 Data */
 	ROM_LOAD( "sx011-09.10", 0x000000, 0x200000, CRC(58f74438) SHA1(a256e39ca0406e513ab4dbd812fb0b559b4f61f2) )
 
  	/* these are accessed directly by the 68k, DMA device etc.  NOT decoded */
-	ROM_REGION( 0x2000000, REGION_USER2, 0)	/* Banked ROM */
+	ROM_REGION( 0x2000000, "nile", 0)	/* Banked ROM */
 	ROM_LOAD16_WORD_SWAP( "sx011-08.15", 0x0000000, 0x0400000, CRC(01b3b1f0) SHA1(bbd60509c9ba78358edbcbb5953eafafd6e2eaf5) ) // CHR00
 	ROM_LOAD16_WORD_SWAP( "sx011-07.16", 0x0400000, 0x0400000, CRC(26e57dac) SHA1(91272268977c5fbff7e8fbe1147bf108bd2ed321) ) // CHR01
 	ROM_LOAD16_WORD_SWAP( "sx011-06.17", 0x0800000, 0x0400000, CRC(220ee32c) SHA1(77f39b54891c2381b967534b0f6d380962eadcae) ) // CHR02
@@ -765,19 +729,10 @@ ROM_START( srmp6 )
 ROM_END
 
 
-/***************************************************************************
-    Driver initialization
-***************************************************************************/
-
-static DRIVER_INIT( srmp6 )
-{
-}
-
 
 /***************************************************************************
     Game driver(s)
 ***************************************************************************/
 
 /*GAME( YEAR,NAME,PARENT,MACHINE,INPUT,INIT,MONITOR,COMPANY,FULLNAME,FLAGS)*/
-GAME( 1995, srmp6, 0, srmp6, srmp6, srmp6, ROT0, "Seta", "Super Real Mahjong P6 (Japan)", GAME_IMPERFECT_GRAPHICS | GAME_NO_SOUND)
-
+GAME( 1995, srmp6, 0, srmp6, srmp6, 0, ROT0, "Seta", "Super Real Mahjong P6 (Japan)", GAME_IMPERFECT_GRAPHICS | GAME_IMPERFECT_SOUND)
