@@ -23,7 +23,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "cpu/m6809/m6809.h"
 #include "video/vector.h"
 #include "video/avgdvg.h"
@@ -40,7 +39,9 @@ UINT8 starwars_is_esb;
 /* Local variables */
 static UINT8 *slapstic_source;
 static UINT8 *slapstic_base;
-static UINT8 current_bank;
+static UINT8 slapstic_current_bank;
+static offs_t slapstic_last_pc;
+static offs_t slapstic_last_address;
 
 
 
@@ -55,13 +56,15 @@ static MACHINE_RESET( starwars )
 	/* ESB-specific */
 	if (starwars_is_esb)
 	{
+		const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 		/* reset the slapstic */
 		slapstic_reset();
-		current_bank = slapstic_bank();
-		memcpy(slapstic_base, &slapstic_source[current_bank * 0x2000], 0x2000);
+		slapstic_current_bank = slapstic_bank();
+		memcpy(slapstic_base, &slapstic_source[slapstic_current_bank * 0x2000], 0x2000);
 
 		/* reset all the banks */
-		starwars_out_w(4, 0);
+		starwars_out_w(space, 4, 0);
 	}
 
 	/* reset the matrix processor */
@@ -78,7 +81,7 @@ static MACHINE_RESET( starwars )
 
 static WRITE8_HANDLER( irq_ack_w )
 {
-	cpunum_set_input_line(Machine, 0, M6809_IRQ_LINE, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[0], M6809_IRQ_LINE, CLEAR_LINE);
 }
 
 
@@ -89,31 +92,30 @@ static WRITE8_HANDLER( irq_ack_w )
  *
  *************************************/
 
+static void esb_slapstic_tweak(const address_space *space, offs_t offset)
+{
+	int new_bank = slapstic_tweak(space, offset);
+
+	/* update for the new bank */
+	if (new_bank != slapstic_current_bank)
+	{
+		slapstic_current_bank = new_bank;
+		memcpy(slapstic_base, &slapstic_source[slapstic_current_bank * 0x2000], 0x2000);
+	}
+}
+
+
 static READ8_HANDLER( esb_slapstic_r )
 {
 	int result = slapstic_base[offset];
-	int new_bank = slapstic_tweak(offset);
-
-	/* update for the new bank */
-	if (new_bank != current_bank)
-	{
-		current_bank = new_bank;
-		memcpy(slapstic_base, &slapstic_source[current_bank * 0x2000], 0x2000);
-	}
+	esb_slapstic_tweak(space, offset);
 	return result;
 }
 
 
 static WRITE8_HANDLER( esb_slapstic_w )
 {
-	int new_bank = slapstic_tweak(offset);
-
-	/* update for the new bank */
-	if (new_bank != current_bank)
-	{
-		current_bank = new_bank;
-		memcpy(slapstic_base, &slapstic_source[current_bank * 0x2000], 0x2000);
-	}
+	esb_slapstic_tweak(space, offset);
 }
 
 
@@ -124,36 +126,31 @@ static WRITE8_HANDLER( esb_slapstic_w )
  *
  *************************************/
 
-static OPBASE_HANDLER( esb_setopbase )
+static DIRECT_UPDATE_HANDLER( esb_setdirect )
 {
-	int prevpc = activecpu_get_previouspc();
-
-	/*
-     *  This is a slightly ugly kludge for Empire Strikes Back because it jumps
-     *  directly to code in the slapstic.
-     */
-
-	/* if we're jumping into the slapstic region, tweak the new PC */
+	/* if we are in the slapstic region, process it */
 	if ((address & 0xe000) == 0x8000)
 	{
-		esb_slapstic_r(address & 0x1fff);
+		offs_t pc = cpu_get_pc(space->cpu);
 
-		/* make sure we catch the next branch as well */
-		catch_nextBranch();
-		return -1;
+		/* filter out duplicates; we get these because the handler gets called for
+           multiple reasons:
+            1. Because we have read/write handlers backing the current address
+            2. Because the CPU core executed a jump to a new address
+        */
+		if (pc != slapstic_last_pc || address != slapstic_last_address)
+		{
+			slapstic_last_pc = pc;
+			slapstic_last_address = address;
+			esb_slapstic_tweak(space, address & 0x1fff);
+		}
+		return ~0;
 	}
-
-	/* if we're jumping out of the slapstic region, tweak the previous PC */
-	else if ((prevpc & 0xe000) == 0x8000)
-	{
-		if (prevpc != 0x8080 && prevpc != 0x8090 && prevpc != 0x80a0 && prevpc != 0x80b0)
-			esb_slapstic_r(prevpc & 0x1fff);
-	}
-
 	return address;
 }
 
 
+
 /*************************************
  *
  *  Main CPU memory handlers
@@ -161,12 +158,12 @@ static OPBASE_HANDLER( esb_setopbase )
  *************************************/
 
 static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x2fff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size) AM_REGION(REGION_CPU1, 0)
+	AM_RANGE(0x0000, 0x2fff) AM_RAM AM_BASE(&vectorram) AM_SIZE(&vectorram_size) AM_REGION("main", 0)
 	AM_RANGE(0x3000, 0x3fff) AM_ROM								/* vector_rom */
-	AM_RANGE(0x4300, 0x431f) AM_READ(input_port_0_r)			/* Memory mapped input port 0 */
-	AM_RANGE(0x4320, 0x433f) AM_READ(starwars_input_1_r)		/* Memory mapped input port 1 */
-	AM_RANGE(0x4340, 0x435f) AM_READ(input_port_2_r)			/* DIP switches bank 0 */
-	AM_RANGE(0x4360, 0x437f) AM_READ(input_port_3_r)			/* DIP switches bank 1 */
+	AM_RANGE(0x4300, 0x431f) AM_READ_PORT("IN0")
+	AM_RANGE(0x4320, 0x433f) AM_READ_PORT("IN1")
+	AM_RANGE(0x4340, 0x435f) AM_READ_PORT("DSW0")
+	AM_RANGE(0x4360, 0x437f) AM_READ_PORT("DSW1")
 	AM_RANGE(0x4380, 0x439f) AM_READ(starwars_adc_r)			/* a-d control result */
 	AM_RANGE(0x4400, 0x4400) AM_READWRITE(starwars_main_read_r, starwars_main_wr_w)
 	AM_RANGE(0x4401, 0x4401) AM_READ(starwars_main_ready_flag_r)
@@ -175,7 +172,7 @@ static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x4620, 0x463f) AM_WRITE(avgdvg_reset_w)
 	AM_RANGE(0x4640, 0x465f) AM_WRITE(watchdog_reset_w)
 	AM_RANGE(0x4660, 0x467f) AM_WRITE(irq_ack_w)
-	AM_RANGE(0x4680, 0x469f) AM_READWRITE(MRA8_NOP,starwars_out_w)
+	AM_RANGE(0x4680, 0x469f) AM_READWRITE(SMH_NOP,starwars_out_w)
 	AM_RANGE(0x46a0, 0x46bf) AM_WRITE(starwars_nstore_w)
 	AM_RANGE(0x46c0, 0x46c2) AM_WRITE(starwars_adc_select_w)
 	AM_RANGE(0x46e0, 0x46e0) AM_WRITE(starwars_soundrst_w)
@@ -201,7 +198,7 @@ static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_WRITE(starwars_sout_w)
 	AM_RANGE(0x0800, 0x0fff) AM_READ(starwars_sin_r)		/* SIN Read */
 	AM_RANGE(0x1000, 0x107f) AM_RAM							/* 6532 ram */
-	AM_RANGE(0x1080, 0x109f) AM_READWRITE(starwars_m6532_r, starwars_m6532_w)
+	AM_RANGE(0x1080, 0x109f) AM_DEVREADWRITE(RIOT6532, "riot", riot6532_r, riot6532_w)
 	AM_RANGE(0x1800, 0x183f) AM_WRITE(quad_pokey_w)
 	AM_RANGE(0x2000, 0x27ff) AM_RAM							/* program RAM */
 	AM_RANGE(0x4000, 0x7fff) AM_ROM							/* sound roms */
@@ -217,156 +214,96 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( starwars )
-	PORT_START	/* IN0 */
-	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT ( 0x08, IP_ACTIVE_LOW, IPT_TILT )
+	PORT_START("IN0")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_TILT )
 	PORT_SERVICE( 0x10, IP_ACTIVE_LOW )
-	PORT_BIT ( 0x20, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_BUTTON4 )
-	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 )
+	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON4 )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 )
 
-	PORT_START	/* IN1 */
-	PORT_BIT ( 0x01, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT ( 0x02, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_START("IN1")
+	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME("Diagnostic Step") PORT_CODE(KEYCODE_F1)
-	PORT_BIT ( 0x08, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_BUTTON3 )
-	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 )
-	/* Bit 6 is MATH_RUN - see machine/starwars.c */
-	PORT_BIT ( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED )
-	/* Bit 7 is VG_HALT - see machine/starwars.c */
-	PORT_BIT ( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_UNUSED )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON3 )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 )
+	/* Bit 6 is VG_HALT */
+	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(avgdvg_done_r, NULL)
+	/* Bit 7 is MATH_RUN - see machine/starwars.c */
+	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(matrix_flag_r, NULL)
 
-	PORT_START	/* DSW0 */
-	PORT_DIPNAME(0x03, 0x00, "Starting Shields" )
-	PORT_DIPSETTING (  0x00, "6" )
-	PORT_DIPSETTING (  0x01, "7" )
-	PORT_DIPSETTING (  0x02, "8" )
-	PORT_DIPSETTING (  0x03, "9" )
-	PORT_DIPNAME(0x0c, 0x00, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING (  0x00, DEF_STR( Easy ) )
-	PORT_DIPSETTING (  0x04, "Moderate" )
-	PORT_DIPSETTING (  0x08, DEF_STR( Hard ) )
-	PORT_DIPSETTING (  0x0c, DEF_STR( Hardest ) )
-	PORT_DIPNAME(0x30, 0x00, "Bonus Shields" )
-	PORT_DIPSETTING (  0x00, "0" )
-	PORT_DIPSETTING (  0x10, "1" )
-	PORT_DIPSETTING (  0x20, "2" )
-	PORT_DIPSETTING (  0x30, "3" )
-	PORT_DIPNAME(0x40, 0x00, DEF_STR( Demo_Sounds ) )
-	PORT_DIPSETTING (  0x40, DEF_STR( Off ) )
-	PORT_DIPSETTING (  0x00, DEF_STR( On ) )
-	PORT_DIPNAME(0x80, 0x80, "Freeze" )
-	PORT_DIPSETTING (  0x80, DEF_STR( Off ) )
-	PORT_DIPSETTING (  0x00, DEF_STR( On ) )
+	PORT_START("DSW0")
+	PORT_DIPNAME( 0x03, 0x00, "Starting Shields" )
+	PORT_DIPSETTING(    0x00, "6" )
+	PORT_DIPSETTING(    0x01, "7" )
+	PORT_DIPSETTING(    0x02, "8" )
+	PORT_DIPSETTING(    0x03, "9" )
+	PORT_DIPNAME( 0x0c, 0x00, DEF_STR( Difficulty ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x04, "Moderate" )
+	PORT_DIPSETTING(    0x08, DEF_STR( Hard ) )
+	PORT_DIPSETTING(    0x0c, DEF_STR( Hardest ) )
+	PORT_DIPNAME( 0x30, 0x00, "Bonus Shields" )
+	PORT_DIPSETTING(    0x00, "0" )
+	PORT_DIPSETTING(    0x10, "1" )
+	PORT_DIPSETTING(    0x20, "2" )
+	PORT_DIPSETTING(    0x30, "3" )
+	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Demo_Sounds ) )
+	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x80, 0x80, "Freeze" )
+	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START	/* DSW1 */
-	PORT_DIPNAME(0x03, 0x02, DEF_STR( Coinage ) )
-	PORT_DIPSETTING (  0x03, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING (  0x02, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING (  0x01, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING (  0x00, DEF_STR( Free_Play ) )
-	PORT_DIPNAME(0x0c, 0x00, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING (  0x00, "*1" )
-	PORT_DIPSETTING (  0x04, "*4" )
-	PORT_DIPSETTING (  0x08, "*5" )
-	PORT_DIPSETTING (  0x0c, "*6" )
-	PORT_DIPNAME(0x10, 0x00, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING (  0x00, "*1" )
-	PORT_DIPSETTING (  0x10, "*2" )
-	PORT_DIPNAME(0xe0, 0x00, "Bonus Coinage" )
-	PORT_DIPSETTING (  0x20, "2 gives 1" )
-	PORT_DIPSETTING (  0x60, "4 gives 2" )
-	PORT_DIPSETTING (  0xa0, "3 gives 1" )
-	PORT_DIPSETTING (  0x40, "4 gives 1" )
-	PORT_DIPSETTING (  0x80, "5 gives 1" )
-	PORT_DIPSETTING (  0x00, DEF_STR( None ) )
-/* 0xc0 and 0xe0 None */
+	PORT_START("DSW1")
+	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Coinage ) )
+	PORT_DIPSETTING(    0x03, DEF_STR( 2C_1C ) )
+	PORT_DIPSETTING(    0x02, DEF_STR( 1C_1C ) )
+	PORT_DIPSETTING(    0x01, DEF_STR( 1C_2C ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
+	PORT_DIPNAME( 0x0c, 0x00, DEF_STR( Coin_B ) )
+	PORT_DIPSETTING(    0x00, "*1" )
+	PORT_DIPSETTING(    0x04, "*4" )
+	PORT_DIPSETTING(    0x08, "*5" )
+	PORT_DIPSETTING(    0x0c, "*6" )
+	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Coin_A ) )
+	PORT_DIPSETTING(    0x00, "*1" )
+	PORT_DIPSETTING(    0x10, "*2" )
+	PORT_DIPNAME( 0xe0, 0x00, "Bonus Coinage" )
+	PORT_DIPSETTING(    0x20, "2 gives 1" )
+	PORT_DIPSETTING(    0x60, "4 gives 2" )
+	PORT_DIPSETTING(    0xa0, "3 gives 1" )
+	PORT_DIPSETTING(    0x40, "4 gives 1" )
+	PORT_DIPSETTING(    0x80, "5 gives 1" )
+	PORT_DIPSETTING(    0x00, DEF_STR( None ) )
+	/* 0xc0 and 0xe0 None */
 
-	PORT_START	/* IN4 */
+	PORT_START("STICKY")
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_Y ) PORT_SENSITIVITY(70) PORT_KEYDELTA(30)
 
-	PORT_START	/* IN5 */
+	PORT_START("STICKX")
 	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_X ) PORT_SENSITIVITY(50) PORT_KEYDELTA(30)
 INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( esb )
-	PORT_START	/* IN0 */
-	PORT_BIT ( 0x01, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT ( 0x02, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT ( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_BIT ( 0x08, IP_ACTIVE_LOW, IPT_TILT )
-	PORT_SERVICE( 0x10, IP_ACTIVE_LOW )
-	PORT_BIT ( 0x20, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT ( 0x40, IP_ACTIVE_LOW, IPT_BUTTON4 )
-	PORT_BIT ( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 )
+	PORT_INCLUDE( starwars )
 
-	PORT_START	/* IN1 */
-	PORT_BIT ( 0x01, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT ( 0x02, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE ) PORT_NAME("Diagnostic Step") PORT_CODE(KEYCODE_F1)
-	PORT_BIT ( 0x08, IP_ACTIVE_HIGH, IPT_UNUSED )
-	PORT_BIT ( 0x10, IP_ACTIVE_LOW, IPT_BUTTON3 )
-	PORT_BIT ( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 )
-	/* Bit 6 is MATH_RUN - see machine/starwars.c */
-	PORT_BIT ( 0x40, IP_ACTIVE_HIGH, IPT_UNUSED )
-	/* Bit 7 is VG_HALT - see machine/starwars.c */
-	PORT_BIT ( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )
-
-	PORT_START	/* DSW0 */
-	PORT_DIPNAME(0x03, 0x03, "Starting Shields" )
-	PORT_DIPSETTING (  0x01, "2" )
-	PORT_DIPSETTING (  0x00, "3" )
-	PORT_DIPSETTING (  0x03, "4" )
-	PORT_DIPSETTING (  0x02, "5" )
-	PORT_DIPNAME(0x0c, 0x0c, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING (  0x08, DEF_STR( Easy ) )
-	PORT_DIPSETTING (  0x0c, "Moderate" )
-	PORT_DIPSETTING (  0x00, DEF_STR( Hard ) )
-	PORT_DIPSETTING (  0x04, DEF_STR( Hardest ) )
-	PORT_DIPNAME(0x30, 0x30, "Jedi-Letter Mode" )
-	PORT_DIPSETTING (  0x00, "Level Only" )
-	PORT_DIPSETTING (  0x10, "Level" )
-	PORT_DIPSETTING (  0x20, "Increment Only" )
-	PORT_DIPSETTING (  0x30, "Increment" )
-	PORT_DIPNAME(0x40, 0x40, DEF_STR( Demo_Sounds ) )
-	PORT_DIPSETTING (  0x00, DEF_STR( Off ) )
-	PORT_DIPSETTING (  0x40, DEF_STR( On ) )
-	PORT_DIPNAME(0x80, 0x80, "Freeze" )
-	PORT_DIPSETTING (  0x80, DEF_STR( Off ) )
-	PORT_DIPSETTING (  0x00, DEF_STR( On ) )
-
-	PORT_START	/* DSW1 */
-	PORT_DIPNAME(0x03, 0x02, DEF_STR( Coinage ) )
-	PORT_DIPSETTING (  0x03, DEF_STR( 2C_1C ) )
-	PORT_DIPSETTING (  0x02, DEF_STR( 1C_1C ) )
-	PORT_DIPSETTING (  0x01, DEF_STR( 1C_2C ) )
-	PORT_DIPSETTING (  0x00, DEF_STR( Free_Play ) )
-	PORT_DIPNAME(0x0c, 0x00, DEF_STR( Coin_B ) )
-	PORT_DIPSETTING (  0x00, "*1" )
-	PORT_DIPSETTING (  0x04, "*4" )
-	PORT_DIPSETTING (  0x08, "*5" )
-	PORT_DIPSETTING (  0x0c, "*6" )
-	PORT_DIPNAME(0x10, 0x00, DEF_STR( Coin_A ) )
-	PORT_DIPSETTING (  0x00, "*1" )
-	PORT_DIPSETTING (  0x10, "*2" )
-	PORT_DIPNAME(0xe0, 0xe0, "Bonus Coinage" )
-	PORT_DIPSETTING (  0x20, "2 gives 1" )
-	PORT_DIPSETTING (  0x60, "4 gives 2" )
-	PORT_DIPSETTING (  0xa0, "3 gives 1" )
-	PORT_DIPSETTING (  0x40, "4 gives 1" )
-	PORT_DIPSETTING (  0x80, "5 gives 1" )
-	PORT_DIPSETTING (  0xe0, DEF_STR( None ) )
-/* 0xc0 and 0x00 None */
-
-	PORT_START	/* IN4 */
-	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_Y ) PORT_SENSITIVITY(70) PORT_KEYDELTA(30)
-
-	PORT_START	/* IN5 */
-	PORT_BIT( 0xff, 0x80, IPT_AD_STICK_X ) PORT_SENSITIVITY(50) PORT_KEYDELTA(30)
+	PORT_MODIFY("DSW0")
+	PORT_DIPNAME( 0x03, 0x03, "Starting Shields" )
+	PORT_DIPSETTING(    0x01, "2" )
+	PORT_DIPSETTING(    0x00, "3" )
+	PORT_DIPSETTING(    0x03, "4" )
+	PORT_DIPSETTING(    0x02, "5" )
+	PORT_DIPNAME( 0x30, 0x30, "Jedi-Letter Mode" )
+	PORT_DIPSETTING(    0x00, "Level Only" )
+	PORT_DIPSETTING(    0x10, "Level" )
+	PORT_DIPSETTING(    0x20, "Increment Only" )
+	PORT_DIPSETTING(    0x30, "Increment" )
 INPUT_PORTS_END
 
 
@@ -380,46 +317,45 @@ INPUT_PORTS_END
 static MACHINE_DRIVER_START( starwars )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M6809, MASTER_CLOCK / 8)
+	MDRV_CPU_ADD("main", M6809, MASTER_CLOCK / 8)
 	MDRV_CPU_PROGRAM_MAP(main_map,0)
 	MDRV_CPU_PERIODIC_INT(irq0_line_assert, (double)MASTER_CLOCK / 4096 / 12)
-	MDRV_WATCHDOG_TIME_INIT(ATTOTIME_IN_HZ(CLOCK_3KHZ / 128))
+	MDRV_WATCHDOG_TIME_INIT(HZ(CLOCK_3KHZ / 128))
 
-	MDRV_CPU_ADD(M6809, MASTER_CLOCK / 8)
-	/* audio CPU */
+	MDRV_CPU_ADD("audio", M6809, MASTER_CLOCK / 8)
 	MDRV_CPU_PROGRAM_MAP(sound_map,0)
 
-	MDRV_SCREEN_REFRESH_RATE(40)
-	MDRV_SCREEN_VBLANK_TIME(0)
 	MDRV_MACHINE_RESET(starwars)
 	MDRV_NVRAM_HANDLER(generic_0fill)
 
+	MDRV_RIOT6532_ADD("riot", MASTER_CLOCK / 8, starwars_riot6532_intf)
+
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_VECTOR )
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB15)
+	MDRV_SCREEN_ADD("main", VECTOR)
+	MDRV_SCREEN_REFRESH_RATE(40)
 	MDRV_SCREEN_SIZE(400, 300)
 	MDRV_SCREEN_VISIBLE_AREA(0, 250, 0, 280)
-	MDRV_PALETTE_LENGTH(32768)
 
 	MDRV_VIDEO_START(avg_starwars)
 	MDRV_VIDEO_UPDATE(vector)
 
 	/* sound hardware */
+	MDRV_SOUND_START(starwars)
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(POKEY, 1500000)
+	MDRV_SOUND_ADD("pokey1", POKEY, 1500000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 
-	MDRV_SOUND_ADD(POKEY, 1500000)
+	MDRV_SOUND_ADD("pokey2", POKEY, 1500000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 
-	MDRV_SOUND_ADD(POKEY, 1500000)
+	MDRV_SOUND_ADD("pokey3", POKEY, 1500000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 
-	MDRV_SOUND_ADD(POKEY, 1500000)
+	MDRV_SOUND_ADD("pokey4", POKEY, 1500000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.20)
 
-	MDRV_SOUND_ADD(TMS5220, 640000)
+	MDRV_SOUND_ADD("tms", TMS5220, 640000)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
@@ -432,7 +368,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( starwar1 )
-	ROM_REGION( 0x12000, REGION_CPU1, 0 )     /* 2 64k ROM spaces */
+	ROM_REGION( 0x12000, "main", 0 )     /* 2 64k ROM spaces */
 	ROM_LOAD( "136021.105",   0x3000, 0x1000, CRC(538e7d2f) SHA1(032c933fd94a6b0b294beee29159a24494ae969b) ) /* 3000-3fff is 4k vector rom */
 	ROM_LOAD( "136021.114",   0x6000, 0x2000, CRC(e75ff867) SHA1(3a40de920c31ffa3c3e67f3edf653b79fcc5ddd7) )   /* ROM 0 bank pages 0 and 1 */
 	ROM_CONTINUE(            0x10000, 0x2000 )
@@ -442,17 +378,17 @@ ROM_START( starwar1 )
 	ROM_LOAD( "136021.206",   0xe000, 0x2000, CRC(c7e51237) SHA1(4960f4446271316e3f730eeb2531dbc702947395) ) /*  8k ROM 4 bank */
 
 	/* Sound ROMS */
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "136021.107",   0x4000, 0x2000, CRC(dbf3aea2) SHA1(c38661b2b846fe93487eef09ca3cda19c44f08a0) ) /* Sound ROM 0 */
 	ROM_RELOAD(               0xc000, 0x2000 )
 	ROM_LOAD( "136021.208",   0x6000, 0x2000, CRC(e38070a8) SHA1(c858ae1702efdd48615453ab46e488848891d139) ) /* Sound ROM 0 */
 	ROM_RELOAD(               0xe000, 0x2000 )
 
-	ROM_REGION( 0x100, REGION_USER1, 0)
+	ROM_REGION( 0x100, "user1", 0)
 	ROM_LOAD( "136021-105.1l",   0x0000, 0x0100, CRC(82fc3eb2) SHA1(184231c7baef598294860a7d2b8a23798c5c7da6) ) /* AVG PROM */
 
 	/* Mathbox PROMs */
-	ROM_REGION( 0x1000, REGION_USER2, 0)
+	ROM_REGION( 0x1000, "user2", 0)
 	ROM_LOAD( "136021.110",   0x0000, 0x0400, CRC(01061762) SHA1(199549ead9ff9a5d5db75a2d15aef0240feb1aca) ) /* PROM 0 */
 	ROM_LOAD( "136021.111",   0x0400, 0x0400, CRC(2e619b70) SHA1(f76132b884ffdf3a4fe58637238c5235aab50408) ) /* PROM 1 */
 	ROM_LOAD( "136021.112",   0x0800, 0x0400, CRC(6cfa3544) SHA1(be059bfffe6b5bfcb4af78e9e7a98870ccf21985) ) /* PROM 2 */
@@ -461,7 +397,7 @@ ROM_END
 
 
 ROM_START( starwars )
-	ROM_REGION( 0x12000, REGION_CPU1, 0 )     /* 2 64k ROM spaces */
+	ROM_REGION( 0x12000, "main", 0 )     /* 2 64k ROM spaces */
 	ROM_LOAD( "136021.105",   0x3000, 0x1000, CRC(538e7d2f) SHA1(032c933fd94a6b0b294beee29159a24494ae969b) ) /* 3000-3fff is 4k vector rom */
 	ROM_LOAD( "136021.214",   0x6000, 0x2000, CRC(04f1876e) SHA1(c1d3637cb31ece0890c25f6122d6bcd27e6ffe0c) )   /* ROM 0 bank pages 0 and 1 */
 	ROM_CONTINUE(            0x10000, 0x2000 )
@@ -471,17 +407,17 @@ ROM_START( starwars )
 	ROM_LOAD( "136021.206",   0xe000, 0x2000, CRC(c7e51237) SHA1(4960f4446271316e3f730eeb2531dbc702947395) ) /*  8k ROM 4 bank */
 
 	/* Sound ROMS */
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "136021.107",   0x4000, 0x2000, CRC(dbf3aea2) SHA1(c38661b2b846fe93487eef09ca3cda19c44f08a0) ) /* Sound ROM 0 */
 	ROM_RELOAD(               0xc000, 0x2000 )
 	ROM_LOAD( "136021.208",   0x6000, 0x2000, CRC(e38070a8) SHA1(c858ae1702efdd48615453ab46e488848891d139) ) /* Sound ROM 0 */
 	ROM_RELOAD(               0xe000, 0x2000 )
 
-	ROM_REGION( 0x100, REGION_USER1, 0)
+	ROM_REGION( 0x100, "user1", 0)
 	ROM_LOAD( "136021-105.1l",   0x0000, 0x0100, CRC(82fc3eb2) SHA1(184231c7baef598294860a7d2b8a23798c5c7da6) ) /* AVG PROM */
 
 	/* Mathbox PROMs */
-	ROM_REGION( 0x1000, REGION_USER2, 0 )
+	ROM_REGION( 0x1000, "user2", 0 )
 	ROM_LOAD( "136021.110",   0x0000, 0x0400, CRC(01061762) SHA1(199549ead9ff9a5d5db75a2d15aef0240feb1aca) ) /* PROM 0 */
 	ROM_LOAD( "136021.111",   0x0400, 0x0400, CRC(2e619b70) SHA1(f76132b884ffdf3a4fe58637238c5235aab50408) ) /* PROM 1 */
 	ROM_LOAD( "136021.112",   0x0800, 0x0400, CRC(6cfa3544) SHA1(be059bfffe6b5bfcb4af78e9e7a98870ccf21985) ) /* PROM 2 */
@@ -489,7 +425,7 @@ ROM_START( starwars )
 ROM_END
 
 ROM_START( tomcatsw )
-	ROM_REGION( 0x12000, REGION_CPU1, 0 )
+	ROM_REGION( 0x12000, "main", 0 )
 	ROM_LOAD( "tcavg3.1l",    0x3000, 0x1000, CRC(27188aa9) SHA1(5d9a978a7ac1913b57586e81045a1b955db27b48) )
 	ROM_LOAD( "tc6.1f",       0x6000, 0x2000, CRC(56e284ff) SHA1(a5fda9db0f6b8f7d28a4a607976fe978e62158cf) )
 	ROM_LOAD( "tc8.1hj",      0x8000, 0x2000, CRC(7b7575e3) SHA1(bdb838603ffb12195966d0ce454900253bc0f43f) )
@@ -497,17 +433,17 @@ ROM_START( tomcatsw )
 	ROM_LOAD( "tce.1m",       0xe000, 0x2000, CRC(4a3de8a3) SHA1(e48fc17201326358317f6b428e583ecaa3ecb881) )
 
 	/* Sound ROMS */
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "136021.107",   0x4000, 0x2000, NO_DUMP ) /* Sound ROM 0 */
 	ROM_RELOAD(               0xc000, 0x2000 )
 	ROM_LOAD( "136021.208",   0x6000, 0x2000, NO_DUMP ) /* Sound ROM 0 */
 	ROM_RELOAD(               0xe000, 0x2000 )
 
-	ROM_REGION( 0x100, REGION_USER1, 0)
+	ROM_REGION( 0x100, "user1", 0)
 	ROM_LOAD( "136021-105.1l",   0x0000, 0x0100, CRC(82fc3eb2) SHA1(184231c7baef598294860a7d2b8a23798c5c7da6) ) /* AVG PROM */
 
 	/* Mathbox PROMs */
-	ROM_REGION( 0x1000, REGION_USER2, 0 )
+	ROM_REGION( 0x1000, "user2", 0 )
 	ROM_LOAD( "136021.110",   0x0000, 0x0400, CRC(01061762) SHA1(199549ead9ff9a5d5db75a2d15aef0240feb1aca) ) /* PROM 0 */
 	ROM_LOAD( "136021.111",   0x0400, 0x0400, CRC(2e619b70) SHA1(f76132b884ffdf3a4fe58637238c5235aab50408) ) /* PROM 1 */
 	ROM_LOAD( "136021.112",   0x0800, 0x0400, CRC(6cfa3544) SHA1(be059bfffe6b5bfcb4af78e9e7a98870ccf21985) ) /* PROM 2 */
@@ -516,7 +452,7 @@ ROM_END
 
 
 ROM_START( esb )
-	ROM_REGION( 0x22000, REGION_CPU1, 0 )     /* 64k for code and a buttload for the banked ROMs */
+	ROM_REGION( 0x22000, "main", 0 )     /* 64k for code and a buttload for the banked ROMs */
 	ROM_LOAD( "136031.111",   0x03000, 0x1000, CRC(b1f9bd12) SHA1(76f15395c9fdcd80dd241307a377031a1f44e150) )    /* 3000-3fff is 4k vector rom */
 	ROM_LOAD( "136031.101",   0x06000, 0x2000, CRC(ef1e3ae5) SHA1(d228ff076faa7f9605badeee3b827adb62593e0a) )
 	ROM_CONTINUE(             0x10000, 0x2000 )
@@ -532,17 +468,17 @@ ROM_START( esb )
 	ROM_LOAD( "136031.106",   0x18000, 0x4000, CRC(76d07f59) SHA1(44dd018b406f95e1512ce92923c2c87f1458844f) ) /* slapstic 2, 3 */
 
 	/* Sound ROMS */
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "136031.113",   0x4000, 0x2000, CRC(24ae3815) SHA1(b1a93af76de79b902317eebbc50b400b1f8c1e3c) ) /* Sound ROM 0 */
 	ROM_CONTINUE(             0xc000, 0x2000 )
 	ROM_LOAD( "136031.112",   0x6000, 0x2000, CRC(ca72d341) SHA1(52de5b82bb85d7c9caad2047e540d0748aa93ba5) ) /* Sound ROM 1 */
 	ROM_CONTINUE(             0xe000, 0x2000 )
 
-	ROM_REGION( 0x100, REGION_USER1, 0)
+	ROM_REGION( 0x100, "user1", 0)
 	ROM_LOAD( "136021-105.1l",   0x0000, 0x0100, CRC(82fc3eb2) SHA1(184231c7baef598294860a7d2b8a23798c5c7da6) ) /* AVG PROM */
 
 	/* Mathbox PROMs */
-	ROM_REGION( 0x1000, REGION_USER2, 0 )
+	ROM_REGION( 0x1000, "user2", 0 )
 	ROM_LOAD( "136031.110",   0x0000, 0x0400, CRC(b8d0f69d) SHA1(c196f1a592bd1ac482a81e23efa224d9dfaefc0a) ) /* PROM 0 */
 	ROM_LOAD( "136031.109",   0x0400, 0x0400, CRC(6a2a4d98) SHA1(cefca71f025f92a193c5a7d8b5ab8be10db2fd44) ) /* PROM 1 */
 	ROM_LOAD( "136031.108",   0x0800, 0x0400, CRC(6a76138f) SHA1(9ef7af898a3e29d03f35045901023615a6a55205) ) /* PROM 2 */
@@ -564,43 +500,49 @@ static DRIVER_INIT( starwars )
 
 	/* prepare the mathbox */
 	starwars_is_esb = 0;
-	starwars_mproc_init();
+	starwars_mproc_init(machine);
 
 	/* initialize banking */
-	memory_configure_bank(1, 0, 2, memory_region(REGION_CPU1) + 0x6000, 0x10000 - 0x6000);
-	memory_set_bank(1, 0);
+	memory_configure_bank(machine, 1, 0, 2, memory_region(machine, "main") + 0x6000, 0x10000 - 0x6000);
+	memory_set_bank(machine, 1, 0);
 }
 
 
 static DRIVER_INIT( esb )
 {
+	UINT8 *rom = memory_region(machine, "main");
+
 	/* X2212 nvram */
 	generic_nvram = auto_malloc(generic_nvram_size);
 
 	/* init the slapstic */
-	slapstic_init(101);
-	slapstic_source = &memory_region(REGION_CPU1)[0x14000];
-	slapstic_base = &memory_region(REGION_CPU1)[0x08000];
+	slapstic_init(machine, 101);
+	slapstic_source = &rom[0x14000];
+	slapstic_base = &rom[0x08000];
 
 	/* install an opcode base handler */
-	memory_set_opbase_handler(0, esb_setopbase);
+	memory_set_direct_update_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), esb_setdirect);
 
 	/* install read/write handlers for it */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x9fff, 0, 0, esb_slapstic_r);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x9fff, 0, 0, esb_slapstic_w);
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x8000, 0x9fff, 0, 0, esb_slapstic_r, esb_slapstic_w);
 
 	/* install additional banking */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa000, 0xffff, 0, 0, MRA8_BANK2);
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xa000, 0xffff, 0, 0, SMH_BANK2);
 
 	/* prepare the matrix processor */
 	starwars_is_esb = 1;
-	starwars_mproc_init();
+	starwars_mproc_init(machine);
 
 	/* initialize banking */
-	memory_configure_bank(1, 0, 2, memory_region(REGION_CPU1) + 0x6000, 0x10000 - 0x6000);
-	memory_set_bank(1, 0);
-	memory_configure_bank(2, 0, 2, memory_region(REGION_CPU1) + 0xa000, 0x1c000 - 0xa000);
-	memory_set_bank(2, 0);
+	memory_configure_bank(machine, 1, 0, 2, rom + 0x6000, 0x10000 - 0x6000);
+	memory_set_bank(machine, 1, 0);
+	memory_configure_bank(machine, 2, 0, 2, rom + 0xa000, 0x1c000 - 0xa000);
+	memory_set_bank(machine, 2, 0);
+
+	/* additional globals for state saving */
+	state_save_register_global(machine, slapstic_current_bank);
+	state_save_register_global(machine, slapstic_last_pc);
+	state_save_register_global(machine, slapstic_last_address);
 }
 
 
