@@ -229,95 +229,66 @@ DONE? (check on real board)
 *****************************************************************************/
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
 #include "sound/2203intf.h"
 #include "sound/msm5205.h"
-
-// machine
-DRIVER_INIT( empcity );
-DRIVER_INIT( stfight );
-MACHINE_RESET( stfight );
-INTERRUPT_GEN( stfight_vb_interrupt );
-INTERRUPT_GEN( stfight_interrupt_1 );
-READ8_HANDLER( stfight_dsw_r );
-WRITE8_HANDLER( stfight_fm_w );
-WRITE8_HANDLER( stfight_voice_w );
-READ8_HANDLER( stfight_coin_r );
-WRITE8_HANDLER( stfight_coin_w );
-WRITE8_HANDLER( stfight_e800_w );
-READ8_HANDLER( stfight_fm_r );
-void stfight_adpcm_int( int data );
-WRITE8_HANDLER( stfight_adpcm_control_w );
-
-// video
-PALETTE_INIT( stfight );
-WRITE8_HANDLER( stfight_text_char_w );
-WRITE8_HANDLER( stfight_text_attr_w );
-WRITE8_HANDLER( stfight_vh_latch_w );
-WRITE8_HANDLER( stfight_sprite_bank_w );
-VIDEO_START( stfight );
-VIDEO_UPDATE( stfight );
-
-// video
-extern UINT8 *stfight_text_char_ram;
-extern UINT8 *stfight_text_attr_ram;
-extern UINT8 *stfight_vh_latch_ram;
-extern UINT8 *stfight_sprite_ram;
+#include "includes/stfight.h"
 
 static ADDRESS_MAP_START( readmem_cpu1, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_READ(MRA8_BANK1)          /* sf02.bin */
-	AM_RANGE(0xc000, 0xc1ff) AM_READ(MRA8_RAM)            /* palette ram */
-	AM_RANGE(0xc200, 0xc200) AM_READ(input_port_0_r)     /* IN1 */
-	AM_RANGE(0xc201, 0xc201) AM_READ(input_port_1_r)     /* IN2 */
-	AM_RANGE(0xc202, 0xc202) AM_READ(input_port_2_r)     /* IN3 */
-	AM_RANGE(0xc203, 0xc204) AM_READ(stfight_dsw_r)      /* DS0,1 */
-	AM_RANGE(0xc205, 0xc205) AM_READ(stfight_coin_r)     /* coin mech */
-	AM_RANGE(0xd000, 0xd7ff) AM_READ(MRA8_RAM)            /* video */
-	AM_RANGE(0xe000, 0xffff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x8000, 0xbfff) AM_READ(SMH_BANK1)			/* sf02.bin */
+	AM_RANGE(0xc000, 0xc1ff) AM_READ(SMH_RAM)			/* palette ram */
+	AM_RANGE(0xc200, 0xc200) AM_READ_PORT("P1")			/* IN1 */
+	AM_RANGE(0xc201, 0xc201) AM_READ_PORT("P2")			/* IN2 */
+	AM_RANGE(0xc202, 0xc202) AM_READ_PORT("START")		/* IN3 */
+	AM_RANGE(0xc203, 0xc204) AM_READ(stfight_dsw_r)		/* DS0,1 */
+	AM_RANGE(0xc205, 0xc205) AM_READ(stfight_coin_r)	/* coin mech */
+	AM_RANGE(0xd000, 0xd7ff) AM_READ(SMH_RAM)			/* video */
+	AM_RANGE(0xe000, 0xffff) AM_READ(SMH_RAM)
 
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem_cpu1, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0x8000, 0xbfff) AM_WRITE(MWA8_BANK1)                  /* sf02.bin */
-	AM_RANGE(0xc000, 0xc0ff) AM_WRITE(paletteram_xxxxBBBBRRRRGGGG_split1_w) AM_BASE(&paletteram)
-	AM_RANGE(0xc100, 0xc1ff) AM_WRITE(paletteram_xxxxBBBBRRRRGGGG_split2_w) AM_BASE(&paletteram_2)
+	AM_RANGE(0x0000, 0x7fff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x8000, 0xbfff) AM_WRITE(SMH_BANK1)                  /* sf02.bin */
+	AM_RANGE(0xc000, 0xc0ff) AM_WRITE(SMH_RAM) AM_BASE(&paletteram)
+	AM_RANGE(0xc100, 0xc1ff) AM_WRITE(SMH_RAM) AM_BASE(&paletteram_2)
 	AM_RANGE(0xc500, 0xc500) AM_WRITE(stfight_fm_w)               /* play fm sound */
 	AM_RANGE(0xc600, 0xc600) AM_WRITE(stfight_adpcm_control_w)    /* voice control */
 	AM_RANGE(0xc700, 0xc700) AM_WRITE(stfight_coin_w)             /* coin mech */
-	AM_RANGE(0xc804, 0xc806) AM_WRITE(MWA8_NOP)                    /* TBD */
+	AM_RANGE(0xc804, 0xc806) AM_WRITE(SMH_NOP)                    /* TBD */
 	AM_RANGE(0xc807, 0xc807) AM_WRITE(stfight_sprite_bank_w)
 	AM_RANGE(0xd000, 0xd3ff) AM_WRITE(stfight_text_char_w) AM_BASE(&stfight_text_char_ram)
 	AM_RANGE(0xd400, 0xd7ff) AM_WRITE(stfight_text_attr_w) AM_BASE(&stfight_text_attr_ram)
 	AM_RANGE(0xd800, 0xd808) AM_WRITE(stfight_vh_latch_w) AM_BASE(&stfight_vh_latch_ram)
-	AM_RANGE(0xe000, 0xefff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xf000, 0xffff) AM_WRITE(MWA8_RAM) AM_BASE(&stfight_sprite_ram)
+	AM_RANGE(0xe000, 0xefff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0xf000, 0xffff) AM_WRITE(SMH_RAM) AM_BASE(&stfight_sprite_ram)
 
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readmem_cpu2, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xc001, 0xc001) AM_READ(YM2203_read_port_0_r)
-	AM_RANGE(0xc801, 0xc801) AM_READ(YM2203_read_port_1_r)
+	AM_RANGE(0x0000, 0x7fff) AM_READ(SMH_ROM)
+	AM_RANGE(0xc001, 0xc001) AM_READ(ym2203_read_port_0_r)
+	AM_RANGE(0xc801, 0xc801) AM_READ(ym2203_read_port_1_r)
 	AM_RANGE(0xf000, 0xf000) AM_READ(stfight_fm_r)
-	AM_RANGE(0xf800, 0xffff) AM_READ(MRA8_RAM)
+	AM_RANGE(0xf800, 0xffff) AM_READ(SMH_RAM)
 
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem_cpu2, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xc000, 0xc000) AM_WRITE(YM2203_control_port_0_w)
-	AM_RANGE(0xc001, 0xc001) AM_WRITE(YM2203_write_port_0_w)
-	AM_RANGE(0xc800, 0xc800) AM_WRITE(YM2203_control_port_1_w)
-	AM_RANGE(0xc801, 0xc801) AM_WRITE(YM2203_write_port_1_w)
+	AM_RANGE(0x0000, 0x7fff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0xc000, 0xc000) AM_WRITE(ym2203_control_port_0_w)
+	AM_RANGE(0xc001, 0xc001) AM_WRITE(ym2203_write_port_0_w)
+	AM_RANGE(0xc800, 0xc800) AM_WRITE(ym2203_control_port_1_w)
+	AM_RANGE(0xc801, 0xc801) AM_WRITE(ym2203_write_port_1_w)
 	AM_RANGE(0xe800, 0xe800) AM_WRITE(stfight_e800_w)
-	AM_RANGE(0xf800, 0xffff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0xf800, 0xffff) AM_WRITE(SMH_RAM)
 
 ADDRESS_MAP_END
 
 
 static INPUT_PORTS_START( stfight )
-	PORT_START	/* PLAYER 1 */
+	PORT_START("P1")	/* PLAYER 1 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
@@ -327,7 +298,7 @@ static INPUT_PORTS_START( stfight )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	/* PLAYER 2 */
+	PORT_START("P2")	/* PLAYER 2 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
@@ -337,13 +308,12 @@ static INPUT_PORTS_START( stfight )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	/* START BUTTONS */
+	PORT_START("START")	/* START BUTTONS */
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0xe7, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	/* DSW0 */
-
+	PORT_START("DSW0")	/* DSW0 */
 	PORT_DIPNAME( 0x07, 0x00, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x07, DEF_STR( 5C_1C ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( 4C_1C ) )
@@ -366,7 +336,7 @@ static INPUT_PORTS_START( stfight )
 	PORT_DIPSETTING(    0x80, "Red" )
 	PORT_DIPSETTING(    0x00, "Blue" )
 
-	PORT_START	/* DSW1 */
+	PORT_START("DSW1")	/* DSW1 */
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Cabinet ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Cocktail ) )
@@ -389,7 +359,7 @@ static INPUT_PORTS_START( stfight )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 
-	PORT_START	/* COIN MECH */
+	PORT_START("COIN")	/* COIN MECH */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 ) PORT_IMPULSE(2)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 ) PORT_IMPULSE(2)
 INPUT_PORTS_END
@@ -469,14 +439,14 @@ static const gfx_layout spritelayout =
 
 
 static GFXDECODE_START( stfight )
-	GFXDECODE_ENTRY( REGION_GFX1, 0x0000, charlayout,   0,                16 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x0000, fglayout,     16*4,             16 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x0000, bglayout,     16*4+16*16,       16 )
-	GFXDECODE_ENTRY( REGION_GFX3, 0x0020, bglayout,     16*4+16*16,       16 )
-	GFXDECODE_ENTRY( REGION_GFX4, 0x0000, spritelayout, 16*4+16*16+16*16, 16 )
+	GFXDECODE_ENTRY( "gfx1", 0x0000, charlayout,   0,                16 )
+	GFXDECODE_ENTRY( "gfx2", 0x0000, fglayout,     16*4,             16 )
+	GFXDECODE_ENTRY( "gfx3", 0x0000, bglayout,     16*4+16*16,       16 )
+	GFXDECODE_ENTRY( "gfx3", 0x0020, bglayout,     16*4+16*16,       16 )
+	GFXDECODE_ENTRY( "gfx4", 0x0000, spritelayout, 16*4+16*16+16*16, 16 )
 GFXDECODE_END
 
-static const struct MSM5205interface msm5205_interface =
+static const msm5205_interface msm5205_config =
 {
 	stfight_adpcm_int,  /* interrupt function */
 	MSM5205_S48_4B		/* 8KHz               */
@@ -485,29 +455,28 @@ static const struct MSM5205interface msm5205_interface =
 static MACHINE_DRIVER_START( stfight )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80, 3000000)	/* 3 MHz */
+	MDRV_CPU_ADD("main", Z80, 3000000)	/* 3 MHz */
 	MDRV_CPU_PROGRAM_MAP(readmem_cpu1,writemem_cpu1)
-	MDRV_CPU_VBLANK_INT(stfight_vb_interrupt,1)
+	MDRV_CPU_VBLANK_INT("main", stfight_vb_interrupt)
 
-	MDRV_CPU_ADD(Z80, 3000000)
-	/* audio CPU */	/* 3 MHz */
+	MDRV_CPU_ADD("audio", Z80, 3000000)	/* 3 MHz */
 	MDRV_CPU_PROGRAM_MAP(readmem_cpu2,writemem_cpu2)
 	MDRV_CPU_PERIODIC_INT(irq0_line_hold,120)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(10)
+	MDRV_QUANTUM_TIME(HZ(600))
 
 	MDRV_MACHINE_RESET(stfight)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(32*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+
 	MDRV_GFXDECODE(stfight)
-	MDRV_PALETTE_LENGTH(256+1)
-	MDRV_COLORTABLE_LENGTH(16*4+16*16+16*16+16*16)
+	MDRV_PALETTE_LENGTH(16*4+16*16+16*16+16*16)
 
 	MDRV_PALETTE_INIT(stfight)
 	MDRV_VIDEO_START(stfight)
@@ -516,20 +485,20 @@ static MACHINE_DRIVER_START( stfight )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_ADD("ym1", YM2203, 3000000)
 	MDRV_SOUND_ROUTE(0, "mono", 0.15)
 	MDRV_SOUND_ROUTE(1, "mono", 0.15)
 	MDRV_SOUND_ROUTE(2, "mono", 0.15)
 	MDRV_SOUND_ROUTE(3, "mono", 0.10)
 
-	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_ADD("ym2", YM2203, 3000000)
 	MDRV_SOUND_ROUTE(0, "mono", 0.15)
 	MDRV_SOUND_ROUTE(1, "mono", 0.15)
 	MDRV_SOUND_ROUTE(2, "mono", 0.15)
 	MDRV_SOUND_ROUTE(3, "mono", 0.10)
 
-	MDRV_SOUND_ADD(MSM5205, 384000)
-	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ADD("msm", MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.50)
 MACHINE_DRIVER_END
 
@@ -541,43 +510,43 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( empcity )
-	ROM_REGION( 2*0x18000, REGION_CPU1, 0 )	/* 96k for code + 96k for decrypted opcodes */
+	ROM_REGION( 2*0x18000, "main", 0 )	/* 96k for code + 96k for decrypted opcodes */
 	ROM_LOAD( "ec_01.rom",  0x00000, 0x8000, CRC(fe01d9b1) SHA1(c4b62d1b7e3a062f6a7a75f49cce5712f9016f98) )
 	ROM_LOAD( "ec_02.rom",  0x10000, 0x8000, CRC(b3cf1ef7) SHA1(91bc92293cbb47c38a2552c5beea53894b87d446) )	/* bank switched */
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the second CPU */
+	ROM_REGION( 0x10000, "audio", 0 )	/* 64k for the second CPU */
 	ROM_LOAD( "ec_04.rom",  0x0000,  0x8000, CRC(aa3e7d1e) SHA1(da350384d55f011253d19ce17fc327cd2604257f) )
 
-	ROM_REGION( 0x02000, REGION_GFX1, ROMREGION_DISPOSE )	/* character data */
+	ROM_REGION( 0x02000, "gfx1", ROMREGION_DISPOSE )	/* character data */
 	ROM_LOAD( "sf17.bin",   0x0000, 0x2000, CRC(1b3706b5) SHA1(61f069329a7a836523ffc8cce915b0d0129fd896) )
 
-	ROM_REGION( 0x20000, REGION_GFX2, ROMREGION_DISPOSE ) /* foreground tile pixel data */
+	ROM_REGION( 0x20000, "gfx2", ROMREGION_DISPOSE ) /* foreground tile pixel data */
 	ROM_LOAD( "sf07.bin",   0x10000, 0x8000, CRC(2c6caa5f) SHA1(f6893cb87004979ead331897c684f995f850447e) )
 	ROM_LOAD( "sf08.bin",   0x18000, 0x8000, CRC(e11ded31) SHA1(e3e634ad324d51e52d79dd79e5e6e5697cb8d21f) )
 	ROM_LOAD( "sf05.bin",   0x00000, 0x8000, CRC(0c099a31) SHA1(dabaf8edc59e4954941cd8176031a358f45a1956) )
 	ROM_LOAD( "sf06.bin",   0x08000, 0x8000, CRC(3cc77c31) SHA1(13d2324df5a322d499c9959a6bb3a844edaefb45) )
 
-	ROM_REGION( 0x20000, REGION_GFX3, ROMREGION_DISPOSE )	/* background tile pixel data */
+	ROM_REGION( 0x20000, "gfx3", ROMREGION_DISPOSE )	/* background tile pixel data */
 	ROM_LOAD( "sf13.bin",   0x10000, 0x8000, CRC(0ae48dd3) SHA1(ca3d9aeb9f4343c379cef9282e408fbf8aa67d99) )
 	ROM_LOAD( "sf14.bin",   0x18000, 0x8000, CRC(debf5d76) SHA1(eb18c35166eb5f93be98b3c30c7d909c0a68eada) )
 	ROM_LOAD( "sf11.bin",   0x00000, 0x8000, CRC(8261ecfe) SHA1(5817f4a0458a949298414fe09c86bbcf50be52f3) )
 	ROM_LOAD( "sf12.bin",   0x08000, 0x8000, CRC(71137301) SHA1(087a9f401939bc30f1dafa9916e8d8c564595a57) )
 
-	ROM_REGION( 0x20000, REGION_GFX4, ROMREGION_DISPOSE )	/* sprite data */
+	ROM_REGION( 0x20000, "gfx4", ROMREGION_DISPOSE )	/* sprite data */
 	ROM_LOAD( "sf20.bin",   0x10000, 0x8000, CRC(8299f247) SHA1(71891f7b1fbfaed14c3854b7f6e10a3ddb4bd479) )
 	ROM_LOAD( "sf21.bin",   0x18000, 0x8000, CRC(b57dc037) SHA1(69ac79a95ba9ace7c9ca7af480a4a10176be5ace) )
 	ROM_LOAD( "sf18.bin",   0x00000, 0x8000, CRC(68acd627) SHA1(f98ff9ccb0913711079a2988e8dd08695fb5e107) )
 	ROM_LOAD( "sf19.bin",   0x08000, 0x8000, CRC(5170a057) SHA1(9222f9febc222fa0c2eead258ad77c857f6d40c8) )
 
-	ROM_REGION( 0x10000, REGION_GFX5, 0 )	/* foreground map data */
+	ROM_REGION( 0x10000, "gfx5", 0 )	/* foreground map data */
 	ROM_LOAD( "sf09.bin",   0x00000, 0x8000, CRC(8ceaf4fe) SHA1(5698f2ff44c109825b8d9d0b6dd2426624df668b) )
 	ROM_LOAD( "sf10.bin",   0x08000, 0x8000, CRC(5a1a227a) SHA1(24928ab218824ae1f5380398ceb90dcad525cc08) )
 
-	ROM_REGION( 0x10000, REGION_GFX6, 0 )	/* background map data */
+	ROM_REGION( 0x10000, "gfx6", 0 )	/* background map data */
 	ROM_LOAD( "sf15.bin",   0x00000, 0x8000, CRC(27a310bc) SHA1(dd30d72bc33b0bf7ddaf3ab730e028f51b20152a) )
 	ROM_LOAD( "sf16.bin",   0x08000, 0x8000, CRC(3d19ce18) SHA1(38f691a23c96ef672637965c1a13f6d1595f9d51) )
 
-	ROM_REGION( 0x0800, REGION_PROMS, 0 )
+	ROM_REGION( 0x0800, "proms", 0 )
 	ROM_LOAD( "82s129.006", 0x0000, 0x0100, CRC(f9424b5b) SHA1(e3bc23213406d35d54f1221f17f25d433df273a2) )	/* text lookup table */
 	ROM_LOAD( "82s129.002", 0x0100, 0x0100, CRC(c883d49b) SHA1(e84900ccf6f27e5043e43c0d85ea1e4eee7e52d3) )	/* fg lookup table */
 	ROM_LOAD( "82s129.003", 0x0200, 0x0100, CRC(af81882a) SHA1(b1008c991bd8d1157b3479e465ab286c70418b58) )
@@ -587,49 +556,49 @@ ROM_START( empcity )
 	ROM_LOAD( "82s129.066", 0x0600, 0x0100, CRC(51e8832f) SHA1(ed8c00559e7a02bb8c11861d747c8c64c01b7437) )
 	ROM_LOAD( "82s129.015", 0x0700, 0x0100, CRC(0eaf5158) SHA1(bafd4108708f66cd7b280e47152b108f3e254fc9) )	/* timing? (not used) */
 
-	ROM_REGION( 0x08000, REGION_SOUND1, 0 )	/* adpcm voice data */
+	ROM_REGION( 0x08000, "adpcm", 0 )	/* adpcm voice data */
 	ROM_LOAD( "sf04.bin",   0x00000, 0x8000, CRC(1b8d0c07) SHA1(c163ccd2b7ed6c84facc075eb1564ca399f3ba17) )
 ROM_END
 
 /* set just contained the 3 roms cpu.4u, cpu.2u and vid.2p and the prom 82s123.a7 */
 ROM_START( empcityu )
-	ROM_REGION( 2*0x18000, REGION_CPU1, 0 )	/* 96k for code + 96k for decrypted opcodes */
+	ROM_REGION( 2*0x18000, "main", 0 )	/* 96k for code + 96k for decrypted opcodes */
 	ROM_LOAD( "cpu.4u",  0x00000, 0x8000, CRC(e2c40ea3) SHA1(fd3c21fe3b5faf323a16be54ad2eed23b12c977e) )
 	ROM_LOAD( "cpu.2u",  0x10000, 0x8000, CRC(96ee8b81) SHA1(95b516c023766fae79241d4422814e39e268ae7d) )	/* bank switched */
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the second CPU */
+	ROM_REGION( 0x10000, "audio", 0 )	/* 64k for the second CPU */
 	ROM_LOAD( "ec_04.rom",  0x0000,  0x8000, CRC(aa3e7d1e) SHA1(da350384d55f011253d19ce17fc327cd2604257f) )
 
-	ROM_REGION( 0x02000, REGION_GFX1, ROMREGION_DISPOSE )	/* character data */
+	ROM_REGION( 0x02000, "gfx1", ROMREGION_DISPOSE )	/* character data */
 	ROM_LOAD( "vid.2p",   0x0000, 0x2000, CRC(15593793) SHA1(ac9ca8a0aa0ce3810f45aa41e74d4946ecced245) )
 
-	ROM_REGION( 0x20000, REGION_GFX2, ROMREGION_DISPOSE ) /* foreground tile pixel data */
+	ROM_REGION( 0x20000, "gfx2", ROMREGION_DISPOSE ) /* foreground tile pixel data */
 	ROM_LOAD( "sf07.bin",   0x10000, 0x8000, CRC(2c6caa5f) SHA1(f6893cb87004979ead331897c684f995f850447e) )
 	ROM_LOAD( "sf08.bin",   0x18000, 0x8000, CRC(e11ded31) SHA1(e3e634ad324d51e52d79dd79e5e6e5697cb8d21f) )
 	ROM_LOAD( "sf05.bin",   0x00000, 0x8000, CRC(0c099a31) SHA1(dabaf8edc59e4954941cd8176031a358f45a1956) )
 	ROM_LOAD( "sf06.bin",   0x08000, 0x8000, CRC(3cc77c31) SHA1(13d2324df5a322d499c9959a6bb3a844edaefb45) )
 
-	ROM_REGION( 0x20000, REGION_GFX3, ROMREGION_DISPOSE )	/* background tile pixel data */
+	ROM_REGION( 0x20000, "gfx3", ROMREGION_DISPOSE )	/* background tile pixel data */
 	ROM_LOAD( "sf13.bin",   0x10000, 0x8000, CRC(0ae48dd3) SHA1(ca3d9aeb9f4343c379cef9282e408fbf8aa67d99) )
 	ROM_LOAD( "sf14.bin",   0x18000, 0x8000, CRC(debf5d76) SHA1(eb18c35166eb5f93be98b3c30c7d909c0a68eada) )
 	ROM_LOAD( "sf11.bin",   0x00000, 0x8000, CRC(8261ecfe) SHA1(5817f4a0458a949298414fe09c86bbcf50be52f3) )
 	ROM_LOAD( "sf12.bin",   0x08000, 0x8000, CRC(71137301) SHA1(087a9f401939bc30f1dafa9916e8d8c564595a57) )
 
-	ROM_REGION( 0x20000, REGION_GFX4, ROMREGION_DISPOSE )	/* sprite data */
+	ROM_REGION( 0x20000, "gfx4", ROMREGION_DISPOSE )	/* sprite data */
 	ROM_LOAD( "sf20.bin",   0x10000, 0x8000, CRC(8299f247) SHA1(71891f7b1fbfaed14c3854b7f6e10a3ddb4bd479) )
 	ROM_LOAD( "sf21.bin",   0x18000, 0x8000, CRC(b57dc037) SHA1(69ac79a95ba9ace7c9ca7af480a4a10176be5ace) )
 	ROM_LOAD( "sf18.bin",   0x00000, 0x8000, CRC(68acd627) SHA1(f98ff9ccb0913711079a2988e8dd08695fb5e107) )
 	ROM_LOAD( "sf19.bin",   0x08000, 0x8000, CRC(5170a057) SHA1(9222f9febc222fa0c2eead258ad77c857f6d40c8) )
 
-	ROM_REGION( 0x10000, REGION_GFX5, 0 )	/* foreground map data */
+	ROM_REGION( 0x10000, "gfx5", 0 )	/* foreground map data */
 	ROM_LOAD( "sf09.bin",   0x00000, 0x8000, CRC(8ceaf4fe) SHA1(5698f2ff44c109825b8d9d0b6dd2426624df668b) )
 	ROM_LOAD( "sf10.bin",   0x08000, 0x8000, CRC(5a1a227a) SHA1(24928ab218824ae1f5380398ceb90dcad525cc08) )
 
-	ROM_REGION( 0x10000, REGION_GFX6, 0 )	/* background map data */
+	ROM_REGION( 0x10000, "gfx6", 0 )	/* background map data */
 	ROM_LOAD( "sf15.bin",   0x00000, 0x8000, CRC(27a310bc) SHA1(dd30d72bc33b0bf7ddaf3ab730e028f51b20152a) )
 	ROM_LOAD( "sf16.bin",   0x08000, 0x8000, CRC(3d19ce18) SHA1(38f691a23c96ef672637965c1a13f6d1595f9d51) )
 
-	ROM_REGION( 0x0800, REGION_PROMS, 0 )
+	ROM_REGION( 0x0800, "proms", 0 )
 	ROM_LOAD( "82s129.006", 0x0000, 0x0100, CRC(f9424b5b) SHA1(e3bc23213406d35d54f1221f17f25d433df273a2) )	/* text lookup table */
 	ROM_LOAD( "82s129.002", 0x0100, 0x0100, CRC(c883d49b) SHA1(e84900ccf6f27e5043e43c0d85ea1e4eee7e52d3) )	/* fg lookup table */
 	ROM_LOAD( "82s129.003", 0x0200, 0x0100, CRC(af81882a) SHA1(b1008c991bd8d1157b3479e465ab286c70418b58) )
@@ -639,51 +608,51 @@ ROM_START( empcityu )
 	ROM_LOAD( "82s129.066", 0x0600, 0x0100, CRC(51e8832f) SHA1(ed8c00559e7a02bb8c11861d747c8c64c01b7437) )
 	ROM_LOAD( "82s129.015", 0x0700, 0x0100, CRC(0eaf5158) SHA1(bafd4108708f66cd7b280e47152b108f3e254fc9) )	/* timing? (not used) */
 
-	ROM_REGION( 0x08000, REGION_SOUND1, 0 )	/* adpcm voice data */
+	ROM_REGION( 0x08000, "adpcm", 0 )	/* adpcm voice data */
 	ROM_LOAD( "sf04.bin",   0x00000, 0x8000, CRC(1b8d0c07) SHA1(c163ccd2b7ed6c84facc075eb1564ca399f3ba17) )
 
-	ROM_REGION( 0x020, REGION_USER1, 0 )
+	ROM_REGION( 0x020, "user1", 0 )
 	ROM_LOAD( "82s123.a7", 0x0000, 0x0020, CRC(93e2d292) SHA1(af8edd0cfe85f28ede9604cfaf4516d54e5277c9) )	/* ?*/
 ROM_END
 
 ROM_START( empcityj )
-	ROM_REGION( 2*0x18000, REGION_CPU1, 0 )	/* 96k for code + 96k for decrypted opcodes */
+	ROM_REGION( 2*0x18000, "main", 0 )	/* 96k for code + 96k for decrypted opcodes */
 	ROM_LOAD( "1.bin",      0x00000, 0x8000, CRC(8162331c) SHA1(f2fdf5fbc52d4ea692fb87fa049c48935a73d67b) )
 	ROM_LOAD( "2.bin",      0x10000, 0x8000, CRC(960edea6) SHA1(fd19475e841defe42625a94c40c6390b7e6e7682) )	/* bank switched */
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the second CPU */
+	ROM_REGION( 0x10000, "audio", 0 )	/* 64k for the second CPU */
 	ROM_LOAD( "ec_04.rom",  0x0000,  0x8000, CRC(aa3e7d1e) SHA1(da350384d55f011253d19ce17fc327cd2604257f) )
 
-	ROM_REGION( 0x02000, REGION_GFX1, ROMREGION_DISPOSE )	/* character data */
+	ROM_REGION( 0x02000, "gfx1", ROMREGION_DISPOSE )	/* character data */
 	ROM_LOAD( "sf17.bin",   0x0000, 0x2000, CRC(1b3706b5) SHA1(61f069329a7a836523ffc8cce915b0d0129fd896) )
 
-	ROM_REGION( 0x20000, REGION_GFX2, ROMREGION_DISPOSE ) /* foreground tile pixel data */
+	ROM_REGION( 0x20000, "gfx2", ROMREGION_DISPOSE ) /* foreground tile pixel data */
 	ROM_LOAD( "sf07.bin",   0x10000, 0x8000, CRC(2c6caa5f) SHA1(f6893cb87004979ead331897c684f995f850447e) )
 	ROM_LOAD( "sf08.bin",   0x18000, 0x8000, CRC(e11ded31) SHA1(e3e634ad324d51e52d79dd79e5e6e5697cb8d21f) )
 	ROM_LOAD( "sf05.bin",   0x00000, 0x8000, CRC(0c099a31) SHA1(dabaf8edc59e4954941cd8176031a358f45a1956) )
 	ROM_LOAD( "sf06.bin",   0x08000, 0x8000, CRC(3cc77c31) SHA1(13d2324df5a322d499c9959a6bb3a844edaefb45) )
 
-	ROM_REGION( 0x20000, REGION_GFX3, ROMREGION_DISPOSE )	/* background tile pixel data */
+	ROM_REGION( 0x20000, "gfx3", ROMREGION_DISPOSE )	/* background tile pixel data */
 	ROM_LOAD( "sf13.bin",   0x10000, 0x8000, CRC(0ae48dd3) SHA1(ca3d9aeb9f4343c379cef9282e408fbf8aa67d99) )
 	ROM_LOAD( "sf14.bin",   0x18000, 0x8000, CRC(debf5d76) SHA1(eb18c35166eb5f93be98b3c30c7d909c0a68eada) )
 	ROM_LOAD( "sf11.bin",   0x00000, 0x8000, CRC(8261ecfe) SHA1(5817f4a0458a949298414fe09c86bbcf50be52f3) )
 	ROM_LOAD( "sf12.bin",   0x08000, 0x8000, CRC(71137301) SHA1(087a9f401939bc30f1dafa9916e8d8c564595a57) )
 
-	ROM_REGION( 0x20000, REGION_GFX4, ROMREGION_DISPOSE )	/* sprite data */
+	ROM_REGION( 0x20000, "gfx4", ROMREGION_DISPOSE )	/* sprite data */
 	ROM_LOAD( "sf20.bin",   0x10000, 0x8000, CRC(8299f247) SHA1(71891f7b1fbfaed14c3854b7f6e10a3ddb4bd479) )
 	ROM_LOAD( "sf21.bin",   0x18000, 0x8000, CRC(b57dc037) SHA1(69ac79a95ba9ace7c9ca7af480a4a10176be5ace) )
 	ROM_LOAD( "sf18.bin",   0x00000, 0x8000, CRC(68acd627) SHA1(f98ff9ccb0913711079a2988e8dd08695fb5e107) )
 	ROM_LOAD( "sf19.bin",   0x08000, 0x8000, CRC(5170a057) SHA1(9222f9febc222fa0c2eead258ad77c857f6d40c8) )
 
-	ROM_REGION( 0x10000, REGION_GFX5, 0 )	/* foreground map data */
+	ROM_REGION( 0x10000, "gfx5", 0 )	/* foreground map data */
 	ROM_LOAD( "sf09.bin",   0x00000, 0x8000, CRC(8ceaf4fe) SHA1(5698f2ff44c109825b8d9d0b6dd2426624df668b) )
 	ROM_LOAD( "sf10.bin",   0x08000, 0x8000, CRC(5a1a227a) SHA1(24928ab218824ae1f5380398ceb90dcad525cc08) )
 
-	ROM_REGION( 0x10000, REGION_GFX6, 0 )	/* background map data */
+	ROM_REGION( 0x10000, "gfx6", 0 )	/* background map data */
 	ROM_LOAD( "sf15.bin",   0x00000, 0x8000, CRC(27a310bc) SHA1(dd30d72bc33b0bf7ddaf3ab730e028f51b20152a) )
 	ROM_LOAD( "sf16.bin",   0x08000, 0x8000, CRC(3d19ce18) SHA1(38f691a23c96ef672637965c1a13f6d1595f9d51) )
 
-	ROM_REGION( 0x0800, REGION_PROMS, 0 )
+	ROM_REGION( 0x0800, "proms", 0 )
 	ROM_LOAD( "82s129.006", 0x0000, 0x0100, CRC(f9424b5b) SHA1(e3bc23213406d35d54f1221f17f25d433df273a2) )	/* text lookup table */
 	ROM_LOAD( "82s129.002", 0x0100, 0x0100, CRC(c883d49b) SHA1(e84900ccf6f27e5043e43c0d85ea1e4eee7e52d3) )	/* fg lookup table */
 	ROM_LOAD( "82s129.003", 0x0200, 0x0100, CRC(af81882a) SHA1(b1008c991bd8d1157b3479e465ab286c70418b58) )
@@ -693,48 +662,48 @@ ROM_START( empcityj )
 	ROM_LOAD( "82s129.066", 0x0600, 0x0100, CRC(51e8832f) SHA1(ed8c00559e7a02bb8c11861d747c8c64c01b7437) )
 	ROM_LOAD( "82s129.015", 0x0700, 0x0100, CRC(0eaf5158) SHA1(bafd4108708f66cd7b280e47152b108f3e254fc9) )	/* timing? (not used) */
 
-	ROM_REGION( 0x08000, REGION_SOUND1, 0 )	/* adpcm voice data */
+	ROM_REGION( 0x08000, "adpcm", 0 )	/* adpcm voice data */
 	ROM_LOAD( "sf04.bin",   0x00000, 0x8000, CRC(1b8d0c07) SHA1(c163ccd2b7ed6c84facc075eb1564ca399f3ba17) )
 ROM_END
 
 ROM_START( stfight )
-	ROM_REGION( 2*0x18000, REGION_CPU1, 0 )	/* 96k for code + 96k for decrypted opcodes */
+	ROM_REGION( 2*0x18000, "main", 0 )	/* 96k for code + 96k for decrypted opcodes */
 	ROM_LOAD( "a-1.4q",     0x00000, 0x8000, CRC(ff83f316) SHA1(84553ebd96ddbf59a1bcb221d53781980a006925) )
 	ROM_LOAD( "sf02.bin",   0x10000, 0x8000, CRC(e626ce9e) SHA1(2c6c5a5cf15cc50217c9864a4d861af8a1b1b5ad) )	/* bank switched */
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the second CPU */
+	ROM_REGION( 0x10000, "audio", 0 )	/* 64k for the second CPU */
 	ROM_LOAD( "sf03.bin",   0x0000,  0x8000, CRC(6a8cb7a6) SHA1(dc123cc48d3623752b78e7c23dd8d2f5adf84f92) )
 
-	ROM_REGION( 0x02000, REGION_GFX1, ROMREGION_DISPOSE )	/* character data */
+	ROM_REGION( 0x02000, "gfx1", ROMREGION_DISPOSE )	/* character data */
 	ROM_LOAD( "sf17.bin",   0x0000, 0x2000, CRC(1b3706b5) SHA1(61f069329a7a836523ffc8cce915b0d0129fd896) )
 
-	ROM_REGION( 0x20000, REGION_GFX2, ROMREGION_DISPOSE ) /* foreground tile pixel data */
+	ROM_REGION( 0x20000, "gfx2", ROMREGION_DISPOSE ) /* foreground tile pixel data */
 	ROM_LOAD( "sf07.bin",   0x10000, 0x8000, CRC(2c6caa5f) SHA1(f6893cb87004979ead331897c684f995f850447e) )
 	ROM_LOAD( "sf08.bin",   0x18000, 0x8000, CRC(e11ded31) SHA1(e3e634ad324d51e52d79dd79e5e6e5697cb8d21f) )
 	ROM_LOAD( "sf05.bin",   0x00000, 0x8000, CRC(0c099a31) SHA1(dabaf8edc59e4954941cd8176031a358f45a1956) )
 	ROM_LOAD( "sf06.bin",   0x08000, 0x8000, CRC(3cc77c31) SHA1(13d2324df5a322d499c9959a6bb3a844edaefb45) )
 
-	ROM_REGION( 0x20000, REGION_GFX3, ROMREGION_DISPOSE )	/* background tile pixel data */
+	ROM_REGION( 0x20000, "gfx3", ROMREGION_DISPOSE )	/* background tile pixel data */
 	ROM_LOAD( "sf13.bin",   0x10000, 0x8000, CRC(0ae48dd3) SHA1(ca3d9aeb9f4343c379cef9282e408fbf8aa67d99) )
 	ROM_LOAD( "sf14.bin",   0x18000, 0x8000, CRC(debf5d76) SHA1(eb18c35166eb5f93be98b3c30c7d909c0a68eada) )
 	ROM_LOAD( "sf11.bin",   0x00000, 0x8000, CRC(8261ecfe) SHA1(5817f4a0458a949298414fe09c86bbcf50be52f3) )
 	ROM_LOAD( "sf12.bin",   0x08000, 0x8000, CRC(71137301) SHA1(087a9f401939bc30f1dafa9916e8d8c564595a57) )
 
-	ROM_REGION( 0x20000, REGION_GFX4, ROMREGION_DISPOSE )	/* sprite data */
+	ROM_REGION( 0x20000, "gfx4", ROMREGION_DISPOSE )	/* sprite data */
 	ROM_LOAD( "sf20.bin",   0x10000, 0x8000, CRC(8299f247) SHA1(71891f7b1fbfaed14c3854b7f6e10a3ddb4bd479) )
 	ROM_LOAD( "sf21.bin",   0x18000, 0x8000, CRC(b57dc037) SHA1(69ac79a95ba9ace7c9ca7af480a4a10176be5ace) )
 	ROM_LOAD( "sf18.bin",   0x00000, 0x8000, CRC(68acd627) SHA1(f98ff9ccb0913711079a2988e8dd08695fb5e107) )
 	ROM_LOAD( "sf19.bin",   0x08000, 0x8000, CRC(5170a057) SHA1(9222f9febc222fa0c2eead258ad77c857f6d40c8) )
 
-	ROM_REGION( 0x10000, REGION_GFX5, 0 )	/* foreground map data */
+	ROM_REGION( 0x10000, "gfx5", 0 )	/* foreground map data */
 	ROM_LOAD( "sf09.bin",   0x00000, 0x8000, CRC(8ceaf4fe) SHA1(5698f2ff44c109825b8d9d0b6dd2426624df668b) )
 	ROM_LOAD( "sf10.bin",   0x08000, 0x8000, CRC(5a1a227a) SHA1(24928ab218824ae1f5380398ceb90dcad525cc08) )
 
-	ROM_REGION( 0x10000, REGION_GFX6, 0 )	/* background map data */
+	ROM_REGION( 0x10000, "gfx6", 0 )	/* background map data */
 	ROM_LOAD( "sf15.bin",   0x00000, 0x8000, CRC(27a310bc) SHA1(dd30d72bc33b0bf7ddaf3ab730e028f51b20152a) )
 	ROM_LOAD( "sf16.bin",   0x08000, 0x8000, CRC(3d19ce18) SHA1(38f691a23c96ef672637965c1a13f6d1595f9d51) )
 
-	ROM_REGION( 0x0800, REGION_PROMS, 0 )
+	ROM_REGION( 0x0800, "proms", 0 )
 	ROM_LOAD( "82s129.006", 0x0000, 0x0100, CRC(f9424b5b) SHA1(e3bc23213406d35d54f1221f17f25d433df273a2) )	/* text lookup table */
 	ROM_LOAD( "82s129.002", 0x0100, 0x0100, CRC(c883d49b) SHA1(e84900ccf6f27e5043e43c0d85ea1e4eee7e52d3) )	/* fg lookup table */
 	ROM_LOAD( "82s129.003", 0x0200, 0x0100, CRC(af81882a) SHA1(b1008c991bd8d1157b3479e465ab286c70418b58) )
@@ -744,50 +713,50 @@ ROM_START( stfight )
 	ROM_LOAD( "82s129.066", 0x0600, 0x0100, CRC(51e8832f) SHA1(ed8c00559e7a02bb8c11861d747c8c64c01b7437) )
 	ROM_LOAD( "82s129.015", 0x0700, 0x0100, CRC(0eaf5158) SHA1(bafd4108708f66cd7b280e47152b108f3e254fc9) )	/* timing? (not used) */
 
-	ROM_REGION( 0x08000, REGION_SOUND1, 0 )	/* adpcm voice data */
+	ROM_REGION( 0x08000, "adpcm", 0 )	/* adpcm voice data */
 	ROM_LOAD( "sf04.bin",   0x00000, 0x8000, CRC(1b8d0c07) SHA1(c163ccd2b7ed6c84facc075eb1564ca399f3ba17) )
 ROM_END
 
 /* not sure if this is a bootleg or not, it still displays the seibu copyright on a screen during the attract mode
    but not during the initial startup, must investigate this set more later */
 ROM_START( stfighta )
-	ROM_REGION( 2*0x18000, REGION_CPU1, 0 )	/* 96k for code + 96k for decrypted opcodes */
+	ROM_REGION( 2*0x18000, "main", 0 )	/* 96k for code + 96k for decrypted opcodes */
 	ROM_LOAD( "sfight2.bin",     0x00000, 0x8000, CRC(8fb4dfc9) SHA1(0350f4a8749883a4e2e9c4aed2447a64a078f9ce) )//  2.bin 58.532715%
 	ROM_LOAD( "sfight1.bin",     0x10000, 0x8000, CRC(983ce746) SHA1(3c7b9498f1adf253ba651558ee40641ec3dbc5eb) )/* bank switched */ //  a-1.4q 99.737549%
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the second CPU */
+	ROM_REGION( 0x10000, "audio", 0 )	/* 64k for the second CPU */
 	ROM_LOAD( "sf03.bin",   0x0000,  0x8000, CRC(6a8cb7a6) SHA1(dc123cc48d3623752b78e7c23dd8d2f5adf84f92) )
 
-	ROM_REGION( 0x02000, REGION_GFX1, ROMREGION_DISPOSE )	/* character data */
+	ROM_REGION( 0x02000, "gfx1", ROMREGION_DISPOSE )	/* character data */
 	ROM_LOAD( "sf17.bin",   0x0000, 0x2000, CRC(1b3706b5) SHA1(61f069329a7a836523ffc8cce915b0d0129fd896) )
 
-	ROM_REGION( 0x20000, REGION_GFX2, ROMREGION_DISPOSE ) /* foreground tile pixel data */
+	ROM_REGION( 0x20000, "gfx2", ROMREGION_DISPOSE ) /* foreground tile pixel data */
 	ROM_LOAD( "sf07.bin",   0x10000, 0x8000, CRC(2c6caa5f) SHA1(f6893cb87004979ead331897c684f995f850447e) )
 	ROM_LOAD( "sf08.bin",   0x18000, 0x8000, CRC(e11ded31) SHA1(e3e634ad324d51e52d79dd79e5e6e5697cb8d21f) )
 	ROM_LOAD( "sf05.bin",   0x00000, 0x8000, CRC(0c099a31) SHA1(dabaf8edc59e4954941cd8176031a358f45a1956) )
 	ROM_LOAD( "sf06.bin",   0x08000, 0x8000, CRC(3cc77c31) SHA1(13d2324df5a322d499c9959a6bb3a844edaefb45) )
 
-	ROM_REGION( 0x20000, REGION_GFX3, ROMREGION_DISPOSE )	/* background tile pixel data */
+	ROM_REGION( 0x20000, "gfx3", ROMREGION_DISPOSE )	/* background tile pixel data */
 	ROM_LOAD( "sf13.bin",   0x10000, 0x8000, CRC(0ae48dd3) SHA1(ca3d9aeb9f4343c379cef9282e408fbf8aa67d99) )
 	ROM_LOAD( "sf14.bin",   0x18000, 0x8000, CRC(debf5d76) SHA1(eb18c35166eb5f93be98b3c30c7d909c0a68eada) )
 	ROM_LOAD( "sf11.bin",   0x00000, 0x8000, CRC(8261ecfe) SHA1(5817f4a0458a949298414fe09c86bbcf50be52f3) )
 	ROM_LOAD( "sf12.bin",   0x08000, 0x8000, CRC(71137301) SHA1(087a9f401939bc30f1dafa9916e8d8c564595a57) )
 
-	ROM_REGION( 0x20000, REGION_GFX4, ROMREGION_DISPOSE )	/* sprite data */
+	ROM_REGION( 0x20000, "gfx4", ROMREGION_DISPOSE )	/* sprite data */
 	ROM_LOAD( "sf20.bin",   0x10000, 0x8000, CRC(8299f247) SHA1(71891f7b1fbfaed14c3854b7f6e10a3ddb4bd479) )
 	ROM_LOAD( "sf21.bin",   0x18000, 0x8000, CRC(b57dc037) SHA1(69ac79a95ba9ace7c9ca7af480a4a10176be5ace) )
 	ROM_LOAD( "sf18.bin",   0x00000, 0x8000, CRC(68acd627) SHA1(f98ff9ccb0913711079a2988e8dd08695fb5e107) )
 	ROM_LOAD( "sf19.bin",   0x08000, 0x8000, CRC(5170a057) SHA1(9222f9febc222fa0c2eead258ad77c857f6d40c8) )
 
-	ROM_REGION( 0x10000, REGION_GFX5, 0 )	/* foreground map data */
+	ROM_REGION( 0x10000, "gfx5", 0 )	/* foreground map data */
 	ROM_LOAD( "sf09.bin",   0x00000, 0x8000, CRC(8ceaf4fe) SHA1(5698f2ff44c109825b8d9d0b6dd2426624df668b) )
 	ROM_LOAD( "sf10.bin",   0x08000, 0x8000, CRC(5a1a227a) SHA1(24928ab218824ae1f5380398ceb90dcad525cc08) )
 
-	ROM_REGION( 0x10000, REGION_GFX6, 0 )	/* background map data */
+	ROM_REGION( 0x10000, "gfx6", 0 )	/* background map data */
 	ROM_LOAD( "sf15.bin",   0x00000, 0x8000, CRC(27a310bc) SHA1(dd30d72bc33b0bf7ddaf3ab730e028f51b20152a) )
 	ROM_LOAD( "sf16.bin",   0x08000, 0x8000, CRC(3d19ce18) SHA1(38f691a23c96ef672637965c1a13f6d1595f9d51) )
 
-	ROM_REGION( 0x0800, REGION_PROMS, 0 )
+	ROM_REGION( 0x0800, "proms", 0 )
 	ROM_LOAD( "82s129.006", 0x0000, 0x0100, CRC(f9424b5b) SHA1(e3bc23213406d35d54f1221f17f25d433df273a2) )	/* text lookup table */
 	ROM_LOAD( "82s129.002", 0x0100, 0x0100, CRC(c883d49b) SHA1(e84900ccf6f27e5043e43c0d85ea1e4eee7e52d3) )	/* fg lookup table */
 	ROM_LOAD( "82s129.003", 0x0200, 0x0100, CRC(af81882a) SHA1(b1008c991bd8d1157b3479e465ab286c70418b58) )
@@ -797,7 +766,7 @@ ROM_START( stfighta )
 	ROM_LOAD( "82s129.066", 0x0600, 0x0100, CRC(51e8832f) SHA1(ed8c00559e7a02bb8c11861d747c8c64c01b7437) )
 	ROM_LOAD( "82s129.015", 0x0700, 0x0100, CRC(0eaf5158) SHA1(bafd4108708f66cd7b280e47152b108f3e254fc9) )	/* timing? (not used) */
 
-	ROM_REGION( 0x08000, REGION_SOUND1, 0 )	/* adpcm voice data */
+	ROM_REGION( 0x08000, "adpcm", 0 )	/* adpcm voice data */
 	ROM_LOAD( "sf04.bin",   0x00000, 0x8000, CRC(1b8d0c07) SHA1(c163ccd2b7ed6c84facc075eb1564ca399f3ba17) )
 ROM_END
 
