@@ -15,36 +15,28 @@ Notes:
 *****************************************************************************/
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
 #include "deprecat.h"
 #include "sound/sn76496.h"
 
-static UINT8 *strnskil_sharedram;
-
 /****************************************************************************/
 
-extern WRITE8_HANDLER( strnskil_videoram_w );
-extern WRITE8_HANDLER( strnskil_scroll_x_w );
-extern WRITE8_HANDLER( strnskil_scrl_ctrl_w );
+WRITE8_HANDLER( strnskil_videoram_w );
+WRITE8_HANDLER( strnskil_scrl_ctrl_w );
 
-extern PALETTE_INIT( strnskil );
-extern VIDEO_START( strnskil );
-extern VIDEO_UPDATE( strnskil );
+PALETTE_INIT( strnskil );
+VIDEO_START( strnskil );
+VIDEO_UPDATE( strnskil );
+
+extern UINT8 *strnskil_xscroll;
 
-static WRITE8_HANDLER( strnskil_sharedram_w )
-{
-	strnskil_sharedram[offset] = data;
-}
 
-static READ8_HANDLER( strnskil_sharedram_r )
-{
-	return strnskil_sharedram[offset];
-}
 
 static READ8_HANDLER( strnskil_d800_r )
 {
 /* bit0: interrupt type?, bit1: CPU2 busack? */
 
-	if (cpu_getiloops() == 0)
+	if (cpu_getiloops(space->cpu) == 0)
 		return 0;
 	return 1;
 }
@@ -55,18 +47,18 @@ static READ8_HANDLER( pettanp_protection_r )
 {
 	int res;
 
-	switch (activecpu_get_pc())
+	switch (cpu_get_pc(space->cpu))
 	{
 		case 0x6066:	res = 0xa5;	break;
 		case 0x60dc:	res = 0x20;	break;	/* bits 0-3 unknown */
 		case 0x615d:	res = 0x30;	break;	/* bits 0-3 unknown */
-		case 0x61b9:	res = 0x60|(mame_rand(Machine)&0x0f);	break;	/* bits 0-3 unknown */
+		case 0x61b9:	res = 0x60|(mame_rand(space->machine)&0x0f);	break;	/* bits 0-3 unknown */
 		case 0x6219:	res = 0x77;	break;
 		case 0x626c:	res = 0xb4;	break;
 		default:		res = 0xff; break;
 	}
 
-	logerror("%04x: protection_r -> %02x\n",activecpu_get_pc(),res);
+	logerror("%04x: protection_r -> %02x\n",cpu_get_pc(space->cpu),res);
 	return res;
 }
 
@@ -74,75 +66,75 @@ static READ8_HANDLER( banbam_protection_r )
 {
 	int res;
 
-	switch (activecpu_get_pc())
+	switch (cpu_get_pc(space->cpu))
 	{
 		case 0x6094:	res = 0xa5;	break;
 		case 0x6118:	res = 0x20;	break;	/* bits 0-3 unknown */
 		case 0x6199:	res = 0x30;	break;	/* bits 0-3 unknown */
-		case 0x61f5:	res = 0x60|(mame_rand(Machine)&0x0f);	break;	/* bits 0-3 unknown */
+		case 0x61f5:	res = 0x60|(mame_rand(space->machine)&0x0f);	break;	/* bits 0-3 unknown */
 		case 0x6255:	res = 0x77;	break;
 		case 0x62a8:	res = 0xb4;	break;
 		default:		res = 0xff; break;
 	}
 
-	logerror("%04x: protection_r -> %02x\n",activecpu_get_pc(),res);
+	logerror("%04x: protection_r -> %02x\n",cpu_get_pc(space->cpu),res);
 	return res;
 }
 
 static WRITE8_HANDLER( protection_w )
 {
-	logerror("%04x: protection_w %02x\n",activecpu_get_pc(),data);
+	logerror("%04x: protection_w %02x\n",cpu_get_pc(space->cpu),data);
 }
 
 /****************************************************************************/
 
 static ADDRESS_MAP_START( strnskil_readmem1, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x9fff) AM_READ(MRA8_ROM)
+	AM_RANGE(0x0000, 0x9fff) AM_READ(SMH_ROM)
 
-	AM_RANGE(0xc000, 0xc7ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xc800, 0xcfff) AM_READ(strnskil_sharedram_r)
-	AM_RANGE(0xd000, 0xd7ff) AM_READ(MRA8_RAM) /* videoram */
+	AM_RANGE(0xc000, 0xc7ff) AM_READ(SMH_RAM)
+	AM_RANGE(0xc800, 0xcfff) AM_READ(SMH_RAM) AM_SHARE(1)
+	AM_RANGE(0xd000, 0xd7ff) AM_READ(SMH_RAM) /* videoram */
 
 	AM_RANGE(0xd800, 0xd800) AM_READ(strnskil_d800_r)
-	AM_RANGE(0xd801, 0xd801) AM_READ(input_port_0_r) /* dsw 1 */
-	AM_RANGE(0xd802, 0xd802) AM_READ(input_port_1_r) /* dsw 2 */
-	AM_RANGE(0xd803, 0xd803) AM_READ(input_port_4_r) /* other inputs */
-	AM_RANGE(0xd804, 0xd804) AM_READ(input_port_2_r) /* player1 */
-	AM_RANGE(0xd805, 0xd805) AM_READ(input_port_3_r) /* player2 */
+	AM_RANGE(0xd801, 0xd801) AM_READ_PORT("DSW1")
+	AM_RANGE(0xd802, 0xd802) AM_READ_PORT("DSW2")
+	AM_RANGE(0xd803, 0xd803) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0xd804, 0xd804) AM_READ_PORT("P1")
+	AM_RANGE(0xd805, 0xd805) AM_READ_PORT("P2")
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( strnskil_writemem1, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x9fff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x0000, 0x9fff) AM_WRITE(SMH_ROM)
 
-	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xc800, 0xcfff) AM_WRITE(strnskil_sharedram_w)
+	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0xc800, 0xcfff) AM_WRITE(SMH_RAM) AM_SHARE(1)
 	AM_RANGE(0xd000, 0xd7ff) AM_WRITE(strnskil_videoram_w) AM_BASE(&videoram)
 
 	AM_RANGE(0xd808, 0xd808) AM_WRITE(strnskil_scrl_ctrl_w)
-	AM_RANGE(0xd809, 0xd809) AM_WRITE(MWA8_NOP) /* coin counter? */
-	AM_RANGE(0xd80a, 0xd80b) AM_WRITE(strnskil_scroll_x_w)
+	AM_RANGE(0xd809, 0xd809) AM_WRITE(SMH_NOP) /* coin counter? */
+	AM_RANGE(0xd80a, 0xd80b) AM_WRITE(SMH_RAM) AM_BASE(&strnskil_xscroll)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( strnskil_readmem2, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x5fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xc800, 0xcfff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0000, 0x5fff) AM_READ(SMH_ROM)
+	AM_RANGE(0xc000, 0xc7ff) AM_READ(SMH_RAM)
+	AM_RANGE(0xc800, 0xcfff) AM_READ(SMH_RAM) AM_SHARE(1)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( strnskil_writemem2, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x5fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
-	AM_RANGE(0xc800, 0xcfff) AM_WRITE(MWA8_RAM) AM_BASE(&strnskil_sharedram)
+	AM_RANGE(0x0000, 0x5fff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+	AM_RANGE(0xc800, 0xcfff) AM_WRITE(SMH_RAM) AM_SHARE(1)
 
-	AM_RANGE(0xd801, 0xd801) AM_WRITE(SN76496_0_w)
-	AM_RANGE(0xd802, 0xd802) AM_WRITE(SN76496_1_w)
+	AM_RANGE(0xd801, 0xd801) AM_WRITE(sn76496_0_w)
+	AM_RANGE(0xd802, 0xd802) AM_WRITE(sn76496_1_w)
 ADDRESS_MAP_END
 
 
 /****************************************************************************/
 
 static INPUT_PORTS_START( strnskil )
-	PORT_START  /* dsw1 */
+	PORT_START("DSW1")
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Demo_Sounds ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -173,7 +165,7 @@ static INPUT_PORTS_START( strnskil )
 	PORT_DIPSETTING(    0xe0, "1C 2C / 1C 6C" )
 	PORT_DIPSETTING(    0xf0, DEF_STR( Free_Play ) )
 
-	PORT_START  /* dsw2 */
+	PORT_START("DSW2")
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Normal ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Hard ) )
@@ -199,7 +191,7 @@ static INPUT_PORTS_START( strnskil )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 
-	PORT_START /* d804 */
+	PORT_START("P1")		/* d804 */
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_BUTTON2 )
@@ -209,7 +201,7 @@ static INPUT_PORTS_START( strnskil )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_8WAY
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_8WAY
 
-	PORT_START /* d805 */
+	PORT_START("P2")		/* d805 */
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_COCKTAIL
@@ -219,7 +211,7 @@ static INPUT_PORTS_START( strnskil )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
 
-	PORT_START /* d803 */
+	PORT_START("SYSTEM")	/* d803 */
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_SERVICE1 )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_SERVICE( 0x20, IP_ACTIVE_HIGH )
@@ -231,7 +223,7 @@ static INPUT_PORTS_START( strnskil )
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( banbam )
-	PORT_START  /* dsw1 */
+	PORT_START("DSW1")
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Lives ) ) PORT_DIPLOCATION("SW1:1")
 	PORT_DIPSETTING(    0x00, "3" )
 	PORT_DIPSETTING(    0x01, "5" )
@@ -260,7 +252,7 @@ static INPUT_PORTS_START( banbam )
 	PORT_DIPSETTING(    0xe0, "1C 2C / 1C 6C" )
 	PORT_DIPSETTING(    0xf0, DEF_STR( Free_Play ) )
 
-	PORT_START  /* dsw2 */
+	PORT_START("DSW2")
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Demo_Sounds ) ) PORT_DIPLOCATION("SW2:1")
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -275,9 +267,11 @@ static INPUT_PORTS_START( banbam )
 	PORT_DIPUNUSED_DIPLOC( 0x10, 0x10, "SW2:5" )	/*  These four dips are unused according to the manual */
 	PORT_DIPUNUSED_DIPLOC( 0x20, 0x20, "SW2:6" )
 	PORT_DIPUNUSED_DIPLOC( 0x40, 0x40, "SW2:7" )
-	PORT_DIPUNUSED_DIPLOC( 0x80, 0x80, "SW2:8" )
+	PORT_DIPNAME( 0x80, 0x00, "Freeze" ) PORT_DIPLOCATION("SW2:8") //game stands in a tight loop at $14-$16 -> $866 if this is putted off
+	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 
-	PORT_START /* d804 */
+	PORT_START("P1")		/* d804 */
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_UNKNOWN )
@@ -287,7 +281,7 @@ static INPUT_PORTS_START( banbam )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_4WAY
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_4WAY
 
-	PORT_START /* d805 */
+	PORT_START("P2")		/* d805 */
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_UNKNOWN )
@@ -297,7 +291,7 @@ static INPUT_PORTS_START( banbam )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT ) PORT_4WAY PORT_COCKTAIL
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT ) PORT_4WAY PORT_COCKTAIL
 
-	PORT_START /* d803 */
+	PORT_START("SYSTEM")	/* d803 */
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_SERVICE1 )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_UNKNOWN )
 	PORT_SERVICE( 0x20, IP_ACTIVE_HIGH )
@@ -336,34 +330,34 @@ static const gfx_layout spritelayout =
 };
 
 static GFXDECODE_START( strnskil )
-	GFXDECODE_ENTRY( REGION_GFX2, 0x0000, charlayout,   512, 64 )
-	GFXDECODE_ENTRY( REGION_GFX1, 0x0000, spritelayout, 0,   64 )
+	GFXDECODE_ENTRY( "gfx2", 0x0000, charlayout,   512, 64 )
+	GFXDECODE_ENTRY( "gfx1", 0x0000, spritelayout, 0,   64 )
 GFXDECODE_END
 
 
 static MACHINE_DRIVER_START( strnskil )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(Z80,8000000/2) /* 4.000MHz */
+	MDRV_CPU_ADD("main", Z80,8000000/2) /* 4.000MHz */
 	MDRV_CPU_PROGRAM_MAP(strnskil_readmem1,strnskil_writemem1)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,2)
+	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,2)
 
-	MDRV_CPU_ADD(Z80,8000000/2) /* 4.000MHz */
+	MDRV_CPU_ADD("sub", Z80,8000000/2) /* 4.000MHz */
 	MDRV_CPU_PROGRAM_MAP(strnskil_readmem2,strnskil_writemem2)
-	MDRV_CPU_VBLANK_INT(irq0_line_hold,2)
+	MDRV_CPU_VBLANK_INT_HACK(irq0_line_hold,2)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_REAL_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(100)
+	MDRV_QUANTUM_TIME(HZ(6000))
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(2500) /* not accurate */)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(32*8, 32*8)
 	MDRV_SCREEN_VISIBLE_AREA(1*8, 31*8-1, 2*8, 30*8-1)
+
 	MDRV_GFXDECODE(strnskil)
-	MDRV_PALETTE_LENGTH(256)
-	MDRV_COLORTABLE_LENGTH(1024)
+	MDRV_PALETTE_LENGTH(1024)
 
 	MDRV_PALETTE_INIT(strnskil)
 	MDRV_VIDEO_START(strnskil)
@@ -372,168 +366,168 @@ static MACHINE_DRIVER_START( strnskil )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(SN76496, 8000000/4)
+	MDRV_SOUND_ADD("sn1", SN76496, 8000000/4)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
 
-	MDRV_SOUND_ADD(SN76496, 8000000/2)
+	MDRV_SOUND_ADD("sn2", SN76496, 8000000/2)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.75)
 MACHINE_DRIVER_END
 
 /****************************************************************************/
 
 ROM_START( strnskil )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 ) /* main CPU */
+	ROM_REGION( 0x10000, "main", 0 ) /* main CPU */
 	ROM_LOAD( "tvg3.7",  0x0000,  0x2000, CRC(31fd793a) SHA1(b86efe8ea60edf414a23fb6abc09db691c085fe9) )
 	ROM_CONTINUE(        0x8000,  0x2000 )
 	ROM_LOAD( "tvg4.8",  0x2000,  0x2000, CRC(c58315b5) SHA1(2039cd89ef59d05f353f6c367fa851c0f60cdc4a) )
 	ROM_LOAD( "tvg5.9",  0x4000,  0x2000, CRC(29e7ded5) SHA1(6eae5988139f22c3ff166192e4fda77db38a79bc) )
 	ROM_LOAD( "tvg6.10", 0x6000,  0x2000, CRC(8b126a4b) SHA1(68b617c5dc120c777e152919cba9daeaf3ceac5f) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* sub CPU */
+	ROM_REGION( 0x10000, "sub", 0 ) /* sub CPU */
 	ROM_LOAD( "tvg1.2",  0x0000,  0x2000, CRC(b586b753) SHA1(7c9891fb279b1323c059ffdcf7c009bf971037be) )
 	ROM_LOAD( "tvg2.3",  0x2000,  0x2000, CRC(8bd71bb6) SHA1(cc35e1e4cbb893ab04f1b6ceef0a050243e3b462) )
 
-	ROM_REGION( 0x6000, REGION_GFX1, ROMREGION_DISPOSE ) /* sprite */
+	ROM_REGION( 0x6000, "gfx1", ROMREGION_DISPOSE ) /* sprite */
 	ROM_LOAD( "tvg7.90",   0x0000,  0x2000, CRC(ee3bd593) SHA1(398e426e53695cc184d5a2750fd32a1c2c68bf30) )
 	ROM_LOAD( "tvg8.92",   0x2000,  0x2000, CRC(1b265360) SHA1(fbc64c504639106c1813bf91bd31bda1ce4c7ffe) )
 	ROM_LOAD( "tvg9.94",   0x4000,  0x2000, CRC(776c7ca6) SHA1(23fd1ac15395822b318db4435e48dd4e0e3e61de) )
 
-	ROM_REGION( 0x6000, REGION_GFX2, ROMREGION_DISPOSE ) /* bg */
+	ROM_REGION( 0x6000, "gfx2", ROMREGION_DISPOSE ) /* bg */
 	ROM_LOAD( "tvg12.102", 0x0000,  0x2000, CRC(68b9d888) SHA1(7a4071fe882c1949979f97a020d7c6e95643ef42) )
 	ROM_LOAD( "tvg11.101", 0x2000,  0x2000, CRC(7f2179ff) SHA1(24fab1f4430ae883bc1f477d3df7643e06c67349) )
 	ROM_LOAD( "tvg10.100", 0x4000,  0x2000, CRC(321ad963) SHA1(9b50fbf0c3b4ce7ce3c68339b99a2ccadef4646f) )
 
-	ROM_REGION( 0x0800, REGION_PROMS, 0 ) /* color PROMs */
+	ROM_REGION( 0x0800, "proms", 0 ) /* color PROMs */
 	ROM_LOAD( "15-3.prm", 0x0000,  0x0100, CRC(dbcd3bec) SHA1(1baeec277b16c82b67e10da9d4c84cf383ef4a82) ) /* R */
 	ROM_LOAD( "15-4.prm", 0x0100,  0x0100, CRC(9eb7b6cf) SHA1(86451e8a510f8cfbc0be7d4e7bb1ee7dfd67f1f4) ) /* G */
 	ROM_LOAD( "15-5.prm", 0x0200,  0x0100, CRC(9b30a7f3) SHA1(a0aefc2c8325b95ea227e404583d14622b04a3b9) ) /* B */
 	ROM_LOAD( "15-1.prm", 0x0300,  0x0200, CRC(d4f5b3d7) SHA1(9a244c77a752df655ff756e063d56c2c767e37d9) ) /* sprite */
 	ROM_LOAD( "15-2.prm", 0x0500,  0x0200, CRC(cdffede9) SHA1(3ecdf91e3f78eb6cdd3a6f58d1a89d448a676c52) ) /* bg */
 
-	ROM_REGION( 0x0100, REGION_USER1, 0 ) /* scroll control PROM */
+	ROM_REGION( 0x0100, "user1", 0 ) /* scroll control PROM */
 	ROM_LOAD( "15-6.prm", 0x0000,  0x0100, CRC(ec4faf5b) SHA1(7ebbf50807d04105ebadec91bded069408e399ba) )
 ROM_END
 
 ROM_START( guiness )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 ) /* main CPU */
+	ROM_REGION( 0x10000, "main", 0 ) /* main CPU */
 	ROM_LOAD( "tvg3.15", 0x0000,  0x2000, CRC(3a605ad8) SHA1(f6e2dd4989fdb68bc55857f5a8f06601416139d5) )
 	ROM_CONTINUE(        0x8000,  0x2000 )
 	ROM_LOAD( "tvg4.8",  0x2000,  0x2000, CRC(c58315b5) SHA1(2039cd89ef59d05f353f6c367fa851c0f60cdc4a) )
 	ROM_LOAD( "tvg5.9",  0x4000,  0x2000, CRC(29e7ded5) SHA1(6eae5988139f22c3ff166192e4fda77db38a79bc) )
 	ROM_LOAD( "tvg6.10", 0x6000,  0x2000, CRC(8b126a4b) SHA1(68b617c5dc120c777e152919cba9daeaf3ceac5f) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* sub CPU */
+	ROM_REGION( 0x10000, "sub", 0 ) /* sub CPU */
 	ROM_LOAD( "tvg1.2",  0x0000,  0x2000, CRC(b586b753) SHA1(7c9891fb279b1323c059ffdcf7c009bf971037be) )
 	ROM_LOAD( "tvg2.3",  0x2000,  0x2000, CRC(8bd71bb6) SHA1(cc35e1e4cbb893ab04f1b6ceef0a050243e3b462) )
 
-	ROM_REGION( 0x6000, REGION_GFX1, ROMREGION_DISPOSE ) /* sprite */
+	ROM_REGION( 0x6000, "gfx1", ROMREGION_DISPOSE ) /* sprite */
 	ROM_LOAD( "tvg7.90",   0x0000,  0x2000, CRC(ee3bd593) SHA1(398e426e53695cc184d5a2750fd32a1c2c68bf30) )
 	ROM_LOAD( "tvg8.92",   0x2000,  0x2000, CRC(1b265360) SHA1(fbc64c504639106c1813bf91bd31bda1ce4c7ffe) )
 	ROM_LOAD( "tvg9.94",   0x4000,  0x2000, CRC(776c7ca6) SHA1(23fd1ac15395822b318db4435e48dd4e0e3e61de) )
 
-	ROM_REGION( 0x6000, REGION_GFX2, ROMREGION_DISPOSE ) /* bg */
+	ROM_REGION( 0x6000, "gfx2", ROMREGION_DISPOSE ) /* bg */
 	ROM_LOAD( "tvg12.15", 0x0000,  0x2000, CRC(a82c923d) SHA1(2bd2b028d782fac18f2fe9c9ef73ce0af67db347) )
 	ROM_LOAD( "tvg11.15", 0x2000,  0x2000, CRC(d432c96f) SHA1(0d4b3af778dbd40bc26bad4c673a9ce1ef537c04) )
 	ROM_LOAD( "tvg10.15", 0x4000,  0x2000, CRC(a53959d6) SHA1(cdf7acf1a75d83b259948c482f06543624a695a3) )
 
-	ROM_REGION( 0x0800, REGION_PROMS, 0 ) /* color PROMs */
+	ROM_REGION( 0x0800, "proms", 0 ) /* color PROMs */
 	ROM_LOAD( "15-3.prm", 0x0000,  0x0100, CRC(dbcd3bec) SHA1(1baeec277b16c82b67e10da9d4c84cf383ef4a82) ) /* R */
 	ROM_LOAD( "15-4.prm", 0x0100,  0x0100, CRC(9eb7b6cf) SHA1(86451e8a510f8cfbc0be7d4e7bb1ee7dfd67f1f4) ) /* G */
 	ROM_LOAD( "15-5.prm", 0x0200,  0x0100, CRC(9b30a7f3) SHA1(a0aefc2c8325b95ea227e404583d14622b04a3b9) ) /* B */
 	ROM_LOAD( "15-1.prm", 0x0300,  0x0200, CRC(d4f5b3d7) SHA1(9a244c77a752df655ff756e063d56c2c767e37d9) ) /* sprite */
 	ROM_LOAD( "15-2.prm", 0x0500,  0x0200, CRC(cdffede9) SHA1(3ecdf91e3f78eb6cdd3a6f58d1a89d448a676c52) ) /* bg */
 
-	ROM_REGION( 0x0100, REGION_USER1, 0 ) /* scroll control PROM */
+	ROM_REGION( 0x0100, "user1", 0 ) /* scroll control PROM */
 	ROM_LOAD( "15-6.prm", 0x0000,  0x0100, CRC(ec4faf5b) SHA1(7ebbf50807d04105ebadec91bded069408e399ba) )
 ROM_END
 
 ROM_START( pettanp )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 ) /* main CPU */
+	ROM_REGION( 0x10000, "main", 0 ) /* main CPU */
 	ROM_LOAD( "tvg2-16a.7",  0x0000,  0x2000, CRC(4cbbbd01) SHA1(3905cf9e9d324bb23688ab29c98d71529d3dbf0c) )
 	ROM_CONTINUE(            0x8000,  0x2000 )
 	ROM_LOAD( "tvg3-16a.8",  0x2000,  0x2000, CRC(aaa0420f) SHA1(aa7ead51002f8b1bbefd07ff23b9064804fc31b3) )
 	ROM_LOAD( "tvg4-16a.9",  0x4000,  0x2000, CRC(43306369) SHA1(1eadebd3d962da49fd204eff8692f1e1a1e3cc98) )
 	ROM_LOAD( "tvg5-16a.10", 0x6000,  0x2000, CRC(da9c635f) SHA1(3c084ad159dbabfd02a9772489c3193852d135b7) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* sub CPU */
+	ROM_REGION( 0x10000, "sub", 0 ) /* sub CPU */
 	ROM_LOAD( "tvg1-16.2",   0x0000,  0x2000, CRC(e36009f6) SHA1(72c485e8c19fbfc9c850094cfd87f1055154c0c5) )
 
-	ROM_REGION( 0x6000, REGION_GFX1, ROMREGION_DISPOSE ) /* sprite */
+	ROM_REGION( 0x6000, "gfx1", ROMREGION_DISPOSE ) /* sprite */
 	ROM_LOAD( "tvg6-16.90",  0x0000,  0x2000, CRC(6905d9d5) SHA1(586bf72bab5ab6e3e319c925decc16d7f3711af1) )
 	ROM_LOAD( "tvg7-16.92",  0x2000,  0x2000, CRC(40d02bfd) SHA1(2f6ca8197048318f7900b56169aba4c9fdf48693) )
 	ROM_LOAD( "tvg8-16.94",  0x4000,  0x2000, CRC(b18a2244) SHA1(168061e050530e6a5bc78c14a64e635370256dfd) )
 
-	ROM_REGION( 0x6000, REGION_GFX2, ROMREGION_DISPOSE ) /* bg */
+	ROM_REGION( 0x6000, "gfx2", ROMREGION_DISPOSE ) /* bg */
 	ROM_LOAD( "tvg11-16.102",0x0000,  0x2000, CRC(327b7a29) SHA1(4b8d57607c4a1e84c630c38eba3fa90b5496dcde) )
 	ROM_LOAD( "tvg10-16.101",0x2000,  0x2000, CRC(624ac061) SHA1(9d479a8a256a8ff37c00bc7449b11357f9fe6cdc) )
 	ROM_LOAD( "tvg9-16.100", 0x4000,  0x2000, CRC(c477e74c) SHA1(864eddcd9c817aeecb09423071f87d3b39eb5fc4) )
 
-	ROM_REGION( 0x0700, REGION_PROMS, 0 ) /* color PROMs */
+	ROM_REGION( 0x0700, "proms", 0 ) /* color PROMs */
 	ROM_LOAD( "16-3.66",  0x0000,  0x0100, CRC(dbcd3bec) SHA1(1baeec277b16c82b67e10da9d4c84cf383ef4a82) ) /* R       Prom type 24s10 */
 	ROM_LOAD( "16-4.67",  0x0100,  0x0100, CRC(9eb7b6cf) SHA1(86451e8a510f8cfbc0be7d4e7bb1ee7dfd67f1f4) ) /* G       Prom type 24s10 */
 	ROM_LOAD( "16-5.68",  0x0200,  0x0100, CRC(9b30a7f3) SHA1(a0aefc2c8325b95ea227e404583d14622b04a3b9) ) /* B       Prom type 24s10 */
 	ROM_LOAD( "16-1.148", 0x0300,  0x0200, CRC(777e2770) SHA1(7f4ef42ab4e0546c2932d498cf573bd4f4296db7) ) /* sprite  Prom type mb7124h */
 	ROM_LOAD( "16-2.97",  0x0500,  0x0200, CRC(7f95d4b2) SHA1(68dc311739a4d5d72f4cfbace27f3a82f05316ff) ) /* bg      Prom type mb7124h */
 
-	ROM_REGION( 0x0100, REGION_USER1, 0 ) /* scroll control PROM */
+	ROM_REGION( 0x0100, "user1", 0 ) /* scroll control PROM */
 	ROM_LOAD( "16-6.59",  0x0000,  0x0100, CRC(ec4faf5b) SHA1(7ebbf50807d04105ebadec91bded069408e399ba) ) /* Prom type 24s10 */
 
-	ROM_REGION( 0x1000, REGION_USER2, 0 ) /* protection, program code used with Fujitsu MB8841 4-Bit MCU */
+	ROM_REGION( 0x1000, "user2", 0 ) /* protection, program code used with Fujitsu MB8841 4-Bit MCU */
 	ROM_LOAD( "tvg12-16.2", 0x0000,  0x1000, CRC(3abc6ba8) SHA1(15e0b0f9d068f6094e2be4f4f1dea0ff6e85686b) )
 ROM_END
 
 ROM_START( banbam )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 ) /* main CPU */
+	ROM_REGION( 0x10000, "main", 0 ) /* main CPU */
 	ROM_LOAD( "ban-rom2.ic7",  0x0000,  0x2000, CRC(a5aeef6e) SHA1(92c1ad6ccb96b723e122899150e3c1855c5017b8) )
 	ROM_CONTINUE(              0x8000,  0x2000 )
 	ROM_LOAD( "ban-rom3.ic8",  0x2000,  0x2000, CRC(f91472bf) SHA1(94988b7bf2be3d3704a802db544070251d6c6a9c) )
 	ROM_LOAD( "ban-rom4.ic9",  0x4000,  0x2000, CRC(436a09ef) SHA1(7287f741fbf3ac43d5c46b2f43ec4439cb3d0d56) )
 	ROM_LOAD( "ban-rom5.ic10", 0x6000,  0x2000, CRC(45205f86) SHA1(a11d10beb21519f797c902b8a18775c8e2aa0fae) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* sub CPU */
+	ROM_REGION( 0x10000, "sub", 0 ) /* sub CPU */
 	ROM_LOAD( "ban-rom1.ic2",   0x0000,  0x2000, CRC(e36009f6) SHA1(72c485e8c19fbfc9c850094cfd87f1055154c0c5) )
 
-	ROM_REGION( 0x6000, REGION_GFX1, ROMREGION_DISPOSE ) /* sprite */
+	ROM_REGION( 0x6000, "gfx1", ROMREGION_DISPOSE ) /* sprite */
 	ROM_LOAD( "ban-rom6.ic90",  0x0000,  0x2000, CRC(41fc44df) SHA1(1c4f21cdc423078fab58370d5245a13292bf7fe6) )
 	ROM_LOAD( "ban-rom7.ic92",  0x2000,  0x2000, CRC(8b429c5b) SHA1(505796eac2c8dd84f9ed29a6227b3243f81ec072) )
 	ROM_LOAD( "ban-rom8.ic94",  0x4000,  0x2000, CRC(76c02d6b) SHA1(9ef7585da5376cdd604afee281594e24c69addf2) )
 
-	ROM_REGION( 0x6000, REGION_GFX2, ROMREGION_DISPOSE ) /* bg */
+	ROM_REGION( 0x6000, "gfx2", ROMREGION_DISPOSE ) /* bg */
 	ROM_LOAD( "ban-rom11.ic102", 0x0000,  0x2000, CRC(aa827c57) SHA1(87d0c5e7df6ce40b0b2fc8f4b9dd43d4b7b0bc2e) )
 	ROM_LOAD( "ban-rom10.ic101", 0x2000,  0x2000, CRC(51bd1c5c) SHA1(f714a3168d59cb4f8512440f7a2e27b6e0726a39) )
 	ROM_LOAD( "ban-rom9.ic100",  0x4000,  0x2000, CRC(c0a5a4c8) SHA1(7f0978669218982d379a5d72c6198a33a8213ab5) )
 
-	ROM_REGION( 0x0700, REGION_PROMS, 0 ) /* color PROMs */
+	ROM_REGION( 0x0700, "proms", 0 ) /* color PROMs */
 	ROM_LOAD( "16-3.66",  0x0000,  0x0100, CRC(dbcd3bec) SHA1(1baeec277b16c82b67e10da9d4c84cf383ef4a82) ) /* R       Prom type 24s10 */
 	ROM_LOAD( "16-4.67",  0x0100,  0x0100, CRC(9eb7b6cf) SHA1(86451e8a510f8cfbc0be7d4e7bb1ee7dfd67f1f4) ) /* G       Prom type 24s10 */
 	ROM_LOAD( "16-5.68",  0x0200,  0x0100, CRC(9b30a7f3) SHA1(a0aefc2c8325b95ea227e404583d14622b04a3b9) ) /* B       Prom type 24s10 */
 	ROM_LOAD( "16-1.148", 0x0300,  0x0200, CRC(777e2770) SHA1(7f4ef42ab4e0546c2932d498cf573bd4f4296db7) ) /* sprite  Prom type mb7124h */
 	ROM_LOAD( "16-2.97",  0x0500,  0x0200, CRC(7f95d4b2) SHA1(68dc311739a4d5d72f4cfbace27f3a82f05316ff) ) /* bg      Prom type mb7124h */
 
-	ROM_REGION( 0x0100, REGION_USER1, 0 ) /* scroll control PROM */
+	ROM_REGION( 0x0100, "user1", 0 ) /* scroll control PROM */
 	ROM_LOAD( "16-6.59",  0x0000,  0x0100, CRC(ec4faf5b) SHA1(7ebbf50807d04105ebadec91bded069408e399ba) ) /* Prom type 24s10 */
 
-	ROM_REGION( 0x2000, REGION_USER2, 0 ) /* protection, program code used with Fujitsu MB8841 4-Bit MCU */
+	ROM_REGION( 0x2000, "user2", 0 ) /* protection, program code used with Fujitsu MB8841 4-Bit MCU */
 	ROM_LOAD( "ban-rom12.ic2", 0x0000,  0x2000, CRC(044bb2f6) SHA1(829b2152740061e0506c7504885d8404fb8fe360) )
 ROM_END
 
 static DRIVER_INIT( pettanp )
 {
-//  AM_RANGE(0xd80c, 0xd80c) AM_WRITE(MWA8_NOP)     /* protection reset? */
+//  AM_RANGE(0xd80c, 0xd80c) AM_WRITE(SMH_NOP)     /* protection reset? */
 //  AM_RANGE(0xd80d, 0xd80d) AM_WRITE(protection_w) /* protection data write (pettanp) */
 //  AM_RANGE(0xd806, 0xd806) AM_READ(protection_r) /* protection data read (pettanp) */
 
 	/* Fujitsu MB8841 4-Bit MCU */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd806, 0xd806, 0, 0, pettanp_protection_r);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd80d, 0xd80d, 0, 0, protection_w);
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xd806, 0xd806, 0, 0, pettanp_protection_r);
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xd80d, 0xd80d, 0, 0, protection_w);
 
 }
 
 static DRIVER_INIT( banbam )
 {
 	/* Fujitsu MB8841 4-Bit MCU */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd806, 0xd806, 0, 0, banbam_protection_r);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd80d, 0xd80d, 0, 0, protection_w);
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xd806, 0xd806, 0, 0, banbam_protection_r);
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xd80d, 0xd80d, 0, 0, protection_w);
 }
 
 GAME( 1984, strnskil, 0,        strnskil, strnskil, 0,       ROT0, "Sun Electronics", "Strength & Skill", 0 )
