@@ -128,7 +128,8 @@ Recordbr: loads of unmapped IOC reads and writes.
 
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
+#include "cpu/m68000/m68000.h"
 #include "taitoipt.h"
 #include "audio/taitosnd.h"
 #include "video/taitoic.h"
@@ -159,23 +160,14 @@ VIDEO_UPDATE( dleague );
 ***************************************************************************/
 
 /* Handler called by the YM2610 emulator when the internal timers cause an IRQ */
-static void irqhandler(int irq)
+static void irqhandler(running_machine *machine, int irq)
 {
-	cpunum_set_input_line(Machine, 1,0,irq ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[1],0,irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
-static const struct YM2610interface syvalion_ym2610_interface =
+static const ym2610_interface ym2610_config =
 {
-	irqhandler,
-	REGION_SOUND1,
-	REGION_SOUND2
-};
-
-static const struct YM2610interface dleague_ym2610_interface =
-{
-	irqhandler,
-	REGION_SOUND1,
-	REGION_SOUND1
+	irqhandler
 };
 
 
@@ -200,63 +192,63 @@ static READ16_HANDLER( syvalion_input_bypass_r )
 {
 	/* Bypass TC0220IOC controller for analog input */
 
-	UINT8	port = TC0220IOC_port_r(0);	/* read port number */
+	UINT8	port = TC0220IOC_port_r(space,0);	/* read port number */
 
 	switch( port )
 	{
 		case 0x08:				/* trackball y coords bottom 8 bits for 2nd player */
-			return readinputportbytag(P2TRACKY_PORT_TAG);
+			return input_port_read(space->machine, P2TRACKY_PORT_TAG);
 
 		case 0x09:				/* trackball y coords top 8 bits for 2nd player */
-			if (readinputportbytag(P2TRACKY_PORT_TAG) & 0x80)	/* y- direction (negative value) */
+			if (input_port_read(space->machine, P2TRACKY_PORT_TAG) & 0x80)	/* y- direction (negative value) */
 				return 0xff;
 			else												/* y+ direction (positive value) */
 				return 0x00;
 
 		case 0x0a:				/* trackball x coords bottom 8 bits for 2nd player */
-			return readinputportbytag(P2TRACKX_PORT_TAG);
+			return input_port_read(space->machine, P2TRACKX_PORT_TAG);
 
 		case 0x0b:				/* trackball x coords top 8 bits for 2nd player */
-			if (readinputportbytag(P2TRACKX_PORT_TAG) & 0x80)	/* x- direction (negative value) */
+			if (input_port_read(space->machine, P2TRACKX_PORT_TAG) & 0x80)	/* x- direction (negative value) */
 				return 0xff;
 			else												/* x+ direction (positive value) */
 				return 0x00;
 
 		case 0x0c:				/* trackball y coords bottom 8 bits for 1st player */
-			return readinputportbytag(P1TRACKY_PORT_TAG);
+			return input_port_read(space->machine, P1TRACKY_PORT_TAG);
 
 		case 0x0d:				/* trackball y coords top 8 bits for 1st player */
-			if (readinputportbytag(P1TRACKY_PORT_TAG) & 0x80)	/* y- direction (negative value) */
+			if (input_port_read(space->machine, P1TRACKY_PORT_TAG) & 0x80)	/* y- direction (negative value) */
 				return 0xff;
 			else												/* y+ direction (positive value) */
 				return 0x00;
 
 		case 0x0e:				/* trackball x coords bottom 8 bits for 1st player */
-			return readinputportbytag(P1TRACKX_PORT_TAG);
+			return input_port_read(space->machine, P1TRACKX_PORT_TAG);
 
 		case 0x0f:				/* trackball x coords top 8 bits for 1st player */
-			if (readinputportbytag(P1TRACKX_PORT_TAG) & 0x80)	/* x- direction (negative value) */
+			if (input_port_read(space->machine, P1TRACKX_PORT_TAG) & 0x80)	/* x- direction (negative value) */
 				return 0xff;
 			else												/* x+ direction (positive value) */
 				return 0x00;
 
 		default:
-			return TC0220IOC_portreg_r( offset );
+			return TC0220IOC_portreg_r( space,offset );
 	}
 }
 
 
-static INT32 banknum = -1;
+static INT32 banknum;
 
-static void reset_sound_region(void)
+static void reset_sound_region(running_machine *machine)
 {
-	memory_set_bankptr(1, memory_region(REGION_CPU2) + (banknum * 0x4000) + 0x10000);
+	memory_set_bankptr(machine, 1, memory_region(machine, "audio") + (banknum * 0x4000) + 0x10000);
 }
 
 static WRITE8_HANDLER( sound_bankswitch_w )
 {
 	banknum = (data - 1) & 3;
-	reset_sound_region();
+	reset_sound_region(space->machine);
 }
 
 
@@ -267,20 +259,20 @@ static WRITE8_HANDLER( sound_bankswitch_w )
 ***************************************************************************/
 
 static ADDRESS_MAP_START( syvalion_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x100000, 0x10ffff) AM_READ(MRA16_RAM)				/* 68000 RAM */
+	AM_RANGE(0x000000, 0x07ffff) AM_READ(SMH_ROM)
+	AM_RANGE(0x100000, 0x10ffff) AM_READ(SMH_RAM)				/* 68000 RAM */
 	AM_RANGE(0x110000, 0x11ffff) AM_READ(taitoh_mirrorram_r)		/* 68000 RAM (Mirror) */
 	AM_RANGE(0x200000, 0x200001) AM_READ(syvalion_input_bypass_r)
 	AM_RANGE(0x200002, 0x200003) AM_READ(TC0220IOC_halfword_port_r)
-	AM_RANGE(0x300000, 0x300001) AM_READ(MRA16_NOP)
+	AM_RANGE(0x300000, 0x300001) AM_READ(SMH_NOP)
 	AM_RANGE(0x300002, 0x300003) AM_READ(taitosound_comm16_lsb_r)
 	AM_RANGE(0x400000, 0x420fff) AM_READ(TC0080VCO_word_r)
-	AM_RANGE(0x500800, 0x500fff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x500800, 0x500fff) AM_READ(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( syvalion_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(MWA16_ROM)
-	AM_RANGE(0x100000, 0x10ffff) AM_WRITE(MWA16_RAM) AM_BASE(&taitoh_68000_mainram)
+	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x100000, 0x10ffff) AM_WRITE(SMH_RAM) AM_BASE(&taitoh_68000_mainram)
 	AM_RANGE(0x200000, 0x200001) AM_WRITE(TC0220IOC_halfword_portreg_w)
 	AM_RANGE(0x200002, 0x200003) AM_WRITE(TC0220IOC_halfword_port_w)
 	AM_RANGE(0x300000, 0x300001) AM_WRITE(taitosound_port16_lsb_w)
@@ -290,20 +282,20 @@ static ADDRESS_MAP_START( syvalion_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( recordbr_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x100000, 0x10ffff) AM_READ(MRA16_RAM)				/* 68000 RAM */
+	AM_RANGE(0x000000, 0x07ffff) AM_READ(SMH_ROM)
+	AM_RANGE(0x100000, 0x10ffff) AM_READ(SMH_RAM)				/* 68000 RAM */
 	AM_RANGE(0x110000, 0x11ffff) AM_READ(taitoh_mirrorram_r)		/* 68000 RAM (Mirror) */
 	AM_RANGE(0x200000, 0x200001) AM_READ(TC0220IOC_halfword_portreg_r)
 	AM_RANGE(0x200002, 0x200003) AM_READ(TC0220IOC_halfword_port_r)
-	AM_RANGE(0x300000, 0x300001) AM_READ(MRA16_NOP)
+	AM_RANGE(0x300000, 0x300001) AM_READ(SMH_NOP)
 	AM_RANGE(0x300002, 0x300003) AM_READ(taitosound_comm16_lsb_r)
 	AM_RANGE(0x400000, 0x420fff) AM_READ(TC0080VCO_word_r)
-	AM_RANGE(0x500800, 0x500fff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x500800, 0x500fff) AM_READ(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( recordbr_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(MWA16_ROM)
-	AM_RANGE(0x100000, 0x10ffff) AM_WRITE(MWA16_RAM) AM_BASE(&taitoh_68000_mainram)
+	AM_RANGE(0x000000, 0x07ffff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x100000, 0x10ffff) AM_WRITE(SMH_RAM) AM_BASE(&taitoh_68000_mainram)
 	AM_RANGE(0x200000, 0x200001) AM_WRITE(TC0220IOC_halfword_portreg_w)
 	AM_RANGE(0x200002, 0x200003) AM_WRITE(TC0220IOC_halfword_port_w)
 	AM_RANGE(0x300000, 0x300001) AM_WRITE(taitosound_port16_lsb_w)
@@ -313,52 +305,52 @@ static ADDRESS_MAP_START( recordbr_writemem, ADDRESS_SPACE_PROGRAM, 16 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( dleague_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x05ffff) AM_READ(MRA16_ROM)
-	AM_RANGE(0x100000, 0x10ffff) AM_READ(MRA16_RAM)				/* 68000 RAM */
+	AM_RANGE(0x000000, 0x05ffff) AM_READ(SMH_ROM)
+	AM_RANGE(0x100000, 0x10ffff) AM_READ(SMH_RAM)				/* 68000 RAM */
 	AM_RANGE(0x110000, 0x11ffff) AM_READ(taitoh_mirrorram_r)		/* 68000 RAM (Mirror) */
 	AM_RANGE(0x200000, 0x20000f) AM_READ(TC0220IOC_halfword_r)
-	AM_RANGE(0x300000, 0x300001) AM_READ(MRA16_NOP)
+	AM_RANGE(0x300000, 0x300001) AM_READ(SMH_NOP)
 	AM_RANGE(0x300002, 0x300003) AM_READ(taitosound_comm16_lsb_r)
 	AM_RANGE(0x400000, 0x420fff) AM_READ(TC0080VCO_word_r)
-	AM_RANGE(0x500800, 0x500fff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x500800, 0x500fff) AM_READ(SMH_RAM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( dleague_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x05ffff) AM_WRITE(MWA16_ROM)
-	AM_RANGE(0x100000, 0x10ffff) AM_WRITE(MWA16_RAM) AM_BASE(&taitoh_68000_mainram)
+	AM_RANGE(0x000000, 0x05ffff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0x100000, 0x10ffff) AM_WRITE(SMH_RAM) AM_BASE(&taitoh_68000_mainram)
 	AM_RANGE(0x200000, 0x20000f) AM_WRITE(TC0220IOC_halfword_w)
 	AM_RANGE(0x300000, 0x300001) AM_WRITE(taitosound_port16_lsb_w)
 	AM_RANGE(0x300002, 0x300003) AM_WRITE(taitosound_comm16_lsb_w)
 	AM_RANGE(0x400000, 0x420fff) AM_WRITE(TC0080VCO_word_w)
 	AM_RANGE(0x500800, 0x500fff) AM_WRITE(paletteram16_xBBBBBGGGGGRRRRR_word_w) AM_BASE(&paletteram16)
-	AM_RANGE(0x600000, 0x600001) AM_WRITE(MWA16_NOP)	/* ?? writes zero once per frame */
+	AM_RANGE(0x600000, 0x600001) AM_WRITE(SMH_NOP)	/* ?? writes zero once per frame */
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3fff) AM_READ(MRA8_ROM)
-	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_BANK1)
-	AM_RANGE(0xc000, 0xdfff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xe000, 0xe000) AM_READ(YM2610_status_port_0_A_r)
-	AM_RANGE(0xe001, 0xe001) AM_READ(YM2610_read_port_0_r)
-	AM_RANGE(0xe002, 0xe002) AM_READ(YM2610_status_port_0_B_r)
-	AM_RANGE(0xe200, 0xe200) AM_READ(MRA8_NOP)
+	AM_RANGE(0x0000, 0x3fff) AM_READ(SMH_ROM)
+	AM_RANGE(0x4000, 0x7fff) AM_READ(SMH_BANK1)
+	AM_RANGE(0xc000, 0xdfff) AM_READ(SMH_RAM)
+	AM_RANGE(0xe000, 0xe000) AM_READ(ym2610_status_port_0_a_r)
+	AM_RANGE(0xe001, 0xe001) AM_READ(ym2610_read_port_0_r)
+	AM_RANGE(0xe002, 0xe002) AM_READ(ym2610_status_port_0_b_r)
+	AM_RANGE(0xe200, 0xe200) AM_READ(SMH_NOP)
 	AM_RANGE(0xe201, 0xe201) AM_READ(taitosound_slave_comm_r)
-	AM_RANGE(0xea00, 0xea00) AM_READ(MRA8_NOP)
+	AM_RANGE(0xea00, 0xea00) AM_READ(SMH_NOP)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)
-	AM_RANGE(0xc000, 0xdfff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0xe000, 0xe000) AM_WRITE(YM2610_control_port_0_A_w)
-	AM_RANGE(0xe001, 0xe001) AM_WRITE(YM2610_data_port_0_A_w)
-	AM_RANGE(0xe002, 0xe002) AM_WRITE(YM2610_control_port_0_B_w)
-	AM_RANGE(0xe003, 0xe003) AM_WRITE(YM2610_data_port_0_B_w)
+	AM_RANGE(0x0000, 0x7fff) AM_WRITE(SMH_ROM)
+	AM_RANGE(0xc000, 0xdfff) AM_WRITE(SMH_RAM)
+	AM_RANGE(0xe000, 0xe000) AM_WRITE(ym2610_control_port_0_a_w)
+	AM_RANGE(0xe001, 0xe001) AM_WRITE(ym2610_data_port_0_a_w)
+	AM_RANGE(0xe002, 0xe002) AM_WRITE(ym2610_control_port_0_b_w)
+	AM_RANGE(0xe003, 0xe003) AM_WRITE(ym2610_data_port_0_b_w)
 	AM_RANGE(0xe200, 0xe200) AM_WRITE(taitosound_slave_port_w)
 	AM_RANGE(0xe201, 0xe201) AM_WRITE(taitosound_slave_comm_w)
-	AM_RANGE(0xe400, 0xe403) AM_WRITE(MWA8_NOP)		/* pan control */
-	AM_RANGE(0xee00, 0xee00) AM_WRITE(MWA8_NOP) 		/* ? */
-	AM_RANGE(0xf000, 0xf000) AM_WRITE(MWA8_NOP) 		/* ? */
+	AM_RANGE(0xe400, 0xe403) AM_WRITE(SMH_NOP)		/* pan control */
+	AM_RANGE(0xee00, 0xee00) AM_WRITE(SMH_NOP) 		/* ? */
+	AM_RANGE(0xf000, 0xf000) AM_WRITE(SMH_NOP) 		/* ? */
 	AM_RANGE(0xf200, 0xf200) AM_WRITE(sound_bankswitch_w)
 ADDRESS_MAP_END
 
@@ -371,12 +363,12 @@ ADDRESS_MAP_END
 
 static INPUT_PORTS_START( syvalion )
 	/* 0x200000 (port 0) -> 0x102842.b (-$57be,A5) */
-	PORT_START_TAG("DSWA")
+	PORT_START("DSWA")
 	TAITO_MACHINE_COCKTAIL
 	TAITO_COINAGE_JAPAN_OLD
 
 	/* 0x200000 (port 1) -> 0x102843.b (-$57bd,A5) */
-	PORT_START_TAG("DSWB")
+	PORT_START("DSWB")
 	TAITO_DIFFICULTY
 	PORT_DIPNAME( 0x0c, 0x0c, DEF_STR( Bonus_Life ) )
 	PORT_DIPSETTING(    0x08, "1000k" )
@@ -393,7 +385,7 @@ static INPUT_PORTS_START( syvalion )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_DIPUNUSED( 0x80, IP_ACTIVE_LOW )
 
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN1 )
@@ -403,7 +395,7 @@ static INPUT_PORTS_START( syvalion )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW,  IPT_START1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW,  IPT_START2 )
 
-	PORT_START_TAG("IN1")
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
@@ -413,26 +405,29 @@ static INPUT_PORTS_START( syvalion )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG(P1TRACKX_PORT_TAG)
+	PORT_START("IN2")
+	PORT_BIT( 0xff, IP_ACTIVE_LOW, IPT_UNUSED )
+
+	PORT_START(P1TRACKX_PORT_TAG)
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(30) PORT_KEYDELTA(30) PORT_RESET PORT_PLAYER(1)
 
-	PORT_START_TAG(P1TRACKY_PORT_TAG)
+	PORT_START(P1TRACKY_PORT_TAG)
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(30) PORT_KEYDELTA(30) PORT_RESET PORT_REVERSE PORT_PLAYER(1)
 
-	PORT_START_TAG(P2TRACKX_PORT_TAG)
+	PORT_START(P2TRACKX_PORT_TAG)
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_X ) PORT_SENSITIVITY(30) PORT_KEYDELTA(30) PORT_RESET PORT_PLAYER(2)
 
-	PORT_START_TAG(P2TRACKY_PORT_TAG)
+	PORT_START(P2TRACKY_PORT_TAG)
 	PORT_BIT( 0xff, 0x00, IPT_TRACKBALL_Y ) PORT_SENSITIVITY(30) PORT_KEYDELTA(30) PORT_RESET PORT_REVERSE PORT_PLAYER(2)
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( recordbr )
 	/* 0x200000 (port 0) -> 0x1022e6.b (-$5d1a,A5) */
-	PORT_START_TAG("DSWA")
+	PORT_START("DSWA")
 	TAITO_MACHINE_NO_COCKTAIL
 	TAITO_COINAGE_WORLD
 
-	PORT_START_TAG("DSWB")
+	PORT_START("DSWB")
 	/* 0x200000 (port 1) -> 0x1022e7.b (-$5d19,A5) */
 	TAITO_DIFFICULTY
 	PORT_DIPUNUSED( 0x04, IP_ACTIVE_LOW )
@@ -442,7 +437,7 @@ static INPUT_PORTS_START( recordbr )
 	PORT_DIPUNUSED( 0x40, IP_ACTIVE_LOW )
 	PORT_DIPUNUSED( 0x80, IP_ACTIVE_LOW )
 
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN1 )
@@ -452,7 +447,7 @@ static INPUT_PORTS_START( recordbr )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 
-	PORT_START_TAG("IN1")
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )                 /* IPT_START3 in service mode */
@@ -462,7 +457,7 @@ static INPUT_PORTS_START( recordbr )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("IN2")
+	PORT_START("IN2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_PLAYER(1)
@@ -475,7 +470,7 @@ INPUT_PORTS_END
 
 static INPUT_PORTS_START( dleague )
 	/* 0x200000 -> 0x100526.b ($526,A5) */
-	PORT_START_TAG("DSWA")
+	PORT_START("DSWA")
 	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Difficulty ) )            /* see notes */
 	PORT_DIPSETTING(    0x01, "Constant" )
 	PORT_DIPSETTING(    0x00, "Based on Inning" )
@@ -483,7 +478,7 @@ static INPUT_PORTS_START( dleague )
 	TAITO_COINAGE_JAPAN_OLD
 
 	/* 0x200002 -> 0x100527.b ($527,A5) */
-	PORT_START_TAG("DSWB")
+	PORT_START("DSWB")
 	PORT_DIPUNUSED( 0x01, IP_ACTIVE_LOW )                        /* see notes */
 	PORT_DIPUNUSED( 0x02, IP_ACTIVE_LOW )
 	PORT_DIPNAME( 0x0c, 0x0c, "Extra Credit Needed" )            /* see notes */
@@ -496,7 +491,7 @@ static INPUT_PORTS_START( dleague )
 	PORT_DIPUNUSED( 0x40, IP_ACTIVE_LOW )
 	PORT_DIPUNUSED( 0x80, IP_ACTIVE_LOW )
 
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW,  IPT_SERVICE1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW,  IPT_TILT )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW,  IPT_COIN1 )
@@ -506,10 +501,10 @@ static INPUT_PORTS_START( dleague )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 
-	PORT_START_TAG("IN1")
+	PORT_START("IN1")
 	TAITO_JOY_DUAL_UDLR( 1, 2 )
 
-	PORT_START_TAG("IN2")
+	PORT_START("IN2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
@@ -553,47 +548,59 @@ static const gfx_layout charlayout =
 
 
 static GFXDECODE_START( syvalion )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, tilelayout, 0,     32*16 )
+	GFXDECODE_ENTRY( "gfx1", 0, tilelayout, 0,     32 )
 GFXDECODE_END
 
 static GFXDECODE_START( recordbr )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, tilelayout, 0,     32*16 )
+	GFXDECODE_ENTRY( "gfx1", 0, tilelayout, 0,     32 )
 GFXDECODE_END
 
 static GFXDECODE_START( dleague )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, tilelayout, 0,     32*16 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0, charlayout, 32*16, 16    )	// seems to be bogus...?
+	GFXDECODE_ENTRY( "gfx1", 0, tilelayout, 0,     32 )
+	GFXDECODE_ENTRY( "gfx2", 0, charlayout, 32*16, 16    )	// seems to be bogus...?
 GFXDECODE_END
 
 
+static STATE_POSTLOAD( taitoh_postload )
+{
+	reset_sound_region(machine);
+}
+
+static MACHINE_RESET( taitoh )
+{
+	banknum = -1;
+}
+
 static MACHINE_START( taitoh )
 {
-	state_save_register_global(banknum);
-	state_save_register_func_postload(reset_sound_region);
+	state_save_register_global(machine, banknum);
+	state_save_register_postload(machine, taitoh_postload, NULL);
 }
 
 
 static MACHINE_DRIVER_START( syvalion )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000,24000000 / 2)		/* 12 MHz */
+	MDRV_CPU_ADD("main", M68000,24000000 / 2)		/* 12 MHz */
 	MDRV_CPU_PROGRAM_MAP(syvalion_readmem,syvalion_writemem)
-	MDRV_CPU_VBLANK_INT(irq2_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq2_line_hold)
 
-	MDRV_CPU_ADD(Z80,8000000 / 2)		/* 4 MHz ??? */
+	MDRV_CPU_ADD("audio", Z80,8000000 / 2)		/* 4 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_MACHINE_START(taitoh)
+	MDRV_MACHINE_RESET(taitoh)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(10)
+	MDRV_QUANTUM_TIME(HZ(600))
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*16, 64*16)
 	MDRV_SCREEN_VISIBLE_AREA(0*16, 32*16-1, 3*16, 28*16-1)
+
 	MDRV_GFXDECODE(syvalion)
 	MDRV_PALETTE_LENGTH(33*16)
 
@@ -603,8 +610,8 @@ static MACHINE_DRIVER_START( syvalion )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM2610, 8000000)
-	MDRV_SOUND_CONFIG(syvalion_ym2610_interface)
+	MDRV_SOUND_ADD("ym", YM2610, 8000000)
+	MDRV_SOUND_CONFIG(ym2610_config)
 	MDRV_SOUND_ROUTE(0, "mono", 0.25)
 	MDRV_SOUND_ROUTE(1, "mono", 1.0)
 	MDRV_SOUND_ROUTE(2, "mono", 1.0)
@@ -614,24 +621,26 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( recordbr )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000,24000000 / 2)		/* 12 MHz */
+	MDRV_CPU_ADD("main", M68000,24000000 / 2)		/* 12 MHz */
 	MDRV_CPU_PROGRAM_MAP(recordbr_readmem,recordbr_writemem)
-	MDRV_CPU_VBLANK_INT(irq2_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq2_line_hold)
 
-	MDRV_CPU_ADD(Z80,8000000 / 2)		/* 4 MHz ??? */
+	MDRV_CPU_ADD("audio", Z80,8000000 / 2)		/* 4 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_MACHINE_START(taitoh)
+	MDRV_MACHINE_RESET(taitoh)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(10)
+	MDRV_QUANTUM_TIME(HZ(600))
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*16, 64*16)
 	MDRV_SCREEN_VISIBLE_AREA(1*16, 21*16-1, 2*16, 17*16-1)
+
 	MDRV_GFXDECODE(recordbr)
 	MDRV_PALETTE_LENGTH(32*16)
 
@@ -641,8 +650,8 @@ static MACHINE_DRIVER_START( recordbr )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM2610, 8000000)
-	MDRV_SOUND_CONFIG(syvalion_ym2610_interface)
+	MDRV_SOUND_ADD("ym", YM2610, 8000000)
+	MDRV_SOUND_CONFIG(ym2610_config)
 	MDRV_SOUND_ROUTE(0, "mono", 0.25)
 	MDRV_SOUND_ROUTE(1, "mono", 1.0)
 	MDRV_SOUND_ROUTE(2, "mono", 1.0)
@@ -652,24 +661,26 @@ MACHINE_DRIVER_END
 static MACHINE_DRIVER_START( dleague )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000,24000000 / 2)		/* 12 MHz */
+	MDRV_CPU_ADD("main", M68000,24000000 / 2)		/* 12 MHz */
 	MDRV_CPU_PROGRAM_MAP(dleague_readmem,dleague_writemem)
-	MDRV_CPU_VBLANK_INT(irq1_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq1_line_hold)
 
-	MDRV_CPU_ADD(Z80,8000000 / 2)		/* 4 MHz ??? */
+	MDRV_CPU_ADD("audio", Z80,8000000 / 2)		/* 4 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
 
 	MDRV_MACHINE_START(taitoh)
+	MDRV_MACHINE_RESET(taitoh)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(10)
+	MDRV_QUANTUM_TIME(HZ(600))
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*16, 64*16)
 	MDRV_SCREEN_VISIBLE_AREA(1*16, 21*16-1, 2*16, 17*16-1)
+
 	MDRV_GFXDECODE(dleague)
 	MDRV_PALETTE_LENGTH(33*16)
 
@@ -679,8 +690,8 @@ static MACHINE_DRIVER_START( dleague )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM2610, 8000000)
-	MDRV_SOUND_CONFIG(dleague_ym2610_interface)
+	MDRV_SOUND_ADD("ym", YM2610, 8000000)
+	MDRV_SOUND_CONFIG(ym2610_config)
 	MDRV_SOUND_ROUTE(0, "mono", 0.25)
 	MDRV_SOUND_ROUTE(1, "mono", 1.0)
 	MDRV_SOUND_ROUTE(2, "mono", 1.0)
@@ -694,17 +705,17 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( syvalion )
-	ROM_REGION( 0x80000, REGION_CPU1, 0 )		/* main cpu */
+	ROM_REGION( 0x80000, "main", 0 )		/* main cpu */
 	ROM_LOAD16_BYTE( "b51-20.bin", 0x00000, 0x20000, CRC(440b6418) SHA1(262b65f39eb13c11ae7b87013951097ab0a9cb63) )
 	ROM_LOAD16_BYTE( "b51-22.bin", 0x00001, 0x20000, CRC(e6c61079) SHA1(b786ef1bfc72706347c12c17616652bc8302a98c) )
 	ROM_LOAD16_BYTE( "b51-19.bin", 0x40000, 0x20000, CRC(2abd762c) SHA1(97cdb9f1dba5b11b96b5d3431937669de5220512) )
 	ROM_LOAD16_BYTE( "b51-21.bin", 0x40001, 0x20000, CRC(aa111f30) SHA1(77da4a8db49999f5fa2cf0209028d0f70e26dfe3) )
 
-	ROM_REGION( 0x1c000, REGION_CPU2, 0 )		/* sound cpu */
+	ROM_REGION( 0x1c000, "audio", 0 )		/* sound cpu */
 	ROM_LOAD( "b51-23.bin", 0x00000, 0x04000, CRC(734662de) SHA1(0058d6de68f26cd58b9eb8859e15f3ced6bd3489) )
 	ROM_CONTINUE(           0x10000, 0x0c000 )
 
-	ROM_REGION( 0x400000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x400000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD16_BYTE( "b51-16.bin", 0x000000, 0x20000, CRC(c0fcf7a5) SHA1(4550ba6d822ba12ad39576bcbed09b5fa54279e8) )
 	ROM_LOAD16_BYTE( "b51-12.bin", 0x000001, 0x20000, CRC(6b36d358) SHA1(4101c110e99fe2ac1a989c84857f6438439b79a1) )
 	ROM_LOAD16_BYTE( "b51-15.bin", 0x040000, 0x20000, CRC(30b2ee02) SHA1(eacd179c8760ce9ba01e234dfd3f159773e4f2ab) )
@@ -722,25 +733,25 @@ ROM_START( syvalion )
 	ROM_LOAD16_BYTE( "b51-05.bin", 0x340000, 0x20000, CRC(47976ae9) SHA1(a2b19a39d8968b886412a85c082806917e02d9fd) )
 	ROM_LOAD16_BYTE( "b51-01.bin", 0x340001, 0x20000, CRC(8dab004a) SHA1(1772cdcb9d0ca5ebf429f371c041b9ae12fafcd0) )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )	/* samples */
+	ROM_REGION( 0x80000, "ym.deltat", 0 )	/* samples */
 	ROM_LOAD( "b51-18.bin", 0x00000, 0x80000, CRC(8b23ac83) SHA1(340b9e7f09c1809a332b41d3fb579f5f8cd6367f) )
 
-	ROM_REGION( 0x80000, REGION_SOUND2, 0 )	/* samples */
+	ROM_REGION( 0x80000, "ym", 0 )	/* samples */
 	ROM_LOAD( "b51-17.bin", 0x00000, 0x80000, CRC(d85096aa) SHA1(dac39ed182e9eda06575f1667c4c1ff9a4a56599) )
 ROM_END
 
 ROM_START( recordbr )
-	ROM_REGION( 0x80000, REGION_CPU1, 0 )		/* main cpu */
+	ROM_REGION( 0x80000, "main", 0 )		/* main cpu */
 	ROM_LOAD16_BYTE( "b56-17.rom", 0x00000, 0x20000, CRC(3e0a9c35) SHA1(900a741b2abbbbe883b9d78162a88b4397af1a56) )
 	ROM_LOAD16_BYTE( "b56-16.rom", 0x00001, 0x20000, CRC(b447f12c) SHA1(58ee30337836f260c7fbda728dac93f06d861ec4) )
 	ROM_LOAD16_BYTE( "b56-15.rom", 0x40000, 0x20000, CRC(b346e282) SHA1(f6b4a2e9093a33d19c2eaf3ef9801179f39a83a3) )
 	ROM_LOAD16_BYTE( "b56-21.rom", 0x40001, 0x20000, CRC(e5f63790) SHA1(b81db7690a989146c438609d9633ddcb1fd219dd) )
 
-	ROM_REGION( 0x1c000, REGION_CPU2, 0 )		/* sound cpu */
+	ROM_REGION( 0x1c000, "audio", 0 )		/* sound cpu */
 	ROM_LOAD( "b56-19.rom", 0x00000, 0x04000, CRC(c68085ee) SHA1(78634216a622a08c20dae0422283c4a7ed360546) )
 	ROM_CONTINUE(           0x10000, 0x0c000 )
 
-	ROM_REGION( 0x400000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x400000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD16_BYTE( "b56-04",     0x000000, 0x20000, CRC(f7afdff0) SHA1(8f8ea0e8da20913426ff3b58d7bb63bd352d3fb4) )
 	ROM_LOAD16_BYTE( "b56-08",     0x000001, 0x20000, CRC(c9f0d38a) SHA1(aa22f1a06e00f90c546eebcd8b42da3e3c7d0781) )
 	ROM_LOAD16_BYTE( "b56-03",     0x100000, 0x20000, CRC(4045fd44) SHA1(a84be9eedba7aed30d4f2841016784f8024d9443) )
@@ -750,25 +761,25 @@ ROM_START( recordbr )
 	ROM_LOAD16_BYTE( "b56-01.rom", 0x300000, 0x20000, CRC(766b7260) SHA1(f7d7176af614f06e8c66e890e4d194ffb6f7af73) )
 	ROM_LOAD16_BYTE( "b56-05.rom", 0x300001, 0x20000, CRC(ed390378) SHA1(0275e5ead206028bfcff7ecbe11c7ab961e648ea) )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )	/* samples */
+	ROM_REGION( 0x80000, "ym.deltat", 0 )	/* samples */
 	ROM_LOAD( "b56-09.bin", 0x00000, 0x80000, CRC(7fd9ee68) SHA1(edc4455b3f6a6f30f418d03c6e53af875542a325) )
 
-	ROM_REGION( 0x80000, REGION_SOUND2, 0 )	/* samples */
+	ROM_REGION( 0x80000, "ym", 0 )	/* samples */
 	ROM_LOAD( "b56-10.bin", 0x00000, 0x80000, CRC(de1bce59) SHA1(aa3aea30d6f53e60d9a0d4ec767e1b261d5efc8a) )
 ROM_END
 
 ROM_START( dleague )
-	ROM_REGION( 0x60000, REGION_CPU1, 0 )
+	ROM_REGION( 0x60000, "main", 0 )
 	ROM_LOAD16_BYTE( "c02-19a.33", 0x00000, 0x20000, CRC(7e904e45) SHA1(04ac470c973753e71fba3998099a88ab0e6fcbab) )
 	ROM_LOAD16_BYTE( "c02-21a.36", 0x00001, 0x20000, CRC(18c8a32b) SHA1(507cd7a83dcb6eaefa52f2661b9f3a6fabbfbd46) )
 	ROM_LOAD16_BYTE( "c02-20.34",  0x40000, 0x10000, CRC(cdf593f3) SHA1(6afbd9d8d74e6801dc991eb9fd3205057747b986) )
 	ROM_LOAD16_BYTE( "c02-22.37",  0x40001, 0x10000, CRC(f50db2d7) SHA1(4f16cc42469f1e5bf6dc1aee0919712db089f9cc) )
 
-	ROM_REGION( 0x1c000, REGION_CPU2, 0 )
+	ROM_REGION( 0x1c000, "audio", 0 )
 	ROM_LOAD( "c02-23.40", 0x00000, 0x04000, CRC(5632ee49) SHA1(90dedaf40ab526529cd7d569b78a9d5451ec3e25) )
 	ROM_CONTINUE(          0x10000, 0x0c000 )
 
-	ROM_REGION( 0x400000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x400000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD       ( "c02-02.15", 0x000000, 0x80000, CRC(b273f854) SHA1(5961b9fe2c49fb05f5bc3e27e05925dbef8577e9) )
 	ROM_LOAD16_BYTE( "c02-06.6",  0x080000, 0x20000, CRC(b8473c7b) SHA1(8fe8d838bdba7aaaf4527ac1c5c16604922bb245) )
 	ROM_LOAD16_BYTE( "c02-10.14", 0x080001, 0x20000, CRC(50c02f0f) SHA1(7d13b798c0a98387719ab738b9178ee6079327b2) )
@@ -782,10 +793,10 @@ ROM_START( dleague )
 	ROM_LOAD16_BYTE( "c02-09.9",  0x380000, 0x20000, CRC(a614d234) SHA1(dc68a6a8cf89ab82edc571853249643aa304d37f) )
 	ROM_LOAD16_BYTE( "c02-13.20", 0x380001, 0x20000, CRC(8eb3194d) SHA1(98290f77a03826cdf7c8238dd35da1f9349d5cf5) )
 
-	ROM_REGION( 0x02000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x02000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "c02-18.22", 0x00000, 0x02000, CRC(c88f0bbe) SHA1(18c87c744fbeca35d13033e50f62e5383eb4ec2c) )
 
-	ROM_REGION( 0x80000, REGION_SOUND1, 0 )	/* samples */
+	ROM_REGION( 0x80000, "ym", 0 )	/* samples */
 	ROM_LOAD( "c02-01.31", 0x00000, 0x80000, CRC(d5a3d1aa) SHA1(544f807015b5d854a4d8cb73e4dbae4b953fd440) )
 ROM_END
 
