@@ -216,7 +216,8 @@ cpu #2 (PC=0000060E): unmapped memory word read from 0000683A & FFFF
 ****************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/z80/z80.h"
+#include "cpu/m68000/m68000.h"
 #include "taitoipt.h"
 #include "audio/taitosnd.h"
 #include "video/taitoic.h"
@@ -240,16 +241,16 @@ VIDEO_UPDATE( taitoair );
 
 static WRITE16_HANDLER( system_control_w )
 {
-	if ((ACCESSING_LSB == 0) && ACCESSING_MSB)
+	if ((ACCESSING_BITS_0_7 == 0) && ACCESSING_BITS_8_15)
 	{
 		data >>= 8;
 	}
 
 	dsp_HOLD_signal = (data & 4) ? CLEAR_LINE : ASSERT_LINE;
 
-	cpunum_set_input_line(Machine, 2, INPUT_LINE_RESET, (data & 1) ? CLEAR_LINE : ASSERT_LINE);
+	cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_RESET, (data & 1) ? CLEAR_LINE : ASSERT_LINE);
 
-	logerror("68K:%06x writing %04x to TMS32025.  %s HOLD , %s RESET\n",activecpu_get_previouspc(),data,((data & 4) ? "Clear" : "Assert"),((data & 1) ? "Clear" : "Assert"));
+	logerror("68K:%06x writing %04x to TMS32025.  %s HOLD , %s RESET\n",cpu_get_previouspc(space->cpu),data,((data & 4) ? "Clear" : "Assert"),((data & 1) ? "Clear" : "Assert"));
 }
 
 static READ16_HANDLER( lineram_r )
@@ -259,7 +260,7 @@ static READ16_HANDLER( lineram_r )
 
 static WRITE16_HANDLER( lineram_w )
 {
-	if (ACCESSING_MSB && ACCESSING_LSB)
+	if (ACCESSING_BITS_8_15 && ACCESSING_BITS_0_7)
 		taitoair_line_ram[offset] = data;
 }
 
@@ -270,14 +271,14 @@ static READ16_HANDLER( dspram_r )
 
 static WRITE16_HANDLER( dspram_w )
 {
-	if (ACCESSING_MSB && ACCESSING_LSB)
+	if (ACCESSING_BITS_8_15 && ACCESSING_BITS_0_7)
 		dsp_ram[offset] = data;
 }
 
 static READ16_HANDLER( dsp_HOLD_signal_r )
 {
 	/* HOLD signal is active low */
-	//  logerror("TMS32025:%04x Reading %01x level from HOLD signal\n",activecpu_get_previouspc(),dsp_HOLD_signal);
+	//  logerror("TMS32025:%04x Reading %01x level from HOLD signal\n",cpu_get_previouspc(space->cpu),dsp_HOLD_signal);
 
 	return dsp_HOLD_signal;
 }
@@ -285,7 +286,7 @@ static READ16_HANDLER( dsp_HOLD_signal_r )
 static WRITE16_HANDLER( dsp_HOLDA_signal_w )
 {
 	if (offset)
-		logerror("TMS32025:%04x Writing %01x level to HOLD-Acknowledge signal\n",activecpu_get_previouspc(),data);
+		logerror("TMS32025:%04x Writing %01x level to HOLD-Acknowledge signal\n",cpu_get_previouspc(space->cpu),data);
 }
 
 
@@ -295,7 +296,7 @@ static WRITE16_HANDLER( airsys_paletteram16_w )	/* xxBBBBxRRRRxGGGG */
 	COMBINE_DATA(&paletteram16[offset]);
 
 	a = paletteram16[offset];
-	palette_set_color_rgb(Machine,offset,pal4bit(a >> 0),pal4bit(a >> 5),pal4bit(a >> 10));
+	palette_set_color_rgb(space->machine,offset,pal4bit(a >> 0),pal4bit(a >> 5),pal4bit(a >> 10));
 }
 
 
@@ -312,16 +313,16 @@ static READ16_HANDLER( stick_input_r )
 	switch( offset )
 	{
 		case 0x00:	/* "counter 1" lo */
-			return readinputportbytag(STICK1_PORT_TAG);
+			return input_port_read(space->machine, STICK1_PORT_TAG);
 
 		case 0x01:	/* "counter 2" lo */
-			return readinputportbytag(STICK2_PORT_TAG);
+			return input_port_read(space->machine, STICK2_PORT_TAG);
 
 		case 0x02:	/* "counter 1" hi */
-			return (readinputportbytag(STICK1_PORT_TAG) & 0xff00) >> 8;
+			return (input_port_read(space->machine, STICK1_PORT_TAG) & 0xff00) >> 8;
 
 		case 0x03:	/* "counter 2" hi */
-			return (readinputportbytag(STICK2_PORT_TAG) & 0xff00) >> 8;
+			return (input_port_read(space->machine, STICK2_PORT_TAG) & 0xff00) >> 8;
 	}
 
 	return 0;
@@ -332,36 +333,41 @@ static READ16_HANDLER( stick2_input_r )
 	switch( offset )
 	{
 		case 0x00:	/* "counter 3" lo */
-			return readinputportbytag(STICK3_PORT_TAG);
+			return input_port_read(space->machine, STICK3_PORT_TAG);
 
 		case 0x02:	/* "counter 3" hi */
-			return (readinputportbytag(STICK3_PORT_TAG) & 0xff00) >> 8;
+			return (input_port_read(space->machine, STICK3_PORT_TAG) & 0xff00) >> 8;
 	}
 
 	return 0;
 }
 
 
-static INT32 banknum = -1;
+static INT32 banknum;
 
-static void reset_sound_region(void)
+static void reset_sound_region(running_machine *machine)
 {
-	memory_set_bankptr(1, memory_region(REGION_CPU2) + (banknum * 0x4000) + 0x10000);
+	memory_set_bankptr(machine, 1, memory_region(machine, "audio") + (banknum * 0x4000) + 0x10000);
 }
 
 static WRITE8_HANDLER( sound_bankswitch_w )
 {
 	banknum = (data - 1) & 3;
-	reset_sound_region();
+	reset_sound_region(space->machine);
 }
 
+static STATE_POSTLOAD( taitoair_postload )
+{
+	reset_sound_region(machine);
+}
 
 static MACHINE_START( taitoair )
 {
 	dsp_HOLD_signal = ASSERT_LINE;
+	banknum = -1;
 
-	state_save_register_global(banknum);
-	state_save_register_func_postload(reset_sound_region);
+	state_save_register_global(machine, banknum);
+	state_save_register_postload(machine, taitoair_postload, NULL);
 }
 
 
@@ -375,14 +381,14 @@ static ADDRESS_MAP_START( airsys_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x140000, 0x140001) AM_WRITE(system_control_w)	/* Pause the TMS32025 */
 	AM_RANGE(0x180000, 0x183fff) AM_RAM              		/* "gradiation ram (0)" */
 	AM_RANGE(0x184000, 0x187fff) AM_RAM            			/* "gradiation ram (1)" */
-	AM_RANGE(0x188000, 0x18bfff) AM_READWRITE(MRA16_RAM, airsys_paletteram16_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x188000, 0x18bfff) AM_RAM_WRITE(airsys_paletteram16_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x800000, 0x820fff) AM_READWRITE(TC0080VCO_word_r, TC0080VCO_word_w)	/* tilemaps, sprites */
 	AM_RANGE(0x908000, 0x90ffff) AM_RAM AM_BASE(&taitoair_line_ram)	/* "line ram" */
 	AM_RANGE(0x910000, 0x91ffff) AM_RAM	AM_BASE(&dsp_ram)	/* "dsp common ram" (TMS320C25) */
 	AM_RANGE(0xa00000, 0xa00007) AM_READ(stick_input_r)
 	AM_RANGE(0xa00100, 0xa00107) AM_READ(stick2_input_r)
 	AM_RANGE(0xa00200, 0xa0020f) AM_READWRITE(TC0220IOC_halfword_r, TC0220IOC_halfword_w)	/* other I/O */
-	AM_RANGE(0xa80000, 0xa80001) AM_READWRITE(MRA16_NOP, taitosound_port16_lsb_w)
+	AM_RANGE(0xa80000, 0xa80001) AM_READWRITE(SMH_NOP, taitosound_port16_lsb_w)
 	AM_RANGE(0xa80002, 0xa80003) AM_READWRITE(taitosound_comm16_lsb_r, taitosound_comm16_lsb_w)
 	AM_RANGE(0xb00000, 0xb007ff) AM_RAM						/* "power common ram" (mecha drive) */
 ADDRESS_MAP_END
@@ -393,16 +399,16 @@ static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x3fff) AM_ROM
 	AM_RANGE(0x4000, 0x7fff) AM_ROMBANK(1)
 	AM_RANGE(0xc000, 0xdfff) AM_RAM
-	AM_RANGE(0xe000, 0xe000) AM_READWRITE(YM2610_status_port_0_A_r, YM2610_control_port_0_A_w)
-	AM_RANGE(0xe001, 0xe001) AM_READWRITE(YM2610_read_port_0_r, YM2610_data_port_0_A_w)
-	AM_RANGE(0xe002, 0xe002) AM_READWRITE(YM2610_status_port_0_B_r, YM2610_control_port_0_B_w)
-	AM_RANGE(0xe003, 0xe003) AM_WRITE(YM2610_data_port_0_B_w)
-	AM_RANGE(0xe200, 0xe200) AM_READWRITE(MRA8_NOP, taitosound_slave_port_w)
+	AM_RANGE(0xe000, 0xe000) AM_READWRITE(ym2610_status_port_0_a_r, ym2610_control_port_0_a_w)
+	AM_RANGE(0xe001, 0xe001) AM_READWRITE(ym2610_read_port_0_r, ym2610_data_port_0_a_w)
+	AM_RANGE(0xe002, 0xe002) AM_READWRITE(ym2610_status_port_0_b_r, ym2610_control_port_0_b_w)
+	AM_RANGE(0xe003, 0xe003) AM_WRITE(ym2610_data_port_0_b_w)
+	AM_RANGE(0xe200, 0xe200) AM_READWRITE(SMH_NOP, taitosound_slave_port_w)
 	AM_RANGE(0xe201, 0xe201) AM_READWRITE(taitosound_slave_comm_r, taitosound_slave_comm_w)
-	AM_RANGE(0xe400, 0xe403) AM_WRITE(MWA8_NOP)		/* pan control */
-	AM_RANGE(0xea00, 0xea00) AM_READ(MRA8_NOP)
-	AM_RANGE(0xee00, 0xee00) AM_WRITE(MWA8_NOP) 		/* ? */
-	AM_RANGE(0xf000, 0xf000) AM_WRITE(MWA8_NOP) 		/* ? */
+	AM_RANGE(0xe400, 0xe403) AM_WRITE(SMH_NOP)		/* pan control */
+	AM_RANGE(0xea00, 0xea00) AM_READ(SMH_NOP)
+	AM_RANGE(0xee00, 0xee00) AM_WRITE(SMH_NOP) 		/* ? */
+	AM_RANGE(0xf000, 0xf000) AM_WRITE(SMH_NOP) 		/* ? */
 	AM_RANGE(0xf200, 0xf200) AM_WRITE(sound_bankswitch_w)
 ADDRESS_MAP_END
 
@@ -428,14 +434,14 @@ ADDRESS_MAP_END
 
 static INPUT_PORTS_START( topland )
 	/* 0xa00200 -> 0x0c0d7c (-$7285,A5) */
-	PORT_START_TAG("DSWA")
+	PORT_START("DSWA")
 	PORT_DIPUNUSED_DIPLOC( 0x01, IP_ACTIVE_LOW, "SWA:1" )
 	PORT_DIPUNUSED_DIPLOC( 0x02, IP_ACTIVE_LOW, "SWA:2" )
 	TAITO_DSWA_BITS_2_TO_3_LOC(SWA)
 	TAITO_COINAGE_WORLD_LOC(SWA)
 
 	/* 0xa00202 -> 0x0c0d7e (-$7283,A5) */
-	PORT_START_TAG("DSWA")
+	PORT_START("DSWB")
 	TAITO_DIFFICULTY_LOC(SWA)
 	PORT_DIPUNUSED_DIPLOC( 0x04, IP_ACTIVE_LOW, "SWB:3" )
 	PORT_DIPUNUSED_DIPLOC( 0x08, IP_ACTIVE_LOW, "SWB:4" )
@@ -444,7 +450,7 @@ static INPUT_PORTS_START( topland )
 	PORT_DIPUNUSED_DIPLOC( 0x40, IP_ACTIVE_LOW, "SWB:7" )
 	PORT_DIPUNUSED_DIPLOC( 0x80, IP_ACTIVE_LOW, "SWB:8" )
 
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN1 )
@@ -454,7 +460,7 @@ static INPUT_PORTS_START( topland )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW,  IPT_START1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW,  IPT_BUTTON3 ) PORT_PLAYER(1)	/* "door" (!) */
 
-	PORT_START_TAG("IN1")
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW,  IPT_BUTTON1 ) PORT_PLAYER(1)	/* slot down */
 	PORT_BIT( 0x02, IP_ACTIVE_LOW,  IPT_BUTTON2 ) PORT_PLAYER(1)	/* slot up */
 	PORT_BIT( 0x04, IP_ACTIVE_LOW,  IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)	/* handle */
@@ -464,24 +470,27 @@ static INPUT_PORTS_START( topland )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("Freeze") PORT_CODE(KEYCODE_F1)
 	PORT_BIT( 0x80, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 
+	PORT_START("IN2")
+	PORT_BIT( 0xff, IP_ACTIVE_LOW,  IPT_UNUSED )
+
 	/* The range of these sticks reflects the range test mode displays.
        Eventually we want standard 0-0xff input range and a scale-up later
        in the stick_r routines.  And fake DSW with self-centering option
        to make keyboard control feasible! */
 
-	PORT_START_TAG(STICK1_PORT_TAG)
+	PORT_START(STICK1_PORT_TAG)
 	PORT_BIT( 0xffff, 0x0000, IPT_AD_STICK_X ) PORT_MINMAX(0xf800,0x7ff) PORT_SENSITIVITY(30) PORT_KEYDELTA(40) PORT_PLAYER(1)
 
-	PORT_START_TAG(STICK2_PORT_TAG)
+	PORT_START(STICK2_PORT_TAG)
 	PORT_BIT( 0xffff, 0x0000, IPT_AD_STICK_Y ) PORT_MINMAX(0xf800,0x7ff) PORT_SENSITIVITY(30) PORT_KEYDELTA(40) PORT_PLAYER(1)
 
-	PORT_START_TAG(STICK3_PORT_TAG)
+	PORT_START(STICK3_PORT_TAG)
 	PORT_BIT( 0xffff, 0x0000, IPT_AD_STICK_Y ) PORT_MINMAX(0xf800,0x7ff) PORT_SENSITIVITY(30) PORT_KEYDELTA(40) PORT_PLAYER(2)
 INPUT_PORTS_END
 
 static INPUT_PORTS_START( ainferno )
 	/* 0xa00200 -> 0x0c0003.b (-$7ffd,A5) */
-	PORT_START_TAG("DSWA")
+	PORT_START("DSWA")
 	PORT_DIPNAME( 0x01, 0x01, "Moving Control" )		PORT_DIPLOCATION("SWA:1")
 	PORT_DIPSETTING(    0x01, "Upright/Cockpit" )
 	PORT_DIPSETTING(    0x00, "DX Moving Only" )
@@ -492,7 +501,7 @@ static INPUT_PORTS_START( ainferno )
 	TAITO_COINAGE_US_LOC(SWA)
 
 	/* 0xa00202 -> 0x0c0004.b (-$7ffc,A5) */
-	PORT_START_TAG("DSWB")
+	PORT_START("DSWB")
 	TAITO_DIFFICULTY_LOC(SWA)
 	PORT_DIPNAME( 0x0c, 0x0c, "Timer Length" )		PORT_DIPLOCATION("SWB:3,4")
 	PORT_DIPSETTING(    0x08, DEF_STR( Easy ) )
@@ -506,7 +515,7 @@ static INPUT_PORTS_START( ainferno )
 	PORT_DIPUNUSED_DIPLOC( 0x40, IP_ACTIVE_LOW, "SWB:7" )
 	PORT_DIPUNUSED_DIPLOC( 0x80, IP_ACTIVE_LOW, "SWB:8" )
 
-	PORT_START_TAG("IN0")
+	PORT_START("IN0")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_COIN1 )
@@ -516,7 +525,7 @@ static INPUT_PORTS_START( ainferno )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW,  IPT_START1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW,  IPT_START2 )
 
-	PORT_START_TAG("IN1")
+	PORT_START("IN1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW,  IPT_BUTTON1 ) PORT_PLAYER(1)	/* lever */
 	PORT_BIT( 0x02, IP_ACTIVE_LOW,  IPT_BUTTON2 ) PORT_PLAYER(1)	/* handle x */
 	PORT_BIT( 0x04, IP_ACTIVE_LOW,  IPT_BUTTON3 ) PORT_PLAYER(1)	/* handle y */
@@ -526,18 +535,21 @@ static INPUT_PORTS_START( ainferno )
 	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_OTHER ) PORT_NAME("Freeze") PORT_CODE(KEYCODE_F1)
 	PORT_BIT( 0x80, IP_ACTIVE_LOW,  IPT_UNKNOWN )
 
+	PORT_START("IN2")
+	PORT_BIT( 0xff, IP_ACTIVE_LOW,  IPT_UNUSED )
+
 	/* The range of these sticks reflects the range test mode displays.
        Eventually we want standard 0-0xff input range and a scale-up later
        in the stick_r routines. And fake DSW with self-centering option
        to make keyboard control feasible! */
 
-	PORT_START_TAG(STICK1_PORT_TAG)
+	PORT_START(STICK1_PORT_TAG)
 	PORT_BIT( 0xffff, 0x0000, IPT_AD_STICK_X ) PORT_MINMAX(0xf800,0x7ff) PORT_SENSITIVITY(30) PORT_KEYDELTA(40) PORT_PLAYER(1)
 
-	PORT_START_TAG(STICK2_PORT_TAG)
+	PORT_START(STICK2_PORT_TAG)
 	PORT_BIT( 0xffff, 0x0000, IPT_AD_STICK_Y ) PORT_MINMAX(0xf800,0x7ff) PORT_SENSITIVITY(30) PORT_KEYDELTA(40) PORT_PLAYER(1)
 
-	PORT_START_TAG(STICK3_PORT_TAG)
+	PORT_START(STICK3_PORT_TAG)
 	PORT_BIT( 0xffff, 0x0000, IPT_AD_STICK_Y ) PORT_MINMAX(0xf800,0x7ff) PORT_SENSITIVITY(30) PORT_KEYDELTA(40) PORT_PLAYER(2)
 INPUT_PORTS_END
 
@@ -562,7 +574,7 @@ static const gfx_layout tilelayout =
 };
 
 static GFXDECODE_START( airsys )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, tilelayout, 0, 32*16 )
+	GFXDECODE_ENTRY( "gfx1", 0, tilelayout, 0, 32*16 )
 GFXDECODE_END
 
 
@@ -571,16 +583,14 @@ GFXDECODE_END
 ************************************************************/
 
 /* Handler called by the YM2610 emulator when the internal timers cause an IRQ */
-static void irqhandler(int irq)
+static void irqhandler(running_machine *machine, int irq)
 {
-	cpunum_set_input_line(Machine, 1,0,irq ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[1],0,irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
-static const struct YM2610interface airsys_ym2610_interface =
+static const ym2610_interface airsys_ym2610_interface =
 {
-	irqhandler,
-	REGION_SOUND2,
-	REGION_SOUND1
+	irqhandler
 };
 
 
@@ -591,29 +601,30 @@ static const struct YM2610interface airsys_ym2610_interface =
 static MACHINE_DRIVER_START( airsys )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000,24000000 / 2)		/* 12 MHz ??? */
+	MDRV_CPU_ADD("main", M68000,24000000 / 2)		/* 12 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(airsys_map, 0)
-	MDRV_CPU_VBLANK_INT(irq5_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq5_line_hold)
 
-	MDRV_CPU_ADD(Z80,8000000 / 2)			/* 4 MHz ??? */
+	MDRV_CPU_ADD("audio", Z80,8000000 / 2)			/* 4 MHz ??? */
 	MDRV_CPU_PROGRAM_MAP(sound_map, 0)
 
-	MDRV_CPU_ADD(TMS32025,24000000)			/* 24 MHz ??? *///
+	MDRV_CPU_ADD("dsp", TMS32025,24000000)			/* 24 MHz ??? *///
 	MDRV_CPU_PROGRAM_MAP(DSP_map_program, 0)
 	MDRV_CPU_DATA_MAP(DSP_map_data, 0)
 	MDRV_CPU_IO_MAP(DSP_map_io, 0)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(10)
+	MDRV_QUANTUM_TIME(HZ(600))
 
 	MDRV_MACHINE_START(taitoair)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*16, 64*16)
 	MDRV_SCREEN_VISIBLE_AREA(0*16, 32*16-1, 3*16, 28*16-1)
+
 	MDRV_GFXDECODE(airsys)
 	MDRV_PALETTE_LENGTH(512*16)
 
@@ -623,7 +634,7 @@ static MACHINE_DRIVER_START( airsys )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM2610, 8000000)
+	MDRV_SOUND_ADD("ym", YM2610, 8000000)
 	MDRV_SOUND_CONFIG(airsys_ym2610_interface)
 	MDRV_SOUND_ROUTE(0, "mono", 0.30)
 	MDRV_SOUND_ROUTE(1, "mono", 0.60)
@@ -639,7 +650,7 @@ board - possibly?
 *************************************************************/
 
 ROM_START( topland )
-	ROM_REGION( 0xc0000, REGION_CPU1, 0 )	/* 68000 */
+	ROM_REGION( 0xc0000, "main", 0 )	/* 68000 */
 	ROM_LOAD16_BYTE( "b62_41.43",  0x00000, 0x20000, CRC(28264798) SHA1(72e4441ad468f37cff69c36699867119ad28274c) )
 	ROM_LOAD16_BYTE( "b62_40.14",  0x00001, 0x20000, CRC(db872f7d) SHA1(6932c62d8051b1811c30139dbd0375115305c731) )
 	ROM_LOAD16_BYTE( "b62_25.42",  0x40000, 0x20000, CRC(1bd53a72) SHA1(ada679198739cd6a419d3fa4311bb92dc385099c) )
@@ -647,15 +658,15 @@ ROM_START( topland )
 	ROM_LOAD16_BYTE( "b62_23.41",  0x80000, 0x20000, CRC(ef3a971c) SHA1(0840668dda48f4c9a85410361bfba3ae9580a71f) )
 	ROM_LOAD16_BYTE( "b62_22.12",  0x80001, 0x20000, CRC(94279201) SHA1(8518d8e722d4f2516f75224d9a21ab20d8ee6c78) )
 
-	ROM_REGION( 0x1c000, REGION_CPU2, 0 )	/* Z80 */
+	ROM_REGION( 0x1c000, "audio", 0 )	/* Z80 */
 	ROM_LOAD( "b62-42.34", 0x00000, 0x04000, CRC(389230e0) SHA1(3a336987aad7bf4df658f924de4bbe6f0fff6d59) )
 	ROM_CONTINUE(          0x10000, 0x0c000 )
 
-	ROM_REGION( 0x20000, REGION_CPU3, 0 )	/* TMS320C25 */
+	ROM_REGION( 0x20000, "dsp", 0 )	/* TMS320C25 */
 	ROM_LOAD16_BYTE( "b62-21.35", 0x00000, 0x02000, CRC(5f38460d) SHA1(0593718d15b30b10f7686959932e2c934de2a529) )	// cpu board
 	ROM_LOAD16_BYTE( "b62-20.6",  0x00001, 0x02000, CRC(a4afe958) SHA1(7593a327f4ea0cc9e28fd3269278871f62fb0598) )	// cpu board
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )	/* 16x16 tiles */
+	ROM_REGION( 0x100000, "gfx1", ROMREGION_DISPOSE )	/* 16x16 tiles */
 	ROM_LOAD16_BYTE( "b62-33.39",  0x000000, 0x20000, CRC(38786867) SHA1(7292e3fa69cad6494f2e8e7efa9c3f989bdf958d) )
 	ROM_LOAD16_BYTE( "b62-36.48",  0x000001, 0x20000, CRC(4259e76a) SHA1(eb0dc5d0a6f875e3b8335fb30d4c2ad3880c31b9) )
 	ROM_LOAD16_BYTE( "b62-29.27",  0x040000, 0x20000, CRC(efdd5c51) SHA1(6df3e9782946cf6f4a21ee3d335548c53cd21e3a) )
@@ -665,20 +676,20 @@ ROM_START( topland )
 	ROM_LOAD16_BYTE( "b62-31.29",  0x0c0000, 0x20000, CRC(3feebfe3) SHA1(5b014d7d6fa1daf400ac1a437f551281debfdba6) )
 	ROM_LOAD16_BYTE( "b62-32.30",  0x0c0001, 0x20000, CRC(66806646) SHA1(d8e0c37b5227d8583d523164ffc6828b4508d5a3) )
 
-	ROM_REGION( 0xa0000, REGION_SOUND1, 0 )	/* ADPCM samples */
-	ROM_LOAD( "b62-13.1",  0x00000, 0x20000, CRC(b37dc3ea) SHA1(198d4f828132316c624da998e49b1873b9886bf0) )
-	ROM_LOAD( "b62-14.2",  0x20000, 0x20000, CRC(617948a3) SHA1(4660570fa6263c28cfae7ccdf154763cc6144896) )
+	ROM_REGION( 0xa0000, "ym", 0 )	/* ADPCM samples */
+	ROM_LOAD( "b62-17.5",  0x00000, 0x20000, CRC(36447066) SHA1(91c8cc4e99534b2d533895a342abb22766a20090) )
+	ROM_LOAD( "b62-16.4",  0x20000, 0x20000, CRC(203a5c27) SHA1(f6fc9322dea8d82bfec3be3fdc8616dc6adf666e) )
 	ROM_LOAD( "b62-15.3",  0x40000, 0x20000, CRC(e35ffe81) SHA1(f35afdd7cfd4c09907fb062beb5ae46c2286a381) )
-	ROM_LOAD( "b62-16.4",  0x60000, 0x20000, CRC(203a5c27) SHA1(f6fc9322dea8d82bfec3be3fdc8616dc6adf666e) )
-	ROM_LOAD( "b62-17.5",  0x80000, 0x20000, CRC(36447066) SHA1(91c8cc4e99534b2d533895a342abb22766a20090) )
+	ROM_LOAD( "b62-14.2",  0x60000, 0x20000, CRC(617948a3) SHA1(4660570fa6263c28cfae7ccdf154763cc6144896) )
+	ROM_LOAD( "b62-13.1",  0x80000, 0x20000, CRC(b37dc3ea) SHA1(198d4f828132316c624da998e49b1873b9886bf0) )
 
-	ROM_REGION( 0x20000, REGION_SOUND2, 0 )	/* Delta-T samples */
+	ROM_REGION( 0x20000, "ym.deltat", 0 )	/* Delta-T samples */
 	ROM_LOAD( "b62-18.31", 0x00000, 0x20000, CRC(3a4e687a) SHA1(43f07fe19dec351e851defdf9c7810fb9df04736) )
 
-	ROM_REGION( 0x02000, REGION_USER1, 0 )	/* unknown */
+	ROM_REGION( 0x02000, "user1", 0 )	/* unknown */
 	ROM_LOAD( "b62-28.22", 0x00000, 0x02000, CRC(c4be68a6) SHA1(2c07a0e71d11bca67427331217c507d849500ec1) )	// video board
 
-	ROM_REGION( 0x0800, REGION_PLDS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0800, "plds", ROMREGION_DISPOSE )
 	ROM_LOAD( "pal20l8b-b62-02.bin", 0x0000, 0x0144, CRC(c43ab9d8) SHA1(38542b10e9206a25669534ee26a0472e5f2d6257) )
 	ROM_LOAD( "pal20l8b-b62-03.bin", 0x0200, 0x0144, CRC(904753fa) SHA1(87f7414c3eab5740b188276b06c5b898ed07c1cd) )
 	ROM_LOAD( "pal20l8b-b62-04.bin", 0x0400, 0x0144, CRC(80512abc) SHA1(0e87e59df3c4d3b4adba295dbd5a2c27b9d5fefd) )
@@ -686,7 +697,7 @@ ROM_START( topland )
 ROM_END
 
 ROM_START( ainferno )
-	ROM_REGION( 0xc0000, REGION_CPU1, 0 )	/* 68000 */
+	ROM_REGION( 0xc0000, "main", 0 )	/* 68000 */
 	ROM_LOAD16_BYTE( "c45_22.43", 0x00000, 0x20000, CRC(50300926) SHA1(9c2a60282d3f9f115b94cb5b6d64bbfc9d726d1d) )
 	ROM_LOAD16_BYTE( "c45_20.14", 0x00001, 0x20000, CRC(39b189d9) SHA1(002013c02b546d3f5a9f3a3149971975a73cc8ce) )
 	ROM_LOAD16_BYTE( "c45_21.42", 0x40000, 0x20000, CRC(1b687241) SHA1(309e42f79cbd48ceae58a15afb648aef838822f0) )
@@ -694,15 +705,15 @@ ROM_START( ainferno )
 
 	/* 0x80000 to 0xbffff is empty for this game */
 
-	ROM_REGION( 0x1c000, REGION_CPU2, 0 )	/* Z80 */
+	ROM_REGION( 0x1c000, "audio", 0 )	/* Z80 */
 	ROM_LOAD( "c45-23.34", 0x00000, 0x04000, CRC(d0750c78) SHA1(63232c2acef86e8c8ffaad36ab0b6c4cc1eb48f8) )
 	ROM_CONTINUE(          0x10000, 0x0c000 )
 
-	ROM_REGION( 0x20000, REGION_CPU3, 0 )	/* TMS320C25 */
+	ROM_REGION( 0x20000, "dsp", 0 )	/* TMS320C25 */
 	ROM_LOAD16_BYTE( "c45-25.35", 0x00000, 0x02000, CRC(c0d39f95) SHA1(542aa6e2af510aea00db40bf803cb6653d4e7747) )
 	ROM_LOAD16_BYTE( "c45-24.6",  0x00001, 0x02000, CRC(1013d937) SHA1(817769d21583f5281ba044ce8c134c9239d1e83e) )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE )	/* 16x16 tiles */
+	ROM_REGION( 0x100000, "gfx1", ROMREGION_DISPOSE )	/* 16x16 tiles */
 	ROM_LOAD16_BYTE( "c45-11.28", 0x000000, 0x20000, CRC(d9b4b77c) SHA1(69d570efa8146fb0a712ff45e77bda6fd85769f8) )
 	ROM_LOAD16_BYTE( "c45-15.40", 0x000001, 0x20000, CRC(d4610698) SHA1(5de519a23300d5b3b09ce7cf8c02a1a6b2fb985c) )
 	ROM_LOAD16_BYTE( "c45-12.29", 0x040000, 0x20000, CRC(4ae305b8) SHA1(2bbb981853a7abbba90afb8eb58f6869357551d3) )
@@ -712,20 +723,20 @@ ROM_START( ainferno )
 	ROM_LOAD16_BYTE( "c45-14.31", 0x0c0000, 0x20000, CRC(481b6f29) SHA1(0b047e805663b144dc2388c86438950fcdc29658) )
 	ROM_LOAD16_BYTE( "c45-18.43", 0x0c0001, 0x20000, CRC(ba7ecf3b) SHA1(dd073b7bfbf2f88432337027ae9fb6c4f02a538f) )
 
-	ROM_REGION( 0xa0000, REGION_SOUND1, 0 )	/* ADPCM samples */
+	ROM_REGION( 0xa0000, "ym", 0 )	/* ADPCM samples */
 	ROM_LOAD( "c45-01.5",  0x00000, 0x20000, CRC(052997b2) SHA1(3aa8b4f759a1c196de39754a9ccdf4fabdbab388) )
 	ROM_LOAD( "c45-02.4",  0x20000, 0x20000, CRC(2fc0a88e) SHA1(6a635671fa2518f74015429ce580d7b7f00299ad) )
 	ROM_LOAD( "c45-03.3",  0x40000, 0x20000, CRC(0e1e5b5f) SHA1(a53d5ba01825f825e31a014cb4808f59ef86f0c9) )
 	ROM_LOAD( "c45-04.2",  0x60000, 0x20000, CRC(6d081044) SHA1(2d98bde55621762509dfc645d9ca5e267b1757ae) )
 	ROM_LOAD( "c45-05.1",  0x80000, 0x20000, CRC(6c59a808) SHA1(6264bbe4d7ad3070c6441859eb704a42910a82f0) )
 
-	ROM_REGION( 0x20000, REGION_SOUND2, 0 )	/* Delta-T samples */
+	ROM_REGION( 0x20000, "ym.deltat", 0 )	/* Delta-T samples */
 	ROM_LOAD( "c45-06.31", 0x00000, 0x20000, CRC(6a7976d4) SHA1(a465f9bb874b1eff08742b33cc3c364703b281ca) )
 
-	ROM_REGION( 0x02000, REGION_USER1, 0 )
+	ROM_REGION( 0x02000, "user1", 0 )
 	ROM_LOAD( "c45-xx.22", 0x00000, 0x02000, NO_DUMP )	// video board
 
-	ROM_REGION( 0x1c00, REGION_PLDS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x1c00, "plds", ROMREGION_DISPOSE )
 	ROM_LOAD( "pal16l8b-c45-07.ic6",   0x0000, 0x0104, CRC(a139114f) SHA1(d21f0c02c34a59b2cea925a9a417d5c2db27a30e) )
 	ROM_LOAD( "pal16l8b-c45-08.ic62",  0x0200, 0x0104, CRC(6f8ec860) SHA1(25161f6e5a5a76c35e697312567abe995b08b945) )
 	ROM_LOAD( "pal16l8b-c45-09.ic63",  0x0400, 0x0104, CRC(6703d122) SHA1(8636ee19cf850461e95318b2b82ace036d92225d) )
