@@ -18,17 +18,13 @@
 
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/m68000/m68000.h"
 #include "machine/atarigen.h"
 #include "audio/atarijsa.h"
 #include "thunderj.h"
 
 
 
-static UINT16 *shared_ram;
-static UINT16 *rom_base[2];
-
-
 /*************************************
  *
  *  Initialization & interrupts
@@ -37,36 +33,18 @@ static UINT16 *rom_base[2];
 
 static void update_interrupts(running_machine *machine)
 {
-	int newstate = 0;
-	int newstate2 = 0;
-
-	if (atarigen_scanline_int_state)
-		newstate |= 4, newstate2 |= 4;
-	if (atarigen_sound_int_state)
-		newstate |= 6;
-
-	if (newstate)
-		cpunum_set_input_line(machine, 0, newstate, ASSERT_LINE);
-	else
-		cpunum_set_input_line(machine, 0, 7, CLEAR_LINE);
-
-	if (newstate2)
-		cpunum_set_input_line(machine, 1, newstate2, ASSERT_LINE);
-	else
-		cpunum_set_input_line(machine, 1, 7, CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], 4, atarigen_scanline_int_state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[1], 4, atarigen_scanline_int_state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], 6, atarigen_sound_int_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 static MACHINE_RESET( thunderj )
 {
 	atarigen_eeprom_reset();
-	atarivc_reset(0, atarivc_eof_data, 2);
 	atarigen_interrupt_reset(update_interrupts);
+	atarivc_reset(machine->primary_screen, atarivc_eof_data, 2);
 	atarijsa_reset();
-
-	rom_base[0] = (UINT16 *)memory_region(REGION_CPU1);
-	rom_base[1] = (UINT16 *)memory_region(REGION_CPU2);
-	memory_set_bankptr(1, shared_ram);
 }
 
 
@@ -79,7 +57,7 @@ static MACHINE_RESET( thunderj )
 
 static READ16_HANDLER( special_port2_r )
 {
-	int result = readinputport(2);
+	int result = input_port_read(space->machine, "260012");
 
 	if (atarigen_sound_to_cpu_ready) result ^= 0x0004;
 	if (atarigen_cpu_to_sound_ready) result ^= 0x0008;
@@ -92,18 +70,18 @@ static READ16_HANDLER( special_port2_r )
 static WRITE16_HANDLER( latch_w )
 {
 	/* reset extra CPU */
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		/* 0 means hold CPU 2's reset low */
 		if (data & 1)
-			cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, CLEAR_LINE);
+			cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, CLEAR_LINE);
 		else
-			cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, ASSERT_LINE);
+			cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, ASSERT_LINE);
 
 		/* bits 2-5 are the alpha bank */
 		if (thunderj_alpha_tile_bank != ((data >> 2) & 7))
 		{
-			video_screen_update_partial(0, video_screen_get_vpos(0));
+			video_screen_update_partial(space->machine->primary_screen, video_screen_get_vpos(space->machine->primary_screen));
 			tilemap_mark_all_tiles_dirty(atarigen_alpha_tilemap);
 			thunderj_alpha_tile_bank = (data >> 2) & 7;
 		}
@@ -112,61 +90,19 @@ static WRITE16_HANDLER( latch_w )
 
 
 
-/*************************************
- *
- *  Synchronization helper
- *
- *************************************/
-
-static TIMER_CALLBACK( shared_sync_callback )
-{
-	if (--param)
-		timer_set(ATTOTIME_IN_USEC(50), NULL, param, shared_sync_callback);
-}
-
-
-static READ16_HANDLER( shared_ram_r )
-{
-	UINT16 result = shared_ram[offset];
-
-	/* look for a byte access, and then check for the high bit and a TAS opcode */
-	if (mem_mask != 0 && (result & ~mem_mask & 0x8080))
-	{
-		offs_t ppc = activecpu_get_previouspc();
-		if (ppc < 0xa0000)
-		{
-			int cpunum = cpu_getactivecpu();
-			UINT16 opcode = rom_base[cpunum][ppc / 2];
-
-			/* look for TAS or BTST #$7; both CPUs spin waiting for these in order to */
-			/* coordinate communications. Some spins have timeouts that reset the machine */
-			/* if they fail, so we must make sure they are released in time */
-			if ((opcode & 0xffc0) == 0x4ac0 ||
-				((opcode & 0xffc0) == 0x0080 && rom_base[cpunum][ppc / 2 + 1] == 7))
-			{
-				timer_call_after_resynch(NULL, 4, shared_sync_callback);
-			}
-		}
-	}
-
-	return result;
-}
-
-
-
 /*************************************
  *
  *  Video Controller Hack
  *
  *************************************/
 
-static READ16_HANDLER( thunderj_video_control_r )
+static READ16_HANDLER( thunderj_atarivc_r )
 {
 	/* Sigh. CPU #1 reads the video controller register twice per frame, once at
        the beginning of interrupt and once near the end. It stores these values in a
        table starting at $163484. CPU #2 periodically looks at this table to make
        sure that it is getting interrupts at the appropriate times, and that the
-       VBLANK bit is set appropriately. Unfortunately, due to all the cpu_yield()
+       VBLANK bit is set appropriately. Unfortunately, due to all the cpu_yield(space->cpu)
        calls we make to synchronize the two CPUs, we occasionally get out of time
        and generate the interrupt outside of the tight tolerances CPU #2 expects.
 
@@ -175,12 +111,20 @@ static READ16_HANDLER( thunderj_video_control_r )
        memory (which is what it does if this interrupt test fails -- see the code
        at $1E56 to see!) */
 
-	/* Use these lines to detect when things go south:
+	/* Use these lines to detect when things go south: */
 
-    if (cpu_readmem24bew_word(0x163482) > 0xfff)
-        mame_printf_debug("You're screwed!");*/
+#if 0
+	if (memory_read_word(space, 0x163482) > 0xfff)
+		mame_printf_debug("You're screwed!");
+#endif
 
-	return atarivc_r(offset,0);
+	return atarivc_r(space->machine->primary_screen, offset);
+}
+
+
+static WRITE16_HANDLER( thunderj_atarivc_w )
+{
+	atarivc_w(space->machine->primary_screen, offset, data, mem_mask);
 }
 
 
@@ -194,25 +138,25 @@ static READ16_HANDLER( thunderj_video_control_r )
 static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x09ffff) AM_ROM
 	AM_RANGE(0x0e0000, 0x0e0fff) AM_READWRITE(atarigen_eeprom_r, atarigen_eeprom_w) AM_BASE(&atarigen_eeprom) AM_SIZE(&atarigen_eeprom_size)
-	AM_RANGE(0x160000, 0x16ffff) AM_READWRITE(shared_ram_r, MWA16_BANK1) AM_BASE(&shared_ram)
+	AM_RANGE(0x160000, 0x16ffff) AM_RAM AM_SHARE(1)
 	AM_RANGE(0x1f0000, 0x1fffff) AM_WRITE(atarigen_eeprom_enable_w)
-	AM_RANGE(0x260000, 0x26000f) AM_READ(input_port_0_word_r)
-	AM_RANGE(0x260010, 0x260011) AM_READ(input_port_1_word_r)
+	AM_RANGE(0x260000, 0x26000f) AM_READ_PORT("260000")
+	AM_RANGE(0x260010, 0x260011) AM_READ_PORT("260010")
 	AM_RANGE(0x260012, 0x260013) AM_READ(special_port2_r)
 	AM_RANGE(0x260030, 0x260031) AM_READ(atarigen_sound_r)
 	AM_RANGE(0x2e0000, 0x2e0001) AM_WRITE(watchdog_reset16_w)
 	AM_RANGE(0x360010, 0x360011) AM_WRITE(latch_w)
 	AM_RANGE(0x360020, 0x360021) AM_WRITE(atarigen_sound_reset_w)
 	AM_RANGE(0x360030, 0x360031) AM_WRITE(atarigen_sound_w)
-	AM_RANGE(0x3e0000, 0x3e0fff) AM_READWRITE(MRA16_RAM, atarigen_666_paletteram_w) AM_BASE(&paletteram16)
-	AM_RANGE(0x3effc0, 0x3effff) AM_READWRITE(thunderj_video_control_r, atarivc_w) AM_BASE(&atarivc_data)
-	AM_RANGE(0x3f0000, 0x3f1fff) AM_READWRITE(MRA16_RAM, atarigen_playfield2_latched_msb_w) AM_BASE(&atarigen_playfield2)
-	AM_RANGE(0x3f2000, 0x3f3fff) AM_READWRITE(MRA16_RAM, atarigen_playfield_latched_lsb_w) AM_BASE(&atarigen_playfield)
-	AM_RANGE(0x3f4000, 0x3f5fff) AM_READWRITE(MRA16_RAM, atarigen_playfield_dual_upper_w) AM_BASE(&atarigen_playfield_upper)
-	AM_RANGE(0x3f6000, 0x3f7fff) AM_READWRITE(MRA16_RAM, atarimo_0_spriteram_w) AM_BASE(&atarimo_0_spriteram)
-	AM_RANGE(0x3f8000, 0x3f8eff) AM_READWRITE(MRA16_RAM, atarigen_alpha_w) AM_BASE(&atarigen_alpha)
+	AM_RANGE(0x3e0000, 0x3e0fff) AM_RAM_WRITE(atarigen_666_paletteram_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x3effc0, 0x3effff) AM_READWRITE(thunderj_atarivc_r, thunderj_atarivc_w) AM_BASE(&atarivc_data)
+	AM_RANGE(0x3f0000, 0x3f1fff) AM_RAM_WRITE(atarigen_playfield2_latched_msb_w) AM_BASE(&atarigen_playfield2)
+	AM_RANGE(0x3f2000, 0x3f3fff) AM_RAM_WRITE(atarigen_playfield_latched_lsb_w) AM_BASE(&atarigen_playfield)
+	AM_RANGE(0x3f4000, 0x3f5fff) AM_RAM_WRITE(atarigen_playfield_dual_upper_w) AM_BASE(&atarigen_playfield_upper)
+	AM_RANGE(0x3f6000, 0x3f7fff) AM_RAM_WRITE(atarimo_0_spriteram_w) AM_BASE(&atarimo_0_spriteram)
+	AM_RANGE(0x3f8000, 0x3f8eff) AM_RAM_WRITE(atarigen_alpha_w) AM_BASE(&atarigen_alpha)
 	AM_RANGE(0x3f8f00, 0x3f8f7f) AM_RAM AM_BASE(&atarivc_eof_data)
-	AM_RANGE(0x3f8f80, 0x3f8fff) AM_READWRITE(MRA16_RAM, atarimo_0_slipram_w) AM_BASE(&atarimo_0_slipram)
+	AM_RANGE(0x3f8f80, 0x3f8fff) AM_RAM_WRITE(atarimo_0_slipram_w) AM_BASE(&atarimo_0_slipram)
 	AM_RANGE(0x3f9000, 0x3fffff) AM_RAM
 ADDRESS_MAP_END
 
@@ -227,9 +171,9 @@ ADDRESS_MAP_END
 static ADDRESS_MAP_START( extra_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
 	AM_RANGE(0x060000, 0x07ffff) AM_ROM
-	AM_RANGE(0x160000, 0x16ffff) AM_READWRITE(shared_ram_r, MWA16_BANK1)
-	AM_RANGE(0x260000, 0x26000f) AM_READ(input_port_0_word_r)
-	AM_RANGE(0x260010, 0x260011) AM_READ(input_port_1_word_r)
+	AM_RANGE(0x160000, 0x16ffff) AM_RAM AM_SHARE(1)
+	AM_RANGE(0x260000, 0x26000f) AM_READ_PORT("260000")
+	AM_RANGE(0x260010, 0x260011) AM_READ_PORT("260010")
 	AM_RANGE(0x260012, 0x260013) AM_READ(special_port2_r)
 	AM_RANGE(0x260030, 0x260031) AM_READ(atarigen_sound_r)
 	AM_RANGE(0x360000, 0x360001) AM_WRITE(atarigen_video_int_ack_w)
@@ -247,12 +191,11 @@ ADDRESS_MAP_END
  *************************************/
 
 static INPUT_PORTS_START( thunderj )
-	PORT_START		/* 260000 */
+	PORT_START("260000")
 	PORT_BIT( 0xffff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START		/* 260010 */
+	PORT_START("260010")
 	PORT_BIT( 0x00ff, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
 	PORT_BIT( 0x0c00, IP_ACTIVE_LOW, IPT_UNUSED )
@@ -261,14 +204,13 @@ static INPUT_PORTS_START( thunderj )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(1)
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(1)
 
-	PORT_START		/* 260012 */
+	PORT_START("260012")
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_VBLANK )
 	PORT_SERVICE( 0x0002, IP_ACTIVE_LOW )
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_UNUSED )	/* Input buffer full (@260030) */
 	PORT_BIT( 0x0008, IP_ACTIVE_LOW, IPT_UNUSED )	/* Output buffer full (@360030) */
 	PORT_BIT( 0x0010, IP_ACTIVE_HIGH, IPT_UNUSED )
 	PORT_BIT( 0x00e0, IP_ACTIVE_LOW, IPT_UNUSED )
-	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x0100, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x0200, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
 	PORT_BIT( 0x0c00, IP_ACTIVE_LOW, IPT_UNUSED )
@@ -277,7 +219,7 @@ static INPUT_PORTS_START( thunderj )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_PLAYER(2)
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_PLAYER(2)
 
-	JSA_II_PORT		/* audio board port */
+	PORT_INCLUDE( atarijsa_ii )		/* audio board port */
 INPUT_PORTS_END
 
 
@@ -313,9 +255,9 @@ static const gfx_layout pfmolayout =
 
 
 static GFXDECODE_START( thunderj )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, pfmolayout,  512,  96 )	/* sprites & playfield */
-	GFXDECODE_ENTRY( REGION_GFX2, 0, pfmolayout,  256, 112 )	/* sprites & playfield */
-	GFXDECODE_ENTRY( REGION_GFX3, 0, anlayout,      0, 512 )	/* characters 8x8 */
+	GFXDECODE_ENTRY( "gfx1", 0, pfmolayout,  512,  96 )	/* sprites & playfield */
+	GFXDECODE_ENTRY( "gfx2", 0, pfmolayout,  256, 112 )	/* sprites & playfield */
+	GFXDECODE_ENTRY( "gfx3", 0, anlayout,      0, 512 )	/* characters 8x8 */
 GFXDECODE_END
 
 
@@ -329,22 +271,24 @@ GFXDECODE_END
 static MACHINE_DRIVER_START( thunderj )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000, ATARI_CLOCK_14MHz/2)
+	MDRV_CPU_ADD("main", M68000, ATARI_CLOCK_14MHz/2)
 	MDRV_CPU_PROGRAM_MAP(main_map,0)
 
-	MDRV_CPU_ADD(M68000, ATARI_CLOCK_14MHz/2)
+	MDRV_CPU_ADD("extra", M68000, ATARI_CLOCK_14MHz/2)
 	MDRV_CPU_PROGRAM_MAP(extra_map,0)
 
 	MDRV_MACHINE_RESET(thunderj)
 	MDRV_NVRAM_HANDLER(atarigen)
-	MDRV_INTERLEAVE(100)
+
+	/* perfect synchronization due to shared RAM */
+	MDRV_QUANTUM_PERFECT_CPU("main")
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER | VIDEO_UPDATE_BEFORE_VBLANK)
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_UPDATE_BEFORE_VBLANK)
 	MDRV_GFXDECODE(thunderj)
 	MDRV_PALETTE_LENGTH(2048)
 
-	MDRV_SCREEN_ADD("main", 0)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	/* note: these parameters are from published specs, not derived */
 	/* the board uses a VAD chip to generate video signals */
@@ -366,7 +310,7 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( thunderj )
-	ROM_REGION( 0xa0000, REGION_CPU1, 0 )	/* 10*64k for 68000 code */
+	ROM_REGION( 0xa0000, "main", 0 )	/* 10*64k for 68000 code */
 	ROM_LOAD16_BYTE( "136076-2001.14e",   0x00000, 0x10000, CRC(f6a71532) SHA1(b1c55968d7da9b64bde737d66aa8f0ddcdcfee27) )
 	ROM_LOAD16_BYTE( "136076-2002.14c",   0x00001, 0x10000, CRC(173ec10d) SHA1(e32eca9194336f3d7e289b2a187ed125ed03688c) )
 	ROM_LOAD16_BYTE( "136076-2003.15e",   0x20000, 0x10000, CRC(6e155469) SHA1(ba87d0a510304fd8a0f91c81580c4f09fc4d1886) )
@@ -378,16 +322,16 @@ ROM_START( thunderj )
 	ROM_LOAD16_BYTE( "136076-1007.17e",   0x80000, 0x10000, CRC(9c2a8aba) SHA1(10e4fc04e64bb6a5083a56f630224b5d1af241b2) )
 	ROM_LOAD16_BYTE( "136076-1008.17c",   0x80001, 0x10000, CRC(22109d16) SHA1(8725696271c4a617f9f050d9d483fe4141bf1e00) )
 
-	ROM_REGION( 0x80000, REGION_CPU2, 0 )	/* 8*64k for 68000 code */
+	ROM_REGION( 0x80000, "extra", 0 )	/* 8*64k for 68000 code */
 	ROM_LOAD16_BYTE( "136076-1011.17l",    0x00000, 0x10000, CRC(bbbbca45) SHA1(977e785e0272a84c8d7e28e25f45064d1b37aad1) )
 	ROM_LOAD16_BYTE( "136076-1012.17n",    0x00001, 0x10000, CRC(53e5e638) SHA1(75593e5d328ede105b8db64005dd5d1c5cae11ed) )
-	ROM_COPY( REGION_CPU1, 0x60000, 0x60000, 0x20000 )
+	ROM_COPY( "main", 0x60000, 0x60000, 0x20000 )
 
-	ROM_REGION( 0x14000, REGION_CPU3, 0 )	/* 64k + 16k for 6502 code */
+	ROM_REGION( 0x14000, "jsa", 0 )	/* 64k + 16k for 6502 code */
 	ROM_LOAD( "136076-2015.1b", 0x10000, 0x4000, CRC(d8feb7fb) SHA1(684ebf2f0c0df742c98e7f45f74de86a11c8d6e8) )
 	ROM_CONTINUE(               0x04000, 0xc000 )
 
-	ROM_REGION( 0x100000, REGION_GFX1, ROMREGION_DISPOSE | ROMREGION_INVERT )
+	ROM_REGION( 0x100000, "gfx1", ROMREGION_DISPOSE | ROMREGION_INVERT )
 	ROM_LOAD( "136076-1021.5s",   0x000000, 0x10000, CRC(d8432766) SHA1(04e7d820974c0890fde1257b4710cf7b520d7d48) )	/* graphics, plane 0 */
 	ROM_LOAD( "136076-1025.5r",   0x010000, 0x10000, CRC(839feed5) SHA1(c683ef5b78f8fd63dd557a630544f1e21aebe665) )
 	ROM_LOAD( "136076-1029.3p",   0x020000, 0x10000, CRC(fa887662) SHA1(5d19022e8d40be86b85d0bcc28c97207ab9ec403) )
@@ -405,7 +349,7 @@ ROM_START( thunderj )
 	ROM_LOAD( "136076-1032.14p",  0x0e0000, 0x10000, CRC(f639161a) SHA1(cc2549f7fdd251fa44735a6cd5fdb8ffb97948be) )
 	ROM_LOAD( "136076-1036.16p",  0x0f0000, 0x10000, CRC(b342443d) SHA1(fa7865f8a90c0e761e1cc5e155931d0574f2d81c) )
 
-	ROM_REGION( 0x100000, REGION_GFX2, ROMREGION_DISPOSE | ROMREGION_INVERT )
+	ROM_REGION( 0x100000, "gfx2", ROMREGION_DISPOSE | ROMREGION_INVERT )
 	ROM_LOAD( "136076-1037.2s",   0x000000, 0x10000, CRC(07addba6) SHA1(4a3286ee570bf4263944854bf959c8ef114cc123) )
 	ROM_LOAD( "136076-1041.2r",   0x010000, 0x10000, CRC(1e9c29e4) SHA1(e4afa2c469bfa22504cba5dfd23704c5c2bb33c4) )
 	ROM_LOAD( "136076-1045.34s",  0x020000, 0x10000, CRC(e7235876) SHA1(0bb03baec1de3e520dc270a3ed44bec953e08c00) )
@@ -423,16 +367,16 @@ ROM_START( thunderj )
 	ROM_LOAD( "136076-1048.16s",  0x0e0000, 0x10000, CRC(200d45b3) SHA1(72f1b3deaebc6266140fb79a97154f80f2cadf33) )
 	ROM_LOAD( "136076-1052.16r",  0x0f0000, 0x10000, CRC(74711ef1) SHA1(c1429d6b54dc4352defdd6cf83f1a5734784e703) )
 
-	ROM_REGION( 0x010000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x010000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "136076-1020.4m",   0x000000, 0x10000, CRC(65470354) SHA1(9895d26fa9e01c254a3d15e657152cac717c68a3) )	/* alphanumerics */
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )	/* 256k for ADPCM */
+	ROM_REGION( 0x40000, "adpcm", 0 )	/* 256k for ADPCM */
 	ROM_LOAD( "136076-1016.7k",  0x00000, 0x10000, CRC(c10bdf73) SHA1(a0371c6ddef2a95193c68879044b3338d481fc96) )
 	ROM_LOAD( "136076-1017.7j",  0x10000, 0x10000, CRC(4e5e25e8) SHA1(373c946abd24ce8dd5221f1a0409af4537610d3d) )
 	ROM_LOAD( "136076-1018.7e",  0x20000, 0x10000, CRC(ec81895d) SHA1(56acffb0700d3b70ca705fba9d240a82950fd320) )
 	ROM_LOAD( "136076-1019.7d",  0x30000, 0x10000, CRC(a4009037) SHA1(01cd3f4cf510f4956258f39f3ddbb42628bc2b9a) )
 
-	ROM_REGION( 0x0e00, REGION_PLDS, ROMREGION_DISPOSE )
+	ROM_REGION( 0x0e00, "plds", ROMREGION_DISPOSE )
 	ROM_LOAD( "gal16v8a-136076-1070.12e", 0x0000, 0x0117, CRC(0e96e51e) SHA1(bf23d0089e5e34ad579cb56ff869353545c29792) )
 	ROM_LOAD( "gal16v8a-136076-1071.13j", 0x0200, 0x0117, CRC(ad7beb34) SHA1(d50fa0526fd83b6a9a79adcacef56a64ebafa448) )
 	ROM_LOAD( "gal16v8a-136076-1072.5n",  0x0400, 0x0117, CRC(2827620a) SHA1(25c5dfae3d8f4b73936833031b95fafd2ba0ae5d) )
@@ -453,7 +397,7 @@ ROM_END
 static DRIVER_INIT( thunderj )
 {
 	atarigen_eeprom_default = NULL;
-	atarijsa_init(machine, 2, 0x0002);
+	atarijsa_init(machine, "260012", 0x0002);
 }
 
 
