@@ -30,7 +30,8 @@ TODO:
 ****************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/m6809/m6809.h"
+#include "cpu/m68000/m68000.h"
 #include "machine/namcoio.h"
 #include "sound/namco.h"
 
@@ -56,17 +57,17 @@ PALETTE_INIT( toypop );
 
 ***************************************************************************/
 
-static READ8_HANDLER( in0_l )	{ return readinputport(0); }		// P1 joystick
-static READ8_HANDLER( in0_h )	{ return readinputport(0) >> 4; }	// P2 joystick
-static READ8_HANDLER( in1_l )	{ return readinputport(1); }		// fire and start buttons
-static READ8_HANDLER( in1_h )	{ return readinputport(1) >> 4; }	// coins
-static READ8_HANDLER( dipA_l )	{ return readinputport(2); }		// dips A
-static READ8_HANDLER( dipA_h )	{ return readinputport(2) >> 4; }	// dips A
-static READ8_HANDLER( dipB_l )	{ return readinputport(3); }		// dips B
-static READ8_HANDLER( dipB_h )	{ return readinputport(3) >> 4; }	// dips B
-static READ8_HANDLER( in2_l )	{ return readinputport(4); }		// P1 joystick left in liblrabl
-static READ8_HANDLER( in2_h )	{ return readinputport(4) >> 4; }	// P2 joystick left in liblrabl
-static READ8_HANDLER( in3 )		{ return readinputport(5); }		// test, cocktail, optional buttons
+static READ8_HANDLER( in0_l )	{ return input_port_read(space->machine, "INPUT_RIGHT"); }			// P1 joystick
+static READ8_HANDLER( in0_h )	{ return input_port_read(space->machine, "INPUT_RIGHT") >> 4; }	// P2 joystick
+static READ8_HANDLER( in1_l )	{ return input_port_read(space->machine, "SYSTEM"); }				// fire and start buttons
+static READ8_HANDLER( in1_h )	{ return input_port_read(space->machine, "SYSTEM") >> 4; }			// coins
+static READ8_HANDLER( dipA_l )	{ return input_port_read(space->machine, "DSW1"); }				// dips A
+static READ8_HANDLER( dipA_h )	{ return input_port_read(space->machine, "DSW1") >> 4; }			// dips A
+static READ8_HANDLER( dipB_l )	{ return input_port_read(space->machine, "DSW2"); }				// dips B
+static READ8_HANDLER( dipB_h )	{ return input_port_read(space->machine, "DSW2") >> 4; }			// dips B
+static READ8_HANDLER( in2_l )	{ return input_port_read(space->machine, "INPUT_LEFT"); }			// P1 joystick left in liblrabl
+static READ8_HANDLER( in2_h )	{ return input_port_read(space->machine, "INPUT_LEFT") >> 4; }		// P2 joystick left in liblrabl
+static READ8_HANDLER( in3 )		{ return input_port_read(space->machine, "SERVICE"); }				// test, cocktail, optional buttons
 static WRITE8_HANDLER( out_coin0 )
 {
 	coin_lockout_global_w(data & 4);
@@ -78,7 +79,7 @@ static WRITE8_HANDLER( out_coin1 )
 }
 static WRITE8_HANDLER( flip )
 {
-	flip_screen_set(data & 1);
+	flip_screen_set(space->machine, data & 1);
 }
 
 /* chip #0: player inputs, buttons, coins */
@@ -109,16 +110,16 @@ static const struct namcoio_interface intf2 =
 
 static DRIVER_INIT( 58c_56_56 )
 {
-	namcoio_init(0, NAMCOIO_58XX, &intf0_coin);
-	namcoio_init(1, NAMCOIO_56XX, &intf1);
-	namcoio_init(2, NAMCOIO_56XX, &intf2);
+	namcoio_init(machine, 0, NAMCOIO_58XX, &intf0_coin);
+	namcoio_init(machine, 1, NAMCOIO_56XX, &intf1);
+	namcoio_init(machine, 2, NAMCOIO_56XX, &intf2);
 }
 
 static DRIVER_INIT( 58_56_56 )
 {
-	namcoio_init(0, NAMCOIO_58XX, &intf0);
-	namcoio_init(1, NAMCOIO_56XX, &intf1);
-	namcoio_init(2, NAMCOIO_56XX, &intf2);
+	namcoio_init(machine, 0, NAMCOIO_58XX, &intf0);
+	namcoio_init(machine, 1, NAMCOIO_56XX, &intf1);
+	namcoio_init(machine, 2, NAMCOIO_56XX, &intf2);
 }
 
 
@@ -137,7 +138,7 @@ static READ8_HANDLER( toypop_sound_sharedram_r )
 static WRITE8_HANDLER( toypop_sound_sharedram_w )
 {
 	if (offset < 0x40)
-		namco_15xx_w(offset,data);
+		namco_15xx_w(space,offset,data);
 	else
 		namco_soundregs[offset] = data;
 }
@@ -149,74 +150,74 @@ static READ16_HANDLER( toypop_m68000_sharedram_r )
 
 static WRITE16_HANDLER( toypop_m68000_sharedram_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 		toypop_m68000_sharedram[offset] = data & 0xff;
 }
 
 static READ8_HANDLER( toypop_main_interrupt_enable_r )
 {
-	cpu_interrupt_enable(0,1);
+	cpu_interrupt_enable(space->machine->cpu[0],1);
 	return 0;
 }
 
 static WRITE8_HANDLER( toypop_main_interrupt_enable_w )
 {
-	cpu_interrupt_enable(0,1);
-	cpunum_set_input_line(Machine, 0, 0, CLEAR_LINE);
+	cpu_interrupt_enable(space->machine->cpu[0],1);
+	cpu_set_input_line(space->machine->cpu[0], 0, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( toypop_main_interrupt_disable_w )
 {
-	cpu_interrupt_enable(0,0);
+	cpu_interrupt_enable(space->machine->cpu[0],0);
 }
 
 static WRITE8_HANDLER( toypop_sound_interrupt_enable_acknowledge_w )
 {
-	cpu_interrupt_enable(1,1);
-	cpunum_set_input_line(Machine, 1, 0, CLEAR_LINE);
+	cpu_interrupt_enable(space->machine->cpu[1],1);
+	cpu_set_input_line(space->machine->cpu[1], 0, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( toypop_sound_interrupt_disable_w )
 {
-	cpu_interrupt_enable(1,0);
+	cpu_interrupt_enable(space->machine->cpu[1],0);
 }
 
 static INTERRUPT_GEN( toypop_main_interrupt )
 {
-	irq0_line_assert(machine, cpunum);	// this also checks if irq is enabled - IMPORTANT!
-						// so don't replace with cpunum_set_input_line(machine, 0, 0, ASSERT_LINE);
+	irq0_line_assert(device);	// this also checks if irq is enabled - IMPORTANT!
+						// so don't replace with cpu_set_input_line(machine->cpu[0], 0, ASSERT_LINE);
 
-	namcoio_set_irq_line(0,PULSE_LINE);
-	namcoio_set_irq_line(1,PULSE_LINE);
-	namcoio_set_irq_line(2,PULSE_LINE);
+	namcoio_set_irq_line(device->machine,0,PULSE_LINE);
+	namcoio_set_irq_line(device->machine,1,PULSE_LINE);
+	namcoio_set_irq_line(device->machine,2,PULSE_LINE);
 }
 
 static WRITE8_HANDLER( toypop_sound_clear_w )
 {
-	cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( toypop_sound_assert_w )
 {
-	cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, ASSERT_LINE);
+	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, ASSERT_LINE);
 }
 
 static WRITE8_HANDLER( toypop_m68000_clear_w )
 {
-	cpunum_set_input_line(Machine, 2, INPUT_LINE_RESET, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_RESET, CLEAR_LINE);
 }
 
 static WRITE8_HANDLER( toypop_m68000_assert_w )
 {
-	cpunum_set_input_line(Machine, 2, INPUT_LINE_RESET, ASSERT_LINE);
+	cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_RESET, ASSERT_LINE);
 }
 
 static TIMER_CALLBACK( disable_interrupts )
 {
-	cpu_interrupt_enable(0,0);
-	cpunum_set_input_line(machine, 0, 0, CLEAR_LINE);
-	cpu_interrupt_enable(1,0);
-	cpunum_set_input_line(machine, 1, 0, CLEAR_LINE);
+	cpu_interrupt_enable(machine->cpu[0],0);
+	cpu_set_input_line(machine->cpu[0], 0, CLEAR_LINE);
+	cpu_interrupt_enable(machine->cpu[1],0);
+	cpu_set_input_line(machine->cpu[1], 0, CLEAR_LINE);
 	interrupt_enable_68k = 0;
 }
 
@@ -224,13 +225,13 @@ static MACHINE_RESET( toypop )
 {
 	/* we must do this on a timer in order to have it take effect */
 	/* otherwise, the reset process will override our changes */
-	timer_call_after_resynch(NULL, 0, disable_interrupts);
+	timer_call_after_resynch(machine, NULL, 0, disable_interrupts);
 }
 
 static INTERRUPT_GEN( toypop_m68000_interrupt )
 {
 	if (interrupt_enable_68k)
-		cpunum_set_input_line(machine, 2, 6, HOLD_LINE);
+		cpu_set_input_line(device, 6, HOLD_LINE);
 }
 
 static WRITE16_HANDLER( toypop_m68000_interrupt_enable_w )
@@ -252,30 +253,30 @@ static WRITE16_HANDLER( toypop_m68000_interrupt_disable_w )
  *************************************/
 
 static ADDRESS_MAP_START( readmem_mainCPU_liblrabl, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x2fff) AM_READ(MRA8_RAM)								/* RAM everywhere else */
+	AM_RANGE(0x0000, 0x2fff) AM_READ(SMH_RAM)								/* RAM everywhere else */
 	AM_RANGE(0x6000, 0x63ff) AM_READ(toypop_sound_sharedram_r)				/* shared RAM with sound CPU */
 	AM_RANGE(0x6800, 0x683f) AM_READ(namcoio_r)								/* custom I/O */
 	AM_RANGE(0x7800, 0x7800) AM_READ(watchdog_reset_r)						/* not sure; this is NOT irq enable (game crashes otherwise) */
-	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_ROM)								/* ROM code */
+	AM_RANGE(0x8000, 0xffff) AM_READ(SMH_ROM)								/* ROM code */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readmem_mainCPU_toypop, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x2fff) AM_READ(MRA8_RAM)								/* RAM everywhere else */
+	AM_RANGE(0x0000, 0x2fff) AM_READ(SMH_RAM)								/* RAM everywhere else */
 	AM_RANGE(0x6000, 0x603f) AM_READ(namcoio_r)								/* custom I/O */
 	AM_RANGE(0x6800, 0x6bff) AM_READ(toypop_sound_sharedram_r)				/* shared RAM with sound CPU */
 	AM_RANGE(0x7000, 0x7000) AM_READ(toypop_main_interrupt_enable_r)			/* enable interrupt?? */
-	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_ROM)								/* ROM code */
+	AM_RANGE(0x8000, 0xffff) AM_READ(SMH_ROM)								/* ROM code */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem_mainCPU_liblrabl, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_WRITE(toypop_videoram_w) AM_BASE(&toypop_videoram)	/* video RAM */
-	AM_RANGE(0x0800, 0x0f7f) AM_WRITE(MWA8_RAM)								/* general RAM, area 1 */
-	AM_RANGE(0x0f80, 0x0fff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram)					/* sprite RAM, area 1 */
-	AM_RANGE(0x1000, 0x177f) AM_WRITE(MWA8_RAM)								/* general RAM, area 2 */
-	AM_RANGE(0x1780, 0x17ff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram_2)					/* sprite RAM, area 2 */
-	AM_RANGE(0x1800, 0x1f7f) AM_WRITE(MWA8_RAM)								/* general RAM, area 3 */
-	AM_RANGE(0x1f80, 0x1fff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram_3)					/* sprite RAM, area 3 */
-	AM_RANGE(0x2800, 0x2fff) AM_WRITE(MWA8_RAM) AM_BASE(&toypop_m68000_sharedram)		/* shared RAM with the 68000 CPU */
+	AM_RANGE(0x0800, 0x0f7f) AM_WRITE(SMH_RAM)								/* general RAM, area 1 */
+	AM_RANGE(0x0f80, 0x0fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram)					/* sprite RAM, area 1 */
+	AM_RANGE(0x1000, 0x177f) AM_WRITE(SMH_RAM)								/* general RAM, area 2 */
+	AM_RANGE(0x1780, 0x17ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram_2)					/* sprite RAM, area 2 */
+	AM_RANGE(0x1800, 0x1f7f) AM_WRITE(SMH_RAM)								/* general RAM, area 3 */
+	AM_RANGE(0x1f80, 0x1fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram_3)					/* sprite RAM, area 3 */
+	AM_RANGE(0x2800, 0x2fff) AM_WRITE(SMH_RAM) AM_BASE(&toypop_m68000_sharedram)		/* shared RAM with the 68000 CPU */
 	AM_RANGE(0x6000, 0x63ff) AM_WRITE(toypop_sound_sharedram_w)				/* shared RAM with sound CPU */
 	AM_RANGE(0x6800, 0x683f) AM_WRITE(namcoio_w)								/* custom I/O */
 	AM_RANGE(0x7000, 0x7000) AM_WRITE(toypop_main_interrupt_enable_w)			/* enable interrupt */
@@ -285,18 +286,18 @@ static ADDRESS_MAP_START( writemem_mainCPU_liblrabl, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x9000, 0x9000) AM_WRITE(toypop_sound_clear_w)					/* sound CPU reset */
 	AM_RANGE(0x9800, 0x9800) AM_WRITE(toypop_sound_assert_w)					/* sound CPU reset */
 	AM_RANGE(0xa000, 0xa001) AM_WRITE(toypop_palettebank_w)					/* background image palette */
-	AM_RANGE(0x8000, 0xffff) AM_WRITE(MWA8_ROM)								/* ROM code */
+	AM_RANGE(0x8000, 0xffff) AM_WRITE(SMH_ROM)								/* ROM code */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem_mainCPU_toypop, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x07ff) AM_WRITE(toypop_videoram_w) AM_BASE(&toypop_videoram)	/* video RAM */
-	AM_RANGE(0x0800, 0x0f7f) AM_WRITE(MWA8_RAM)								/* general RAM, area 1 */
-	AM_RANGE(0x0f80, 0x0fff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram)					/* sprite RAM, area 1 */
-	AM_RANGE(0x1000, 0x177f) AM_WRITE(MWA8_RAM)								/* general RAM, area 2 */
-	AM_RANGE(0x1780, 0x17ff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram_2)					/* sprite RAM, area 2 */
-	AM_RANGE(0x1800, 0x1f7f) AM_WRITE(MWA8_RAM)								/* general RAM, area 3 */
-	AM_RANGE(0x1f80, 0x1fff) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram_3)					/* sprite RAM, area 3 */
-	AM_RANGE(0x2800, 0x2fff) AM_WRITE(MWA8_RAM) AM_BASE(&toypop_m68000_sharedram)		/* shared RAM with the 68000 CPU */
+	AM_RANGE(0x0800, 0x0f7f) AM_WRITE(SMH_RAM)								/* general RAM, area 1 */
+	AM_RANGE(0x0f80, 0x0fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram)					/* sprite RAM, area 1 */
+	AM_RANGE(0x1000, 0x177f) AM_WRITE(SMH_RAM)								/* general RAM, area 2 */
+	AM_RANGE(0x1780, 0x17ff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram_2)					/* sprite RAM, area 2 */
+	AM_RANGE(0x1800, 0x1f7f) AM_WRITE(SMH_RAM)								/* general RAM, area 3 */
+	AM_RANGE(0x1f80, 0x1fff) AM_WRITE(SMH_RAM) AM_BASE(&spriteram_3)					/* sprite RAM, area 3 */
+	AM_RANGE(0x2800, 0x2fff) AM_WRITE(SMH_RAM) AM_BASE(&toypop_m68000_sharedram)		/* shared RAM with the 68000 CPU */
 	AM_RANGE(0x6000, 0x603f) AM_WRITE(namcoio_w)								/* custom I/O */
 	AM_RANGE(0x6800, 0x6bff) AM_WRITE(toypop_sound_sharedram_w)				/* shared RAM with sound CPU */
 	AM_RANGE(0x7000, 0x7000) AM_WRITE(toypop_main_interrupt_disable_w)		/* disable interrupt */
@@ -305,7 +306,7 @@ static ADDRESS_MAP_START( writemem_mainCPU_toypop, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x9000, 0x9000) AM_WRITE(toypop_sound_clear_w)					/* sound CPU reset */
 	AM_RANGE(0x9800, 0x9800) AM_WRITE(toypop_sound_assert_w)					/* sound CPU reset */
 	AM_RANGE(0xa000, 0xa001) AM_WRITE(toypop_palettebank_w)					/* background image palette */
-	AM_RANGE(0x8000, 0xffff) AM_WRITE(MWA8_ROM)								/* ROM code */
+	AM_RANGE(0x8000, 0xffff) AM_WRITE(SMH_ROM)								/* ROM code */
 ADDRESS_MAP_END
 
 
@@ -317,7 +318,7 @@ ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( readmem_soundCPU, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x03ff) AM_READ(toypop_sound_sharedram_r)
-	AM_RANGE(0xe000, 0xffff) AM_READ(MRA8_ROM)
+	AM_RANGE(0xe000, 0xffff) AM_READ(SMH_ROM)
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem_soundCPU, ADDRESS_SPACE_PROGRAM, 8 )
@@ -325,7 +326,7 @@ static ADDRESS_MAP_START( writemem_soundCPU, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x2000, 0x2000) AM_WRITE(toypop_sound_interrupt_disable_w)	/* ??? toypop doesn't write here */
 	AM_RANGE(0x4000, 0x4000) AM_WRITE(toypop_sound_interrupt_enable_acknowledge_w)
 	AM_RANGE(0x6000, 0x6000) AM_WRITE(watchdog_reset_w)
-	AM_RANGE(0xe000, 0xffff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0xe000, 0xffff) AM_WRITE(SMH_ROM)
 ADDRESS_MAP_END
 
 
@@ -337,20 +338,20 @@ ADDRESS_MAP_END
  *************************************/
 
 static ADDRESS_MAP_START( readmem_68k, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x007fff) AM_READ(MRA16_ROM)				// ROM code
-	AM_RANGE(0x080000, 0x0bffff) AM_READ(MRA16_RAM)				// RAM
+	AM_RANGE(0x000000, 0x007fff) AM_READ(SMH_ROM)				// ROM code
+	AM_RANGE(0x080000, 0x0bffff) AM_READ(SMH_RAM)				// RAM
 	AM_RANGE(0x100000, 0x100fff) AM_READ(toypop_m68000_sharedram_r)	// shared RAM with the main CPU
 	AM_RANGE(0x180000, 0x187fff) AM_READ(toypop_merged_background_r)	// RAM merged with the background image
-	AM_RANGE(0x190000, 0x1dffff) AM_READ(MRA16_RAM)				// RAM containing the background image
+	AM_RANGE(0x190000, 0x1dffff) AM_READ(SMH_RAM)				// RAM containing the background image
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( writemem_68k, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x007fff) AM_WRITE(MWA16_ROM)						/* ROM code */
-	AM_RANGE(0x080000, 0x0bffff) AM_WRITE(MWA16_RAM)						/* RAM */
+	AM_RANGE(0x000000, 0x007fff) AM_WRITE(SMH_ROM)						/* ROM code */
+	AM_RANGE(0x080000, 0x0bffff) AM_WRITE(SMH_RAM)						/* RAM */
 	AM_RANGE(0x100000, 0x100fff) AM_WRITE(toypop_m68000_sharedram_w)		/* shared RAM with the main CPU */
 	AM_RANGE(0x180000, 0x187fff) AM_WRITE(toypop_merged_background_w)		/* RAM that has to be merged with the background image */
 	AM_RANGE(0x18fffc, 0x18ffff) AM_WRITE(toypop_flipscreen_w)			/* flip mode */
-	AM_RANGE(0x190000, 0x1dffff) AM_WRITE(MWA16_RAM) AM_BASE(&toypop_bg_image)			/* RAM containing the background image */
+	AM_RANGE(0x190000, 0x1dffff) AM_WRITE(SMH_RAM) AM_BASE(&toypop_bg_image)			/* RAM containing the background image */
 	AM_RANGE(0x300000, 0x300001) AM_WRITE(toypop_m68000_interrupt_enable_w)		/* interrupt enable */
 	AM_RANGE(0x380000, 0x380001) AM_WRITE(toypop_m68000_interrupt_disable_w)		/* interrupt disable */
 ADDRESS_MAP_END
@@ -359,7 +360,7 @@ ADDRESS_MAP_END
 
 static INPUT_PORTS_START( liblrabl )
 	/* The inputs are not memory mapped, they are handled by three I/O chips. */
-	PORT_START	/* 58XX #0 pins 22-29 */
+	PORT_START("INPUT_RIGHT")	/* 58XX #0 pins 22-29 */
 	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_JOYSTICKRIGHT_UP ) PORT_8WAY
 	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_JOYSTICKRIGHT_RIGHT ) PORT_8WAY
 	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_JOYSTICKRIGHT_DOWN ) PORT_8WAY
@@ -369,7 +370,7 @@ static INPUT_PORTS_START( liblrabl )
 	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_JOYSTICKRIGHT_DOWN ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_JOYSTICKRIGHT_LEFT ) PORT_8WAY PORT_COCKTAIL
 
-	PORT_START	/* 58XX #0 pins 30-33 and 38-41 */
+	PORT_START("SYSTEM")	/* 58XX #0 pins 30-33 and 38-41 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_START1 )
@@ -379,7 +380,7 @@ static INPUT_PORTS_START( liblrabl )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE1 )
 
-	PORT_START	/* 56XX #1 pins 22-29 */
+	PORT_START("DSW1")	/* 56XX #1 pins 22-29 */
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x02, "1" )
 	PORT_DIPSETTING(    0x00, "2" )
@@ -405,7 +406,7 @@ static INPUT_PORTS_START( liblrabl )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_3C ) )
 	PORT_DIPSETTING(    0x20, DEF_STR( 1C_6C ) )
 
-	PORT_START	/* 56XX #1 pins 30-33 and 38-41 */
+	PORT_START("DSW2")	/* 56XX #1 pins 30-33 and 38-41 */
 	PORT_DIPNAME( 0x01, 0x01, "Freeze" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -429,7 +430,7 @@ static INPUT_PORTS_START( liblrabl )
 	PORT_DIPSETTING(    0x80, "C" )
 	PORT_DIPSETTING(    0x00, "D" )
 
-	PORT_START	/* 56XX #2 pins 22-29 */
+	PORT_START("INPUT_LEFT")	/* 56XX #2 pins 22-29 */
 	PORT_BIT(0x01, IP_ACTIVE_LOW, IPT_JOYSTICKLEFT_UP ) PORT_8WAY
 	PORT_BIT(0x02, IP_ACTIVE_LOW, IPT_JOYSTICKLEFT_RIGHT ) PORT_8WAY
 	PORT_BIT(0x04, IP_ACTIVE_LOW, IPT_JOYSTICKLEFT_DOWN ) PORT_8WAY
@@ -439,7 +440,7 @@ static INPUT_PORTS_START( liblrabl )
 	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_JOYSTICKLEFT_DOWN ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT(0x80, IP_ACTIVE_LOW, IPT_JOYSTICKLEFT_LEFT ) PORT_8WAY PORT_COCKTAIL
 
-	PORT_START	/* 56XX #2 pins 30-33 */
+	PORT_START("SERVICE")	/* 56XX #2 pins 30-33 */
 	PORT_BIT( 0x03, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_DIPNAME( 0x04, 0x04, DEF_STR( Cabinet ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( Upright ) )
@@ -449,7 +450,7 @@ INPUT_PORTS_END
 
 static INPUT_PORTS_START( toypop )
 	/* The inputs are not memory mapped, they are handled by three I/O chips. */
-	PORT_START	/* 58XX #0 pins 22-29 */
+	PORT_START("INPUT_RIGHT")	/* 58XX #0 pins 22-29 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_4WAY
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_4WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_4WAY
@@ -459,7 +460,7 @@ static INPUT_PORTS_START( toypop )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_4WAY PORT_PLAYER(2)
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_4WAY PORT_PLAYER(2)
 
-	PORT_START	/* 58XX #0 pins 30-33 and 38-41 */
+	PORT_START("SYSTEM")	/* 58XX #0 pins 30-33 and 38-41 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_START1 )
@@ -469,7 +470,7 @@ static INPUT_PORTS_START( toypop )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE1 )
 
-	PORT_START	/* 56XX #1 pins 22-29 */
+	PORT_START("DSW1")	/* 56XX #1 pins 22-29 */
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x02, "1" )
 	PORT_DIPSETTING(    0x01, "2" )
@@ -490,7 +491,7 @@ static INPUT_PORTS_START( toypop )
 	PORT_DIPSETTING(    0x40, DEF_STR( On ) )
 	PORT_SERVICE( 0x80, IP_ACTIVE_LOW )
 
-	PORT_START	/* 56XX #1 pins 30-33 and 38-41 */
+	PORT_START("DSW2")	/* 56XX #1 pins 30-33 and 38-41 */
 	PORT_DIPNAME( 0x01, 0x01, "Freeze" )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -515,10 +516,10 @@ static INPUT_PORTS_START( toypop )
 	PORT_DIPSETTING(    0x80, "Every 15000 points" )
 	PORT_DIPSETTING(    0x00, "Every 20000 points" )
 
-	PORT_START	/* 56XX #2 pins 22-29 */
+	PORT_START("INPUT_LEFT")	/* 56XX #2 pins 22-29 */
 	PORT_BIT(0xff, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	/* 56XX #2 pins 30-33 */
+	PORT_START("SERVICE")	/* 56XX #2 pins 30-33 */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNUSED )	// would be Cabinet, but this game has no cocktail mode
@@ -552,16 +553,16 @@ static const gfx_layout spritelayout =
 };
 
 static GFXDECODE_START( toypop )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, charlayout,       0, 128 )
-	GFXDECODE_ENTRY( REGION_GFX2, 0, spritelayout, 128*4,  64 )
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout,       0, 128 )
+	GFXDECODE_ENTRY( "gfx2", 0, spritelayout, 128*4,  64 )
 GFXDECODE_END
 
 
 
-static const struct namco_interface namco_interface =
+static const namco_interface namco_config =
 {
 	8,		/* number of voices */
-	REGION_SOUND1	/* memory region */
+	0		/* stereo */
 };
 
 
@@ -569,30 +570,30 @@ static const struct namco_interface namco_interface =
 static MACHINE_DRIVER_START( liblrabl )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main", M6809, 1536000)	/* 1.536 MHz (measured on Libble Rabble board) */
+	MDRV_CPU_ADD("main", M6809, 1536000)	/* 1.536 MHz (measured on Libble Rabble board) */
 	MDRV_CPU_PROGRAM_MAP(readmem_mainCPU_liblrabl,writemem_mainCPU_liblrabl)
-	MDRV_CPU_VBLANK_INT(toypop_main_interrupt,1)
+	MDRV_CPU_VBLANK_INT("main", toypop_main_interrupt)
 
-	MDRV_CPU_ADD(M6809, 1536000)
-	/* audio CPU */
+	MDRV_CPU_ADD("audio", M6809, 1536000)
 	MDRV_CPU_PROGRAM_MAP(readmem_soundCPU,writemem_soundCPU)
-	MDRV_CPU_VBLANK_INT(irq0_line_assert,1)
+	MDRV_CPU_VBLANK_INT("main", irq0_line_assert)
 
-	MDRV_CPU_ADD(M68000, 6144000)	/* 6.144 MHz (measured on Libble Rabble board) */
+	MDRV_CPU_ADD("sub", M68000, 6144000)	/* 6.144 MHz (measured on Libble Rabble board) */
 	MDRV_CPU_PROGRAM_MAP(readmem_68k,writemem_68k)
-	MDRV_CPU_VBLANK_INT(toypop_m68000_interrupt,1)
+	MDRV_CPU_VBLANK_INT("main", toypop_m68000_interrupt)
 
-	MDRV_SCREEN_REFRESH_RATE(60.606060)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(100)    /* 100 CPU slices per frame - an high value to ensure proper */
+	MDRV_QUANTUM_TIME(HZ(6000))    /* 100 CPU slices per frame - an high value to ensure proper */
 							/* synchronization of the CPUs */
 	MDRV_MACHINE_RESET(toypop)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60.606060)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(36*8, 28*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 36*8-1, 0*8, 28*8-1)
+
 	MDRV_GFXDECODE(toypop)
 	MDRV_PALETTE_LENGTH(128*4+64*4+16*2)
 
@@ -603,8 +604,8 @@ static MACHINE_DRIVER_START( liblrabl )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(NAMCO_15XX, 24000)
-	MDRV_SOUND_CONFIG(namco_interface)
+	MDRV_SOUND_ADD("namco", NAMCO_15XX, 24000)
+	MDRV_SOUND_CONFIG(namco_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -625,62 +626,62 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( liblrabl )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for the first CPU */
+	ROM_REGION( 0x10000, "main", 0 )	/* 64k for the first CPU */
 	ROM_LOAD( "5b.rom",   0x8000, 0x4000, CRC(da7a93c2) SHA1(fe4a02cdab66722eb7b8cf58825f899b1949a6a2) )
 	ROM_LOAD( "5c.rom",   0xc000, 0x4000, CRC(6cae25dc) SHA1(de74317a7d5de1865d096c377923a764be5e6879) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the second CPU */
+	ROM_REGION( 0x10000, "audio", 0 )	/* 64k for the second CPU */
 	ROM_LOAD( "2c.rom",   0xe000, 0x2000, CRC(7c09e50a) SHA1(5f004d60bbb7355e008a9cda137b28bc2192b8ef) )
 
-	ROM_REGION( 0x8000, REGION_CPU3, 0 )		/* 32k for the third CPU */
+	ROM_REGION( 0x8000, "sub", 0 )		/* 32k for the third CPU */
 	ROM_LOAD16_BYTE( "8c.rom",   0x0000, 0x4000, CRC(a00cd959) SHA1(cc5621103c31cfbc65941615cab391db0f74e6ce) )
 	ROM_LOAD16_BYTE("10c.rom",   0x0001, 0x4000, CRC(09ce209b) SHA1(2ed46d6592f8227bac8ab54963d9a300706ade47) )
 
 	/* temporary space for graphics (disposed after conversion) */
-	ROM_REGION( 0x2000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "5p.rom",   0x0000, 0x2000, CRC(3b4937f0) SHA1(06d9de576f1c2262c34aeb91054e68c9298af688) )	/* characters */
 
-	ROM_REGION( 0x4000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x4000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "9t.rom",   0x0000, 0x4000, CRC(a88e24ca) SHA1(eada133579f19de09255084dcdc386311606a335) )	/* sprites */
 
-	ROM_REGION( 0x0600, REGION_PROMS, 0 )	/* color proms */
+	ROM_REGION( 0x0600, "proms", 0 )	/* color proms */
 	ROM_LOAD( "lr1-3.1r", 0x0000, 0x0100, CRC(f3ec0d07) SHA1(b0aad1fb6df79f202889600f486853995352f9c2) )	// palette: red component
 	ROM_LOAD( "lr1-2.1s", 0x0100, 0x0100, CRC(2ae4f702) SHA1(838fdca9e91fea4f64a59880ac47c48973bb8fbf) )	// palette: green component
 	ROM_LOAD( "lr1-1.1t", 0x0200, 0x0100, CRC(7601f208) SHA1(572d070ca387b780030ed5de38a8970b7cc14349) )	// palette: blue component
 	ROM_LOAD( "lr1-5.5l", 0x0300, 0x0100, CRC(940f5397) SHA1(825a7bd78a8a08d30bad2e4890ae6e9ad88b36b8) )	/* characters */
 	ROM_LOAD( "lr1-6.2p", 0x0400, 0x0200, CRC(a6b7f850) SHA1(7cfde16dfd5c4d5b876b4fbe4f924f1385932a93) )	/* sprites */
 
-	ROM_REGION( 0x0100, REGION_SOUND1, 0 )	/* sound prom */
+	ROM_REGION( 0x0100, "namco", 0 )	/* sound prom */
 	ROM_LOAD( "lr1-4.3d", 0x0000, 0x0100, CRC(16a9166a) SHA1(847cbaf7c88616576c410177e066ae1d792ac0ba) )
 ROM_END
 
 ROM_START( toypop )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for the first CPU */
+	ROM_REGION( 0x10000, "main", 0 )	/* 64k for the first CPU */
 	ROM_LOAD( "tp1-2.5b", 0x8000, 0x4000, CRC(87469620) SHA1(2ee257486c9c044386ac7d0cd4a90583eaeb3e97) )
 	ROM_LOAD( "tp1-1.5c", 0xc000, 0x4000, CRC(dee2fd6e) SHA1(b2c12008d6d3e7544ba3c12a52a6abf9181842c8) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* 64k for the second CPU */
+	ROM_REGION( 0x10000, "audio", 0 )	/* 64k for the second CPU */
 	ROM_LOAD( "tp1-3.2c", 0xe000, 0x2000, CRC(5f3bf6e2) SHA1(d1b3335661b9b23cb10001416c515b77b5e783e9) )
 
-	ROM_REGION( 0x8000, REGION_CPU3, 0 )		/* 32k for the third CPU */
+	ROM_REGION( 0x8000, "sub", 0 )		/* 32k for the third CPU */
 	ROM_LOAD16_BYTE( "tp1-4.8c", 0x0000, 0x4000, CRC(76997db3) SHA1(5023a2f20a5f2c9baff130f6832583493c71f883) )
 	ROM_LOAD16_BYTE("tp1-5.10c", 0x0001, 0x4000, CRC(37de8786) SHA1(710365e34c05d01815844c414518f93234b6160b) )
 
 	/* temporary space for graphics (disposed after conversion) */
-	ROM_REGION( 0x2000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x2000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "tp1-7.5p", 0x0000, 0x2000, CRC(95076f9e) SHA1(1e3d32b21f6d46591ec3921aba51f672d64a9023) )	/* characters */
 
-	ROM_REGION( 0x4000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x4000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "tp1-6.9t", 0x0000, 0x4000, CRC(481ffeaf) SHA1(c51735ad3a1dbb46ad414408b54554e9223b2219) )	/* sprites */
 
-	ROM_REGION( 0x0600, REGION_PROMS, 0 )	/* color proms */
+	ROM_REGION( 0x0600, "proms", 0 )	/* color proms */
 	ROM_LOAD( "tp1-3.1r", 0x0000, 0x0100, CRC(cfce2fa5) SHA1(b42aa0f34d885389d2650bf7a0531b95703b8a28) )	// palette: red component
 	ROM_LOAD( "tp1-2.1s", 0x0100, 0x0100, CRC(aeaf039d) SHA1(574560526100d38635aecd71eb73499c4f57d586) )	// palette: green component
 	ROM_LOAD( "tp1-1.1t", 0x0200, 0x0100, CRC(08e7cde3) SHA1(5261aca6834d635d17f8afaa8e35848930030ba4) )	// palette: blue component
 	ROM_LOAD( "tp1-4.5l", 0x0300, 0x0100, CRC(74138973) SHA1(2e21dbb1b19dd089da52e70fcb0ca91336e004e6) )	/* characters */
 	ROM_LOAD( "tp1-5.2p", 0x0400, 0x0200, CRC(4d77fa5a) SHA1(2438910314b23ecafb553230244f3931861ad2da) )	/* sprites */
 
-	ROM_REGION( 0x0100, REGION_SOUND1, 0 )	/* sound prom */
+	ROM_REGION( 0x0100, "namco", 0 )	/* sound prom */
 	ROM_LOAD( "lr1-4.3d", 0x0000, 0x0100, CRC(16a9166a) SHA1(847cbaf7c88616576c410177e066ae1d792ac0ba) )
 ROM_END
 
