@@ -99,7 +99,7 @@ TP-S.1 TP-S.2 TP-S.3 TP-B.1  8212 TP-B.2 TP-B.3          TP-B.4
 
 
 #include "driver.h"
-#include "deprecat.h"
+#include "cpu/m6800/m6800.h"
 #include "cpu/z80/z80.h"
 #include "cpu/m6805/m6805.h"
 #include "sound/ay8910.h"
@@ -146,10 +146,10 @@ static WRITE8_HANDLER( tubep_LS259_w )
 				//screen_flip_w(offset,data&1); /* bit 0 = screen flip, active high */
 				break;
 		case 6:
-				tubep_background_romselect_w(offset,data);	/* bit0 = 0->select roms: B1,B3,B5; bit0 = 1->select roms: B2,B4,B6 */
+				tubep_background_romselect_w(space,offset,data);	/* bit0 = 0->select roms: B1,B3,B5; bit0 = 1->select roms: B2,B4,B6 */
 				break;
 		case 7:
-				tubep_colorproms_A4_line_w(offset,data);	/* bit0 = line A4 (color proms address) state */
+				tubep_colorproms_A4_line_w(space,offset,data);	/* bit0 = line A4 (color proms address) state */
 				break;
 		default:
 				break;
@@ -161,14 +161,14 @@ static ADDRESS_MAP_START( tubep_main_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x7fff) AM_ROM
 	AM_RANGE(0xa000, 0xa7ff) AM_RAM
 	AM_RANGE(0xc000, 0xc7ff) AM_WRITE(tubep_textram_w) AM_BASE(&tubep_textram)	/* RAM on GFX PCB @B13 */
-	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(MWA8_RAM) AM_SHARE(1)
-	AM_RANGE(0xe800, 0xebff) AM_WRITE(MWA8_RAM) AM_SHARE(4)				/* row of 8 x 2147 RAMs on main PCB */
+	AM_RANGE(0xe000, 0xe7ff) AM_WRITE(SMH_RAM) AM_SHARE(1)
+	AM_RANGE(0xe800, 0xebff) AM_WRITE(SMH_RAM) AM_SHARE(4)				/* row of 8 x 2147 RAMs on main PCB */
 ADDRESS_MAP_END
 
 
 static WRITE8_HANDLER( main_cpu_irq_line_clear_w )
 {
-	cpunum_set_input_line(Machine, 0, 0, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[0], 0, CLEAR_LINE);
 	logerror("CPU#0 VBLANK int clear at scanline=%3i\n", curr_scanline);
 	return;
 }
@@ -180,14 +180,14 @@ static WRITE8_HANDLER( tubep_soundlatch_w )
 }
 
 static ADDRESS_MAP_START( tubep_main_portmap, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x80, 0x80) AM_READ(input_port_3_r)
-	AM_RANGE(0x90, 0x90) AM_READ(input_port_4_r)
-	AM_RANGE(0xa0, 0xa0) AM_READ(input_port_5_r)
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x80, 0x80) AM_READ_PORT("DSW1")
+	AM_RANGE(0x90, 0x90) AM_READ_PORT("DSW2")
+	AM_RANGE(0xa0, 0xa0) AM_READ_PORT("DSW3")
 
-	AM_RANGE(0xb0, 0xb0) AM_READ(input_port_2_r)
-	AM_RANGE(0xc0, 0xc0) AM_READ(input_port_1_r)
-	AM_RANGE(0xd0, 0xd0) AM_READ(input_port_0_r)
+	AM_RANGE(0xb0, 0xb0) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0xc0, 0xc0) AM_READ_PORT("P2")
+	AM_RANGE(0xd0, 0xd0) AM_READ_PORT("P1")
 
 	AM_RANGE(0x80, 0x80) AM_WRITE(main_cpu_irq_line_clear_w)
 	AM_RANGE(0xb0, 0xb7) AM_WRITE(tubep_LS259_w)
@@ -204,7 +204,7 @@ ADDRESS_MAP_END
 
 static WRITE8_HANDLER( second_cpu_irq_line_clear_w )
 {
-	cpunum_set_input_line(Machine, 1, 0, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[1], 0, CLEAR_LINE);
 	logerror("CPU#1 VBLANK int clear at scanline=%3i\n", curr_scanline);
 	return;
 }
@@ -215,14 +215,14 @@ static ADDRESS_MAP_START( tubep_second_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0xa000, 0xa000) AM_WRITE(tubep_background_a000_w)
 	AM_RANGE(0xc000, 0xc000) AM_WRITE(tubep_background_c000_w)
 	AM_RANGE(0xe000, 0xe7ff) AM_RAM AM_SHARE(1) 								/* 6116 #1 */
-	AM_RANGE(0xe800, 0xebff) AM_WRITE(MWA8_RAM) AM_SHARE(4) AM_BASE(&tubep_backgroundram)	/* row of 8 x 2147 RAMs on main PCB */
-	AM_RANGE(0xf000, 0xf3ff) AM_WRITE(MWA8_RAM) AM_SHARE(3)						/* sprites color lookup table */
+	AM_RANGE(0xe800, 0xebff) AM_WRITE(SMH_RAM) AM_SHARE(4) AM_BASE(&tubep_backgroundram)	/* row of 8 x 2147 RAMs on main PCB */
+	AM_RANGE(0xf000, 0xf3ff) AM_WRITE(SMH_RAM) AM_SHARE(3)						/* sprites color lookup table */
 	AM_RANGE(0xf800, 0xffff) AM_RAM AM_SHARE(2)									/* program copies here part of shared ram ?? */
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( tubep_second_portmap, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x7f, 0x7f) AM_WRITE(second_cpu_irq_line_clear_w)
 ADDRESS_MAP_END
 
@@ -239,7 +239,7 @@ static READ8_HANDLER( tubep_soundlatch_r )
 
 static READ8_HANDLER( tubep_sound_irq_ack )
 {
-	cpunum_set_input_line(Machine, 2, 0, CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[2], 0, CLEAR_LINE);
 	return 0;
 }
 
@@ -258,13 +258,13 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( tubep_sound_portmap, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x00, 0x00) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0x01, 0x01) AM_WRITE(AY8910_write_port_0_w)
-	AM_RANGE(0x02, 0x02) AM_WRITE(AY8910_control_port_1_w)
-	AM_RANGE(0x03, 0x03) AM_WRITE(AY8910_write_port_1_w)
-	AM_RANGE(0x04, 0x04) AM_WRITE(AY8910_control_port_2_w)
-	AM_RANGE(0x05, 0x05) AM_WRITE(AY8910_write_port_2_w)
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x00, 0x00) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0x01, 0x01) AM_WRITE(ay8910_write_port_0_w)
+	AM_RANGE(0x02, 0x02) AM_WRITE(ay8910_control_port_1_w)
+	AM_RANGE(0x03, 0x03) AM_WRITE(ay8910_write_port_1_w)
+	AM_RANGE(0x04, 0x04) AM_WRITE(ay8910_control_port_2_w)
+	AM_RANGE(0x05, 0x05) AM_WRITE(ay8910_write_port_2_w)
 	AM_RANGE(0x06, 0x06) AM_READ(tubep_soundlatch_r)
 	AM_RANGE(0x07, 0x07) AM_WRITE(tubep_sound_unknown)
 ADDRESS_MAP_END
@@ -282,7 +282,7 @@ curr_scanline = scanline;//for debugging
 	if (scanline==240)
 	{
 		logerror("VBLANK CPU#0\n");
-		cpunum_set_input_line(machine, 0, 0, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[0], 0, ASSERT_LINE);
 	}
 
 
@@ -291,7 +291,7 @@ curr_scanline = scanline;//for debugging
 	if (scanline==16)
 	{
 		logerror("/VBLANK CPU#1\n");
-		cpunum_set_input_line(machine, 1, 0, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[1], 0, ASSERT_LINE);
 	}
 
 
@@ -301,14 +301,14 @@ curr_scanline = scanline;//for debugging
 	{
 		logerror("/nmi CPU#3\n");
 		tubep_vblank_end(); /* switch buffered sprite RAM page */
-		cpunum_set_input_line(machine, 3, INPUT_LINE_NMI, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[3], INPUT_LINE_NMI, ASSERT_LINE);
 	}
 	/* CPU #3 MS2010-A NMI */
 	/* deactivates at the start of VBLANK signal which happens at the beginning of scanline number 240*/
 	if (scanline==240)
 	{
 		logerror("CPU#3 nmi clear\n");
-		cpunum_set_input_line(machine, 3, INPUT_LINE_NMI, CLEAR_LINE);
+		cpu_set_input_line(machine->cpu[3], INPUT_LINE_NMI, CLEAR_LINE);
 	}
 
 
@@ -316,20 +316,20 @@ curr_scanline = scanline;//for debugging
 	/* activates whenever line V6 from video part goes lo->hi that is when the scanline becomes 64 and 192 */
 	if ((scanline==64) || (scanline==192))
 	{
-		cpunum_set_input_line(machine, 2,0,ASSERT_LINE);	/* sound cpu interrupt (music tempo) */
+		cpu_set_input_line(machine->cpu[2],0,ASSERT_LINE);	/* sound cpu interrupt (music tempo) */
 	}
 
 
-	video_screen_update_partial(0, video_screen_get_vpos(0));
+	video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
 
 //debug
-logerror("scanline=%3i scrgetvpos(0)=%3i\n",scanline,video_screen_get_vpos(0));
+logerror("scanline=%3i scrgetvpos(0)=%3i\n",scanline,video_screen_get_vpos(machine->primary_screen));
 
 	scanline ++;
 	if (scanline>=264)
 		scanline=0;
 
-	timer_adjust(interrupt_timer, video_screen_get_time_until_pos(0, scanline, 0), scanline, attotime_zero);
+	timer_adjust_oneshot(interrupt_timer, video_screen_get_time_until_pos(machine->primary_screen, scanline, 0), scanline);
 }
 
 
@@ -340,12 +340,12 @@ logerror("scanline=%3i scrgetvpos(0)=%3i\n",scanline,video_screen_get_vpos(0));
  *
  *************************************/
 
-static void tubep_setup_save_state(void)
+static void tubep_setup_save_state(running_machine *machine)
 {
 	/* Set up save state */
-	state_save_register_global(sound_latch);
-	state_save_register_global(ls74);
-	state_save_register_global(ls377);
+	state_save_register_global(machine, sound_latch);
+	state_save_register_global(machine, ls74);
+	state_save_register_global(machine, ls377);
 }
 
 
@@ -353,15 +353,15 @@ static void tubep_setup_save_state(void)
 static MACHINE_START( tubep )
 {
 	/* Create interrupt timer */
-	interrupt_timer = timer_alloc(tubep_scanline_callback, NULL);
+	interrupt_timer = timer_alloc(machine, tubep_scanline_callback, NULL);
 
-	tubep_setup_save_state();
+	tubep_setup_save_state(machine);
 }
 
 
 static MACHINE_RESET( tubep )
 {
-	timer_adjust(interrupt_timer, video_screen_get_time_until_pos(0, 0, 0), 0, attotime_zero);
+	timer_adjust_oneshot(interrupt_timer, video_screen_get_time_until_pos(machine->primary_screen, 0, 0), 0);
 }
 
 
@@ -377,7 +377,7 @@ static ADDRESS_MAP_START( nsc_map, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0x03ff) AM_RAM AM_SHARE(3) AM_BASE(&tubep_sprite_colorsharedram)
 	AM_RANGE(0x0800, 0x0fff) AM_RAM AM_SHARE(2)
 	AM_RANGE(0x2000, 0x2009) AM_WRITE(tubep_sprite_control_w)
-	AM_RANGE(0x200a, 0x200b) AM_WRITE(MWA8_NOP) /* not used by the games - perhaps designed for debugging */
+	AM_RANGE(0x200a, 0x200b) AM_WRITE(SMH_NOP) /* not used by the games - perhaps designed for debugging */
 	AM_RANGE(0xc000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
@@ -409,7 +409,7 @@ static WRITE8_HANDLER( rjammer_LS259_w )
 static WRITE8_HANDLER( rjammer_soundlatch_w )
 {
 	sound_latch = data;
-	cpunum_set_input_line(Machine, 2, INPUT_LINE_NMI, PULSE_LINE);
+	cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_NMI, PULSE_LINE);
 }
 
 
@@ -422,13 +422,13 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( rjammer_main_portmap, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
-	AM_RANGE(0x00, 0x00) AM_READ(input_port_2_r)	/* a bug in game code (during attract mode) */
-	AM_RANGE(0x80, 0x80) AM_READ(input_port_2_r)
-	AM_RANGE(0x90, 0x90) AM_READ(input_port_3_r)
-	AM_RANGE(0xa0, 0xa0) AM_READ(input_port_4_r)
-	AM_RANGE(0xb0, 0xb0) AM_READ(input_port_0_r)
-	AM_RANGE(0xc0, 0xc0) AM_READ(input_port_1_r)
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
+	AM_RANGE(0x00, 0x00) AM_READ_PORT("DSW2")	/* a bug in game code (during attract mode) */
+	AM_RANGE(0x80, 0x80) AM_READ_PORT("DSW2")
+	AM_RANGE(0x90, 0x90) AM_READ_PORT("DSW1")
+	AM_RANGE(0xa0, 0xa0) AM_READ_PORT("SYSTEM")
+	AM_RANGE(0xb0, 0xb0) AM_READ_PORT("P1")
+	AM_RANGE(0xc0, 0xc0) AM_READ_PORT("P2")
 
 	AM_RANGE(0xd0, 0xd7) AM_WRITE(rjammer_LS259_w)
 	AM_RANGE(0xe0, 0xe0) AM_WRITE(main_cpu_irq_line_clear_w)	/* clear IRQ interrupt */
@@ -446,7 +446,7 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( rjammer_second_portmap, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0xb0, 0xb0) AM_WRITE(rjammer_background_page_w)
 	AM_RANGE(0xd0, 0xd0) AM_WRITE(rjammer_background_LS377_w)
 ADDRESS_MAP_END
@@ -464,7 +464,7 @@ curr_scanline = scanline;//for debugging
 	if (scanline==240)
 	{
 		logerror("VBLANK CPU#0\n");
-		cpunum_set_input_line(machine, 0, 0, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[0], 0, ASSERT_LINE);
 	}
 
 
@@ -473,7 +473,7 @@ curr_scanline = scanline;//for debugging
 	if (scanline==16)
 	{
 		logerror("/VBLANK CPU#1\n");
-		cpunum_set_input_line(machine, 1, 0, HOLD_LINE);
+		cpu_set_input_line(machine->cpu[1], 0, HOLD_LINE);
 	}
 
 
@@ -483,14 +483,14 @@ curr_scanline = scanline;//for debugging
 	{
 		logerror("/nmi CPU#3\n");
 		tubep_vblank_end(); /* switch buffered sprite RAM page */
-		cpunum_set_input_line(machine, 3, INPUT_LINE_NMI, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[3], INPUT_LINE_NMI, ASSERT_LINE);
 	}
 	/* CPU #3 MS2010-A NMI */
 	/* deactivates at the start of VBLANK signal which happens at the beginning of scanline number 240*/
 	if (scanline==240)
 	{
 		logerror("CPU#3 nmi clear\n");
-		cpunum_set_input_line(machine, 3, INPUT_LINE_NMI, CLEAR_LINE);
+		cpu_set_input_line(machine->cpu[3], INPUT_LINE_NMI, CLEAR_LINE);
 	}
 
 
@@ -498,33 +498,33 @@ curr_scanline = scanline;//for debugging
 	/* activates whenever line V6 from video part goes lo->hi that is when the scanline becomes 64 and 192 */
 	if ((scanline==64) || (scanline==192))
 	{
-		cpunum_set_input_line(machine, 2,0,ASSERT_LINE);	/* sound cpu interrupt (music tempo) */
+		cpu_set_input_line(machine->cpu[2],0,ASSERT_LINE);	/* sound cpu interrupt (music tempo) */
 	}
 
 
-	video_screen_update_partial(0, video_screen_get_vpos(0));
+	video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
 
-logerror("scanline=%3i scrgetvpos(0)=%3i\n",scanline,video_screen_get_vpos(0));
+logerror("scanline=%3i scrgetvpos(0)=%3i\n",scanline,video_screen_get_vpos(machine->primary_screen));
 
 	scanline ++;
 	if (scanline>=264)
 		scanline=0;
 
-	timer_adjust(interrupt_timer, video_screen_get_time_until_pos(0, scanline, 0), scanline, attotime_zero);
+	timer_adjust_oneshot(interrupt_timer, video_screen_get_time_until_pos(machine->primary_screen, scanline, 0), scanline);
 }
 
 
 static MACHINE_START( rjammer )
 {
 	/* Create interrupt timer */
-	interrupt_timer = timer_alloc(rjammer_scanline_callback, NULL);
+	interrupt_timer = timer_alloc(machine, rjammer_scanline_callback, NULL);
 
-	tubep_setup_save_state();
+	tubep_setup_save_state(machine);
 }
 
 static MACHINE_RESET( rjammer )
 {
-	timer_adjust(interrupt_timer, video_screen_get_time_until_pos(0, 0, 0), 0, attotime_zero);
+	timer_adjust_oneshot(interrupt_timer, video_screen_get_time_until_pos(machine->primary_screen, 0, 0), 0);
 }
 
 
@@ -546,7 +546,7 @@ static WRITE8_HANDLER( rjammer_voice_startstop_w )
 {
 	/* bit 0 of data selects voice start/stop (reset pin on MSM5205)*/
 	// 0 -stop; 1-start
-	MSM5205_reset_w (0, (data&1)^1 );
+	msm5205_reset_w (0, (data&1)^1 );
 
 	return;
 }
@@ -557,26 +557,26 @@ static WRITE8_HANDLER( rjammer_voice_frequency_select_w )
 	/* bit 0 of data selects voice frequency on MSM5205 */
 	// 0 -4 KHz; 1- 8KHz
 	if (data&1)
-		MSM5205_playmode_w(0,MSM5205_S48_4B);	/* 8 KHz */
+		msm5205_playmode_w(0,MSM5205_S48_4B);	/* 8 KHz */
 	else
-		MSM5205_playmode_w(0,MSM5205_S96_4B);	/* 4 KHz */
+		msm5205_playmode_w(0,MSM5205_S96_4B);	/* 4 KHz */
 
 	return;
 }
 
 
-static void rjammer_adpcm_vck (int data)
+static void rjammer_adpcm_vck (const device_config *device)
 {
 	ls74 = (ls74+1) & 1;
 
 	if (ls74==1)
 	{
-		MSM5205_data_w(0, (ls377>>0) & 15 );
-		cpunum_set_input_line(Machine, 2, 0, ASSERT_LINE );
+		msm5205_data_w(0, (ls377>>0) & 15 );
+		cpu_set_input_line(device->machine->cpu[2], 0, ASSERT_LINE );
 	}
 	else
 	{
-		MSM5205_data_w(0, (ls377>>4) & 15 );
+		msm5205_data_w(0, (ls377>>4) & 15 );
 	}
 
 }
@@ -594,7 +594,7 @@ static WRITE8_HANDLER( rjammer_voice_input_w )
             I do it here because this port (0x80) is first one accessed
             in the interrupt routine.
     */
-	cpunum_set_input_line(Machine, 2, 0, CLEAR_LINE );
+	cpu_set_input_line(space->machine->cpu[2], 0, CLEAR_LINE );
 	return;
 }
 
@@ -614,17 +614,17 @@ ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( rjammer_sound_portmap, ADDRESS_SPACE_IO, 8 )
-	ADDRESS_MAP_FLAGS( AMEF_ABITS(8) )
+	ADDRESS_MAP_GLOBAL_MASK(0xff)
 	AM_RANGE(0x00, 0x00) AM_READ(rjammer_soundlatch_r)
 	AM_RANGE(0x10, 0x10) AM_WRITE(rjammer_voice_startstop_w)
 	AM_RANGE(0x18, 0x18) AM_WRITE(rjammer_voice_frequency_select_w)
 	AM_RANGE(0x80, 0x80) AM_WRITE(rjammer_voice_input_w)
-	AM_RANGE(0x90, 0x90) AM_WRITE(AY8910_control_port_0_w)
-	AM_RANGE(0x91, 0x91) AM_WRITE(AY8910_write_port_0_w)
-	AM_RANGE(0x92, 0x92) AM_WRITE(AY8910_control_port_1_w)
-	AM_RANGE(0x93, 0x93) AM_WRITE(AY8910_write_port_1_w)
-	AM_RANGE(0x94, 0x94) AM_WRITE(AY8910_control_port_2_w)
-	AM_RANGE(0x95, 0x95) AM_WRITE(AY8910_write_port_2_w)
+	AM_RANGE(0x90, 0x90) AM_WRITE(ay8910_control_port_0_w)
+	AM_RANGE(0x91, 0x91) AM_WRITE(ay8910_write_port_0_w)
+	AM_RANGE(0x92, 0x92) AM_WRITE(ay8910_control_port_1_w)
+	AM_RANGE(0x93, 0x93) AM_WRITE(ay8910_write_port_1_w)
+	AM_RANGE(0x94, 0x94) AM_WRITE(ay8910_control_port_2_w)
+	AM_RANGE(0x95, 0x95) AM_WRITE(ay8910_write_port_2_w)
 	AM_RANGE(0x96, 0x96) AM_WRITE(rjammer_voice_intensity_control_w)
 ADDRESS_MAP_END
 
@@ -664,7 +664,7 @@ static WRITE8_HANDLER( ay8910_portB_2_w )
 
 
 static INPUT_PORTS_START( tubep )
-	PORT_START_TAG("P1")
+	PORT_START("P1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
@@ -674,7 +674,7 @@ static INPUT_PORTS_START( tubep )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("P2")
+	PORT_START("P2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP  ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
@@ -684,7 +684,7 @@ static INPUT_PORTS_START( tubep )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("Coin_Start")
+	PORT_START("SYSTEM")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_START1 )
@@ -694,7 +694,7 @@ static INPUT_PORTS_START( tubep )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START_TAG("DSW1")
+	PORT_START("DSW1")
 	PORT_DIPNAME( 0x07, 0x07, DEF_STR( Coin_A ) ) PORT_DIPLOCATION("SW1:6,5,4")
 	PORT_DIPSETTING(    0x07, DEF_STR( 1C_1C ) )
 	PORT_DIPSETTING(    0x06, DEF_STR( 1C_2C ) )
@@ -716,7 +716,7 @@ static INPUT_PORTS_START( tubep )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("DSW2")
+	PORT_START("DSW2")
 	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Lives ) ) PORT_DIPLOCATION("SW2:6,5")
 	PORT_DIPSETTING(    0x03, "2" )
 	PORT_DIPSETTING(    0x02, "3" )
@@ -736,7 +736,7 @@ static INPUT_PORTS_START( tubep )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("DSW3")
+	PORT_START("DSW3")
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Demo_Sounds ) ) PORT_DIPLOCATION("SW3:6")
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -776,7 +776,7 @@ INPUT_PORTS_END
 
 
 static INPUT_PORTS_START( rjammer )
-	PORT_START_TAG("P1")
+	PORT_START("P1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON2 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON1 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
@@ -786,7 +786,7 @@ static INPUT_PORTS_START( rjammer )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON3 )
 
-	PORT_START_TAG("P2")
+	PORT_START("P2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_COCKTAIL
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP  ) PORT_8WAY PORT_COCKTAIL
@@ -796,28 +796,17 @@ static INPUT_PORTS_START( rjammer )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_COCKTAIL
 
-	PORT_START_TAG("DSW2")
-	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Demo_Sounds ) ) PORT_DIPLOCATION("SW2:6")
-	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
-	PORT_DIPNAME( 0x02, 0x02, "Bonus Time" ) PORT_DIPLOCATION("SW2:5")
-	PORT_DIPSETTING(    0x02, "100" )
-	PORT_DIPSETTING(    0x00, "200" )
-	PORT_DIPNAME( 0x0c, 0x0c, "Clear Men" ) PORT_DIPLOCATION("SW2:4,3")
-	PORT_DIPSETTING(    0x0c, "20" )
-	PORT_DIPSETTING(    0x08, "30" )
-	PORT_DIPSETTING(    0x04, "40" )
-	PORT_DIPSETTING(    0x00, "50" )
-	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Difficulty ) ) PORT_DIPLOCATION("SW2:2")
-	PORT_DIPSETTING(    0x10, DEF_STR( Easy ) )
-	PORT_DIPSETTING(    0x00, DEF_STR( Hard ) )
-	PORT_DIPNAME( 0x20, 0x20, "Time" ) PORT_DIPLOCATION("SW2:1")
-	PORT_DIPSETTING(    0x20, "40" )
-	PORT_DIPSETTING(    0x00, "50" )
+	PORT_START("SYSTEM")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
+	PORT_SERVICE( 0x08, IP_ACTIVE_LOW )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("DSW1")
+	PORT_START("DSW1")
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Cabinet ) ) PORT_DIPLOCATION("SW1:6")
 	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Cocktail ) )
@@ -837,77 +826,67 @@ static INPUT_PORTS_START( rjammer )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START_TAG("Coins_Service")
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
-	PORT_SERVICE( 0x08, IP_ACTIVE_LOW )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_START("DSW2")
+	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Demo_Sounds ) ) PORT_DIPLOCATION("SW2:6")
+	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
+	PORT_DIPNAME( 0x02, 0x02, "Bonus Time" ) PORT_DIPLOCATION("SW2:5")
+	PORT_DIPSETTING(    0x02, "100" )
+	PORT_DIPSETTING(    0x00, "200" )
+	PORT_DIPNAME( 0x0c, 0x0c, "Clear Men" ) PORT_DIPLOCATION("SW2:4,3")
+	PORT_DIPSETTING(    0x0c, "20" )
+	PORT_DIPSETTING(    0x08, "30" )
+	PORT_DIPSETTING(    0x04, "40" )
+	PORT_DIPSETTING(    0x00, "50" )
+	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Difficulty ) ) PORT_DIPLOCATION("SW2:2")
+	PORT_DIPSETTING(    0x10, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x00, DEF_STR( Hard ) )
+	PORT_DIPNAME( 0x20, 0x20, "Time" ) PORT_DIPLOCATION("SW2:1")
+	PORT_DIPSETTING(    0x20, "40" )
+	PORT_DIPSETTING(    0x00, "50" )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
 
 
-/*************************************
- *
- *  Graphics definitions
- *
- *************************************/
-
-static const gfx_layout charlayout =
-{
-	8, 8,	/* 8*8 characters */
-	512,	/* 512 characters */
-	1,		/* 1 bit per pixel */
-	{ 0 },
-	{ 0, 1, 2, 3, 4, 5, 6, 7 },
-	{ 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8 },
-	8*8 /* every char takes 8 consecutive bytes */
-};
-
-static GFXDECODE_START( tubep )
-	GFXDECODE_ENTRY( REGION_GFX1,      0, charlayout,       0, 32 )	/* 32 color codes */
-GFXDECODE_END
-
-static GFXDECODE_START( rjammer )
-	GFXDECODE_ENTRY( REGION_GFX1,      0, charlayout,       0, 16 )	/* 16 color codes */
-GFXDECODE_END
-
-
-
 /*************************************
  *
  *  Sound definitions
  *
  *************************************/
 
-static const struct AY8910interface ay8910_interface_1 =
+static const ay8910_interface ay8910_interface_1 =
 {
-	0,
-	0,
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
+	NULL,
+	NULL,
 	ay8910_portA_0_w, /* write port A */
 	ay8910_portB_0_w  /* write port B */
 };
 
-static const struct AY8910interface ay8910_interface_2 =
+static const ay8910_interface ay8910_interface_2 =
 {
-	0,
-	0,
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
+	NULL,
+	NULL,
 	ay8910_portA_1_w, /* write port A */
 	ay8910_portB_1_w  /* write port B */
 };
 
-static const struct AY8910interface ay8910_interface_3 =
+static const ay8910_interface ay8910_interface_3 =
 {
-	0,
-	0,
+	AY8910_LEGACY_OUTPUT,
+	AY8910_DEFAULT_LOADS,
+	NULL,
+	NULL,
 	ay8910_portA_2_w, /* write port A */
 	ay8910_portB_2_w  /* write port B */
 };
 
-static const struct MSM5205interface msm5205_interface =
+static const msm5205_interface msm5205_config =
 {
 	rjammer_adpcm_vck,			/* VCK function */
 	MSM5205_S48_4B				/* 8 KHz (changes at run time) */
@@ -924,53 +903,52 @@ static const struct MSM5205interface msm5205_interface =
 static MACHINE_DRIVER_START( tubep )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main",Z80,16000000 / 4)	/* 4 MHz */
+	MDRV_CPU_ADD("main",Z80,16000000 / 4)	/* 4 MHz */
 	MDRV_CPU_PROGRAM_MAP(tubep_main_map,0)
 	MDRV_CPU_IO_MAP(tubep_main_portmap,0)
 
-	MDRV_CPU_ADD_TAG("slave",Z80,16000000 / 4)	/* 4 MHz */
+	MDRV_CPU_ADD("slave",Z80,16000000 / 4)	/* 4 MHz */
 	MDRV_CPU_PROGRAM_MAP(tubep_second_map,0)
 	MDRV_CPU_IO_MAP(tubep_second_portmap,0)
 
-	/* audio CPU */
-	MDRV_CPU_ADD_TAG("sound",Z80,19968000 / 8)	/* X2 19968000 Hz divided by LS669 (on Qc output) (signal RH0) */
+	MDRV_CPU_ADD("sound",Z80,19968000 / 8)	/* X2 19968000 Hz divided by LS669 (on Qc output) (signal RH0) */
 	MDRV_CPU_PROGRAM_MAP(tubep_sound_map,0)
 	MDRV_CPU_IO_MAP(tubep_sound_portmap,0)
 
-	MDRV_CPU_ADD_TAG("nsc",NSC8105,6000000)	/* 6 MHz Xtal - divided internally ??? */
+	MDRV_CPU_ADD("nsc",NSC8105,6000000)	/* 6 MHz Xtal - divided internally ??? */
 	MDRV_CPU_PROGRAM_MAP(nsc_map,0)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_INTERLEAVE(100)
+	MDRV_QUANTUM_TIME(HZ(6000))
 
 	MDRV_MACHINE_START(tubep)
 	MDRV_MACHINE_RESET(tubep)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 264)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MDRV_GFXDECODE(tubep)
+
 	MDRV_PALETTE_LENGTH(32 + 256*64)
-	MDRV_COLORTABLE_LENGTH(32*2)
 
 	MDRV_PALETTE_INIT(tubep)
 	MDRV_VIDEO_START(tubep)
+	MDRV_VIDEO_RESET(tubep)
 	MDRV_VIDEO_UPDATE(tubep)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, 19968000 / 8 / 2)
+	MDRV_SOUND_ADD("ay1", AY8910, 19968000 / 8 / 2)
 	MDRV_SOUND_CONFIG(ay8910_interface_1)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
-	MDRV_SOUND_ADD(AY8910, 19968000 / 8 / 2)
+	MDRV_SOUND_ADD("ay2", AY8910, 19968000 / 8 / 2)
 	MDRV_SOUND_CONFIG(ay8910_interface_2)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
-	MDRV_SOUND_ADD(AY8910, 19968000 / 8 / 2)
+	MDRV_SOUND_ADD("ay3", AY8910, 19968000 / 8 / 2)
 	MDRV_SOUND_CONFIG(ay8910_interface_3)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 MACHINE_DRIVER_END
@@ -981,67 +959,65 @@ static MACHINE_DRIVER_START( tubepb )
 
 	MDRV_CPU_REMOVE("nsc")
 
-	MDRV_CPU_ADD(M6802,6000000) /* ? MHz Xtal */
+	MDRV_CPU_ADD("mcu", M6802,6000000) /* ? MHz Xtal */
 	MDRV_CPU_PROGRAM_MAP(nsc_map,0)
-	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
+	MDRV_CPU_VBLANK_INT("main", nmi_line_pulse)
 MACHINE_DRIVER_END
 
 
 static MACHINE_DRIVER_START( rjammer )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD_TAG("main",Z80,16000000 / 4)	/* 4 MHz */
+	MDRV_CPU_ADD("main",Z80,16000000 / 4)	/* 4 MHz */
 	MDRV_CPU_PROGRAM_MAP(rjammer_main_map,0)
 	MDRV_CPU_IO_MAP(rjammer_main_portmap,0)
 
-	MDRV_CPU_ADD_TAG("slave",Z80,16000000 / 4)	/* 4 MHz */
+	MDRV_CPU_ADD("slave",Z80,16000000 / 4)	/* 4 MHz */
 	MDRV_CPU_PROGRAM_MAP(rjammer_second_map,0)
 	MDRV_CPU_IO_MAP(rjammer_second_portmap,0)
 
-	/* audio CPU */
-	MDRV_CPU_ADD_TAG("sound",Z80,19968000 / 8)	/* X2 19968000 Hz divided by LS669 (on Qc output) (signal RH0) */
+	MDRV_CPU_ADD("sound",Z80,19968000 / 8)	/* X2 19968000 Hz divided by LS669 (on Qc output) (signal RH0) */
 	MDRV_CPU_PROGRAM_MAP(rjammer_sound_map,0)
 	MDRV_CPU_IO_MAP(rjammer_sound_portmap,0)
 
-	MDRV_CPU_ADD_TAG("nsc",NSC8105,6000000)	/* 6 MHz Xtal - divided internally ??? */
+	MDRV_CPU_ADD("nsc",NSC8105,6000000)	/* 6 MHz Xtal - divided internally ??? */
 	MDRV_CPU_PROGRAM_MAP(nsc_map,0)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-
 	MDRV_MACHINE_START(rjammer)
 	MDRV_MACHINE_RESET(rjammer)
 
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(256, 264)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
-	MDRV_GFXDECODE(rjammer)
+
 	MDRV_PALETTE_LENGTH(64)
-	MDRV_COLORTABLE_LENGTH(2*16 + 16*2)
 
 	MDRV_PALETTE_INIT(rjammer)
 	MDRV_VIDEO_START(tubep)
+	MDRV_VIDEO_RESET(tubep)
 	MDRV_VIDEO_UPDATE(rjammer)
 
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(AY8910, 19968000 / 8 / 2)
+	MDRV_SOUND_ADD("ay1", AY8910, 19968000 / 8 / 2)
 	MDRV_SOUND_CONFIG(ay8910_interface_1)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
-	MDRV_SOUND_ADD(AY8910, 19968000 / 8 / 2)
+	MDRV_SOUND_ADD("ay2", AY8910, 19968000 / 8 / 2)
 	MDRV_SOUND_CONFIG(ay8910_interface_2)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
-	MDRV_SOUND_ADD(AY8910, 19968000 / 8 / 2)
+	MDRV_SOUND_ADD("ay3", AY8910, 19968000 / 8 / 2)
 	MDRV_SOUND_CONFIG(ay8910_interface_3)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.10)
 
-	MDRV_SOUND_ADD(MSM5205, 384000)
-	MDRV_SOUND_CONFIG(msm5205_interface)
+	MDRV_SOUND_ADD("msm", MSM5205, 384000)
+	MDRV_SOUND_CONFIG(msm5205_config)
 	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
 MACHINE_DRIVER_END
 
@@ -1054,27 +1030,27 @@ MACHINE_DRIVER_END
  *************************************/
 
 ROM_START( tubep )
-	ROM_REGION( 0x10000,REGION_CPU1, 0 ) /* Z80 (master) cpu code */
+	ROM_REGION( 0x10000,"main", 0 ) /* Z80 (master) cpu code */
 	ROM_LOAD( "tp-p.5", 0x0000, 0x2000, CRC(d5e0cc2f) SHA1(db9b062b14af52bb5458fe71996da295a69148ac) )
 	ROM_LOAD( "tp-p.6", 0x2000, 0x2000, CRC(97b791a0) SHA1(20ef87b3d3bdfc8b983bcb8231252f81d98ad452) )
 	ROM_LOAD( "tp-p.7", 0x4000, 0x2000, CRC(add9983e) SHA1(70a517451553a8c0e74a1995d9afddb779efc92c) )
 	ROM_LOAD( "tp-p.8", 0x6000, 0x2000, CRC(b3793cb5) SHA1(0ed622b6bb97b9877acb6dc174edcd9977fa784e) )
 
-	ROM_REGION( 0x10000,REGION_CPU2, 0 ) /* Z80 (slave) cpu code */
+	ROM_REGION( 0x10000,"slave", 0 ) /* Z80 (slave) cpu code */
 	ROM_LOAD( "tp-p.1", 0x0000, 0x2000, CRC(b4020fcc) SHA1(437a037adedd596d295a0b6e400d64dee6c4488e) )
 	ROM_LOAD( "tp-p.2", 0x2000, 0x2000, CRC(a69862d6) SHA1(7180cc26cd11d2daf453fcda8e6cc90851068bc4) )
 	ROM_LOAD( "tp-p.3", 0x4000, 0x2000, CRC(f1d86e00) SHA1(5c26f20f49e09a736cede4f276f5bdf76f932400) )
 	ROM_LOAD( "tp-p.4", 0x6000, 0x2000, CRC(0a1027bc) SHA1(2ebb53a1da53a9c3f0b99da084030c4d2b62a7b3) )
 
-	ROM_REGION( 0x10000,REGION_CPU3, 0 ) /* Z80 (sound) cpu code */
+	ROM_REGION( 0x10000,"sound", 0 ) /* Z80 (sound) cpu code */
 	ROM_LOAD( "tp-s.1", 0x0000, 0x2000, CRC(78964fcc) SHA1(a2c6119275d6291d82ac11dcffdaf2e8726e935a) )
 	ROM_LOAD( "tp-s.2", 0x2000, 0x2000, CRC(61232e29) SHA1(a9ef0fefb7250392ef51173b69a69c903ff91ee8) )
 
-	ROM_REGION( 0x10000,REGION_CPU4, 0 ) /* 64k for the custom CPU */
+	ROM_REGION( 0x10000,"nsc", 0 ) /* 64k for the custom CPU */
 	ROM_LOAD( "tp-g5.e1", 0xc000, 0x2000, CRC(9f375b27) SHA1(9666d1b20169d899176fbdf5954df41df06b4b82) )
 	ROM_LOAD( "tp-g6.d1", 0xe000, 0x2000, CRC(3ea127b8) SHA1(a5f83ee0eb871da81eeaf839499baf14b986c69e) )
 
-	ROM_REGION( 0xc000, REGION_USER1, 0 ) /* background data */
+	ROM_REGION( 0xc000, "user1", 0 ) /* background data */
 	ROM_LOAD( "tp-b.1", 0x0000, 0x2000, CRC(fda355e0) SHA1(3270c65a4ee5d01388727f38691f7fe38f541031) )
 	ROM_LOAD( "tp-b.2", 0x2000, 0x2000, CRC(cbe30149) SHA1(e66057286bea3026743f6de27a7e8dc8a709f8f7) )
 	ROM_LOAD( "tp-b.3", 0x4000, 0x2000, CRC(f5d118e7) SHA1(a899bef3accef8995c457e8142a0001eed033fae) )
@@ -1082,7 +1058,7 @@ ROM_START( tubep )
 	ROM_LOAD( "tp-b.5", 0x8000, 0x2000, CRC(4dabea43) SHA1(72b9df9a3665baf34fb1f7301c5b9dd2619ed206) )
 	ROM_LOAD( "tp-b.6", 0xa000, 0x2000, CRC(01952144) SHA1(d1074c79b51d3e2c152c9f3df6892027fe3a0e00) )
 
-	ROM_REGION( 0x18000,REGION_USER2, 0 )
+	ROM_REGION( 0x18000,"user2", 0 )
 	ROM_LOAD( "tp-c.1", 0x0000, 0x2000, CRC(ec002af2) SHA1(f9643c2ff01412d3da42b050bce4cf7f7d2e6f6a) )
 	ROM_LOAD( "tp-c.2", 0x2000, 0x2000, CRC(c44f7128) SHA1(e05c00a7094b3fbf7ac6ed6ed38e1b227d462b27) )
 	ROM_LOAD( "tp-c.3", 0x4000, 0x2000, CRC(4146b0c9) SHA1(cd3d620531660834530c64cdf1ef0659f9f6f437) )
@@ -1099,17 +1075,17 @@ ROM_START( tubep )
 	ROM_LOAD( "tp-g7.h2",  0x14000, 0x2000, CRC(105cb9e4) SHA1(b9d8ffe35c1f66aa401e5d8e415bf7c016ff53bb) )
 	ROM_LOAD( "tp-g8.i2",  0x16000, 0x2000, CRC(27e5e6c1) SHA1(f3896d0006351d165e36bafa4340175077b3d6ba) )
 
-	ROM_REGION( 0x1000, REGION_GFX1, 0 )
+	ROM_REGION( 0x1000, "gfx1", 0 )
 	ROM_LOAD( "tp-g3.c10", 0x0000, 0x1000, CRC(657a465d) SHA1(848217c3b736550586e8e9ba7a6e99e884094066) )	/* text characters */
 
-	ROM_REGION( 0x40,   REGION_PROMS, 0 ) /* color proms */
+	ROM_REGION( 0x40,   "proms", 0 ) /* color proms */
 	ROM_LOAD( "tp-2.c12", 0x0000, 0x0020, CRC(ac7e582f) SHA1(9d8f9eda7130b49b91d9c63bafa119b2a91eeda0) ) /* text and sprites palette */
 	ROM_LOAD( "tp-1.c13", 0x0020, 0x0020, CRC(cd0910d6) SHA1(1e6dae16115d5a03bbaf76c695327a06eb6da602) ) /* color control prom */
 ROM_END
 
 
 ROM_START( tubepb )
-	ROM_REGION( 0x10000,REGION_CPU1, 0 ) /* Z80 (master) cpu code */
+	ROM_REGION( 0x10000,"main", 0 ) /* Z80 (master) cpu code */
 	ROM_LOAD( "a15.bin", 0x0000, 0x1000, CRC(806370a8) SHA1(c1915fae15bd766ffbd3c47d65ade51d36117eb8) )
 	ROM_LOAD( "a16.bin", 0x1000, 0x1000, CRC(0917fb76) SHA1(1ce2680700d6ce28dfd202f238f1fc6e9c4a2758) )
 	ROM_LOAD( "a13.bin", 0x2000, 0x1000, CRC(6e4bb47e) SHA1(092eba1a90f43eb298ee9e4dc0f13d5411a14b4a) )
@@ -1119,7 +1095,7 @@ ROM_START( tubepb )
 	ROM_LOAD( "a9.bin",  0x6000, 0x1000, CRC(a20de3d1) SHA1(84f2417597dbaecace0ce72a1684345fb212fc3a) )
 	ROM_LOAD( "a10.bin", 0x7000, 0x1000, CRC(033ba70c) SHA1(de561c5db7cd493aee05e3513e48d52ed95bd510) )
 
-	ROM_REGION( 0x10000,REGION_CPU2, 0 ) /* Z80 (slave) cpu code */
+	ROM_REGION( 0x10000,"slave", 0 ) /* Z80 (slave) cpu code */
 	ROM_LOAD( "a1.bin",  0x0000, 0x1000, CRC(8a68523d) SHA1(268c659a2312e4d1a29e2064f55dfa07e57f6bca) )
 	ROM_LOAD( "a2.bin",  0x1000, 0x1000, CRC(d15a8645) SHA1(9970377ff49ac525f2ef21c36ded8e7447ed700c) )
 	ROM_LOAD( "a3.bin",  0x2000, 0x1000, CRC(7acf777c) SHA1(042b051de8fcc1295aca459f762619771438625e) )
@@ -1129,15 +1105,15 @@ ROM_START( tubepb )
 	ROM_LOAD( "a7.bin",  0x6000, 0x1000, CRC(417dd321) SHA1(aa0faa19eed1397e46a67e8793c5a27991ea9c1b) )
 	ROM_LOAD( "a8.bin",  0x7000, 0x1000, CRC(d26ab4c0) SHA1(8d92386e75114494d65df4cfebdbacd09fddb48e) )
 
-	ROM_REGION( 0x10000,REGION_CPU3, 0 ) /* Z80 (sound) cpu code */
+	ROM_REGION( 0x10000,"sound", 0 ) /* Z80 (sound) cpu code */
 	ROM_LOAD( "15.bin",  0x0000, 0x2000, CRC(78964fcc) SHA1(a2c6119275d6291d82ac11dcffdaf2e8726e935a) )
 	ROM_LOAD( "16.bin",  0x2000, 0x2000, CRC(61232e29) SHA1(a9ef0fefb7250392ef51173b69a69c903ff91ee8) )
 
-	ROM_REGION( 0x10000,REGION_CPU4, 0 ) /* 64k for the custom CPU */
+	ROM_REGION( 0x10000,"mcu", 0 ) /* 64k for the custom CPU */
 	ROM_LOAD( "5.bin",   0xc000, 0x2000, CRC(9f375b27) SHA1(9666d1b20169d899176fbdf5954df41df06b4b82) )
 	ROM_LOAD( "6.bin",   0xe000, 0x2000, CRC(46a273b5) SHA1(ff862c9337b3eeadee5a3d3f0837931a7a71393e) )
 
-	ROM_REGION( 0xc000, REGION_USER1, 0 ) /* background data */
+	ROM_REGION( 0xc000, "user1", 0 ) /* background data */
 	ROM_LOAD( "9.bin",   0x0000, 0x2000, CRC(fda355e0) SHA1(3270c65a4ee5d01388727f38691f7fe38f541031) )
 	ROM_LOAD( "10.bin",  0x2000, 0x2000, CRC(0ccb23b0) SHA1(71660a3476ed299684e5662058b8c40153d4a168) )
 	ROM_LOAD( "11.bin",  0x4000, 0x2000, CRC(f5d118e7) SHA1(a899bef3accef8995c457e8142a0001eed033fae) )
@@ -1145,7 +1121,7 @@ ROM_START( tubepb )
 	ROM_LOAD( "13.bin",  0x8000, 0x2000, CRC(4dabea43) SHA1(72b9df9a3665baf34fb1f7301c5b9dd2619ed206) )
 	ROM_LOAD( "14.bin",  0xa000, 0x2000, CRC(01952144) SHA1(d1074c79b51d3e2c152c9f3df6892027fe3a0e00) )
 
-	ROM_REGION( 0x18000,REGION_USER2, 0 )
+	ROM_REGION( 0x18000,"user2", 0 )
 	ROM_LOAD( "d1.bin",  0x0000, 0x1000, CRC(702348d7) SHA1(717e48d8c3529acb9a216b4e99df1599fb2e6b3b) )
 	ROM_LOAD( "d2.bin",  0x1000, 0x1000, CRC(47601e8b) SHA1(4e56fe72644a000648199e92b306365c100cca30) )
 	ROM_LOAD( "d3.bin",  0x2000, 0x1000, CRC(caad3ee2) SHA1(a99b8da36bf26a193d92fa807f168e60ed4bdce5) )
@@ -1170,46 +1146,46 @@ ROM_START( tubepb )
 	ROM_LOAD( "7.bin",   0x14000, 0x2000, CRC(105cb9e4) SHA1(b9d8ffe35c1f66aa401e5d8e415bf7c016ff53bb) )
 	ROM_LOAD( "8.bin",   0x16000, 0x2000, CRC(27e5e6c1) SHA1(f3896d0006351d165e36bafa4340175077b3d6ba) )
 
-	ROM_REGION( 0x1000, REGION_GFX1, 0 )
+	ROM_REGION( 0x1000, "gfx1", 0 )
 	ROM_LOAD( "3.bin",   0x0000, 0x1000, CRC(657a465d) SHA1(848217c3b736550586e8e9ba7a6e99e884094066) )	/* text characters */
 
-	ROM_REGION( 0x40,   REGION_PROMS, 0 ) /* color proms */
+	ROM_REGION( 0x40,   "proms", 0 ) /* color proms */
 	ROM_LOAD( "prom6331.b", 0x0000, 0x0020, CRC(ac7e582f) SHA1(9d8f9eda7130b49b91d9c63bafa119b2a91eeda0) ) /* text and sprites palette */
 	ROM_LOAD( "prom6331.a", 0x0020, 0x0020, CRC(cd0910d6) SHA1(1e6dae16115d5a03bbaf76c695327a06eb6da602) ) /* color control prom */
 ROM_END
 
 
 ROM_START( rjammer )
-	ROM_REGION( 0x10000,REGION_CPU1, 0 ) /* Z80 (master) cpu code */
+	ROM_REGION( 0x10000,"main", 0 ) /* Z80 (master) cpu code */
 	ROM_LOAD( "tp-p.1", 0x0000, 0x2000, CRC(93eeed67) SHA1(9ccfc49f42c6b451ff1c541d6487276f4bf9338e) )
 	ROM_LOAD( "tp-p.2", 0x2000, 0x2000, CRC(ed2830c4) SHA1(078046e88604617342d29f0f4a0473fe6d484b19) )
 	ROM_LOAD( "tp-p.3", 0x4000, 0x2000, CRC(e29f25e3) SHA1(21abf0e7c315fac15dd39355c16f9401c2cf4593) )
 	ROM_LOAD( "tp-p.4", 0x8000, 0x2000, CRC(6ed71fbc) SHA1(821506943b980077a9b4f309db095be7e952b13d) )
 	ROM_CONTINUE(       0x6000, 0x2000 )
 
-	ROM_REGION( 0x10000,REGION_CPU2, 0 ) /* Z80 (slave) cpu code */
+	ROM_REGION( 0x10000,"slave", 0 ) /* Z80 (slave) cpu code */
 	ROM_LOAD( "tp-p.8", 0x0000, 0x2000, CRC(388b9c66) SHA1(6d3e614736a7f06c26191699e8a8a13b239b259f) )
 	ROM_LOAD( "tp-p.7", 0x2000, 0x2000, CRC(595030bb) SHA1(00dd0b3af965a2768c71297ba2a358050bdb8ef7) )
 	ROM_LOAD( "tp-p.6", 0x4000, 0x2000, CRC(b5aa0f89) SHA1(d7e8b7e76fe6e5ef1d9bcad8469d56b81c9509ac) )
 	ROM_LOAD( "tp-p.5", 0x6000, 0x2000, CRC(56eae9ac) SHA1(e5cd75df0c38021b81de2abf049b12c10db4f3cb) )
 
-	ROM_REGION( 0x10000,REGION_CPU3, 0 ) /* Z80 (sound) cpu code */
+	ROM_REGION( 0x10000,"sound", 0 ) /* Z80 (sound) cpu code */
 	ROM_LOAD( "tp-b1.6d", 0x0000, 0x2000, CRC(b1c2525c) SHA1(7a184142e83982e33bc41cabae6fe804cec78748) )
 	ROM_LOAD( "tp-s3.4d", 0x2000, 0x2000, CRC(90c9d0b9) SHA1(8657ee93d7b67ba89848bf94e03b5c3bcace92c4) )
 	ROM_LOAD( "tp-s2.2d", 0x4000, 0x2000, CRC(444b6a1d) SHA1(1252b14d473d764a5326401aac782a1fa3419784) )
 	ROM_LOAD( "tp-s1.1d", 0x6000, 0x2000, CRC(391097cd) SHA1(d4b48a3f26044b131e65f74479bf1671ad677eb4) )
 
-	ROM_REGION( 0x10000,REGION_CPU4, 0 ) /* 64k for the custom CPU */
+	ROM_REGION( 0x10000,"nsc", 0 ) /* 64k for the custom CPU */
 	ROM_LOAD( "tp-g7.e1",  0xc000, 0x2000, CRC(9f375b27) SHA1(9666d1b20169d899176fbdf5954df41df06b4b82) )
 	ROM_LOAD( "tp-g8.d1",  0xe000, 0x2000, CRC(2e619fec) SHA1(d3d5fa708ca0097abf12d59ae41cb852278fe45d) )
 
-	ROM_REGION( 0x7000, REGION_USER1, 0 ) /* background data */
+	ROM_REGION( 0x7000, "user1", 0 ) /* background data */
 	ROM_LOAD( "tp-b3.13d", 0x0000, 0x1000, CRC(b80ef399) SHA1(75fa17e1bb39363e194737a32db2d92e0cae5e79) )
 	ROM_LOAD( "tp-b5.11b", 0x1000, 0x2000, CRC(0f260bfe) SHA1(975b7837f6c3c9d743903910fbdc3111c18a5955) )
 	ROM_LOAD( "tp-b2.11d", 0x3000, 0x2000, CRC(8cd2c917) SHA1(472aceaf4a1050b2513d56b2703e556ac1e2a61a) )
 	ROM_LOAD( "tp-b4.19c", 0x5000, 0x2000, CRC(6600f306) SHA1(2e25790839a465f5f8729964cfe27a587eb663f5) )
 
-	ROM_REGION( 0x18000,REGION_USER2, 0 )
+	ROM_REGION( 0x18000,"user2", 0 )
 	ROM_LOAD( "tp-c.8", 0x0000, 0x2000, CRC(9f31ecb5) SHA1(c4b979c7da096648d0c58b2c8a205e1622ee28e9) )
 	ROM_LOAD( "tp-c.7", 0x2000, 0x2000, CRC(cbf093f1) SHA1(128e01249165a87304eaf8003a9adf6f38d35d5e) )
 	ROM_LOAD( "tp-c.6", 0x4000, 0x2000, CRC(11f9752b) SHA1(11dcbbfe4e673e379afd67874b64b48cdafa00f5) )
@@ -1225,10 +1201,10 @@ ROM_START( rjammer )
 	ROM_LOAD( "tp-g6.h2",  0x14000, 0x2000, CRC(105cb9e4) SHA1(b9d8ffe35c1f66aa401e5d8e415bf7c016ff53bb) )
 	ROM_LOAD( "tp-g5.i2",  0x16000, 0x2000, CRC(27e5e6c1) SHA1(f3896d0006351d165e36bafa4340175077b3d6ba) )
 
-	ROM_REGION( 0x1000, REGION_GFX1, 0 )
+	ROM_REGION( 0x1000, "gfx1", 0 )
 	ROM_LOAD( "tp-g4.c10", 0x0000, 0x1000, CRC(99e72549) SHA1(2509265c2d84ac6144aecd77f1b3f0d16bdcb572) )	/* text characters */
 
-	ROM_REGION( 0x40,   REGION_PROMS, 0 ) /* color proms */
+	ROM_REGION( 0x40,   "proms", 0 ) /* color proms */
 	ROM_LOAD( "16b", 0x0000, 0x0020, CRC(9a12873a) SHA1(70f088b6eb5431e2ac6afcf15531eeb02a169442) ) /* text palette, sprites palette */
 	ROM_LOAD( "16a", 0x0020, 0x0020, CRC(90222a71) SHA1(c3fd49c8075b0af451f6d2a142a4c4a2e397ac08) ) /* background palette */
 ROM_END
