@@ -270,6 +270,8 @@ TODO:
 ***************************************************************************/
 
 #include "driver.h"
+#include "cpu/z80/z80.h"
+#include "cpu/m68000/m68000.h"
 #include "deprecat.h"
 #include "video/konamiic.h"
 #include "cpu/m6809/m6809.h"
@@ -366,17 +368,17 @@ static WRITE16_HANDLER( wecleman_protection_w )
 */
 static WRITE16_HANDLER( irqctrl_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
-		// logerror("CPU #0 - PC = %06X - $140005 <- %02X (old value: %02X)\n",activecpu_get_pc(), data&0xFF, old_data&0xFF);
+		// logerror("CPU #0 - PC = %06X - $140005 <- %02X (old value: %02X)\n",cpu_get_pc(space->cpu), data&0xFF, old_data&0xFF);
 
 		// Bit 0 : SUBINT
 		if ( (wecleman_irqctrl & 1) && (!(data & 1)) )	// 1->0 transition
-			cpunum_set_input_line(Machine, 1,4,HOLD_LINE);
+			cpu_set_input_line(space->machine->cpu[1],4,HOLD_LINE);
 
 		// Bit 1 : NSUBRST
-		if (data & 2)   cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, CLEAR_LINE  );
-		else                    cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, ASSERT_LINE );
+		if (data & 2)   cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, CLEAR_LINE  );
+		else                    cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, ASSERT_LINE );
 
 		// Bit 2 : SOUND-ON
 		// Bit 3 : SOUNDRST
@@ -400,18 +402,18 @@ static WRITE16_HANDLER( irqctrl_w )
 */
 static WRITE16_HANDLER( selected_ip_w )
 {
-	if (ACCESSING_LSB) wecleman_selected_ip = data & 0xff;	// latch the value
+	if (ACCESSING_BITS_0_7) wecleman_selected_ip = data & 0xff;	// latch the value
 }
 
 /* $140021.b - Return the previously selected input port's value */
 static READ16_HANDLER( selected_ip_r )
 {
 	switch ( (wecleman_selected_ip >> 5) & 3 )
-	{												// From WEC Le Mans Schems:
-		case 0:  return input_port_4_r(offset);		// Accel - Schems: Accelevr
-		case 1:  return ~0;							// ????? - Schems: Not Used
-		case 2:  return input_port_5_r(offset);		// Wheel - Schems: Handlevr
-		case 3:  return ~0;							// Table - Schems: Turnvr
+	{																	// From WEC Le Mans Schems:
+		case 0:  return input_port_read(space->machine, "ACCEL");		// Accel - Schems: Accelevr
+		case 1:  return ~0;												// ????? - Schems: Not Used
+		case 2:  return input_port_read(space->machine, "STEER");		// Wheel - Schems: Handlevr
+		case 3:  return ~0;												// Table - Schems: Turnvr
 
 		default: return ~0;
 	}
@@ -456,7 +458,7 @@ static WRITE16_HANDLER( blitter_w )
 	COMBINE_DATA(&blitter_regs[offset]);
 
 	/* do a blit if $80010.b has been written */
-	if ( (offset == 0x10/2) && (ACCESSING_MSB) )
+	if ( (offset == 0x10/2) && (ACCESSING_BITS_8_15) )
 	{
 		/* 80000.b = ?? usually 0 - other values: 02 ; 00 - ? logic function ? */
 		/* 80001.b = ?? usually 0 - other values: 3f ; 01 - ? height ? */
@@ -490,7 +492,7 @@ static WRITE16_HANDLER( blitter_w )
 			for ( ; size > 0 ; size--)
 			{
 				/* maybe slower than a memcpy but safer (and errors are logged) */
-				program_write_word(dest,program_read_word(src));
+				memory_write_word(space, dest, memory_read_word(space, src));
 				src += 2;
 				dest += 2;
 			}
@@ -503,23 +505,23 @@ static WRITE16_HANDLER( blitter_w )
 				int i, j, destptr;
 
 				/* Read offset of source from the list of blits */
-				i = src + program_read_word(list+2);
+				i = src + memory_read_word(space, list+2);
 				j = i + (size<<1);
 				destptr = dest;
 
 				for (; i<j; destptr+=2, i+=2)
-					program_write_word(destptr, program_read_word(i));
+					memory_write_word(space, destptr, memory_read_word(space, i));
 
 				destptr = dest + 14;
-				i = program_read_word(list) + spr_color_offs;
-				program_write_word(destptr, i);
+				i = memory_read_word(space, list) + spr_color_offs;
+				memory_write_word(space, destptr, i);
 
 				dest += 16;
 				list += 4;
 			}
 
 			/* hack for the blit to Sprites RAM - Sprite list end-marker */
-			program_write_word(dest,0xFFFF);
+			memory_write_word(space, dest, 0xFFFF);
 		}
 	}
 }
@@ -537,23 +539,23 @@ static ADDRESS_MAP_START( wecleman_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x040000, 0x043fff) AM_RAM	// RAM
 	AM_RANGE(0x060000, 0x060005) AM_WRITE(wecleman_protection_w) AM_BASE(&wecleman_protection_ram)
 	AM_RANGE(0x060006, 0x060007) AM_READ(wecleman_protection_r)	// MCU read
-	AM_RANGE(0x080000, 0x080011) AM_READWRITE(MRA16_RAM, blitter_w) AM_BASE(&blitter_regs)	// Blitter
-	AM_RANGE(0x100000, 0x103fff) AM_READWRITE(MRA16_RAM, wecleman_pageram_w) AM_BASE(&wecleman_pageram)	// Background Layers
-	AM_RANGE(0x108000, 0x108fff) AM_READWRITE(MRA16_RAM, wecleman_txtram_w) AM_BASE(&wecleman_txtram)	// Text Layer
-	AM_RANGE(0x110000, 0x110fff) AM_READWRITE(MRA16_RAM, wecleman_paletteram16_SSSSBBBBGGGGRRRR_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x080000, 0x080011) AM_RAM_WRITE(blitter_w) AM_BASE(&blitter_regs)	// Blitter
+	AM_RANGE(0x100000, 0x103fff) AM_RAM_WRITE(wecleman_pageram_w) AM_BASE(&wecleman_pageram)	// Background Layers
+	AM_RANGE(0x108000, 0x108fff) AM_RAM_WRITE(wecleman_txtram_w) AM_BASE(&wecleman_txtram)	// Text Layer
+	AM_RANGE(0x110000, 0x110fff) AM_RAM_WRITE(wecleman_paletteram16_SSSSBBBBGGGGRRRR_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x124000, 0x127fff) AM_RAM AM_SHARE(1)	// Shared with main CPU
 	AM_RANGE(0x130000, 0x130fff) AM_RAM AM_BASE(&spriteram16)	// Sprites
 	AM_RANGE(0x140000, 0x140001) AM_WRITE(wecleman_soundlatch_w)	// To sound CPU
 	AM_RANGE(0x140002, 0x140003) AM_WRITE(selected_ip_w)	// Selects accelerator / wheel / ..
 	AM_RANGE(0x140004, 0x140005) AM_WRITE(irqctrl_w)	// Main CPU controls the other CPUs
-	AM_RANGE(0x140006, 0x140007) AM_WRITE(MWA16_NOP)	// Watchdog reset
-	AM_RANGE(0x140010, 0x140011) AM_READ(input_port_0_word_r)	// Coins + brake + gear
-	AM_RANGE(0x140012, 0x140013) AM_READ(input_port_1_word_r)	// ??
-	AM_RANGE(0x140014, 0x140015) AM_READ(input_port_2_word_r)	// DSW
-	AM_RANGE(0x140016, 0x140017) AM_READ(input_port_3_word_r)	// DSW
-	AM_RANGE(0x140020, 0x140021) AM_WRITE(MWA16_RAM)	// Paired with writes to $140003
+	AM_RANGE(0x140006, 0x140007) AM_WRITE(SMH_NOP)	// Watchdog reset
+	AM_RANGE(0x140010, 0x140011) AM_READ_PORT("IN0")	// Coins + brake + gear
+	AM_RANGE(0x140012, 0x140013) AM_READ_PORT("IN1")	// ??
+	AM_RANGE(0x140014, 0x140015) AM_READ_PORT("DSWA")	// DSW 2
+	AM_RANGE(0x140016, 0x140017) AM_READ_PORT("DSWB")	// DSW 1
+	AM_RANGE(0x140020, 0x140021) AM_WRITE(SMH_RAM)	// Paired with writes to $140003
 	AM_RANGE(0x140020, 0x140021) AM_READ(selected_ip_r)	// Accelerator or Wheel or ..
-	AM_RANGE(0x140030, 0x140031) AM_WRITE(MWA16_NOP)	// toggles between 0 & 1 on hitting bumps and crashes (vibration?)
+	AM_RANGE(0x140030, 0x140031) AM_WRITE(SMH_NOP)	// toggles between 0 & 1 on hitting bumps and crashes (vibration?)
 ADDRESS_MAP_END
 
 
@@ -563,32 +565,32 @@ ADDRESS_MAP_END
 
 static READ16_HANDLER( hotchase_K051316_0_r )
 {
-	return K051316_0_r(offset) & 0xff;
+	return K051316_0_r(space, offset) & 0xff;
 }
 
 static READ16_HANDLER( hotchase_K051316_1_r )
 {
-	return K051316_1_r(offset) & 0xff;
+	return K051316_1_r(space, offset) & 0xff;
 }
 
 static WRITE16_HANDLER( hotchase_K051316_0_w )
 {
-	if (ACCESSING_LSB)      K051316_0_w(offset, data & 0xff);
+	if (ACCESSING_BITS_0_7)      K051316_0_w(space, offset, data & 0xff);
 }
 
 static WRITE16_HANDLER( hotchase_K051316_1_w )
 {
-	if (ACCESSING_LSB)      K051316_1_w(offset, data & 0xff);
+	if (ACCESSING_BITS_0_7)      K051316_1_w(space, offset, data & 0xff);
 }
 
 static WRITE16_HANDLER( hotchase_K051316_ctrl_0_w )
 {
-	if (ACCESSING_LSB)      K051316_ctrl_0_w(offset, data & 0xff);
+	if (ACCESSING_BITS_0_7)      K051316_ctrl_0_w(space, offset, data & 0xff);
 }
 
 static WRITE16_HANDLER( hotchase_K051316_ctrl_1_w )
 {
-	if (ACCESSING_LSB)      K051316_ctrl_1_w(offset, data & 0xff);
+	if (ACCESSING_BITS_0_7)      K051316_ctrl_1_w(space, offset, data & 0xff);
 }
 
 static WRITE16_HANDLER( hotchase_soundlatch_w );
@@ -596,26 +598,26 @@ static WRITE16_HANDLER( hotchase_soundlatch_w );
 static ADDRESS_MAP_START( hotchase_map, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x000000, 0x03ffff) AM_ROM
 	AM_RANGE(0x040000, 0x063fff) AM_RAM										// RAM (weird size!?)
-	AM_RANGE(0x080000, 0x080011) AM_READWRITE(MRA16_RAM, blitter_w) AM_BASE(&blitter_regs)	// Blitter
+	AM_RANGE(0x080000, 0x080011) AM_RAM_WRITE(blitter_w) AM_BASE(&blitter_regs)	// Blitter
 	AM_RANGE(0x100000, 0x100fff) AM_READWRITE(hotchase_K051316_0_r, hotchase_K051316_0_w)	// Background
 	AM_RANGE(0x101000, 0x10101f) AM_WRITE(hotchase_K051316_ctrl_0_w)	// Background Ctrl
 	AM_RANGE(0x102000, 0x102fff) AM_READWRITE(hotchase_K051316_1_r, hotchase_K051316_1_w)	// Foreground
 	AM_RANGE(0x103000, 0x10301f) AM_WRITE(hotchase_K051316_ctrl_1_w)	// Foreground Ctrl
-	AM_RANGE(0x110000, 0x111fff) AM_READWRITE(MRA16_RAM, hotchase_paletteram16_SBGRBBBBGGGGRRRR_word_w) AM_BASE(&paletteram16)
+	AM_RANGE(0x110000, 0x111fff) AM_RAM_WRITE(hotchase_paletteram16_SBGRBBBBGGGGRRRR_word_w) AM_BASE(&paletteram16)
 	AM_RANGE(0x120000, 0x123fff) AM_RAM AM_SHARE(1)					// Shared with sub CPU
 	AM_RANGE(0x130000, 0x130fff) AM_RAM AM_BASE(&spriteram16)	// Sprites
 	// Input Ports:
 	AM_RANGE(0x140000, 0x140001) AM_WRITE(hotchase_soundlatch_w)	// To sound CPU
 	AM_RANGE(0x140002, 0x140003) AM_WRITE(selected_ip_w)	// Selects accelerator / wheel /
 	AM_RANGE(0x140004, 0x140005) AM_WRITE(irqctrl_w)	// Main CPU controls the other CPUs
-	AM_RANGE(0x140006, 0x140007) AM_READ(MRA16_NOP)	// Watchdog reset
-	AM_RANGE(0x140010, 0x140011) AM_READ(input_port_0_word_r)	// Coins + brake + gear
-	AM_RANGE(0x140012, 0x140013) AM_READ(input_port_1_word_r)	// ?? bit 4 from sound cpu
-	AM_RANGE(0x140014, 0x140015) AM_READ(input_port_2_word_r)	// DSW 2
-	AM_RANGE(0x140016, 0x140017) AM_READ(input_port_3_word_r)	// DSW 1
-	AM_RANGE(0x140020, 0x140021) AM_READWRITE(selected_ip_r, MWA16_NOP)	// Paired with writes to $140003
-	AM_RANGE(0x140022, 0x140023) AM_READ(MRA16_NOP)	// ??
-	AM_RANGE(0x140030, 0x140031) AM_WRITE(MWA16_NOP)	// signal to cabinet vibration motors?
+	AM_RANGE(0x140006, 0x140007) AM_READ(SMH_NOP)	// Watchdog reset
+	AM_RANGE(0x140010, 0x140011) AM_READ_PORT("IN0")	// Coins + brake + gear
+	AM_RANGE(0x140012, 0x140013) AM_READ_PORT("IN1")	// ?? bit 4 from sound cpu
+	AM_RANGE(0x140014, 0x140015) AM_READ_PORT("DSW2")	// DSW 2
+	AM_RANGE(0x140016, 0x140017) AM_READ_PORT("DSW1")	// DSW 1
+	AM_RANGE(0x140020, 0x140021) AM_READWRITE(selected_ip_r, SMH_NOP)	// Paired with writes to $140003
+	AM_RANGE(0x140022, 0x140023) AM_READ(SMH_NOP)	// ??
+	AM_RANGE(0x140030, 0x140031) AM_WRITE(SMH_NOP)	// signal to cabinet vibration motors?
 ADDRESS_MAP_END
 
 
@@ -649,10 +651,10 @@ ADDRESS_MAP_END
 /* 140001.b */
 WRITE16_HANDLER( wecleman_soundlatch_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
-		soundlatch_w(0,data & 0xFF);
-		cpunum_set_input_line(Machine, 2,0, HOLD_LINE);
+		soundlatch_w(space,0,data & 0xFF);
+		cpu_set_input_line(space->machine->cpu[2],0, HOLD_LINE);
 	}
 }
 
@@ -685,27 +687,20 @@ static WRITE8_HANDLER( multiply_w )
 
 static WRITE8_HANDLER( wecleman_K00723216_bank_w )
 {
-	K007232_set_bank( 0, 0, ~data&1 );	//* (wecleman062gre)
+	k007232_set_bank( 0, 0, ~data&1 );	//* (wecleman062gre)
 }
 
-static ADDRESS_MAP_START( wecleman_sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)	// ROM
-	AM_RANGE(0x8000, 0x83ff) AM_READ(MRA8_RAM)	// RAM
+static ADDRESS_MAP_START( wecleman_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_ROM
+	AM_RANGE(0x8000, 0x83ff) AM_RAM
+	AM_RANGE(0x8500, 0x8500) AM_WRITE(SMH_NOP)	// incresed with speed (global volume)?
 	AM_RANGE(0x9000, 0x9000) AM_READ(multiply_r)	// Protection
-	AM_RANGE(0xa000, 0xa000) AM_READ(soundlatch_r)	// From main CPU
-	AM_RANGE(0xb000, 0xb00d) AM_READ(K007232_read_port_0_r)	// K007232 (Reading offset 5/b triggers the sample)
-	AM_RANGE(0xc001, 0xc001) AM_READ(YM2151_status_port_0_r)	// YM2151
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( wecleman_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)	// ROM
-	AM_RANGE(0x8000, 0x83ff) AM_WRITE(MWA8_RAM)	// RAM
-	AM_RANGE(0x8500, 0x8500) AM_WRITE(MWA8_NOP)	// incresed with speed (global volume)?
 	AM_RANGE(0x9000, 0x9001) AM_WRITE(multiply_w)	// Protection
-	AM_RANGE(0x9006, 0x9006) AM_WRITE(MWA8_NOP)	// ?
-	AM_RANGE(0xb000, 0xb00d) AM_WRITE(K007232_write_port_0_w)	// K007232
-	AM_RANGE(0xc000, 0xc000) AM_WRITE(YM2151_register_port_0_w)	// YM2151
-	AM_RANGE(0xc001, 0xc001) AM_WRITE(YM2151_data_port_0_w)
+	AM_RANGE(0x9006, 0x9006) AM_WRITE(SMH_NOP)	// ?
+	AM_RANGE(0xa000, 0xa000) AM_READ(soundlatch_r)	// From main CPU
+	AM_RANGE(0xb000, 0xb00d) AM_READWRITE(k007232_read_port_0_r, k007232_write_port_0_w)	// K007232 (Reading offset 5/b triggers the sample)
+	AM_RANGE(0xc000, 0xc000) AM_WRITE(ym2151_register_port_0_w)	// YM2151
+	AM_RANGE(0xc001, 0xc001) AM_READWRITE(ym2151_status_port_0_r, ym2151_data_port_0_w)
 	AM_RANGE(0xf000, 0xf000) AM_WRITE(wecleman_K00723216_bank_w)	// Samples banking
 ADDRESS_MAP_END
 
@@ -717,28 +712,13 @@ ADDRESS_MAP_END
 /* 140001.b */
 static WRITE16_HANDLER( hotchase_soundlatch_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
-		soundlatch_w(0,data & 0xFF);
-		cpunum_set_input_line(Machine, 2,M6809_IRQ_LINE, HOLD_LINE);
+		soundlatch_w(space,0,data & 0xFF);
+		cpu_set_input_line(space->machine->cpu[2],M6809_IRQ_LINE, HOLD_LINE);
 	}
 }
 
-static const struct K007232_interface hotchase_k007232_interface_1 =
-{
-	REGION_SOUND1
-};
-
-static const struct K007232_interface hotchase_k007232_interface_2 =
-{
-	REGION_SOUND2
-};
-
-static const struct K007232_interface hotchase_k007232_interface_3 =
-{
-	REGION_SOUND3
-};
-
 static WRITE8_HANDLER( hotchase_sound_control_w )
 {
 	int reg[8];
@@ -758,7 +738,7 @@ static WRITE8_HANDLER( hotchase_sound_control_w )
                 ++------ chip select ( 0:chip 1, 1:chip2, 2:chip3)
                 data&0x0f left volume  (data>>4)&0x0f right volume
             */
-		  K007232_set_volume( offset>>1, offset&1,  (data&0x0f) * 0x08, (data>>4) * 0x08 );
+		  k007232_set_volume( offset>>1, offset&1,  (data&0x0f) * 0x08, (data>>4) * 0x08 );
 		  break;
 
 		case 0x06:	/* Bankswitch for chips 0 & 1 */
@@ -770,8 +750,8 @@ static WRITE8_HANDLER( hotchase_sound_control_w )
 			// bit 6: chip 2 - ch0 ?
 			// bit 7: chip 2 - ch1 ?
 
-			K007232_set_bank( 0, bank0_a, bank0_b );
-			K007232_set_bank( 1, bank1_a, bank1_b );
+			k007232_set_bank( 0, bank0_a, bank0_b );
+			k007232_set_bank( 1, bank1_a, bank1_b );
 		}
 		break;
 
@@ -780,7 +760,7 @@ static WRITE8_HANDLER( hotchase_sound_control_w )
 			int bank2_a = (data >> 0) & 7;
 			int bank2_b = (data >> 3) & 7;
 
-			K007232_set_bank( 2, bank2_a, bank2_b );
+			k007232_set_bank( 2, bank2_a, bank2_b );
 		}
 		break;
 	}
@@ -788,39 +768,31 @@ static WRITE8_HANDLER( hotchase_sound_control_w )
 
 /* Read and write handlers for one K007232 chip:
    even and odd register are mapped swapped */
-#define HOTCHASE_K007232_RW(_chip_) \
-static READ8_HANDLER( hotchase_K007232_##_chip_##_r ) \
+#define HOTCHASE_k007232_RW(_chip_) \
+static READ8_HANDLER( hotchase_k007232_##_chip_##_r ) \
 { \
-	return K007232_read_port_##_chip_##_r(offset ^ 1); \
+	return k007232_read_port_##_chip_##_r(space, offset ^ 1); \
 } \
-static WRITE8_HANDLER( hotchase_K007232_##_chip_##_w ) \
+static WRITE8_HANDLER( hotchase_k007232_##_chip_##_w ) \
 { \
-	K007232_write_port_##_chip_##_w(offset ^ 1, data); \
+	k007232_write_port_##_chip_##_w(space, offset ^ 1, data); \
 } \
 
 /* 3 x K007232 */
-HOTCHASE_K007232_RW(0)
-HOTCHASE_K007232_RW(1)
-HOTCHASE_K007232_RW(2)
+HOTCHASE_k007232_RW(0)
+HOTCHASE_k007232_RW(1)
+HOTCHASE_k007232_RW(2)
 
-static ADDRESS_MAP_START( hotchase_sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_READ(MRA8_RAM)	// RAM
-	AM_RANGE(0x1000, 0x100d) AM_READ(hotchase_K007232_0_r)	// 3 x  K007232
-	AM_RANGE(0x2000, 0x200d) AM_READ(hotchase_K007232_1_r)
-	AM_RANGE(0x3000, 0x300d) AM_READ(hotchase_K007232_2_r)
-	AM_RANGE(0x6000, 0x6000) AM_READ(soundlatch_r)	// From main CPU (Read on IRQ)
-	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_ROM)	// ROM
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( hotchase_sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_WRITE(MWA8_RAM)	// RAM
-	AM_RANGE(0x1000, 0x100d) AM_WRITE(hotchase_K007232_0_w)	// 3 x K007232
-	AM_RANGE(0x2000, 0x200d) AM_WRITE(hotchase_K007232_1_w)
-	AM_RANGE(0x3000, 0x300d) AM_WRITE(hotchase_K007232_2_w)
+static ADDRESS_MAP_START( hotchase_sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x07ff) AM_RAM
+	AM_RANGE(0x1000, 0x100d) AM_READWRITE(hotchase_k007232_0_r, hotchase_k007232_0_w)	// 3 x K007232
+	AM_RANGE(0x2000, 0x200d) AM_READWRITE(hotchase_k007232_1_r, hotchase_k007232_1_w)
+	AM_RANGE(0x3000, 0x300d) AM_READWRITE(hotchase_k007232_2_r, hotchase_k007232_2_w)
 	AM_RANGE(0x4000, 0x4007) AM_WRITE(hotchase_sound_control_w)	// Sound volume, banking, etc.
-	AM_RANGE(0x5000, 0x5000) AM_WRITE(MWA8_NOP)	// ? (written with 0 on IRQ, 1 on FIRQ)
-	AM_RANGE(0x7000, 0x7000) AM_WRITE(MWA8_NOP)	// Command acknowledge ?
-	AM_RANGE(0x8000, 0xffff) AM_WRITE(MWA8_ROM)	// ROM
+	AM_RANGE(0x5000, 0x5000) AM_WRITE(SMH_NOP)	// ? (written with 0 on IRQ, 1 on FIRQ)
+	AM_RANGE(0x6000, 0x6000) AM_READ(soundlatch_r)	// From main CPU (Read on IRQ)
+	AM_RANGE(0x7000, 0x7000) AM_WRITE(SMH_NOP)	// Command acknowledge ?
+	AM_RANGE(0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
 
@@ -829,24 +801,24 @@ ADDRESS_MAP_END
 ***************************************************************************/
 
 static INPUT_PORTS_START( wecleman )
-	PORT_START	/* IN0 - Controls and Coins - $140011.b */
+	PORT_START("IN0")	/* IN0 - Controls and Coins - $140011.b */
 	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_COIN2 )
 	PORT_SERVICE_NO_TOGGLE( 0x04, IP_ACTIVE_HIGH )
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_SERVICE1 )
 	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_START1 )
-	PORT_BIT(0x20, IP_ACTIVE_HIGH, IPT_BUTTON3 ) PORT_NAME("Shift") PORT_TOGGLE
-	PORT_BIT(0x40, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_NAME("Brake")
+	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_BUTTON3 ) PORT_NAME("Shift") PORT_TOGGLE
+	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_BUTTON2 ) PORT_NAME("Brake")
 	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )
 
-	PORT_START	/* IN1 - Motor? - $140013.b */
+	PORT_START("IN1")	/* IN1 - Motor? - $140013.b */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_SERVICE2 )	// right sw
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SERVICE3 )	// left sw
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE4 )	// thermo
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_SPECIAL )	// from sound cpu ?
 	PORT_BIT( 0xf0, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	/* IN2 - DSW A (Coinage) - $140015.b */
+	PORT_START("DSWA")	/* IN2 - DSW A (Coinage) - $140015.b */
 	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( 4C_1C ) )
 	PORT_DIPSETTING(    0x05, DEF_STR( 3C_1C ) )
@@ -881,7 +853,7 @@ static INPUT_PORTS_START( wecleman )
 	PORT_DIPSETTING(    0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(    0x90, DEF_STR( 1C_7C ) )
 
-	PORT_START	/* IN3 - DSW B (options) - $140017.b */
+	PORT_START("DSWB")	/* IN3 - DSW B (options) - $140017.b */
 	PORT_DIPNAME( 0x01, 0x01, "Speed Unit" )
 	PORT_DIPSETTING(    0x01, "km/h" )
 	PORT_DIPSETTING(    0x00, "mph" )
@@ -906,10 +878,10 @@ static INPUT_PORTS_START( wecleman )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START	/* IN4 - Accelerator - $140021.b (0) */
+	PORT_START("ACCEL")	/* IN4 - Accelerator - $140021.b (0) */
 	PORT_BIT( 0xff, 0, IPT_PEDAL ) PORT_MINMAX(0,0x80) PORT_SENSITIVITY(30) PORT_KEYDELTA(10)
 
-	PORT_START	/* IN5 - Steering Wheel - $140021.b (2) */
+	PORT_START("STEER")	/* IN5 - Steering Wheel - $140021.b (2) */
 	PORT_BIT( 0xff, 0x80, IPT_PADDLE ) PORT_SENSITIVITY(50) PORT_KEYDELTA(5)
 INPUT_PORTS_END
 
@@ -919,24 +891,24 @@ INPUT_PORTS_END
 ***************************************************************************/
 
 static INPUT_PORTS_START( hotchase )
-	PORT_START	/* IN0 - Controls and Coins - $140011.b */
+	PORT_START("IN0")	/* IN0 - Controls and Coins - $140011.b */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_SERVICE_NO_TOGGLE( 0x04, IP_ACTIVE_LOW )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_SERVICE1 )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START1 )
-	PORT_BIT(0x20, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_NAME("Shift") PORT_TOGGLE
-	PORT_BIT(0x40, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_NAME("Brake")
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON3 ) PORT_NAME("Shift") PORT_TOGGLE
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_NAME("Brake")
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	/* IN1 - Motor? - $140013.b */
+	PORT_START("IN1")	/* IN1 - Motor? - $140013.b */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_SERVICE2 )	// right sw
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_SERVICE3 )	// left sw
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE4 )	// thermo
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_SPECIAL )	// from sound cpu ?
 	PORT_BIT( 0xf0, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START	/* IN2 - DSW 2 (options) - $140015.b */
+	PORT_START("DSW2")	/* IN2 - DSW 2 (options) - $140015.b */
 	PORT_DIPNAME( 0x01, 0x01, "Speed Unit" )
 	PORT_DIPSETTING(    0x01, "KM" )
 	PORT_DIPSETTING(    0x00, "M.P.H." )
@@ -962,7 +934,7 @@ static INPUT_PORTS_START( hotchase )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START	/* IN3 - DSW 1 (Coinage) - $140017.b */
+	PORT_START("DSW1")	/* IN3 - DSW 1 (Coinage) - $140017.b */
 	PORT_DIPNAME( 0x0f, 0x0f, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( 5C_1C ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( 4C_1C ) )
@@ -997,10 +969,10 @@ static INPUT_PORTS_START( hotchase )
 	PORT_DIPSETTING(    0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0x00, "1 Coin/99 Credits" )
 
-	PORT_START	/* IN4 - Accelerator - $140021.b (0) */
+	PORT_START("ACCEL")	/* IN4 - Accelerator - $140021.b (0) */
 	PORT_BIT( 0xff, 0, IPT_PEDAL ) PORT_MINMAX(0,0x80) PORT_SENSITIVITY(30) PORT_KEYDELTA(10)
 
-	PORT_START	/* IN5 - Steering Wheel - $140021.b (2) */
+	PORT_START("STEER")	/* IN5 - Steering Wheel - $140021.b (2) */
 	PORT_BIT( 0xff, 0x80, IPT_PADDLE ) PORT_SENSITIVITY(50) PORT_KEYDELTA(5)
 INPUT_PORTS_END
 
@@ -1048,9 +1020,9 @@ static const gfx_layout wecleman_road_layout =
 };
 
 static GFXDECODE_START( wecleman )
-	// REGION_GFX1 holds sprite, which are not decoded here
-	GFXDECODE_ENTRY( REGION_GFX2, 0, wecleman_bg_layout,   0, 2048/8 )	// [0] bg + fg + txt
-	GFXDECODE_ENTRY( REGION_GFX3, 0, wecleman_road_layout, 0, 2048/8 )	// [1] road
+	// "gfx1" holds sprite, which are not decoded here
+	GFXDECODE_ENTRY( "gfx2", 0, wecleman_bg_layout,   0, 2048/8 )	// [0] bg + fg + txt
+	GFXDECODE_ENTRY( "gfx3", 0, wecleman_road_layout, 0, 2048/8 )	// [1] road
 GFXDECODE_END
 
 
@@ -1082,9 +1054,9 @@ static const gfx_layout hotchase_road_layout =
 };
 
 static GFXDECODE_START( hotchase )
-	// REGION_GFX1 holds sprite, which are not decoded here
-	// REGION_GFX2 and 3 are for the 051316
-	GFXDECODE_ENTRY( REGION_GFX4, 0, hotchase_road_layout, 0x70*16, 16 )	// road
+	// "gfx1" holds sprite, which are not decoded here
+	// "gfx2" and 3 are for the 051316
+	GFXDECODE_ENTRY( "gfx4", 0, hotchase_road_layout, 0x70*16, 16 )	// road
 GFXDECODE_END
 
 
@@ -1094,48 +1066,43 @@ GFXDECODE_END
 
 static INTERRUPT_GEN( wecleman_interrupt )
 {
-	if (cpu_getiloops() == 0)
-		cpunum_set_input_line(machine, 0, 4, HOLD_LINE);	/* once */
+	if (cpu_getiloops(device) == 0)
+		cpu_set_input_line(device, 4, HOLD_LINE);	/* once */
 	else
-		cpunum_set_input_line(machine, 0, 5, HOLD_LINE);	/* to read input ports */
+		cpu_set_input_line(device, 5, HOLD_LINE);	/* to read input ports */
 }
 
-static const struct K007232_interface wecleman_k007232_interface =
-{
-	REGION_SOUND1	/* but the 2 channels use different ROMs !*/
-};
-
 static MACHINE_RESET( wecleman )
 {
-	K007232_set_bank( 0, 0, 1 );
+	k007232_set_bank( 0, 0, 1 );
 }
 
 static MACHINE_DRIVER_START( wecleman )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000, 10000000)	/* Schems show 10MHz */
+	MDRV_CPU_ADD("main", M68000, 10000000)	/* Schems show 10MHz */
 	MDRV_CPU_PROGRAM_MAP(wecleman_map,0)
-	MDRV_CPU_VBLANK_INT(wecleman_interrupt,5 + 1)	/* in order to read the inputs once per frame */
+	MDRV_CPU_VBLANK_INT_HACK(wecleman_interrupt,5 + 1)	/* in order to read the inputs once per frame */
 
-	MDRV_CPU_ADD(M68000, 10000000)	/* Schems show 10MHz */
+	MDRV_CPU_ADD("sub", M68000, 10000000)	/* Schems show 10MHz */
 	MDRV_CPU_PROGRAM_MAP(wecleman_sub_map,0)
 
 	/* Schems: can be reset, no nmi, soundlatch, 3.58MHz */
-	MDRV_CPU_ADD(Z80, 3579545)
-	/* audio CPU */
-	MDRV_CPU_PROGRAM_MAP(wecleman_sound_readmem,wecleman_sound_writemem)
+	MDRV_CPU_ADD("audio", Z80, 3579545)
+	MDRV_CPU_PROGRAM_MAP(wecleman_sound_map,0)
 
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(100)
+	MDRV_QUANTUM_TIME(HZ(6000))
 
 	MDRV_MACHINE_RESET(wecleman)
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
-	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB15)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
+	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_RGB32)
 	MDRV_SCREEN_SIZE(320 +16, 224 +16)
 	MDRV_SCREEN_VISIBLE_AREA(0 +8, 320-1 +8, 0 +8, 224-1 +8)
+
 	MDRV_GFXDECODE(wecleman)
 
 	MDRV_PALETTE_LENGTH(2048)
@@ -1146,12 +1113,11 @@ static MACHINE_DRIVER_START( wecleman )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM2151, 3579545)
+	MDRV_SOUND_ADD("ym", YM2151, 3579545)
 	MDRV_SOUND_ROUTE(0, "mono", 0.85)
 	MDRV_SOUND_ROUTE(1, "mono", 0.85)
 
-	MDRV_SOUND_ADD(K007232, 3579545)
-	MDRV_SOUND_CONFIG(wecleman_k007232_interface)
+	MDRV_SOUND_ADD("konami", K007232, 3579545)
 	MDRV_SOUND_ROUTE(0, "mono", 0.20)
 	MDRV_SOUND_ROUTE(1, "mono", 0.20)
 MACHINE_DRIVER_END
@@ -1163,34 +1129,35 @@ MACHINE_DRIVER_END
 
 static INTERRUPT_GEN( hotchase_sound_timer )
 {
-	cpunum_set_input_line(machine, 2, M6809_FIRQ_LINE, PULSE_LINE );
+	generic_pulse_irq_line(device, M6809_FIRQ_LINE);
 }
 
 static MACHINE_DRIVER_START( hotchase )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M68000, 10000000)	/* 10 MHz - PCB is drawn in one set's readme */
+	MDRV_CPU_ADD("main", M68000, 10000000)	/* 10 MHz - PCB is drawn in one set's readme */
 	MDRV_CPU_PROGRAM_MAP(hotchase_map,0)
-	MDRV_CPU_VBLANK_INT(irq4_line_hold,1)
+	MDRV_CPU_VBLANK_INT("main", irq4_line_hold)
 
-	MDRV_CPU_ADD(M68000, 10000000)	/* 10 MHz - PCB is drawn in one set's readme */
+	MDRV_CPU_ADD("sub", M68000, 10000000)	/* 10 MHz - PCB is drawn in one set's readme */
 	MDRV_CPU_PROGRAM_MAP(hotchase_sub_map,0)
 
-	MDRV_CPU_ADD(M6809, 3579545 / 2)
-	/* audio CPU */	/* 3.579/2 MHz - PCB is drawn in one set's readme */
-	MDRV_CPU_PROGRAM_MAP(hotchase_sound_readmem,hotchase_sound_writemem)
+	MDRV_CPU_ADD("audio", M6809, 3579545 / 2)	/* 3.579/2 MHz - PCB is drawn in one set's readme */
+	MDRV_CPU_PROGRAM_MAP(hotchase_sound_map,0)
 	MDRV_CPU_PERIODIC_INT( hotchase_sound_timer, 496 )
 
 	/* Amuse: every 2 ms */
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(100)
+
+	MDRV_QUANTUM_TIME(HZ(6000))
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(320, 224)
 	MDRV_SCREEN_VISIBLE_AREA(0, 320-1, 0, 224-1)
+
 	MDRV_GFXDECODE(hotchase)
 	MDRV_PALETTE_LENGTH(2048*2)
 
@@ -1200,18 +1167,15 @@ static MACHINE_DRIVER_START( hotchase )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(K007232, 3579545)
-	MDRV_SOUND_CONFIG(hotchase_k007232_interface_1)
+	MDRV_SOUND_ADD("konami1", K007232, 3579545)
 	MDRV_SOUND_ROUTE(0, "mono", 0.20)
 	MDRV_SOUND_ROUTE(1, "mono", 0.20)
 
-	MDRV_SOUND_ADD(K007232, 3579545)
-	MDRV_SOUND_CONFIG(hotchase_k007232_interface_2)
+	MDRV_SOUND_ADD("konami2", K007232, 3579545)
 	MDRV_SOUND_ROUTE(0, "mono", 0.20)
 	MDRV_SOUND_ROUTE(1, "mono", 0.20)
 
-	MDRV_SOUND_ADD(K007232, 3579545)
-	MDRV_SOUND_CONFIG(hotchase_k007232_interface_3)
+	MDRV_SOUND_ADD("konami3", K007232, 3579545)
 	MDRV_SOUND_ROUTE(0, "mono", 0.20)
 	MDRV_SOUND_ROUTE(1, "mono", 0.20)
 MACHINE_DRIVER_END
@@ -1223,20 +1187,20 @@ MACHINE_DRIVER_END
 
 ROM_START( wecleman )
 
-	ROM_REGION( 0x40000, REGION_CPU1, 0 )	/* Main CPU Code */
+	ROM_REGION( 0x40000, "main", 0 )	/* Main CPU Code */
 	ROM_LOAD16_BYTE( "602f08.17h", 0x00000, 0x10000, CRC(493b79d3) SHA1(9625e3b65c211d5081d8ed8977de287eff100842) )
 	ROM_LOAD16_BYTE( "602f11.23h", 0x00001, 0x10000, CRC(6bb4f1fa) SHA1(2cfb7885b42b49dab9892e8dfd54914b64eeab06) )
 	ROM_LOAD16_BYTE( "602a09.18h", 0x20000, 0x10000, CRC(8a9d756f) SHA1(12605e86ce29e6300b5400720baac7b0293d9e66) )
 	ROM_LOAD16_BYTE( "602a10.22h", 0x20001, 0x10000, CRC(569f5001) SHA1(ec2dd331a279083cf847fbbe71c017038a1d562a) )
 
-	ROM_REGION( 0x10000, REGION_CPU2, 0 )	/* Sub CPU Code */
+	ROM_REGION( 0x10000, "sub", 0 )	/* Sub CPU Code */
 	ROM_LOAD16_BYTE( "602a06.18a", 0x00000, 0x08000, CRC(e12c0d11) SHA1(991afd48bf1b2c303b975ce80c754e5972c39111) )
 	ROM_LOAD16_BYTE( "602a07.20a", 0x00001, 0x08000, CRC(47968e51) SHA1(9b01b2c6a14dd80327a8f66a7f1994471a4bc38e) )
 
-	ROM_REGION( 0x10000, REGION_CPU3, 0 )	/* Sound CPU Code */
+	ROM_REGION( 0x10000, "audio", 0 )	/* Sound CPU Code */
 	ROM_LOAD( "602a01.6d",  0x00000, 0x08000, CRC(deafe5f1) SHA1(4cfbe2841233b1222c22160af7287b7a7821c3a0) )
 
-	ROM_REGION( 0x200000 * 2, REGION_GFX1, 0 )	/* x2, do not dispose, zooming sprites */
+	ROM_REGION( 0x200000 * 2, "gfx1", 0 )	/* x2, do not dispose, zooming sprites */
 	ROM_LOAD( "602a25.12e", 0x000000, 0x20000, CRC(0eacf1f9) SHA1(b4dcd457e68175ffee3da4aff23a241fe33eb500) )
 	ROM_LOAD( "602a26.14e", 0x020000, 0x20000, CRC(2182edaf) SHA1(5ae4223a76b3c0be8f66458707f2e6f63fba0b13) )
 	ROM_LOAD( "602a27.15e", 0x040000, 0x20000, CRC(b22f08e9) SHA1(1ba99bc4e00e206507e9bfafc989208d6ae6f8a3) )
@@ -1254,31 +1218,31 @@ ROM_START( wecleman )
 	ROM_LOAD( "602a15.9c",  0x1c0000, 0x20000, CRC(0d493c9f) SHA1(02690a1963cadd469bd67cb362384923916900a1) )
 	ROM_LOAD( "602a16.10c", 0x1e0000, 0x20000, CRC(b08770b3) SHA1(41871e9261d08fd372b7deb72d939973fb694b54) )
 
-	ROM_REGION( 0x18000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x18000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "602a31.26g", 0x000000, 0x08000, CRC(01fa40dd) SHA1(2b8aa97f5116f39ae6a8e46f109853d70e370884) )	// layers
 	ROM_LOAD( "602a30.24g", 0x008000, 0x08000, CRC(be5c4138) SHA1(7aee2ee17ef3e37399a60d9b019cfa733acbf07b) )
 	ROM_LOAD( "602a29.23g", 0x010000, 0x08000, CRC(f1a8d33e) SHA1(ed6531f2fd4ad6835a879e9a5600387d8cad6d17) )
 
-	ROM_REGION( 0x0c000, REGION_GFX3, ROMREGION_DISPOSE )	/* road */
+	ROM_REGION( 0x0c000, "gfx3", ROMREGION_DISPOSE )	/* road */
 	ROM_LOAD( "602a04.11e", 0x000000, 0x08000, CRC(ade9f359) SHA1(58db6be6217ed697827015e50e99e58602042a4c) )
 	ROM_LOAD( "602a05.13e", 0x008000, 0x04000, CRC(f22b7f2b) SHA1(857389c57552c4e2237cb599f4c68c381430475e) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )	/* Samples (Channel A 0x20000=Channel B) */
+	ROM_REGION( 0x40000, "konami", 0 )	/* Samples (Channel A 0x20000=Channel B) */
 	ROM_LOAD( "602a03.10a", 0x00000, 0x20000, CRC(31392b01) SHA1(0424747bc2015c9c93afd20e6a23083c0dcc4fb7) )
 	ROM_LOAD( "602a02.8a",  0x20000, 0x20000, CRC(e2be10ae) SHA1(109c31bf7252c83a062d259143cd8299681db778) )
 
-	ROM_REGION( 0x04000, REGION_USER1, 0 )	/* extra data for road effects? */
+	ROM_REGION( 0x04000, "user1", 0 )	/* extra data for road effects? */
 	ROM_LOAD( "602a12.1a",  0x000000, 0x04000, CRC(77b9383d) SHA1(7cb970889677704d6324bb64aafc05326c4503ad) )
 
 ROM_END
 
-static void wecleman_unpack_sprites(void)
+static void wecleman_unpack_sprites(running_machine *machine)
 {
-	const int region       = REGION_GFX1;	// sprites
+	const char *region       = "gfx1";	// sprites
 
-	const UINT32 len = memory_region_length(region);
-	UINT8 *src     = memory_region(region) + len / 2 - 1;
-	UINT8 *dst     = memory_region(region) + len - 1;
+	const UINT32 len = memory_region_length(machine, region);
+	UINT8 *src     = memory_region(machine, region) + len / 2 - 1;
+	UINT8 *dst     = memory_region(machine, region) + len - 1;
 
 	while(dst > src)
 	{
@@ -1308,9 +1272,9 @@ static void bitswap(UINT8 *src,size_t len,int _14,int _13,int _12,int _11,int _1
 /* Unpack sprites data and do some patching */
 static DRIVER_INIT( wecleman )
 {
-	int i;
+	int i, len;
 	UINT8 *RAM;
-//  UINT16 *RAM1 = (UINT16 *) memory_region(REGION_CPU1);   /* Main CPU patches */
+//  UINT16 *RAM1 = (UINT16 *) memory_region(machine, "main");   /* Main CPU patches */
 //  RAM1[0x08c2/2] = 0x601e;    // faster self test
 
 	/* Decode GFX Roms - Compensate for the address lines scrambling */
@@ -1320,8 +1284,9 @@ static DRIVER_INIT( wecleman )
         I hope you'll appreciate this effort!  */
 
 	/* let's swap even and odd *pixels* of the sprites */
-	RAM = memory_region(REGION_GFX1);
-	for (i = 0; i < memory_region_length(REGION_GFX1); i ++)
+	RAM = memory_region(machine, "gfx1");
+	len = memory_region_length(machine, "gfx1");
+	for (i = 0; i < len; i ++)
 	{
 		/* TODO: could be wrong, colors have to be fixed.       */
 		/* The only certain thing is that 87 must convert to f0 */
@@ -1329,18 +1294,18 @@ static DRIVER_INIT( wecleman )
 		RAM[i] = BITSWAP8(RAM[i],7,0,1,2,3,4,5,6);
 	}
 
-	bitswap(memory_region(REGION_GFX1), memory_region_length(REGION_GFX1),
+	bitswap(memory_region(machine, "gfx1"), memory_region_length(machine, "gfx1"),
 			0,1,20,19,18,17,14,9,16,6,4,7,8,15,10,11,13,5,12,3,2);
 
 	/* Now we can unpack each nibble of the sprites into a pixel (one byte) */
-	wecleman_unpack_sprites();
+	wecleman_unpack_sprites(machine);
 
 	/* Bg & Fg & Txt */
-	bitswap(memory_region(REGION_GFX2), memory_region_length(REGION_GFX2),
+	bitswap(memory_region(machine, "gfx2"), memory_region_length(machine, "gfx2"),
 			20,19,18,17,16,15,12,7,14,4,2,5,6,13,8,9,11,3,10,1,0);
 
 	/* Road */
-	bitswap(memory_region(REGION_GFX3), memory_region_length(REGION_GFX3),
+	bitswap(memory_region(machine, "gfx3"), memory_region_length(machine, "gfx3"),
 			20,19,18,17,16,15,14,7,12,4,2,5,6,13,8,9,11,3,10,1,0);
 
 	spr_color_offs = 0x40;
@@ -1352,20 +1317,20 @@ static DRIVER_INIT( wecleman )
 ***************************************************************************/
 
 ROM_START( hotchase )
-	ROM_REGION( 0x40000, REGION_CPU1, 0 )	/* Main Code */
+	ROM_REGION( 0x40000, "main", 0 )	/* Main Code */
 	ROM_LOAD16_BYTE( "763k05", 0x000000, 0x010000, CRC(f34fef0b) SHA1(9edaf6da988348cb32d5686fe7a67fb92b1c9777) )
 	ROM_LOAD16_BYTE( "763k04", 0x000001, 0x010000, CRC(60f73178) SHA1(49c919d09fa464b205d7eccce337349e3a633a14) )
 	ROM_LOAD16_BYTE( "763k03", 0x020000, 0x010000, CRC(28e3a444) SHA1(106b22a3cbe8301eac2e46674a267b96e72ac72f) )
 	ROM_LOAD16_BYTE( "763k02", 0x020001, 0x010000, CRC(9510f961) SHA1(45b1920cab08a0dacd044c851d4e7f0cb5772b46) )
 
-	ROM_REGION( 0x20000, REGION_CPU2, 0 )	/* Sub Code */
+	ROM_REGION( 0x20000, "sub", 0 )	/* Sub Code */
 	ROM_LOAD16_BYTE( "763k07", 0x000000, 0x010000, CRC(ae12fa90) SHA1(7f76f09916fe152411b5af3c504ee7be07497ef4) )
 	ROM_LOAD16_BYTE( "763k06", 0x000001, 0x010000, CRC(b77e0c07) SHA1(98bf492ac889d31419df706029fdf3d51b85c936) )
 
-	ROM_REGION( 0x10000, REGION_CPU3, 0 )	/* Sound Code */
+	ROM_REGION( 0x10000, "audio", 0 )	/* Sound Code */
 	ROM_LOAD( "763f01", 0x8000, 0x8000, CRC(4fddd061) SHA1(ff0aa18605612f6102107a6be1f93ae4c5edc84f) )
 
-	ROM_REGION( 0x300000 * 2, REGION_GFX1, 0 )	/* x2, do not dispose, zooming sprites */
+	ROM_REGION( 0x300000 * 2, "gfx1", 0 )	/* x2, do not dispose, zooming sprites */
 	ROM_LOAD16_WORD_SWAP( "763e17", 0x000000, 0x080000, CRC(8db4e0aa) SHA1(376cb3cae110998f2f9df7e6cdd35c06732fea69) )
 	ROM_LOAD16_WORD_SWAP( "763e20", 0x080000, 0x080000, CRC(a22c6fce) SHA1(174fb9c1706c092947bcce386831acd33a237046) )
 	ROM_LOAD16_WORD_SWAP( "763e18", 0x100000, 0x080000, CRC(50920d01) SHA1(313c7ecbd154b3f4c96f25c29a7734a9b3facea4) )
@@ -1373,26 +1338,26 @@ ROM_START( hotchase )
 	ROM_LOAD16_WORD_SWAP( "763e19", 0x200000, 0x080000, CRC(a2622e56) SHA1(0a0ed9713882b987518e6f06a02dba417c1f4f32) )
 	ROM_LOAD16_WORD_SWAP( "763e22", 0x280000, 0x080000, CRC(967c49d1) SHA1(01979d216a9fd8085298445ac5f7870d1598db74) )
 
-	ROM_REGION( 0x20000, REGION_GFX2, 0 )	/* bg */
+	ROM_REGION( 0x20000, "gfx2", 0 )	/* bg */
 	ROM_LOAD( "763e14", 0x000000, 0x020000, CRC(60392aa1) SHA1(8499eb40a246587e24f6fd00af2eaa6d75ee6363) )
 
-	ROM_REGION( 0x10000, REGION_GFX3, 0 )	/* fg (patched) */
+	ROM_REGION( 0x10000, "gfx3", 0 )	/* fg (patched) */
 	ROM_LOAD( "763a13", 0x000000, 0x010000, CRC(8bed8e0d) SHA1(ccff330abc23fe499e76c16cab5783c3daf155dd) )
 
-	ROM_REGION( 0x20000, REGION_GFX4, ROMREGION_DISPOSE )	/* road */
+	ROM_REGION( 0x20000, "gfx4", ROMREGION_DISPOSE )	/* road */
 	ROM_LOAD( "763e15", 0x000000, 0x020000, CRC(7110aa43) SHA1(639dc002cc1580f0530bb5bb17f574e2258d5954) )
 
-	ROM_REGION( 0x40000, REGION_SOUND1, 0 )	/* Samples, 2 banks */
+	ROM_REGION( 0x40000, "konami1", 0 )	/* Samples, 2 banks */
 	ROM_LOAD( "763e11", 0x000000, 0x040000, CRC(9d99a5a7) SHA1(96e37bbb259e0a91d124c26b6b1a9b70de2e19a4) )
 
-	ROM_REGION( 0x40000, REGION_SOUND2, 0 )	/* Samples, 2 banks */
+	ROM_REGION( 0x40000, "konami2", 0 )	/* Samples, 2 banks */
 	ROM_LOAD( "763e10", 0x000000, 0x040000, CRC(ca409210) SHA1(703d7619c4bd33d2ff5fad127d98c82906fede33) )
 
-	ROM_REGION( 0x100000, REGION_SOUND3, 0 )	/* Samples, 4 banks for each ROM */
+	ROM_REGION( 0x100000, "konami3", 0 )	/* Samples, 4 banks for each ROM */
 	ROM_LOAD( "763e08", 0x000000, 0x080000, CRC(054a9a63) SHA1(45d7926c9e7af47c041ba9b733e334bccd730a6d) )
 	ROM_LOAD( "763e09", 0x080000, 0x080000, CRC(c39857db) SHA1(64b135a9ccf9e1dd50789cdd5c6bc03da8decfd0) )
 
-	ROM_REGION( 0x08000, REGION_USER1, 0 )	/* extra data for road effects? */
+	ROM_REGION( 0x08000, "user1", 0 )	/* extra data for road effects? */
 	ROM_LOAD( "763a12", 0x000000, 0x008000, CRC(05f1e553) SHA1(8aaeb7374bd93038c24e6470398936f22cabb0fe) )
 ROM_END
 
@@ -1400,12 +1365,12 @@ ROM_END
     in a ROM module definition.  This routine unpacks each sprite nibble
     into a byte, doubling the memory consumption. */
 
-static void hotchase_sprite_decode( int num16_banks, int bank_size )
+static void hotchase_sprite_decode( running_machine *machine, int num16_banks, int bank_size )
 {
 	UINT8 *base, *temp;
 	int i;
 
-	base = memory_region(REGION_GFX1);	// sprites
+	base = memory_region(machine, "gfx1");	// sprites
 	temp = malloc_or_die( bank_size );
 
 	for( i = num16_banks; i >0; i-- ){
@@ -1450,7 +1415,7 @@ static void hotchase_sprite_decode( int num16_banks, int bank_size )
 /* Unpack sprites data and do some patching */
 static DRIVER_INIT( hotchase )
 {
-//  UINT16 *RAM1 = (UINT16) memory_region(REGION_CPU1); /* Main CPU patches */
+//  UINT16 *RAM1 = (UINT16) memory_region(machine, "main"); /* Main CPU patches */
 //  RAM[0x1140/2] = 0x0015; RAM[0x195c/2] = 0x601A; // faster self test
 
 	UINT8 *RAM;
@@ -1458,13 +1423,13 @@ static DRIVER_INIT( hotchase )
 	/* Decode GFX Roms */
 
 	/* Let's swap even and odd bytes of the sprites gfx roms */
-	RAM = memory_region(REGION_GFX1);
+	RAM = memory_region(machine, "gfx1");
 
 	/* Now we can unpack each nibble of the sprites into a pixel (one byte) */
-	hotchase_sprite_decode(3,0x80000*2);	// num banks, bank len
+	hotchase_sprite_decode(machine,3,0x80000*2);	// num banks, bank len
 
 	/* Let's copy the second half of the fg layer gfx (charset) over the first */
-	RAM = memory_region(REGION_GFX3);
+	RAM = memory_region(machine, "gfx3");
 	memcpy(&RAM[0], &RAM[0x10000/2], 0x10000/2);
 
 	spr_color_offs = 0;
