@@ -49,33 +49,30 @@ something is missing, currently needs a hack to boot
 
 
 #include "driver.h"
+#include "cpu/m68000/m68000.h"
 #include "deprecat.h"
 
 static int toggle_bit;
 
 static READ16_HANDLER( wheelfir_rand1 )
 {
-
-
-
-
-	return readinputport(0)^toggle_bit;// mame_rand(Machine);
+	return input_port_read(space->machine, "IN0") ^ toggle_bit;	// mame_rand(space->machine);
 }
 
 static READ16_HANDLER( wheelfir_rand2 )
 {
-	return readinputport(1);// mame_rand(Machine);
+	return input_port_read(space->machine, "IN1");		// mame_rand(space->machine);
 }
 
 
 static READ16_HANDLER( wheelfir_rand4 )
 {
-	return mame_rand(Machine);
+	return mame_rand(space->machine);
 }
 
 static UINT16 *wheelfir_myram;
 static UINT16 wheelfir_blitdata[16];
-static mame_bitmap *wheelfir_tmp_bitmap[3];
+static bitmap_t *wheelfir_tmp_bitmap[3];
 
 /*
 
@@ -150,11 +147,13 @@ therefore a 512x256 page is
 
 /* it draws the background and road with direct writes to port 6... but where does this really go? an extra blit source page? */
 static int wheelfir_six_pos = 0;
-static mame_bitmap* render_bitmap;
+static bitmap_t* render_bitmap;
 
 static WRITE16_HANDLER(wheelfir_blit_w)
 {
 	//wheelfir_blitdata[offset]=data;
+	int width = video_screen_get_width(space->machine->primary_screen);
+	int height = video_screen_get_height(space->machine->primary_screen);
 	int vpage=0;
 	COMBINE_DATA(&wheelfir_blitdata[offset]);
 
@@ -184,7 +183,7 @@ static WRITE16_HANDLER(wheelfir_blit_w)
 
 		int x,y;
 		int xsize,ysize;
-		UINT8 *rom = memory_region(REGION_GFX1);
+		UINT8 *rom = memory_region(space->machine, "gfx1");
 		int dir=0;
 
 
@@ -263,7 +262,7 @@ static WRITE16_HANDLER(wheelfir_blit_w)
 				pix = rom[offs];
 
 
-				if(pix && destx >0 && desty >0 && destx<Machine->screen[0].width && desty <Machine->screen[0].height)
+				if(pix && destx >0 && desty >0 && destx<width && desty <height)
 					*BITMAP_ADDR16(wheelfir_tmp_bitmap[vpage], desty, destx) = pix;
 			}
 	}
@@ -275,11 +274,11 @@ static WRITE16_HANDLER(wheelfir_blit_w)
 static VIDEO_START(wheelfir)
 {
 
-	wheelfir_tmp_bitmap[0] = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
-	wheelfir_tmp_bitmap[1] = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
-	wheelfir_tmp_bitmap[2] = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
+	wheelfir_tmp_bitmap[0] = video_screen_auto_bitmap_alloc(machine->primary_screen);
+	wheelfir_tmp_bitmap[1] = video_screen_auto_bitmap_alloc(machine->primary_screen);
+	wheelfir_tmp_bitmap[2] = video_screen_auto_bitmap_alloc(machine->primary_screen);
 
-	render_bitmap =          auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
+	render_bitmap =          video_screen_auto_bitmap_alloc(machine->primary_screen);
 
 }
 
@@ -288,7 +287,7 @@ static int wheelfir_palpos = 0;
 /* Press R to show a page of gfx, Q / E to move between pages, and W to clear the framebuffer */
 static VIDEO_UPDATE(wheelfir)
 {
-	/*
+#if 0
     int x,y;
     static int base = 0;
 
@@ -304,10 +303,11 @@ static VIDEO_UPDATE(wheelfir)
     copybitmap(bitmap, wheelfir_tmp_bitmap[2], 0, 0, 0, 0, cliprect);
     //copybitmap_trans(bitmap, wheelfir_tmp_bitmap[1], 0, 0, 0, 0, cliprect, 0);
     copybitmap_trans(bitmap, wheelfir_tmp_bitmap[0], 0, 0, 0, 0, cliprect, 0);
-    fillbitmap(wheelfir_tmp_bitmap[0], 0,&machine->screen[0].visarea);
+    bitmap_fill(wheelfir_tmp_bitmap[0], video_screen_get_visible_area(screen),0);
 
     if ( input_code_pressed(KEYCODE_R) )
     {
+        const UINT8 *gfx = memory_region(machine, "gfx1");
         for (y=0;y<128;y++)
         {
             for (x=0;x<512;x++)
@@ -317,13 +317,13 @@ static VIDEO_UPDATE(wheelfir)
 
                 romoffs = base+y*512+x;
 
-                romdata = memory_region(REGION_GFX1)[romoffs];
+                romdata = gfx[romoffs];
 
                 *BITMAP_ADDR16(bitmap, y, x) = romdata;
             }
         }
     }
-    */
+#endif
 
 	copybitmap(bitmap, render_bitmap, 0, 0, 0, 0, cliprect);
 	copybitmap_trans(bitmap, wheelfir_tmp_bitmap[0], 0, 0, 0, 0, cliprect, 0);
@@ -338,10 +338,10 @@ static VIDEO_UPDATE(wheelfir)
 			r = wheelfir_palette[x];
 			g = wheelfir_palette[x+1];
 			b = wheelfir_palette[x+2];
-			palette_set_color(machine,x/3,MAKE_RGB(r,g,b));
+			palette_set_color(screen->machine,x/3,MAKE_RGB(r,g,b));
 		}
 	}
-/*
+#if 0
     {
         FILE* fp;
         fp=fopen("wheelfir_pal.dmp", "w+b");
@@ -351,7 +351,7 @@ static VIDEO_UPDATE(wheelfir)
             fclose(fp);
         }
     }
-*/
+#endif
 
 	return 0;
 }
@@ -377,20 +377,20 @@ static ADDRESS_MAP_START( wheelfir_main, ADDRESS_SPACE_PROGRAM, 16 )
 
 	AM_RANGE(0x7c0000, 0x7c0001) AM_READ(wheelfir_rand1)
 	AM_RANGE(0x780000, 0x780001) AM_READ(wheelfir_rand2)
-	AM_RANGE(0x7e0000, 0x7e0001) AM_READ(input_port_2_word_r)
-	AM_RANGE(0x7e0002, 0x7e0003) AM_READ(input_port_3_word_r)
+	AM_RANGE(0x7e0000, 0x7e0001) AM_READ_PORT("P1")
+	AM_RANGE(0x7e0002, 0x7e0003) AM_READ_PORT("P2")
 
 
 	AM_RANGE(0x700000, 0x70001f) AM_WRITE(wheelfir_blit_w) // blitter stuff
 	AM_RANGE(0x720000, 0x720001) AM_WRITE(pal_reset_pos_w) // always 0?
 	AM_RANGE(0x720002, 0x720003) AM_WRITE(pal_data_w) // lots of different values.. also blitter? palette?
-//  AM_RANGE(0x720004, 0x720005) AM_WRITE(MWA16_NOP) // always ffff?
+//  AM_RANGE(0x720004, 0x720005) AM_WRITE(SMH_NOP) // always ffff?
 
-//  AM_RANGE(0x740000, 0x740001) AM_WRITE(MWA16_NOP)
-//  AM_RANGE(0x760000, 0x760001) AM_WRITE(MWA16_NOP)
-//  AM_RANGE(0x740000, 0x740001) AM_WRITE(MWA16_NOP)
-//  AM_RANGE(0x7a0000, 0x7a0001) AM_WRITE(MWA16_NOP)
-//  AM_RANGE(0x7c0000, 0x7c0001) AM_WRITE(MWA16_NOP)
+//  AM_RANGE(0x740000, 0x740001) AM_WRITE(SMH_NOP)
+//  AM_RANGE(0x760000, 0x760001) AM_WRITE(SMH_NOP)
+//  AM_RANGE(0x740000, 0x740001) AM_WRITE(SMH_NOP)
+//  AM_RANGE(0x7a0000, 0x7a0001) AM_WRITE(SMH_NOP)
+//  AM_RANGE(0x7c0000, 0x7c0001) AM_WRITE(SMH_NOP)
 
   ADDRESS_MAP_END
 
@@ -401,13 +401,13 @@ static ADDRESS_MAP_START( wheelfir_sub, ADDRESS_SPACE_PROGRAM, 16 )
 	AM_RANGE(0x200000, 0x20ffff) AM_RAM
 
 	AM_RANGE(0x780000, 0x780001) AM_READ(wheelfir_rand4)
-	AM_RANGE(0x700000, 0x700001) AM_WRITE(MWA16_NOP)
-	AM_RANGE(0x740000, 0x740001) AM_WRITE(MWA16_NOP)
+	AM_RANGE(0x700000, 0x700001) AM_WRITE(SMH_NOP)
+	AM_RANGE(0x740000, 0x740001) AM_WRITE(SMH_NOP)
 ADDRESS_MAP_END
 
 
 static INPUT_PORTS_START( wheelfir )
-	PORT_START	/* 16bit */
+	PORT_START("IN0")	/* 16bit */
 	PORT_DIPNAME( 0x0001, 0x0001, "0" )
 	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -457,7 +457,7 @@ static INPUT_PORTS_START( wheelfir )
 	PORT_DIPSETTING(      0x8000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 
-	PORT_START	/* 16bit */
+	PORT_START("IN1")	/* 16bit */
 	PORT_DIPNAME( 0x0001, 0x0001, "1" )
 	PORT_DIPSETTING(      0x0001, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
@@ -507,7 +507,7 @@ static INPUT_PORTS_START( wheelfir )
 	PORT_DIPSETTING(      0x8000, DEF_STR( Off ) )
 	PORT_DIPSETTING(      0x0000, DEF_STR( On ) )
 
-	PORT_START	/* 16bit */
+	PORT_START("P1")	/* 16bit */
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
@@ -527,7 +527,7 @@ static INPUT_PORTS_START( wheelfir )
 	PORT_BIT( 0x4000, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x8000, IP_ACTIVE_LOW, IPT_UNUSED )
 
-	PORT_START	/* 16bit */
+	PORT_START("P2")	/* 16bit */
 	PORT_BIT( 0x0001, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x0002, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
 	PORT_BIT( 0x0004, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
@@ -571,13 +571,13 @@ static void render_background_to_render_buffer(int scanline)
 
 static TIMER_CALLBACK( scanline_timer_callback )
 {
-	timer_call_after_resynch(NULL, 0, 0);
+	timer_call_after_resynch(machine, NULL, 0, 0);
 
 	if (scanline_counter!=(total_scanlines-1))
 	{
 		scanline_counter++;
-		cpunum_set_input_line(machine, 0, 5, HOLD_LINE); // raster IRQ, changes scroll values for road
-		timer_adjust(scanline_timer, attotime_div(ATTOTIME_IN_HZ(60), total_scanlines), 0, attotime_zero);
+		cpu_set_input_line(machine->cpu[0], 5, HOLD_LINE); // raster IRQ, changes scroll values for road
+		timer_adjust_oneshot(scanline_timer, attotime_div(ATTOTIME_IN_HZ(60), total_scanlines), 0);
 
 		if (scanline_counter<256)
 		{
@@ -586,7 +586,7 @@ static TIMER_CALLBACK( scanline_timer_callback )
 
 		if (scanline_counter==256)
 		{
-			cpunum_set_input_line(machine, 0, 3, HOLD_LINE); // vblank IRQ?
+			cpu_set_input_line(machine->cpu[0], 3, HOLD_LINE); // vblank IRQ?
 			toggle_bit = 0x8000; // must toggle..
 		}
 
@@ -606,44 +606,43 @@ static TIMER_CALLBACK( scanline_timer_callback )
 static VIDEO_EOF( wheelfir )
 {
 	scanline_counter = -1;
-	fillbitmap(wheelfir_tmp_bitmap[0], 0,&machine->screen[0].visarea);
+	bitmap_fill(wheelfir_tmp_bitmap[0], video_screen_get_visible_area(machine->primary_screen),0);
 
-	timer_adjust(frame_timer,  attotime_zero, 0, attotime_zero);
-	timer_adjust(scanline_timer,  attotime_zero, 0, attotime_zero);
+	timer_adjust_oneshot(frame_timer,  attotime_zero, 0);
+	timer_adjust_oneshot(scanline_timer,  attotime_zero, 0);
 }
 
 static MACHINE_RESET(wheelfir)
 {
-	frame_timer = timer_alloc(frame_timer_callback, NULL);
-	scanline_timer = timer_alloc(scanline_timer_callback, NULL);
-	timer_adjust(frame_timer, attotime_zero, 0, attotime_zero);
-	timer_adjust(scanline_timer,  attotime_zero, 0, attotime_zero);
+	frame_timer = timer_alloc(machine, frame_timer_callback, NULL);
+	scanline_timer = timer_alloc(machine, scanline_timer_callback, NULL);
+	timer_adjust_oneshot(frame_timer, attotime_zero, 0);
+	timer_adjust_oneshot(scanline_timer,  attotime_zero, 0);
 	scanline_counter = -1;
 }
 
 static INTERRUPT_GEN( wheelfir_irq )
 {
 	// we seem to need this interrupt at least once for every object drawn on the screen, otherwise things flicker + slowdown
-	cpunum_set_input_line(machine, 0, 1, HOLD_LINE); // blitter IRQ?
+	cpu_set_input_line(device, 1, HOLD_LINE); // blitter IRQ?
 }
 
 
 static MACHINE_DRIVER_START( wheelfir )
-	MDRV_CPU_ADD_TAG("main", M68000, 32000000)
+	MDRV_CPU_ADD("main", M68000, 32000000)
 	MDRV_CPU_PROGRAM_MAP(wheelfir_main, 0)
-	MDRV_CPU_VBLANK_INT(wheelfir_irq,256)  // 1,3,5 valid
+	MDRV_CPU_VBLANK_INT_HACK(wheelfir_irq,256)  // 1,3,5 valid
 
-	MDRV_CPU_ADD_TAG("main", M68000, 32000000/2)
+	MDRV_CPU_ADD("sub", M68000, 32000000/2)
 	MDRV_CPU_PROGRAM_MAP(wheelfir_sub, 0)
-	MDRV_CPU_VBLANK_INT(irq1_line_hold,1) // 1 valid
-
-
-	MDRV_SCREEN_REFRESH_RATE(60)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_CPU_VBLANK_INT("main", irq1_line_hold) // 1 valid
 
 	MDRV_MACHINE_RESET (wheelfir)
 
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+
+	MDRV_SCREEN_ADD("main", RASTER)
+	MDRV_SCREEN_REFRESH_RATE(60)
+	MDRV_SCREEN_VBLANK_TIME(ATTOSECONDS_IN_USEC(0))
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
 	MDRV_SCREEN_SIZE(64*8, 64*8)
 	MDRV_SCREEN_VISIBLE_AREA(0*8, 42*8-1, 0*8, 32*8-1)
@@ -657,15 +656,15 @@ MACHINE_DRIVER_END
 
 
 ROM_START( wheelfir )
-	ROM_REGION( 0x100000, REGION_CPU1, 0 ) /* 68000 Code */
+	ROM_REGION( 0x100000, "main", 0 ) /* 68000 Code */
 	ROM_LOAD16_BYTE( "tch1.u19", 0x00001, 0x80000, CRC(33bbbc67) SHA1(c2ecc0ab522ee442076ea7b9536aee6e1fad0540) )
 	ROM_LOAD16_BYTE( "tch2.u21", 0x00000, 0x80000, CRC(ed6b9e8a) SHA1(214c5aaf55963a219db33dd5d530492e09ad5e07) )
 
-	ROM_REGION( 0x100000, REGION_CPU2, 0 ) /* 68000 Code + sound samples */
+	ROM_REGION( 0x100000, "sub", 0 ) /* 68000 Code + sound samples */
 	ROM_LOAD16_BYTE( "tch3.u83",  0x00001, 0x80000, CRC(43c014a6) SHA1(6c01a08dda204f36e8768795dd5d405576a49140) )
 	ROM_LOAD16_BYTE( "tch11.u65", 0x00000, 0x80000, CRC(fc894b2e) SHA1(ebe6d1adf889731fb6f53b4ce5f09c60e2aefb97) )
 
-	ROM_REGION( 0x400000, REGION_GFX1, 0 ) // 512x512 gfx pages
+	ROM_REGION( 0x400000, "gfx1", 0 ) // 512x512 gfx pages
 	ROM_LOAD( "tch4.u52", 0x000000, 0x80000, CRC(fe4bc2c7) SHA1(33a2ef79cb13f9e7e7d513915c6e13c4e7fe0188) )
 	ROM_LOAD( "tch5.u53", 0x080000, 0x80000, CRC(a38b9ca5) SHA1(083c9f700b9df1039fb553e918e205c6d32057ad) )
 	ROM_LOAD( "tch6.u54", 0x100000, 0x80000, CRC(2733ae6b) SHA1(ebd91e123b670159f79be19a552d1ae0c8a0faff) )
@@ -678,7 +677,7 @@ ROM_END
 
 static DRIVER_INIT(wheelfir)
 {
-	UINT16 *RAM = (UINT16 *)memory_region(REGION_CPU1);
+	UINT16 *RAM = (UINT16 *)memory_region(machine, "main");
 	RAM[0xdd3da/2] = 0x4e71; // hack!
 }
 
