@@ -147,7 +147,11 @@ TODO:
 #include "cpu/m6805/m6805.h"
 #include "sound/2203intf.h"
 
-static UINT8 *xain_sharedram;
+#define MASTER_CLOCK		XTAL_12MHz
+#define CPU_CLOCK			MASTER_CLOCK / 8
+#define MCU_CLOCK			MASTER_CLOCK / 4
+#define PIXEL_CLOCK		MASTER_CLOCK / 2
+
 static int vblank;
 
 VIDEO_UPDATE( xain );
@@ -164,43 +168,81 @@ WRITE8_HANDLER( xain_flipscreen_w );
 extern UINT8 *xain_charram, *xain_bgram0, *xain_bgram1, xain_pri;
 
 
-static READ8_HANDLER( xain_sharedram_r )
+/*
+    Based on the Solar Warrior schematics, vertical timing counts as follows:
+
+        08,09,0A,0B,...,FC,FD,FE,FF,E8,E9,EA,EB,...,FC,FD,FE,FF,
+        08,09,....
+
+    Thus, it counts from 08 to FF, then resets to E8 and counts to FF again.
+    This gives (256 - 8) + (256 - 232) = 248 + 24 = 272 total scanlines.
+
+    VBLK is signalled starting when the counter hits F8, and continues through
+    the reset to E8 and through until the next reset to 08 again.
+
+    Since MAME's video timing is 0-based, we need to convert this.
+*/
+
+INLINE int scanline_to_vcount(int scanline)
 {
-	return xain_sharedram[offset];
+	int vcount = scanline + 8;
+	if (vcount < 0x100)
+		return vcount;
+	else
+		return (vcount - 0x18) | 0x100;
 }
 
-static WRITE8_HANDLER( xain_sharedram_w )
+static TIMER_DEVICE_CALLBACK( xain_scanline )
 {
-	/* locations 003d and 003e are used as a semaphores between CPU A and B, */
-	/* so let's resync every time they are changed to avoid deadlocks */
-	if ((offset == 0x003d || offset == 0x003e)
-			&& xain_sharedram[offset] != data)
-		cpu_boost_interleave(attotime_zero, ATTOTIME_IN_USEC(20));
-	xain_sharedram[offset] = data;
+	int scanline = param;
+	int screen_height = video_screen_get_height(timer->machine->primary_screen);
+	int vcount_old = scanline_to_vcount((scanline == 0) ? screen_height - 1 : scanline - 1);
+	int vcount = scanline_to_vcount(scanline);
+
+	/* update to the current point */
+	if (scanline > 0)
+	{
+		video_screen_update_partial(timer->machine->primary_screen, scanline - 1);
+	}
+
+	/* FIRQ (IMS) fires every on every 8th scanline (except 0) */
+	if (!(vcount_old & 8) && (vcount & 8))
+	{
+		cpu_set_input_line(timer->machine->cpu[0], M6809_FIRQ_LINE, ASSERT_LINE);
+	}
+
+	/* NMI fires on scanline 248 (VBL) and is latched */
+	if (vcount == 0xf8)
+	{
+		cpu_set_input_line(timer->machine->cpu[0], INPUT_LINE_NMI, ASSERT_LINE);
+	}
+
+	/* VBLANK input bit is held high from scanlines 248-255 */
+	if (vcount >= 248-1)	// -1 is a hack - see notes above
+	{
+		vblank = 1;
+	}
+	else
+	{
+		vblank = 0;
+	}
 }
 
 static WRITE8_HANDLER( xainCPUA_bankswitch_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
-
-	xain_pri=data&0x7;
-
-	if (data & 0x08) {memory_set_bankptr(1,&RAM[0x10000]);}
-	else {memory_set_bankptr(1,&RAM[0x4000]);}
+	xain_pri = data & 0x7;
+	memory_set_bank(space->machine, 1, (data >> 3) & 1);
 }
 
 static WRITE8_HANDLER( xainCPUB_bankswitch_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU2);
-
-	if (data & 0x01) {memory_set_bankptr(2,&RAM[0x10000]);}
-	else {memory_set_bankptr(2,&RAM[0x4000]);}
+	memory_set_bank(space->machine, 2, data & 1);
 }
 
 static WRITE8_HANDLER( xain_sound_command_w )
 {
-	soundlatch_w(offset,data);
-	cpunum_set_input_line(Machine, 2,M6809_IRQ_LINE,HOLD_LINE);
+	soundlatch_w(space,offset,data);
+	cpu_set_input_line(space->machine->cpu[2],M6809_IRQ_LINE,HOLD_LINE);
 }
 
 static WRITE8_HANDLER( xain_main_irq_w )
@@ -208,28 +250,28 @@ static WRITE8_HANDLER( xain_main_irq_w )
 	switch (offset)
 	{
 	case 0: /* 0x3a09 - NMI clear */
-		cpunum_set_input_line(Machine, 0,INPUT_LINE_NMI,CLEAR_LINE);
+		cpu_set_input_line(space->machine->cpu[0],INPUT_LINE_NMI,CLEAR_LINE);
 		break;
 	case 1: /* 0x3a0a - FIRQ clear */
-		cpunum_set_input_line(Machine, 0,M6809_FIRQ_LINE,CLEAR_LINE);
+		cpu_set_input_line(space->machine->cpu[0],M6809_FIRQ_LINE,CLEAR_LINE);
 		break;
 	case 2: /* 0x3a0b - IRQ clear */
-		cpunum_set_input_line(Machine, 0,M6809_IRQ_LINE,CLEAR_LINE);
+		cpu_set_input_line(space->machine->cpu[0],M6809_IRQ_LINE,CLEAR_LINE);
 		break;
 	case 3: /* 0x3a0c - IRQB assert */
-		cpunum_set_input_line(Machine, 1,M6809_IRQ_LINE,ASSERT_LINE);
+		cpu_set_input_line(space->machine->cpu[1],M6809_IRQ_LINE,ASSERT_LINE);
 		break;
 	}
 }
 
 static WRITE8_HANDLER( xain_irqA_assert_w )
 {
-	cpunum_set_input_line(Machine, 0,M6809_IRQ_LINE,ASSERT_LINE);
+	cpu_set_input_line(space->machine->cpu[0],M6809_IRQ_LINE,ASSERT_LINE);
 }
 
 static WRITE8_HANDLER( xain_irqB_clear_w )
 {
-	cpunum_set_input_line(Machine, 1,M6809_IRQ_LINE,CLEAR_LINE);
+	cpu_set_input_line(space->machine->cpu[1],M6809_IRQ_LINE,CLEAR_LINE);
 }
 
 static READ8_HANDLER( xain_68705_r )
@@ -243,53 +285,28 @@ static WRITE8_HANDLER( xain_68705_w )
 //  logerror("write %02x to 68705\n",data);
 }
 
-static READ8_HANDLER( xain_input_port_4_r )
+static CUSTOM_INPUT( xain_vblank_r )
 {
-	return readinputport(4) | vblank;
+	return vblank;
 }
 
-static INTERRUPT_GEN( xain_interrupt )
-{
-	int scanline=255-cpu_getiloops();
 
-	/* FIRQ (IMS) fires every on every 8th scanline (except 0) */
-	if (scanline&0x08)
-		cpunum_set_input_line(machine, 0, M6809_FIRQ_LINE, ASSERT_LINE);
-
-	/* NMI fires on scanline 248 (VBL) and is latched */
-	if (scanline==248)
-		cpunum_set_input_line(machine, 0, INPUT_LINE_NMI, ASSERT_LINE);
-
-	/* VBLANK input bit is held high from scanlines 248-255 */
-	if (scanline>=248-1) // -1 is a hack - see notes above
-		vblank=0x20;
-	else
-		vblank=0;
-}
-
-static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_READ(xain_sharedram_r)
-	AM_RANGE(0x2000, 0x37ff) AM_READ(MRA8_RAM)
-	AM_RANGE(0x3a00, 0x3a00) AM_READ(input_port_0_r)
-	AM_RANGE(0x3a01, 0x3a01) AM_READ(input_port_1_r)
-	AM_RANGE(0x3a02, 0x3a02) AM_READ(input_port_2_r)
-	AM_RANGE(0x3a03, 0x3a03) AM_READ(input_port_3_r)
-	AM_RANGE(0x3a04, 0x3a04) AM_READ(xain_68705_r)	/* from the 68705 */
-	AM_RANGE(0x3a05, 0x3a05) AM_READ(xain_input_port_4_r)
-//  AM_RANGE(0x3a06, 0x3a06) AM_READ(MRA8_NOP)  /* ?? read (and discarded) on startup. Maybe reset the 68705 */
-	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_BANK1)
-	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_ROM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_WRITE(xain_sharedram_w) AM_BASE(&xain_sharedram)
-	AM_RANGE(0x2000, 0x27ff) AM_WRITE(xain_charram_w) AM_BASE(&xain_charram)
-	AM_RANGE(0x2800, 0x2fff) AM_WRITE(xain_bgram1_w) AM_BASE(&xain_bgram1)
-	AM_RANGE(0x3000, 0x37ff) AM_WRITE(xain_bgram0_w) AM_BASE(&xain_bgram0)
-	AM_RANGE(0x3800, 0x397f) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+static ADDRESS_MAP_START( main_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x1fff) AM_RAM AM_SHARE(1)
+	AM_RANGE(0x2000, 0x27ff) AM_RAM_WRITE(xain_charram_w) AM_BASE(&xain_charram)
+	AM_RANGE(0x2800, 0x2fff) AM_RAM_WRITE(xain_bgram1_w) AM_BASE(&xain_bgram1)
+	AM_RANGE(0x3000, 0x37ff) AM_RAM_WRITE(xain_bgram0_w) AM_BASE(&xain_bgram0)
+	AM_RANGE(0x3800, 0x397f) AM_RAM AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+	AM_RANGE(0x3a00, 0x3a00) AM_READ_PORT("P1")
 	AM_RANGE(0x3a00, 0x3a01) AM_WRITE(xain_scrollxP1_w)
+	AM_RANGE(0x3a01, 0x3a01) AM_READ_PORT("P2")
+	AM_RANGE(0x3a02, 0x3a02) AM_READ_PORT("DSW0")
 	AM_RANGE(0x3a02, 0x3a03) AM_WRITE(xain_scrollyP1_w)
+	AM_RANGE(0x3a03, 0x3a03) AM_READ_PORT("DSW1")
+	AM_RANGE(0x3a04, 0x3a04) AM_READ(xain_68705_r)	/* from the 68705 */
 	AM_RANGE(0x3a04, 0x3a05) AM_WRITE(xain_scrollxP0_w)
+	AM_RANGE(0x3a05, 0x3a05) AM_READ_PORT("VBLANK")
+//  AM_RANGE(0x3a06, 0x3a06) AM_READ(SMH_NOP)  /* ?? read (and discarded) on startup. Maybe reset the 68705 */
 	AM_RANGE(0x3a06, 0x3a07) AM_WRITE(xain_scrollyP0_w)
 	AM_RANGE(0x3a08, 0x3a08) AM_WRITE(xain_sound_command_w)
 	AM_RANGE(0x3a09, 0x3a0c) AM_WRITE(xain_main_irq_w)
@@ -298,54 +315,39 @@ static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x3a0f, 0x3a0f) AM_WRITE(xainCPUA_bankswitch_w)
 	AM_RANGE(0x3c00, 0x3dff) AM_WRITE(paletteram_xxxxBBBBGGGGRRRR_split1_w) AM_BASE(&paletteram)
 	AM_RANGE(0x3e00, 0x3fff) AM_WRITE(paletteram_xxxxBBBBGGGGRRRR_split2_w) AM_BASE(&paletteram_2)
-	AM_RANGE(0x4000, 0xffff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x4000, 0x7fff) AM_ROMBANK(1)
+	AM_RANGE(0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( readmemB, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_READ(xain_sharedram_r)
-	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_BANK2)
-	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_ROM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( writememB, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x1fff) AM_WRITE(xain_sharedram_w)
+static ADDRESS_MAP_START( cpu_map_B, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x1fff) AM_RAM AM_SHARE(1)
 	AM_RANGE(0x2000, 0x2000) AM_WRITE(xain_irqA_assert_w)
 	AM_RANGE(0x2800, 0x2800) AM_WRITE(xain_irqB_clear_w)
 	AM_RANGE(0x3000, 0x3000) AM_WRITE(xainCPUB_bankswitch_w)
-	AM_RANGE(0x4000, 0xffff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x4000, 0x7fff) AM_ROMBANK(2)
+	AM_RANGE(0x8000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
 #if 0
-static ADDRESS_MAP_START( mcu_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0010, 0x007f) AM_READ(MRA8_RAM)
-	AM_RANGE(0x0080, 0x07ff) AM_READ(MRA8_ROM)
-ADDRESS_MAP_END
-
-static ADDRESS_MAP_START( mcu_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0010, 0x007f) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0x0080, 0x07ff) AM_WRITE(MWA8_ROM)
+static ADDRESS_MAP_START( mcu_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0010, 0x007f) AM_RAM
+	AM_RANGE(0x0080, 0x07ff) AM_ROM
 ADDRESS_MAP_END
 #endif
 
-static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_READ(MRA8_RAM)
+static ADDRESS_MAP_START( sound_map, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x07ff) AM_RAM
 	AM_RANGE(0x1000, 0x1000) AM_READ(soundlatch_r)
-	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_ROM)
+	AM_RANGE(0x2800, 0x2800) AM_WRITE(ym2203_control_port_0_w)
+	AM_RANGE(0x2801, 0x2801) AM_WRITE(ym2203_write_port_0_w)
+	AM_RANGE(0x3000, 0x3000) AM_WRITE(ym2203_control_port_1_w)
+	AM_RANGE(0x3001, 0x3001) AM_WRITE(ym2203_write_port_1_w)
+	AM_RANGE(0x4000, 0xffff) AM_ROM
 ADDRESS_MAP_END
 
-static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x07ff) AM_WRITE(MWA8_RAM)
-	AM_RANGE(0x2800, 0x2800) AM_WRITE(YM2203_control_port_0_w)
-	AM_RANGE(0x2801, 0x2801) AM_WRITE(YM2203_write_port_0_w)
-	AM_RANGE(0x3000, 0x3000) AM_WRITE(YM2203_control_port_1_w)
-	AM_RANGE(0x3001, 0x3001) AM_WRITE(YM2203_write_port_1_w)
-	AM_RANGE(0x4000, 0xffff) AM_WRITE(MWA8_ROM)
-ADDRESS_MAP_END
-
-
 
 static INPUT_PORTS_START( xsleena )
-	PORT_START_TAG("IN0")
+	PORT_START("P1")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
@@ -355,7 +357,7 @@ static INPUT_PORTS_START( xsleena )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_START2 )
 
-	PORT_START_TAG("IN1")
+	PORT_START("P2")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL
@@ -365,7 +367,7 @@ static INPUT_PORTS_START( xsleena )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )
 
-	PORT_START_TAG("DSW0")
+	PORT_START("DSW0")
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Coin_B ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) )
@@ -389,7 +391,7 @@ static INPUT_PORTS_START( xsleena )
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
 
-	PORT_START_TAG("DSW1")
+	PORT_START("DSW1")
 	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Difficulty ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( Easy ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( Normal ) )
@@ -411,17 +413,16 @@ static INPUT_PORTS_START( xsleena )
 	PORT_DIPSETTING(    0x40, "6")
 	PORT_DIPSETTING(    0x00, "Infinite (Cheat")
 
-	PORT_START_TAG("IN2")
+	PORT_START("VBLANK")
 	PORT_BIT( 0x03, IP_ACTIVE_LOW,  IPT_UNUSED )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW,  IPT_COIN3 )
 	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_UNKNOWN )	/* when 0, 68705 is ready to send data */
 	PORT_BIT( 0x10, IP_ACTIVE_LOW,  IPT_UNKNOWN )	/* when 1, 68705 is ready to receive data */
-	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_SPECIAL )	/* VBLANK */
+	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_SPECIAL ) PORT_CUSTOM(xain_vblank_r, NULL)	/* VBLANK */
 	PORT_BIT( 0xc0, IP_ACTIVE_LOW,  IPT_UNUSED )
 INPUT_PORTS_END
 
 
-
 static const gfx_layout charlayout =
 {
 	8,8,
@@ -445,62 +446,62 @@ static const gfx_layout tilelayout =
 };
 
 static GFXDECODE_START( xain )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, charlayout,   0, 8 )	/* 8x8 text */
-	GFXDECODE_ENTRY( REGION_GFX2, 0, tilelayout, 256, 8 )	/* 16x16 Background */
-	GFXDECODE_ENTRY( REGION_GFX3, 0, tilelayout, 384, 8 )	/* 16x16 Background */
-	GFXDECODE_ENTRY( REGION_GFX4, 0, tilelayout, 128, 8 )	/* Sprites */
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout,   0, 8 )	/* 8x8 text */
+	GFXDECODE_ENTRY( "gfx2", 0, tilelayout, 256, 8 )	/* 16x16 Background */
+	GFXDECODE_ENTRY( "gfx3", 0, tilelayout, 384, 8 )	/* 16x16 Background */
+	GFXDECODE_ENTRY( "gfx4", 0, tilelayout, 128, 8 )	/* Sprites */
 GFXDECODE_END
 
 
-
 /* handler called by the 2203 emulator when the internal timers cause an IRQ */
-static void irqhandler(int irq)
+static void irqhandler(running_machine *machine, int irq)
 {
-	cpunum_set_input_line(Machine, 2,M6809_FIRQ_LINE,irq ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[2],M6809_FIRQ_LINE,irq ? ASSERT_LINE : CLEAR_LINE);
 }
 
-static const struct YM2203interface ym2203_interface =
+static const ym2203_interface ym2203_config =
 {
-	0,0,0,0,irqhandler
+	{
+		AY8910_LEGACY_OUTPUT,
+		AY8910_DEFAULT_LOADS,
+		NULL, NULL, NULL, NULL
+	},
+	irqhandler
 };
 
-
 static MACHINE_START( xsleena )
 {
-	/* initialize the bank pointers */
-	xainCPUA_bankswitch_w(0,0);
-	xainCPUB_bankswitch_w(0,0);
+	memory_configure_bank(machine, 1, 0, 2, memory_region(machine, "main") + 0x4000, 0xc000);
+	memory_configure_bank(machine, 2, 0, 2, memory_region(machine, "sub")  + 0x4000, 0xc000);
+	memory_set_bank(machine, 1, 0);
+	memory_set_bank(machine, 2, 0);
 }
 
-
 static MACHINE_DRIVER_START( xsleena )
 
 	/* basic machine hardware */
-	MDRV_CPU_ADD(M6809, 1500000)	/* Confirmed 1.5MHz */
-	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
-	MDRV_CPU_VBLANK_INT(xain_interrupt,256)
+	MDRV_CPU_ADD("main", M6809, CPU_CLOCK)	/* Confirmed 1.5MHz */
+	MDRV_CPU_PROGRAM_MAP(main_map,0)
+	MDRV_TIMER_ADD_SCANLINE("scantimer", xain_scanline, "main", 0, 1)
 
-	MDRV_CPU_ADD(M6809, 1500000)	/* Confirmed 1.5MHz */
-	MDRV_CPU_PROGRAM_MAP(readmemB,writememB)
+	MDRV_CPU_ADD("sub", M6809, CPU_CLOCK)	/* Confirmed 1.5MHz */
+	MDRV_CPU_PROGRAM_MAP(cpu_map_B,0)
 
-	MDRV_CPU_ADD(M6809, 1500000)	/* Confirmed 1.5MHz */
-	/* audio CPU */
-	MDRV_CPU_PROGRAM_MAP(sound_readmem,sound_writemem)
+	MDRV_CPU_ADD("audio", M6809, CPU_CLOCK)	/* Confirmed 1.5MHz */
+	MDRV_CPU_PROGRAM_MAP(sound_map,0)
 
-//  MDRV_CPU_ADD(M68705, 3000000)    /* Confirmed 3MHz */
-//  MDRV_CPU_PROGRAM_MAP(mcu_readmem,mcu_writemem)
+//  MDRV_CPU_ADD("mcu", M68705, MCU_CLOCK)    /* Confirmed 3MHz */
+//  MDRV_CPU_PROGRAM_MAP(mcu_map,0)
 
 	MDRV_MACHINE_START(xsleena)
 
-	MDRV_SCREEN_REFRESH_RATE(57)
-	MDRV_SCREEN_VBLANK_TIME(DEFAULT_60HZ_VBLANK_DURATION)
-	MDRV_INTERLEAVE(100)
+	MDRV_QUANTUM_PERFECT_CPU("main")
 
 	/* video hardware */
-	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_ADD("main", RASTER)
 	MDRV_SCREEN_FORMAT(BITMAP_FORMAT_INDEXED16)
-	MDRV_SCREEN_SIZE(32*8, 32*8)
-	MDRV_SCREEN_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MDRV_SCREEN_RAW_PARAMS(PIXEL_CLOCK, 384, 0, 256, 272, 8, 248)	/* based on ddragon driver */
+
 	MDRV_GFXDECODE(xain)
 	MDRV_PALETTE_LENGTH(512)
 
@@ -510,14 +511,14 @@ static MACHINE_DRIVER_START( xsleena )
 	/* sound hardware */
 	MDRV_SPEAKER_STANDARD_MONO("mono")
 
-	MDRV_SOUND_ADD(YM2203, 3000000)
-	MDRV_SOUND_CONFIG(ym2203_interface)
+	MDRV_SOUND_ADD("ym1", YM2203, 3000000)
+	MDRV_SOUND_CONFIG(ym2203_config)
 	MDRV_SOUND_ROUTE(0, "mono", 0.50)
 	MDRV_SOUND_ROUTE(1, "mono", 0.50)
 	MDRV_SOUND_ROUTE(2, "mono", 0.50)
 	MDRV_SOUND_ROUTE(3, "mono", 0.40)
 
-	MDRV_SOUND_ADD(YM2203, 3000000)
+	MDRV_SOUND_ADD("ym2", YM2203, 3000000)
 	MDRV_SOUND_ROUTE(0, "mono", 0.50)
 	MDRV_SOUND_ROUTE(1, "mono", 0.50)
 	MDRV_SOUND_ROUTE(2, "mono", 0.50)
@@ -525,7 +526,6 @@ static MACHINE_DRIVER_START( xsleena )
 MACHINE_DRIVER_END
 
 
-
 /***************************************************************************
 
   Game driver(s)
@@ -533,26 +533,26 @@ MACHINE_DRIVER_END
 ***************************************************************************/
 
 ROM_START( xsleena )
-	ROM_REGION( 0x14000, REGION_CPU1, 0 )
+	ROM_REGION( 0x14000, "main", 0 )
 	ROM_LOAD( "s-10.7d",      0x08000, 0x8000, CRC(370164be) SHA1(65c9951cac7dc3943fa4d5f9919ebb4c4f29b3ae) )
 	ROM_LOAD( "s-11.7c",      0x04000, 0x4000, CRC(d22bf859) SHA1(9edb159bef2eba2c5d93c03c15fbcb87eea52236) )
 	ROM_CONTINUE(             0x10000, 0x4000 )
 
-	ROM_REGION( 0x14000, REGION_CPU2, 0 )
+	ROM_REGION( 0x14000, "sub", 0 )
 	ROM_LOAD( "s-2.3b",       0x08000, 0x8000, CRC(a1a860e2) SHA1(fb2b152bfafc44608039774436ddf3b17eed979c) )
 	ROM_LOAD( "s-1.2b",       0x04000, 0x4000, CRC(948b9757) SHA1(3ea840cc47ae6a66f3e5f6a2f3e88475dcfe1840) )
 	ROM_CONTINUE(             0x10000, 0x4000 )
 
-	ROM_REGION( 0x10000, REGION_CPU3, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "s-3.4s",       0x8000, 0x8000, CRC(a5318cb8) SHA1(35fb28c5598e39f22552bb036ae356b78422f080) )
 
-//  ROM_REGION( 0x800, REGION_CPU4, 0 )
+//  ROM_REGION( 0x800, "cpu3", 0 )
 //  ROM_LOAD( "pz-0.113",       0x000, 0x800, CRC(0) SHA1(0) )
 
-	ROM_REGION( 0x08000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x08000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "s-12.8b",      0x00000, 0x8000, CRC(83c00dd8) SHA1(8e9b19281039b63072270c7a63d9fb30cda570fd) ) /* chars */
 
-	ROM_REGION( 0x40000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x40000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "s-21.16i",     0x00000, 0x8000, CRC(11eb4247) SHA1(5d2f1fa07b8fb1c6bebfdb02c39282d29813791b) ) /* tiles */
 	ROM_LOAD( "s-22.15i",     0x08000, 0x8000, CRC(422b536e) SHA1(d5985c0bd1c840cb6f0da6b177a2caaff6db5a04) )
 	ROM_LOAD( "s-23.14i",     0x10000, 0x8000, CRC(828c1b0c) SHA1(cb9b64073b0ade3885f61545191db4c445e3066b) )
@@ -562,7 +562,7 @@ ROM_START( xsleena )
 	ROM_LOAD( "s-15.14g",     0x30000, 0x8000, CRC(a8eeabc8) SHA1(e5dc31df0b223b65144af3602be5bcb2ff9eebbd) )
 	ROM_LOAD( "s-16.13g",     0x38000, 0x8000, CRC(e59a2f27) SHA1(4643cea85f8613c36b416f46f9d1753fa9839237) )
 
-	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x40000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "s-6.4h",       0x00000, 0x8000, CRC(5c6c453c) SHA1(68c0028d15da8f5e53f09e3d154d18cd9f219601) ) /* tiles */
 	ROM_LOAD( "s-5.4l",       0x08000, 0x8000, CRC(59d87a9a) SHA1(f23cb9a9d6c6249a8a1f8e2acbc235086b008c7b) )
 	ROM_LOAD( "s-4.4m",       0x10000, 0x8000, CRC(84884a2e) SHA1(5087010a72226e91a084a61b5089c110dba7e933) )
@@ -572,7 +572,7 @@ ROM_START( xsleena )
 	ROM_LOAD( "s-9.4c",       0x30000, 0x8000, CRC(7fc9704f) SHA1(b6f353fb7fec58f68b9e28be2aa29146ac64ffd4) )
 	/* 0x80000-0x87fff empty */
 
-	ROM_REGION( 0x40000, REGION_GFX4, ROMREGION_DISPOSE )
+	ROM_REGION( 0x40000, "gfx4", ROMREGION_DISPOSE )
 	ROM_LOAD( "s-25.10i",     0x00000, 0x8000, CRC(252976ae) SHA1(534c9148d33e453f3541543a8c0eb4afc59c7de8) ) /* sprites */
 	ROM_LOAD( "s-26.9i",      0x08000, 0x8000, CRC(e6f1e8d5) SHA1(2ee0227361d1f1358f5b5964dab7e691243cd9ae) )
 	ROM_LOAD( "s-27.8i",      0x10000, 0x8000, CRC(785381ed) SHA1(95bf4eb29830c589a9793a4138e645e5b77f0c06) )
@@ -582,28 +582,28 @@ ROM_START( xsleena )
 	ROM_LOAD( "s-19.8g",      0x30000, 0x8000, CRC(76641ee3) SHA1(8fba0fa6639e7bdfb3f7be5e945a55b64411d242) )
 	ROM_LOAD( "s-20.7g",      0x38000, 0x8000, CRC(37671f36) SHA1(1494eec4ecde9ae1f1101aa13eb301b3f3d06602) )
 
-	ROM_REGION( 0x0100, REGION_PROMS, 0 ) /* Priority */
+	ROM_REGION( 0x0100, "proms", 0 ) /* Priority */
 	ROM_LOAD( "mb7114e.59",   0x0000, 0x0100, CRC(fed32888) SHA1(4e9330456b20f7198c1e27ca1ae7200f25595599) )	/* timing? (not used) */
 ROM_END
 
 ROM_START( xsleenab )
-	ROM_REGION( 0x14000, REGION_CPU1, 0 )
+	ROM_REGION( 0x14000, "main", 0 )
 	ROM_LOAD( "1.rom",        0x08000, 0x8000, CRC(79f515a7) SHA1(e61f18e3639dd9afe16c7bcb90fa7be31905e2c6) )
 	ROM_LOAD( "s-11.7c",      0x04000, 0x4000, CRC(d22bf859) SHA1(9edb159bef2eba2c5d93c03c15fbcb87eea52236) )
 	ROM_CONTINUE(             0x10000, 0x4000 )
 
-	ROM_REGION( 0x14000, REGION_CPU2, 0 )
+	ROM_REGION( 0x14000, "sub", 0 )
 	ROM_LOAD( "s-2.3b",       0x08000, 0x8000, CRC(a1a860e2) SHA1(fb2b152bfafc44608039774436ddf3b17eed979c) )
 	ROM_LOAD( "s-1.2b",       0x04000, 0x4000, CRC(948b9757) SHA1(3ea840cc47ae6a66f3e5f6a2f3e88475dcfe1840) )
 	ROM_CONTINUE(             0x10000, 0x4000 )
 
-	ROM_REGION( 0x10000, REGION_CPU3, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "s-3.4s",       0x8000, 0x8000, CRC(a5318cb8) SHA1(35fb28c5598e39f22552bb036ae356b78422f080) )
 
-	ROM_REGION( 0x08000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x08000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "s-12.8b",      0x00000, 0x8000, CRC(83c00dd8) SHA1(8e9b19281039b63072270c7a63d9fb30cda570fd) ) /* chars */
 
-	ROM_REGION( 0x40000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x40000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "s-21.16i",     0x00000, 0x8000, CRC(11eb4247) SHA1(5d2f1fa07b8fb1c6bebfdb02c39282d29813791b) ) /* tiles */
 	ROM_LOAD( "s-22.15i",     0x08000, 0x8000, CRC(422b536e) SHA1(d5985c0bd1c840cb6f0da6b177a2caaff6db5a04) )
 	ROM_LOAD( "s-23.14i",     0x10000, 0x8000, CRC(828c1b0c) SHA1(cb9b64073b0ade3885f61545191db4c445e3066b) )
@@ -613,7 +613,7 @@ ROM_START( xsleenab )
 	ROM_LOAD( "s-15.14g",     0x30000, 0x8000, CRC(a8eeabc8) SHA1(e5dc31df0b223b65144af3602be5bcb2ff9eebbd) )
 	ROM_LOAD( "s-16.13g",     0x38000, 0x8000, CRC(e59a2f27) SHA1(4643cea85f8613c36b416f46f9d1753fa9839237) )
 
-	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x40000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "s-6.4h",       0x00000, 0x8000, CRC(5c6c453c) SHA1(68c0028d15da8f5e53f09e3d154d18cd9f219601) ) /* tiles */
 	ROM_LOAD( "s-5.4l",       0x08000, 0x8000, CRC(59d87a9a) SHA1(f23cb9a9d6c6249a8a1f8e2acbc235086b008c7b) )
 	ROM_LOAD( "s-4.4m",       0x10000, 0x8000, CRC(84884a2e) SHA1(5087010a72226e91a084a61b5089c110dba7e933) )
@@ -623,7 +623,7 @@ ROM_START( xsleenab )
 	ROM_LOAD( "s-9.4c",       0x30000, 0x8000, CRC(7fc9704f) SHA1(b6f353fb7fec58f68b9e28be2aa29146ac64ffd4) )
 	/* 0x80000-0x87fff empty */
 
-	ROM_REGION( 0x40000, REGION_GFX4, ROMREGION_DISPOSE )
+	ROM_REGION( 0x40000, "gfx4", ROMREGION_DISPOSE )
 	ROM_LOAD( "s-25.10i",     0x00000, 0x8000, CRC(252976ae) SHA1(534c9148d33e453f3541543a8c0eb4afc59c7de8) ) /* sprites */
 	ROM_LOAD( "s-26.9i",      0x08000, 0x8000, CRC(e6f1e8d5) SHA1(2ee0227361d1f1358f5b5964dab7e691243cd9ae) )
 	ROM_LOAD( "s-27.8i",      0x10000, 0x8000, CRC(785381ed) SHA1(95bf4eb29830c589a9793a4138e645e5b77f0c06) )
@@ -633,31 +633,31 @@ ROM_START( xsleenab )
 	ROM_LOAD( "s-19.8g",      0x30000, 0x8000, CRC(76641ee3) SHA1(8fba0fa6639e7bdfb3f7be5e945a55b64411d242) )
 	ROM_LOAD( "s-20.7g",      0x38000, 0x8000, CRC(37671f36) SHA1(1494eec4ecde9ae1f1101aa13eb301b3f3d06602) )
 
-	ROM_REGION( 0x0100, REGION_PROMS, 0 ) /* Priority */
+	ROM_REGION( 0x0100, "proms", 0 ) /* Priority */
 	ROM_LOAD( "mb7114e.59",   0x0000, 0x0100, CRC(fed32888) SHA1(4e9330456b20f7198c1e27ca1ae7200f25595599) )	/* timing? (not used) */
 ROM_END
 
 ROM_START( solarwar )
-	ROM_REGION( 0x14000, REGION_CPU1, 0 )
+	ROM_REGION( 0x14000, "main", 0 )
 	ROM_LOAD( "p9-0.bin",     0x08000, 0x8000, CRC(8ff372a8) SHA1(0fc396e662419fb9cb5bea11748aa8e0e8d072e6) )
 	ROM_LOAD( "pa-0.bin",     0x04000, 0x4000, CRC(154f946f) SHA1(25b776eb9c494e5302795ae79e494cbfc7c104b1) )
 	ROM_CONTINUE(             0x10000, 0x4000 )
 
-	ROM_REGION( 0x14000, REGION_CPU2, 0 )
+	ROM_REGION( 0x14000, "sub", 0 )
 	ROM_LOAD( "p1-0.bin",     0x08000, 0x8000, CRC(f5f235a3) SHA1(9f57dd7c5e514afa750edc6da6d263bf1e913c14) )
 	ROM_LOAD( "p0-0.bin",     0x04000, 0x4000, CRC(51ae95ae) SHA1(e03f7ccb0b33b05547577c60a7f92dc75e24b4d6) )
 	ROM_CONTINUE(             0x10000, 0x4000 )
 
-	ROM_REGION( 0x10000, REGION_CPU3, 0 )
+	ROM_REGION( 0x10000, "audio", 0 )
 	ROM_LOAD( "s-3.4s",       0x8000, 0x8000, CRC(a5318cb8) SHA1(35fb28c5598e39f22552bb036ae356b78422f080) )
 
-//  ROM_REGION( 0x800, REGION_CPU4, 0 )
+//  ROM_REGION( 0x800, "cpu3", 0 )
 //  ROM_LOAD( "pz-0.113",       0x000, 0x800, CRC(0) SHA1(0) )
 
-	ROM_REGION( 0x08000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_REGION( 0x08000, "gfx1", ROMREGION_DISPOSE )
 	ROM_LOAD( "s-12.8b",      0x00000, 0x8000, CRC(83c00dd8) SHA1(8e9b19281039b63072270c7a63d9fb30cda570fd) ) /* chars */
 
-	ROM_REGION( 0x40000, REGION_GFX2, ROMREGION_DISPOSE )
+	ROM_REGION( 0x40000, "gfx2", ROMREGION_DISPOSE )
 	ROM_LOAD( "s-21.16i",     0x00000, 0x8000, CRC(11eb4247) SHA1(5d2f1fa07b8fb1c6bebfdb02c39282d29813791b) ) /* tiles */
 	ROM_LOAD( "s-22.15i",     0x08000, 0x8000, CRC(422b536e) SHA1(d5985c0bd1c840cb6f0da6b177a2caaff6db5a04) )
 	ROM_LOAD( "s-23.14i",     0x10000, 0x8000, CRC(828c1b0c) SHA1(cb9b64073b0ade3885f61545191db4c445e3066b) )
@@ -667,7 +667,7 @@ ROM_START( solarwar )
 	ROM_LOAD( "s-15.14g",     0x30000, 0x8000, CRC(a8eeabc8) SHA1(e5dc31df0b223b65144af3602be5bcb2ff9eebbd) )
 	ROM_LOAD( "pf-0.bin",     0x38000, 0x8000, CRC(6e627a77) SHA1(1d16031acd53c9e691ae7eac8a6f1ae3954fac8c) )
 
-	ROM_REGION( 0x40000, REGION_GFX3, ROMREGION_DISPOSE )
+	ROM_REGION( 0x40000, "gfx3", ROMREGION_DISPOSE )
 	ROM_LOAD( "s-6.4h",       0x00000, 0x8000, CRC(5c6c453c) SHA1(68c0028d15da8f5e53f09e3d154d18cd9f219601) ) /* tiles */
 	ROM_LOAD( "s-5.4l",       0x08000, 0x8000, CRC(59d87a9a) SHA1(f23cb9a9d6c6249a8a1f8e2acbc235086b008c7b) )
 	ROM_LOAD( "s-4.4m",       0x10000, 0x8000, CRC(84884a2e) SHA1(5087010a72226e91a084a61b5089c110dba7e933) )
@@ -677,7 +677,7 @@ ROM_START( solarwar )
 	ROM_LOAD( "s-9.4c",       0x30000, 0x8000, CRC(7fc9704f) SHA1(b6f353fb7fec58f68b9e28be2aa29146ac64ffd4) )
 	/* 0x80000-0x87fff empty */
 
-	ROM_REGION( 0x40000, REGION_GFX4, ROMREGION_DISPOSE )
+	ROM_REGION( 0x40000, "gfx4", ROMREGION_DISPOSE )
 	ROM_LOAD( "s-25.10i",     0x00000, 0x8000, CRC(252976ae) SHA1(534c9148d33e453f3541543a8c0eb4afc59c7de8) )	/* sprites */
 	ROM_LOAD( "s-26.9i",      0x08000, 0x8000, CRC(e6f1e8d5) SHA1(2ee0227361d1f1358f5b5964dab7e691243cd9ae) )
 	ROM_LOAD( "s-27.8i",      0x10000, 0x8000, CRC(785381ed) SHA1(95bf4eb29830c589a9793a4138e645e5b77f0c06) )
@@ -687,15 +687,14 @@ ROM_START( solarwar )
 	ROM_LOAD( "s-19.8g",      0x30000, 0x8000, CRC(76641ee3) SHA1(8fba0fa6639e7bdfb3f7be5e945a55b64411d242) )
 	ROM_LOAD( "s-20.7g",      0x38000, 0x8000, CRC(37671f36) SHA1(1494eec4ecde9ae1f1101aa13eb301b3f3d06602) )
 
-	ROM_REGION( 0x0100, REGION_PROMS, 0 ) /* Priority */
+	ROM_REGION( 0x0100, "proms", 0 ) /* Priority */
 	ROM_LOAD( "mb7114e.59",   0x0000, 0x0100, CRC(fed32888) SHA1(4e9330456b20f7198c1e27ca1ae7200f25595599) )	/* timing? (not used) */
 ROM_END
 
 
-
 static DRIVER_INIT( xsleena )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
+	UINT8 *RAM = memory_region(machine, "main");
 
 	/* do the same patch as the bootleg xsleena */
 	RAM[0xd488] = 0x12;
@@ -708,7 +707,7 @@ static DRIVER_INIT( xsleena )
 
 static DRIVER_INIT( solarwar )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
+	UINT8 *RAM = memory_region(machine, "main");
 
 	/* do the same patch as the bootleg xsleena */
 	RAM[0xd47e] = 0x12;
@@ -720,7 +719,6 @@ static DRIVER_INIT( solarwar )
 }
 
 
-
 GAME( 1986, xsleena,  0,       xsleena, xsleena, xsleena,  ROT0, "Technos", "Xain'd Sleena", 0 )
 GAME( 1986, xsleenab, xsleena, xsleena, xsleena, 0,        ROT0, "bootleg", "Xain'd Sleena (bootleg)", 0 )
 GAME( 1986, solarwar, xsleena, xsleena, xsleena, solarwar, ROT0, "[Technos] Taito (Memetron license)", "Solar-Warrior", 0 )
