@@ -309,28 +309,18 @@ struct _amiga_machine_interface
 {
 	UINT32 chip_ram_mask;
 
-	UINT8 (*cia_0_portA_r)(void);
-	UINT8 (*cia_0_portB_r)(void);
-	void (*cia_0_portA_w)(UINT8 data);
-	void (*cia_0_portB_w)(UINT8 data);
+	UINT16 (*joy0dat_r)(running_machine *machine);
+	UINT16 (*joy1dat_r)(running_machine *machine);
+	void (*potgo_w)(running_machine *machine, UINT16 data);
 
-	UINT8 (*cia_1_portA_r)(void);
-	UINT8 (*cia_1_portB_r)(void);
-	void (*cia_1_portA_w)(UINT8 data);
-	void (*cia_1_portB_w)(UINT8 data);
+	UINT16 (*dskbytr_r)(running_machine *machine);
+	void (*dsklen_w)(running_machine *machine, UINT16 data);
 
-	UINT16 (*joy0dat_r)(void);
-	UINT16 (*joy1dat_r)(void);
-	void (*potgo_w)(UINT16 data);
+	void (*serdat_w)(running_machine *machine, UINT16 data);
 
-	UINT16 (*dskbytr_r)(void);
-	void (*dsklen_w)(UINT16 data);
-
-	void (*serdat_w)(UINT16 data);
-
-	void (*scanline0_callback)(void);
-	void (*reset_callback)(void);
-	void (*nmi_callback)(void);
+	void (*scanline0_callback)(running_machine *machine);
+	void (*reset_callback)(running_machine *machine);
+	void (*nmi_callback)(running_machine *machine);
 
 	UINT32 flags;
 };
@@ -352,10 +342,10 @@ struct _amiga_autoconfig_device
 	UINT16		mfr_number;			/* manufacturers number */
 	UINT32		serial_number;		/* serial number */
 	UINT16		rom_vector;			/* ROM vector offset */
-	UINT8		(*int_control_r)(void); /* interrupt control read */
-	void		(*int_control_w)(UINT8 data); /* interrupt control write */
-	void		(*install)(offs_t base); /* memory installation */
-	void		(*uninstall)(offs_t base); /* memory uninstallation */
+	UINT8		(*int_control_r)(running_machine *machine); /* interrupt control read */
+	void		(*int_control_w)(running_machine *machine, UINT8 data); /* interrupt control write */
+	void		(*install)(running_machine *machine, offs_t base); /* memory installation */
+	void		(*uninstall)(running_machine *machine, offs_t base); /* memory uninstallation */
 };
 
 
@@ -374,10 +364,9 @@ extern const char *const amiga_custom_names[0x100];
 extern UINT16 (*amiga_chip_ram_r)(offs_t offset);
 extern void (*amiga_chip_ram_w)(offs_t offset, UINT16 data);
 
-void amiga_machine_config(const amiga_machine_interface *intf);
+void amiga_machine_config(running_machine *machine, const amiga_machine_interface *intf);
 
 MACHINE_RESET( amiga );
-INTERRUPT_GEN( amiga_scanline_callback );
 
 CUSTOM_INPUT( amiga_joystick_convert );
 
@@ -387,19 +376,22 @@ WRITE16_HANDLER( amiga_cia_w );
 READ16_HANDLER( amiga_custom_r );
 WRITE16_HANDLER( amiga_custom_w );
 
-void amiga_serial_in_w(UINT16 data);
-attotime amiga_get_serial_char_period(void);
+void amiga_serial_in_w(running_machine *machine, UINT16 data);
+attotime amiga_get_serial_char_period(running_machine *machine);
 
-void amiga_add_autoconfig(const amiga_autoconfig_device *device);
+void amiga_add_autoconfig(running_machine *machine, const amiga_autoconfig_device *device);
 READ16_HANDLER( amiga_autoconfig_r );
 WRITE16_HANDLER( amiga_autoconfig_w );
 
+void amiga_cia_0_irq(const device_config *device, int state);
+void amiga_cia_1_irq(const device_config *device, int state);
+
 const amiga_machine_interface *amiga_get_interface(void);
 
 
 /*----------- defined in audio/amiga.c -----------*/
 
-void *amiga_sh_start(int clock, const struct CustomSound_interface *config);
+CUSTOM_START( amiga_sh_start );
 void amiga_audio_update(void);
 void amiga_audio_data_w(int which, UINT16 data);
 
@@ -408,11 +400,12 @@ void amiga_audio_data_w(int which, UINT16 data);
 
 PALETTE_INIT( amiga );
 VIDEO_START( amiga );
+VIDEO_UPDATE( amiga );
 
-UINT32 amiga_gethvpos(void);
+UINT32 amiga_gethvpos(const device_config *screen);
 void copper_setpc(UINT32 pc);
 void amiga_set_genlock_color(UINT16 color);
-void amiga_render_scanline(int scanline);
+void amiga_render_scanline(running_machine *machine, bitmap_t *bitmap, int scanline);
 void amiga_sprite_dma_reset(int which);
 void amiga_sprite_enable_comparitor(int which, int enable);
 
