@@ -36,33 +36,27 @@ MACHINE_START( a800xl );
 MACHINE_START( a5200 );
 
 #ifdef MESS
-DEVICE_LOAD( a800_floppy );
+DEVICE_IMAGE_LOAD( a800_floppy );
 
-DEVICE_LOAD( a800_cart );
-DEVICE_UNLOAD( a800_cart );
+DEVICE_IMAGE_LOAD( a800_cart );
+DEVICE_IMAGE_UNLOAD( a800_cart );
 
-DEVICE_LOAD( a800xl_cart );
-DEVICE_UNLOAD( a800xl_cart );
+DEVICE_IMAGE_LOAD( a800xl_cart );
+DEVICE_IMAGE_UNLOAD( a800xl_cart );
 
-DEVICE_LOAD( a5200_cart );
-DEVICE_UNLOAD( a5200_cart );
+DEVICE_IMAGE_LOAD( a5200_cart );
+DEVICE_IMAGE_UNLOAD( a5200_cart );
 #endif
 
  READ8_HANDLER ( atari_serin_r );
 WRITE8_HANDLER ( atari_serout_w );
-void atari_interrupt_cb(int mask);
+void atari_interrupt_cb(running_machine *machine, int mask);
 
-void a800_handle_keyboard(void);
-void a5200_handle_keypads(void);
+void a800_handle_keyboard(running_machine *machine);
+void a5200_handle_keypads(running_machine *machine);
 
 /* video */
 
-/* Enable this to make the video code use readmem16 to retrieve data */
-/* Otherwise the RAM memory array is accessed and thus, if a display list would */
-/* point to memory mapped IO, the result is different from a real machine */
-#define ACCURATE_ANTIC_READMEM	1
-
-
 #define CYCLES_PER_LINE 114 	/* total number of cpu cycles per scanline (incl. hblank) */
 #define CYCLES_REFRESH	9		/* number of cycles lost for ANTICs RAM refresh using DMA */
 #define CYCLES_HSTART	32		/* where does the ANTIC DMA fetch start */
@@ -315,47 +309,39 @@ typedef struct {
 	UINT8   *uc_g3;				/* used colors for gfx GTIA 3 */
 }   ANTIC;
 
-#if ACCURATE_ANTIC_READMEM
-#define RDANTIC()	cpunum_read_byte(0, antic.dpage+antic.doffs)
-#define RDVIDEO(o)	cpunum_read_byte(0, antic.vpage+((antic.voffs+(o))&VOFFS))
-#define RDCHGEN(o)	cpunum_read_byte(0, antic.chbase+(o))
-#define RDPMGFXS(o) cpunum_read_byte(0, antic.pmbase_s+(o)+(antic.scanline>>1))
-#define RDPMGFXD(o) cpunum_read_byte(0, antic.pmbase_d+(o)+antic.scanline)
-#else
-#define RDANTIC()	(memory_region(REGION_CPU1))[antic.dpage+antic.doffs]
-#define RDVIDEO(o)	(memory_region(REGION_CPU1))[antic.vpage+((antic.voffs+(o))&VOFFS)]
-#define RDCHGEN(o)	(memory_region(REGION_CPU1))[antic.chbase+(o)]
-#define RDPMGFXS(o) (memory_region(REGION_CPU1))[antic.pmbase_s+(o)+(antic.scanline>>1)]
-#define RDPMGFXD(o) (memory_region(REGION_CPU1))[antic.pmbase_d+(o)+antic.scanline]
-#endif
+#define RDANTIC(space)		memory_read_byte(space, antic.dpage+antic.doffs)
+#define RDVIDEO(space,o)	memory_read_byte(space, antic.vpage+((antic.voffs+(o))&VOFFS))
+#define RDCHGEN(space,o)	memory_read_byte(space, antic.chbase+(o))
+#define RDPMGFXS(space,o) 	memory_read_byte(space, antic.pmbase_s+(o)+(antic.scanline>>1))
+#define RDPMGFXD(space,o) 	memory_read_byte(space, antic.pmbase_d+(o)+antic.scanline)
 
 #define PREPARE()												\
 	UINT32 *dst = (UINT32 *)&antic.cclock[PMOFFSET]
 
-#define PREPARE_TXT2(width) 									\
+#define PREPARE_TXT2(space,width)								\
 	UINT32 *dst = (UINT32 *)&antic.cclock[PMOFFSET];			\
     int i;                                                      \
 	for( i = 0; i < width; i++ )								\
 	{															\
-		UINT16 ch = RDVIDEO(i) << 3;							\
+		UINT16 ch = RDVIDEO(space,i) << 3;						\
 		if( ch & 0x400 )										\
 		{														\
-			ch = RDCHGEN((ch & 0x3f8) + antic.w.chbasl);		\
+			ch = RDCHGEN(space,(ch & 0x3f8) + antic.w.chbasl);	\
 			ch = (ch ^ antic.chxor) & antic.chand;				\
 		}														\
 		else													\
 		{														\
-			ch = RDCHGEN(ch + antic.w.chbasl);					\
+			ch = RDCHGEN(space,ch + antic.w.chbasl);			\
 		}														\
 		video->data[i] = ch;									\
 	}
 
-#define PREPARE_TXT3(width) 									\
+#define PREPARE_TXT3(space,width)								\
 	UINT32 *dst = (UINT32 *)&antic.cclock[PMOFFSET];			\
     int i;                                                      \
 	for( i = 0; i < width; i++ )								\
 	{															\
-		UINT16 ch = RDVIDEO(i) << 3;							\
+		UINT16 ch = RDVIDEO(space,i) << 3;						\
 		if( ch & 0x400 )										\
 		{														\
 			ch &= 0x3f8;										\
@@ -364,14 +350,14 @@ typedef struct {
 				if (antic.w.chbasl < 2) /* first two lines empty */ \
 					ch = 0x00;									\
 				else /* lines 2..7 are standard, 8&9 are 0&1 */ \
-					ch = RDCHGEN(ch + (antic.w.chbasl & 7));	\
+					ch = RDCHGEN(space,ch + (antic.w.chbasl & 7));\
 			}													\
 			else												\
 			{													\
 				if (antic.w.chbasl > 7) /* last two lines empty */	\
 					ch = 0x00;									\
 				else /* lines 0..7 are standard */				\
-					ch = RDCHGEN(ch + antic.w.chbasl);			\
+					ch = RDCHGEN(space,ch + antic.w.chbasl);		\
 			}													\
 			ch = (ch ^ antic.chxor) & antic.chand;				\
 		}														\
@@ -382,87 +368,87 @@ typedef struct {
 				if (antic.w.chbasl < 2) /* first two lines empty */ \
 					ch = 0x00;									\
 				else /* lines 2..7 are standard, 8&9 are 0&1 */ \
-					ch = RDCHGEN(ch + (antic.w.chbasl & 7));	\
+					ch = RDCHGEN(space,ch + (antic.w.chbasl & 7));\
 			}													\
 			else												\
 			{													\
 				if (antic.w.chbasl > 7) /* last two lines empty */	\
 					ch = 0x00;									\
 				else /* lines 0..7 are standard */				\
-					ch = RDCHGEN(ch + antic.w.chbasl);			\
+					ch = RDCHGEN(space,ch + antic.w.chbasl);		\
 			}													\
 		}														\
         video->data[i] = ch;                                    \
 	}
 
-#define PREPARE_TXT45(width,shift)								\
+#define PREPARE_TXT45(space,width,shift)							\
 	UINT32 *dst = (UINT32 *)&antic.cclock[PMOFFSET];			\
     int i;                                                      \
 	for( i = 0; i < width; i++ )								\
 	{															\
-		UINT16 ch = RDVIDEO(i) << 3;							\
-		ch = ((ch>>2)&0x100)|RDCHGEN((ch&0x3f8)+(antic.w.chbasl>>shift)); \
+		UINT16 ch = RDVIDEO(space,i) << 3;						\
+		ch = ((ch>>2)&0x100)|RDCHGEN(space,(ch&0x3f8)+(antic.w.chbasl>>shift)); \
 		video->data[i] = ch;									\
 	}
 
 
-#define PREPARE_TXT67(width,shift)								\
+#define PREPARE_TXT67(space,width,shift)							\
 	UINT32 *dst = (UINT32 *)&antic.cclock[PMOFFSET];			\
     int i;                                                      \
 	for( i = 0; i < width; i++ )								\
 	{															\
-		UINT16 ch = RDVIDEO(i) << 3;							\
-		ch = (ch&0x600)|(RDCHGEN((ch&0x1f8)+(antic.w.chbasl>>shift))<<1); \
+		UINT16 ch = RDVIDEO(space,i) << 3;						\
+		ch = (ch&0x600)|(RDCHGEN(space,(ch&0x1f8)+(antic.w.chbasl>>shift))<<1); \
 		video->data[i] = ch;									\
 	}
 
-#define PREPARE_GFX8(width)                                     \
+#define PREPARE_GFX8(space,width)                                 \
 	UINT32 *dst = (UINT32 *)&antic.cclock[PMOFFSET];			\
     int i;                                                      \
 	for( i = 0; i < width; i++ )								\
-		video->data[i] = RDVIDEO(i) << 2
+		video->data[i] = RDVIDEO(space,i) << 2
 
-#define PREPARE_GFX9BC(width)									\
+#define PREPARE_GFX9BC(space,width)								\
 	UINT32 *dst = (UINT32 *)&antic.cclock[PMOFFSET];			\
     int i;                                                      \
 	for( i = 0; i < width; i++ )								\
-		video->data[i] = RDVIDEO(i) << 1
+		video->data[i] = RDVIDEO(space,i) << 1
 
-#define PREPARE_GFXA(width) 									\
+#define PREPARE_GFXA(space,width) 								\
 	UINT32 *dst = (UINT32 *)&antic.cclock[PMOFFSET];			\
     int i;                                                      \
 	for( i = 0; i < width; i++ )								\
-		video->data[i] = RDVIDEO(i) << 1
+		video->data[i] = RDVIDEO(space,i) << 1
 
-#define PREPARE_GFXDE(width)									\
+#define PREPARE_GFXDE(space,width)								\
 	UINT32 *dst = (UINT32 *)&antic.cclock[PMOFFSET];			\
     int i;                                                      \
 	for( i = 0; i < width; i++ )								\
-		video->data[i] = RDVIDEO(i)
+		video->data[i] = RDVIDEO(space,i)
 
-#define PREPARE_GFXF(width) 									\
+#define PREPARE_GFXF(space,width) 								\
 	UINT32 *dst = (UINT32 *)&antic.cclock[PMOFFSET];			\
     int i;                                                      \
 	for( i = 0; i < width; i++ )								\
-		video->data[i] = RDVIDEO(i)
+		video->data[i] = RDVIDEO(space,i)
 
-#define PREPARE_GFXG1(width)									\
+#define PREPARE_GFXG1(space,width)								\
 	UINT32 *dst = (UINT32 *)&antic.cclock[PMOFFSET];			\
     int i;                                                      \
 	for( i = 0; i < width; i++ )								\
-		video->data[i] = RDVIDEO(i)
+		video->data[i] = RDVIDEO(space,i)
 
-#define PREPARE_GFXG2(width)									\
+#define PREPARE_GFXG2(space,width)								\
 	UINT32 *dst = (UINT32 *)&antic.cclock[PMOFFSET];			\
     int i;                                                      \
 	for( i = 0; i < width; i++ )								\
-		video->data[i] = RDVIDEO(i)
+		video->data[i] = RDVIDEO(space,i)
 
-#define PREPARE_GFXG3(width)									\
+#define PREPARE_GFXG3(space,width)								\
 	UINT32 *dst = (UINT32 *)&antic.cclock[PMOFFSET];			\
     int i;                                                      \
 	for( i = 0; i < width; i++ )								\
-		video->data[i] = RDVIDEO(i)
+		video->data[i] = RDVIDEO(space,i)
 
 /******************************************************************
  * common end of a single antic/gtia mode emulation function
@@ -589,7 +575,7 @@ typedef struct {
 	FUNC(40); FUNC(41); FUNC(42); FUNC(43); \
 	FUNC(44); FUNC(45); FUNC(46); FUNC(47);
 
-typedef void (*renderer_function)(VIDEO *video);
+typedef void (*atari_renderer_func)(const address_space *space, VIDEO *video);
 
 /*----------- defined in video/antic.c -----------*/
 
@@ -600,49 +586,51 @@ void antic_reset(void);
  READ8_HANDLER ( atari_antic_r );
 WRITE8_HANDLER ( atari_antic_w );
 
-void antic_mode_0_xx(VIDEO *video);
-void antic_mode_2_32(VIDEO *video);
-void antic_mode_2_40(VIDEO *video);
-void antic_mode_2_48(VIDEO *video);
-void antic_mode_3_32(VIDEO *video);
-void antic_mode_3_40(VIDEO *video);
-void antic_mode_3_48(VIDEO *video);
-void antic_mode_4_32(VIDEO *video);
-void antic_mode_4_40(VIDEO *video);
-void antic_mode_4_48(VIDEO *video);
-void antic_mode_5_32(VIDEO *video);
-void antic_mode_5_40(VIDEO *video);
-void antic_mode_5_48(VIDEO *video);
-void antic_mode_6_32(VIDEO *video);
-void antic_mode_6_40(VIDEO *video);
-void antic_mode_6_48(VIDEO *video);
-void antic_mode_7_32(VIDEO *video);
-void antic_mode_7_40(VIDEO *video);
-void antic_mode_7_48(VIDEO *video);
-void antic_mode_8_32(VIDEO *video);
-void antic_mode_8_40(VIDEO *video);
-void antic_mode_8_48(VIDEO *video);
-void antic_mode_9_32(VIDEO *video);
-void antic_mode_9_40(VIDEO *video);
-void antic_mode_9_48(VIDEO *video);
-void antic_mode_a_32(VIDEO *video);
-void antic_mode_a_40(VIDEO *video);
-void antic_mode_a_48(VIDEO *video);
-void antic_mode_b_32(VIDEO *video);
-void antic_mode_b_40(VIDEO *video);
-void antic_mode_b_48(VIDEO *video);
-void antic_mode_c_32(VIDEO *video);
-void antic_mode_c_40(VIDEO *video);
-void antic_mode_c_48(VIDEO *video);
-void antic_mode_d_32(VIDEO *video);
-void antic_mode_d_40(VIDEO *video);
-void antic_mode_d_48(VIDEO *video);
-void antic_mode_e_32(VIDEO *video);
-void antic_mode_e_40(VIDEO *video);
-void antic_mode_e_48(VIDEO *video);
-void antic_mode_f_32(VIDEO *video);
-void antic_mode_f_40(VIDEO *video);
-void antic_mode_f_48(VIDEO *video);
+#define ANTIC_RENDERER(name) void name(const address_space *space, VIDEO *video)
+
+ANTIC_RENDERER( antic_mode_0_xx );
+ANTIC_RENDERER( antic_mode_2_32 );
+ANTIC_RENDERER( antic_mode_2_40 );
+ANTIC_RENDERER( antic_mode_2_48 );
+ANTIC_RENDERER( antic_mode_3_32 );
+ANTIC_RENDERER( antic_mode_3_40 );
+ANTIC_RENDERER( antic_mode_3_48 );
+ANTIC_RENDERER( antic_mode_4_32 );
+ANTIC_RENDERER( antic_mode_4_40 );
+ANTIC_RENDERER( antic_mode_4_48 );
+ANTIC_RENDERER( antic_mode_5_32 );
+ANTIC_RENDERER( antic_mode_5_40 );
+ANTIC_RENDERER( antic_mode_5_48 );
+ANTIC_RENDERER( antic_mode_6_32 );
+ANTIC_RENDERER( antic_mode_6_40 );
+ANTIC_RENDERER( antic_mode_6_48 );
+ANTIC_RENDERER( antic_mode_7_32 );
+ANTIC_RENDERER( antic_mode_7_40 );
+ANTIC_RENDERER( antic_mode_7_48 );
+ANTIC_RENDERER( antic_mode_8_32 );
+ANTIC_RENDERER( antic_mode_8_40 );
+ANTIC_RENDERER( antic_mode_8_48 );
+ANTIC_RENDERER( antic_mode_9_32 );
+ANTIC_RENDERER( antic_mode_9_40 );
+ANTIC_RENDERER( antic_mode_9_48 );
+ANTIC_RENDERER( antic_mode_a_32 );
+ANTIC_RENDERER( antic_mode_a_40 );
+ANTIC_RENDERER( antic_mode_a_48 );
+ANTIC_RENDERER( antic_mode_b_32 );
+ANTIC_RENDERER( antic_mode_b_40 );
+ANTIC_RENDERER( antic_mode_b_48 );
+ANTIC_RENDERER( antic_mode_c_32 );
+ANTIC_RENDERER( antic_mode_c_40 );
+ANTIC_RENDERER( antic_mode_c_48 );
+ANTIC_RENDERER( antic_mode_d_32 );
+ANTIC_RENDERER( antic_mode_d_40 );
+ANTIC_RENDERER( antic_mode_d_48 );
+ANTIC_RENDERER( antic_mode_e_32 );
+ANTIC_RENDERER( antic_mode_e_40 );
+ANTIC_RENDERER( antic_mode_e_48 );
+ANTIC_RENDERER( antic_mode_f_32 );
+ANTIC_RENDERER( antic_mode_f_40 );
+ANTIC_RENDERER( antic_mode_f_48 );
 
 /*----------- defined in video/atari.c -----------*/
 
