@@ -3,7 +3,7 @@
 /*----------- defined in audio/attckufo.c -----------*/
 
 void attckufo_soundport_w (int offset, int data);
-void *attckufo_custom_start(int clock, const struct CustomSound_interface *config);
+CUSTOM_START( attckufo_custom_start );
 
 
 /*----------- defined in video/attckufo.c -----------*/
