@@ -1,5 +1,8 @@
 #include "sound/discrete.h"
 
+#include "sound/samples.h"
+
+
 /*----------- defined in video/blockade.c -----------*/
 
 WRITE8_HANDLER( blockade_videoram_w );
@@ -9,7 +12,7 @@ VIDEO_UPDATE( blockade );
 
 /*----------- defined in audio/blockade.c -----------*/
 
-extern const struct Samplesinterface blockade_samples_interface;
+extern const samples_interface blockade_samples_interface;
 DISCRETE_SOUND_EXTERN( blockade );
 
 WRITE8_HANDLER( blockade_sound_freq_w );
