@@ -26,18 +26,18 @@ static UINT8 portC_out,ddrC;
 
 MACHINE_START( arkanoid )
 {
-	state_save_register_global(arkanoid_paddle_select);
-	state_save_register_global(z80write);
-	state_save_register_global(fromz80);
-	state_save_register_global(m68705write);
-	state_save_register_global(toz80);
+	state_save_register_global(machine, arkanoid_paddle_select);
+	state_save_register_global(machine, z80write);
+	state_save_register_global(machine, fromz80);
+	state_save_register_global(machine, m68705write);
+	state_save_register_global(machine, toz80);
 
-	state_save_register_global(portA_in);
-	state_save_register_global(portA_out);
-	state_save_register_global(ddrA);
+	state_save_register_global(machine, portA_in);
+	state_save_register_global(machine, portA_out);
+	state_save_register_global(machine, ddrA);
 
-	state_save_register_global(portC_out);
-	state_save_register_global(ddrC);
+	state_save_register_global(machine, portC_out);
+	state_save_register_global(machine, ddrC);
 }
 
 MACHINE_RESET( arkanoid )
@@ -60,9 +60,9 @@ static TIMER_CALLBACK( test )
 
 WRITE8_HANDLER( arkanoid_Z80_mcu_w )
 {
-	timer_call_after_resynch(NULL, data, test);
+	timer_call_after_resynch(space->machine, NULL, data, test);
 	/* boost the interleave for a few usecs to make sure it is read successfully */
-	cpu_boost_interleave(attotime_zero, ATTOTIME_IN_USEC(10));
+	cpuexec_boost_interleave(space->machine, attotime_zero, ATTOTIME_IN_USEC(10));
 }
 
 READ8_HANDLER( arkanoid_68705_portA_r )
@@ -117,36 +117,26 @@ WRITE8_HANDLER( arkanoid_68705_ddrC_w )
 	ddrC = data;
 }
 
-
-
-READ8_HANDLER( arkanoid_68705_input_0_r )
+CUSTOM_INPUT( arkanoid_68705_input_r )
 {
-	int res = input_port_0_r(offset) & 0x3f;
+	int res = 0;
 
-	/* bit 0x40 comes from the sticky bit */
-	if (!z80write) res |= 0x40;
+	/* bit 0x40 of comes from the sticky bit */
+	if (!z80write) res |= 0x01;
 
 	/* bit 0x80 comes from a write latch */
-	if (!m68705write) res |= 0x80;
+	if (!m68705write) res |= 0x02;
 
 	return res;
 }
 
-READ8_HANDLER( arkanoid_input_2_r )
+CUSTOM_INPUT( arkanoid_input_mux )
 {
-	if (arkanoid_paddle_select)
-	{
-		arkanoid_paddle_value = input_port_3_r(offset);
-	}
-	else
-	{
-		arkanoid_paddle_value = input_port_2_r(offset);
-	}
-
-	return arkanoid_paddle_value;
+	const char *tag1 = param;
+	const char *tag2 = tag1 + strlen(tag1) + 1;
+	return input_port_read(field->port->machine, (arkanoid_paddle_select == 0) ? tag1 : tag2);
 }
 
-
 /*
 
 Bootlegs stuff
@@ -194,9 +184,9 @@ TO DO (2006.09.12) :
 */
 
 
-#define LOG_F002_R if (ARKANOID_BOOTLEG_VERBOSE) logerror("%04x: arkanoid_bootleg_f002_r - cmd = %02x - val = %02x\n",activecpu_get_pc(),arkanoid_bootleg_cmd,arkanoid_bootleg_val);
-#define LOG_D018_W if (ARKANOID_BOOTLEG_VERBOSE) logerror("%04x: arkanoid_bootleg_d018_w - data = %02x - cmd = %02x\n",activecpu_get_pc(),data,arkanoid_bootleg_cmd);
-#define LOG_D008_R if (ARKANOID_BOOTLEG_VERBOSE) logerror("%04x: arkanoid_bootleg_d008_r - val = %02x\n",activecpu_get_pc(),arkanoid_bootleg_d008_val);
+#define LOG_F002_R if (ARKANOID_BOOTLEG_VERBOSE) logerror("%04x: arkanoid_bootleg_f002_r - cmd = %02x - val = %02x\n",cpu_get_pc(space->cpu),arkanoid_bootleg_cmd,arkanoid_bootleg_val);
+#define LOG_D018_W if (ARKANOID_BOOTLEG_VERBOSE) logerror("%04x: arkanoid_bootleg_d018_w - data = %02x - cmd = %02x\n",cpu_get_pc(space->cpu),data,arkanoid_bootleg_cmd);
+#define LOG_D008_R if (ARKANOID_BOOTLEG_VERBOSE) logerror("%04x: arkanoid_bootleg_d008_r - val = %02x\n",cpu_get_pc(space->cpu),arkanoid_bootleg_d008_val);
 
 
 static UINT8 arkanoid_bootleg_cmd;
@@ -280,7 +270,7 @@ READ8_HANDLER( arkanoid_bootleg_f002_r )
 			LOG_F002_R
 			break;
 		default:
-			logerror("%04x: arkanoid_bootleg_f002_r - cmd = %02x - unknown bootleg !\n",activecpu_get_pc(),arkanoid_bootleg_cmd);
+			logerror("%04x: arkanoid_bootleg_f002_r - cmd = %02x - unknown bootleg !\n",cpu_get_pc(space->cpu),arkanoid_bootleg_cmd);
 			break;
 	}
 
@@ -299,27 +289,27 @@ WRITE8_HANDLER( arkanoid_bootleg_d018_w )
 			switch (data)
 			{
 				case 0x36:  /* unneeded value : no call 0x2050, unused A and overwritten HL (0x0313 -> 0x0340) */
-					if (activecpu_get_pc() == 0x7c47)
+					if (cpu_get_pc(space->cpu) == 0x7c47)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x38:  /* unneeded value : no call 0x2050, unused A and fixed HL (0x7bd5) */
-					if (activecpu_get_pc() == 0x7b87)
+					if (cpu_get_pc(space->cpu) == 0x7b87)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x8a:  /* unneeded value : no call 0x2050, unused A and overwritten HL (0x7b77 -> 0x7c1c) */
-					if (activecpu_get_pc() == 0x9661)
+					if (cpu_get_pc(space->cpu) == 0x9661)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xe3:  /* unneeded value : call 0x2050 but fixed A (0x00) and fixed HL (0xed83) */
-					if (activecpu_get_pc() == 0x67e3)
+					if (cpu_get_pc(space->cpu) == 0x67e3)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xf7:  /* unneeded value : 3 * 'NOP' at 0x034f + 2 * 'NOP' at 0x35b */
-					if (activecpu_get_pc() == 0x0349)
+					if (cpu_get_pc(space->cpu) == 0x0349)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xff:  /* unneeded value : no call 0x2050, unused A and overwritten HL (0x7c4f -> 0x7d31) */
-					if (activecpu_get_pc() == 0x9670)
+					if (cpu_get_pc(space->cpu) == 0x9670)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				default:
@@ -332,37 +322,37 @@ WRITE8_HANDLER( arkanoid_bootleg_d018_w )
 			switch (data)
 			{
 				case 0x36:  /* unneeded value : call 0x2050 but fixed A (0x2d) */
-					if (activecpu_get_pc() == 0x7c4c)
+					if (cpu_get_pc(space->cpu) == 0x7c4c)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x38:  /* unneeded value : call 0x2050 but fixed A (0xf3) */
-					if (activecpu_get_pc() == 0x7b87)
+					if (cpu_get_pc(space->cpu) == 0x7b87)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x88:  /* unneeded value : no read back */
-					if (activecpu_get_pc() == 0x67e3)
+					if (cpu_get_pc(space->cpu) == 0x67e3)
 						arkanoid_bootleg_cmd = 0x00;
-					if (activecpu_get_pc() == 0x7c47)
+					if (cpu_get_pc(space->cpu) == 0x7c47)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x89:  /* unneeded value : no read back */
-					if (activecpu_get_pc() == 0x67e5)
+					if (cpu_get_pc(space->cpu) == 0x67e5)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x8a:  /* unneeded value : call 0x2050 but fixed A (0xa5) */
-					if (activecpu_get_pc() == 0x9661)
+					if (cpu_get_pc(space->cpu) == 0x9661)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xc0:  /* unneeded value : no read back */
-					if (activecpu_get_pc() == 0x67e7)
+					if (cpu_get_pc(space->cpu) == 0x67e7)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xe3:  /* unneeded value : call 0x2050 but fixed A (0x61) */
-					if (activecpu_get_pc() == 0x67e9)
+					if (cpu_get_pc(space->cpu) == 0x67e9)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xff:  /* unneeded value : call 0x2050 but fixed A (0xe2) */
-					if (activecpu_get_pc() == 0x9670)
+					if (cpu_get_pc(space->cpu) == 0x9670)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				default:
@@ -375,41 +365,41 @@ WRITE8_HANDLER( arkanoid_bootleg_d018_w )
 			switch (data)
 			{
 				case 0x36:  /* unneeded value : call 0x2050 but fixed A (0x2d) */
-					if (activecpu_get_pc() == 0x7c4c)
+					if (cpu_get_pc(space->cpu) == 0x7c4c)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x38:  /* unneeded value : call 0x2050 but fixed A (0xf3) */
-					if (activecpu_get_pc() == 0x7b87)
+					if (cpu_get_pc(space->cpu) == 0x7b87)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x88:  /* unneeded value : no read back */
-					if (activecpu_get_pc() == 0x67e3)
+					if (cpu_get_pc(space->cpu) == 0x67e3)
 						arkanoid_bootleg_cmd = 0x00;
-					if (activecpu_get_pc() == 0x7c47)
+					if (cpu_get_pc(space->cpu) == 0x7c47)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x89:  /* unneeded value : no read back */
-					if (activecpu_get_pc() == 0x67e5)
+					if (cpu_get_pc(space->cpu) == 0x67e5)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x8a:  /* unneeded value : call 0x2050 but unused HL and fixed DE (0x7c1c) */
-					if (activecpu_get_pc() == 0x9661)
+					if (cpu_get_pc(space->cpu) == 0x9661)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xc0:  /* unneeded value : no read back */
-					if (activecpu_get_pc() == 0x67e7)
+					if (cpu_get_pc(space->cpu) == 0x67e7)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xe3:  /* unneeded value : call 0x2050 but fixed A (0x61) */
-					if (activecpu_get_pc() == 0x67e9)
+					if (cpu_get_pc(space->cpu) == 0x67e9)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xf7:  /* unneeded value : call 0x2050 but never called (check code at 0x0340) */
-					if (activecpu_get_pc() == 0x0349)
+					if (cpu_get_pc(space->cpu) == 0x0349)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xff:  /* unneeded value : no call 0x2050, unused A and fixed HL (0x7d31) */
-					if (activecpu_get_pc() == 0x9670)
+					if (cpu_get_pc(space->cpu) == 0x9670)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				default:
@@ -422,40 +412,40 @@ WRITE8_HANDLER( arkanoid_bootleg_d018_w )
 			switch (data)
 			{
 				case 0x36:  /* unneeded value : call 0x2050 but fixed A (0x2d) */
-					if (activecpu_get_pc() == 0x7c4c)
+					if (cpu_get_pc(space->cpu) == 0x7c4c)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x38:  /* unneeded value : call 0x2050 but fixed A (0xf3) */
-					if (activecpu_get_pc() == 0x7b87)
+					if (cpu_get_pc(space->cpu) == 0x7b87)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x88:  /* unneeded value : no read back */
-					if (activecpu_get_pc() == 0x67e3)
+					if (cpu_get_pc(space->cpu) == 0x67e3)
 						arkanoid_bootleg_cmd = 0x00;
-					if (activecpu_get_pc() == 0x7c47)
+					if (cpu_get_pc(space->cpu) == 0x7c47)
 						arkanoid_bootleg_cmd = 0x00;
 				case 0x89:  /* unneeded value : no read back */
-					if (activecpu_get_pc() == 0x67e5)
+					if (cpu_get_pc(space->cpu) == 0x67e5)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x8a:  /* call 0x2050 with A read from 0xf002 and wrong HL */
-					if (activecpu_get_pc() == 0x9661)
+					if (cpu_get_pc(space->cpu) == 0x9661)
 						arkanoid_bootleg_cmd = data;
 					break;
 				case 0xc0:  /* unneeded value : no read back */
-					if (activecpu_get_pc() == 0x67e7)
+					if (cpu_get_pc(space->cpu) == 0x67e7)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xe3:  /* unneeded value : call 0x2050 but fixed A (0x61) */
-					if (activecpu_get_pc() == 0x67e9)
+					if (cpu_get_pc(space->cpu) == 0x67e9)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xf7:  /* unneeded value : 3 * 'NOP' at 0x034f + 'JR NZ,$035D' at 0x35b */
-					if (activecpu_get_pc() == 0x0349)
+					if (cpu_get_pc(space->cpu) == 0x0349)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xff:  /* call 0x2050 with A read from 0xf002 and wrong HL */
-					if (activecpu_get_pc() == 0x9670)
+					if (cpu_get_pc(space->cpu) == 0x9670)
 						arkanoid_bootleg_cmd = data;
 					break;
 				default:
@@ -468,48 +458,48 @@ WRITE8_HANDLER( arkanoid_bootleg_d018_w )
 			switch (data)
 			{
 				case 0x24:  /* A read from 0xf002 (expected to be 0x9b) */
-					if (activecpu_get_pc() == 0xbd7a)
+					if (cpu_get_pc(space->cpu) == 0xbd7a)
 						arkanoid_bootleg_cmd = data;
 					break;
 				case 0x36:  /* call 0x2050 with A read from 0xf002 and wrong HL */
-					if (activecpu_get_pc() == 0x7c4c)
+					if (cpu_get_pc(space->cpu) == 0x7c4c)
 						arkanoid_bootleg_cmd = data;
 					break;
 				case 0x38:  /* call 0x2050 with A read from 0xf002 and wrong HL */
-					if (activecpu_get_pc() == 0x7b87)
+					if (cpu_get_pc(space->cpu) == 0x7b87)
 						arkanoid_bootleg_cmd = data;
 					break;
 				case 0x88:  /* unneeded value : no read back */
-					if (activecpu_get_pc() == 0x67e3)
+					if (cpu_get_pc(space->cpu) == 0x67e3)
 						arkanoid_bootleg_cmd = 0x00;
-					if (activecpu_get_pc() == 0x7c47)
+					if (cpu_get_pc(space->cpu) == 0x7c47)
 						arkanoid_bootleg_cmd = 0x00;
 				case 0x89:  /* unneeded value : no read back */
-					if (activecpu_get_pc() == 0x67e5)
+					if (cpu_get_pc(space->cpu) == 0x67e5)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0x8a:  /* call 0x2050 with A read from 0xf002 and wrong HL */
-					if (activecpu_get_pc() == 0x9661)
+					if (cpu_get_pc(space->cpu) == 0x9661)
 						arkanoid_bootleg_cmd = data;
 					break;
 				case 0xc0:  /* unneeded value : no read back */
-					if (activecpu_get_pc() == 0x67e7)
+					if (cpu_get_pc(space->cpu) == 0x67e7)
 						arkanoid_bootleg_cmd = 0x00;
 					break;
 				case 0xc3:  /* A read from 0xf002 (expected to be 0x1d) */
-					if (activecpu_get_pc() == 0xbd8a)
+					if (cpu_get_pc(space->cpu) == 0xbd8a)
 						arkanoid_bootleg_cmd = data;
 					break;
 				case 0xe3:  /* call 0x2050 with A read from 0xf002 and wrong HL */
-					if (activecpu_get_pc() == 0x67e9)
+					if (cpu_get_pc(space->cpu) == 0x67e9)
 						arkanoid_bootleg_cmd = data;
 					break;
 				case 0xf7:  /* call 0x2050 with A read from 0xf002 and wrong HL */
-					if (activecpu_get_pc() == 0x0349)
+					if (cpu_get_pc(space->cpu) == 0x0349)
 						arkanoid_bootleg_cmd = data;
 					break;
 				case 0xff:  /* call 0x2050 with A read from 0xf002 and wrong HL */
-					if (activecpu_get_pc() == 0x9670)
+					if (cpu_get_pc(space->cpu) == 0x9670)
 						arkanoid_bootleg_cmd = data;
 					break;
 				default:
@@ -519,7 +509,7 @@ WRITE8_HANDLER( arkanoid_bootleg_d018_w )
 			LOG_D018_W
 			break;
 		default:
-			logerror("%04x: arkanoid_bootleg_d018_w - data = %02x - unknown bootleg !\n",activecpu_get_pc(),data);
+			logerror("%04x: arkanoid_bootleg_d018_w - data = %02x - unknown bootleg !\n",cpu_get_pc(space->cpu),data);
 			break;
 	}
 }
@@ -577,7 +567,7 @@ READ8_HANDLER( arkanoid_bootleg_d008_r )
 			arkanoid_bootleg_d008_bit[2] = 0;  /* untested bit */
 			arkanoid_bootleg_d008_bit[3] = 0;  /* untested bit */
 			arkanoid_bootleg_d008_bit[5] = 0;  /* untested bit */
-			logerror("%04x: arkanoid_bootleg_d008_r - unknown bootleg !\n",activecpu_get_pc());
+			logerror("%04x: arkanoid_bootleg_d008_r - unknown bootleg !\n",cpu_get_pc(space->cpu));
 			break;
 	}
 
