@@ -9,7 +9,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "cpu/m6502/m6502.h"
 #include "includes/atari.h"
 #include "sound/pokey.h"
@@ -35,12 +34,12 @@ static int a800_cart_loaded = 0;
 static int a800_cart_is_16k = 0;
 #endif
 
-static void a800xl_mmu(UINT8 new_mmu);
-static void a600xl_mmu(UINT8 new_mmu);
+static void a800xl_mmu(running_machine *machine, UINT8 new_mmu);
+static void a600xl_mmu(running_machine *machine, UINT8 new_mmu);
 
 static void pokey_reset(running_machine *machine);
 
-void atari_interrupt_cb(int mask)
+void atari_interrupt_cb(running_machine *machine, int mask)
 {
 
 	if (VERBOSE_POKEY)
@@ -69,7 +68,7 @@ void atari_interrupt_cb(int mask)
 			logerror("atari interrupt_cb TIMR1\n");
 	}
 
-	cpunum_set_input_line(Machine, 0, 0, HOLD_LINE);
+	cpu_set_input_line(machine->cpu[0], 0, HOLD_LINE);
 }
 
 /**************************************************************
@@ -80,16 +79,16 @@ void atari_interrupt_cb(int mask)
 
 static READ8_HANDLER(atari_pia_pa_r)
 {
-	return atari_input_disabled() ? 0xFF : readinputportbytag_safe("djoy_0_1", 0);
+	return atari_input_disabled() ? 0xFF : input_port_read_safe(space->machine, "djoy_0_1", 0);
 }
 
 static READ8_HANDLER(atari_pia_pb_r)
 {
-	return atari_input_disabled() ? 0xFF : readinputportbytag_safe("djoy_2_3", 0);
+	return atari_input_disabled() ? 0xFF : input_port_read_safe(space->machine, "djoy_2_3", 0);
 }
 
-static WRITE8_HANDLER(a600xl_pia_pb_w) { a600xl_mmu(data); }
-static WRITE8_HANDLER(a800xl_pia_pb_w) { a800xl_mmu(data); }
+static WRITE8_HANDLER(a600xl_pia_pb_w) { a600xl_mmu(space->machine, data); }
+static WRITE8_HANDLER(a800xl_pia_pb_w) { a800xl_mmu(space->machine, data); }
 
 #ifdef MESS
 extern WRITE8_HANDLER(atari_pia_cb2_w);
@@ -127,101 +126,96 @@ static const pia6821_interface a800xl_pia_interface =
  *
  **************************************************************/
 
-void a600xl_mmu(UINT8 new_mmu)
+void a600xl_mmu(running_machine *machine, UINT8 new_mmu)
 {
-	read8_handler rbank2;
-	write8_handler wbank2;
+	read8_space_func rbank2;
+	write8_space_func wbank2;
 
 	/* check if self-test ROM changed */
 	if ( new_mmu & 0x80 )
 	{
-		logerror("%s MMU SELFTEST RAM\n", Machine->gamedrv->name);
-		rbank2 = MRA8_NOP;
-		wbank2 = MWA8_NOP;
+		logerror("%s MMU SELFTEST RAM\n", machine->gamedrv->name);
+		rbank2 = SMH_NOP;
+		wbank2 = SMH_NOP;
 	}
 	else
 	{
-		logerror("%s MMU SELFTEST ROM\n", Machine->gamedrv->name);
-		rbank2 = MRA8_BANK2;
-		wbank2 = MWA8_ROM;
+		logerror("%s MMU SELFTEST ROM\n", machine->gamedrv->name);
+		rbank2 = SMH_BANK2;
+		wbank2 = SMH_UNMAP;
 	}
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0x57ff, 0, 0, rbank2);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0x57ff, 0, 0, wbank2);
-	if (rbank2 == MRA8_BANK2)
-		memory_set_bankptr(2, memory_region(REGION_CPU1)+0x5000);
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x5000, 0x57ff, 0, 0, rbank2, wbank2);
+	if (rbank2 == SMH_BANK2)
+		memory_set_bankptr(machine, 2, memory_region(machine, "main")+0x5000);
 }
 
-void a800xl_mmu(UINT8 new_mmu)
+void a800xl_mmu(running_machine *machine, UINT8 new_mmu)
 {
-	read8_handler rbank1, rbank2, rbank3, rbank4;
-	write8_handler wbank1, wbank2, wbank3, wbank4;
+	read8_space_func rbank1, rbank2, rbank3, rbank4;
+	write8_space_func wbank1, wbank2, wbank3, wbank4;
 	UINT8 *base1, *base2, *base3, *base4;
 
 	/* check if memory C000-FFFF changed */
 	if( new_mmu & 0x01 )
 	{
-		logerror("%s MMU BIOS ROM\n", Machine->gamedrv->name);
-		rbank3 = MRA8_BANK3;
-		wbank3 = MWA8_ROM;
-		base3 = memory_region(REGION_CPU1)+0x14000;  /* 8K lo BIOS */
-		rbank4 = MRA8_BANK4;
-		wbank4 = MWA8_ROM;
-		base4 = memory_region(REGION_CPU1)+0x15800;  /* 4K FP ROM + 8K hi BIOS */
+		logerror("%s MMU BIOS ROM\n", machine->gamedrv->name);
+		rbank3 = SMH_BANK3;
+		wbank3 = SMH_UNMAP;
+		base3 = memory_region(machine, "main")+0x14000;  /* 8K lo BIOS */
+		rbank4 = SMH_BANK4;
+		wbank4 = SMH_UNMAP;
+		base4 = memory_region(machine, "main")+0x15800;  /* 4K FP ROM + 8K hi BIOS */
 	}
 	else
 	{
-		logerror("%s MMU BIOS RAM\n", Machine->gamedrv->name);
-		rbank3 = MRA8_BANK3;
-		wbank3 = MWA8_BANK3;
-		base3 = memory_region(REGION_CPU1)+0x0c000;  /* 8K RAM */
-		rbank4 = MRA8_BANK4;
-		wbank4 = MWA8_BANK4;
-		base4 = memory_region(REGION_CPU1)+0x0d800;  /* 4K RAM + 8K RAM */
+		logerror("%s MMU BIOS RAM\n", machine->gamedrv->name);
+		rbank3 = SMH_BANK3;
+		wbank3 = SMH_BANK3;
+		base3 = memory_region(machine, "main")+0x0c000;  /* 8K RAM */
+		rbank4 = SMH_BANK4;
+		wbank4 = SMH_BANK4;
+		base4 = memory_region(machine, "main")+0x0d800;  /* 4K RAM + 8K RAM */
 	}
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, rbank3);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, wbank3);
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd800, 0xffff, 0, 0, rbank4);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd800, 0xffff, 0, 0, wbank4);
-	memory_set_bankptr(3, base3);
-	memory_set_bankptr(4, base4);
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xc000, 0xcfff, 0, 0, rbank3, wbank3);
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xd800, 0xffff, 0, 0, rbank4, wbank4);
+	memory_set_bankptr(machine, 3, base3);
+	memory_set_bankptr(machine, 4, base4);
 
 	/* check if BASIC changed */
 	if( new_mmu & 0x02 )
 	{
-		logerror("%s MMU BASIC RAM\n", Machine->gamedrv->name);
-		rbank1 = MRA8_BANK1;
-		wbank1 = MWA8_BANK1;
-		base1 = memory_region(REGION_CPU1)+0x0a000;  /* 8K RAM */
+		logerror("%s MMU BASIC RAM\n", machine->gamedrv->name);
+		rbank1 = SMH_BANK1;
+		wbank1 = SMH_BANK1;
+		base1 = memory_region(machine, "main")+0x0a000;  /* 8K RAM */
 	}
 	else
 	{
-		logerror("%s MMU BASIC ROM\n", Machine->gamedrv->name);
-		rbank1 = MRA8_BANK1;
-		wbank1 = MWA8_ROM;
-		base1 = memory_region(REGION_CPU1)+0x10000;  /* 8K BASIC */
+		logerror("%s MMU BASIC ROM\n", machine->gamedrv->name);
+		rbank1 = SMH_BANK1;
+		wbank1 = SMH_UNMAP;
+		base1 = memory_region(machine, "main")+0x10000;  /* 8K BASIC */
 	}
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa000, 0xbfff, 0, 0, rbank1);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xa000, 0xbfff, 0, 0, wbank1);
-	memory_set_bankptr(1, base1);
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xa000, 0xbfff, 0, 0, rbank1, wbank1);
+	memory_set_bankptr(machine, 1, base1);
 
 	/* check if self-test ROM changed */
 	if( new_mmu & 0x80 )
 	{
-		logerror("%s MMU SELFTEST RAM\n", Machine->gamedrv->name);
-		rbank2 = MRA8_BANK2;
-		wbank2 = MWA8_BANK2;
-		base2 = memory_region(REGION_CPU1)+0x05000;  /* 0x0800 bytes */
+		logerror("%s MMU SELFTEST RAM\n", machine->gamedrv->name);
+		rbank2 = SMH_BANK2;
+		wbank2 = SMH_BANK2;
+		base2 = memory_region(machine, "main")+0x05000;  /* 0x0800 bytes */
 	}
 	else
 	{
-		logerror("%s MMU SELFTEST ROM\n", Machine->gamedrv->name);
-		rbank2 = MRA8_BANK2;
-		wbank2 = MWA8_ROM;
-		base2 = memory_region(REGION_CPU1)+0x15000;  /* 0x0800 bytes */
+		logerror("%s MMU SELFTEST ROM\n", machine->gamedrv->name);
+		rbank2 = SMH_BANK2;
+		wbank2 = SMH_UNMAP;
+		base2 = memory_region(machine, "main")+0x15000;  /* 0x0800 bytes */
 	}
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0x57ff, 0, 0, rbank2);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5000, 0x57ff, 0, 0, wbank2);
-	memory_set_bankptr(2, base2);
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x5000, 0x57ff, 0, 0, rbank2, wbank2);
+	memory_set_bankptr(machine, 2, base2);
 }
 
 
@@ -521,7 +515,7 @@ static const UINT8 keys[64][4] = {
 };
 
 
-void a800_handle_keyboard(void)
+void a800_handle_keyboard(running_machine *machine)
 {
 	static int atari_last = 0xff;
 	int i, modifiers, atari_code;
@@ -540,7 +534,7 @@ void a800_handle_keyboard(void)
 	for( i = 0; i < 64; i++ )
 	{
 		sprintf(tag, "keyboard_%d", i / 16);
-		if( readinputportbytag_safe(tag, 0) & (1 << (i&15)) )
+		if( input_port_read_safe(machine, tag, 0) & (1 << (i&15)) )
 		{
 			atari_code = keys[i][modifiers];
 			if( atari_code != AKEY_NONE )
@@ -566,7 +560,7 @@ void a800_handle_keyboard(void)
 #define VKEY_BREAK		0x10
 
 /* absolutely no clue what to do here :((( */
-void a5200_handle_keypads(void)
+void a5200_handle_keypads(running_machine *machine)
 {
 	int i, modifiers;
 	static int atari_last = 0xff;
@@ -584,7 +578,7 @@ void a5200_handle_keypads(void)
 	/* check keypad */
 	for (i = 0; i < 16; i++)
 	{
-		if( readinputportbytag("keypad") & (1 << i) )
+		if( input_port_read(machine, "keypad") & (1 << i) )
 		{
 			if( i == atari_last )
 				return;
@@ -600,7 +594,7 @@ void a5200_handle_keypads(void)
 	}
 
 	/* check top button */
-	if ((readinputportbytag("djoy_b") & 0x10) == 0)
+	if ((input_port_read(machine, "djoy_b") & 0x10) == 0)
 	{
 		if (atari_last == 0xFE)
 			return;
@@ -638,11 +632,11 @@ DRIVER_INIT( atari )
 
 	/* install RAM */
 	ram_top = MIN(mess_ram_size, ram_size) - 1;
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM,
-		0x0000, ram_top, 0, 0, MRA8_BANK2);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM,
-		0x0000, ram_top, 0, 0, MWA8_BANK2);
-	memory_set_bankptr(2, mess_ram);
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM),
+		0x0000, ram_top, 0, 0, SMH_BANK2);
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM),
+		0x0000, ram_top, 0, 0, SMH_BANK2);
+	memory_set_bankptr(machine, 2, mess_ram);
 }
 #endif
 
@@ -655,11 +649,11 @@ DRIVER_INIT( atari )
  *************************************/
 
 #ifdef MESS
-static void a800_setbank(int n)
+static void a800_setbank(running_machine *machine, int n)
 {
 	void *read_addr;
 	void *write_addr;
-	UINT8 *mem = memory_region(REGION_CPU1);
+	UINT8 *mem = memory_region(machine, "main");
 
 	switch (n)
 	{
@@ -682,14 +676,14 @@ static void a800_setbank(int n)
 			break;
 	}
 
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xbfff, 0, 0,
-		read_addr ? MRA8_BANK1 : MRA8_NOP);
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xbfff, 0, 0,
-		write_addr ? MWA8_BANK1 : MWA8_NOP);
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x8000, 0xbfff, 0, 0,
+		read_addr ? SMH_BANK1 : SMH_NOP);
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x8000, 0xbfff, 0, 0,
+		write_addr ? SMH_BANK1 : SMH_NOP);
 	if (read_addr)
-		memory_set_bankptr(1, read_addr);
+		memory_set_bankptr(machine, 1, read_addr);
 	if (write_addr)
-		memory_set_bankptr(1, write_addr);
+		memory_set_bankptr(machine, 1, write_addr);
 }
 #endif
 
@@ -697,7 +691,8 @@ static void a800_setbank(int n)
 
 static void pokey_reset(running_machine *machine)
 {
-	pokey1_w(15,0);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	pokey1_w(space,15,0);
 }
 
 
@@ -706,25 +701,25 @@ static void cart_reset(running_machine *machine)
 {
 #ifdef MESS
 	if (a800_cart_loaded)
-		a800_setbank(1);
+		a800_setbank(machine, 1);
 #endif /* MESS */
 }
 
 
 
-static UINT8 console_read(void)
+static UINT8 console_read(const address_space *space)
 {
-	return readinputportbytag("console");
+	return input_port_read(space->machine, "console");
 }
 
 
 
-static void console_write(UINT8 data)
+static void console_write(const address_space *space, UINT8 data)
 {
 	if (data & 0x08)
-		DAC_data_w(0, -120);
+		dac_data_w(0, -120);
 	else
-		DAC_data_w(0, +120);
+		dac_data_w(0, +120);
 }
 
 
@@ -739,7 +734,7 @@ static void _antic_reset(running_machine *machine)
 }
 
 
-static void atari_machine_start(int type, const pia6821_interface *pia_intf, int has_cart)
+static void atari_machine_start(running_machine *machine, int type, const pia6821_interface *pia_intf, int has_cart)
 {
 	gtia_interface gtia_intf;
 
@@ -747,39 +742,39 @@ static void atari_machine_start(int type, const pia6821_interface *pia_intf, int
 
 	/* GTIA */
 	memset(&gtia_intf, 0, sizeof(gtia_intf));
-	if (port_tag_to_index("console") >= 0)
+	if (input_port_by_tag(machine->portconfig, "console") != NULL)
 		gtia_intf.console_read = console_read;
 	if (sndti_exists(SOUND_DAC, 0))
 		gtia_intf.console_write = console_write;
-	gtia_init(&gtia_intf);
+	gtia_init(machine, &gtia_intf);
 
 	/* pokey */
-	add_reset_callback(Machine, pokey_reset);
+	add_reset_callback(machine, pokey_reset);
 
 	/* PIA */
 	if (pia_intf)
 	{
-		pia_config(0, pia_intf);
-		add_reset_callback(Machine, _pia_reset);
+		pia_config(machine, 0, pia_intf);
+		add_reset_callback(machine, _pia_reset);
 	}
 
 	/* ANTIC */
-	add_reset_callback(Machine, _antic_reset);
+	add_reset_callback(machine, _antic_reset);
 
 	/* cartridge */
 	if (has_cart)
-		add_reset_callback(Machine, cart_reset);
+		add_reset_callback(machine, cart_reset);
 
 #ifdef MESS
 	{
 		offs_t ram_top;
 		offs_t ram_size;
 
-		if (!strcmp(Machine->gamedrv->name, "a400")
-			|| !strcmp(Machine->gamedrv->name, "a400pal")
-			|| !strcmp(Machine->gamedrv->name, "a800")
-			|| !strcmp(Machine->gamedrv->name, "a800pal")
-			|| !strcmp(Machine->gamedrv->name, "a800xl"))
+		if (!strcmp(machine->gamedrv->name, "a400")
+			|| !strcmp(machine->gamedrv->name, "a400pal")
+			|| !strcmp(machine->gamedrv->name, "a800")
+			|| !strcmp(machine->gamedrv->name, "a800pal")
+			|| !strcmp(machine->gamedrv->name, "a800xl"))
 		{
 			ram_size = 0xA000;
 		}
@@ -790,17 +785,17 @@ static void atari_machine_start(int type, const pia6821_interface *pia_intf, int
 
 		/* install RAM */
 		ram_top = MIN(mess_ram_size, ram_size) - 1;
-		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM,
-			0x0000, ram_top, 0, 0, MRA8_BANK2);
-		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM,
-			0x0000, ram_top, 0, 0, MWA8_BANK2);
-		memory_set_bankptr(2, mess_ram);
+		memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM),
+			0x0000, ram_top, 0, 0, SMH_BANK2);
+		memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM),
+			0x0000, ram_top, 0, 0, SMH_BANK2);
+		memory_set_bankptr(machine, 2, mess_ram);
 	}
 #endif /* MESS */
 
 	/* save states */
-	state_save_register_global_pointer(((UINT8 *) &antic.r), sizeof(antic.r));
-	state_save_register_global_pointer(((UINT8 *) &antic.w), sizeof(antic.w));
+	state_save_register_global_pointer(machine, ((UINT8 *) &antic.r), sizeof(antic.r));
+	state_save_register_global_pointer(machine, ((UINT8 *) &antic.w), sizeof(antic.w));
 }
 
 
@@ -814,12 +809,12 @@ static void atari_machine_start(int type, const pia6821_interface *pia_intf, int
 
 MACHINE_START( a400 )
 {
-	atari_machine_start(ATARI_400, &atari_pia_interface, TRUE);
+	atari_machine_start(machine, ATARI_400, &atari_pia_interface, TRUE);
 }
 
 MACHINE_START( a600xl )
 {
-	atari_machine_start(ATARI_600XL, &a600xl_pia_interface, TRUE);
+	atari_machine_start(machine, ATARI_600XL, &a600xl_pia_interface, TRUE);
 }
 
 
@@ -832,23 +827,23 @@ MACHINE_START( a600xl )
 
 MACHINE_START( a800 )
 {
-	atari_machine_start(ATARI_800, &atari_pia_interface, TRUE);
+	atari_machine_start(machine, ATARI_800, &atari_pia_interface, TRUE);
 }
 
 
 
 #ifdef MESS
-DEVICE_LOAD( a800_cart )
+DEVICE_IMAGE_LOAD( a800_cart )
 {
-	UINT8 *mem = memory_region(REGION_CPU1);
+	UINT8 *mem = memory_region(image->machine, "main");
 	int size;
 
 	/* load an optional (dual) cartridge (e.g. basic.rom) */
-	if( image_index_in_device(image) > 0 )
+	if( strcmp(image->tag,"cart2") == 0 )
 	{
 		size = image_fread(image, &mem[0x12000], 0x2000);
 		a800_cart_is_16k = (size == 0x2000);
-		logerror("%s loaded right cartridge '%s' size 16K\n", Machine->gamedrv->name, image_filename(image) );
+		logerror("%s loaded right cartridge '%s' size 16K\n", image->machine->gamedrv->name, image_filename(image) );
 	}
 	else
 	{
@@ -856,22 +851,22 @@ DEVICE_LOAD( a800_cart )
 		a800_cart_loaded = size > 0x0000;
 		size = image_fread(image, &mem[0x12000], 0x2000);
 		a800_cart_is_16k = size > 0x2000;
-		logerror("%s loaded left cartridge '%s' size %s\n", Machine->gamedrv->name, image_filename(image) , (a800_cart_is_16k) ? "16K":"8K");
+		logerror("%s loaded left cartridge '%s' size %s\n", image->machine->gamedrv->name, image_filename(image) , (a800_cart_is_16k) ? "16K":"8K");
 	}
 	return INIT_PASS;
 }
 
-DEVICE_UNLOAD( a800_cart )
+DEVICE_IMAGE_UNLOAD( a800_cart )
 {
-	if( image_index_in_device(image) > 0 )
+	if( strcmp(image->tag,"cart2") == 0 )
 	{
 		a800_cart_is_16k = 0;
-		a800_setbank(1);
+		a800_setbank(image->machine, 1);
     }
 	else
 	{
 		a800_cart_loaded = 0;
-		a800_setbank(0);
+		a800_setbank(image->machine, 0);
     }
 }
 #endif
@@ -886,21 +881,21 @@ DEVICE_UNLOAD( a800_cart )
 
 MACHINE_START( a800xl )
 {
-	atari_machine_start(ATARI_800XL, &a800xl_pia_interface, TRUE);
+	atari_machine_start(machine, ATARI_800XL, &a800xl_pia_interface, TRUE);
 }
 
 
 
 #ifdef MESS
-DEVICE_LOAD( a800xl_cart )
+DEVICE_IMAGE_LOAD( a800xl_cart )
 {
-	UINT8 *mem = memory_region(REGION_CPU1);
+	UINT8 *mem = memory_region(image->machine, "main");
 	astring *fname;
 	mame_file *basic_fp;
 	file_error filerr;
 	unsigned size;
 
-	fname = astring_assemble_3(astring_alloc(), Machine->gamedrv->name, PATH_SEPARATOR, "basic.rom");
+	fname = astring_assemble_3(astring_alloc(), image->machine->gamedrv->name, PATH_SEPARATOR, "basic.rom");
 	filerr = mame_fopen(SEARCHPATH_ROM, astring_c(fname), OPEN_FLAG_READ, &basic_fp);
 	astring_free(fname);
 
@@ -909,7 +904,7 @@ DEVICE_LOAD( a800xl_cart )
 		size = mame_fread(basic_fp, &mem[0x14000], 0x2000);
 		if( size < 0x2000 )
 		{
-			logerror("%s image '%s' load failed (less than 8K)\n", Machine->gamedrv->name, astring_c(fname));
+			logerror("%s image '%s' load failed (less than 8K)\n", image->machine->gamedrv->name, astring_c(fname));
 			mame_fclose(basic_fp);
 			return 2;
 		}
@@ -924,7 +919,7 @@ DEVICE_LOAD( a800xl_cart )
 			size = image_fread(image, &mem[0x16000], 0x2000);
 			a800_cart_is_16k = size / 0x2000;
 			logerror("%s loaded cartridge '%s' size %s\n",
-					Machine->gamedrv->name, image_filename(image), (a800_cart_is_16k) ? "16K":"8K");
+					image->machine->gamedrv->name, image_filename(image), (a800_cart_is_16k) ? "16K":"8K");
 		}
 		mame_fclose(basic_fp);
 	}
@@ -943,15 +938,15 @@ DEVICE_LOAD( a800xl_cart )
 
 MACHINE_START( a5200 )
 {
-	atari_machine_start(ATARI_800XL, NULL, FALSE);
+	atari_machine_start(machine, ATARI_800XL, NULL, FALSE);
 }
 
 
 
 #ifdef MESS
-DEVICE_LOAD( a5200_cart )
+DEVICE_IMAGE_LOAD( a5200_cart )
 {
-	UINT8 *mem = memory_region(REGION_CPU1);
+	UINT8 *mem = memory_region(image->machine, "main");
 	int size;
 
 	/* load an optional (dual) cartidge */
@@ -972,14 +967,14 @@ DEVICE_LOAD( a5200_cart )
 		}
 	}
 	logerror("%s loaded cartridge '%s' size %dK\n",
-		Machine->gamedrv->name, image_filename(image) , size/1024);
+		image->machine->gamedrv->name, image_filename(image) , size/1024);
 	return INIT_PASS;
 }
 
-DEVICE_UNLOAD( a5200_cart )
+DEVICE_IMAGE_UNLOAD( a5200_cart )
 {
-	UINT8 *mem = memory_region(REGION_CPU1);
-    /* zap the cartridge memory (again) */
+	UINT8 *mem = memory_region(image->machine, "main");
+	/* zap the cartridge memory (again) */
 	memset(&mem[0x4000], 0x00, 0x8000);
 }
 #endif
