@@ -8,7 +8,6 @@
 
 
 #include "driver.h"
-#include "deprecat.h"
 #include "atarigen.h"
 #include "slapstic.h"
 #include "cpu/m6502/m6502.h"
@@ -65,34 +64,43 @@ struct atarivc_state_desc atarivc_state;
     STATIC VARIABLES
 ***************************************************************************/
 
-static atarigen_int_callback update_int_callback;
-static emu_timer * scanline_interrupt_timer;
+static atarigen_int_func update_int_callback;
 
-static UINT8 			eeprom_unlocked;
+static UINT8 					eeprom_unlocked;
 
-static UINT8			atarigen_slapstic_num;
-static UINT16 *			atarigen_slapstic;
-static UINT8			atarigen_slapstic_bank;
-static void *			atarigen_slapstic_bank0;
+static UINT8					atarigen_slapstic_num;
+static UINT16 *					atarigen_slapstic;
+static UINT8					atarigen_slapstic_bank;
+static void *					atarigen_slapstic_bank0;
+static offs_t					atarigen_slapstic_last_pc;
+static offs_t					atarigen_slapstic_last_address;
+static offs_t					atarigen_slapstic_base;
+static offs_t					atarigen_slapstic_mirror;
 
-static UINT8 			sound_cpu_num;
-static UINT8 			atarigen_cpu_to_sound;
-static UINT8 			atarigen_sound_to_cpu;
-static UINT8 			timed_int;
-static UINT8 			ym2151_int;
+static const device_config *	sound_cpu;
+static UINT8 					atarigen_cpu_to_sound;
+static UINT8 					atarigen_sound_to_cpu;
+static UINT8 					timed_int;
+static UINT8 					ym2151_int;
 
-static atarigen_scanline_callback scanline_callback;
-static UINT32 			scanlines_per_callback;
+static atarigen_scanline_func 	scanline_callback;
+static UINT32 					scanlines_per_callback;
 
-static UINT32 			actual_vc_latch0;
-static UINT32 			actual_vc_latch1;
-static UINT8			atarivc_playfields;
+static UINT32 					actual_vc_latch0;
+static UINT32 					actual_vc_latch1;
+static UINT8					atarivc_playfields;
 
-static UINT32			playfield_latch;
-static UINT32			playfield2_latch;
+static UINT32					playfield_latch;
+static UINT32					playfield2_latch;
 
-static emu_timer *		scanline_timer[ATARIMO_MAX];
-static emu_timer *		atarivc_eof_update_timer[ATARIMO_MAX];
+static const device_config *	scanline_interrupt_timer_screens[ATARIMO_MAX];
+static emu_timer *				scanline_interrupt_timers[ATARIMO_MAX];
+
+static const device_config *	scanline_timer_screens[ATARIMO_MAX];
+static emu_timer *				scanline_timers[ATARIMO_MAX];
+
+static const device_config *	atarivc_eof_update_timer_screens[ATARIMO_MAX];
+static emu_timer *				atarivc_eof_update_timers[ATARIMO_MAX];
 
 
 
@@ -105,7 +113,7 @@ static TIMER_CALLBACK( scanline_interrupt_callback );
 static void decompress_eeprom_word(const UINT16 *data);
 static void decompress_eeprom_byte(const UINT16 *data);
 
-static void update_6502_irq(void);
+static void update_6502_irq(running_machine *machine);
 static TIMER_CALLBACK( delayed_sound_reset );
 static TIMER_CALLBACK( delayed_sound_w );
 static TIMER_CALLBACK( delayed_6502_sound_w );
@@ -114,7 +122,7 @@ static void atarigen_set_vol(running_machine *machine, int volume, sound_type ty
 
 static TIMER_CALLBACK( scanline_timer_callback );
 
-static void atarivc_common_w(int scrnum, offs_t offset, UINT16 newword);
+static void atarivc_common_w(const device_config *screen, offs_t offset, UINT16 newword);
 
 static TIMER_CALLBACK( unhalt_cpu );
 
@@ -131,7 +139,7 @@ static TIMER_CALLBACK( atarivc_eof_update );
     the interrupt sources.
 ---------------------------------------------------------------*/
 
-void atarigen_interrupt_reset(atarigen_int_callback update_int)
+void atarigen_interrupt_reset(atarigen_int_func update_int)
 {
 	int i;
 
@@ -140,14 +148,15 @@ void atarigen_interrupt_reset(atarigen_int_callback update_int)
 
 	/* reset the interrupt states */
 	atarigen_video_int_state = atarigen_sound_int_state = atarigen_scanline_int_state = 0;
-	scanline_interrupt_timer = NULL;
 
-	/* create timers */
+	/* clear the timers */
 	for (i = 0; i < ATARIMO_MAX; i++)
-		scanline_timer[i] = timer_alloc(scanline_timer_callback, NULL);
-
-	/* create a timer for scanlines */
-	scanline_interrupt_timer = timer_alloc(scanline_interrupt_callback, NULL);
+	{
+		scanline_interrupt_timer_screens[i] = NULL;
+		scanline_interrupt_timers[i] = NULL;
+		scanline_timer_screens[i] = NULL;
+		scanline_timers[i] = NULL;
+	}
 }
 
 
@@ -157,21 +166,57 @@ void atarigen_interrupt_reset(atarigen_int_callback update_int)
     states.
 ---------------------------------------------------------------*/
 
-void atarigen_update_interrupts(void)
+void atarigen_update_interrupts(running_machine *machine)
 {
-	(*update_int_callback)(Machine);
+	(*update_int_callback)(machine);
 }
 
 
+/*---------------------------------------------------------------
+    get_scanline_interrupt_timer_for_screen: Retrieves or
+    creates a scanline interrupt timer.
+---------------------------------------------------------------*/
+
+static emu_timer *get_scanline_interrupt_timer_for_screen(const device_config *screen)
+{
+	int i;
+
+	/* find the index of the timer that matches the screen */
+	for (i = 0; i < ATARIMO_MAX; i++)
+	{
+		/* matching */
+		if (scanline_interrupt_timer_screens[i] == screen)
+			break;
+
+		/* no more */
+		if (scanline_interrupt_timer_screens[i] == NULL)
+			break;
+	}
+
+	/* check that we still have room */
+	assert(i != ATARIMO_MAX);
+
+	/* need to create? */
+	if (scanline_interrupt_timer_screens[i] == NULL)
+	{
+		scanline_interrupt_timer_screens[i] = screen;
+		scanline_interrupt_timers[i] = timer_alloc(screen->machine, scanline_interrupt_callback, (void *)screen);
+	}
+
+	/* found it */
+	return scanline_interrupt_timers[i];
+}
+
 
 /*---------------------------------------------------------------
     atarigen_scanline_int_set: Sets the scanline when the next
     scanline interrupt should be generated.
 ---------------------------------------------------------------*/
 
-void atarigen_scanline_int_set(int scrnum, int scanline)
+void atarigen_scanline_int_set(const device_config *screen, int scanline)
 {
-	timer_adjust(scanline_interrupt_timer, video_screen_get_time_until_pos(scrnum, scanline, 0), scrnum, attotime_zero);
+	emu_timer *timer = get_scanline_interrupt_timer_for_screen(screen);
+	timer_adjust_oneshot(timer, video_screen_get_time_until_pos(screen, scanline, 0), 0);
 }
 
 
@@ -183,7 +228,7 @@ void atarigen_scanline_int_set(int scrnum, int scanline)
 INTERRUPT_GEN( atarigen_scanline_int_gen )
 {
 	atarigen_scanline_int_state = 1;
-	(*update_int_callback)(machine);
+	(*update_int_callback)(device->machine);
 }
 
 
@@ -195,13 +240,13 @@ INTERRUPT_GEN( atarigen_scanline_int_gen )
 WRITE16_HANDLER( atarigen_scanline_int_ack_w )
 {
 	atarigen_scanline_int_state = 0;
-	(*update_int_callback)(Machine);
+	(*update_int_callback)(space->machine);
 }
 
 WRITE32_HANDLER( atarigen_scanline_int_ack32_w )
 {
 	atarigen_scanline_int_state = 0;
-	(*update_int_callback)(Machine);
+	(*update_int_callback)(space->machine);
 }
 
 
@@ -213,7 +258,7 @@ WRITE32_HANDLER( atarigen_scanline_int_ack32_w )
 INTERRUPT_GEN( atarigen_sound_int_gen )
 {
 	atarigen_sound_int_state = 1;
-	(*update_int_callback)(machine);
+	(*update_int_callback)(device->machine);
 }
 
 
@@ -225,13 +270,13 @@ INTERRUPT_GEN( atarigen_sound_int_gen )
 WRITE16_HANDLER( atarigen_sound_int_ack_w )
 {
 	atarigen_sound_int_state = 0;
-	(*update_int_callback)(Machine);
+	(*update_int_callback)(space->machine);
 }
 
 WRITE32_HANDLER( atarigen_sound_int_ack32_w )
 {
 	atarigen_sound_int_state = 0;
-	(*update_int_callback)(Machine);
+	(*update_int_callback)(space->machine);
 }
 
 
@@ -243,7 +288,7 @@ WRITE32_HANDLER( atarigen_sound_int_ack32_w )
 INTERRUPT_GEN( atarigen_video_int_gen )
 {
 	atarigen_video_int_state = 1;
-	(*update_int_callback)(machine);
+	(*update_int_callback)(device->machine);
 }
 
 
@@ -255,13 +300,13 @@ INTERRUPT_GEN( atarigen_video_int_gen )
 WRITE16_HANDLER( atarigen_video_int_ack_w )
 {
 	atarigen_video_int_state = 0;
-	(*update_int_callback)(Machine);
+	(*update_int_callback)(space->machine);
 }
 
 WRITE32_HANDLER( atarigen_video_int_ack32_w )
 {
 	atarigen_video_int_state = 0;
-	(*update_int_callback)(Machine);
+	(*update_int_callback)(space->machine);
 }
 
 
@@ -271,11 +316,14 @@ WRITE32_HANDLER( atarigen_video_int_ack32_w )
 
 static TIMER_CALLBACK( scanline_interrupt_callback )
 {
+	const device_config *screen = ptr;
+	emu_timer *timer = get_scanline_interrupt_timer_for_screen(screen);
+
 	/* generate the interrupt */
-	atarigen_scanline_int_gen(machine, 0);
+	atarigen_scanline_int_gen(machine->cpu[0]);
 
 	/* set a new timer to go off at the same scan line next frame */
-	timer_adjust(scanline_interrupt_timer, video_screen_get_frame_period(param), param, attotime_zero);
+	timer_adjust_oneshot(timer, video_screen_get_frame_period(screen), 0);
 }
 
 
@@ -453,18 +501,41 @@ INLINE void update_bank(int bank)
 }
 
 
-static void slapstic_postload(void)
+static STATE_POSTLOAD( slapstic_postload )
 {
 	update_bank(slapstic_bank());
 }
 
 
+static DIRECT_UPDATE_HANDLER( atarigen_slapstic_setdirect )
+{
+	/* if we jump to an address in the slapstic region, tweak the slapstic
+       at that address and return ~0; this will cause us to be called on
+       subsequent fetches as well */
+	address &= ~atarigen_slapstic_mirror;
+	if (address >= atarigen_slapstic_base && address < atarigen_slapstic_base + 0x8000)
+	{
+		offs_t pc = cpu_get_previouspc(space->cpu);
+		if (pc != atarigen_slapstic_last_pc || address != atarigen_slapstic_last_address)
+		{
+			atarigen_slapstic_last_pc = pc;
+			atarigen_slapstic_last_address = address;
+			atarigen_slapstic_r(space, (address >> 1) & 0x3fff, 0xffff);
+		}
+		return ~0;
+	}
+
+	return address;
+}
+
+
+
 /*---------------------------------------------------------------
     atarigen_slapstic_init: Installs memory handlers for the
     slapstic and sets the chip number.
 ---------------------------------------------------------------*/
 
-void atarigen_slapstic_init(int cpunum, offs_t base, offs_t mirror, int chipnum)
+void atarigen_slapstic_init(const device_config *device, offs_t base, offs_t mirror, int chipnum)
 {
 	/* reset in case we have no state */
 	atarigen_slapstic_num = chipnum;
@@ -474,10 +545,10 @@ void atarigen_slapstic_init(int cpunum, offs_t base, offs_t mirror, int chipnum)
 	if (chipnum != 0)
 	{
 		/* initialize the slapstic */
-		slapstic_init(chipnum);
+		slapstic_init(device->machine, chipnum);
 
 		/* install the memory handlers */
-		atarigen_slapstic = memory_install_readwrite16_handler(cpunum, ADDRESS_SPACE_PROGRAM, base, base + 0x7fff, 0, mirror, atarigen_slapstic_r, atarigen_slapstic_w);
+		atarigen_slapstic = memory_install_readwrite16_handler(cpu_get_address_space(device, ADDRESS_SPACE_PROGRAM), base, base + 0x7fff, 0, mirror, atarigen_slapstic_r, atarigen_slapstic_w);
 
 		/* allocate memory for a copy of bank 0 */
 		atarigen_slapstic_bank0 = auto_malloc(0x2000);
@@ -485,6 +556,11 @@ void atarigen_slapstic_init(int cpunum, offs_t base, offs_t mirror, int chipnum)
 
 		/* ensure we recopy memory for the bank */
 		atarigen_slapstic_bank = 0xff;
+
+		/* install an opcode base handler if we are a 68000 or variant */
+		atarigen_slapstic_base = base;
+		atarigen_slapstic_mirror = mirror;
+		memory_set_direct_update_handler(cpu_get_address_space(device, ADDRESS_SPACE_PROGRAM), atarigen_slapstic_setdirect);
 	}
 }
 
@@ -512,7 +588,7 @@ void atarigen_slapstic_reset(void)
 
 WRITE16_HANDLER( atarigen_slapstic_w )
 {
-	update_bank(slapstic_tweak(offset));
+	update_bank(slapstic_tweak(space, offset));
 }
 
 
@@ -527,7 +603,7 @@ READ16_HANDLER( atarigen_slapstic_r )
 	int result = atarigen_slapstic[offset & 0xfff];
 
 	/* then determine the new one */
-	update_bank(slapstic_tweak(offset));
+	update_bank(slapstic_tweak(space, offset));
 	return result;
 }
 
@@ -541,10 +617,10 @@ READ16_HANDLER( atarigen_slapstic_r )
     atarigen_sound_io_reset: Resets the state of the sound I/O.
 ---------------------------------------------------------------*/
 
-void atarigen_sound_io_reset(int cpu_num)
+void atarigen_sound_io_reset(const device_config *device)
 {
 	/* remember which CPU is the sound CPU */
-	sound_cpu_num = cpu_num;
+	sound_cpu = device;
 
 	/* reset the internal interrupts states */
 	timed_int = ym2151_int = 0;
@@ -563,7 +639,7 @@ void atarigen_sound_io_reset(int cpu_num)
 INTERRUPT_GEN( atarigen_6502_irq_gen )
 {
 	timed_int = 1;
-	update_6502_irq();
+	update_6502_irq(device->machine);
 }
 
 
@@ -575,14 +651,14 @@ INTERRUPT_GEN( atarigen_6502_irq_gen )
 READ8_HANDLER( atarigen_6502_irq_ack_r )
 {
 	timed_int = 0;
-	update_6502_irq();
+	update_6502_irq(space->machine);
 	return 0;
 }
 
 WRITE8_HANDLER( atarigen_6502_irq_ack_w )
 {
 	timed_int = 0;
-	update_6502_irq();
+	update_6502_irq(space->machine);
 }
 
 
@@ -591,10 +667,10 @@ WRITE8_HANDLER( atarigen_6502_irq_ack_w )
     IRQ line.
 ---------------------------------------------------------------*/
 
-void atarigen_ym2151_irq_gen(int irq)
+void atarigen_ym2151_irq_gen(running_machine *machine, int irq)
 {
 	ym2151_int = irq;
-	update_6502_irq();
+	update_6502_irq(machine);
 }
 
 
@@ -605,7 +681,7 @@ void atarigen_ym2151_irq_gen(int irq)
 
 WRITE16_HANDLER( atarigen_sound_reset_w )
 {
-	timer_call_after_resynch(NULL, 0, delayed_sound_reset);
+	timer_call_after_resynch(space->machine, NULL, 0, delayed_sound_reset);
 }
 
 
@@ -614,9 +690,9 @@ WRITE16_HANDLER( atarigen_sound_reset_w )
     manually.
 ---------------------------------------------------------------*/
 
-void atarigen_sound_reset(void)
+void atarigen_sound_reset(running_machine *machine)
 {
-	timer_call_after_resynch(NULL, 1, delayed_sound_reset);
+	timer_call_after_resynch(machine, NULL, 1, delayed_sound_reset);
 }
 
 
@@ -629,20 +705,20 @@ void atarigen_sound_reset(void)
 
 WRITE16_HANDLER( atarigen_sound_w )
 {
-	if (ACCESSING_LSB)
-		timer_call_after_resynch(NULL, data & 0xff, delayed_sound_w);
+	if (ACCESSING_BITS_0_7)
+		timer_call_after_resynch(space->machine, NULL, data & 0xff, delayed_sound_w);
 }
 
 WRITE16_HANDLER( atarigen_sound_upper_w )
 {
-	if (ACCESSING_MSB)
-		timer_call_after_resynch(NULL, (data >> 8) & 0xff, delayed_sound_w);
+	if (ACCESSING_BITS_8_15)
+		timer_call_after_resynch(space->machine, NULL, (data >> 8) & 0xff, delayed_sound_w);
 }
 
 WRITE32_HANDLER( atarigen_sound_upper32_w )
 {
-	if (ACCESSING_MSB32)
-		timer_call_after_resynch(NULL, (data >> 24) & 0xff, delayed_sound_w);
+	if (ACCESSING_BITS_24_31)
+		timer_call_after_resynch(space->machine, NULL, (data >> 24) & 0xff, delayed_sound_w);
 }
 
 
@@ -656,21 +732,21 @@ WRITE32_HANDLER( atarigen_sound_upper32_w )
 READ16_HANDLER( atarigen_sound_r )
 {
 	atarigen_sound_to_cpu_ready = 0;
-	atarigen_sound_int_ack_w(0, 0, 0);
+	atarigen_sound_int_ack_w(space, 0, 0, 0xffff);
 	return atarigen_sound_to_cpu | 0xff00;
 }
 
 READ16_HANDLER( atarigen_sound_upper_r )
 {
 	atarigen_sound_to_cpu_ready = 0;
-	atarigen_sound_int_ack_w(0, 0, 0);
+	atarigen_sound_int_ack_w(space, 0, 0, 0xffff);
 	return (atarigen_sound_to_cpu << 8) | 0x00ff;
 }
 
 READ32_HANDLER( atarigen_sound_upper32_r )
 {
 	atarigen_sound_to_cpu_ready = 0;
-	atarigen_sound_int_ack32_w(0, 0, 0);
+	atarigen_sound_int_ack32_w(space, 0, 0, 0xffff);
 	return (atarigen_sound_to_cpu << 24) | 0x00ffffff;
 }
 
@@ -682,7 +758,7 @@ READ32_HANDLER( atarigen_sound_upper32_r )
 
 WRITE8_HANDLER( atarigen_6502_sound_w )
 {
-	timer_call_after_resynch(NULL, data, delayed_6502_sound_w);
+	timer_call_after_resynch(space->machine, NULL, data, delayed_6502_sound_w);
 }
 
 
@@ -694,7 +770,7 @@ WRITE8_HANDLER( atarigen_6502_sound_w )
 READ8_HANDLER( atarigen_6502_sound_r )
 {
 	atarigen_cpu_to_sound_ready = 0;
-	cpunum_set_input_line(Machine, sound_cpu_num, INPUT_LINE_NMI, CLEAR_LINE);
+	cpu_set_input_line(sound_cpu, INPUT_LINE_NMI, CLEAR_LINE);
 	return atarigen_cpu_to_sound;
 }
 
@@ -706,12 +782,12 @@ READ8_HANDLER( atarigen_6502_sound_r )
     the atarigen_ym2151_irq_gen() callback.
 ---------------------------------------------------------------*/
 
-void update_6502_irq(void)
+static void update_6502_irq(running_machine *machine)
 {
 	if (timed_int || ym2151_int)
-		cpunum_set_input_line(Machine, sound_cpu_num, M6502_IRQ_LINE, ASSERT_LINE);
+		cpu_set_input_line(sound_cpu, M6502_IRQ_LINE, ASSERT_LINE);
 	else
-		cpunum_set_input_line(Machine, sound_cpu_num, M6502_IRQ_LINE, CLEAR_LINE);
+		cpu_set_input_line(sound_cpu, M6502_IRQ_LINE, CLEAR_LINE);
 }
 
 
@@ -722,20 +798,22 @@ void update_6502_irq(void)
 
 static TIMER_CALLBACK( delayed_sound_reset )
 {
+	const address_space *space = cpu_get_address_space(sound_cpu, ADDRESS_SPACE_PROGRAM);
+
 	/* unhalt and reset the sound CPU */
 	if (param == 0)
 	{
-		cpunum_set_input_line(machine, sound_cpu_num, INPUT_LINE_HALT, CLEAR_LINE);
-		cpunum_set_input_line(machine, sound_cpu_num, INPUT_LINE_RESET, PULSE_LINE);
+		cpu_set_input_line(sound_cpu, INPUT_LINE_HALT, CLEAR_LINE);
+		cpu_set_input_line(sound_cpu, INPUT_LINE_RESET, PULSE_LINE);
 	}
 
 	/* reset the sound write state */
 	atarigen_sound_to_cpu_ready = 0;
-	atarigen_sound_int_ack_w(0, 0, 0);
+	atarigen_sound_int_ack_w(space, 0, 0, 0xffff);
 
 	/* allocate a high frequency timer until a response is generated */
 	/* the main CPU is *very* sensistive to the timing of the response */
-	cpu_boost_interleave(SOUND_TIMER_RATE, SOUND_TIMER_BOOST);
+	cpuexec_boost_interleave(machine, SOUND_TIMER_RATE, SOUND_TIMER_BOOST);
 }
 
 
@@ -753,11 +831,11 @@ static TIMER_CALLBACK( delayed_sound_w )
 	/* set up the states and signal an NMI to the sound CPU */
 	atarigen_cpu_to_sound = param;
 	atarigen_cpu_to_sound_ready = 1;
-	cpunum_set_input_line(machine, sound_cpu_num, INPUT_LINE_NMI, ASSERT_LINE);
+	cpu_set_input_line(sound_cpu, INPUT_LINE_NMI, ASSERT_LINE);
 
 	/* allocate a high frequency timer until a response is generated */
 	/* the main CPU is *very* sensistive to the timing of the response */
-	cpu_boost_interleave(SOUND_TIMER_RATE, SOUND_TIMER_BOOST);
+	cpuexec_boost_interleave(machine, SOUND_TIMER_RATE, SOUND_TIMER_BOOST);
 }
 
 
@@ -775,7 +853,7 @@ static TIMER_CALLBACK( delayed_6502_sound_w )
 	/* set up the states and signal the sound interrupt to the main CPU */
 	atarigen_sound_to_cpu = param;
 	atarigen_sound_to_cpu_ready = 1;
-	atarigen_sound_int_gen(machine, 0);
+	atarigen_sound_int_gen(machine->cpu[0]);
 }
 
 
@@ -795,7 +873,7 @@ void atarigen_set_vol(running_machine *machine, int volume, sound_type type)
 	int ch;
 
 	for (ch = 0; ch < MAX_SOUND; ch++)
-		if (machine->drv->sound[ch].type == type)
+		if (machine->config->sound[ch].type == type)
 		{
 			int output;
 			for (output = 0; output < 2; output++)
@@ -841,11 +919,47 @@ void atarigen_set_oki6295_vol(running_machine *machine, int volume)
     SCANLINE TIMING
 ***************************************************************************/
 
+/*---------------------------------------------------------------
+    get_scanline_timer_for_screen: Retrieves or
+    creates the the scanline timer.
+---------------------------------------------------------------*/
+
+static emu_timer *get_scanline_timer_for_screen(const device_config *screen)
+{
+	int i;
+
+	/* find the index of the timer that matches the screen */
+	for (i = 0; i < ATARIMO_MAX; i++)
+	{
+		/* matching */
+		if (scanline_timer_screens[i] == screen)
+			break;
+
+		/* no more */
+		if (scanline_timer_screens[i] == NULL)
+			break;
+	}
+
+	/* check that we still have room */
+	assert(i != ATARIMO_MAX);
+
+	/* need to create? */
+	if (scanline_timer_screens[i] == NULL)
+	{
+		scanline_timer_screens[i] = screen;
+		scanline_timers[i] = timer_alloc(screen->machine, scanline_timer_callback, (void *)screen);
+	}
+
+	/* found it */
+	return scanline_timers[i];
+}
+
+
 /*---------------------------------------------------------------
     atarigen_scanline_timer_reset: Sets up the scanline timer.
 ---------------------------------------------------------------*/
 
-void atarigen_scanline_timer_reset(int scrnum, atarigen_scanline_callback update_graphics, int frequency)
+void atarigen_scanline_timer_reset(const device_config *screen, atarigen_scanline_func update_graphics, int frequency)
 {
 	/* set the scanline callback */
 	scanline_callback = update_graphics;
@@ -853,30 +967,37 @@ void atarigen_scanline_timer_reset(int scrnum, atarigen_scanline_callback update
 
 	/* set a timer to go off at scanline 0 */
 	if (scanline_callback != NULL)
-		timer_adjust(scanline_timer[scrnum], video_screen_get_time_until_pos(scrnum, 0, 0), (scrnum << 16) | 0, attotime_zero);
+	{
+		emu_timer *timer = get_scanline_timer_for_screen(screen);
+		timer_adjust_oneshot(timer, video_screen_get_time_until_pos(screen, 0, 0), 0);
+	}
+
+	/* implicitly allocate a scanline interrupt timer */
+	get_scanline_interrupt_timer_for_screen(screen);
+
 }
 
 
 /*---------------------------------------------------------------
-    scanline_timer: Called once every n scanlines to generate
-    the periodic callback to the main system.
+    scanline_timer_callback: Called once every n scanlines
+    to generate the periodic callback to the main system.
 ---------------------------------------------------------------*/
 
 static TIMER_CALLBACK( scanline_timer_callback )
 {
-	int scanline = param & 0x0fff;
-	int scrnum = param >> 16;
+	const device_config *screen = ptr;
+	int scanline = param;
 
 	/* callback */
 	if (scanline_callback != NULL)
 	{
-		(*scanline_callback)(machine, scrnum, scanline);
+		(*scanline_callback)(screen, scanline);
 
 		/* generate another */
 		scanline += scanlines_per_callback;
-		if (scanline >= machine->screen[scrnum].height)
+		if (scanline >= video_screen_get_height(screen))
 			scanline = 0;
-		timer_adjust(scanline_timer[scrnum], video_screen_get_time_until_pos(scrnum, scanline, 0), (scrnum << 16) | scanline, attotime_zero);
+		timer_adjust_oneshot(get_scanline_timer_for_screen(screen), video_screen_get_time_until_pos(screen, scanline, 0), scanline);
 	}
 }
 
@@ -886,6 +1007,42 @@ static TIMER_CALLBACK( scanline_timer_callback )
     VIDEO CONTROLLER
 ***************************************************************************/
 
+/*---------------------------------------------------------------
+    get_scanline_timer_for_screen: Retrieves or
+    creates the the scanline timer.
+---------------------------------------------------------------*/
+
+static emu_timer *get_atarivc_eof_update_timer_for_screen(const device_config *screen)
+{
+	int i;
+
+	/* find the index of the timer that matches the screen */
+	for (i = 0; i < ATARIMO_MAX; i++)
+	{
+		/* matching */
+		if (atarivc_eof_update_timer_screens[i] == screen)
+			break;
+
+		/* no more */
+		if (atarivc_eof_update_timer_screens[i] == NULL)
+			break;
+	}
+
+	/* check that we still have room */
+	assert(i != ATARIMO_MAX);
+
+	/* need to create? */
+	if (atarivc_eof_update_timer_screens[i] == NULL)
+	{
+		atarivc_eof_update_timer_screens[i] = screen;
+		atarivc_eof_update_timers[i] = timer_alloc(screen->machine, atarivc_eof_update, (void *)screen);
+	}
+
+	/* found it */
+	return atarivc_eof_update_timers[i];
+}
+
+
 /*---------------------------------------------------------------
     atarivc_eof_update: Callback that slurps up data and feeds
     it into the video controller registers every refresh.
@@ -893,13 +1050,14 @@ static TIMER_CALLBACK( scanline_timer_callback )
 
 static TIMER_CALLBACK( atarivc_eof_update )
 {
-	int scrnum = param;
+	const device_config *screen = ptr;
+	emu_timer *timer = get_atarivc_eof_update_timer_for_screen(screen);
 	int i;
 
 	/* echo all the commands to the video controller */
 	for (i = 0; i < 0x1c; i++)
 		if (atarivc_eof_data[i])
-			atarivc_common_w(scrnum, i, atarivc_eof_data[i]);
+			atarivc_common_w(screen, i, atarivc_eof_data[i]);
 
 	/* update the scroll positions */
 	atarimo_set_xscroll(0, atarivc_state.mo_xscroll);
@@ -913,7 +1071,7 @@ static TIMER_CALLBACK( atarivc_eof_update )
 		tilemap_set_scrollx(atarigen_playfield2_tilemap, 0, atarivc_state.pf1_xscroll);
 		tilemap_set_scrolly(atarigen_playfield2_tilemap, 0, atarivc_state.pf1_yscroll);
 	}
-	timer_adjust(atarivc_eof_update_timer[scrnum], video_screen_get_time_until_pos(scrnum, 0, 0), scrnum, attotime_zero);
+	timer_adjust_oneshot(timer, video_screen_get_time_until_pos(screen, 0, 0), 0);
 
 	/* use this for debugging the video controller values */
 #if 0
@@ -936,8 +1094,10 @@ static TIMER_CALLBACK( atarivc_eof_update )
     atarivc_reset: Initializes the video controller.
 ---------------------------------------------------------------*/
 
-void atarivc_reset(int scrnum, UINT16 *eof_data, int playfields)
+void atarivc_reset(const device_config *screen, UINT16 *eof_data, int playfields)
 {
+	int i;
+
 	/* this allows us to manually reset eof_data to NULL if it's not used */
 	atarivc_eof_data = eof_data;
 	atarivc_playfields = playfields;
@@ -950,11 +1110,19 @@ void atarivc_reset(int scrnum, UINT16 *eof_data, int playfields)
 	atarivc_state.latch1 = atarivc_state.latch2 = -1;
 	actual_vc_latch0 = actual_vc_latch1 = -1;
 
-	atarivc_eof_update_timer[scrnum] = timer_alloc(atarivc_eof_update, NULL);
+	/* clear the timers */
+	for (i = 0; i < ATARIMO_MAX; i++)
+	{
+		atarivc_eof_update_timer_screens[i] = NULL;
+		atarivc_eof_update_timers[i] = NULL;
+	}
 
 	/* start a timer to go off a little before scanline 0 */
 	if (atarivc_eof_data)
-		timer_adjust(atarivc_eof_update_timer[scrnum], video_screen_get_time_until_pos(scrnum, 0, 0), scrnum, attotime_zero);
+	{
+		emu_timer *timer = get_atarivc_eof_update_timer_for_screen(screen);
+		timer_adjust_oneshot(timer, video_screen_get_time_until_pos(screen, 0, 0), 0);
+	}
 }
 
 
@@ -963,13 +1131,13 @@ void atarivc_reset(int scrnum, UINT16 *eof_data, int playfields)
     atarivc_w: Handles an I/O write to the video controller.
 ---------------------------------------------------------------*/
 
-WRITE16_HANDLER( atarivc_w )
+void atarivc_w(const device_config *screen, offs_t offset, UINT16 data, UINT16 mem_mask)
 {
 	int oldword = atarivc_data[offset];
 	int newword = oldword;
 
 	COMBINE_DATA(&newword);
-	atarivc_common_w(0, offset, newword); 	/* need to support scrnum */
+	atarivc_common_w(screen, offset, newword);
 }
 
 
@@ -979,7 +1147,7 @@ WRITE16_HANDLER( atarivc_w )
     write.
 ---------------------------------------------------------------*/
 
-static void atarivc_common_w(int scrnum, offs_t offset, UINT16 newword)
+static void atarivc_common_w(const device_config *screen, offs_t offset, UINT16 newword)
 {
 	int oldword = atarivc_data[offset];
 	atarivc_data[offset] = newword;
@@ -997,7 +1165,7 @@ static void atarivc_common_w(int scrnum, offs_t offset, UINT16 newword)
 		/* set the scanline interrupt here */
 		case 0x03:
 			if (oldword != newword)
-				atarigen_scanline_int_set(scrnum, newword & 0x1ff);
+				atarigen_scanline_int_set(screen, newword & 0x1ff);
 			break;
 
 		/* latch enable */
@@ -1013,7 +1181,7 @@ static void atarivc_common_w(int scrnum, offs_t offset, UINT16 newword)
 			/* check for palette banking */
 			if (atarivc_state.palette_bank != (((newword & 0x0400) >> 10) ^ 1))
 			{
-				video_screen_update_partial(scrnum, video_screen_get_vpos(scrnum));
+				video_screen_update_partial(screen, video_screen_get_vpos(screen));
 				atarivc_state.palette_bank = ((newword & 0x0400) >> 10) ^ 1;
 			}
 			break;
@@ -1070,7 +1238,8 @@ static void atarivc_common_w(int scrnum, offs_t offset, UINT16 newword)
 
 		/* scanline IRQ ack here */
 		case 0x1e:
-			atarigen_scanline_int_ack_w(0, 0, 0);
+			/* hack: this should be a device */
+			atarigen_scanline_int_ack_w(cpu_get_address_space(screen->machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0, 0, 0xffff);
 			break;
 
 		/* log anything else */
@@ -1087,7 +1256,7 @@ static void atarivc_common_w(int scrnum, offs_t offset, UINT16 newword)
     atarivc_r: Handles an I/O read from the video controller.
 ---------------------------------------------------------------*/
 
-READ16_HANDLER( atarivc_r )
+UINT16 atarivc_r(const device_config *screen, offs_t offset)
 {
 	logerror("vc_r(%02X)\n", offset);
 
@@ -1095,11 +1264,11 @@ READ16_HANDLER( atarivc_r )
 	/* also sets bit 0x4000 if we're in VBLANK */
 	if (offset == 0)
 	{
-		int result = video_screen_get_vpos(0);	/* need to support scrum */
+		int result = video_screen_get_vpos(screen);
 
 		if (result > 255)
 			result = 255;
-		if (result > Machine->screen[0].visarea.max_y)	/* need to support scrum */
+		if (result > video_screen_get_visible_area(screen)->max_y)
 			result |= 0x4000;
 
 		return result;
@@ -1127,9 +1296,9 @@ WRITE16_HANDLER( atarigen_alpha_w )
 WRITE32_HANDLER( atarigen_alpha32_w )
 {
 	COMBINE_DATA(&atarigen_alpha32[offset]);
-	if ((mem_mask & 0xffff0000) != 0xffff0000)
+	if (ACCESSING_BITS_16_31)
 		tilemap_mark_tile_dirty(atarigen_alpha_tilemap, offset * 2);
-	if ((mem_mask & 0x0000ffff) != 0x0000ffff)
+	if (ACCESSING_BITS_0_15)
 		tilemap_mark_tile_dirty(atarigen_alpha_tilemap, offset * 2 + 1);
 }
 
@@ -1171,9 +1340,9 @@ WRITE16_HANDLER( atarigen_playfield_w )
 WRITE32_HANDLER( atarigen_playfield32_w )
 {
 	COMBINE_DATA(&atarigen_playfield32[offset]);
-	if ((mem_mask & 0xffff0000) != 0xffff0000)
+	if (ACCESSING_BITS_16_31)
 		tilemap_mark_tile_dirty(atarigen_playfield_tilemap, offset * 2);
-	if ((mem_mask & 0x0000ffff) != 0x0000ffff)
+	if (ACCESSING_BITS_0_15)
 		tilemap_mark_tile_dirty(atarigen_playfield_tilemap, offset * 2 + 1);
 }
 
@@ -1287,32 +1456,33 @@ WRITE16_HANDLER( atarigen_playfield2_latched_msb_w )
     10% of the scanline period.
 ---------------------------------------------------------------*/
 
-int atarigen_get_hblank(running_machine *machine, int scrnum)
+int atarigen_get_hblank(const device_config *screen)
 {
-	return (video_screen_get_hpos(scrnum) > (machine->screen[scrnum].width * 9 / 10));
+	return (video_screen_get_hpos(screen) > (video_screen_get_width(screen) * 9 / 10));
 }
 
 
 /*---------------------------------------------------------------
-    atarigen_halt_until_hblank_0_w: Halts CPU 0 until the
+    atarigen_halt_until_hblank_0: Halts CPU 0 until the
     next HBLANK.
 ---------------------------------------------------------------*/
 
-WRITE16_HANDLER( atarigen_halt_until_hblank_0_w )
+void atarigen_halt_until_hblank_0(const device_config *screen)
 {
 	/* halt the CPU until the next HBLANK */
-	int hpos = video_screen_get_hpos(0);	/* need to support scrnum */
-	int hblank = Machine->screen[0].width * 9 / 10;
+	int hpos = video_screen_get_hpos(screen);
+	int width = video_screen_get_width(screen);
+	int hblank = width * 9 / 10;
 	double fraction;
 
 	/* if we're in hblank, set up for the next one */
 	if (hpos >= hblank)
-		hblank += Machine->screen[0].width;
+		hblank += width;
 
 	/* halt and set a timer to wake up */
-	fraction = (double)(hblank - hpos) / (double)Machine->screen[0].width;
-	timer_set(double_to_attotime(attotime_to_double(video_screen_get_scan_period(0)) * fraction), NULL, 0, unhalt_cpu);
-	cpunum_set_input_line(Machine, 0, INPUT_LINE_HALT, ASSERT_LINE);
+	fraction = (double)(hblank - hpos) / (double)width;
+	timer_set(screen->machine, double_to_attotime(attotime_to_double(video_screen_get_scan_period(screen)) * fraction), NULL, 0, unhalt_cpu);
+	cpu_set_input_line(screen->machine->cpu[0], INPUT_LINE_HALT, ASSERT_LINE);
 }
 
 
@@ -1331,7 +1501,7 @@ WRITE16_HANDLER( atarigen_666_paletteram_w )
 	g = ((newword >> 4) & 0x3e) | ((newword >> 15) & 1);
 	b = ((newword << 1) & 0x3e) | ((newword >> 15) & 1);
 
-	palette_set_color_rgb(Machine, offset, pal6bit(r), pal6bit(g), pal6bit(b));
+	palette_set_color_rgb(space->machine, offset, pal6bit(r), pal6bit(g), pal6bit(b));
 }
 
 
@@ -1344,7 +1514,7 @@ WRITE16_HANDLER( atarigen_expanded_666_paletteram_w )
 {
 	COMBINE_DATA(&paletteram16[offset]);
 
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		int palentry = offset / 2;
 		int newword = (paletteram16[palentry * 2] & 0xff00) | (paletteram16[palentry * 2 + 1] >> 8);
@@ -1355,7 +1525,7 @@ WRITE16_HANDLER( atarigen_expanded_666_paletteram_w )
 		g = ((newword >> 4) & 0x3e) | ((newword >> 15) & 1);
 		b = ((newword << 1) & 0x3e) | ((newword >> 15) & 1);
 
-		palette_set_color_rgb(Machine, palentry & 0x1ff, pal6bit(r), pal6bit(g), pal6bit(b));
+		palette_set_color_rgb(space->machine, palentry & 0x1ff, pal6bit(r), pal6bit(g), pal6bit(b));
 	}
 }
 
@@ -1370,7 +1540,7 @@ WRITE32_HANDLER( atarigen_666_paletteram32_w )
 
 	COMBINE_DATA(&paletteram32[offset]);
 
-	if (ACCESSING_MSW32)
+	if (ACCESSING_BITS_16_31)
 	{
 		newword = paletteram32[offset] >> 16;
 
@@ -1378,10 +1548,10 @@ WRITE32_HANDLER( atarigen_666_paletteram32_w )
 		g = ((newword >> 4) & 0x3e) | ((newword >> 15) & 1);
 		b = ((newword << 1) & 0x3e) | ((newword >> 15) & 1);
 
-		palette_set_color_rgb(Machine, offset * 2, pal6bit(r), pal6bit(g), pal6bit(b));
+		palette_set_color_rgb(space->machine, offset * 2, pal6bit(r), pal6bit(g), pal6bit(b));
 	}
 
-	if (ACCESSING_LSW32)
+	if (ACCESSING_BITS_0_15)
 	{
 		newword = paletteram32[offset] & 0xffff;
 
@@ -1389,7 +1559,7 @@ WRITE32_HANDLER( atarigen_666_paletteram32_w )
 		g = ((newword >> 4) & 0x3e) | ((newword >> 15) & 1);
 		b = ((newword << 1) & 0x3e) | ((newword >> 15) & 1);
 
-		palette_set_color_rgb(Machine, offset * 2 + 1, pal6bit(r), pal6bit(g), pal6bit(b));
+		palette_set_color_rgb(space->machine, offset * 2 + 1, pal6bit(r), pal6bit(g), pal6bit(b));
 	}
 }
 
@@ -1400,7 +1570,7 @@ WRITE32_HANDLER( atarigen_666_paletteram32_w )
 
 static TIMER_CALLBACK( unhalt_cpu )
 {
-	cpunum_set_input_line(machine, param, INPUT_LINE_HALT, CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[param], INPUT_LINE_HALT, CLEAR_LINE);
 }
 
 
@@ -1471,47 +1641,48 @@ void atarigen_blend_gfx(running_machine *machine, int gfx0, int gfx1, int mask0,
     SAVE STATE
 ***************************************************************************/
 
-void atarigen_init_save_state(void)
+void atarigen_init_save_state(running_machine *machine)
 {
-	state_save_register_global(atarigen_scanline_int_state);
-	state_save_register_global(atarigen_sound_int_state);
-	state_save_register_global(atarigen_video_int_state);
+	state_save_register_global(machine, atarigen_scanline_int_state);
+	state_save_register_global(machine, atarigen_sound_int_state);
+	state_save_register_global(machine, atarigen_video_int_state);
 
-	state_save_register_global(atarigen_cpu_to_sound_ready);
-	state_save_register_global(atarigen_sound_to_cpu_ready);
+	state_save_register_global(machine, atarigen_cpu_to_sound_ready);
+	state_save_register_global(machine, atarigen_sound_to_cpu_ready);
 
-	state_save_register_global(atarivc_state.latch1);				/* latch #1 value (-1 means disabled) */
-	state_save_register_global(atarivc_state.latch2);				/* latch #2 value (-1 means disabled) */
-	state_save_register_global(atarivc_state.rowscroll_enable);		/* true if row-scrolling is enabled */
-	state_save_register_global(atarivc_state.palette_bank);			/* which palette bank is enabled */
-	state_save_register_global(atarivc_state.pf0_xscroll);			/* playfield 1 xscroll */
-	state_save_register_global(atarivc_state.pf0_xscroll_raw);		/* playfield 1 xscroll raw value */
-	state_save_register_global(atarivc_state.pf0_yscroll);			/* playfield 1 yscroll */
-	state_save_register_global(atarivc_state.pf1_xscroll);			/* playfield 2 xscroll */
-	state_save_register_global(atarivc_state.pf1_xscroll_raw);		/* playfield 2 xscroll raw value */
-	state_save_register_global(atarivc_state.pf1_yscroll);			/* playfield 2 yscroll */
-	state_save_register_global(atarivc_state.mo_xscroll);			/* sprite xscroll */
-	state_save_register_global(atarivc_state.mo_yscroll);			/* sprite xscroll */
+	state_save_register_global(machine, atarivc_state.latch1);				/* latch #1 value (-1 means disabled) */
+	state_save_register_global(machine, atarivc_state.latch2);				/* latch #2 value (-1 means disabled) */
+	state_save_register_global(machine, atarivc_state.rowscroll_enable);		/* true if row-scrolling is enabled */
+	state_save_register_global(machine, atarivc_state.palette_bank);			/* which palette bank is enabled */
+	state_save_register_global(machine, atarivc_state.pf0_xscroll);			/* playfield 1 xscroll */
+	state_save_register_global(machine, atarivc_state.pf0_xscroll_raw);		/* playfield 1 xscroll raw value */
+	state_save_register_global(machine, atarivc_state.pf0_yscroll);			/* playfield 1 yscroll */
+	state_save_register_global(machine, atarivc_state.pf1_xscroll);			/* playfield 2 xscroll */
+	state_save_register_global(machine, atarivc_state.pf1_xscroll_raw);		/* playfield 2 xscroll raw value */
+	state_save_register_global(machine, atarivc_state.pf1_yscroll);			/* playfield 2 yscroll */
+	state_save_register_global(machine, atarivc_state.mo_xscroll);			/* sprite xscroll */
+	state_save_register_global(machine, atarivc_state.mo_yscroll);			/* sprite xscroll */
 
-	state_save_register_global(eeprom_unlocked);
+	state_save_register_global(machine, eeprom_unlocked);
 
-	state_save_register_global(atarigen_slapstic_num);
-	state_save_register_global(atarigen_slapstic_bank);
+	state_save_register_global(machine, atarigen_slapstic_num);
+	state_save_register_global(machine, atarigen_slapstic_bank);
+	state_save_register_global(machine, atarigen_slapstic_last_pc);
+	state_save_register_global(machine, atarigen_slapstic_last_address);
 
-	state_save_register_global(sound_cpu_num);
-	state_save_register_global(atarigen_cpu_to_sound);
-	state_save_register_global(atarigen_sound_to_cpu);
-	state_save_register_global(timed_int);
-	state_save_register_global(ym2151_int);
+	state_save_register_global(machine, atarigen_cpu_to_sound);
+	state_save_register_global(machine, atarigen_sound_to_cpu);
+	state_save_register_global(machine, timed_int);
+	state_save_register_global(machine, ym2151_int);
 
-	state_save_register_global(scanlines_per_callback);
+	state_save_register_global(machine, scanlines_per_callback);
 
-	state_save_register_global(actual_vc_latch0);
-	state_save_register_global(actual_vc_latch1);
+	state_save_register_global(machine, actual_vc_latch0);
+	state_save_register_global(machine, actual_vc_latch1);
 
-	state_save_register_global(playfield_latch);
-	state_save_register_global(playfield2_latch);
+	state_save_register_global(machine, playfield_latch);
+	state_save_register_global(machine, playfield2_latch);
 
 	/* need a postload to reset the state */
-	state_save_register_func_postload(slapstic_postload);
+	state_save_register_postload(machine, slapstic_postload, NULL);
 }
