@@ -7,7 +7,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "cpu/m6809/m6809.h"
 #include "balsente.h"
 #include "sound/cem3394.h"
@@ -18,10 +17,10 @@
 
 /* local prototypes */
 static void poly17_init(void);
-static void counter_set_out(int which, int gate);
+static void counter_set_out(running_machine *machine, int which, int gate);
 static TIMER_CALLBACK( counter_callback );
 static TIMER_CALLBACK( clock_counter_0_ff );
-static void update_grudge_steering(void);
+static void update_grudge_steering(running_machine *machine);
 
 /* global data */
 UINT8 balsente_shooter;
@@ -103,7 +102,7 @@ static UINT8 grudge_last_steering[3];
 
 static TIMER_CALLBACK( irq_off )
 {
-	cpunum_set_input_line(machine, 0, M6809_IRQ_LINE, CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], M6809_IRQ_LINE, CLEAR_LINE);
 }
 
 
@@ -111,19 +110,19 @@ static TIMER_CALLBACK( interrupt_timer )
 {
 	/* next interrupt after scanline 256 is scanline 64 */
 	if (param == 256)
-		timer_adjust(scanline_timer, video_screen_get_time_until_pos(0, 64, 0), 64, attotime_zero);
+		timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, 64, 0), 64);
 	else
-		timer_adjust(scanline_timer, video_screen_get_time_until_pos(0, param + 64, 0), param + 64, attotime_zero);
+		timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, param + 64, 0), param + 64);
 
 	/* IRQ starts on scanline 0, 64, 128, etc. */
-	cpunum_set_input_line(machine, 0, M6809_IRQ_LINE, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[0], M6809_IRQ_LINE, ASSERT_LINE);
 
 	/* it will turn off on the next HBLANK */
-	timer_set(video_screen_get_time_until_pos(0, param, BALSENTE_HBSTART), NULL, 0, irq_off);
+	timer_set(machine, video_screen_get_time_until_pos(machine->primary_screen, param, BALSENTE_HBSTART), NULL, 0, irq_off);
 
 	/* if this is Grudge Match, update the steering */
 	if (grudge_steering_result & 0x80)
-		update_grudge_steering();
+		update_grudge_steering(machine);
 
 	/* if we're a shooter, we do a little more work */
 	if (balsente_shooter)
@@ -133,8 +132,8 @@ static TIMER_CALLBACK( interrupt_timer )
 		/* we latch the beam values on the first interrupt after VBLANK */
 		if (param == 64 && balsente_shooter)
 		{
-			balsente_shooter_x = readinputport(8);
-			balsente_shooter_y = readinputport(9);
+			balsente_shooter_x = input_port_read(machine, "FAKEX");
+			balsente_shooter_y = input_port_read(machine, "FAKEY");
 		}
 
 		/* which bits get returned depends on which scanline we're at */
@@ -148,6 +147,7 @@ static TIMER_CALLBACK( interrupt_timer )
 
 MACHINE_RESET( balsente )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	int numbanks, i;
 
 	/* create the polynomial tables */
@@ -155,14 +155,14 @@ MACHINE_RESET( balsente )
 
 	/* reset counters; counter 2's gate is tied high */
 	memset(counter, 0, sizeof(counter));
-	counter[1].timer = timer_alloc(counter_callback, NULL);
-	counter[2].timer = timer_alloc(counter_callback, NULL);
+	counter[1].timer = timer_alloc(machine, counter_callback, NULL);
+	counter[2].timer = timer_alloc(machine, counter_callback, NULL);
 	counter[2].gate = 1;
 
 	/* reset the manual counter 0 clock */
 	counter_control = 0x00;
 	counter_0_ff = 0;
-	counter_0_timer = timer_alloc(clock_counter_0_ff, NULL);
+	counter_0_timer = timer_alloc(machine, clock_counter_0_ff, NULL);
 	counter_0_timer_active = 0;
 
 	/* reset the ADC states */
@@ -177,66 +177,67 @@ MACHINE_RESET( balsente )
 	grudge_steering_result = 0;
 
 	/* reset the 6850 chips */
-	balsente_m6850_w(0, 3);
-	balsente_m6850_sound_w(0, 3);
+	balsente_m6850_w(space, 0, 3);
+	balsente_m6850_sound_w(space, 0, 3);
 
 	/* reset the noise generator */
 	memset(noise_position, 0, sizeof(noise_position));
 
 	/* point the banks to bank 0 */
-	numbanks = (memory_region_length(REGION_CPU1) > 0x40000) ? 16 : 8;
-	memory_configure_bank(1, 0, numbanks, &memory_region(REGION_CPU1)[0x10000], 0x6000);
-	memory_configure_bank(2, 0, numbanks, &memory_region(REGION_CPU1)[0x12000], 0x6000);
-	memory_set_bank(1, 0);
-	memory_set_bank(2, 0);
+	numbanks = (memory_region_length(machine, "main") > 0x40000) ? 16 : 8;
+	memory_configure_bank(machine, 1, 0, numbanks, &memory_region(machine, "main")[0x10000], 0x6000);
+	memory_configure_bank(machine, 2, 0, numbanks, &memory_region(machine, "main")[0x12000], 0x6000);
+	memory_set_bank(space->machine, 1, 0);
+	memory_set_bank(space->machine, 2, 0);
+	device_reset(machine->cpu[0]);
 
 	/* start a timer to generate interrupts */
-	scanline_timer = timer_alloc(interrupt_timer, NULL);
-	timer_adjust(scanline_timer, video_screen_get_time_until_pos(0, 0, 0), 0, attotime_zero);
+	scanline_timer = timer_alloc(machine, interrupt_timer, NULL);
+	timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, 0, 0), 0);
 
 	/* register for saving */
 	for (i = 0; i < 3; i++)
 	{
-		state_save_register_item("8253counter", i, counter[i].timer_active);
-		state_save_register_item("8253counter", i, counter[i].initial);
-		state_save_register_item("8253counter", i, counter[i].count);
-		state_save_register_item("8253counter", i, counter[i].gate);
-		state_save_register_item("8253counter", i, counter[i].out);
-		state_save_register_item("8253counter", i, counter[i].mode);
-		state_save_register_item("8253counter", i, counter[i].readbyte);
-		state_save_register_item("8253counter", i, counter[i].writebyte);
+		state_save_register_item(machine, "8253counter", NULL, i, counter[i].timer_active);
+		state_save_register_item(machine, "8253counter", NULL, i, counter[i].initial);
+		state_save_register_item(machine, "8253counter", NULL, i, counter[i].count);
+		state_save_register_item(machine, "8253counter", NULL, i, counter[i].gate);
+		state_save_register_item(machine, "8253counter", NULL, i, counter[i].out);
+		state_save_register_item(machine, "8253counter", NULL, i, counter[i].mode);
+		state_save_register_item(machine, "8253counter", NULL, i, counter[i].readbyte);
+		state_save_register_item(machine, "8253counter", NULL, i, counter[i].writebyte);
 	}
 
-	state_save_register_global(counter_control);
-	state_save_register_global(counter_0_ff);
-	state_save_register_global(counter_0_timer_active);
+	state_save_register_global(machine, counter_control);
+	state_save_register_global(machine, counter_0_ff);
+	state_save_register_global(machine, counter_0_timer_active);
 
-	state_save_register_global_array(analog_input_data);
-	state_save_register_global(adc_value);
+	state_save_register_global_array(machine, analog_input_data);
+	state_save_register_global(machine, adc_value);
 
-	state_save_register_global(dac_value);
-	state_save_register_global(dac_register);
-	state_save_register_global(chip_select);
+	state_save_register_global(machine, dac_value);
+	state_save_register_global(machine, dac_register);
+	state_save_register_global(machine, chip_select);
 
-	state_save_register_global(m6850_status);
-	state_save_register_global(m6850_control);
-	state_save_register_global(m6850_input);
-	state_save_register_global(m6850_output);
-	state_save_register_global(m6850_data_ready);
+	state_save_register_global(machine, m6850_status);
+	state_save_register_global(machine, m6850_control);
+	state_save_register_global(machine, m6850_input);
+	state_save_register_global(machine, m6850_output);
+	state_save_register_global(machine, m6850_data_ready);
 
-	state_save_register_global(m6850_sound_status);
-	state_save_register_global(m6850_sound_control);
-	state_save_register_global(m6850_sound_input);
-	state_save_register_global(m6850_sound_output);
+	state_save_register_global(machine, m6850_sound_status);
+	state_save_register_global(machine, m6850_sound_control);
+	state_save_register_global(machine, m6850_sound_input);
+	state_save_register_global(machine, m6850_sound_output);
 
-	state_save_register_global_array(noise_position);
+	state_save_register_global_array(machine, noise_position);
 
-	state_save_register_global(nstocker_bits);
-	state_save_register_global(spiker_expand_color);
-	state_save_register_global(spiker_expand_bgcolor);
-	state_save_register_global(spiker_expand_bits);
-	state_save_register_global(grudge_steering_result);
-	state_save_register_global_array(grudge_last_steering);
+	state_save_register_global(machine, nstocker_bits);
+	state_save_register_global(machine, spiker_expand_color);
+	state_save_register_global(machine, spiker_expand_bgcolor);
+	state_save_register_global(machine, spiker_expand_bits);
+	state_save_register_global(machine, grudge_steering_result);
+	state_save_register_global_array(machine, grudge_last_steering);
 }
 
 
@@ -313,7 +314,7 @@ READ8_HANDLER( balsente_random_num_r )
 	UINT32 cc;
 
 	/* CPU runs at 1.25MHz, noise source at 100kHz --> multiply by 12.5 */
-	cc = activecpu_gettotalcycles();
+	cc = cpu_get_total_cycles(space->cpu);
 
 	/* 12.5 = 8 + 4 + 0.5 */
 	cc = (cc << 3) + (cc << 2) + (cc >> 1);
@@ -331,8 +332,8 @@ READ8_HANDLER( balsente_random_num_r )
 WRITE8_HANDLER( balsente_rombank_select_w )
 {
 	/* the bank number comes from bits 4-6 */
-	memory_set_bank(1, (data >> 4) & 7);
-	memory_set_bank(2, (data >> 4) & 7);
+	memory_set_bank(space->machine, 1, (data >> 4) & 7);
+	memory_set_bank(space->machine, 2, (data >> 4) & 7);
 }
 
 
@@ -342,20 +343,20 @@ WRITE8_HANDLER( balsente_rombank2_select_w )
 	int bank = data & 7;
 
 	/* top bit controls which half of the ROMs to use (Name that Tune only) */
-	if (memory_region_length(REGION_CPU1) > 0x40000) bank |= (data >> 4) & 8;
+	if (memory_region_length(space->machine, "main") > 0x40000) bank |= (data >> 4) & 8;
 
 	/* when they set the AB bank, it appears as though the CD bank is reset */
 	if (data & 0x20)
 	{
-		memory_set_bank(1, bank);
-		memory_set_bank(2, 6);
+		memory_set_bank(space->machine, 1, bank);
+		memory_set_bank(space->machine, 2, 6);
 	}
 
 	/* set both banks */
 	else
 	{
-		memory_set_bank(1, bank);
-		memory_set_bank(2, bank);
+		memory_set_bank(space->machine, 1, bank);
+		memory_set_bank(space->machine, 2, bank);
 	}
 }
 
@@ -392,7 +393,7 @@ WRITE8_HANDLER( balsente_misc_output_w )
  *
  *************************************/
 
-static void m6850_update_io(void)
+static void m6850_update_io(running_machine *machine)
 {
 	UINT8 new_state;
 
@@ -448,12 +449,12 @@ static void m6850_update_io(void)
 	/* apply the change */
 	if (new_state && !(m6850_status & 0x80))
 	{
-		cpunum_set_input_line(Machine, 0, M6809_FIRQ_LINE, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[0], M6809_FIRQ_LINE, ASSERT_LINE);
 		m6850_status |= 0x80;
 	}
 	else if (!new_state && (m6850_status & 0x80))
 	{
-		cpunum_set_input_line(Machine, 0, M6809_FIRQ_LINE, CLEAR_LINE);
+		cpu_set_input_line(machine->cpu[0], M6809_FIRQ_LINE, CLEAR_LINE);
 		m6850_status &= ~0x80;
 	}
 
@@ -466,12 +467,12 @@ static void m6850_update_io(void)
 	/* apply the change */
 	if (new_state && !(m6850_sound_status & 0x80))
 	{
-		cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[1], INPUT_LINE_NMI, ASSERT_LINE);
 		m6850_sound_status |= 0x80;
 	}
 	else if (!new_state && (m6850_sound_status & 0x80))
 	{
-		cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, CLEAR_LINE);
+		cpu_set_input_line(machine->cpu[1], INPUT_LINE_NMI, CLEAR_LINE);
 		m6850_sound_status &= ~0x80;
 	}
 }
@@ -501,7 +502,7 @@ READ8_HANDLER( balsente_m6850_r )
 
 		/* clear the overrun and receive buffer full bits */
 		m6850_status &= ~0x21;
-		m6850_update_io();
+		m6850_update_io(space->machine);
 	}
 
 	return result;
@@ -513,7 +514,7 @@ static TIMER_CALLBACK( m6850_data_ready_callback )
 	/* set the output data byte and indicate that we're ready to go */
 	m6850_output = param;
 	m6850_data_ready = 1;
-	m6850_update_io();
+	m6850_update_io(machine);
 }
 
 
@@ -521,11 +522,11 @@ static TIMER_CALLBACK( m6850_w_callback )
 {
 	/* indicate that the transmit buffer is no longer empty and update the I/O state */
 	m6850_status &= ~0x02;
-	m6850_update_io();
+	m6850_update_io(machine);
 
 	/* set a timer for 500usec later to actually transmit the data */
 	/* (this is very important for several games, esp Snacks'n Jaxson) */
-	timer_set(ATTOTIME_IN_USEC(500), NULL, param, m6850_data_ready_callback);
+	timer_set(machine, ATTOTIME_IN_USEC(500), NULL, param, m6850_data_ready_callback);
 }
 
 
@@ -537,12 +538,12 @@ WRITE8_HANDLER( balsente_m6850_w )
 		m6850_control = data;
 
 		/* re-update since interrupt enables could have been modified */
-		m6850_update_io();
+		m6850_update_io(space->machine);
 	}
 
 	/* output register is at offset 1; set a timer to synchronize the CPUs */
 	else
-		timer_call_after_resynch(NULL, data, m6850_w_callback);
+		timer_call_after_resynch(space->machine, NULL, data, m6850_w_callback);
 }
 
 
@@ -570,7 +571,7 @@ READ8_HANDLER( balsente_m6850_sound_r )
 
 		/* clear the overrun and receive buffer full bits */
 		m6850_sound_status &= ~0x21;
-		m6850_update_io();
+		m6850_update_io(space->machine);
 	}
 
 	return result;
@@ -591,7 +592,7 @@ WRITE8_HANDLER( balsente_m6850_sound_w )
 	}
 
 	/* re-update since interrupt enables could have been modified */
-	m6850_update_io();
+	m6850_update_io(space->machine);
 }
 
 
@@ -605,13 +606,14 @@ WRITE8_HANDLER( balsente_m6850_sound_w )
 INTERRUPT_GEN( balsente_update_analog_inputs )
 {
 	int i;
+	static const char *const analog[] = { "AN0", "AN1", "AN2", "AN3" };
 
 	/* the analog input system helpfully scales the value read by the percentage of time */
 	/* into the current frame we are; unfortunately, this is bad for us, since the analog */
 	/* ports are read once a frame, just at varying intervals. To get around this, we */
 	/* read all the analog inputs at VBLANK time and just return the cached values. */
 	for (i = 0; i < 4; i++)
-		analog_input_data[i] = readinputport(4 + i);
+		analog_input_data[i] = input_port_read(device->machine, analog[i]);
 }
 
 
@@ -661,7 +663,7 @@ WRITE8_HANDLER( balsente_adc_select_w )
 	/* set a timer to go off and read the value after 50us */
 	/* it's important that we do this for Mini Golf */
 logerror("adc_select %d\n", offset & 7);
-	timer_set(ATTOTIME_IN_USEC(50), NULL, offset & 7, adc_finished);
+	timer_set(space->machine, ATTOTIME_IN_USEC(50), NULL, offset & 7, adc_finished);
 }
 
 
@@ -683,7 +685,7 @@ INLINE void counter_start(int which)
 		if (counter[which].gate && !counter[which].timer_active)
 		{
 			counter[which].timer_active = 1;
-			timer_adjust(counter[which].timer, attotime_mul(ATTOTIME_IN_HZ(2000000), counter[which].count), which, attotime_zero);
+			timer_adjust_oneshot(counter[which].timer, attotime_mul(ATTOTIME_IN_HZ(2000000), counter[which].count), which);
 		}
 	}
 }
@@ -693,7 +695,7 @@ INLINE void counter_stop(int which)
 {
 	/* only stop the timer if it exists */
 	if (counter[which].timer_active)
-		timer_adjust(counter[which].timer, attotime_never, 0, attotime_zero);
+		timer_adjust_oneshot(counter[which].timer, attotime_never, 0);
 	counter[which].timer_active = 0;
 }
 
@@ -719,7 +721,7 @@ INLINE void counter_update_count(int which)
  *
  *************************************/
 
-static void counter_set_gate(int which, int gate)
+static void counter_set_gate(running_machine *machine, int which, int gate)
 {
 	int oldgate = counter[which].gate;
 
@@ -739,7 +741,7 @@ static void counter_set_gate(int which, int gate)
 		/* mode 1 waits for the gate to trigger the counter */
 		if (counter[which].mode == 1)
 		{
-			counter_set_out(which, 0);
+			counter_set_out(machine, which, 0);
 
 			/* add one to the count; technically, OUT goes low on the next clock pulse */
 			/* and then starts counting down; it's important that we don't count the first one */
@@ -752,15 +754,15 @@ static void counter_set_gate(int which, int gate)
 }
 
 
-static void counter_set_out(int which, int out)
+static void counter_set_out(running_machine *machine, int which, int out)
 {
 	/* OUT on counter 2 is hooked to the /INT line on the Z80 */
 	if (which == 2)
-		cpunum_set_input_line(Machine, 1, 0, out ? ASSERT_LINE : CLEAR_LINE);
+		cpu_set_input_line(machine->cpu[1], 0, out ? ASSERT_LINE : CLEAR_LINE);
 
 	/* OUT on counter 0 is hooked to the GATE line on counter 1 */
 	else if (which == 0)
-		counter_set_gate(1, !out);
+		counter_set_gate(machine, 1, !out);
 
 	/* remember the out state */
 	counter[which].out = out;
@@ -776,7 +778,7 @@ static TIMER_CALLBACK( counter_callback )
 	/* set the state of the OUT line */
 	/* mode 0 and 1: when firing, transition OUT to high */
 	if (counter[param].mode == 0 || counter[param].mode == 1)
-		counter_set_out(param, 1);
+		counter_set_out(machine, param, 1);
 
 	/* no other modes handled currently */
 }
@@ -839,7 +841,7 @@ WRITE8_HANDLER( balsente_counter_8253_w )
 
 			/* if the counter is in mode 0, a write here will reset the OUT state */
 			if (counter[which].mode == 0)
-				counter_set_out(which, 0);
+				counter_set_out(space->machine, which, 0);
 
 			/* write the LSB */
 			if (counter[which].writebyte == 0)
@@ -868,7 +870,7 @@ WRITE8_HANDLER( balsente_counter_8253_w )
 
 				/* if the counter is in mode 1, a write here will set the OUT state */
 				if (counter[which].mode == 1)
-					counter_set_out(which, 1);
+					counter_set_out(space->machine, which, 1);
 			}
 			break;
 
@@ -879,14 +881,14 @@ WRITE8_HANDLER( balsente_counter_8253_w )
 
 			/* if the counter was in mode 0, a write here will reset the OUT state */
 			if (((counter[which].mode >> 1) & 7) == 0)
-				counter_set_out(which, 0);
+				counter_set_out(space->machine, which, 0);
 
 			/* set the mode */
 			counter[which].mode = (data >> 1) & 7;
 
 			/* if the counter is in mode 0, a write here will reset the OUT state */
 			if (counter[which].mode == 0)
-				counter_set_out(which, 0);
+				counter_set_out(space->machine, which, 0);
 			break;
 	}
 }
@@ -932,7 +934,7 @@ static void update_counter_0_timer(void)
 
 	/* if there's already a timer, remove it */
 	if (counter_0_timer_active)
-		timer_adjust(counter_0_timer, attotime_never, 0, attotime_zero);
+		timer_adjust_oneshot(counter_0_timer, attotime_never, 0);
 	counter_0_timer_active = 0;
 
 	/* find the counter with the maximum frequency */
@@ -957,7 +959,7 @@ static void update_counter_0_timer(void)
 	if (maxfreq > 0.0)
 	{
 		counter_0_timer_active = 1;
-		timer_adjust(counter_0_timer, ATTOTIME_IN_HZ(maxfreq), 0, ATTOTIME_IN_HZ(maxfreq));
+		timer_adjust_periodic(counter_0_timer, ATTOTIME_IN_HZ(maxfreq), 0, ATTOTIME_IN_HZ(maxfreq));
 	}
 }
 
@@ -1006,19 +1008,19 @@ WRITE8_HANDLER( balsente_counter_control_w )
 	/* if we gate off, remove the timer */
 	else if (counter[0].gate && !(data & 0x02) && counter_0_timer_active)
 	{
-		timer_adjust(counter_0_timer, attotime_never, 0, attotime_zero);
+		timer_adjust_oneshot(counter_0_timer, attotime_never, 0);
 		counter_0_timer_active = 0;
 	}
 
 	/* set the actual gate afterwards, since we need to know the old value above */
-	counter_set_gate(0, (data >> 1) & 1);
+	counter_set_gate(space->machine, 0, (data >> 1) & 1);
 
 	/* bits D2 and D4 control the clear/reset flags on the flip-flop that feeds counter 0 */
-	if (!(data & 0x04)) set_counter_0_ff(Machine, 1);
-	if (!(data & 0x10)) set_counter_0_ff(Machine, 0);
+	if (!(data & 0x04)) set_counter_0_ff(space->machine, 1);
+	if (!(data & 0x10)) set_counter_0_ff(space->machine, 0);
 
 	/* bit 5 clears the NMI interrupt; recompute the I/O state now */
-	m6850_update_io();
+	m6850_update_io(space->machine);
 }
 
 
@@ -1077,7 +1079,7 @@ WRITE8_HANDLER( balsente_chip_select_w )
 					"PULSE_WIDTH",
 					"WAVE_SELECT"
 				};
-				logerror("s%04X:   CEM#%d:%s=%f\n", activecpu_get_previouspc(), i, names[dac_register], voltage);
+				logerror("s%04X:   CEM#%d:%s=%f\n", cpu_get_previouspc(space->cpu), i, names[dac_register], voltage);
 			}
 #endif
 		}
@@ -1101,8 +1103,8 @@ WRITE8_HANDLER( balsente_dac_data_w )
 	if ((chip_select & 0x3f) != 0x3f)
 	{
 		UINT8 temp = chip_select;
-		balsente_chip_select_w(0, 0x3f);
-		balsente_chip_select_w(0, temp);
+		balsente_chip_select_w(space, 0, 0x3f);
+		balsente_chip_select_w(space, 0, temp);
 	}
 }
 
@@ -1120,9 +1122,9 @@ WRITE8_HANDLER( balsente_register_addr_w )
  *
  *************************************/
 
-READ8_HANDLER( nstocker_port2_r )
+CUSTOM_INPUT( nstocker_bits_r )
 {
-	return (readinputport(2) & 0xf0) | nstocker_bits;
+	return nstocker_bits;
 }
 
 
@@ -1161,15 +1163,15 @@ READ8_HANDLER( spiker_expand_r )
 }
 
 
-static void update_grudge_steering(void)
+static void update_grudge_steering(running_machine *machine)
 {
 	UINT8 wheel[3];
 	INT8 diff[3];
 
 	/* read the current steering values */
-	wheel[0] = readinputport(4);
-	wheel[1] = readinputport(5);
-	wheel[2] = readinputport(6);
+	wheel[0] = input_port_read(machine, "AN0");
+	wheel[1] = input_port_read(machine, "AN1");
+	wheel[2] = input_port_read(machine, "AN2");
 
 	/* diff the values */
 	diff[0] = wheel[0] - grudge_last_steering[0];
@@ -1204,7 +1206,7 @@ static void update_grudge_steering(void)
 
 READ8_HANDLER( grudge_steering_r )
 {
-	logerror("%04X:grudge_steering_r(@%d)\n", activecpu_get_pc(), video_screen_get_vpos(0));
+	logerror("%04X:grudge_steering_r(@%d)\n", cpu_get_pc(space->cpu), video_screen_get_vpos(space->machine->primary_screen));
 	grudge_steering_result |= 0x80;
 	return grudge_steering_result;
 }
@@ -1219,22 +1221,22 @@ READ8_HANDLER( grudge_steering_r )
 
 READ8_HANDLER( shrike_shared_6809_r )
 {
-  UINT16 mem_mask = offset & 1 ? 0xff : 0xff00;
+  UINT16 mem_mask = offset & 1 ? 0xff00 : 0x00ff;
 
   switch( offset )
   {
     case 6: // return OK for 68k status register until motors hooked up
       return 0;
     default:
-      return ( shrike_shared[offset >> 1] & mem_mask ) >> ( ~mem_mask & 8 );
+      return ( shrike_shared[offset >> 1] & ~mem_mask ) >> ( mem_mask & 8 );
   }
 }
 
 
 WRITE8_HANDLER( shrike_shared_6809_w )
 {
-  UINT16 mem_mask = offset & 1 ? 0xff : 0xff00;
-  shrike_shared[offset >> 1] = ( shrike_shared[offset >> 1] & ~mem_mask ) | ( data << ( ~mem_mask & 0x8 ) );
+  UINT16 mem_mask = offset & 1 ? 0xff00 : 0x00ff;
+  shrike_shared[offset >> 1] = ( shrike_shared[offset >> 1] & mem_mask ) | ( data << ( mem_mask & 0x8 ) );
 }
 
 // uses movep, so writes even 8 bit addresses to odd 16 bit addresses, reads as 16 bit from odd addresses
@@ -1246,6 +1248,6 @@ WRITE16_HANDLER( shrike_io_68k_w )
 
 READ16_HANDLER( shrike_io_68k_r )
 {
-  return ( shrike_io[offset] & ~mem_mask ) >> ( 8 & mem_mask );
+  return ( shrike_io[offset] & mem_mask ) >> ( 8 & ~mem_mask );
 }
 
