@@ -78,7 +78,7 @@ static void amiga_akiko_exit(running_machine* machine)
 
 void amiga_akiko_init(running_machine* machine)
 {
-	i2cmem_init( 0, I2CMEM_SLAVE_ADDRESS, NVRAM_PAGE_SIZE, NVRAM_SIZE, NULL );
+	i2cmem_init( machine, 0, I2CMEM_SLAVE_ADDRESS, NVRAM_PAGE_SIZE, NVRAM_SIZE, NULL );
 
 	akiko.c2p_input_index = 0;
 	akiko.c2p_output_index = 0;
@@ -102,10 +102,10 @@ void amiga_akiko_init(running_machine* machine)
 	akiko.cdrom_cmd_start = 0;
 	akiko.cdrom_cmd_end = 0;
 	akiko.cdrom_cmd_resp = 0;
-	akiko.cdrom = cdrom_open(get_disk_handle(0));
+	akiko.cdrom = cdrom_open(get_disk_handle("cdrom"));
 	akiko.cdrom_toc = NULL;
-	akiko.dma_timer = timer_alloc(akiko_dma_proc, NULL);
-	akiko.frame_timer = timer_alloc(akiko_frame_proc, NULL);
+	akiko.dma_timer = timer_alloc(machine, akiko_dma_proc, NULL);
+	akiko.frame_timer = timer_alloc(machine, akiko_frame_proc, NULL);
 
 	add_exit_callback(machine, amiga_akiko_exit);
 
@@ -159,18 +159,18 @@ void amiga_akiko_init(running_machine* machine)
 	}
 }
 
-static void akiko_nvram_write(UINT32 data)
+static void akiko_nvram_write(running_machine *machine, UINT32 data)
 {
 	akiko.i2c_scl_out = BIT(data,31);
 	akiko.i2c_sda_out = BIT(data,30);
 	akiko.i2c_scl_dir = BIT(data,15);
 	akiko.i2c_sda_dir = BIT(data,14);
 
-	i2cmem_write( 0, I2CMEM_SCL, akiko.i2c_scl_out );
-	i2cmem_write( 0, I2CMEM_SDA, akiko.i2c_sda_out );
+	i2cmem_write( machine, 0, I2CMEM_SCL, akiko.i2c_scl_out );
+	i2cmem_write( machine, 0, I2CMEM_SDA, akiko.i2c_sda_out );
 }
 
-static UINT32 akiko_nvram_read(void)
+static UINT32 akiko_nvram_read(running_machine *machine)
 {
 	UINT32	v = 0;
 
@@ -189,7 +189,7 @@ static UINT32 akiko_nvram_read(void)
 	}
 	else
 	{
-		v |= i2cmem_read( 0, I2CMEM_SDA ) << 30;
+		v |= i2cmem_read( machine, 0, I2CMEM_SDA ) << 30;
 	}
 
 	v |= akiko.i2c_scl_dir << 15;
@@ -240,7 +240,6 @@ static UINT32 akiko_c2p_read(void)
 	return val;
 }
 
-#if LOG_AKIKO
 static const char *const akiko_reg_names[] =
 {
 	/*0*/	"ID",
@@ -260,7 +259,7 @@ static const char *const akiko_reg_names[] =
 	/*E*/	"C2P"
 };
 
-const char* get_akiko_reg_name(int reg)
+static const char* get_akiko_reg_name(int reg)
 {
 	if (reg < 0xf )
 	{
@@ -271,7 +270,6 @@ const char* get_akiko_reg_name(int reg)
 		return "???";
 	}
 }
-#endif
 
 /*************************************
  *
@@ -296,7 +294,7 @@ static void akiko_cdda_play( UINT32 lba, UINT32 num_blocks )
 	if (cddanum != -1)
 	{
 		cdda_start_audio(cddanum, lba, num_blocks);
-		timer_adjust( akiko.frame_timer, ATTOTIME_IN_HZ( 75 ), 0, attotime_zero );
+		timer_adjust_oneshot( akiko.frame_timer, ATTOTIME_IN_HZ( 75 ), 0 );
 	}
 }
 
@@ -315,7 +313,7 @@ static void akiko_cdda_pause( int pause )
 			}
 			else
 			{
-				timer_adjust( akiko.frame_timer, ATTOTIME_IN_HZ( 75 ), 0, attotime_zero );
+				timer_adjust_oneshot( akiko.frame_timer, ATTOTIME_IN_HZ( 75 ), 0 );
 			}
 		}
 	}
@@ -351,16 +349,14 @@ static UINT8 akiko_cdda_getstatus( UINT32 *lba )
 	return 0x15;	/* no audio status */
 }
 
-static void akiko_set_cd_status( UINT32 status )
+static void akiko_set_cd_status( running_machine *machine, UINT32 status )
 {
 	akiko.cdrom_status[0] |= status;
 
 	if ( akiko.cdrom_status[0] & akiko.cdrom_status[1] )
 	{
-#if LOG_AKIKO_CD
-		logerror( "Akiko CD IRQ\n" );
-#endif
-		amiga_custom_w(REG_INTREQ, 0x8000 | INTENA_PORTS, 0);
+		if (LOG_AKIKO_CD) logerror( "Akiko CD IRQ\n" );
+		amiga_custom_w(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), REG_INTREQ, 0x8000 | INTENA_PORTS, 0xffff);
 	}
 }
 
@@ -376,10 +372,10 @@ static TIMER_CALLBACK(akiko_frame_proc)
 
 		if ( s == 0x11 )
 		{
-			akiko_set_cd_status( 0x80000000 );	/* subcode ready */
+			akiko_set_cd_status( machine, 0x80000000 );	/* subcode ready */
 		}
 
-		timer_adjust( akiko.frame_timer, ATTOTIME_IN_HZ( 75 ), 0, attotime_zero );
+		timer_adjust_oneshot( akiko.frame_timer, ATTOTIME_IN_HZ( 75 ), 0 );
 	}
 }
 
@@ -461,9 +457,7 @@ static TIMER_CALLBACK(akiko_dma_proc)
 			}
 		}
 
-#if LOG_AKIKO_CD
-		logerror( "DMA: sector %d - address %08x\n", akiko.cdrom_lba_cur, akiko.cdrom_address[0] + (index*4096) );
-#endif
+		if (LOG_AKIKO_CD) logerror( "DMA: sector %d - address %08x\n", akiko.cdrom_lba_cur, akiko.cdrom_address[0] + (index*4096) );
 
 		for( i = 0; i < 2352; i += 2 )
 		{
@@ -482,9 +476,9 @@ static TIMER_CALLBACK(akiko_dma_proc)
 	}
 
 	if ( akiko.cdrom_readreqmask == 0 )
-		akiko_set_cd_status(0x04000000);
+		akiko_set_cd_status(machine, 0x04000000);
 	else
-		timer_adjust( akiko.dma_timer, ATTOTIME_IN_USEC( CD_SECTOR_TIME / akiko.cdrom_speed ), 0, attotime_zero );
+		timer_adjust_oneshot( akiko.dma_timer, ATTOTIME_IN_USEC( CD_SECTOR_TIME / akiko.cdrom_speed ), 0 );
 }
 
 static void akiko_start_dma( void )
@@ -500,10 +494,10 @@ static void akiko_start_dma( void )
 
 	akiko.cdrom_lba_cur = akiko.cdrom_lba_start;
 
-	timer_adjust( akiko.dma_timer, ATTOTIME_IN_USEC( CD_SECTOR_TIME / akiko.cdrom_speed ), 0, attotime_zero );
+	timer_adjust_oneshot( akiko.dma_timer, ATTOTIME_IN_USEC( CD_SECTOR_TIME / akiko.cdrom_speed ), 0 );
 }
 
-static void akiko_setup_response( int len, UINT8 *r1 )
+static void akiko_setup_response( const address_space *space, int len, UINT8 *r1 )
 {
 	int		resp_addr = akiko.cdrom_address[1];
 	UINT8	resp_csum = 0xff;
@@ -522,12 +516,12 @@ static void akiko_setup_response( int len, UINT8 *r1 )
 
 	for( i = 0; i < len; i++ )
 	{
-		program_write_byte( resp_addr + ((akiko.cdrom_cmd_resp + i) & 0xff), resp_buffer[i] );
+		memory_write_byte( space, resp_addr + ((akiko.cdrom_cmd_resp + i) & 0xff), resp_buffer[i] );
 	}
 
 	akiko.cdrom_cmd_resp = (akiko.cdrom_cmd_resp+len) & 0xff;
 
-	akiko_set_cd_status( 0x10000000 ); /* new data available */
+	akiko_set_cd_status( space->machine, 0x10000000 ); /* new data available */
 }
 
 static TIMER_CALLBACK( akiko_cd_delayed_cmd )
@@ -550,16 +544,15 @@ static TIMER_CALLBACK( akiko_cd_delayed_cmd )
 
 	if ( param == 0x05 )
 	{
-#if LOG_AKIKO_CD
-		logerror( "AKIKO: Completing Command %d\n", param );
-#endif
+		const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+		if (LOG_AKIKO_CD) logerror( "AKIKO: Completing Command %d\n", param );
 
 		resp[0] = 0x06;
 
 		if ( akiko.cdrom == NULL || akiko.cdrom_numtracks == 0 )
 		{
 			resp[1] = 0x80;
-			akiko_setup_response( 15, resp );
+			akiko_setup_response( space, 15, resp );
 		}
 		else
 		{
@@ -568,12 +561,12 @@ static TIMER_CALLBACK( akiko_cd_delayed_cmd )
 
 			akiko.cdrom_track_index = ( akiko.cdrom_track_index + 1 ) % akiko.cdrom_numtracks;
 
-			akiko_setup_response( 15, resp );
+			akiko_setup_response( space, 15, resp );
 		}
 	}
 }
 
-static void akiko_update_cdrom( void )
+static void akiko_update_cdrom(const address_space *space)
 {
 	UINT8	resp[32], cmdbuf[32];
 
@@ -583,16 +576,14 @@ static void akiko_update_cdrom( void )
 	while ( akiko.cdrom_cmd_start != akiko.cdrom_cmd_end )
 	{
 		UINT32	cmd_addr = akiko.cdrom_address[1] + 0x200 + akiko.cdrom_cmd_start;
-		int		cmd = program_read_byte( cmd_addr );
+		int		cmd = memory_read_byte( space, cmd_addr );
 
 		memset( resp, 0, sizeof( resp ) );
 		resp[0] = cmd;
 
 		cmd &= 0x0f;
 
-#if LOG_AKIKO_CD
-		logerror( "CDROM command: %02X\n", cmd );
-#endif
+		if (LOG_AKIKO_CD) logerror( "CDROM command: %02X\n", cmd );
 
 		if ( cmd == 0x02 ) /* pause audio */
 		{
@@ -605,7 +596,7 @@ static void akiko_update_cdrom( void )
 
 			akiko.cdrom_cmd_start = (akiko.cdrom_cmd_start+2) & 0xff;
 
-			akiko_setup_response( 2, resp );
+			akiko_setup_response( space, 2, resp );
 		}
 		else if ( cmd == 0x03 ) /* unpause audio (and check audiocd playing status) */
 		{
@@ -618,7 +609,7 @@ static void akiko_update_cdrom( void )
 
 			akiko.cdrom_cmd_start = (akiko.cdrom_cmd_start+2) & 0xff;
 
-			akiko_setup_response( 2, resp );
+			akiko_setup_response( space, 2, resp );
 		}
 		else if ( cmd == 0x04 ) /* seek/read/play cd multi command */
 		{
@@ -627,7 +618,7 @@ static void akiko_update_cdrom( void )
 
 			for( i = 0; i < 13; i++ )
 			{
-				cmdbuf[i] = program_read_byte( cmd_addr );
+				cmdbuf[i] = memory_read_byte( space, cmd_addr );
 				cmd_addr &= 0xffffff00;
 				cmd_addr += ( akiko.cdrom_cmd_start + i + 1 ) & 0xff;
 			}
@@ -637,7 +628,7 @@ static void akiko_update_cdrom( void )
 			if ( akiko.cdrom == NULL || akiko.cdrom_numtracks == 0 )
 			{
 				resp[1] = 0x80;
-				akiko_setup_response( 2, resp );
+				akiko_setup_response( space, 2, resp );
 			}
 			else
 			{
@@ -650,9 +641,7 @@ static void akiko_update_cdrom( void )
 
 				if ( cmdbuf[7] == 0x80 )
 				{
-#if LOG_AKIKO_CD
-					logerror( "AKIKO CD: PC:%06x Data read - start lba: %08x - end lba: %08x\n", safe_activecpu_get_pc(), startpos, endpos );
-#endif
+					if (LOG_AKIKO_CD) logerror( "%s:AKIKO CD: Data read - start lba: %08x - end lba: %08x\n", cpuexec_describe_context(space->machine), startpos, endpos );
 					akiko.cdrom_speed = (cmdbuf[8] & 0x40) ? 2 : 1;
 					akiko.cdrom_lba_start = startpos;
 					akiko.cdrom_lba_end = endpos;
@@ -667,9 +656,7 @@ static void akiko_update_cdrom( void )
 				}
 				else
 				{
-#if LOG_AKIKO_CD
-					logerror( "AKIKO CD: Seek - start lba: %08x - end lba: %08x\n", startpos, endpos );
-#endif
+					if (LOG_AKIKO_CD) logerror( "AKIKO CD: Seek - start lba: %08x - end lba: %08x\n", startpos, endpos );
 					akiko.cdrom_track_index = 0;
 
 					for( i = 0; i < cdrom_get_last_track(akiko.cdrom); i++ )
@@ -684,14 +671,14 @@ static void akiko_update_cdrom( void )
 					}
 				}
 
-				akiko_setup_response( 2, resp );
+				akiko_setup_response( space, 2, resp );
 			}
 		}
 		else if ( cmd == 0x05 ) /* read toc */
 		{
 			akiko.cdrom_cmd_start = (akiko.cdrom_cmd_start+3) & 0xff;
 
-			timer_set( ATTOTIME_IN_MSEC(1), NULL, resp[0], akiko_cd_delayed_cmd );
+			timer_set( space->machine, ATTOTIME_IN_MSEC(1), NULL, resp[0], akiko_cd_delayed_cmd );
 
 			break;
 		}
@@ -737,7 +724,7 @@ static void akiko_update_cdrom( void )
 				resp[1] = 0x80;
 			}
 
-			akiko_setup_response( 15, resp );
+			akiko_setup_response( space, 15, resp );
 		}
 		else if ( cmd == 0x07 )	/* check door status */
 		{
@@ -748,7 +735,7 @@ static void akiko_update_cdrom( void )
 			if ( akiko.cdrom == NULL || akiko.cdrom_numtracks == 0 )
 				resp[1] = 0x80;
 
-			akiko_setup_response( 20, resp );
+			akiko_setup_response( space, 20, resp );
 			break;
 		}
 		else
@@ -762,12 +749,10 @@ READ32_HANDLER(amiga_akiko32_r)
 {
 	UINT32		retval;
 
-#if LOG_AKIKO
-	if ( offset < (0x30/4) )
+	if ( LOG_AKIKO && offset < (0x30/4) )
 	{
-		logerror( "Reading AKIKO reg %0x [%s] at PC=%06x\n", offset, get_akiko_reg_name(offset), activecpu_get_pc() );
+		logerror( "Reading AKIKO reg %0x [%s] at PC=%06x\n", offset, get_akiko_reg_name(offset), cpu_get_pc(space->cpu) );
 	}
-#endif
 
 	switch( offset )
 	{
@@ -788,7 +773,7 @@ READ32_HANDLER(amiga_akiko32_r)
 			return akiko.cdrom_address[1];
 
 		case 0x18/4:	/* CDROM COMMAND 1 */
-			akiko_update_cdrom();
+			akiko_update_cdrom(space);
 			retval = akiko.cdrom_cmd_start;
 			retval <<= 8;
 			retval |= akiko.cdrom_cmd_resp;
@@ -796,7 +781,7 @@ READ32_HANDLER(amiga_akiko32_r)
 			return retval;
 
 		case 0x1C/4:	/* CDROM COMMAND 2 */
-			akiko_update_cdrom();
+			akiko_update_cdrom(space);
 			retval = akiko.cdrom_cmd_end;
 			retval <<= 16;
 			return retval;
@@ -810,7 +795,7 @@ READ32_HANDLER(amiga_akiko32_r)
 			return retval;
 
 		case 0x30/4:	/* NVRAM */
-			return akiko_nvram_read();
+			return akiko_nvram_read(space->machine);
 
 		case 0x38/4:	/* C2P */
 			return akiko_c2p_read();
@@ -824,12 +809,10 @@ READ32_HANDLER(amiga_akiko32_r)
 
 WRITE32_HANDLER(amiga_akiko32_w)
 {
-#if LOG_AKIKO
-	if ( offset < (0x30/4) )
+	if ( LOG_AKIKO && offset < (0x30/4) )
 	{
-		logerror( "Writing AKIKO reg %0x [%s] with %08x at PC=%06x\n", offset, get_akiko_reg_name(offset), data, activecpu_get_pc() );
+		logerror( "Writing AKIKO reg %0x [%s] with %08x at PC=%06x\n", offset, get_akiko_reg_name(offset), data, cpu_get_pc(space->cpu) );
 	}
-#endif
 
 	switch( offset )
 	{
@@ -851,27 +834,25 @@ WRITE32_HANDLER(amiga_akiko32_w)
 			break;
 
 		case 0x18/4:	/* CDROM COMMAND 1 */
-			if ( ( mem_mask & 0x00ff0000 ) == 0 )
+			if ( ACCESSING_BITS_16_23 )
 				akiko.cdrom_cmd_start = ( data >> 16 ) & 0xff;
 
-			if ( ( mem_mask & 0x0000ff00 ) == 0 )
+			if ( ACCESSING_BITS_8_15 )
 				akiko.cdrom_cmd_resp = ( data >> 8 ) & 0xff;
 
-			akiko_update_cdrom();
+			akiko_update_cdrom(space);
 			break;
 
 		case 0x1C/4:	/* CDROM COMMAND 2 */
-			if ( ( mem_mask & 0x00ff0000 ) == 0 )
+			if ( ACCESSING_BITS_16_23 )
 				akiko.cdrom_cmd_end = ( data >> 16 ) & 0xff;
 
-			akiko_update_cdrom();
+			akiko_update_cdrom(space);
 			break;
 
 		case 0x20/4:	/* CDROM DMA SECTOR READ REQUEST WRITE */
-#if LOG_AKIKO_CD
-			logerror( "Read Req mask W: data %08x - mem mask %08x\n", data, mem_mask );
-#endif
-			if ( ( mem_mask & 0xffff0000 ) == 0 )
+			if (LOG_AKIKO_CD) logerror( "Read Req mask W: data %08x - mem mask %08x\n", data, mem_mask );
+			if ( ACCESSING_BITS_16_31 )
 			{
 				akiko.cdrom_readreqmask = (data >> 16);
 				akiko.cdrom_readmask = 0;
@@ -879,9 +860,7 @@ WRITE32_HANDLER(amiga_akiko32_w)
 			break;
 
 		case 0x24/4:	/* CDROM DMA ENABLE? */
-#if LOG_AKIKO_CD
-			logerror( "DMA enable W: data %08x - mem mask %08x\n", data, mem_mask );
-#endif
+			if (LOG_AKIKO_CD) logerror( "DMA enable W: data %08x - mem mask %08x\n", data, mem_mask );
 			if ( ( akiko.cdrom_dmacontrol ^ data ) & 0x04000000 )
 			{
 				if ( data & 0x04000000 )
@@ -891,7 +870,7 @@ WRITE32_HANDLER(amiga_akiko32_w)
 			break;
 
 		case 0x30/4:
-			akiko_nvram_write(data);
+			akiko_nvram_write(space->machine, data);
 			break;
 
 		case 0x38/4:
