@@ -7,7 +7,6 @@ Data East machine functions - Bryan McPhail, mish@tendril.co.uk
 *******************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "dec0.h"
 #include "cpu/h6280/h6280.h"
 
@@ -20,20 +19,20 @@ READ16_HANDLER( dec0_controls_r )
 	switch (offset<<1)
 	{
 		case 0: /* Player 1 & 2 joystick & buttons */
-			return (readinputport(0) + (readinputport(1) << 8));
+			return input_port_read(space->machine, "INPUTS");
 
 		case 2: /* Credits, start buttons */
-			return readinputport(2);
+			return input_port_read(space->machine, "SYSTEM");
 
 		case 4: /* Byte 4: Dipswitch bank 2, Byte 5: Dipswitch Bank 1 */
-			return (readinputport(3) + (readinputport(4) << 8));
+			return input_port_read(space->machine, "DSW");
 
 		case 8: /* Intel 8751 mc, Bad Dudes & Heavy Barrel only */
-			//logerror("CPU #0 PC %06x: warning - read unmapped memory address %06x\n",activecpu_get_pc(),0x30c000+offset);
+			//logerror("CPU #0 PC %06x: warning - read unmapped memory address %06x\n", cpu_get_pc(space->cpu), 0x30c000+offset);
 			return i8751_return;
 	}
 
-	logerror("CPU #0 PC %06x: warning - read unmapped memory address %06x\n",activecpu_get_pc(),0x30c000+offset);
+	logerror("CPU #0 PC %06x: warning - read unmapped memory address %06x\n", cpu_get_pc(space->cpu), 0x30c000+offset);
 	return ~0;
 }
 
@@ -44,13 +43,13 @@ READ16_HANDLER( dec0_rotary_r )
 	switch (offset<<1)
 	{
 		case 0: /* Player 1 rotary */
-			return ~(1 << (readinputport(5) * 12 / 256));
+			return ~(1 << (input_port_read(space->machine, "AN0") * 12 / 256));
 
 		case 8: /* Player 2 rotary */
-			return ~(1 << (readinputport(6) * 12 / 256));
+			return ~(1 << (input_port_read(space->machine, "AN1") * 12 / 256));
 
 		default:
-			logerror("Unknown rotary read at 300000 %02x\n",offset);
+			logerror("Unknown rotary read at 300000 %02x\n", offset);
 	}
 
 	return 0;
@@ -63,25 +62,25 @@ READ16_HANDLER( midres_controls_r )
 	switch (offset<<1)
 	{
 		case 0: /* Player 1 Joystick + start, Player 2 Joystick + start */
-			return (readinputport(0) + (readinputport(1) << 8));
+			return input_port_read(space->machine, "INPUTS");
 
 		case 2: /* Dipswitches */
-			return (readinputport(3) + (readinputport(4) << 8));
+			return input_port_read(space->machine, "DSW");
 
 		case 4: /* Player 1 rotary */
-			return ~(1 << (readinputport(5) * 12 / 256));
+			return ~(1 << (input_port_read(space->machine, "AN0") * 12 / 256));
 
 		case 6: /* Player 2 rotary */
-			return ~(1 << (readinputport(6) * 12 / 256));
+			return ~(1 << (input_port_read(space->machine, "AN1") * 12 / 256));
 
 		case 8: /* Credits, start buttons */
-			return readinputport(2);
+			return input_port_read(space->machine, "SYSTEM");
 
 		case 12:
 			return 0;	/* ?? watchdog ?? */
 	}
 
-	logerror("PC %06x unknown control read at %02x\n",activecpu_get_pc(),0x180000+offset);
+	logerror("PC %06x unknown control read at %02x\n", cpu_get_pc(space->cpu), 0x180000+offset);
 	return ~0;
 }
 
@@ -92,16 +91,16 @@ READ16_HANDLER( slyspy_controls_r )
 	switch (offset<<1)
 	{
 		case 0: /* Dip Switches */
-			return (readinputport(3) + (readinputport(4) << 8));
+			return input_port_read(space->machine, "DSW");
 
 		case 2: /* Player 1 & Player 2 joysticks & fire buttons */
-			return (readinputport(0) + (readinputport(1) << 8));
+			return input_port_read(space->machine, "INPUTS");
 
 		case 4: /* Credits */
-			return readinputport(2);
+			return input_port_read(space->machine, "SYSTEM");
 	}
 
-	logerror("Unknown control read at 30c000 %d\n",offset);
+	logerror("Unknown control read at 30c000 %d\n", offset);
 	return ~0;
 }
 
@@ -115,7 +114,7 @@ READ16_HANDLER( slyspy_protection_r )
 		case 6:		return 0x2;
 	}
 
-	logerror("%04x, Unknown protection read at 30c000 %d\n",activecpu_get_pc(),offset);
+	logerror("%04x, Unknown protection read at 30c000 %d\n", cpu_get_pc(space->cpu), offset);
 	return 0;
 }
 
@@ -168,72 +167,72 @@ WRITE16_HANDLER( slyspy_240000_w )
 {
 	switch (slyspy_state) {
 		case 0x3:
-			dec0_pf1_data_w(offset,data,mem_mask);
+			dec0_pf1_data_w(space,offset,data,mem_mask);
 			return;
 		case 0x2:
-			dec0_pf2_data_w(offset,data,mem_mask);
+			dec0_pf2_data_w(space,offset,data,mem_mask);
 			return;
 		case 0x0:
-			if (offset<0x8) dec0_pf2_control_0_w(offset,data,mem_mask);
-			else if (offset<0x10) dec0_pf2_control_1_w(offset-0x8,data,mem_mask);
+			if (offset<0x8) dec0_pf2_control_0_w(space,offset,data,mem_mask);
+			else if (offset<0x10) dec0_pf2_control_1_w(space,offset-0x8,data,mem_mask);
 			return;
 	}
-	logerror("Wrote to 240000 %02x at %04x %04x (Trap %02x)\n",offset,activecpu_get_pc(),data,slyspy_state);
+	logerror("Wrote to 240000 %02x at %04x %04x (Trap %02x)\n",offset,cpu_get_pc(space->cpu),data,slyspy_state);
 }
 
 WRITE16_HANDLER( slyspy_242000_w )
 {
 	switch (slyspy_state) {
 		case 0x2: /* Trap A */
-			dec0_pf1_data_w(offset,data,mem_mask);
+			dec0_pf1_data_w(space,offset,data,mem_mask);
 			return;
 		case 0x0: /* Trap C */
 			if (offset<0x40) COMBINE_DATA(&dec0_pf2_colscroll[offset]);
 			else if (offset<0x300) COMBINE_DATA(&dec0_pf2_rowscroll[offset-0x200]);
 			return;
 	}
-	logerror("Wrote to 242000 %02x at %04x %04x (Trap %02x)\n",offset,activecpu_get_pc(),data,slyspy_state);
+	logerror("Wrote to 242000 %02x at %04x %04x (Trap %02x)\n",offset,cpu_get_pc(space->cpu),data,slyspy_state);
 }
 
 WRITE16_HANDLER( slyspy_246000_w )
 {
 	switch (slyspy_state) {
 		case 0x0:
-			dec0_pf2_data_w(offset,data,mem_mask);
+			dec0_pf2_data_w(space,offset,data,mem_mask);
 			return;
 	}
-	logerror("Wrote to 246000 %02x at %04x %04x (Trap %02x)\n",offset,activecpu_get_pc(),data,slyspy_state);
+	logerror("Wrote to 246000 %02x at %04x %04x (Trap %02x)\n",offset,cpu_get_pc(space->cpu),data,slyspy_state);
 }
 
 WRITE16_HANDLER( slyspy_248000_w )
 {
 	switch (slyspy_state) {
 		case 0x1:
-			dec0_pf1_data_w(offset,data,mem_mask);
+			dec0_pf1_data_w(space,offset,data,mem_mask);
 			return;
 		case 0x3:
-			dec0_pf2_data_w(offset,data,mem_mask);
+			dec0_pf2_data_w(space,offset,data,mem_mask);
 			return;
 		case 0x0:
-			if (offset<0x8) dec0_pf1_control_0_w(offset,data,mem_mask);
-			else if (offset<0x10) dec0_pf1_control_1_w(offset-0x8,data,mem_mask);
+			if (offset<0x8) dec0_pf1_control_0_w(space,offset,data,mem_mask);
+			else if (offset<0x10) dec0_pf1_control_1_w(space,offset-0x8,data,mem_mask);
 			return;
 	}
-	logerror("Wrote to 248000 %02x at %04x %04x (Trap %02x)\n",offset,activecpu_get_pc(),data,slyspy_state);
+	logerror("Wrote to 248000 %02x at %04x %04x (Trap %02x)\n",offset,cpu_get_pc(space->cpu),data,slyspy_state);
 }
 
 WRITE16_HANDLER( slyspy_24c000_w )
 {
 	switch (slyspy_state) {
 		case 0x1: /* Trap 9 */
-			dec0_pf2_data_w(offset,data,mem_mask);
+			dec0_pf2_data_w(space,offset,data,mem_mask);
 			return;
 		case 0x0: /* Trap C */
 			if (offset<0x40) COMBINE_DATA(&dec0_pf1_colscroll[offset]);
 			else if (offset<0x300) COMBINE_DATA(&dec0_pf1_rowscroll[offset-0x200]);
 			return;
 	}
-	logerror("Wrote to 24c000 %02x at %04x %04x (Trap %02x)\n",offset,activecpu_get_pc(),data,slyspy_state);
+	logerror("Wrote to 24c000 %02x at %04x %04x (Trap %02x)\n",offset,cpu_get_pc(space->cpu),data,slyspy_state);
 }
 
 WRITE16_HANDLER( slyspy_24e000_w )
@@ -241,10 +240,10 @@ WRITE16_HANDLER( slyspy_24e000_w )
 	switch (slyspy_state) {
 		case 0x2:
 		case 0x0:
-			dec0_pf1_data_w(offset,data,mem_mask);
+			dec0_pf1_data_w(space,offset,data,mem_mask);
 			return;
 	}
-	logerror("Wrote to 24e000 %02x at %04x %04x (Trap %02x)\n",offset,activecpu_get_pc(),data,slyspy_state);
+	logerror("Wrote to 24e000 %02x at %04x %04x (Trap %02x)\n",offset,cpu_get_pc(space->cpu),data,slyspy_state);
 }
 
 /******************************************************************************/
@@ -281,7 +280,7 @@ WRITE8_HANDLER( hippodrm_shared_w )
 
 static READ16_HANDLER( hippodrm_68000_share_r )
 {
-	if (offset==0) cpu_yield(); /* A wee helper */
+	if (offset==0) cpu_yield(space->cpu); /* A wee helper */
 	return share[offset]&0xff;
 }
 
@@ -332,7 +331,7 @@ static void hbarrel_i8751_write(int data)
 			break;
 		case 0x06:	/* Controls appearance & placement of special weapons */
 			i8751_return=weapons_table[level][data&0x1f];
-			//logerror("CPU #0 PC %06x: warning - write %02x to i8751, returning %04x\n",activecpu_get_pc(),data,i8751_return);
+			//logerror("%s: warning - write %02x to i8751, returning %04x\n",cpuexec_describe_context(machine),data,i8751_return);
 			break;
 		case 0xb:	/* Initialise the variables? */
 			i8751_return=0;
@@ -359,10 +358,10 @@ static void hbarrel_i8751_write(int data)
 		/* We have to use a state as the microcontroller remembers previous commands */
 	}
 
-//logerror("CPU #0 PC %06x: warning - write %02x to i8751\n",activecpu_get_pc(),data);
+//logerror("%s: warning - write %02x to i8751\n",cpuexec_describe_context(machine),data);
 }
 
-static void baddudes_i8751_write(int data)
+static void baddudes_i8751_write(running_machine *machine, int data)
 {
 	i8751_return=0;
 
@@ -385,10 +384,10 @@ static void baddudes_i8751_write(int data)
 		case 0x75b: i8751_return=0x70f; break;
 	}
 
-	if (!i8751_return) logerror("%04x: warning - write unknown command %02x to 8571\n",activecpu_get_pc(),data);
+	if (!i8751_return) logerror("%s: warning - write unknown command %02x to 8571\n",cpuexec_describe_context(machine),data);
 }
 
-static void birdtry_i8751_write(int data)
+static void birdtry_i8751_write(running_machine *machine, int data)
 {
 	static int 	pwr,
 				hgt;
@@ -454,7 +453,7 @@ static void birdtry_i8751_write(int data)
 		/*These are activated after a shot (???)*/
 		case 0x6ca: i8751_return = 0xff;      break;
 		case 0x7ff: i8751_return = 0x200;     break;
-		default: logerror("%04x: warning - write unknown command %02x to 8571\n",activecpu_get_pc(),data);
+		default: logerror("%s: warning - write unknown command %02x to 8571\n",cpuexec_describe_context(machine),data);
 	}
 }
 
@@ -464,27 +463,27 @@ static emu_timer *i8751_timer;
 static TIMER_CALLBACK( i8751_callback )
 {
 	/* Signal main cpu microcontroller task is complete */
-	cpunum_set_input_line(machine, 0,5,HOLD_LINE);
+	cpu_set_input_line(machine->cpu[0],5,HOLD_LINE);
 	i8751_timer=NULL;
 
 	logerror("i8751:  Timer called!!!\n");
 }
 #endif
 
-void dec0_i8751_write(int data)
+void dec0_i8751_write(running_machine *machine, int data)
 {
 	/* Writes to this address cause an IRQ to the i8751 microcontroller */
 	if (GAME==1) hbarrel_i8751_write(data);
-	if (GAME==2) baddudes_i8751_write(data);
-	if (GAME==3) birdtry_i8751_write(data);
+	if (GAME==2) baddudes_i8751_write(machine, data);
+	if (GAME==3) birdtry_i8751_write(machine, data);
 
-	cpunum_set_input_line(Machine, 0,5,HOLD_LINE);
+	cpu_set_input_line(machine->cpu[0],5,HOLD_LINE);
 
 	/* Simulate the processing time of the i8751, time value is guessed
     if (i8751_timer)
         logerror("i8751:  Missed a timer!!!\n");
     else
-        i8751_timer = timer_call_after_resynch(NULL, 0, i8751_callback);*/
+        i8751_timer = timer_call_after_resynch(machine, NULL, 0, i8751_callback);*/
 
 /* There is a timing problem in Heavy Barrel if the processing time is not
 simulated - if the interrupt is triggered straight away then HB will reset
@@ -495,7 +494,7 @@ See the code about 0xb60 (USA version)
 
 */
 
-logerror("CPU #0 PC %06x: warning - write %02x to i8751\n",activecpu_get_pc(),data);
+logerror("%s: warning - write %02x to i8751\n",cpuexec_describe_context(machine),data);
 
 }
 
@@ -515,27 +514,27 @@ static WRITE16_HANDLER( sprite_mirror_w )
 
 static READ16_HANDLER( robocop_68000_share_r )
 {
-//logerror("%08x: Share read %04x\n",activecpu_get_pc(),offset);
+//logerror("%08x: Share read %04x\n",cpu_get_pc(space->cpu),offset);
 
 	return robocop_shared_ram[offset];
 }
 
 static WRITE16_HANDLER( robocop_68000_share_w )
 {
-//  logerror("%08x: Share write %04x %04x\n",activecpu_get_pc(),offset,data);
+//  logerror("%08x: Share write %04x %04x\n",cpu_get_pc(space->cpu),offset,data);
 
 	robocop_shared_ram[offset]=data&0xff;
 
 	if (offset==0x7ff) /* A control address - not standard ram */
-		cpunum_set_input_line(Machine, 2,0,HOLD_LINE);
+		cpu_set_input_line(space->machine->cpu[2],0,HOLD_LINE);
 }
 
 /******************************************************************************/
 
-static void h6280_decrypt(int memory_area)
+static void h6280_decrypt(running_machine *machine, const char *cputag)
 {
 	int i;
-	UINT8 *RAM = memory_region(memory_area);
+	UINT8 *RAM = memory_region(machine, cputag);
 
 	/* Read each byte, decrypt it */
 	for (i=0x00000; i<0x10000; i++)
@@ -544,13 +543,12 @@ static void h6280_decrypt(int memory_area)
 
 DRIVER_INIT( hippodrm )
 {
-	UINT8 *RAM = memory_region(REGION_CPU3);
+	UINT8 *RAM = memory_region(machine, "sub");
 
-	memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0x180000, 0x180fff, 0, 0, hippodrm_68000_share_r);
-	memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0x180000, 0x180fff, 0, 0, hippodrm_68000_share_w);
-	memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0xffc800, 0xffcfff, 0, 0, sprite_mirror_w);
+	memory_install_readwrite16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x180000, 0x180fff, 0, 0, hippodrm_68000_share_r, hippodrm_68000_share_w);
+	memory_install_write16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xffc800, 0xffcfff, 0, 0, sprite_mirror_w);
 
-	h6280_decrypt(REGION_CPU3);
+	h6280_decrypt(machine, "sub");
 
 	/* The protection cpu has additional memory mapped protection! */
 	RAM[0x189]=0x60; /* RTS prot area */
@@ -561,9 +559,9 @@ DRIVER_INIT( hippodrm )
 
 DRIVER_INIT( slyspy )
 {
-	UINT8 *RAM = memory_region(REGION_CPU2);
+	UINT8 *RAM = memory_region(machine, "audio");
 
-	h6280_decrypt(REGION_CPU2);
+	h6280_decrypt(machine, "audio");
 
 	/* Slyspy sound cpu has some protection */
 	RAM[0xf2d]=0xea;
@@ -572,8 +570,7 @@ DRIVER_INIT( slyspy )
 
 DRIVER_INIT( robocop )
 {
-	memory_install_read16_handler(0, ADDRESS_SPACE_PROGRAM, 0x180000, 0x180fff, 0, 0, robocop_68000_share_r);
-	memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0x180000, 0x180fff, 0, 0, robocop_68000_share_w);
+	memory_install_readwrite16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x180000, 0x180fff, 0, 0, robocop_68000_share_r, robocop_68000_share_w);
 }
 
 DRIVER_INIT( baddudes )
@@ -585,7 +582,7 @@ DRIVER_INIT( hbarrel )
 {
 	GAME=1;
 { /* Remove this patch once processing time of i8751 is simulated */
-UINT16 *rom = (UINT16 *)memory_region(REGION_CPU1);
+UINT16 *rom = (UINT16 *)memory_region(machine, "main");
 rom[0xb68/2] = 0x8008;
 }
 }
@@ -594,7 +591,7 @@ DRIVER_INIT( hbarrelw )
 {
 	GAME=1;
 { /* Remove this patch once processing time of i8751 is simulated */
-UINT16 *rom = (UINT16 *)memory_region(REGION_CPU1);
+UINT16 *rom = (UINT16 *)memory_region(machine, "main");
 rom[0xb3e/2] = 0x8008;
 }
 }
@@ -606,7 +603,7 @@ DRIVER_INIT( birdtry )
 
 	GAME=3;
 
-	src = memory_region(REGION_GFX4);
+	src = memory_region(machine, "gfx4");
 
 	/* some parts of the graphic have bytes swapped */
 	for (k = 0;k < 0x70000;k += 0x20000)
