@@ -6,7 +6,6 @@
 
 #include "driver.h"
 #include "profiler.h"
-#include "deprecat.h"
 #include "cpu/m6809/m6809.h"
 #include "irobot.h"
 
@@ -25,9 +24,9 @@
 #define IR_TIMING 				1		/* try to emulate MB and VG running time */
 #define DISASSEMBLE_MB_ROM		0		/* generate a disassembly of the mathbox ROMs */
 
-#define IR_CPU_STATE \
+#define IR_CPU_STATE(m) \
 	logerror(\
-			"pc: %4x, scanline: %d\n", activecpu_get_previouspc(), video_screen_get_vpos(0))
+			"%s, scanline: %d\n", cpuexec_describe_context(m), video_screen_get_vpos((m)->primary_screen))
 
 
 UINT8 irobot_vg_clear;
@@ -51,7 +50,7 @@ UINT8 *irobot_combase;
 UINT8 irobot_bufsel;
 UINT8 irobot_alphamap;
 
-static void irmb_run(void);
+static void irmb_run(running_machine *machine);
 
 
 /***********************************************************************/
@@ -94,13 +93,13 @@ static TIMER_CALLBACK( irvg_done_callback )
 WRITE8_HANDLER( irobot_statwr_w )
 {
 	logerror("write %2x ", data);
-	IR_CPU_STATE;
+	IR_CPU_STATE(space->machine);
 
 	irobot_combase = comRAM[data >> 7];
 	irobot_combase_mb = comRAM[(data >> 7) ^ 1];
 	irobot_bufsel = data & 0x02;
 	if (((data & 0x01) == 0x01) && (irobot_vg_clear == 0))
-		irobot_poly_clear();
+		irobot_poly_clear(space->machine);
 
 	irobot_vg_clear = data & 0x01;
 
@@ -112,31 +111,31 @@ WRITE8_HANDLER( irobot_statwr_w )
 			logerror("vg start ");
 		else
 			logerror("vg start [busy!] ");
-		IR_CPU_STATE;
-		timer_adjust(irvg_timer, ATTOTIME_IN_MSEC(10), 0, attotime_zero);
+		IR_CPU_STATE(space->machine);
+		timer_adjust_oneshot(irvg_timer, ATTOTIME_IN_MSEC(10), 0);
 #endif
 		irvg_running=1;
 	}
 	if ((data & 0x10) && !(irobot_statwr & 0x10))
-		irmb_run();
+		irmb_run(space->machine);
 	irobot_statwr = data;
 }
 
 WRITE8_HANDLER( irobot_out0_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
+	UINT8 *RAM = memory_region(space->machine, "main");
 
 	irobot_out0 = data;
 	switch (data & 0x60)
 	{
 		case 0:
-			memory_set_bankptr(2, &RAM[0x1C000]);
+			memory_set_bankptr(space->machine, 2, &RAM[0x1C000]);
 			break;
 		case 0x20:
-			memory_set_bankptr(2, &RAM[0x1C800]);
+			memory_set_bankptr(space->machine, 2, &RAM[0x1C800]);
 			break;
 		case 0x40:
-			memory_set_bankptr(2, &RAM[0x1D000]);
+			memory_set_bankptr(space->machine, 2, &RAM[0x1D000]);
 			break;
 	}
 	irobot_outx = (data & 0x18) >> 3;
@@ -146,27 +145,27 @@ WRITE8_HANDLER( irobot_out0_w )
 
 WRITE8_HANDLER( irobot_rom_banksel_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
+	UINT8 *RAM = memory_region(space->machine, "main");
 
 	switch ((data & 0x0E) >> 1)
 	{
 		case 0:
-			memory_set_bankptr(1, &RAM[0x10000]);
+			memory_set_bankptr(space->machine, 1, &RAM[0x10000]);
 			break;
 		case 1:
-			memory_set_bankptr(1, &RAM[0x12000]);
+			memory_set_bankptr(space->machine, 1, &RAM[0x12000]);
 			break;
 		case 2:
-			memory_set_bankptr(1, &RAM[0x14000]);
+			memory_set_bankptr(space->machine, 1, &RAM[0x14000]);
 			break;
 		case 3:
-			memory_set_bankptr(1, &RAM[0x16000]);
+			memory_set_bankptr(space->machine, 1, &RAM[0x16000]);
 			break;
 		case 4:
-			memory_set_bankptr(1, &RAM[0x18000]);
+			memory_set_bankptr(space->machine, 1, &RAM[0x18000]);
 			break;
 		case 5:
-			memory_set_bankptr(1, &RAM[0x1A000]);
+			memory_set_bankptr(space->machine, 1, &RAM[0x1A000]);
 			break;
 	}
 	set_led_status(0,data & 0x10);
@@ -181,18 +180,18 @@ static TIMER_CALLBACK( scanline_callback )
     if (scanline == 224) irvg_vblank=1;
     logerror("SCANLINE CALLBACK %d\n",scanline);
     /* set the IRQ line state based on the 32V line state */
-    cpunum_set_input_line(machine, 0, M6809_IRQ_LINE, (scanline & 32) ? ASSERT_LINE : CLEAR_LINE);
+    cpu_set_input_line(machine->cpu[0], M6809_IRQ_LINE, (scanline & 32) ? ASSERT_LINE : CLEAR_LINE);
 
     /* set a callback for the next 32-scanline increment */
     scanline += 32;
     if (scanline >= 256) scanline = 0;
-    timer_set(video_screen_get_time_until_pos(0, scanline, 0), NULL, scanline, scanline_callback);
+    timer_set(machine, video_screen_get_time_until_pos(machine->primary_screen, scanline, 0), NULL, scanline, scanline_callback);
 }
 
 static TIMER_CALLBACK( irmb_done_callback );
 MACHINE_RESET( irobot )
 {
-	UINT8 *MB = memory_region(REGION_CPU2);
+	UINT8 *MB = memory_region(machine, "mathbox");
 
 	/* initialize the memory regions */
 	mbROM 		= MB + 0x00000;
@@ -202,15 +201,15 @@ MACHINE_RESET( irobot )
 
 	irvg_vblank=0;
 	irvg_running = 0;
-	irvg_timer = timer_alloc(irvg_done_callback, NULL);
+	irvg_timer = timer_alloc(machine, irvg_done_callback, NULL);
 	irmb_running = 0;
-	irmb_timer = timer_alloc(irmb_done_callback, NULL);
+	irmb_timer = timer_alloc(machine, irmb_done_callback, NULL);
 
 	/* set an initial timer to go off on scanline 0 */
-	timer_set(video_screen_get_time_until_pos(0, 0, 0), NULL, 0, scanline_callback);
+	timer_set(machine, video_screen_get_time_until_pos(machine->primary_screen, 0, 0), NULL, 0, scanline_callback);
 
-	irobot_rom_banksel_w(0,0);
-	irobot_out0_w(0,0);
+	irobot_rom_banksel_w(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM),0,0);
+	irobot_out0_w(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM),0,0);
 	irobot_combase = comRAM[0];
 	irobot_combase_mb = comRAM[1];
 	irobot_outx = 0;
@@ -226,9 +225,9 @@ READ8_HANDLER( irobot_control_r )
 {
 
 	if (irobot_control_num == 0)
-		return readinputport (5);
+		return input_port_read(space->machine, "AN0");
 	else if (irobot_control_num == 1)
-		return readinputport (6);
+		return input_port_read(space->machine, "AN1");
 	return 0;
 
 }
@@ -240,7 +239,7 @@ READ8_HANDLER( irobot_status_r )
 	int d=0;
 
 	logerror("status read. ");
-	IR_CPU_STATE;
+	IR_CPU_STATE(space->machine);
 
 	if (!irmb_running) d |= 0x20;
 	if (irvg_running) d |= 0x40;
@@ -370,9 +369,9 @@ static void irmb_dout(const irmb_ops *curop, UINT32 d)
 
 
 /* Convert microcode roms to a more usable form */
-static void load_oproms(void)
+static void load_oproms(running_machine *machine)
 {
-	UINT8 *MB = memory_region(REGION_PROMS) + 0x20;
+	UINT8 *MB = memory_region(machine, "proms") + 0x20;
 	int i;
 
 	/* allocate RAM */
@@ -451,14 +450,14 @@ DRIVER_INIT( irobot )
 		irmb_regs[i] = 0;
 	}
 	irmb_latch=0;
-	load_oproms();
+	load_oproms(machine);
 }
 
 static TIMER_CALLBACK( irmb_done_callback )
 {
     logerror("mb done. ");
 	irmb_running = 0;
-	cpunum_set_input_line(machine, 0, M6809_FIRQ_LINE, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[0], M6809_FIRQ_LINE, ASSERT_LINE);
 }
 
 
@@ -575,7 +574,7 @@ static TIMER_CALLBACK( irmb_done_callback )
 
 
 /* Run mathbox */
-static void irmb_run(void)
+static void irmb_run(running_machine *machine)
 {
 	const irmb_ops *prevop = &mbops[0];
 	const irmb_ops *curop = &mbops[0];
@@ -851,18 +850,18 @@ default:	case 0x3f:	IXOR(irmb_din(curop), 0);							break;
 #if IR_TIMING
 	if (irmb_running == 0)
 	{
-		timer_adjust(irmb_timer, attotime_mul(ATTOTIME_IN_HZ(12000000), icount), 0, attotime_zero);
+		timer_adjust_oneshot(irmb_timer, attotime_mul(ATTOTIME_IN_HZ(12000000), icount), 0);
 		logerror("mb start ");
-		IR_CPU_STATE;
+		IR_CPU_STATE(machine);
 	}
 	else
 	{
 		logerror("mb start [busy!] ");
-		IR_CPU_STATE;
-		timer_adjust(irmb_timer, attotime_mul(ATTOTIME_IN_NSEC(200), icount), 0, attotime_zero);
+		IR_CPU_STATE(machine);
+		timer_adjust_oneshot(irmb_timer, attotime_mul(ATTOTIME_IN_NSEC(200), icount), 0);
 	}
 #else
-	cpunum_set_input_line(Machine, 0, M6809_FIRQ_LINE, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[0], M6809_FIRQ_LINE, ASSERT_LINE);
 #endif
 	irmb_running=1;
 }
