@@ -7,7 +7,6 @@
  */
 
 #include "driver.h"
-#include "deprecat.h"
 #include "video/konamiic.h"
 #include "machine/konamigx.h"
 
@@ -146,22 +145,22 @@ READ8_HANDLER( tms57002_data_r )
 
 READ16_HANDLER( tms57002_data_word_r )
 {
-	return(tms57002_data_r(0));
+	return(tms57002_data_r(space,0));
 }
 
 READ16_HANDLER( tms57002_status_word_r )
 {
-	return(tms57002_status_r(0));
+	return(tms57002_status_r(space,0));
 }
 
 WRITE16_HANDLER( tms57002_control_word_w )
 {
-	tms57002_control_w(0, data);
+	tms57002_control_w(space, 0, data);
 }
 
 WRITE16_HANDLER( tms57002_data_word_w )
 {
-	tms57002_data_w(0, data);
+	tms57002_data_w(space, 0, data);
 }
 
 
@@ -208,7 +207,8 @@ void K053936GP_set_cliprect(int chip, int minx, int maxx, int miny, int maxy)
 	cliprect->max_y = maxy;
 }
 
-INLINE void K053936GP_copyroz32clip( mame_bitmap *dst_bitmap, mame_bitmap *src_bitmap,
+INLINE void K053936GP_copyroz32clip( running_machine *machine,
+		bitmap_t *dst_bitmap, bitmap_t *src_bitmap,
 		const rectangle *dst_cliprect, const rectangle *src_cliprect,
 		UINT32 _startx,UINT32 _starty,int _incxx,int _incxy,int _incyx,int _incyy,
 		int tilebpp, int blend, int clip )
@@ -257,7 +257,7 @@ INLINE void K053936GP_copyroz32clip( mame_bitmap *dst_bitmap, mame_bitmap *src_b
 	ecx = tx = -tx;
 
 	tilebpp = (tilebpp-1) & 7;
-	pal_base = Machine->remapped_colortable;
+	pal_base = machine->pens;
 	cmask = colormask[tilebpp];
 
 	src_pitch = src_bitmap->rowpixels;
@@ -358,11 +358,12 @@ INLINE void K053936GP_copyroz32clip( mame_bitmap *dst_bitmap, mame_bitmap *src_b
 }
 
 // adpoted from generic K053936_zoom_draw()
-static void K053936GP_zoom_draw(int chip, UINT16 *ctrl, UINT16 *linectrl,
-		mame_bitmap *bitmap, const rectangle *cliprect, tilemap *tmap,
+static void K053936GP_zoom_draw(running_machine *machine,
+		int chip, UINT16 *ctrl, UINT16 *linectrl,
+		bitmap_t *bitmap, const rectangle *cliprect, tilemap *tmap,
 		int tilebpp, int blend)
 {
-	mame_bitmap *src_bitmap;
+	bitmap_t *src_bitmap;
 	rectangle *src_cliprect;
 	UINT16 *lineaddr;
 
@@ -397,7 +398,8 @@ static void K053936GP_zoom_draw(int chip, UINT16 *ctrl, UINT16 *linectrl,
 			startx -= K053936_offset[chip][0] * incxx;
 			starty -= K053936_offset[chip][0] * incxy;
 
-			K053936GP_copyroz32clip(bitmap, src_bitmap, &my_clip, src_cliprect,
+			K053936GP_copyroz32clip(machine,
+					bitmap, src_bitmap, &my_clip, src_cliprect,
 					startx<<5, starty<<5, incxx<<5, incxy<<5, 0, 0,
 					tilebpp, blend, clip);
 			y++;
@@ -421,22 +423,23 @@ static void K053936GP_zoom_draw(int chip, UINT16 *ctrl, UINT16 *linectrl,
 		startx -= K053936_offset[chip][0] * incxx;
 		starty -= K053936_offset[chip][0] * incxy;
 
-		K053936GP_copyroz32clip(bitmap, src_bitmap, cliprect, src_cliprect,
+		K053936GP_copyroz32clip(machine,
+				bitmap, src_bitmap, cliprect, src_cliprect,
 				startx<<5, starty<<5, incxx<<5, incxy<<5, incyx<<5, incyy<<5,
 				tilebpp, blend, clip);
 	}
 }
 
-void K053936GP_0_zoom_draw(mame_bitmap *bitmap, const rectangle *cliprect,
+void K053936GP_0_zoom_draw(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect,
 		tilemap *tmap, int tilebpp, int blend)
 {
-	K053936GP_zoom_draw(0,K053936_0_ctrl,K053936_0_linectrl,bitmap,cliprect,tmap,tilebpp,blend);
+	K053936GP_zoom_draw(machine, 0,K053936_0_ctrl,K053936_0_linectrl,bitmap,cliprect,tmap,tilebpp,blend);
 }
 
-void K053936GP_1_zoom_draw(mame_bitmap *bitmap, const rectangle *cliprect,
+void K053936GP_1_zoom_draw(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect,
 		tilemap *tmap, int tilebpp, int blend)
 {
-	K053936GP_zoom_draw(1,K053936_1_ctrl,K053936_1_linectrl,bitmap,cliprect,tmap,tilebpp,blend);
+	K053936GP_zoom_draw(machine, 1,K053936_1_ctrl,K053936_1_linectrl,bitmap,cliprect,tmap,tilebpp,blend);
 }
 
 
@@ -457,7 +460,8 @@ void K053936GP_1_zoom_draw(mame_bitmap *bitmap, const rectangle *cliprect,
     pri     : 0 = topmost, 255 = backmost (pixel priority)
 */
 
-INLINE void zdrawgfxzoom32GP( mame_bitmap *bitmap, const gfx_element *gfx, const rectangle *cliprect,
+INLINE void zdrawgfxzoom32GP( running_machine *machine,
+		bitmap_t *bitmap, const gfx_element *gfx, const rectangle *cliprect,
 		UINT32 code, UINT32 color, int flipx, int flipy, int sx, int sy,
 		int scalex, int scaley, int alpha, int drawmode, int zcode, int pri)
 {
@@ -522,8 +526,8 @@ INLINE void zdrawgfxzoom32GP( mame_bitmap *bitmap, const gfx_element *gfx, const
 	src_fh    = 16;
 	src_base  = gfx->gfxdata + (code % gfx->total_elements) * gfx->char_modulo;
 
-	pal_base  = Machine->remapped_colortable + gfx->color_base + (color % gfx->total_colors) * granularity;
-	shd_base  = Machine->shadow_table;
+	pal_base  = machine->pens + gfx->color_base + (color % gfx->total_colors) * granularity;
+	shd_base  = machine->shadow_table;
 
 	dst_ptr   = bitmap->base;
 	dst_pitch = bitmap->rowpixels;
@@ -536,7 +540,8 @@ INLINE void zdrawgfxzoom32GP( mame_bitmap *bitmap, const gfx_element *gfx, const
 
 	// cull off-screen objects
 	if (dst_x > dst_maxx || dst_y > dst_maxy) return;
-	if ((nozoom = (scalex == 0x10000 && scaley == 0x10000)))
+	nozoom = (scalex == 0x10000 && scaley == 0x10000);
+	if (nozoom)
 	{
 		dst_h = dst_w = 16;
 		src_fdy = src_fdx = 1;
@@ -1119,17 +1124,16 @@ int K055555GX_decode_osmixcolor(int layer, int *color) // (see p.63, p.49-50 and
 	return(emx);
 }
 
-static void gx_wipezbuf(int noshadow)
+static void gx_wipezbuf(running_machine *machine, int noshadow)
 {
-	UINT8  *zptr;
-	int w, h;
-	register int ecx;
+	const rectangle *visarea = video_screen_get_visible_area(machine->primary_screen);
 
-	w = Machine->screen[0].visarea.max_x - Machine->screen[0].visarea.min_x + 1;
-	h = Machine->screen[0].visarea.max_y - Machine->screen[0].visarea.min_y + 1;
+	int w = visarea->max_x - visarea->min_x + 1;
+	int h = visarea->max_y - visarea->min_y + 1;
+
+	UINT8 *zptr = gx_objzbuf;
+	int ecx = h;
 
-	zptr = gx_objzbuf;
-	ecx = h;
 	do { memset(zptr, -1, w); zptr += GX_ZBUFW; } while (--ecx);
 
 	if (!noshadow)
@@ -1192,7 +1196,7 @@ void K053247GP_set_SpriteOffset(int offsx, int offsy)
 	K053247_dy = offsy;
 }
 
-void konamigx_mixer_init(int objdma)
+void konamigx_mixer_init(running_machine *machine, int objdma)
 {
 	gx_objdma = 0;
 	gx_primode = 0;
@@ -1212,7 +1216,7 @@ void konamigx_mixer_init(int objdma)
 	else
 		gx_spriteram = K053247_ram;
 
-	palette_set_shadow_dRGB32(Machine, 3,-80,-80,-80, 0);
+	palette_set_shadow_dRGB32(machine, 3,-80,-80,-80, 0);
 	K054338_invert_alpha(1);
 }
 
@@ -1226,7 +1230,7 @@ void konamigx_objdma(void)
 	if (gx_objdma && gx_spriteram && K053247_ram) memcpy(gx_spriteram, K053247_ram, 0x1000);
 }
 
-void konamigx_mixer(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect,
+void konamigx_mixer(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect,
 					tilemap *sub1, int sub1flags,
 					tilemap *sub2, int sub2flags,
 					int mixerflags)
@@ -1247,14 +1251,16 @@ void konamigx_mixer(running_machine *machine, mame_bitmap *bitmap, const rectang
 
 
 	// abort if object database failed to initialize
-	if (!(objpool = gx_objpool)) return;
+	objpool = gx_objpool;
+	if (!objpool) return;
 
 	// clear screen with backcolor and update flicker pulse
 	K054338_fill_backcolor(machine, bitmap, konamigx_wrport1_0 & 0x20);
 	parity ^= 1;
 
 	// abort if video has been disabled
-	if (!(disp = K055555_read_register(K55_INPUT_ENABLES))) return;
+	disp = K055555_read_register(K55_INPUT_ENABLES);
+	if (!disp) return;
 	cltc_shdpri = K054338_read_register(K338_REG_CONTROL);
 	if (!(cltc_shdpri & K338_CTL_KILL)) return;
 
@@ -1265,7 +1271,7 @@ void konamigx_mixer(running_machine *machine, mame_bitmap *bitmap, const rectang
 	if (mixerflags & GXMIX_NOZBUF)
 		mixerflags |= GXMIX_NOSHADOW;
 	else
-		gx_wipezbuf(mixerflags & GXMIX_NOSHADOW);
+		gx_wipezbuf(machine, mixerflags & GXMIX_NOSHADOW);
 
 	// cache global parameters
 	konamigx_precache_registers();
@@ -1438,7 +1444,8 @@ void konamigx_mixer(running_machine *machine, mame_bitmap *bitmap, const rectang
 		}
 		else
 		{
-			if ((shadow = k>>10 & 3)) // object has shadow?
+			shadow = k>>10 & 3;
+			if (shadow) // object has shadow?
 			{
 				if (shadow != 1 || K053246_objset1 & 0x20)
 				{
@@ -1551,7 +1558,7 @@ void konamigx_mixer(running_machine *machine, mame_bitmap *bitmap, const rectang
 	}
 
 	// traverse draw list
-	screenwidth = Machine->screen[0].width;
+	screenwidth = video_screen_get_width(machine->primary_screen);
 
 	for (count=0; count<nobj; count++)
 	{
@@ -1628,7 +1635,7 @@ void konamigx_mixer(running_machine *machine, mame_bitmap *bitmap, const rectang
 					l = sub1flags & 0xf;
 
 					if (offs == -2)
-						K053936GP_0_zoom_draw(bitmap, cliprect, sub1, l, k);
+						K053936GP_0_zoom_draw(machine, bitmap, cliprect, sub1, l, k);
 					else
 						K053250_draw(machine, bitmap, cliprect, 0, vcblk[4]<<l, 0, 0);
 				}
@@ -1657,7 +1664,7 @@ void konamigx_mixer(running_machine *machine, mame_bitmap *bitmap, const rectang
 					l = sub2flags & 0xf;
 
 					if (offs == -3)
-						K053936GP_1_zoom_draw(bitmap, cliprect, sub2, l, k);
+						K053936GP_1_zoom_draw(machine, bitmap, cliprect, sub2, l, k);
 					else
 						K053250_draw(machine, bitmap, cliprect, 1, vcblk[5]<<l, 0, 0);
 				}
@@ -1671,12 +1678,13 @@ void konamigx_mixer(running_machine *machine, mame_bitmap *bitmap, const rectang
 		alpha = 255;
 		if (drawmode & 2)
 		{
-			if ((alpha = color>>K055555_MIXSHIFT & 3)) alpha = K054338_set_alpha_level(alpha);
+			alpha = color>>K055555_MIXSHIFT & 3;
+			if (alpha) alpha = K054338_set_alpha_level(alpha);
 			if (alpha <= 0) continue;
 		}
 		color &= K055555_COLORMASK;
 
-		if (drawmode >= 4) palette_set_shadow_mode(Machine, order & 0x0f);
+		if (drawmode >= 4) palette_set_shadow_mode(machine, order & 0x0f);
 
 		if (!(mixerflags & GXMIX_NOZBUF))
 		{
@@ -1807,7 +1815,8 @@ void konamigx_mixer(running_machine *machine, mame_bitmap *bitmap, const rectang
 
 				if (nozoom) { scaley = scalex = 0x10000; } else { scalex = zw << 12; scaley = zh << 12; };
 
-				zdrawgfxzoom32GP(bitmap, K053247_gfx, cliprect,
+				zdrawgfxzoom32GP(machine,
+						bitmap, K053247_gfx, cliprect,
 						temp,
 						color,
 						temp1,temp2,
@@ -1842,7 +1851,7 @@ WRITE16_HANDLER( K055550_word_w )
 
 	COMBINE_DATA(prot_data+offset);
 
-	if (offset == 0 && ACCESSING_MSB)
+	if (offset == 0 && ACCESSING_BITS_8_15)
 	{
 		data >>= 8;
 		switch (data)
@@ -1855,7 +1864,7 @@ WRITE16_HANDLER( K055550_word_w )
 
 				lim = adr+bsize*count;
 				for(i=adr; i<lim; i+=2)
-					program_write_word(i, prot_data[0x1a/2]);
+					memory_write_word(space, i, prot_data[0x1a/2]);
 			break;
 
 			// WARNING: The following cases are speculation based with questionable accuracy!(AAT)
@@ -1886,41 +1895,41 @@ WRITE16_HANDLER( K055550_word_w )
 				// let's hope GCC will inline the mem24bew calls
 				for (src=adr; src<srcend; src+=bsize)
 				{
-					cx1 = (short)program_read_word(src);
-					sx1 = (short)program_read_word(src + 2);
-					wx1 = (short)program_read_word(src + 4);
+					cx1 = (short)memory_read_word(space, src);
+					sx1 = (short)memory_read_word(space, src + 2);
+					wx1 = (short)memory_read_word(space, src + 4);
 
-					cy1 = (short)program_read_word(src + 6);
-					sy1 = (short)program_read_word(src + 8);
-					wy1 = (short)program_read_word(src +10);
+					cy1 = (short)memory_read_word(space, src + 6);
+					sy1 = (short)memory_read_word(space, src + 8);
+					wy1 = (short)memory_read_word(space, src +10);
 
-					cz1 = (short)program_read_word(src +12);
-					sz1 = (short)program_read_word(src +14);
-					wz1 = (short)program_read_word(src +16);
+					cz1 = (short)memory_read_word(space, src +12);
+					sz1 = (short)memory_read_word(space, src +14);
+					wz1 = (short)memory_read_word(space, src +16);
 
 					count = i = src + skip;
 					tgt = src + bsize;
 
-					for (; count<tgt; count++) program_write_byte(count, 0);
+					for (; count<tgt; count++) memory_write_byte(space, count, 0);
 
 					for (; tgt<tgtend; i++, tgt+=bsize)
 					{
-						c2 = (short)program_read_word(tgt);
-						s2 = (short)program_read_word(tgt + 2);
-						w2 = (short)program_read_word(tgt + 4);
+						c2 = (short)memory_read_word(space, tgt);
+						s2 = (short)memory_read_word(space, tgt + 2);
+						w2 = (short)memory_read_word(space, tgt + 4);
 						if (abs((cx1+sx1)-(c2+s2))>=wx1+w2) continue; // X rejection
 
-						c2 = (short)program_read_word(tgt + 6);
-						s2 = (short)program_read_word(tgt + 8);
-						w2 = (short)program_read_word(tgt +10);
+						c2 = (short)memory_read_word(space, tgt + 6);
+						s2 = (short)memory_read_word(space, tgt + 8);
+						w2 = (short)memory_read_word(space, tgt +10);
 						if (abs((cy1+sy1)-(c2+s2))>=wy1+w2) continue; // Y rejection
 
-						c2 = (short)program_read_word(tgt +12);
-						s2 = (short)program_read_word(tgt +14);
-						w2 = (short)program_read_word(tgt +16);
+						c2 = (short)memory_read_word(space, tgt +12);
+						s2 = (short)memory_read_word(space, tgt +14);
+						w2 = (short)memory_read_word(space, tgt +16);
 						if (abs((cz1+sz1)-(c2+s2))>=wz1+w2) continue; // Z rejection
 
-						program_write_byte(i, 0x80); // collision confirmed
+						memory_write_byte(space, i, 0x80); // collision confirmed
 					}
 				}
 			break;
@@ -1947,13 +1956,13 @@ WRITE16_HANDLER( K055550_word_w )
 				else
 					if (dy < 0) i = 0x80;
 				else
-					i = mame_rand(Machine) & 0xff; // vector direction indeterminate
+					i = mame_rand(space->machine) & 0xff; // vector direction indeterminate
 
 				prot_data[0x10] = i;
 			break;
 
 			default:
-//              logerror("%06x: unknown K055550 command %02x\n", activecpu_get_pc(), data);
+//              logerror("%06x: unknown K055550 command %02x\n", cpu_get_pc(space->cpu), data);
 			break;
 		}
 	}
@@ -1969,7 +1978,7 @@ WRITE16_HANDLER( K053990_martchmp_word_w )
 
 	COMBINE_DATA(prot_data+offset);
 
-	if (offset == 0x0c && ACCESSING_MSB)
+	if (offset == 0x0c && ACCESSING_BITS_8_15)
 	{
 		mode  = (prot_data[0x0d]<<8 & 0xff00) | (prot_data[0x0f] & 0xff);
 
@@ -1994,13 +2003,13 @@ WRITE16_HANDLER( K053990_martchmp_word_w )
 				if (element_size == 1)
 				for (i=src_count; i; i--)
 				{
-					program_write_byte(dst_addr, program_read_byte(src_addr));
+					memory_write_byte(space, dst_addr, memory_read_byte(space, src_addr));
 					src_addr += src_skip;
 					dst_addr += dst_skip;
 				}
 				else for (i=src_count; i; i--)
 				{
-					program_write_word(dst_addr, program_read_word(src_addr));
+					memory_write_word(space, dst_addr, memory_read_word(space, src_addr));
 					src_addr += src_skip;
 					dst_addr += dst_skip;
 				}
@@ -2025,15 +2034,15 @@ WRITE16_HANDLER( K053990_martchmp_word_w )
 
 				for (i=mod_count; i; i--)
 				{
-					mod_val  = program_read_word(mod_addr);
+					mod_val  = memory_read_word(space, mod_addr);
 					mod_addr += mod_skip;
 
-					mod_data = program_read_word(src_addr);
+					mod_data = memory_read_word(space, src_addr);
 					src_addr += src_skip;
 
 					mod_data += mod_val;
 
-					program_write_word(dst_addr, mod_data);
+					memory_write_word(space, dst_addr, mod_data);
 					dst_addr += dst_skip;
 				}
 			break;
@@ -2220,7 +2229,9 @@ if((data1=obj[0])&0x80000000)\
 		srcend = src + count * 0x30;
 		do
 		{
-			if (!src[0] || !(i = src[7] & 0xf)) continue; // reject retired or zero-element groups
+			if (!src[0]) continue;
+			i = src[7] & 0xf;
+			if (!i) continue; // reject retired or zero-element groups
 			i <<= 2;
 			hoffs = src[5]>>16;
 			voffs = src[6]>>16;
