@@ -9,4 +9,4 @@ WRITE8_HANDLER( mb_go_w );
 READ8_HANDLER( mb_status_r );
 READ8_HANDLER( mb_lo_r );
 READ8_HANDLER( mb_hi_r );
-void mb_register_states(void);
+void mb_register_states(running_machine *machine);
