@@ -62,7 +62,7 @@ static UINT8 m6840_irq_vector;
 static UINT8 v493_irq_state;
 static UINT8 v493_irq_vector;
 
-static timer_callback v493_callback;
+static timer_fired_func v493_callback;
 
 static UINT8 zwackery_sound_data;
 
@@ -72,14 +72,13 @@ static attotime m6840_internal_counter_period;	/* 68000 CLK / 10 */
 static emu_timer *ipu_watchdog_timer;
 
 
-
 /*************************************
  *
  *  Function prototypes
  *
  *************************************/
 
-static void subtract_from_counter(int counter, int count);
+static void subtract_from_counter(running_machine *machine, int counter, int count);
 
 static TIMER_CALLBACK( mcr68_493_callback );
 static TIMER_CALLBACK( zwackery_493_callback );
@@ -87,12 +86,12 @@ static TIMER_CALLBACK( zwackery_493_callback );
 static WRITE8_HANDLER( zwackery_pia_2_w );
 static WRITE8_HANDLER( zwackery_pia_3_w );
 static WRITE8_HANDLER( zwackery_ca2_w );
-static void zwackery_pia_irq(int state);
+static void zwackery_pia_irq(running_machine *machine, int state);
 
 static void reload_count(int counter);
 static TIMER_CALLBACK( counter_fired_callback );
 static TIMER_CALLBACK( ipu_watchdog_reset );
-static WRITE8_HANDLER( ipu_break_changed );
+static WRITE8_DEVICE_HANDLER( ipu_break_changed );
 
 
 
@@ -141,7 +140,7 @@ READ8_HANDLER( zwackery_port_2_r );
 
 static READ8_HANDLER( zwackery_port_1_r )
 {
-	UINT8 ret = readinputport(1);
+	UINT8 ret = input_port_read(space->machine, "IN1");
 
 	pia_set_port_a_z_mask(3, ret);
 
@@ -151,7 +150,7 @@ static READ8_HANDLER( zwackery_port_1_r )
 
 static READ8_HANDLER( zwackery_port_3_r )
 {
-	UINT8 ret = readinputport(3);
+	UINT8 ret = input_port_read(space->machine, "IN3");
 
 	pia_set_port_a_z_mask(4, ret);
 
@@ -188,49 +187,47 @@ static const pia6821_interface zwackery_pia_4_intf =
  *
  *************************************/
 
-static void ctc_interrupt(int state)
+static void ctc_interrupt(const device_config *device, int state)
 {
-	cpunum_set_input_line(Machine, 0, 0, state);
+	cputag_set_input_line(device->machine, "main", 0, state);
 }
 
 
-static void ipu_ctc_interrupt(int state)
+static void ipu_ctc_interrupt(const device_config *device, int state)
 {
-	cpunum_set_input_line(Machine, 3, 0, state);
+	cputag_set_input_line(device->machine, "ipu", 0, state);
 }
 
 
-const struct z80_irq_daisy_chain mcr_daisy_chain[] =
+const z80_daisy_chain mcr_daisy_chain[] =
 {
-	{ z80ctc_reset, z80ctc_irq_state, z80ctc_irq_ack, z80ctc_irq_reti, 0 }, /* CTC number 0 */
-	{ 0, 0, 0, 0, -1 }		/* end mark */
+	{ Z80CTC, "ctc" },
+	{ NULL }
 };
 
 
-const struct z80_irq_daisy_chain mcr_ipu_daisy_chain[] =
+const z80_daisy_chain mcr_ipu_daisy_chain[] =
 {
-	{ z80ctc_reset, z80ctc_irq_state, z80ctc_irq_ack, z80ctc_irq_reti, 1 }, /* CTC number 1 */
-	{ z80pio_reset, z80pio_irq_state, z80pio_irq_ack, z80pio_irq_reti, 1 }, /* PIO number 1 */
-	{ z80sio_reset, z80sio_irq_state, z80sio_irq_ack, z80sio_irq_reti, 0 }, /* SIO number 0 */
-	{ z80pio_reset, z80pio_irq_state, z80pio_irq_ack, z80pio_irq_reti, 0 }, /* PIO number 0 */
-	{ 0, 0, 0, 0, -1 }		/* end mark */
+	{ Z80CTC, "ipu_ctc" },
+	{ Z80PIO, "ipu_pio1" },
+	{ Z80SIO, "ipu_sio" },
+	{ Z80PIO, "ipu_pio0" },
+	{ NULL }
 };
 
 
-static z80ctc_interface ctc_intf =
+const z80ctc_interface mcr_ctc_intf =
 {
-	0,              	/* clock (filled in from the CPU 0 clock) */
 	0,              	/* timer disables */
 	ctc_interrupt,  	/* interrupt handler */
-	z80ctc_0_trg1_w,	/* ZC/TO0 callback */
+	z80ctc_trg1_w,		/* ZC/TO0 callback */
 	0,              	/* ZC/TO1 callback */
 	0               	/* ZC/TO2 callback */
 };
 
 
-static z80ctc_interface nflfoot_ctc_intf =
+const z80ctc_interface nflfoot_ctc_intf =
 {
-	0,                  /* clock (filled in from the CPU 3 clock) */
 	0,                  /* timer disables */
 	ipu_ctc_interrupt,  /* interrupt handler */
 	0,					/* ZC/TO0 callback */
@@ -239,17 +236,20 @@ static z80ctc_interface nflfoot_ctc_intf =
 };
 
 
-static const z80pio_interface nflfoot_pio_intf =
+const z80pio_interface nflfoot_pio_intf =
 {
 	ipu_ctc_interrupt,
-	0,
-	0
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL
 };
 
 
-static z80sio_interface nflfoot_sio_intf =
+const z80sio_interface nflfoot_sio_intf =
 {
-	0,                  /* clock (filled in from the CPU 3 clock) */
 	ipu_ctc_interrupt,	/* interrupt handler */
 	0,					/* DTR changed handler */
 	0,					/* RTS changed handler */
@@ -267,31 +267,14 @@ static z80sio_interface nflfoot_sio_intf =
 
 MACHINE_START( mcr )
 {
-	/* initialize the CTC */
-	ctc_intf.baseclock = cpunum_get_clock(0);
-	z80ctc_init(0, &ctc_intf);
-
-	state_save_register_global(mcr_cocktail_flip);
+	state_save_register_global(machine, mcr_cocktail_flip);
 }
 
 
 MACHINE_START( nflfoot )
 {
-	/* initialize the CTC */
-	ctc_intf.baseclock = cpunum_get_clock(0);
-	z80ctc_init(0, &ctc_intf);
-
-	nflfoot_ctc_intf.baseclock = cpunum_get_clock(3);
-	z80ctc_init(1, &nflfoot_ctc_intf);
-
-	z80pio_init(0, &nflfoot_pio_intf);
-	z80pio_init(1, &nflfoot_pio_intf);
-
-	nflfoot_sio_intf.baseclock = cpunum_get_clock(3);
-	z80sio_init(0, &nflfoot_sio_intf);
-
 	/* allocate a timer for the IPU watchdog */
-	ipu_watchdog_timer = timer_alloc(ipu_watchdog_reset, NULL);
+	ipu_watchdog_timer = timer_alloc(machine, ipu_watchdog_reset, NULL);
 }
 
 
@@ -301,7 +284,7 @@ MACHINE_RESET( mcr )
 	mcr_cocktail_flip = 0;
 
 	/* initialize the sound */
-	mcr_sound_reset();
+	mcr_sound_reset(machine);
 }
 
 
@@ -320,27 +303,27 @@ MACHINE_START( mcr68 )
 	{
 		struct counter_state *m6840 = &m6840_state[i];
 
-		m6840->timer = timer_alloc(counter_fired_callback, NULL);
+		m6840->timer = timer_alloc(machine, counter_fired_callback, NULL);
 
-		state_save_register_item("m6840", i, m6840->control);
-		state_save_register_item("m6840", i, m6840->latch);
-		state_save_register_item("m6840", i, m6840->count);
-		state_save_register_item("m6840", i, m6840->timer_active);
+		state_save_register_item(machine, "m6840", NULL, i, m6840->control);
+		state_save_register_item(machine, "m6840", NULL, i, m6840->latch);
+		state_save_register_item(machine, "m6840", NULL, i, m6840->count);
+		state_save_register_item(machine, "m6840", NULL, i, m6840->timer_active);
 	}
 
-	state_save_register_global(m6840_status);
-	state_save_register_global(m6840_status_read_since_int);
-	state_save_register_global(m6840_msb_buffer);
-	state_save_register_global(m6840_lsb_buffer);
-	state_save_register_global(m6840_irq_state);
-	state_save_register_global(v493_irq_state);
-	state_save_register_global(zwackery_sound_data);
+	state_save_register_global(machine, m6840_status);
+	state_save_register_global(machine, m6840_status_read_since_int);
+	state_save_register_global(machine, m6840_msb_buffer);
+	state_save_register_global(machine, m6840_lsb_buffer);
+	state_save_register_global(machine, m6840_irq_state);
+	state_save_register_global(machine, v493_irq_state);
+	state_save_register_global(machine, zwackery_sound_data);
 
-	state_save_register_global(mcr_cocktail_flip);
+	state_save_register_global(machine, mcr_cocktail_flip);
 }
 
 
-static void mcr68_common_init(void)
+static void mcr68_common_init(running_machine *machine)
 {
 	int i;
 
@@ -365,20 +348,20 @@ static void mcr68_common_init(void)
 	}
 
 	/* initialize the clock */
-	m6840_internal_counter_period = ATTOTIME_IN_HZ(cpunum_get_clock(0) / 10);
+	m6840_internal_counter_period = ATTOTIME_IN_HZ(cpu_get_clock(machine->cpu[0]) / 10);
 
 	/* reset cocktail flip */
 	mcr_cocktail_flip = 0;
 
 	/* initialize the sound */
-	mcr_sound_reset();
+	mcr_sound_reset(machine);
 }
 
 
 MACHINE_RESET( mcr68 )
 {
 	/* for the most part all MCR/68k games are the same */
-	mcr68_common_init();
+	mcr68_common_init(machine);
 	v493_callback = mcr68_493_callback;
 
 	/* vectors are 1 and 2 */
@@ -390,9 +373,9 @@ MACHINE_RESET( mcr68 )
 MACHINE_START( zwackery )
 {
 	/* append our PIA state onto the existing one and reinit */
-	pia_config(2, &zwackery_pia_2_intf);
-	pia_config(3, &zwackery_pia_3_intf);
-	pia_config(4, &zwackery_pia_4_intf);
+	pia_config(machine, 2, &zwackery_pia_2_intf);
+	pia_config(machine, 3, &zwackery_pia_3_intf);
+	pia_config(machine, 4, &zwackery_pia_4_intf);
 
 	MACHINE_START_CALL(mcr68);
 }
@@ -401,7 +384,7 @@ MACHINE_START( zwackery )
 MACHINE_RESET( zwackery )
 {
 	/* for the most part all MCR/68k games are the same */
-	mcr68_common_init();
+	mcr68_common_init(machine);
 	v493_callback = zwackery_493_callback;
 
 	/* append our PIA state onto the existing one and reinit */
@@ -422,29 +405,33 @@ MACHINE_RESET( zwackery )
 
 INTERRUPT_GEN( mcr_interrupt )
 {
+	const device_config *ctc = devtag_get_device(device->machine, Z80CTC, "ctc");
+
 	/* CTC line 2 is connected to VBLANK, which is once every 1/2 frame */
 	/* for the 30Hz interlaced display */
-	z80ctc_0_trg2_w(0, 1);
-	z80ctc_0_trg2_w(0, 0);
+	z80ctc_trg2_w(ctc, 0, 1);
+	z80ctc_trg2_w(ctc, 0, 0);
 
 	/* CTC line 3 is connected to 493, which is signalled once every */
 	/* frame at 30Hz */
-	if (cpu_getiloops() == 0)
+	if (cpu_getiloops(device) == 0)
 	{
-		z80ctc_0_trg3_w(0, 1);
-		z80ctc_0_trg3_w(0, 0);
+		z80ctc_trg3_w(ctc, 0, 1);
+		z80ctc_trg3_w(ctc, 0, 0);
 	}
 }
 
 
 INTERRUPT_GEN( mcr_ipu_interrupt )
 {
+	const device_config *ctc = devtag_get_device(device->machine, Z80CTC, "ipu_ctc");
+
 	/* CTC line 3 is connected to 493, which is signalled once every */
 	/* frame at 30Hz */
-	if (cpu_getiloops() == 0)
+	if (cpu_getiloops(device) == 0)
 	{
-		z80ctc_1_trg3_w(0, 1);
-		z80ctc_1_trg3_w(0, 0);
+		z80ctc_trg3_w(ctc, 0, 1);
+		z80ctc_trg3_w(ctc, 0, 0);
 	}
 }
 
@@ -453,14 +440,14 @@ INTERRUPT_GEN( mcr68_interrupt )
 {
 	/* update the 6840 VBLANK clock */
 	if (!m6840_state[0].timer_active)
-		subtract_from_counter(0, 1);
+		subtract_from_counter(device->machine, 0, 1);
 
 	logerror("--- VBLANK ---\n");
 
 	/* also set a timer to generate the 493 signal at a specific time before the next VBLANK */
 	/* the timing of this is crucial for Blasted and Tri-Sports, which check the timing of */
 	/* VBLANK and 493 using counter 2 */
-	timer_set(attotime_sub(ATTOTIME_IN_HZ(30), mcr68_timing_factor), NULL, 0, v493_callback);
+	timer_set(device->machine, attotime_sub(ATTOTIME_IN_HZ(30), mcr68_timing_factor), NULL, 0, v493_callback);
 }
 
 
@@ -471,36 +458,25 @@ INTERRUPT_GEN( mcr68_interrupt )
  *
  *************************************/
 
-static void update_mcr68_interrupts(void)
+static void update_mcr68_interrupts(running_machine *machine)
 {
-	int newstate = 0;
-
-	/* all interrupts go through an LS148, which gives priority to the highest */
-	if (v493_irq_state)
-		newstate = v493_irq_vector;
-	if (m6840_irq_state)
-		newstate = m6840_irq_vector;
-
-	/* set the new state of the IRQ lines */
-	if (newstate)
-		cpunum_set_input_line(Machine, 0, newstate, ASSERT_LINE);
-	else
-		cpunum_set_input_line(Machine, 0, 7, CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], v493_irq_vector, v493_irq_state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], m6840_irq_vector, m6840_irq_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
 static TIMER_CALLBACK( mcr68_493_off_callback )
 {
 	v493_irq_state = 0;
-	update_mcr68_interrupts();
+	update_mcr68_interrupts(machine);
 }
 
 
 static TIMER_CALLBACK( mcr68_493_callback )
 {
 	v493_irq_state = 1;
-	update_mcr68_interrupts();
-	timer_set(video_screen_get_scan_period(0), NULL, 0, mcr68_493_off_callback);
+	update_mcr68_interrupts(machine);
+	timer_set(machine, video_screen_get_scan_period(machine->primary_screen), NULL, 0, mcr68_493_off_callback);
 	logerror("--- (INT1) ---\n");
 }
 
@@ -585,7 +561,7 @@ WRITE8_HANDLER( mcr_scroll_value_w )
 WRITE8_HANDLER( zwackery_pia_2_w )
 {
 	/* bit 7 is the watchdog */
-	if (!(data & 0x80)) watchdog_reset_w(offset, data);
+	if (!(data & 0x80)) watchdog_reset_w(space, offset, data);
 
 	/* bits 5 and 6 control hflip/vflip */
 	/* bits 3 and 4 control coin counters? */
@@ -601,27 +577,30 @@ WRITE8_HANDLER( zwackery_pia_3_w )
 
 WRITE8_HANDLER( zwackery_ca2_w )
 {
-	csdeluxe_data_w(offset, (data << 4) | zwackery_sound_data);
+	csdeluxe_data_w(space, offset, (data << 4) | zwackery_sound_data);
 }
 
 
-static void zwackery_pia_irq(int state)
+static void zwackery_pia_irq(running_machine *machine, int state)
 {
 	v493_irq_state = pia_get_irq_a(2) | pia_get_irq_b(2);
-	update_mcr68_interrupts();
+	update_mcr68_interrupts(machine);
 }
 
 
 static TIMER_CALLBACK( zwackery_493_off_callback )
 {
-	pia_2_ca1_w(0, 0);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	pia_2_ca1_w(space, 0, 0);
 }
 
 
 static TIMER_CALLBACK( zwackery_493_callback )
 {
-	pia_2_ca1_w(0, 1);
-	timer_set(video_screen_get_scan_period(0), NULL, 0, zwackery_493_off_callback);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	pia_2_ca1_w(space, 0, 1);
+	timer_set(machine, video_screen_get_scan_period(machine->primary_screen), NULL, 0, zwackery_493_off_callback);
 }
 
 
@@ -632,7 +611,7 @@ static TIMER_CALLBACK( zwackery_493_callback )
  *
  *************************************/
 
-INLINE void update_interrupts(void)
+INLINE void update_interrupts(running_machine *machine)
 {
 	m6840_status &= ~0x80;
 
@@ -641,11 +620,11 @@ INLINE void update_interrupts(void)
 	if ((m6840_status & 0x04) && (m6840_state[2].control & 0x40)) m6840_status |= 0x80;
 
 	m6840_irq_state = m6840_status >> 7;
-	update_mcr68_interrupts();
+	update_mcr68_interrupts(machine);
 }
 
 
-static void subtract_from_counter(int counter, int count)
+static void subtract_from_counter(running_machine *machine, int counter, int count)
 {
 	/* dual-byte mode */
 	if (m6840_state[counter].control & 0x04)
@@ -668,7 +647,7 @@ static void subtract_from_counter(int counter, int count)
 			{
 				m6840_status |= 1 << counter;
 				m6840_status_read_since_int &= ~(1 << counter);
-				update_interrupts();
+				update_interrupts(machine);
 				msb = (m6840_state[counter].latch >> 8) + 1;
 				LOG(("** Counter %d fired\n", counter));
 			}
@@ -695,7 +674,7 @@ static void subtract_from_counter(int counter, int count)
 			/* we've expired */
 			m6840_status |= 1 << counter;
 			m6840_status_read_since_int &= ~(1 << counter);
-			update_interrupts();
+			update_interrupts(machine);
 			LOG(("** Counter %d fired\n", counter));
 		}
 
@@ -714,7 +693,7 @@ static TIMER_CALLBACK( counter_fired_callback )
 	m6840_state[counter].timer_active = 0;
 
 	/* subtract it all from the counter; this will generate an interrupt */
-	subtract_from_counter(counter, count);
+	subtract_from_counter(machine, counter, count);
 }
 
 
@@ -730,7 +709,7 @@ static void reload_count(int counter)
 	/* counter 0 is self-updating if clocked externally */
 	if (counter == 0 && !(m6840_state[counter].control & 0x02))
 	{
-		timer_adjust(m6840_state[counter].timer, attotime_never, 0, attotime_zero);
+		timer_adjust_oneshot(m6840_state[counter].timer, attotime_never, 0);
 		m6840_state[counter].timer_active = 0;
 		return;
 	}
@@ -751,7 +730,7 @@ static void reload_count(int counter)
 	/* set the timer */
 	total_period = attotime_make(0, attotime_to_attoseconds(period) * count);
 LOG(("reload_count(%d): period = %f  count = %d\n", counter, attotime_to_double(period), count));
-	timer_adjust(m6840_state[counter].timer, total_period, (count << 2) + counter, attotime_zero);
+	timer_adjust_oneshot(m6840_state[counter].timer, total_period, (count << 2) + counter);
 	m6840_state[counter].timer_active = 1;
 }
 
@@ -814,7 +793,7 @@ static WRITE8_HANDLER( mcr68_6840_w_common )
 			{
 				for (i = 0; i < 3; i++)
 				{
-					timer_adjust(m6840_state[i].timer, attotime_never, 0, attotime_zero);
+					timer_adjust_oneshot(m6840_state[i].timer, attotime_never, 0);
 					m6840_state[i].timer_active = 0;
 				}
 			}
@@ -827,20 +806,20 @@ static WRITE8_HANDLER( mcr68_6840_w_common )
 			}
 
 			m6840_status = 0;
-			update_interrupts();
+			update_interrupts(space->machine);
 		}
 
 		/* changing the clock source? (needed for Zwackery) */
 		if (diffs & 0x02)
 			reload_count(counter);
 
-		LOG(("%06X:Counter %d control = %02X\n", activecpu_get_previouspc(), counter, data));
+		LOG(("%06X:Counter %d control = %02X\n", cpu_get_previouspc(space->cpu), counter, data));
 	}
 
 	/* offsets 2, 4, and 6 are MSB buffer registers */
 	else if ((offset & 1) == 0)
 	{
-		LOG(("%06X:MSB = %02X\n", activecpu_get_previouspc(), data));
+		LOG(("%06X:MSB = %02X\n", cpu_get_previouspc(space->cpu), data));
 		m6840_msb_buffer = data;
 	}
 
@@ -852,13 +831,13 @@ static WRITE8_HANDLER( mcr68_6840_w_common )
 
 		/* clear the interrupt */
 		m6840_status &= ~(1 << counter);
-		update_interrupts();
+		update_interrupts(space->machine);
 
 		/* reload the count if in an appropriate mode */
 		if (!(m6840_state[counter].control & 0x10))
 			reload_count(counter);
 
-		LOG(("%06X:Counter %d latch = %04X\n", activecpu_get_previouspc(), counter, m6840_state[counter].latch));
+		LOG(("%06X:Counter %d latch = %04X\n", cpu_get_previouspc(space->cpu), counter, m6840_state[counter].latch));
 	}
 }
 
@@ -872,7 +851,7 @@ static READ16_HANDLER( mcr68_6840_r_common )
 	/* offset 1 is the status register */
 	else if (offset == 1)
 	{
-		LOG(("%06X:Status read = %04X\n", activecpu_get_previouspc(), m6840_status));
+		LOG(("%06X:Status read = %04X\n", cpu_get_previouspc(space->cpu), m6840_status));
 		m6840_status_read_since_int |= m6840_status & 0x07;
 		return m6840_status;
 	}
@@ -886,11 +865,11 @@ static READ16_HANDLER( mcr68_6840_r_common )
 		/* clear the interrupt if the status has been read */
 		if (m6840_status_read_since_int & (1 << counter))
 			m6840_status &= ~(1 << counter);
-		update_interrupts();
+		update_interrupts(space->machine);
 
 		m6840_lsb_buffer = result & 0xff;
 
-		LOG(("%06X:Counter %d read = %04X\n", activecpu_get_previouspc(), counter, result));
+		LOG(("%06X:Counter %d read = %04X\n", cpu_get_previouspc(space->cpu), counter, result));
 		return result >> 8;
 	}
 
@@ -902,27 +881,27 @@ static READ16_HANDLER( mcr68_6840_r_common )
 
 WRITE16_HANDLER( mcr68_6840_upper_w )
 {
-	if (ACCESSING_MSB)
-		mcr68_6840_w_common(offset, (data >> 8) & 0xff);
+	if (ACCESSING_BITS_8_15)
+		mcr68_6840_w_common(space, offset, (data >> 8) & 0xff);
 }
 
 
 WRITE16_HANDLER( mcr68_6840_lower_w )
 {
-	if (ACCESSING_LSB)
-		mcr68_6840_w_common(offset, data & 0xff);
+	if (ACCESSING_BITS_0_7)
+		mcr68_6840_w_common(space, offset, data & 0xff);
 }
 
 
 READ16_HANDLER( mcr68_6840_upper_r )
 {
-	return (mcr68_6840_r_common(offset,0) << 8) | 0x00ff;
+	return (mcr68_6840_r_common(space,offset,0) << 8) | 0x00ff;
 }
 
 
 READ16_HANDLER( mcr68_6840_lower_r )
 {
-	return mcr68_6840_r_common(offset,0) | 0xff00;
+	return mcr68_6840_r_common(space,offset,0) | 0xff00;
 }
 
 
@@ -933,60 +912,30 @@ READ16_HANDLER( mcr68_6840_lower_r )
  *
  *************************************/
 
-static WRITE8_HANDLER( ipu_break_changed )
+static WRITE8_DEVICE_HANDLER( ipu_break_changed )
 {
 	/* channel B is connected to the CED player */
 	if (offset == 1)
 	{
 		logerror("DTR changed -> %d\n", data);
 		if (data == 1)
-			z80sio_receive_data(0, 1, 0);
+			z80sio_receive_data(device, 1, 0);
 	}
 }
 
 
-READ8_HANDLER( mcr_ipu_pio_0_r )
+READ8_DEVICE_HANDLER( mcr_ipu_sio_r )
 {
-	return (offset & 2) ? z80pio_c_r(0, offset & 1) : z80pio_d_r(0, offset & 1);
+	return (offset & 2) ? z80sio_c_r(device, offset & 1) : z80sio_d_r(device, offset & 1);
 }
 
 
-READ8_HANDLER( mcr_ipu_pio_1_r )
-{
-	return (offset & 2) ? z80pio_c_r(1, offset & 1) : z80pio_d_r(1, offset & 1);
-}
-
-
-READ8_HANDLER( mcr_ipu_sio_r )
-{
-	return (offset & 2) ? z80sio_c_r(0, offset & 1) : z80sio_d_r(0, offset & 1);
-}
-
-
-WRITE8_HANDLER( mcr_ipu_pio_0_w )
+WRITE8_DEVICE_HANDLER( mcr_ipu_sio_w )
 {
 	if (offset & 2)
-		z80pio_c_w(0, offset & 1, data);
+		z80sio_c_w(device, offset & 1, data);
 	else
-		z80pio_d_w(0, offset & 1, data);
-}
-
-
-WRITE8_HANDLER( mcr_ipu_pio_1_w )
-{
-	if (offset & 2)
-		z80pio_c_w(1, offset & 1, data);
-	else
-		z80pio_d_w(1, offset & 1, data);
-}
-
-
-WRITE8_HANDLER( mcr_ipu_sio_w )
-{
-	if (offset & 2)
-		z80sio_c_w(0, offset & 1, data);
-	else
-		z80sio_d_w(0, offset & 1, data);
+		z80sio_d_w(device, offset & 1, data);
 }
 
 
@@ -997,18 +946,18 @@ WRITE8_HANDLER( mcr_ipu_laserdisk_w )
 	/* bit 1 enables (1) LD left channel audio */
 	/* bit 0 enables (1) LD video if PIX SW == 1 */
 	if (data != 0)
-		logerror("%04X:mcr_ipu_laserdisk_w(%d) = %02X\n", activecpu_get_pc(), offset, data);
+		logerror("%04X:mcr_ipu_laserdisk_w(%d) = %02X\n", cpu_get_pc(space->cpu), offset, data);
 }
 
 
 static TIMER_CALLBACK( ipu_watchdog_reset )
 {
 	logerror("ipu_watchdog_reset\n");
-	cpunum_set_input_line(machine, 3, INPUT_LINE_RESET, PULSE_LINE);
-	z80ctc_reset(1);
-	z80pio_reset(0);
-	z80pio_reset(1);
-	z80sio_reset(0);
+	cputag_set_input_line(machine, "ipu", INPUT_LINE_RESET, PULSE_LINE);
+	devtag_reset(machine, Z80CTC, "ipu_ctc");
+	devtag_reset(machine, Z80PIO, "ipu_pio0");
+	devtag_reset(machine, Z80PIO, "ipu_pio1");
+	devtag_reset(machine, Z80SIO, "ipu_sio");
 }
 
 
@@ -1016,12 +965,12 @@ READ8_HANDLER( mcr_ipu_watchdog_r )
 {
 	/* watchdog counter is clocked by 7.3728MHz crystal / 16 */
 	/* watchdog is tripped when 14-bit counter overflows => / 32768 = 14.0625Hz*/
-	timer_adjust(ipu_watchdog_timer, ATTOTIME_IN_HZ(7372800 / 16 / 32768), 0, attotime_zero);
+	timer_adjust_oneshot(ipu_watchdog_timer, ATTOTIME_IN_HZ(7372800 / 16 / 32768), 0);
 	return 0xff;
 }
 
 
 WRITE8_HANDLER( mcr_ipu_watchdog_w )
 {
-	mcr_ipu_watchdog_r(0);
+	mcr_ipu_watchdog_r(space,0);
 }
