@@ -133,7 +133,6 @@ TODO:
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "machine/namcoio.h"
 #include "machine/namco50.h"
 #include "sound/namco52.h"
@@ -146,8 +145,8 @@ TODO:
 struct namcoio
 {
 	INT32 type;
-	read8_handler in[4];
-	write8_handler out[2];
+	read8_space_func in[4];
+	write8_space_func out[2];
 	INT32 reset;
 	INT32 lastcoins,lastbuttons;
 	INT32 credits;
@@ -165,8 +164,8 @@ static emu_timer *nmi_timer[MAX_06XX];
 static READ8_HANDLER( nop_r ) { return 0x0f; }
 static WRITE8_HANDLER( nop_w ) { }
 
-#define READ_PORT(n)	(io[chip].in[n](0) & 0x0f)
-#define WRITE_PORT(n,d)	io[chip].out[n](0,(d) & 0x0f)
+#define READ_PORT(m,n)	(io[chip].in[n](m,0) & 0x0f)
+#define WRITE_PORT(m,n,d)	io[chip].out[n](m,0,(d) & 0x0f)
 
 
 
@@ -184,11 +183,11 @@ commands:
 07: nop
 */
 
-static void namcoio_51XX_write(int chip,int data)
+static void namcoio_51XX_write(running_machine *machine,int chip,int data)
 {
 	data &= 0x07;
 
-	LOG(("%04x: custom 51XX write %02x\n",activecpu_get_pc(),data));
+	LOG(("%s: custom 51XX write %02x\n",cpuexec_describe_context(machine),data));
 
 	if (io[chip].coincred_mode)
 	{
@@ -218,9 +217,9 @@ static void namcoio_51XX_write(int chip,int data)
 					static int namcoio_51XX_kludge = 0;
 
 					/* Only compute namcoio_51XX_kludge when gamedrv changes */
-					if (namcoio_51XX_driver != Machine->gamedrv)
+					if (namcoio_51XX_driver != machine->gamedrv)
 					{
-						namcoio_51XX_driver = Machine->gamedrv;
+						namcoio_51XX_driver = machine->gamedrv;
 						if (strcmp(namcoio_51XX_driver->name, "xevious") == 0 ||
 							strcmp(namcoio_51XX_driver->parent, "xevious") == 0)
 							namcoio_51XX_kludge = 1;
@@ -282,17 +281,19 @@ static const int joy_map[16] =
 {	 0xf, 0xe, 0xd, 0x5, 0xc, 0x9, 0x7, 0x6, 0xb, 0x3, 0xa, 0x4, 0x1, 0x2, 0x0, 0x8 };
 
 
-static UINT8 namcoio_51XX_read(int chip)
+static UINT8 namcoio_51XX_read(running_machine *machine, int chip)
 {
-	LOG(("%04x: custom 51XX read\n",activecpu_get_pc()));
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	LOG(("%s: custom 51XX read\n",cpuexec_describe_context(machine)));
 
 	if (io[chip].mode == 0)	/* switch mode */
 	{
 		switch ((io[chip].in_count++) % 3)
 		{
 			default:
-			case 0: return READ_PORT(0) | (READ_PORT(1) << 4);
-			case 1: return READ_PORT(2) | (READ_PORT(3) << 4);
+			case 0: return READ_PORT(space,0) | (READ_PORT(space,1) << 4);
+			case 1: return READ_PORT(space,2) | (READ_PORT(space,3) << 4);
 			case 2: return 0;	// nothing?
 		}
 	}
@@ -305,7 +306,7 @@ static UINT8 namcoio_51XX_read(int chip)
 				{
 					int in,toggle;
 
-					in = ~(READ_PORT(0) | (READ_PORT(1) << 4));
+					in = ~(READ_PORT(space,0) | (READ_PORT(space,1) << 4));
 					toggle = in ^ io[chip].lastcoins;
 					io[chip].lastcoins = in;
 
@@ -313,17 +314,17 @@ static UINT8 namcoio_51XX_read(int chip)
 					{
 						if (io[chip].credits >= 99)
 						{
-							WRITE_PORT(1,1);	// coin lockout
+							WRITE_PORT(space,1,1);	// coin lockout
 						}
 						else
 						{
-							WRITE_PORT(1,0);	// coin lockout
+							WRITE_PORT(space,1,0);	// coin lockout
 							/* check if the user inserted a coin */
 							if (toggle & in & 0x10)
 							{
 								io[chip].coins[0]++;
-								WRITE_PORT(0,0x04);	// coin counter
-								WRITE_PORT(0,0x0c);
+								WRITE_PORT(space,0,0x04);	// coin counter
+								WRITE_PORT(space,0,0x0c);
 								if (io[chip].coins[0] >= io[chip].coins_per_cred[0])
 								{
 									io[chip].credits += io[chip].creds_per_coin[0];
@@ -333,8 +334,8 @@ static UINT8 namcoio_51XX_read(int chip)
 							if (toggle & in & 0x20)
 							{
 								io[chip].coins[1]++;
-								WRITE_PORT(0,0x08);	// coin counter
-								WRITE_PORT(0,0x0c);
+								WRITE_PORT(space,0,0x08);	// coin counter
+								WRITE_PORT(space,0,0x0c);
 								if (io[chip].coins[1] >= io[chip].coins_per_cred[1])
 								{
 									io[chip].credits += io[chip].creds_per_coin[1];
@@ -351,14 +352,14 @@ static UINT8 namcoio_51XX_read(int chip)
 
 					if (io[chip].mode == 1)
 					{
-						int on = (cpu_getcurrentframe() & 0x10) >> 4;
+						int on = (video_screen_get_frame_number(machine->primary_screen) & 0x10) >> 4;
 
 						if (io[chip].credits >= 2)
-							WRITE_PORT(0,0x0c | 3*on);	// lamps
+							WRITE_PORT(space,0,0x0c | 3*on);	// lamps
 						else if (io[chip].credits >= 1)
-							WRITE_PORT(0,0x0c | 2*on);	// lamps
+							WRITE_PORT(space,0,0x0c | 2*on);	// lamps
 						else
-							WRITE_PORT(0,0x0c);	// lamps off
+							WRITE_PORT(space,0,0x0c);	// lamps off
 
 						/* check for 1 player start button */
 						if (toggle & in & 0x04)
@@ -367,7 +368,7 @@ static UINT8 namcoio_51XX_read(int chip)
 							{
 								io[chip].credits--;
 								io[chip].mode = 2;
-								WRITE_PORT(0,0x0c);	// lamps off
+								WRITE_PORT(space,0,0x0c);	// lamps off
 							}
 						}
 						/* check for 2 players start button */
@@ -377,23 +378,23 @@ static UINT8 namcoio_51XX_read(int chip)
 							{
 								io[chip].credits -= 2;
 								io[chip].mode = 2;
-								WRITE_PORT(0,0x0c);	// lamps off
+								WRITE_PORT(space, 0,0x0c);	// lamps off
 							}
 						}
 					}
 				}
 
-				if (~readinputport(0) & 0x80)	/* check test mode switch */
+				if (~input_port_read(machine, "IN0") & 0x80)	/* check test mode switch */
 					return 0xbb;
 
 				return (io[chip].credits / 10) * 16 + io[chip].credits % 10;
 
 			case 1:
 				{
-					int joy = READ_PORT(2) & 0x0f;
+					int joy = READ_PORT(space,2) & 0x0f;
 					int in,toggle;
 
-					in = ~READ_PORT(0);
+					in = ~READ_PORT(space,0);
 					toggle = in ^ io[chip].lastbuttons;
 					io[chip].lastbuttons = (io[chip].lastbuttons & 2) | (in & 1);
 
@@ -409,10 +410,10 @@ static UINT8 namcoio_51XX_read(int chip)
 
 			case 2:
 				{
-					int joy = READ_PORT(3) & 0x0f;
+					int joy = READ_PORT(space,3) & 0x0f;
 					int in,toggle;
 
-					in = ~READ_PORT(0);
+					in = ~READ_PORT(space,0);
 					toggle = in ^ io[chip].lastbuttons;
 					io[chip].lastbuttons = (io[chip].lastbuttons & 1) | (in & 2);
 
@@ -439,16 +440,17 @@ static UINT8 namcoio_ram[MAX_NAMCOIO * 16];
 #define IORAM_WRITE(offset,data) {namcoio_ram[chip * 0x10 + (offset)] = (data) & 0x0f;}
 
 
-static void handle_coins(int chip,int swap)
+static void handle_coins(running_machine *machine,int chip,int swap)
 {
 	int val,toggled;
 	int credit_add = 0;
 	int credit_sub = 0;
 	int button;
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 
 //popmessage("%x %x %x %x %x %x %x %x",IORAM_READ(8),IORAM_READ(9),IORAM_READ(10),IORAM_READ(11),IORAM_READ(12),IORAM_READ(13),IORAM_READ(14),IORAM_READ(15));
 
-	val = ~READ_PORT(0);	// pins 38-41
+	val = ~READ_PORT(space,0);	// pins 38-41
 	toggled = val ^ io[chip].lastcoins;
 	io[chip].lastcoins = val;
 
@@ -480,7 +482,7 @@ static void handle_coins(int chip,int swap)
 		credit_add = 1;
 	}
 
-	val = ~READ_PORT(3);	// pins 30-33
+	val = ~READ_PORT(space,3);	// pins 30-33
 	toggled = val ^ io[chip].lastbuttons;
 	io[chip].lastbuttons = val;
 
@@ -504,18 +506,20 @@ static void handle_coins(int chip,int swap)
 	IORAM_WRITE(1 ^ swap, io[chip].credits % 10);	// BCD credits
 	IORAM_WRITE(2 ^ swap, credit_add);	// credit increment (coin inputs)
 	IORAM_WRITE(3 ^ swap, credit_sub);	// credit decrement (start buttons)
-	IORAM_WRITE(4, ~READ_PORT(1));	// pins 22-25
+	IORAM_WRITE(4, ~READ_PORT(space,1));	// pins 22-25
 	button = ((val & 0x05) << 1) | (val & toggled & 0x05);
 	IORAM_WRITE(5, button);	// pins 30 & 32 normal and impulse
-	IORAM_WRITE(6, ~READ_PORT(2));	// pins 26-29
+	IORAM_WRITE(6, ~READ_PORT(space,2));	// pins 26-29
 	button = (val & 0x0a) | ((val & toggled & 0x0a) >> 1);
 	IORAM_WRITE(7, button);	// pins 31 & 33 normal and impulse
 }
 
 
 
-static void namco_customio_56XX_run(int chip)
+static void namco_customio_56XX_run(running_machine *machine, int chip)
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 	LOG(("execute 56XX %d mode %d\n",chip,IORAM_READ(8)));
 
 	switch (IORAM_READ(8))
@@ -524,15 +528,15 @@ static void namco_customio_56XX_run(int chip)
 			break;
 
 		case 1:	// read switch inputs
-			IORAM_WRITE(0, ~READ_PORT(0));	// pins 38-41
-			IORAM_WRITE(1, ~READ_PORT(1));	// pins 22-25
-			IORAM_WRITE(2, ~READ_PORT(2));	// pins 26-29
-			IORAM_WRITE(3, ~READ_PORT(3));	// pins 30-33
+			IORAM_WRITE(0, ~READ_PORT(space,0));	// pins 38-41
+			IORAM_WRITE(1, ~READ_PORT(space,1));	// pins 22-25
+			IORAM_WRITE(2, ~READ_PORT(space,2));	// pins 26-29
+			IORAM_WRITE(3, ~READ_PORT(space,3));	// pins 30-33
 
 //popmessage("%x %x %x %x %x %x %x %x",IORAM_READ(8),IORAM_READ(9),IORAM_READ(10),IORAM_READ(11),IORAM_READ(12),IORAM_READ(13),IORAM_READ(14),IORAM_READ(15));
 
-			WRITE_PORT(0,IORAM_READ(9));	// output to pins 13-16 (motos, pacnpal, gaplus)
-			WRITE_PORT(1,IORAM_READ(10));	// output to pins 17-20 (gaplus)
+			WRITE_PORT(space,0,IORAM_READ(9));	// output to pins 13-16 (motos, pacnpal, gaplus)
+			WRITE_PORT(space,1,IORAM_READ(10));	// output to pins 17-20 (gaplus)
 			break;
 
 		case 2:	// initialize coinage settings
@@ -547,7 +551,7 @@ static void namco_customio_56XX_run(int chip)
 
 		case 4:	// druaga, digdug chip #1: read dip switches and inputs
 				// superpac chip #0: process coin and start inputs, read switch inputs
-			handle_coins(chip,0);
+			handle_coins(machine,chip,0);
 			break;
 
 		case 7:	// bootup check (liblrabl only)
@@ -575,16 +579,16 @@ static void namco_customio_56XX_run(int chip)
 			break;
 
 		case 9:	// read dip switches and inputs
-			WRITE_PORT(0,0);	// set pin 13 = 0
-			IORAM_WRITE(0, ~READ_PORT(0));	// pins 38-41, pin 13 = 0
-			IORAM_WRITE(2, ~READ_PORT(1));	// pins 22-25, pin 13 = 0
-			IORAM_WRITE(4, ~READ_PORT(2));	// pins 26-29, pin 13 = 0
-			IORAM_WRITE(6, ~READ_PORT(3));	// pins 30-33, pin 13 = 0
-			WRITE_PORT(0,1);	// set pin 13 = 1
-			IORAM_WRITE(1, ~READ_PORT(0));	// pins 38-41, pin 13 = 1
-			IORAM_WRITE(3, ~READ_PORT(1));	// pins 22-25, pin 13 = 1
-			IORAM_WRITE(5, ~READ_PORT(2));	// pins 26-29, pin 13 = 1
-			IORAM_WRITE(7, ~READ_PORT(3));	// pins 30-33, pin 13 = 1
+			WRITE_PORT(space,0,0);	// set pin 13 = 0
+			IORAM_WRITE(0, ~READ_PORT(space,0));	// pins 38-41, pin 13 = 0
+			IORAM_WRITE(2, ~READ_PORT(space,1));	// pins 22-25, pin 13 = 0
+			IORAM_WRITE(4, ~READ_PORT(space,2));	// pins 26-29, pin 13 = 0
+			IORAM_WRITE(6, ~READ_PORT(space,3));	// pins 30-33, pin 13 = 0
+			WRITE_PORT(space,0,1);	// set pin 13 = 1
+			IORAM_WRITE(1, ~READ_PORT(space,0));	// pins 38-41, pin 13 = 1
+			IORAM_WRITE(3, ~READ_PORT(space,1));	// pins 22-25, pin 13 = 1
+			IORAM_WRITE(5, ~READ_PORT(space,2));	// pins 26-29, pin 13 = 1
+			IORAM_WRITE(7, ~READ_PORT(space,3));	// pins 30-33, pin 13 = 1
 			break;
 
 		default:
@@ -594,8 +598,10 @@ static void namco_customio_56XX_run(int chip)
 
 
 
-static void namco_customio_59XX_run(int chip)
+static void namco_customio_59XX_run(running_machine *machine, int chip)
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 	LOG(("execute 59XX %d mode %d\n",chip,IORAM_READ(8)));
 
 	switch (IORAM_READ(8))
@@ -604,10 +610,10 @@ static void namco_customio_59XX_run(int chip)
 			break;
 
 		case 3:	// pacnpal chip #1: read dip switches and inputs
-			IORAM_WRITE(4, ~READ_PORT(0));	// pins 38-41, pin 13 = 0 ?
-			IORAM_WRITE(5, ~READ_PORT(2));	// pins 26-29 ?
-			IORAM_WRITE(6, ~READ_PORT(1));	// pins 22-25 ?
-			IORAM_WRITE(7, ~READ_PORT(3));	// pins 30-33
+			IORAM_WRITE(4, ~READ_PORT(space,0));	// pins 38-41, pin 13 = 0 ?
+			IORAM_WRITE(5, ~READ_PORT(space,2));	// pins 26-29 ?
+			IORAM_WRITE(6, ~READ_PORT(space,1));	// pins 22-25 ?
+			IORAM_WRITE(7, ~READ_PORT(space,3));	// pins 30-33
 			break;
 
 		default:
@@ -617,8 +623,10 @@ static void namco_customio_59XX_run(int chip)
 
 
 
-static void namco_customio_58XX_run(int chip)
+static void namco_customio_58XX_run(running_machine *machine, int chip)
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 	LOG(("execute 58XX %d mode %d\n",chip,IORAM_READ(8)));
 
 	switch (IORAM_READ(8))
@@ -627,15 +635,15 @@ static void namco_customio_58XX_run(int chip)
 			break;
 
 		case 1:	// read switch inputs
-			IORAM_WRITE(4, ~READ_PORT(0));	// pins 38-41
-			IORAM_WRITE(5, ~READ_PORT(1));	// pins 22-25
-			IORAM_WRITE(6, ~READ_PORT(2));	// pins 26-29
-			IORAM_WRITE(7, ~READ_PORT(3));	// pins 30-33
+			IORAM_WRITE(4, ~READ_PORT(space,0));	// pins 38-41
+			IORAM_WRITE(5, ~READ_PORT(space,1));	// pins 22-25
+			IORAM_WRITE(6, ~READ_PORT(space,2));	// pins 26-29
+			IORAM_WRITE(7, ~READ_PORT(space,3));	// pins 30-33
 
 //popmessage("%x %x %x %x %x %x %x %x",IORAM_READ(8),IORAM_READ(9),IORAM_READ(10),IORAM_READ(11),IORAM_READ(12),IORAM_READ(13),IORAM_READ(14),IORAM_READ(15));
 
-			WRITE_PORT(0,IORAM_READ(9));	// output to pins 13-16 (toypop)
-			WRITE_PORT(1,IORAM_READ(10));	// output to pins 17-20 (toypop)
+			WRITE_PORT(space,0,IORAM_READ(9));	// output to pins 13-16 (toypop)
+			WRITE_PORT(space,1,IORAM_READ(10));	// output to pins 17-20 (toypop)
 			break;
 
 		case 2:	// initialize coinage settings
@@ -649,20 +657,20 @@ static void namco_customio_58XX_run(int chip)
 			break;
 
 		case 3:	// process coin and start inputs, read switch inputs
-			handle_coins(chip,2);
+			handle_coins(machine,chip,2);
 			break;
 
 		case 4:	// read dip switches and inputs
-			WRITE_PORT(0,0);	// set pin 13 = 0
-			IORAM_WRITE(0, ~READ_PORT(0));	// pins 38-41, pin 13 = 0
-			IORAM_WRITE(2, ~READ_PORT(1));	// pins 22-25, pin 13 = 0
-			IORAM_WRITE(4, ~READ_PORT(2));	// pins 26-29, pin 13 = 0
-			IORAM_WRITE(6, ~READ_PORT(3));	// pins 30-33, pin 13 = 0
-			WRITE_PORT(0,1);	// set pin 13 = 1
-			IORAM_WRITE(1, ~READ_PORT(0));	// pins 38-41, pin 13 = 1
-			IORAM_WRITE(3, ~READ_PORT(1));	// pins 22-25, pin 13 = 1
-			IORAM_WRITE(5, ~READ_PORT(2));	// pins 26-29, pin 13 = 1
-			IORAM_WRITE(7, ~READ_PORT(3));	// pins 30-33, pin 13 = 1
+			WRITE_PORT(space,0,0);	// set pin 13 = 0
+			IORAM_WRITE(0, ~READ_PORT(space,0));	// pins 38-41, pin 13 = 0
+			IORAM_WRITE(2, ~READ_PORT(space,1));	// pins 22-25, pin 13 = 0
+			IORAM_WRITE(4, ~READ_PORT(space,2));	// pins 26-29, pin 13 = 0
+			IORAM_WRITE(6, ~READ_PORT(space,3));	// pins 30-33, pin 13 = 0
+			WRITE_PORT(space,0,1);	// set pin 13 = 1
+			IORAM_WRITE(1, ~READ_PORT(space,0));	// pins 38-41, pin 13 = 1
+			IORAM_WRITE(3, ~READ_PORT(space,1));	// pins 22-25, pin 13 = 1
+			IORAM_WRITE(5, ~READ_PORT(space,2));	// pins 26-29, pin 13 = 1
+			IORAM_WRITE(7, ~READ_PORT(space,3));	// pins 30-33, pin 13 = 1
 			break;
 
 		case 5:	// bootup check
@@ -729,7 +737,7 @@ READ8_HANDLER( namcoio_r )
 	// RAM is 4-bit wide; Pac & Pal requires the | 0xf0 otherwise Easter egg doesn't work
 	offset &= 0x3f;
 
-	LOG(("%04x: I/O read %d: mode %d, offset %d = %02x\n", activecpu_get_pc(), offset / 16, namcoio_ram[(offset & 0x30) + 8], offset & 0x0f, namcoio_ram[offset]&0x0f));
+	LOG(("%04x: I/O read %d: mode %d, offset %d = %02x\n", cpu_get_pc(space->cpu), offset / 16, namcoio_ram[(offset & 0x30) + 8], offset & 0x0f, namcoio_ram[offset]&0x0f));
 
 	return 0xf0 | namcoio_ram[offset];
 }
@@ -739,7 +747,7 @@ WRITE8_HANDLER( namcoio_w )
 	offset &= 0x3f;
 	data &= 0x0f;	// RAM is 4-bit wide
 
-	LOG(("%04x: I/O write %d: offset %d = %02x\n", activecpu_get_pc(), offset / 16, offset & 0x0f, data));
+	LOG(("%04x: I/O write %d: offset %d = %02x\n", cpu_get_pc(space->cpu), offset / 16, offset & 0x0f, data));
 
 	namcoio_ram[offset] = data;
 }
@@ -766,44 +774,43 @@ static TIMER_CALLBACK( namcoio_run )
 	switch (io[param].type)
 	{
 		case NAMCOIO_56XX:
-			namco_customio_56XX_run(param);
+			namco_customio_56XX_run(machine, param);
 			break;
 		case NAMCOIO_58XX:
-			namco_customio_58XX_run(param);
+			namco_customio_58XX_run(machine, param);
 			break;
 		case NAMCOIO_59XX:
-			namco_customio_59XX_run(param);
+			namco_customio_59XX_run(machine, param);
 			break;
 	}
 }
 
-void namcoio_set_irq_line(int chipnum, int state)
+void namcoio_set_irq_line(running_machine *machine, int chipnum, int state)
 {
 	if (chipnum < MAX_NAMCOIO && state != CLEAR_LINE && !io[chipnum].reset)
 	{
 		/* give the cpu a tiny bit of time to write the command before processing it */
-		timer_set(ATTOTIME_IN_USEC(50), NULL, chipnum, namcoio_run);
+		timer_set(machine, ATTOTIME_IN_USEC(50), NULL, chipnum, namcoio_run);
 	}
 }
 
-static void namcoio_state_save(int chipnum)
+static void namcoio_state_save(running_machine *machine, int chipnum)
 {
-
-	state_save_register_item_pointer("namcoio", chipnum, ((UINT8 *) (&namcoio_ram[chipnum * 16])), 16);
-	state_save_register_item("namcoio", chipnum, io[chipnum].reset);
-	state_save_register_item("namcoio", chipnum, io[chipnum].lastcoins);
-	state_save_register_item("namcoio", chipnum, io[chipnum].lastbuttons);
-	state_save_register_item("namcoio", chipnum, io[chipnum].credits);
-	state_save_register_item_array("namcoio", chipnum, io[chipnum].coins);
-	state_save_register_item_array("namcoio", chipnum, io[chipnum].coins_per_cred);
-	state_save_register_item_array("namcoio", chipnum, io[chipnum].creds_per_coin);
-	state_save_register_item("namcoio", chipnum, io[chipnum].in_count);
-	state_save_register_item("namcoio", chipnum, io[chipnum].mode);
-	state_save_register_item("namcoio", chipnum, io[chipnum].coincred_mode);
-	state_save_register_item("namcoio", chipnum, io[chipnum].remap_joy);
+	state_save_register_item_pointer(machine, "namcoio", NULL, chipnum, ((UINT8 *) (&namcoio_ram[chipnum * 16])), 16);
+	state_save_register_item(machine, "namcoio", NULL, chipnum, io[chipnum].reset);
+	state_save_register_item(machine, "namcoio", NULL, chipnum, io[chipnum].lastcoins);
+	state_save_register_item(machine, "namcoio", NULL, chipnum, io[chipnum].lastbuttons);
+	state_save_register_item(machine, "namcoio", NULL, chipnum, io[chipnum].credits);
+	state_save_register_item_array(machine, "namcoio", NULL, chipnum, io[chipnum].coins);
+	state_save_register_item_array(machine, "namcoio", NULL, chipnum, io[chipnum].coins_per_cred);
+	state_save_register_item_array(machine, "namcoio", NULL, chipnum, io[chipnum].creds_per_coin);
+	state_save_register_item(machine, "namcoio", NULL, chipnum, io[chipnum].in_count);
+	state_save_register_item(machine, "namcoio", NULL, chipnum, io[chipnum].mode);
+	state_save_register_item(machine, "namcoio", NULL, chipnum, io[chipnum].coincred_mode);
+	state_save_register_item(machine, "namcoio", NULL, chipnum, io[chipnum].remap_joy);
 }
 
-void namcoio_init(int chipnum, int type, const struct namcoio_interface *intf)
+void namcoio_init(running_machine *machine, int chipnum, int type, const struct namcoio_interface *intf)
 {
 	if (chipnum < MAX_NAMCOIO)
 	{
@@ -814,7 +821,7 @@ void namcoio_init(int chipnum, int type, const struct namcoio_interface *intf)
 		io[chipnum].in[3] = (intf && intf->in[3]) ? intf->in[3] : nop_r;
 		io[chipnum].out[0] = (intf && intf->out[0]) ? intf->out[0] : nop_w;
 		io[chipnum].out[1] = (intf && intf->out[1]) ? intf->out[1] : nop_w;
-		namcoio_state_save(chipnum);
+		namcoio_state_save(machine, chipnum);
 		namcoio_set_reset_line(chipnum,PULSE_LINE);
 	}
 }
@@ -827,11 +834,11 @@ void namcoio_init(int chipnum, int type, const struct namcoio_interface *intf)
 
 static TIMER_CALLBACK( nmi_generate )
 {
-	if (!cpunum_is_suspended(param, SUSPEND_REASON_HALT | SUSPEND_REASON_RESET | SUSPEND_REASON_DISABLE))
+	if (!cpu_is_suspended(machine->cpu[param], SUSPEND_REASON_HALT | SUSPEND_REASON_RESET | SUSPEND_REASON_DISABLE))
 	{
 		LOG(("NMI cpu %d\n",nmi_cpu[param]));
 
-		cpunum_set_input_line(machine, nmi_cpu[param], INPUT_LINE_NMI, PULSE_LINE);
+		cpu_set_input_line(machine->cpu[nmi_cpu[param]], INPUT_LINE_NMI, PULSE_LINE);
 	}
 	else
 		LOG(("NMI not generated because cpu %d is suspended\n",nmi_cpu[param]));
@@ -839,15 +846,15 @@ static TIMER_CALLBACK( nmi_generate )
 
 static UINT8 customio_command[MAX_06XX];
 
-static void namco_06xx_state_save(int chipnum)
+static void namco_06xx_state_save(running_machine *machine, int chipnum)
 {
 
-		//state_save_register_item("namcoio06xx", chipnum, nmi_cpu[chipnum]);
-		state_save_register_item("namcoio06xx", chipnum, customio_command[chipnum]);
+	//state_save_register_item(machine, "namcoio06xx", NULL, chipnum, nmi_cpu[chipnum]);
+	state_save_register_item(machine, "namcoio06xx", NULL, chipnum, customio_command[chipnum]);
 }
 
 
-void namco_06xx_init(int chipnum, int cpu,
+void namco_06xx_init(running_machine *machine, int chipnum, int cpu,
 	int type0, const struct namcoio_interface *intf0,
 	int type1, const struct namcoio_interface *intf1,
 	int type2, const struct namcoio_interface *intf2,
@@ -855,157 +862,161 @@ void namco_06xx_init(int chipnum, int cpu,
 {
 	if (chipnum < MAX_06XX)
 	{
-		namcoio_init(4*chipnum + 0, type0, intf0);
-		namcoio_init(4*chipnum + 1, type1, intf1);
-		namcoio_init(4*chipnum + 2, type2, intf2);
-		namcoio_init(4*chipnum + 3, type3, intf3);
+		namcoio_init(machine, 4*chipnum + 0, type0, intf0);
+		namcoio_init(machine, 4*chipnum + 1, type1, intf1);
+		namcoio_init(machine, 4*chipnum + 2, type2, intf2);
+		namcoio_init(machine, 4*chipnum + 3, type3, intf3);
 		nmi_cpu[chipnum] = cpu;
-		nmi_timer[chipnum] = timer_alloc(nmi_generate, NULL);
-		namco_06xx_state_save(chipnum);
+		nmi_timer[chipnum] = timer_alloc(machine, nmi_generate, NULL);
+		namco_06xx_state_save(machine, chipnum);
 	}
 }
 
 
 
-static UINT8 namcoio_53XX_digdug_read(int chip)
+static UINT8 namcoio_53XX_digdug_read(running_machine *machine, int chip)
 {
-	LOG(("%04x: custom 53XX read\n",activecpu_get_pc()));
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	LOG(("%s: custom 53XX read\n",cpuexec_describe_context(machine)));
 
 	switch ((io[chip].in_count++) % 2)
 	{
 		default:
-		case 0: return READ_PORT(0) | (READ_PORT(1) << 4);
-		case 1: return READ_PORT(2) | (READ_PORT(3) << 4);
+		case 0: return READ_PORT(space,0) | (READ_PORT(space,1) << 4);
+		case 1: return READ_PORT(space,2) | (READ_PORT(space,3) << 4);
 	}
 }
 
 
-static UINT8 namcoio_53XX_polepos_read(int chip)
+static UINT8 namcoio_53XX_polepos_read(running_machine *machine,int chip)
 {
-	LOG(("%04x: custom 53XX read\n",activecpu_get_pc()));
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	LOG(("%s: custom 53XX read\n",cpuexec_describe_context(machine)));
 
 	switch ((io[chip].in_count++) % 8)
 	{
-		case 0: return READ_PORT(0) | (READ_PORT(1) << 4);	// steering
-		case 4: return READ_PORT(2) | (READ_PORT(3) << 4);	// dip switches
+		case 0: return READ_PORT(space,0) | (READ_PORT(space,1) << 4);	// steering
+		case 4: return READ_PORT(space,2) | (READ_PORT(space,3) << 4);	// dip switches
 		default: return 0xff;	// polepos2 hangs if 0 is returned
 	}
 }
 
 
-static UINT8 namco_06xx_data_read(int chipnum)
+static UINT8 namco_06xx_data_read(running_machine *machine, int chipnum)
 {
 	LOG(("forwarding read to chip %d\n",chipnum%3));
 
 	switch (io[chipnum].type)
 	{
-		case NAMCOIO_50XX:   return namco_50xx_read();
-		case NAMCOIO_50XX_2: return namco_50xx_2_read();
-		case NAMCOIO_51XX: return namcoio_51XX_read(chipnum);
-		case NAMCOIO_53XX_DIGDUG:  return namcoio_53XX_digdug_read(chipnum);
-		case NAMCOIO_53XX_POLEPOS: return namcoio_53XX_polepos_read(chipnum);
+		case NAMCOIO_50XX:   return namco_50xx_read(machine);
+		case NAMCOIO_50XX_2: return namco_50xx_2_read(machine);
+		case NAMCOIO_51XX: return namcoio_51XX_read(machine, chipnum);
+		case NAMCOIO_53XX_DIGDUG:  return namcoio_53XX_digdug_read(machine, chipnum);
+		case NAMCOIO_53XX_POLEPOS: return namcoio_53XX_polepos_read(machine, chipnum);
 		default:
-			logerror("%04x: custom IO type %d unsupported read\n",activecpu_get_pc(),io[chipnum].type);
+			logerror("%s: custom IO type %d unsupported read\n",cpuexec_describe_context(machine),io[chipnum].type);
 			return 0xff;
 	}
 }
 
 
-static void namco_06xx_data_write(int chipnum,UINT8 data)
+static void namco_06xx_data_write(running_machine *machine,int chipnum,UINT8 data)
 {
 	LOG(("forwarding write to chip %d\n",chipnum%3));
 
 	switch (io[chipnum].type)
 	{
-		case NAMCOIO_50XX:   namco_50xx_write(data); break;
-		case NAMCOIO_50XX_2: namco_50xx_2_write(data); break;
-		case NAMCOIO_51XX:   namcoio_51XX_write(chipnum,data); break;
-		case NAMCOIO_52XX:   namcoio_52XX_write(data); break;
-		case NAMCOIO_54XX:   namco_54xx_write(data); break;
+		case NAMCOIO_50XX:   namco_50xx_write(machine, data); break;
+		case NAMCOIO_50XX_2: namco_50xx_2_write(machine, data); break;
+		case NAMCOIO_51XX:   namcoio_51XX_write(machine,chipnum,data); break;
+		case NAMCOIO_52XX:   namcoio_52xx_write(data); break;
+		case NAMCOIO_54XX:   namco_54xx_write(machine, data); break;
 		default:
-			logerror("%04x: custom IO type %d unsupported write\n",activecpu_get_pc(),io[chipnum].type);
+			logerror("%s: custom IO type %d unsupported write\n",cpuexec_describe_context(machine),io[chipnum].type);
 			break;
 	}
 }
 
 
-static void namco_06xx_read_request(int chipnum)
+static void namco_06xx_read_request(running_machine *machine, int chipnum)
 {
 	LOG(("requesting read to chip %d\n",chipnum%3));
 
 	switch (io[chipnum].type)
 	{
-		case NAMCOIO_50XX:   namco_50xx_read_request(); break;
-		case NAMCOIO_50XX_2: namco_50xx_2_read_request(); break;
+		case NAMCOIO_50XX:   namco_50xx_read_request(machine); break;
+		case NAMCOIO_50XX_2: namco_50xx_2_read_request(machine); break;
 		default:
-			logerror("%04x: custom IO type %d read_request unsupported\n",activecpu_get_pc(),io[chipnum].type);
+			logerror("%s: custom IO type %d read_request unsupported\n",cpuexec_describe_context(machine),io[chipnum].type);
 			break;
 	}
 }
 
 
-static UINT8 namco_06xx_data_r(int chip,int offset)
+static UINT8 namco_06xx_data_r(running_machine *machine,int chip,int offset)
 {
-	LOG(("%04x: 06XX #%d read offset %d\n",activecpu_get_pc(),chip,offset));
+	LOG(("%s: 06XX #%d read offset %d\n",cpuexec_describe_context(machine),chip,offset));
 
 	if (!(customio_command[chip] & 0x10))
 	{
-		logerror("%04x: 06XX #%d read in write mode %02x\n",activecpu_get_pc(),chip,customio_command[chip]);
+		logerror("%s: 06XX #%d read in write mode %02x\n",cpuexec_describe_context(machine),chip,customio_command[chip]);
 		return 0;
 	}
 
 	switch (customio_command[chip] & 0xf)
 	{
-		case 0x1: return namco_06xx_data_read(4*chip + 0); break;
-		case 0x2: return namco_06xx_data_read(4*chip + 1); break;
-		case 0x4: return namco_06xx_data_read(4*chip + 2); break;
-		case 0x8: return namco_06xx_data_read(4*chip + 3); break;
+		case 0x1: return namco_06xx_data_read(machine, 4*chip + 0); break;
+		case 0x2: return namco_06xx_data_read(machine, 4*chip + 1); break;
+		case 0x4: return namco_06xx_data_read(machine, 4*chip + 2); break;
+		case 0x8: return namco_06xx_data_read(machine, 4*chip + 3); break;
 		default:
-			logerror("%04x: 06XX #%d read in unsupported mode %02x\n",activecpu_get_pc(),chip,customio_command[chip]);
+			logerror("%s: 06XX #%d read in unsupported mode %02x\n",cpuexec_describe_context(machine),chip,customio_command[chip]);
 			return 0xff;
 	}
 }
 
 
-static void namco_06xx_data_w(int chip,int offset,int data)
+static void namco_06xx_data_w(running_machine *machine,int chip,int offset,int data)
 {
-	LOG(("%04x: 06XX #%d write offset %d = %02x\n",activecpu_get_pc(),chip,offset,data));
+	LOG(("%s: 06XX #%d write offset %d = %02x\n",cpuexec_describe_context(machine),chip,offset,data));
 
 	if (customio_command[chip] & 0x10)
 	{
-		logerror("%04x: 06XX #%d write in read mode %02x\n",activecpu_get_pc(),chip,customio_command[chip]);
+		logerror("%s: 06XX #%d write in read mode %02x\n",cpuexec_describe_context(machine),chip,customio_command[chip]);
 		return;
 	}
 
 	switch (customio_command[chip] & 0xf)
 	{
-		case 0x1: namco_06xx_data_write(4*chip + 0,data); break;
-		case 0x2: namco_06xx_data_write(4*chip + 1,data); break;
-		case 0x4: namco_06xx_data_write(4*chip + 2,data); break;
-		case 0x8: namco_06xx_data_write(4*chip + 3,data); break;
+		case 0x1: namco_06xx_data_write(machine,4*chip + 0,data); break;
+		case 0x2: namco_06xx_data_write(machine,4*chip + 1,data); break;
+		case 0x4: namco_06xx_data_write(machine,4*chip + 2,data); break;
+		case 0x8: namco_06xx_data_write(machine,4*chip + 3,data); break;
 		default:
-			logerror("%04x: 06XX #%d write in unsupported mode %02x\n",activecpu_get_pc(),chip,customio_command[chip]);
+			logerror("%s: 06XX #%d write in unsupported mode %02x\n",cpuexec_describe_context(machine),chip,customio_command[chip]);
 			break;
 	}
 }
 
 
-static UINT8 namco_06xx_ctrl_r(int chip)
+static UINT8 namco_06xx_ctrl_r(running_machine *machine, int chip)
 {
-	LOG(("%04x: 06XX #%d ctrl_r\n",activecpu_get_pc(),chip));
+	LOG(("%s: 06XX #%d ctrl_r\n",cpuexec_describe_context(machine),chip));
 	return customio_command[chip];
 }
 
-static void namco_06xx_ctrl_w(int chip,int data)
+static void namco_06xx_ctrl_w(running_machine *machine, int chip,int data)
 {
-	LOG(("%04x: 06XX #%d command %02x\n",activecpu_get_pc(),chip,data));
+	LOG(("%s: 06XX #%d command %02x\n",cpuexec_describe_context(machine),chip,data));
 
 	customio_command[chip] = data;
 
 	if ((customio_command[chip] & 0x0f) == 0)
 	{
 		LOG(("disabling nmi generate timer\n"));
-		timer_adjust(nmi_timer[chip], attotime_never, chip, attotime_never);
+		timer_adjust_oneshot(nmi_timer[chip], attotime_never, chip);
 	}
 	else
 	{
@@ -1015,18 +1026,18 @@ static void namco_06xx_ctrl_w(int chip,int data)
 		// inputs if a transfer terminates at the wrong time.
 		// On the other hand, the time cannot be too short otherwise the 54XX will
 		// not have enough time to process the incoming commands.
-		timer_adjust(nmi_timer[chip], ATTOTIME_IN_USEC(200), chip, ATTOTIME_IN_USEC(200));
+		timer_adjust_periodic(nmi_timer[chip], ATTOTIME_IN_USEC(200), chip, ATTOTIME_IN_USEC(200));
 
 		if (customio_command[chip] & 0x10)
 		{
 			switch (customio_command[chip] & 0xf)
 			{
-				case 0x1: namco_06xx_read_request(4*chip + 0); break;
-				case 0x2: namco_06xx_read_request(4*chip + 1); break;
-				case 0x4: namco_06xx_read_request(4*chip + 2); break;
-				case 0x8: namco_06xx_read_request(4*chip + 3); break;
+				case 0x1: namco_06xx_read_request(machine, 4*chip + 0); break;
+				case 0x2: namco_06xx_read_request(machine, 4*chip + 1); break;
+				case 0x4: namco_06xx_read_request(machine, 4*chip + 2); break;
+				case 0x8: namco_06xx_read_request(machine, 4*chip + 3); break;
 				default:
-					logerror("%04x: 06XX #%d read in unsupported mode %02x\n",activecpu_get_pc(),chip,customio_command[chip]);
+					logerror("%s: 06XX #%d read in unsupported mode %02x\n",cpuexec_describe_context(machine),chip,customio_command[chip]);
 			}
 		}
 	}
@@ -1034,11 +1045,11 @@ static void namco_06xx_ctrl_w(int chip,int data)
 
 
 
-READ8_HANDLER( namco_06xx_0_data_r )		{ return namco_06xx_data_r(0,offset); }
-READ8_HANDLER( namco_06xx_1_data_r )		{ return namco_06xx_data_r(1,offset); }
-WRITE8_HANDLER( namco_06xx_0_data_w )	{ namco_06xx_data_w(0,offset,data); }
-WRITE8_HANDLER( namco_06xx_1_data_w )	{ namco_06xx_data_w(1,offset,data); }
-READ8_HANDLER( namco_06xx_0_ctrl_r )		{ return namco_06xx_ctrl_r(0); }
-READ8_HANDLER( namco_06xx_1_ctrl_r )		{ return namco_06xx_ctrl_r(1); }
-WRITE8_HANDLER( namco_06xx_0_ctrl_w )	{ namco_06xx_ctrl_w(0,data); }
-WRITE8_HANDLER( namco_06xx_1_ctrl_w )	{ namco_06xx_ctrl_w(1,data); }
+READ8_HANDLER( namco_06xx_0_data_r )	{ return namco_06xx_data_r(space->machine,0,offset); }
+READ8_HANDLER( namco_06xx_1_data_r )	{ return namco_06xx_data_r(space->machine,1,offset); }
+WRITE8_HANDLER( namco_06xx_0_data_w )	{ namco_06xx_data_w(space->machine,0,offset,data); }
+WRITE8_HANDLER( namco_06xx_1_data_w )	{ namco_06xx_data_w(space->machine,1,offset,data); }
+READ8_HANDLER( namco_06xx_0_ctrl_r )	{ return namco_06xx_ctrl_r(space->machine,0); }
+READ8_HANDLER( namco_06xx_1_ctrl_r )	{ return namco_06xx_ctrl_r(space->machine,1); }
+WRITE8_HANDLER( namco_06xx_0_ctrl_w )	{ namco_06xx_ctrl_w(space->machine, 0,data); }
+WRITE8_HANDLER( namco_06xx_1_ctrl_w )	{ namco_06xx_ctrl_w(space->machine, 1,data); }
