@@ -20,7 +20,8 @@ Memo:
 
 
 int nb1413m3_type;
-int nb1413m3_sndromregion;
+//int nb1413m3_sndromregion;
+const char * nb1413m3_sndromrgntag;
 int nb1413m3_sndrombank1;
 int nb1413m3_sndrombank2;
 int nb1413m3_busyctr;
@@ -44,7 +45,7 @@ static int nb1413m3_outcoin_flag;
 #define NB1413M3_TIMER_BASE 20000000
 static TIMER_CALLBACK( nb1413m3_timer_callback )
 {
-	timer_set(attotime_mul(ATTOTIME_IN_HZ(NB1413M3_TIMER_BASE), 256), NULL, 0, nb1413m3_timer_callback);
+	timer_set(machine, attotime_mul(ATTOTIME_IN_HZ(NB1413M3_TIMER_BASE), 256), NULL, 0, nb1413m3_timer_callback);
 
 	nb1413m3_74ls193_counter++;
 	nb1413m3_74ls193_counter &= 0x0f;
@@ -54,7 +55,7 @@ static TIMER_CALLBACK( nb1413m3_timer_callback )
 
 		if (nb1413m3_nmi_enable)
 		{
-			cpunum_set_input_line(machine, 0, INPUT_LINE_NMI, PULSE_LINE);
+			cpu_set_input_line(machine->cpu[0], INPUT_LINE_NMI, PULSE_LINE);
 			nb1413m3_nmi_count++;
 		}
 
@@ -128,7 +129,7 @@ MACHINE_RESET( nb1413m3 )
 	nb1413m3_nmi_count = 0;
 	nb1413m3_74ls193_counter = 0;
 	nb1413m3_counter = 0;
-	nb1413m3_sndromregion = REGION_SOUND1;
+	nb1413m3_sndromrgntag = "voice";
 	nb1413m3_sndrombank1 = 0;
 	nb1413m3_sndrombank2 = 0;
 	nb1413m3_busyctr = 0;
@@ -141,7 +142,7 @@ MACHINE_RESET( nb1413m3 )
 
 	nb1413m3_74ls193_counter = 0;
 
-	timer_call_after_resynch(NULL, 0, nb1413m3_timer_callback);
+	timer_call_after_resynch(machine, NULL, 0, nb1413m3_timer_callback);
 }
 
 WRITE8_HANDLER( nb1413m3_nmi_clock_w )
@@ -194,15 +195,15 @@ WRITE8_HANDLER( nb1413m3_nmi_clock_w )
 INTERRUPT_GEN( nb1413m3_interrupt )
 {
 #if 0
-	if (!cpu_getiloops())
+	if (!cpu_getiloops(device))
 	{
 //      nb1413m3_busyflag = 1;
 //      nb1413m3_busyctr = 0;
-		cpunum_set_input_line(machine, 0, 0, HOLD_LINE);
+		cpu_set_input_line(device, 0, HOLD_LINE);
 	}
 	if (nb1413m3_nmi_enable)
 	{
-		cpunum_set_input_line(machine, 0, INPUT_LINE_NMI, PULSE_LINE);
+		cpu_set_input_line(device, INPUT_LINE_NMI, PULSE_LINE);
 	}
 
 	#if NB1413M3_CHEAT
@@ -211,7 +212,7 @@ INTERRUPT_GEN( nb1413m3_interrupt )
 #else
 //  nb1413m3_busyflag = 1;
 //  nb1413m3_busyctr = 0;
-	cpunum_set_input_line(machine, 0, 0, HOLD_LINE);
+	cpu_set_input_line(device, 0, HOLD_LINE);
 
 #if NB1413M3_DEBUG
 	popmessage("NMI SW:%01X CLOCK:%02X COUNT:%02X", nb1413m3_nmi_enable, nb1413m3_nmi_clock, nb1413m3_nmi_count);
@@ -242,7 +243,7 @@ READ8_HANDLER( nb1413m3_sndrom_r )
 	int rombank;
 
 	/* get top 8 bits of the I/O port address */
-	offset = (offset << 8) | (activecpu_get_reg(Z80_BC) >> 8);
+	offset = (offset << 8) | (cpu_get_reg(space->cpu, Z80_BC) >> 8);
 
 	switch (nb1413m3_type)
 	{
@@ -327,8 +328,8 @@ READ8_HANDLER( nb1413m3_sndrom_r )
 	popmessage("Sound ROM %02X:%05X [B1:%02X B2:%02X]", rombank, offset, nb1413m3_sndrombank1, nb1413m3_sndrombank2);
 #endif
 
-	if (offset < memory_region_length(nb1413m3_sndromregion))
-		return memory_region(nb1413m3_sndromregion)[offset];
+	if (offset < memory_region_length(space->machine, nb1413m3_sndromrgntag))
+		return memory_region(space->machine, nb1413m3_sndromrgntag)[offset];
 	else
 	{
 		popmessage("read past sound ROM length (%05x[%02X])",offset, rombank);
@@ -339,7 +340,7 @@ READ8_HANDLER( nb1413m3_sndrom_r )
 WRITE8_HANDLER( nb1413m3_sndrombank1_w )
 {
 	// if (data & 0x02) coin counter ?
-	nb1413m3_outcoin_w(0, data);				// (data & 0x04) >> 2;
+	nb1413m3_outcoin_w(space, 0, data);				// (data & 0x04) >> 2;
 	nb1413m3_nmi_enable = ((data & 0x20) >> 5);
 	nb1413m3_sndrombank1 = (((data & 0xc0) >> 5) | ((data & 0x10) >> 4));
 }
@@ -351,7 +352,7 @@ WRITE8_HANDLER( nb1413m3_sndrombank2_w )
 
 READ8_HANDLER( nb1413m3_gfxrom_r )
 {
-	UINT8 *GFXROM = memory_region(REGION_GFX1);
+	UINT8 *GFXROM = memory_region(space->machine, "gfx1");
 
 	return GFXROM[(0x20000 * (nb1413m3_gfxrombank | ((nb1413m3_sndrombank1 & 0x02) << 3))) + ((0x0200 * nb1413m3_gfxradr_h) + (0x0002 * nb1413m3_gfxradr_l)) + (offset & 0x01)];
 }
@@ -376,78 +377,72 @@ WRITE8_HANDLER( nb1413m3_inputportsel_w )
 	nb1413m3_inputport = data;
 }
 
+CUSTOM_INPUT( nb1413m3_busyflag_r )
+{
+	return nb1413m3_busyflag & 0x01;
+}
+
+
+/* 2008-08 FP:
+ * In ALL games (but pastelg, hyhoo & hyhoo2) nb1413m3_outcoin_flag is read at inputport0.
+ * However, a few games (lovehous, maiko, mmaiko, hanaoji and the ones using inputport3_r below)
+ * read nb1413m3_outcoin_flag also at inputport3! Is this the correct behaviour for these games
+ * or should they only check the flag at inputport3? */
+CUSTOM_INPUT( nb1413m3_outcoin_flag_r )
+{
+	return nb1413m3_outcoin_flag & 0x01;
+}
+
 READ8_HANDLER( nb1413m3_inputport0_r )
 {
-	switch (nb1413m3_type)
-	{
-		case NB1413M3_PASTELG:
-			return ((input_port_3_r(0) & 0xfe) | (nb1413m3_busyflag & 0x01));
-		case NB1413M3_TAIWANMB:
-			return ((input_port_3_r(0) & 0xfc) | ((nb1413m3_outcoin_flag & 0x01) << 1) | (nb1413m3_busyflag & 0x01));
-		case NB1413M3_HYHOO:
-		case NB1413M3_HYHOO2:
-			return ((input_port_2_r(0) & 0xfe) | (nb1413m3_busyflag & 0x01));
-		default:
-			return ((input_port_2_r(0) & 0xfc) | ((nb1413m3_outcoin_flag & 0x01) << 1) | (nb1413m3_busyflag & 0x01));
-	}
+	return ((input_port_read(space->machine, "SYSTEM") & 0xfd) | ((nb1413m3_outcoin_flag & 0x01) << 1));
 }
 
 READ8_HANDLER( nb1413m3_inputport1_r )
 {
 	switch (nb1413m3_type)
 	{
-		case NB1413M3_PASTELG:
-		case NB1413M3_THREEDS:
-		case NB1413M3_TAIWANMB:
-			switch ((nb1413m3_inputport ^ 0xff) & 0x1f)
-			{
-				case 0x01:	return readinputport(4);
-				case 0x02:	return readinputport(5);
-				case 0x04:	return readinputport(6);
-				case 0x08:	return readinputport(7);
-				case 0x10:	return readinputport(8);
-				default:	return (readinputport(4) & readinputport(5) & readinputport(6) & readinputport(7) & readinputport(8));
-			}
-			break;
 		case NB1413M3_HYHOO:
 		case NB1413M3_HYHOO2:
 			switch ((nb1413m3_inputport ^ 0xff) & 0x07)
 			{
-				case 0x01:	return readinputport(3);
-				case 0x02:	return readinputport(4);
+				case 0x01:	return input_port_read(space->machine, "IN0");
+				case 0x02:	return input_port_read(space->machine, "IN1");
 				case 0x04:	return 0xff;
 				default:	return 0xff;
 			}
 			break;
 		case NB1413M3_MSJIKEN:
 		case NB1413M3_TELMAHJN:
-			if (readinputport(0) & 0x80)
+			if (input_port_read(space->machine, "DSWA") & 0x80)
 			{
 				switch ((nb1413m3_inputport ^ 0xff) & 0x1f)
 				{
-					case 0x01:	return readinputport(3);
-					case 0x02:	return readinputport(4);
-					case 0x04:	return readinputport(5);
-					case 0x08:	return readinputport(6);
-					case 0x10:	return readinputport(7);
-					default:	return (readinputport(3) & readinputport(4) & readinputport(5) & readinputport(6) & readinputport(7));
+					case 0x01:	return input_port_read(space->machine, "KEY0");
+					case 0x02:	return input_port_read(space->machine, "KEY1");
+					case 0x04:	return input_port_read(space->machine, "KEY2");
+					case 0x08:	return input_port_read(space->machine, "KEY3");
+					case 0x10:	return input_port_read(space->machine, "KEY4");
+					default:	return (input_port_read(space->machine, "KEY0") & input_port_read(space->machine, "KEY1") & input_port_read(space->machine, "KEY2")
+										& input_port_read(space->machine, "KEY3") & input_port_read(space->machine, "KEY4"));
 				}
 			}
-			else return readinputport(14);
+			else return input_port_read(space->machine, "JAMMA2");
 			break;
 		case NB1413M3_PAIRSNB:
 		case NB1413M3_PAIRSTEN:
-			return readinputport(3);
+			return input_port_read(space->machine, "P1");
 			break;
 		default:
 			switch ((nb1413m3_inputport ^ 0xff) & 0x1f)
 			{
-				case 0x01:	return readinputport(3);
-				case 0x02:	return readinputport(4);
-				case 0x04:	return readinputport(5);
-				case 0x08:	return readinputport(6);
-				case 0x10:	return readinputport(7);
-				default:	return (readinputport(3) & readinputport(4) & readinputport(5) & readinputport(6) & readinputport(7));
+				case 0x01:	return input_port_read(space->machine, "KEY0");
+				case 0x02:	return input_port_read(space->machine, "KEY1");
+				case 0x04:	return input_port_read(space->machine, "KEY2");
+				case 0x08:	return input_port_read(space->machine, "KEY3");
+				case 0x10:	return input_port_read(space->machine, "KEY4");
+				default:	return (input_port_read(space->machine, "KEY0") & input_port_read(space->machine, "KEY1") & input_port_read(space->machine, "KEY2")
+									& input_port_read(space->machine, "KEY3") & input_port_read(space->machine, "KEY4"));
 			}
 			break;
 	}
@@ -457,58 +452,47 @@ READ8_HANDLER( nb1413m3_inputport2_r )
 {
 	switch (nb1413m3_type)
 	{
-		case NB1413M3_PASTELG:
-		case NB1413M3_THREEDS:
-		case NB1413M3_TAIWANMB:
-			switch ((nb1413m3_inputport ^ 0xff) & 0x1f)
-			{
-				case 0x01:	return readinputport(9);
-				case 0x02:	return readinputport(10);
-				case 0x04:	return readinputport(11);
-				case 0x08:	return readinputport(12);
-				case 0x10:	return readinputport(13);
-				default:	return (readinputport(9) & readinputport(10) & readinputport(11) & readinputport(12) & readinputport(13));
-			}
-			break;
 		case NB1413M3_HYHOO:
 		case NB1413M3_HYHOO2:
 			switch ((nb1413m3_inputport ^ 0xff) & 0x07)
 			{
 				case 0x01:	return 0xff;
 				case 0x02:	return 0xff;
-				case 0x04:	return readinputport(5);
+				case 0x04:	return input_port_read(space->machine, "IN2");
 				default:	return 0xff;
 			}
 			break;
 		case NB1413M3_MSJIKEN:
 		case NB1413M3_TELMAHJN:
-			if (readinputport(0) & 0x80)
+			if (input_port_read(space->machine, "DSWA") & 0x80)
 			{
 				switch ((nb1413m3_inputport ^ 0xff) & 0x1f)
 				{
-					case 0x01:	return readinputport(8);
-					case 0x02:	return readinputport(9);
-					case 0x04:	return readinputport(10);
-					case 0x08:	return readinputport(11);
-					case 0x10:	return readinputport(12);
-					default:	return (readinputport(8) & readinputport(9) & readinputport(10) & readinputport(11) & readinputport(12));
+					case 0x01:	return input_port_read(space->machine, "KEY5");
+					case 0x02:	return input_port_read(space->machine, "KEY6");
+					case 0x04:	return input_port_read(space->machine, "KEY7");
+					case 0x08:	return input_port_read(space->machine, "KEY8");
+					case 0x10:	return input_port_read(space->machine, "KEY9");
+					default:	return (input_port_read(space->machine, "KEY5") & input_port_read(space->machine, "KEY6") & input_port_read(space->machine, "KEY7")
+										& input_port_read(space->machine, "KEY8") & input_port_read(space->machine, "KEY9"));
 				}
 			}
-			else return readinputport(13);
+			else return input_port_read(space->machine, "JAMMA1");
 			break;
 		case NB1413M3_PAIRSNB:
 		case NB1413M3_PAIRSTEN:
-			return readinputport(4);
+			return input_port_read(space->machine, "P2");
 			break;
 		default:
 			switch ((nb1413m3_inputport ^ 0xff) & 0x1f)
 			{
-				case 0x01:	return readinputport(8);
-				case 0x02:	return readinputport(9);
-				case 0x04:	return readinputport(10);
-				case 0x08:	return readinputport(11);
-				case 0x10:	return readinputport(12);
-				default:	return (readinputport(8) & readinputport(9) & readinputport(10) & readinputport(11) & readinputport(12));
+				case 0x01:	return input_port_read(space->machine, "KEY5");
+				case 0x02:	return input_port_read(space->machine, "KEY6");
+				case 0x04:	return input_port_read(space->machine, "KEY7");
+				case 0x08:	return input_port_read(space->machine, "KEY8");
+				case 0x10:	return input_port_read(space->machine, "KEY9");
+				default:	return (input_port_read(space->machine, "KEY5") & input_port_read(space->machine, "KEY6") & input_port_read(space->machine, "KEY7")
+									& input_port_read(space->machine, "KEY8") & input_port_read(space->machine, "KEY9"));
 			}
 			break;
 	}
@@ -533,12 +517,6 @@ READ8_HANDLER( nb1413m3_inputport3_r )
 		case NB1413M3_MMSIKAKU:
 			return ((nb1413m3_outcoin_flag & 0x01) << 1);
 			break;
-		case NB1413M3_LOVEHOUS:
-		case NB1413M3_MAIKO:
-		case NB1413M3_MMAIKO:
-		case NB1413M3_HANAOJI:
-			return ((input_port_13_r(0) & 0xfd) | ((nb1413m3_outcoin_flag & 0x01) << 1));
-			break;
 		default:
 			return 0xff;
 			break;
@@ -551,16 +529,16 @@ READ8_HANDLER( nb1413m3_dipsw1_r )
 	{
 		case NB1413M3_KANATUEN:
 		case NB1413M3_KYUHITO:
-			return readinputport(1);
+			return input_port_read(space->machine, "DSWB");
 			break;
 		case NB1413M3_TAIWANMB:
-			return ((readinputport(0) & 0xf0) | ((readinputport(1) & 0xf0) >> 4));
+			return ((input_port_read(space->machine, "DSWA") & 0xf0) | ((input_port_read(space->machine, "DSWB") & 0xf0) >> 4));
 			break;
 		case NB1413M3_OTONANO:
 		case NB1413M3_MJCAMERA:
 		case NB1413M3_IDHIMITU:
 		case NB1413M3_KAGUYA2:
-			return (((readinputport(0) & 0x0f) << 4) | (readinputport(1) & 0x0f));
+			return (((input_port_read(space->machine, "DSWA") & 0x0f) << 4) | (input_port_read(space->machine, "DSWB") & 0x0f));
 			break;
 		case NB1413M3_SCANDAL:
 		case NB1413M3_SCANDALM:
@@ -572,7 +550,7 @@ READ8_HANDLER( nb1413m3_dipsw1_r )
 		case NB1413M3_UCHUUAI:
 		case NB1413M3_TOKIMBSJ:
 		case NB1413M3_TOKYOGAL:
-			return ((readinputport(0) & 0x0f) | ((readinputport(1) & 0x0f) << 4));
+			return ((input_port_read(space->machine, "DSWA") & 0x0f) | ((input_port_read(space->machine, "DSWB") & 0x0f) << 4));
 			break;
 		case NB1413M3_TRIPLEW1:
 		case NB1413M3_NTOPSTAR:
@@ -583,13 +561,13 @@ READ8_HANDLER( nb1413m3_dipsw1_r )
 		case NB1413M3_MJLSTORY:
 		case NB1413M3_QMHAYAKU:
 		case NB1413M3_MJGOTTUB:
-			return (((readinputport(1) & 0x01) >> 0) | ((readinputport(1) & 0x04) >> 1) |
-			        ((readinputport(1) & 0x10) >> 2) | ((readinputport(1) & 0x40) >> 3) |
-			        ((readinputport(0) & 0x01) << 4) | ((readinputport(0) & 0x04) << 3) |
-			        ((readinputport(0) & 0x10) << 2) | ((readinputport(0) & 0x40) << 1));
+			return (((input_port_read(space->machine, "DSWB") & 0x01) >> 0) | ((input_port_read(space->machine, "DSWB") & 0x04) >> 1) |
+			        ((input_port_read(space->machine, "DSWB") & 0x10) >> 2) | ((input_port_read(space->machine, "DSWB") & 0x40) >> 3) |
+			        ((input_port_read(space->machine, "DSWA") & 0x01) << 4) | ((input_port_read(space->machine, "DSWA") & 0x04) << 3) |
+			        ((input_port_read(space->machine, "DSWA") & 0x10) << 2) | ((input_port_read(space->machine, "DSWA") & 0x40) << 1));
 			break;
 		default:
-			return readinputport(0);
+			return input_port_read(space->machine, "DSWA");
 			break;
 	}
 }
@@ -600,16 +578,16 @@ READ8_HANDLER( nb1413m3_dipsw2_r )
 	{
 		case NB1413M3_KANATUEN:
 		case NB1413M3_KYUHITO:
-			return readinputport(0);
+			return input_port_read(space->machine, "DSWA");
 			break;
 		case NB1413M3_TAIWANMB:
-			return (((readinputport(0) & 0x0f) << 4) | (readinputport(1) & 0x0f));
+			return (((input_port_read(space->machine, "DSWA") & 0x0f) << 4) | (input_port_read(space->machine, "DSWB") & 0x0f));
 			break;
 		case NB1413M3_OTONANO:
 		case NB1413M3_MJCAMERA:
 		case NB1413M3_IDHIMITU:
 		case NB1413M3_KAGUYA2:
-			return ((readinputport(0) & 0xf0) | ((readinputport(1) & 0xf0) >> 4));
+			return ((input_port_read(space->machine, "DSWA") & 0xf0) | ((input_port_read(space->machine, "DSWB") & 0xf0) >> 4));
 			break;
 		case NB1413M3_SCANDAL:
 		case NB1413M3_SCANDALM:
@@ -621,7 +599,7 @@ READ8_HANDLER( nb1413m3_dipsw2_r )
 		case NB1413M3_UCHUUAI:
 		case NB1413M3_TOKIMBSJ:
 		case NB1413M3_TOKYOGAL:
-			return (((readinputport(0) & 0xf0) >> 4) | (readinputport(1) & 0xf0));
+			return (((input_port_read(space->machine, "DSWA") & 0xf0) >> 4) | (input_port_read(space->machine, "DSWB") & 0xf0));
 			break;
 		case NB1413M3_TRIPLEW1:
 		case NB1413M3_NTOPSTAR:
@@ -632,25 +610,25 @@ READ8_HANDLER( nb1413m3_dipsw2_r )
 		case NB1413M3_MJLSTORY:
 		case NB1413M3_QMHAYAKU:
 		case NB1413M3_MJGOTTUB:
-			return (((readinputport(1) & 0x02) >> 1) | ((readinputport(1) & 0x08) >> 2) |
-			        ((readinputport(1) & 0x20) >> 3) | ((readinputport(1) & 0x80) >> 4) |
-			        ((readinputport(0) & 0x02) << 3) | ((readinputport(0) & 0x08) << 2) |
-			        ((readinputport(0) & 0x20) << 1) | ((readinputport(0) & 0x80) << 0));
+			return (((input_port_read(space->machine, "DSWB") & 0x02) >> 1) | ((input_port_read(space->machine, "DSWB") & 0x08) >> 2) |
+			        ((input_port_read(space->machine, "DSWB") & 0x20) >> 3) | ((input_port_read(space->machine, "DSWB") & 0x80) >> 4) |
+			        ((input_port_read(space->machine, "DSWA") & 0x02) << 3) | ((input_port_read(space->machine, "DSWA") & 0x08) << 2) |
+			        ((input_port_read(space->machine, "DSWA") & 0x20) << 1) | ((input_port_read(space->machine, "DSWA") & 0x80) << 0));
 			break;
 		default:
-			return readinputport(1);
+			return input_port_read(space->machine, "DSWB");
 			break;
 	}
 }
 
 READ8_HANDLER( nb1413m3_dipsw3_l_r )
 {
-	return ((readinputport(2) & 0xf0) >> 4);
+	return ((input_port_read(space->machine, "DSWC") & 0xf0) >> 4);
 }
 
 READ8_HANDLER( nb1413m3_dipsw3_h_r )
 {
-	return ((readinputport(2) & 0x0f) >> 0);
+	return ((input_port_read(space->machine, "DSWC") & 0x0f) >> 0);
 }
 
 WRITE8_HANDLER( nb1413m3_outcoin_w )
@@ -706,3 +684,106 @@ WRITE8_HANDLER( nb1413m3_vcrctrl_w )
 		set_led_status(2, 0);
 	}
 }
+
+/* Nichibutsu Mahjong games share a common control panel */
+INPUT_PORTS_START( nbmjcontrols )
+	PORT_START("KEY0")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_KAN )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_M )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_MAHJONG_I )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_MAHJONG_E )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_MAHJONG_A )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("KEY1")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_MAHJONG_BET )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_REACH )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_N )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_MAHJONG_J )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_MAHJONG_F )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_MAHJONG_B )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("KEY2")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_RON )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_CHI )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_MAHJONG_K )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_MAHJONG_G )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_MAHJONG_C )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("KEY3")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_PON )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_MAHJONG_L )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_MAHJONG_H )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_MAHJONG_D )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("KEY4")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_MAHJONG_SMALL )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_BIG )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_FLIP_FLOP )
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_MAHJONG_DOUBLE_UP )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_MAHJONG_SCORE )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_MAHJONG_LAST_CHANCE )
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("KEY5")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START2 )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_KAN ) PORT_PLAYER(2)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_M ) PORT_PLAYER(2)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_MAHJONG_I ) PORT_PLAYER(2)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_MAHJONG_E ) PORT_PLAYER(2)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_MAHJONG_A ) PORT_PLAYER(2)
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("KEY6")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_MAHJONG_BET ) PORT_PLAYER(2)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_REACH ) PORT_PLAYER(2)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_N ) PORT_PLAYER(2)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_MAHJONG_J ) PORT_PLAYER(2)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_MAHJONG_F ) PORT_PLAYER(2)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_MAHJONG_B ) PORT_PLAYER(2)
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("KEY7")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_RON ) PORT_PLAYER(2)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_CHI ) PORT_PLAYER(2)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_MAHJONG_K ) PORT_PLAYER(2)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_MAHJONG_G ) PORT_PLAYER(2)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_MAHJONG_C ) PORT_PLAYER(2)
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("KEY8")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_PON ) PORT_PLAYER(2)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_MAHJONG_L ) PORT_PLAYER(2)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_MAHJONG_H ) PORT_PLAYER(2)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_MAHJONG_D ) PORT_PLAYER(2)
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+
+	PORT_START("KEY9")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_MAHJONG_SMALL ) PORT_PLAYER(2)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_MAHJONG_BIG ) PORT_PLAYER(2)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_MAHJONG_FLIP_FLOP ) PORT_PLAYER(2)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_MAHJONG_DOUBLE_UP ) PORT_PLAYER(2)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_MAHJONG_SCORE ) PORT_PLAYER(2)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_MAHJONG_LAST_CHANCE ) PORT_PLAYER(2)
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
+	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
+INPUT_PORTS_END
