@@ -18,11 +18,12 @@
 
 /* General Bootleg Functions - used by more than 1 game */
 
-void neogeo_bootleg_cx_decrypt( void )
+
+void neogeo_bootleg_cx_decrypt( running_machine *machine )
 {
 	int i;
-	int cx_size = memory_region_length( NEOGEO_REGION_SPRITES );
-	UINT8 *rom = memory_region( NEOGEO_REGION_SPRITES );
+	int cx_size = memory_region_length( machine, "sprites" );
+	UINT8 *rom = memory_region( machine, "sprites" );
 	UINT8 *buf = malloc_or_die( cx_size );
 
 	memcpy( buf, rom, cx_size );
@@ -34,10 +35,11 @@ void neogeo_bootleg_cx_decrypt( void )
 	free( buf );
 }
 
-void neogeo_bootleg_sx_decrypt( int value )
+
+void neogeo_bootleg_sx_decrypt( running_machine *machine, int value )
 {
-	int sx_size = memory_region_length( NEOGEO_REGION_FIXED_LAYER_CARTRIDGE );
-	UINT8 *rom = memory_region( NEOGEO_REGION_FIXED_LAYER_CARTRIDGE );
+	int sx_size = memory_region_length( machine, "fixed" );
+	UINT8 *rom = memory_region( machine, "fixed" );
 	int i;
 
 	if (value == 1)
@@ -62,16 +64,16 @@ void neogeo_bootleg_sx_decrypt( int value )
 
 /* The King of Gladiator (The King of Fighters '97 bootleg) */
 
-/* the protection patching here may be incomplete */
 
-// Thanks to Razoola for the info
+/* The protection patching here may be incomplete
+   Thanks to Razoola for the info */
 
-void kog_px_decrypt( void )
+void kog_px_decrypt( running_machine *machine )
 {
 	/* the protection chip does some *very* strange things to the rom */
-	UINT8 *src = memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE);
+	UINT8 *src = memory_region(machine, "main");
 	UINT8 *dst = malloc_or_die( 0x600000 );
-	UINT16 *rom = (UINT16 *)memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE);
+	UINT16 *rom = (UINT16 *)memory_region(machine, "main");
 	int i;
 	static const int sec[] = { 0x3, 0x8, 0x7, 0xC, 0x1, 0xA, 0x6, 0xD };
 
@@ -127,7 +129,9 @@ void kog_px_decrypt( void )
 
 }
 
-/* Kof 10th Anniversary (bootleg of King of Fighters 2002 */
+
+/* The King of Fighters 10th Anniversary (The King of Fighters 2002 bootleg) */
+
 
 /* this uses RAM based tiles for the text layer, however the implementation
   is incomplete, at the moment the S data is copied from the program rom on
@@ -135,12 +139,12 @@ void kog_px_decrypt( void )
 
 static UINT16 kof10thExtraRAMB[0x01000];
 
-static void kof10thBankswitch(UINT16 nBank)
+static void kof10thBankswitch(const address_space *space, UINT16 nBank)
 {
 	UINT32 bank = 0x100000 + ((nBank & 7) << 20);
 	if (bank >= 0x700000)
 		bank = 0x100000;
-	neogeo_set_main_cpu_bank_address(bank);
+	neogeo_set_main_cpu_bank_address(space, bank);
 }
 
 static READ16_HANDLER( kof10th_RAMB_r )
@@ -151,10 +155,10 @@ static READ16_HANDLER( kof10th_RAMB_r )
 static WRITE16_HANDLER( kof10th_custom_w )
 {
 	if (!kof10thExtraRAMB[0xFFE]) { // Write to RAM bank A
-		UINT16 *prom = (UINT16*)memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
+		UINT16 *prom = (UINT16*)memory_region( space->machine, "main" );
 		COMBINE_DATA(&prom[(0xE0000/2) + (offset & 0xFFFF)]);
 	} else { // Write S data on-the-fly
-		UINT8 *srom = memory_region( NEOGEO_REGION_FIXED_LAYER_CARTRIDGE );
+		UINT8 *srom = memory_region( space->machine, "fixed" );
 		srom[offset] = BITSWAP8(data,7,6,0,4,3,2,1,5);
 	}
 }
@@ -163,27 +167,27 @@ static WRITE16_HANDLER( kof10th_bankswitch_w )
 {
 	if (offset >= 0x5F000) {
 		if (offset == 0x5FFF8) { // Standard bankswitch
-			kof10thBankswitch(data);
+			kof10thBankswitch(space, data);
 		} else if (offset == 0x5FFFC && kof10thExtraRAMB[0xFFC] != data) { // Special bankswitch
-			UINT8 *src = memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
+			UINT8 *src = memory_region( space->machine, "main" );
 			memcpy (src + 0x10000,  src + ((data & 1) ? 0x810000 : 0x710000), 0xcffff);
 		}
 		COMBINE_DATA(&kof10thExtraRAMB[offset & 0xFFF]);
 	}
 }
 
-void install_kof10th_protection ( void )
+void install_kof10th_protection ( running_machine *machine )
 {
-	memory_install_read16_handler(0,  ADDRESS_SPACE_PROGRAM, 0x2fe000, 0x2fffff, 0, 0, kof10th_RAMB_r);
-	memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0x200000, 0x23ffff, 0, 0, kof10th_custom_w);
-	memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0x240000, 0x2fffff, 0, 0, kof10th_bankswitch_w);
+	memory_install_read16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2fe000, 0x2fffff, 0, 0, kof10th_RAMB_r);
+	memory_install_write16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x200000, 0x23ffff, 0, 0, kof10th_custom_w);
+	memory_install_write16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x240000, 0x2fffff, 0, 0, kof10th_bankswitch_w);
 }
 
-void decrypt_kof10th( void )
+void decrypt_kof10th(running_machine *machine)
 {
 	int i, j;
 	UINT8 *dst = malloc_or_die(0x900000);
-	UINT8 *src = memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
+	UINT8 *src = memory_region( machine, "main" );
 
 		memcpy(dst + 0x000000, src + 0x700000, 0x100000); // Correct (Verified in Uni-bios)
 		memcpy(dst + 0x100000, src + 0x000000, 0x800000);
@@ -204,13 +208,17 @@ void decrypt_kof10th( void )
 	((UINT16*)src)[0x8bf8/2] = 0xf980;
 }
 
-void decrypt_kf10thep(void)
+
+/* The King of Fighters 10th Anniversary Extra Plus (The King of Fighters 2002 bootleg) */
+
+
+void decrypt_kf10thep(running_machine *machine)
 {
 	int i;
-	UINT16 *rom = (UINT16*)memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE);
-	UINT8  *src = memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE);
-	UINT16 *buf = (UINT16*)memory_region(NEOGEO_REGION_AUDIO_CPU_ENCRYPTED);
-	UINT8 *srom = (UINT8*)memory_region(NEOGEO_REGION_FIXED_LAYER_CARTRIDGE);
+	UINT16 *rom = (UINT16*)memory_region(machine, "main");
+	UINT8  *src = memory_region(machine, "main");
+	UINT16 *buf = (UINT16*)memory_region(machine, "audiocrypt");
+	UINT8 *srom = (UINT8*)memory_region(machine, "fixed");
 	UINT8 *sbuf = malloc_or_die(0x20000);
 
 	UINT8 *dst = malloc_or_die(0x200000);
@@ -241,10 +249,14 @@ void decrypt_kf10thep(void)
 	free(sbuf);
 }
 
-static void kf2k5uni_px_decrypt( void )
+
+/* The King of Fighters 10th Anniversary 2005 Unique (The King of Fighters 2002 bootleg) */
+
+
+static void kf2k5uni_px_decrypt( running_machine *machine )
 {
 	int i, j, ofst;
-	UINT8 *src = memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
+	UINT8 *src = memory_region( machine, "main" );
 	UINT8 *dst = malloc_or_die(0x80);
 
 	for (i = 0; i < 0x800000; i+=0x80)
@@ -261,38 +273,77 @@ static void kf2k5uni_px_decrypt( void )
 	memcpy(src, src + 0x600000, 0x100000); // Seems to be the same as kof10th
 }
 
-static void kf2k5uni_sx_decrypt( void )
+static void kf2k5uni_sx_decrypt( running_machine *machine )
 {
 	int i;
-	UINT8 *srom = memory_region( NEOGEO_REGION_FIXED_LAYER_CARTRIDGE );
+	UINT8 *srom = memory_region( machine, "fixed" );
 
 	for (i = 0; i < 0x20000; i++)
 		srom[i] = BITSWAP8(srom[i], 4, 5, 6, 7, 0, 1, 2, 3);
 }
 
-static void kf2k5uni_mx_decrypt( void )
+static void kf2k5uni_mx_decrypt( running_machine *machine )
 {
 	int i;
-	UINT8 *mrom = memory_region( NEOGEO_REGION_AUDIO_CPU_CARTRIDGE );
+	UINT8 *mrom = memory_region( machine, "audio" );
 
 	for (i = 0; i < 0x30000; i++)
 		mrom[i] = BITSWAP8(mrom[i], 4, 5, 6, 7, 0, 1, 2, 3);
 }
 
-void decrypt_kf2k5uni(void)
+void decrypt_kf2k5uni( running_machine *machine )
 {
-	kf2k5uni_px_decrypt();
-	kf2k5uni_sx_decrypt();
-	kf2k5uni_mx_decrypt();
+	kf2k5uni_px_decrypt(machine);
+	kf2k5uni_sx_decrypt(machine);
+	kf2k5uni_mx_decrypt(machine);
 }
 
-/* Kof2002 Magic Plus */
 
-void kf2k2mp_decrypt( void )
+/* The King of Fighters 2002 (bootleg) */
+
+
+// Thanks to IQ_132 for the info
+void kof2002b_gfx_decrypt(running_machine *machine, UINT8 *src, int size)
+{
+	int i, j;
+	int t[ 8 ][ 10 ] =
+	{
+		{ 0, 8, 7, 3, 4, 5, 6, 2, 1 },
+		{ 1, 0, 8, 4, 5, 3, 7, 6, 2 },
+		{ 2, 1, 0, 3, 4, 5, 8, 7, 6 },
+		{ 6, 2, 1, 5, 3, 4, 0, 8, 7 },
+		{ 7, 6, 2, 5, 3, 4, 1, 0, 8 },
+		{ 0, 1, 2, 3, 4, 5, 6, 7, 8 },
+		{ 2, 1, 0, 4, 5, 3, 6, 7, 8 },
+		{ 8, 0, 7, 3, 4, 5, 6, 2, 1 },
+	};
+
+	UINT8 *dst = malloc_or_die( 0x10000 );
+
+	for ( i = 0; i < size; i+=0x10000 )
+	{
+		memcpy( dst, src+i, 0x10000 );
+
+		for ( j = 0; j < 0x200; j++ )
+		{
+			int n = (( j % 0x40) / 8 );
+			int ofst = BITSWAP16(j, 15, 14, 13, 12, 11, 10, 9, t[n][0], t[n][1], t[n][2],
+								 t[n][3], t[n][4], t[n][5], t[n][6], t[n][7], t[n][8]);
+			memcpy( src+i+ofst*128, dst+j*128, 128 );
+		}
+	}
+	free( dst );
+}
+
+
+/* The King of Fighters 2002 Magic Plus (bootleg) */
+
+
+void kf2k2mp_decrypt( running_machine *machine )
 {
 	int i,j;
 
-	UINT8 *src = memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE);
+	UINT8 *src = memory_region(machine, "main");
 	UINT8 *dst = malloc_or_die(0x80);
 
 	memmove(src, src + 0x300000, 0x500000);
@@ -309,12 +360,13 @@ void kf2k2mp_decrypt( void )
 	free(dst);
 }
 
-/* Kof2002 Magic Plus 2 */
+
+/* The King of Fighters 2002 Magic Plus II (bootleg) */
 
 
-void kof2km2_px_decrypt( void )
+void kf2k2mp2_px_decrypt( running_machine *machine )
 {
-	UINT8 *src = memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE);
+	UINT8 *src = memory_region(machine, "main");
 	UINT8 *dst = malloc_or_die(0x600000);
 
 	memcpy (dst + 0x000000, src + 0x1C0000, 0x040000);
@@ -328,14 +380,15 @@ void kof2km2_px_decrypt( void )
 
 /* Crouching Tiger Hidden Dragon 2003 (bootleg of King of Fighters 2001) */
 
+
 /* descrambling information from razoola */
-static void cthd2003_neogeo_gfx_address_fix_do(int start, int end, int bit3shift, int bit2shift, int bit1shift, int bit0shift)
+static void cthd2003_neogeo_gfx_address_fix_do(running_machine *machine, int start, int end, int bit3shift, int bit2shift, int bit1shift, int bit0shift)
 {
 	int i,j;
 	int tilesize=128;
 
 	UINT8* rom = malloc_or_die(16*tilesize);	// 16 tiles buffer
-	UINT8* realrom = memory_region(NEOGEO_REGION_SPRITES) + start*tilesize;
+	UINT8* realrom = memory_region(machine, "sprites") + start*tilesize;
 
 	for (i = 0; i < (end-start)/16; i++) {
 		for (j = 0; j < 16; j++) {
@@ -352,43 +405,43 @@ static void cthd2003_neogeo_gfx_address_fix_do(int start, int end, int bit3shift
 	free(rom);
 }
 
-static void cthd2003_neogeo_gfx_address_fix(int start, int end)
+static void cthd2003_neogeo_gfx_address_fix(running_machine *machine, int start, int end)
 {
-	cthd2003_neogeo_gfx_address_fix_do(start+512*0, end+512*0, 0,3,2,1);
-	cthd2003_neogeo_gfx_address_fix_do(start+512*1, end+512*1, 1,0,3,2);
-	cthd2003_neogeo_gfx_address_fix_do(start+512*2, end+512*2, 2,1,0,3);
+	cthd2003_neogeo_gfx_address_fix_do(machine, start+512*0, end+512*0, 0,3,2,1);
+	cthd2003_neogeo_gfx_address_fix_do(machine, start+512*1, end+512*1, 1,0,3,2);
+	cthd2003_neogeo_gfx_address_fix_do(machine, start+512*2, end+512*2, 2,1,0,3);
 	// skip 3 & 4
-	cthd2003_neogeo_gfx_address_fix_do(start+512*5, end+512*5, 0,1,2,3);
-	cthd2003_neogeo_gfx_address_fix_do(start+512*6, end+512*6, 0,1,2,3);
-	cthd2003_neogeo_gfx_address_fix_do(start+512*7, end+512*7, 0,2,3,1);
+	cthd2003_neogeo_gfx_address_fix_do(machine, start+512*5, end+512*5, 0,1,2,3);
+	cthd2003_neogeo_gfx_address_fix_do(machine, start+512*6, end+512*6, 0,1,2,3);
+	cthd2003_neogeo_gfx_address_fix_do(machine, start+512*7, end+512*7, 0,2,3,1);
 }
 
-static void cthd2003_c(int pow)
+static void cthd2003_c(running_machine *machine, int pow)
 {
 	int i;
 
 	for (i=0; i<=192; i+=8)
-		cthd2003_neogeo_gfx_address_fix(i*512,i*512+512);
+		cthd2003_neogeo_gfx_address_fix(machine, i*512,i*512+512);
 
 	for (i=200; i<=392; i+=8)
-		cthd2003_neogeo_gfx_address_fix(i*512,i*512+512);
+		cthd2003_neogeo_gfx_address_fix(machine, i*512,i*512+512);
 
 	for (i=400; i<=592; i+=8)
-		cthd2003_neogeo_gfx_address_fix(i*512,i*512+512);
+		cthd2003_neogeo_gfx_address_fix(machine, i*512,i*512+512);
 
 	for (i=600; i<=792; i+=8)
-		cthd2003_neogeo_gfx_address_fix(i*512,i*512+512);
+		cthd2003_neogeo_gfx_address_fix(machine, i*512,i*512+512);
 
 	for (i=800; i<=992; i+=8)
-		cthd2003_neogeo_gfx_address_fix(i*512,i*512+512);
+		cthd2003_neogeo_gfx_address_fix(machine, i*512,i*512+512);
 
 	for (i=1000; i<=1016; i+=8)
-		cthd2003_neogeo_gfx_address_fix(i*512,i*512+512);
+		cthd2003_neogeo_gfx_address_fix(machine, i*512,i*512+512);
 }
 
-void decrypt_cthd2003(void)
+void decrypt_cthd2003( running_machine *machine )
 {
-	UINT8 *romdata = memory_region(NEOGEO_REGION_FIXED_LAYER_CARTRIDGE);
+	UINT8 *romdata = memory_region(machine, "fixed");
 	UINT8 *tmp = malloc_or_die(8*128*128);
 
 	memcpy(tmp+8*0*128, romdata+8*0*128, 8*32*128);
@@ -397,7 +450,7 @@ void decrypt_cthd2003(void)
 	memcpy(tmp+8*96*128, romdata+8*96*128, 8*32*128);
 	memcpy(romdata, tmp, 8*128*128);
 
-	romdata = memory_region(NEOGEO_REGION_AUDIO_CPU_CARTRIDGE)+0x10000;
+	romdata = memory_region(machine, "audio")+0x10000;
  	memcpy(tmp+8*0*128, romdata+8*0*128, 8*32*128);
 	memcpy(tmp+8*32*128, romdata+8*64*128, 8*32*128);
  	memcpy(tmp+8*64*128, romdata+8*32*128, 8*32*128);
@@ -408,7 +461,7 @@ void decrypt_cthd2003(void)
 
 	memcpy(romdata-0x10000,romdata,0x10000);
 
-	cthd2003_c(0);
+	cthd2003_c(machine, 0);
 }
 
 static WRITE16_HANDLER ( cthd2003_bankswitch_w )
@@ -421,18 +474,18 @@ static WRITE16_HANDLER ( cthd2003_bankswitch_w )
 	if (offset == 0)
 	{
 		bankaddress = 0x100000 + cthd2003_banks[data&7]*0x100000;
-		neogeo_set_main_cpu_bank_address(bankaddress);
+		neogeo_set_main_cpu_bank_address(space, bankaddress);
 	}
 }
 
-void patch_cthd2003( void )
+void patch_cthd2003( running_machine *machine )
 {
 	/* patches thanks to razoola */
 	int i;
-	UINT16 *mem16 = (UINT16 *)memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE);
+	UINT16 *mem16 = (UINT16 *)memory_region(machine, "main");
 
 	/* special ROM banking handler */
-	memory_install_write16_handler(0, ADDRESS_SPACE_PROGRAM, 0x2ffff0, 0x2fffff, 0, 0, cthd2003_bankswitch_w);
+	memory_install_write16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2ffff0, 0x2fffff, 0, 0, cthd2003_bankswitch_w);
 
 	// theres still a problem on the character select screen but it seems to be related to cpu core timing issues,
 	// overclocking the 68k prevents it.
@@ -466,12 +519,14 @@ void patch_cthd2003( void )
  	mem16[0x9943e/2] = 0xdd03;
 }
 
+
 /* Crouching Tiger Hidden Dragon 2003 Super Plus (bootleg of King of Fighters 2001) */
 
-static void ct2k3sp_sx_decrypt( void )
+
+static void ct2k3sp_sx_decrypt( running_machine *machine )
 {
-	int rom_size = memory_region_length( NEOGEO_REGION_FIXED_LAYER_CARTRIDGE );
-	UINT8 *rom = memory_region( NEOGEO_REGION_FIXED_LAYER_CARTRIDGE );
+	int rom_size = memory_region_length( machine, "fixed" );
+	UINT8 *rom = memory_region( machine, "fixed" );
 	UINT8 *buf = malloc_or_die( rom_size );
 	int i;
 	int ofst;
@@ -498,9 +553,9 @@ static void ct2k3sp_sx_decrypt( void )
 	free( buf );
 }
 
-void decrypt_ct2k3sp(void)
+void decrypt_ct2k3sp( running_machine *machine )
 {
-	UINT8 *romdata = memory_region(NEOGEO_REGION_AUDIO_CPU_CARTRIDGE)+0x10000;
+	UINT8 *romdata = memory_region(machine, "audio")+0x10000;
 	UINT8*tmp = malloc_or_die(8*128*128);
 	memcpy(tmp+8*0*128, romdata+8*0*128, 8*32*128);
 	memcpy(tmp+8*32*128, romdata+8*64*128, 8*32*128);
@@ -510,15 +565,17 @@ void decrypt_ct2k3sp(void)
 
 	free(tmp);
 	memcpy(romdata-0x10000,romdata,0x10000);
-	ct2k3sp_sx_decrypt();
-	cthd2003_c(0);
+	ct2k3sp_sx_decrypt(machine);
+	cthd2003_c(machine, 0);
 }
 
+
 /* Crouching Tiger Hidden Dragon 2003 Super Plus alternate (bootleg of King of Fighters 2001) */
 
-void decrypt_ct2k3sa(void)
+
+void decrypt_ct2k3sa( running_machine *machine )
 {
-	UINT8 *romdata = memory_region(NEOGEO_REGION_AUDIO_CPU_CARTRIDGE)+0x10000;
+	UINT8 *romdata = memory_region(machine, "audio")+0x10000;
 	UINT8*tmp = malloc_or_die(8*128*128);
 	memcpy(tmp+8*0*128, romdata+8*0*128, 8*32*128);
 	memcpy(tmp+8*32*128, romdata+8*64*128, 8*32*128);
@@ -528,14 +585,14 @@ void decrypt_ct2k3sa(void)
 
 	free(tmp);
 	memcpy(romdata-0x10000,romdata,0x10000);
-	cthd2003_c(0);
+	cthd2003_c(machine, 0);
 }
 
-void patch_ct2k3sa( void )
+void patch_ct2k3sa( running_machine *machine )
 {
 	/* patches thanks to razoola - same as for cthd2003*/
 	int i;
-	UINT16 *mem16 = (UINT16 *)memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE);
+	UINT16 *mem16 = (UINT16 *)memory_region(machine, "main");
 
 	// theres still a problem on the character select screen but it seems to be related to cpu core timing issues,
 	// overclocking the 68k prevents it.
@@ -570,11 +627,13 @@ void patch_ct2k3sa( void )
  	mem16[0x9943e/2] = 0xdd03;
 }
 
+
 /* King of Fighters Special Edition 2004 (bootleg of King of Fighters 2002) */
 
-void decrypt_kof2k4se_68k( void )
+
+void decrypt_kof2k4se_68k( running_machine *machine )
 {
-	UINT8 *src = memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE)+0x100000;
+	UINT8 *src = memory_region(machine, "main")+0x100000;
 	UINT8 *dst = malloc_or_die(0x400000);
 	int i;
 	static const int sec[] = {0x300000,0x200000,0x100000,0x000000};
@@ -587,22 +646,24 @@ void decrypt_kof2k4se_68k( void )
 			free(dst);
 }
 
-/* Lans2004 (bootleg of Shock Troopers 2) */
 
-void lans2004_vx_decrypt( void )
+/* Lansquenet 2004 (Shock Troopers - 2nd Squad bootleg) */
+
+
+void lans2004_vx_decrypt( running_machine *machine )
 {
 	int i;
-	UINT8 *rom = memory_region( NEOGEO_REGION_AUDIO_DATA_1 );
+	UINT8 *rom = memory_region( machine, "ym" );
 	for (i = 0; i < 0xA00000; i++)
 		rom[i] = BITSWAP8(rom[i], 0, 1, 5, 4, 3, 2, 6, 7);
 }
 
-void lans2004_decrypt_68k( void )
+void lans2004_decrypt_68k( running_machine *machine )
 {
 	/* Descrambling P ROMs - Thanks to Razoola for the info */
 	int i;
-	UINT8 *src = memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
-	UINT16 *rom = (UINT16*)memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
+	UINT8 *src = memory_region( machine, "main" );
+	UINT16 *rom = (UINT16*)memory_region( machine, "main" );
 	UINT8 *dst = malloc_or_die(0x600000);
 
 	{
@@ -625,6 +686,7 @@ void lans2004_decrypt_68k( void )
 		}
 	}
 
+	/* Patched by protection chip (Altera) ? */
 	rom[0x2D15C/2] = 0x000B;
 	rom[0x2D15E/2] = 0xBB00;
 	rom[0x2D1E4/2] = 0x6002;
@@ -634,48 +696,54 @@ void lans2004_decrypt_68k( void )
 	rom[0xBBE42/2] = 0x6002;
 }
 
+
+/* Metal Slug 5 Plus (bootleg) */
+
+
 static READ16_HANDLER( mslug5_prot_r )
 {
-	logerror("PC %06x: access protected\n",activecpu_get_pc());
+	logerror("PC %06x: access protected\n",cpu_get_pc(space->cpu));
 	return 0xa0;
 }
 
 static WRITE16_HANDLER ( ms5plus_bankswitch_w )
 {
 	int bankaddress;
-	logerror("offset: %06x PC %06x: set banking %04x\n",offset,activecpu_get_pc(),data);
+	logerror("offset: %06x PC %06x: set banking %04x\n",offset,cpu_get_pc(space->cpu),data);
 	if ((offset == 0)&&(data == 0xa0))
 	{
 		bankaddress=0xa0;
-		neogeo_set_main_cpu_bank_address(bankaddress);
-		logerror("offset: %06x PC %06x: set banking %04x\n\n",offset,activecpu_get_pc(),bankaddress);
+		neogeo_set_main_cpu_bank_address(space, bankaddress);
+		logerror("offset: %06x PC %06x: set banking %04x\n\n",offset,cpu_get_pc(space->cpu),bankaddress);
 	}
 	else if(offset == 2)
 	{
 		data=data>>4;
 		//data=data&7;
 		bankaddress=data*0x100000;
-		neogeo_set_main_cpu_bank_address(bankaddress);
-		logerror("offset: %06x PC %06x: set banking %04x\n\n",offset,activecpu_get_pc(),bankaddress);
+		neogeo_set_main_cpu_bank_address(space, bankaddress);
+		logerror("offset: %06x PC %06x: set banking %04x\n\n",offset,cpu_get_pc(space->cpu),bankaddress);
 	}
 }
 
-void install_ms5plus_protection(void)
+void install_ms5plus_protection(running_machine *machine)
 {
 	// special ROM banking handler / additional protection
-	memory_install_readwrite16_handler(0, ADDRESS_SPACE_PROGRAM,0x2ffff0, 0x2fffff,0, 0, mslug5_prot_r, ms5plus_bankswitch_w);
+	memory_install_readwrite16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM),0x2ffff0, 0x2fffff,0, 0, mslug5_prot_r, ms5plus_bankswitch_w);
 }
 
 
+/* SNK vs. CAPCOM SVC CHAOS (bootleg) */
 
-void svcboot_px_decrypt( void )
+
+void svcboot_px_decrypt( running_machine *machine )
 {
 	static const UINT8 sec[] = {
 		0x06, 0x07, 0x01, 0x02, 0x03, 0x04, 0x05, 0x00
 	};
 	int i;
-	int size = memory_region_length( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
-	UINT8 *src = memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
+	int size = memory_region_length( machine, "main" );
+	UINT8 *src = memory_region( machine, "main" );
 	UINT8 *dst = malloc_or_die( size );
 	int ofst;
 	for( i = 0; i < size / 0x100000; i++ ){
@@ -689,9 +757,7 @@ void svcboot_px_decrypt( void )
 	free( dst );
 }
 
-
-
-void svcboot_cx_decrypt( void )
+void svcboot_cx_decrypt( running_machine *machine )
 {
 	static const UINT8 idx_tbl[ 0x10 ] = {
 		0, 1, 0, 1, 2, 3, 2, 3, 3, 4, 3, 4, 4, 5, 4, 5,
@@ -705,8 +771,8 @@ void svcboot_cx_decrypt( void )
 		{ 3, 0, 2, 1 },
 	};
 	int i;
-	int size = memory_region_length( NEOGEO_REGION_SPRITES );
-	UINT8 *src = memory_region( NEOGEO_REGION_SPRITES );
+	int size = memory_region_length( machine, "sprites" );
+	UINT8 *src = memory_region( machine, "sprites" );
 	UINT8 *dst = malloc_or_die( size );
 	int ofst;
 	memcpy( dst, src, size );
@@ -724,14 +790,16 @@ void svcboot_cx_decrypt( void )
 }
 
 
+/* SNK vs. CAPCOM SVC CHAOS Plus (bootleg set 1) */
 
-void svcplus_px_decrypt( void )
+
+void svcplus_px_decrypt( running_machine *machine )
 {
 	static const int sec[] = {
 		0x00, 0x03, 0x02, 0x05, 0x04, 0x01
 	};
-	int size = memory_region_length( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
-	UINT8 *src = memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
+	int size = memory_region_length( machine, "main" );
+	UINT8 *src = memory_region( machine, "main" );
 	UINT8 *dst = malloc_or_die( size );
 	int i;
 	int ofst;
@@ -751,12 +819,10 @@ void svcplus_px_decrypt( void )
 	free( dst );
 }
 
-
-
-void svcplus_px_hack( void )
+void svcplus_px_hack( running_machine *machine )
 {
 	/* patched by the protection chip? */
-	UINT8 *src = memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
+	UINT8 *src = memory_region( machine, "main" );
 	src[ 0x0f8010 ] = 0x40;
 	src[ 0x0f8011 ] = 0x04;
 	src[ 0x0f8012 ] = 0x00;
@@ -767,14 +833,18 @@ void svcplus_px_hack( void )
 	src[ 0x0f802c ] = 0x16;
 }
 
-void svcplusa_px_decrypt( void )
+
+/* SNK vs. CAPCOM SVC CHAOS Plus (bootleg set 2) */
+
+
+void svcplusa_px_decrypt( running_machine *machine )
 {
 	int i;
 	static const int sec[] = {
 		0x01, 0x02, 0x03, 0x04, 0x05, 0x00
 	};
-	int size = memory_region_length( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
-	UINT8 *src = memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
+	int size = memory_region_length( machine, "main" );
+	UINT8 *src = memory_region( machine, "main" );
 	UINT8 *dst = malloc_or_die( size );
 	memcpy( dst, src, size );
 	for( i = 0; i < 6; i++ ){
@@ -784,14 +854,16 @@ void svcplusa_px_decrypt( void )
 }
 
 
+/* SNK vs. CAPCOM SVC CHAOS Super Plus (bootleg) */
 
-void svcsplus_px_decrypt( void )
+
+void svcsplus_px_decrypt( running_machine *machine )
 {
 	static const int sec[] = {
 		0x06, 0x07, 0x01, 0x02, 0x03, 0x04, 0x05, 0x00
 	};
-	int size = memory_region_length( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
-	UINT8 *src = memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
+	int size = memory_region_length( machine, "main" );
+	UINT8 *src = memory_region( machine, "main" );
 	UINT8 *dst = malloc_or_die( size );
 	int i;
 	int ofst;
@@ -807,12 +879,10 @@ void svcsplus_px_decrypt( void )
 	free( dst );
 }
 
-
-
-void svcsplus_px_hack( void )
+void svcsplus_px_hack( running_machine *machine )
 {
 	/* patched by the protection chip? */
-	UINT16 *mem16 = (UINT16 *)memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE);
+	UINT16 *mem16 = (UINT16 *)memory_region(machine, "main");
 	mem16[0x9e90/2] = 0x000f;
 	mem16[0x9e92/2] = 0xc9c0;
 	mem16[0xa10c/2] = 0x4eb9;
@@ -832,17 +902,14 @@ static WRITE16_HANDLER( mv0_bankswitch_w )
 {
     UINT32 bankaddress = (mv0_bank_ram[ 0 ] >> 8) + (mv0_bank_ram[ 1 ] << 8) + 0x100000;
 	COMBINE_DATA( &mv0_bank_ram[ offset ] );
-    neogeo_set_main_cpu_bank_address( bankaddress );
+    neogeo_set_main_cpu_bank_address( space, bankaddress );
 }
 #endif
 
-/* I think the code for the kof2003 bootlegs is wrong, they don't work */
 
-/***************************************************************************
- kof2003b
-****************************************************************************/
+/* The King of Fighters 2003 (bootleg set 1) */
+
 
-/* kof2003 bootleg init info */
 static UINT16 kof2003_tbl[4096];
 
 static READ16_HANDLER( kof2003_r)
@@ -857,12 +924,12 @@ static WRITE16_HANDLER( kof2003_w )
 		UINT8* cr = (UINT8 *)kof2003_tbl;
 		UINT32 address = (cr[BYTE_XOR_LE(0x1ff3)]<<16)|(cr[BYTE_XOR_LE(0x1ff2)]<<8)|cr[BYTE_XOR_LE(0x1ff1)];
 		UINT8 prt = cr[BYTE_XOR_LE(0x1ff2)];
-		UINT8* mem = (UINT8 *)memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE);
+		UINT8* mem = (UINT8 *)memory_region(space->machine, "main");
 
 		cr[BYTE_XOR_LE(0x1ff0)] =  0xa0;
 		cr[BYTE_XOR_LE(0x1ff1)] &= 0xfe;
 		cr[BYTE_XOR_LE(0x1ff3)] &= 0x7f;
-		neogeo_set_main_cpu_bank_address(address+0x100000);
+		neogeo_set_main_cpu_bank_address(space, address+0x100000);
 
 		mem[BYTE_XOR_LE(0x58196)] = prt;
 	}
@@ -875,17 +942,17 @@ static WRITE16_HANDLER( kof2003p_w )
 		UINT8* cr = (UINT8 *)kof2003_tbl;
 		UINT32 address = (cr[BYTE_XOR_LE(0x1ff3)]<<16)|(cr[BYTE_XOR_LE(0x1ff2)]<<8)|cr[BYTE_XOR_LE(0x1ff0)];
 		UINT8 prt = cr[BYTE_XOR_LE(0x1ff2)];
-		UINT8* mem = (UINT8 *)memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE);
+		UINT8* mem = (UINT8 *)memory_region(space->machine, "main");
 
 		cr[BYTE_XOR_LE(0x1ff0)] &= 0xfe;
 		cr[BYTE_XOR_LE(0x1ff3)] &= 0x7f;
-		neogeo_set_main_cpu_bank_address(address+0x100000);
+		neogeo_set_main_cpu_bank_address(space, address+0x100000);
 
 		mem[BYTE_XOR_LE(0x58196)] = prt;
 	}
 }
 
-void kof2003b_px_decrypt( void )
+void kf2k3bl_px_decrypt( running_machine *machine )
 {
 	int i;
 	static const UINT8 sec[] = {
@@ -893,7 +960,7 @@ void kof2003b_px_decrypt( void )
 	};
 
     int rom_size = 0x800000;
-    UINT8 *rom = memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
+    UINT8 *rom = memory_region( machine, "main" );
     UINT8 *buf = malloc_or_die( rom_size );
     memcpy( buf, rom, rom_size );
 
@@ -903,20 +970,19 @@ void kof2003b_px_decrypt( void )
     free( buf );
 }
 
-void kof2003b_install_protection(void)
+void kf2k3bl_install_protection(running_machine *machine)
 {
-    memory_install_readwrite16_handler( 0, ADDRESS_SPACE_PROGRAM, 0x2fe000, 0x2fffff, 0, 0, kof2003_r, kof2003_w );
+    memory_install_readwrite16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2fe000, 0x2fffff, 0, 0, kof2003_r, kof2003_w );
 }
 
 
-/***************************************************************************
- kof2k3pl
-***************************************************************************/
+/* The King of Fighters 2004 Plus / Hero (The King of Fighters 2003 bootleg) */
 
-void kof2k3pl_px_decrypt( void )
+
+void kf2k3pl_px_decrypt( running_machine *machine )
 {
 	UINT16*tmp = malloc_or_die(0x100000);
-	UINT16*rom = (UINT16*)memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
+	UINT16*rom = (UINT16*)memory_region( machine, "main" );
 	int j;
 	int i;
 
@@ -932,21 +998,19 @@ void kof2k3pl_px_decrypt( void )
 	rom[0xf38ac/2] = 0x4e75;
 }
 
-void kf2k3pl_install_protection(void)
+void kf2k3pl_install_protection(running_machine *machine)
 {
-    memory_install_readwrite16_handler( 0, ADDRESS_SPACE_PROGRAM, 0x2fe000, 0x2fffff, 0, 0, kof2003_r, kof2003p_w );
+    memory_install_readwrite16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2fe000, 0x2fffff, 0, 0, kof2003_r, kof2003p_w );
 }
 
 
-/***************************************************************************
- kof2k3up
-***************************************************************************/
+/* The King of Fighters 2004 Ultra Plus (The King of Fighters 2003 bootleg) */
 
 
-void kof2k3up_px_decrypt( void )
+void kf2k3upl_px_decrypt( running_machine *machine )
 {
 	{
-		UINT8 *src = memory_region(NEOGEO_REGION_MAIN_CPU_CARTRIDGE);
+		UINT8 *src = memory_region(machine, "main");
 		memmove(src+0x100000, src, 0x600000);
 		memmove(src, src+0x700000, 0x100000);
 	}
@@ -955,8 +1019,8 @@ void kof2k3up_px_decrypt( void )
 
 		int ofst;
 		int i;
-		UINT8 *rom = memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE ) + 0xfe000;
-		UINT8 *buf = memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE ) + 0xd0610;
+		UINT8 *rom = memory_region( machine, "main" ) + 0xfe000;
+		UINT8 *buf = memory_region( machine, "main" ) + 0xd0610;
 
 		for( i = 0; i < 0x2000 / 2; i++ ){
 			ofst = (i & 0xff00) + BITSWAP8( (i & 0x00ff), 7, 6, 0, 4, 3, 2, 1, 5 );
@@ -965,17 +1029,19 @@ void kof2k3up_px_decrypt( void )
 	}
 }
 
-void kof2k3up_install_protection(void)
+void kf2k3upl_install_protection(running_machine *machine)
 {
-    memory_install_readwrite16_handler( 0, ADDRESS_SPACE_PROGRAM, 0x2fe000, 0x2fffff, 0, 0, kof2003_r, kof2003_w );
+    memory_install_readwrite16_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2fe000, 0x2fffff, 0, 0, kof2003_r, kof2003_w );
 }
 
-/* samsho5bl */
 
-void samsh5bl_px_decrypt( void )
+/* Samurai Shodown V / Samurai Spirits Zero (bootleg) */
+
+
+void samsho5b_px_decrypt( running_machine *machine )
 {
-	int px_size = memory_region_length( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
-	UINT8 *rom = memory_region( NEOGEO_REGION_MAIN_CPU_CARTRIDGE );
+	int px_size = memory_region_length( machine, "main" );
+	UINT8 *rom = memory_region( machine, "main" );
 	UINT8 *buf = malloc_or_die( px_size );
 	int ofst;
 	int i;
@@ -999,3 +1065,61 @@ void samsh5bl_px_decrypt( void )
 }
 
 
+void samsho5b_vx_decrypt( running_machine *machine )
+{
+	int vx_size = memory_region_length( machine, "ym" );
+	UINT8 *rom = memory_region( machine, "ym" );
+	int i;
+
+	for( i = 0; i < vx_size; i++ )
+		rom[ i ] = BITSWAP8( rom[ i ], 0, 1, 5, 4, 3, 2, 6, 7 );
+}
+
+
+/* Matrimelee / Shin Gouketsuji Ichizoku Toukon (bootleg) */
+
+
+#define MATRIMBLZ80( i ) ( i^(BITSWAP8(i&0x3,4,3,1,2,0,7,6,5)<<8) )
+
+void matrimbl_decrypt( running_machine *machine )
+{
+	/* decrypt Z80 */
+	UINT8 *rom = memory_region( machine, "audio" )+0x10000;
+	UINT8 *buf = malloc_or_die( 0x20000 );
+	int i, j=0;
+	memcpy( buf, rom, 0x20000 );
+	for( i=0x00000; i<0x20000; i++ )
+	{
+		if ( i&0x10000 )
+		{
+			if ( i&0x800 )
+			{
+				j=MATRIMBLZ80( i );
+				j=j^0x10000;
+			}
+			else
+			{
+				j=MATRIMBLZ80(( i^0x01 ));
+			}
+		}
+		else
+		{
+			if ( i&0x800 )
+			{
+				j=MATRIMBLZ80(( i^0x01 ));
+				j=j^0x10000;
+			}
+			else
+			{
+				j=MATRIMBLZ80( i );
+			}
+		}
+		rom[ j ]=buf[ i ];
+	}
+	free( buf );
+	memcpy( rom-0x10000, rom, 0x10000 );
+
+	/* decrypt gfx */
+	cthd2003_c( machine, 0 );
+}
+
