@@ -133,7 +133,7 @@ static UINT16 read16(int address)
 
 *****************************/
 
-static void oki_play_sample(int sample_no)
+static void oki_play_sample(const address_space *space, int sample_no)
 {
 	UINT16 table_start = (sample_no & 0x80) ? read16(SAMPLE_TABLE_1) : read16(SAMPLE_TABLE_0);
 	UINT8 byte1 = read8(table_start + 2 * (sample_no & 0x7f) + 0);
@@ -144,9 +144,9 @@ static void oki_play_sample(int sample_no)
 	{
 		// stop all channels
 		if (chip == 0)
-			OKIM6295_data_0_w(0, 0x78 );
+			okim6295_data_0_w(space, 0, 0x78 );
 		else
-			OKIM6295_data_1_w(0, 0x78 );
+			okim6295_data_1_w(space, 0, 0x78 );
 	}
 	else
 	{
@@ -161,13 +161,13 @@ static void oki_play_sample(int sample_no)
 
 		// stop channel
 		if (chip == 0)
-			OKIM6295_data_0_w(0, (0x08 << ch) );
+			okim6295_data_0_w(space, 0, (0x08 << ch) );
 		else
-			OKIM6295_data_1_w(0, (0x08 << ch) );
+			okim6295_data_1_w(space, 0, (0x08 << ch) );
 
 		if (sample != 0)
 		{
-			UINT8 *rom = memory_region(REGION_SOUND1 + chip);
+			UINT8 *rom = memory_region(space->machine, (chip == 0) ? "oki1" : "oki2");
 			int bank = (byte2 & 0x0c) >> 2;
 			int vol = (byte2 & 0x70) >> 4;
 
@@ -176,21 +176,21 @@ static void oki_play_sample(int sample_no)
 
 			if (chip == 0)
 			{
-				OKIM6295_data_0_w(0, 0x80 | sample );
-				OKIM6295_data_0_w(0, (0x10 << ch) | vol );
+				okim6295_data_0_w(space, 0, 0x80 | sample );
+				okim6295_data_0_w(space, 0, (0x10 << ch) | vol );
 			}
 			else
 			{
-				OKIM6295_data_1_w(0, 0x80 | sample );
-				OKIM6295_data_1_w(0, (0x10 << ch) | vol );
+				okim6295_data_1_w(space, 0, 0x80 | sample );
+				okim6295_data_1_w(space, 0, (0x10 << ch) | vol );
 			}
 		}
 	}
 }
 
-static void oki_update_state(void)
+static void oki_update_state(const address_space *space)
 {
-	NMK004_state.oki_playing = ((OKIM6295_status_1_r(0) & 0x0f) << 4) | (OKIM6295_status_0_r(0) & 0x0f);
+	NMK004_state.oki_playing = ((okim6295_status_1_r(space, 0) & 0x0f) << 4) | (okim6295_status_0_r(space, 0) & 0x0f);
 }
 
 
@@ -201,7 +201,7 @@ static void oki_update_state(void)
 
 *****************************/
 
-static void effects_update(int channel)
+static void effects_update(const address_space *space, int channel)
 {
 	struct effects_control *effects = &NMK004_state.effects_control[channel];
 
@@ -233,7 +233,7 @@ static void effects_update(int channel)
 					switch (token)
 					{
 						case 0xef:	// play sample
-							oki_play_sample(read8(effects->current++));
+							oki_play_sample(space, read8(effects->current++));
 							break;
 
 						case 0xf6:	// jump
@@ -308,7 +308,7 @@ static void effects_update(int channel)
 
 *****************************/
 
-static void fm_update(int channel)
+static void fm_update(const address_space *space, int channel)
 {
 	struct fm_control *fm = &NMK004_state.fm_control[channel];
 
@@ -348,7 +348,7 @@ static void fm_update(int channel)
 					switch (token)
 					{
 //                      case 0xef:  // play sample
-//                          oki_play_sample(read8(fm->current++));
+//                          oki_play_sample(machine, read8(fm->current++));
 //                          break;
 
 						case 0xf0:	// slot (for keyon ym2203 command)
@@ -356,8 +356,8 @@ static void fm_update(int channel)
 							fm->slot = read8(fm->current++);
 							if (channel < 3 || !(NMK004_state.fm_control[channel-3].flags & FM_FLAG_ACTIVE))
 							{
-								YM2203_control_port_0_w(0, 0x28);	// keyon/off
-								YM2203_write_port_0_w(0, channel % 3);
+								ym2203_control_port_0_w(space, 0, 0x28);	// keyon/off
+								ym2203_write_port_0_w(space, 0, channel % 3);
 							}
 							break;
 
@@ -585,7 +585,7 @@ popmessage("%02x %02x%02x%02x%02x %02x %02x%02x%02x%02x %02x %02x%02x%02x%02x",
 }
 
 
-static void fm_voices_update(void)
+static void fm_voices_update(const address_space *space )
 {
 	static const int ym2203_registers[0x18] =
 	{
@@ -605,8 +605,8 @@ static void fm_voices_update(void)
 
 			for (i = 0; i < 0x18; i++)
 			{
-				YM2203_control_port_0_w(0, ym2203_registers[i] + channel);
-				YM2203_write_port_0_w(0, fm1->voice_params[i]);
+				ym2203_control_port_0_w(space, 0, ym2203_registers[i] + channel);
+				ym2203_write_port_0_w(space, 0, fm1->voice_params[i]);
 			}
 		}
 
@@ -618,8 +618,8 @@ static void fm_voices_update(void)
 			{
 				for (i = 0; i < 0x18; i++)
 				{
-					YM2203_control_port_0_w(0, ym2203_registers[i] + channel);
-					YM2203_write_port_0_w(0, fm2->voice_params[i]);
+					ym2203_control_port_0_w(space, 0, ym2203_registers[i] + channel);
+					ym2203_write_port_0_w(space, 0, fm2->voice_params[i]);
 				}
 			}
 		}
@@ -627,25 +627,25 @@ static void fm_voices_update(void)
 
 		if (fm1->flags & FM_FLAG_ACTIVE)
 		{
-			YM2203_control_port_0_w(0, 0xb0 + channel);	// self-feedback
-			YM2203_write_port_0_w(0, fm1->self_feedback);
+			ym2203_control_port_0_w(space, 0, 0xb0 + channel);	// self-feedback
+			ym2203_write_port_0_w(space, 0, fm1->self_feedback);
 
-			YM2203_control_port_0_w(0, 0xa4 + channel);	// F-number
-			YM2203_write_port_0_w(0, fm1->f_number >> 8);
+			ym2203_control_port_0_w(space, 0, 0xa4 + channel);	// F-number
+			ym2203_write_port_0_w(space, 0, fm1->f_number >> 8);
 
-			YM2203_control_port_0_w(0, 0xa0 + channel);	// F-number
-			YM2203_write_port_0_w(0, fm1->f_number & 0xff);
+			ym2203_control_port_0_w(space, 0, 0xa0 + channel);	// F-number
+			ym2203_write_port_0_w(space, 0, fm1->f_number & 0xff);
 		}
 		else
 		{
-			YM2203_control_port_0_w(0, 0xb0 + channel);	// self-feedback
-			YM2203_write_port_0_w(0, fm2->self_feedback);
+			ym2203_control_port_0_w(space, 0, 0xb0 + channel);	// self-feedback
+			ym2203_write_port_0_w(space, 0, fm2->self_feedback);
 
-			YM2203_control_port_0_w(0, 0xa4 + channel);	// F-number
-			YM2203_write_port_0_w(0, fm2->f_number >> 8);
+			ym2203_control_port_0_w(space, 0, 0xa4 + channel);	// F-number
+			ym2203_write_port_0_w(space, 0, fm2->f_number >> 8);
 
-			YM2203_control_port_0_w(0, 0xa0 + channel);	// F-number
-			YM2203_write_port_0_w(0, fm2->f_number & 0xff);
+			ym2203_control_port_0_w(space, 0, 0xa0 + channel);	// F-number
+			ym2203_write_port_0_w(space, 0, fm2->f_number & 0xff);
 		}
 
 
@@ -654,8 +654,8 @@ static void fm_voices_update(void)
 		{
 			fm1->flags &= ~FM_FLAG_MUST_SEND_KEYON;
 
-			YM2203_control_port_0_w(0, 0x28);	// keyon/off
-			YM2203_write_port_0_w(0, fm1->slot | channel);
+			ym2203_control_port_0_w(space, 0, 0x28);	// keyon/off
+			ym2203_write_port_0_w(space, 0, fm1->slot | channel);
 		}
 
 		if (fm2->flags & FM_FLAG_MUST_SEND_KEYON)
@@ -664,8 +664,8 @@ static void fm_voices_update(void)
 
 			if (!(fm1->flags & FM_FLAG_ACTIVE))
 			{
-				YM2203_control_port_0_w(0, 0x28);	// keyon/off
-				YM2203_write_port_0_w(0, fm2->slot | channel);
+				ym2203_control_port_0_w(space, 0, 0x28);	// keyon/off
+				ym2203_write_port_0_w(space, 0, fm2->slot | channel);
 			}
 		}
 	}
@@ -679,7 +679,7 @@ static void fm_voices_update(void)
 
 *****************************/
 
-static void psg_update(int channel)
+static void psg_update(const address_space *space, int channel)
 {
 	struct psg_control *psg = &NMK004_state.psg_control[channel];
 
@@ -703,11 +703,11 @@ static void psg_update(int channel)
 			psg->flags &= ~PSG_FLAG_NOISE_NOT_ENABLED;
 
 			// enable noise, disable tone on this channel
-			YM2203_control_port_0_w(0, 0x07);
-			enable = YM2203_read_port_0_r(0);
+			ym2203_control_port_0_w(space, 0, 0x07);
+			enable = ym2203_read_port_0_r(space, 0);
 			enable |=  (0x01 << channel);	// disable tone
 			enable &= ~(0x08 << channel);	// enable noise
-			YM2203_write_port_0_w(0, enable);
+			ym2203_write_port_0_w(space, 0, enable);
 		}
 
 
@@ -741,11 +741,11 @@ static void psg_update(int channel)
 							psg->flags &= ~PSG_FLAG_NOISE_NOT_ENABLED;
 
 							// enable noise, disable tone on this channel
-							YM2203_control_port_0_w(0, 0x07);
-							enable = YM2203_read_port_0_r(0);
+							ym2203_control_port_0_w(space, 0, 0x07);
+							enable = ym2203_read_port_0_r(space, 0);
 							enable |=  (0x01 << channel);	// disable tone
 							enable &= ~(0x08 << channel);	// enable noise
-							YM2203_write_port_0_w(0, enable);
+							ym2203_write_port_0_w(space, 0, enable);
 							break;
 
 						case 0xf2:	// set volume shape
@@ -790,8 +790,8 @@ static void psg_update(int channel)
 							psg->volume_shape = 0;
 
 							// mute channel
-							YM2203_control_port_0_w(0, 8 + channel);
-							YM2203_write_port_0_w(0, 0);
+							ym2203_control_port_0_w(space, 0, 8 + channel);
+							ym2203_write_port_0_w(space, 0, 0);
 							return;
 					}
 				}
@@ -831,10 +831,10 @@ static void psg_update(int channel)
 
 					period >>= octave;
 
-					YM2203_control_port_0_w(0, 2 * channel + 1);
-					YM2203_write_port_0_w(0, (period & 0x0f00) >> 8);
-					YM2203_control_port_0_w(0, 2 * channel + 0);
-					YM2203_write_port_0_w(0, (period & 0x00ff));
+					ym2203_control_port_0_w(space, 0, 2 * channel + 1);
+					ym2203_write_port_0_w(space, 0, (period & 0x0f00) >> 8);
+					ym2203_control_port_0_w(space, 0, 2 * channel + 0);
+					ym2203_write_port_0_w(space, 0, (period & 0x00ff));
 
 					psg->note_period_hi_bits = (period & 0x0f00) >> 8;
 				}
@@ -847,15 +847,15 @@ static void psg_update(int channel)
 						psg->flags |= PSG_FLAG_NOISE_NOT_ENABLED;
 
 						// disable noise, enable tone on this channel
-						YM2203_control_port_0_w(0, 0x07);
-						enable = YM2203_read_port_0_r(0);
+						ym2203_control_port_0_w(space, 0, 0x07);
+						enable = ym2203_read_port_0_r(space, 0);
 						enable &= ~(0x01 << channel);	// enable tone
 						enable |=  (0x08 << channel);	// disable noise
-						YM2203_write_port_0_w(0, enable);
+						ym2203_write_port_0_w(space, 0, enable);
 					}
 
-					YM2203_control_port_0_w(0, 0x06);	// noise period
-					YM2203_write_port_0_w(0, psg->note);
+					ym2203_control_port_0_w(space, 0, 0x06);	// noise period
+					ym2203_write_port_0_w(space, 0, psg->note);
 					psg->note_period_hi_bits = psg->note;
 				}
 			}
@@ -880,8 +880,8 @@ static void psg_update(int channel)
 				volume = 0;
 
 			// set volume
-			YM2203_control_port_0_w(0, 8 + channel);
-			YM2203_write_port_0_w(0, volume & 0x0f);
+			ym2203_control_port_0_w(space, 0, 8 + channel);
+			ym2203_write_port_0_w(space, 0, volume & 0x0f);
 		}
 	}
 }
@@ -894,7 +894,7 @@ static void psg_update(int channel)
 
 *****************************/
 
-static void get_command(void)
+static void get_command(const address_space *space)
 {
 	static const UINT8 from_main[] =
 	{
@@ -931,7 +931,7 @@ static void get_command(void)
 
 		if ((cmd_table & 0xff00) == 0)
 		{
-			oki_play_sample(cmd_table);
+			oki_play_sample(space, cmd_table);
 		}
 		else
 		{
@@ -979,46 +979,47 @@ static void get_command(void)
 
 
 
-static void update_music(void)
+static void update_music(const address_space *space)
 {
 	int channel;
 
 	for (channel = 0; channel < FM_CHANNELS; channel++)
-		fm_update(channel);
-	fm_voices_update();
+		fm_update(space, channel);
+	fm_voices_update(space);
 
 	for (channel = 0; channel < PSG_CHANNELS; channel++)
-		psg_update(channel);
+		psg_update(space, channel);
 
 	for (channel = 0; channel < EFFECTS_CHANNELS; channel++)
-		effects_update(channel);
+		effects_update(space, channel);
 }
 
 
 
-void NMK004_irq(int irq)
+void NMK004_irq(running_machine *machine, int irq)
 {
-	int status;
-
-	if (!irq) return;
-
-	status = YM2203_status_port_0_r(0);
-
-	if (status & 1)	// timer A expired
+	if (irq)
 	{
-		oki_update_state();
-		get_command();
-		update_music();
+		const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+		int status = ym2203_status_port_0_r(space,0);
 
-		// restart timer
-		YM2203_control_port_0_w(0, 0x27);
-		YM2203_write_port_0_w(0, 0x15);
+		if (status & 1)	// timer A expired
+		{
+			oki_update_state(space);
+			get_command(space);
+			update_music(space);
+
+			// restart timer
+			ym2203_control_port_0_w(space, 0, 0x27);
+			ym2203_write_port_0_w(space, 0, 0x15);
+		}
 	}
 }
 
 
 static TIMER_CALLBACK( real_nmk004_init )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	static const UINT8 ym2203_init[] =
 	{
 		0x07,0x38,0x08,0x00,0x09,0x00,0x0A,0x00,0x24,0xB3,0x25,0x00,0x26,0xF9,0x27,0x15,
@@ -1029,36 +1030,36 @@ static TIMER_CALLBACK( real_nmk004_init )
 
 	memset(&NMK004_state, 0, sizeof(NMK004_state));
 
-	NMK004_state.rom = memory_region(REGION_CPU2);
+	NMK004_state.rom = memory_region(machine, "audio");
 
-	YM2203_control_port_0_w(0, 0x2f);
+	ym2203_control_port_0_w(space, 0, 0x2f);
 
 	i = 0;
 	while (ym2203_init[i] != 0xff)
 	{
-		YM2203_control_port_0_w(0, ym2203_init[i++]);
-		YM2203_write_port_0_w(0, ym2203_init[i++]);
+		ym2203_control_port_0_w(space, 0, ym2203_init[i++]);
+		ym2203_write_port_0_w(space, 0, ym2203_init[i++]);
 	}
 
 	NMK004_state.oki_playing = 0;
 
-	oki_play_sample(0);
+	oki_play_sample(space, 0);
 
 	NMK004_state.protection_check = 0;
 }
 
-void NMK004_init(void)
+void NMK004_init(running_machine *machine)
 {
 	/* we have to do this via a timer because we get called before the sound reset */
-	timer_call_after_resynch(NULL, 0, real_nmk004_init);
+	timer_call_after_resynch(machine, NULL, 0, real_nmk004_init);
 }
 
 
 WRITE16_HANDLER( NMK004_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
-logerror("%06x: NMK004_w %02x\n",activecpu_get_pc(),data);
+logerror("%06x: NMK004_w %02x\n",cpu_get_pc(space->cpu),data);
 		NMK004_state.from_main = data & 0xff;
 	}
 }
@@ -1068,7 +1069,7 @@ READ16_HANDLER( NMK004_r )
 static int last;
 	int res = NMK004_state.to_main;
 
-if (res != last) logerror("%06x: NMK004_r %02x\n",activecpu_get_pc(),res);
+if (res != last) logerror("%06x: NMK004_r %02x\n",cpu_get_pc(space->cpu),res);
 last = res;
 
 	return res;
