@@ -1,7 +1,7 @@
 #include "driver.h"
-#include "deprecat.h"
 #include "video/ppu2c0x.h"
 #include "machine/rp5h01.h"
+#include "includes/playch10.h"
 
 /* Globals */
 int pc10_sdcs;			/* ShareD Chip Select */
@@ -28,6 +28,7 @@ static int MMC2_bank[4], MMC2_bank_latch[2];
  *************************************/
 MACHINE_RESET( pc10 )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	/* initialize latches and flip-flops */
 	pc10_nmi_enable = pc10_dog_di = pc10_dispmask = pc10_sdcs = pc10_int_detect = 0;
 
@@ -44,12 +45,12 @@ MACHINE_RESET( pc10 )
 
 	/* reset the security chip */
 	RP5H01_enable_w( 0, 0 );
-	RP5H01_0_reset_w( 0, 0 );
-	RP5H01_0_reset_w( 0, 1 );
+	RP5H01_0_reset_w( space, 0, 0 );
+	RP5H01_0_reset_w( space, 0, 1 );
 	RP5H01_enable_w( 0, 1 );
 
 	/* reset the ppu */
-	ppu2c0x_reset( 0, /* video_screen_get_scan_period(0) * */ 1 );
+	ppu2c0x_reset( machine, 0, /* video_screen_get_scan_period(machine->primary_screen) * */ 1 );
 
 	ppu2c0x_set_mirroring( 0, mirroring );
 }
@@ -59,9 +60,10 @@ MACHINE_RESET( pc10 )
  *  BIOS ports handling
  *
  *************************************/
-READ8_HANDLER( pc10_port_0_r )
+
+CUSTOM_INPUT( pc10_int_detect_r )
 {
-	return readinputport( 0 ) | ( ( ~pc10_int_detect & 1 ) << 3 );
+	return ~pc10_int_detect & 1;
 }
 
 WRITE8_HANDLER( pc10_SDCS_w )
@@ -102,18 +104,18 @@ WRITE8_HANDLER( pc10_DOGDI_w )
 
 WRITE8_HANDLER( pc10_GAMERES_w )
 {
-	cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, ( data & 1 ) ? CLEAR_LINE : ASSERT_LINE );
+	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, ( data & 1 ) ? CLEAR_LINE : ASSERT_LINE );
 }
 
 WRITE8_HANDLER( pc10_GAMESTOP_w )
 {
-	cpunum_set_input_line(Machine, 1, INPUT_LINE_HALT, ( data & 1 ) ? CLEAR_LINE : ASSERT_LINE );
+	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_HALT, ( data & 1 ) ? CLEAR_LINE : ASSERT_LINE );
 }
 
 WRITE8_HANDLER( pc10_PPURES_w )
 {
 	if ( data & 1 )
-		ppu2c0x_reset( 0, /* video_screen_get_scan_period(0) * */ 1 );
+		ppu2c0x_reset( space->machine, 0, /* video_screen_get_scan_period(space->machine->primary_screen) * */ 1 );
 }
 
 READ8_HANDLER( pc10_detectclr_r )
@@ -142,10 +144,10 @@ READ8_HANDLER( pc10_prot_r )
 	/* we only support a single cart connected at slot 0 */
 	if ( cart_sel == 0 )
 	{
-		RP5H01_0_enable_w( 0, 0 );
+		RP5H01_0_enable_w( space, 0, 0 );
 		data |= ( ( ~RP5H01_counter_r( 0 ) ) << 4 ) & 0x10;	/* D4 */
 		data |= ( ( RP5H01_data_r( 0 ) ) << 3 ) & 0x08;		/* D3 */
-		RP5H01_0_enable_w( 0, 1 );
+		RP5H01_0_enable_w( space, 0, 1 );
 	}
 	return data;
 }
@@ -155,18 +157,18 @@ WRITE8_HANDLER( pc10_prot_w )
 	/* we only support a single cart connected at slot 0 */
 	if ( cart_sel == 0 )
 	{
-		RP5H01_0_enable_w( 0, 0 );
-		RP5H01_0_test_w( 0, data & 0x10 );		/* D4 */
-		RP5H01_0_clock_w( 0, data & 0x08 );		/* D3 */
-		RP5H01_0_reset_w( 0, ~data & 0x01 );	/* D0 */
-		RP5H01_0_enable_w( 0, 1 );
+		RP5H01_0_enable_w( space, 0, 0 );
+		RP5H01_0_test_w( space, 0, data & 0x10 );		/* D4 */
+		RP5H01_0_clock_w( space, 0, data & 0x08 );		/* D3 */
+		RP5H01_0_reset_w( space, 0, ~data & 0x01 );	/* D0 */
+		RP5H01_0_enable_w( space, 0, 1 );
 
 		/* this thing gets dense at some point                      */
 		/* it wants to jump and execute an opcode at $ffff, wich    */
 		/* is the actual protection memory area                     */
 		/* setting the whole 0x2000 region every time is a waste    */
 		/* so we just set $ffff with the current value              */
-		memory_region( REGION_CPU1 )[0xffff] = pc10_prot_r(0);
+		memory_region( space->machine, "main" )[0xffff] = pc10_prot_r(space,0);
 	}
 }
 
@@ -183,8 +185,8 @@ WRITE8_HANDLER( pc10_in0_w )
 		return;
 
 	/* load up the latches */
-	input_latch[0] = readinputport( 3 );
-	input_latch[1] = readinputport( 4 );
+	input_latch[0] = input_port_read(space->machine, "P1");
+	input_latch[1] = input_port_read(space->machine, "P2");
 
 	/* apply any masking from the BIOS */
 	if ( cntrl_mask )
@@ -218,11 +220,10 @@ READ8_HANDLER( pc10_in1_r )
 	/* do the gun thing */
 	if ( pc10_gun_controller )
 	{
-		int trigger = readinputport( 3 );
-		int x = readinputport( 5 );
-		int y = readinputport( 6 );
+		int trigger = input_port_read(space->machine, "P1");
+		int x = input_port_read(space->machine, "GUNX");
+		int y = input_port_read(space->machine, "GUNY");
 		UINT32 pix, color_base;
-		const pen_t *pens = Machine->pens;
 
 		/* no sprite hit (yet) */
 		ret |= 0x08;
@@ -234,8 +235,8 @@ READ8_HANDLER( pc10_in1_r )
 		color_base = ppu2c0x_get_colorbase( 0 );
 
 		/* look at the screen and see if the cursor is over a bright pixel */
-		if ( ( pix == pens[color_base+0x20] ) || ( pix == pens[color_base+0x30] ) ||
-			 ( pix == pens[color_base+0x33] ) || ( pix == pens[color_base+0x34] ) )
+		if ( ( pix == color_base+0x20 ) || ( pix == color_base+0x30 ) ||
+			 ( pix == color_base+0x33 ) || ( pix == color_base+0x34 ) )
 		{
 			ret &= ~0x08; /* sprite hit */
 		}
@@ -258,7 +259,7 @@ READ8_HANDLER( pc10_in1_r )
 static const struct RP5H01_interface rp5h01_interface =
 {
 	1,
-	{ REGION_USER1 },
+	{ "user1" },
 	{ 0 }
 };
 
@@ -270,7 +271,7 @@ static const struct RP5H01_interface rp5h01_interface =
 DRIVER_INIT( playch10 )
 {
 	/* initialize the security chip */
-	if ( RP5H01_init( &rp5h01_interface ) )
+	if ( RP5H01_init( machine, &rp5h01_interface ) )
 	{
 		fatalerror("rp5h01_interface initualization failed");
 	}
@@ -398,11 +399,12 @@ static WRITE8_HANDLER( mmc1_rom_switch_w )
 			case 3:	/* program banking */
 				{
 					int bank = ( mmc1_shiftreg & mmc1_rom_mask ) * 0x4000;
+					UINT8 *prg = memory_region( space->machine, "cart" );
 
 					if ( !size16k )
 					{
 						/* switch 32k */
-						memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[0x010000+bank], 0x8000 );
+						memcpy( &prg[0x08000], &prg[0x010000+bank], 0x8000 );
 					}
 					else
 					{
@@ -410,12 +412,12 @@ static WRITE8_HANDLER( mmc1_rom_switch_w )
 						if ( switchlow )
 						{
 							/* low */
-							memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[0x010000+bank], 0x4000 );
+							memcpy( &prg[0x08000], &prg[0x010000+bank], 0x4000 );
 						}
 						else
 						{
 							/* high */
-							memcpy( &memory_region( REGION_CPU2 )[0x0c000], &memory_region( REGION_CPU2 )[0x010000+bank], 0x4000 );
+							memcpy( &prg[0x0c000], &prg[0x010000+bank], 0x4000 );
 						}
 					}
 				}
@@ -436,7 +438,7 @@ static WRITE8_HANDLER( aboard_vrom_switch_w )
 DRIVER_INIT( pcaboard )
 {
 	/* switches vrom with writes to the $803e-$8041 area */
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x8000, 0x8fff, 0, 0, aboard_vrom_switch_w );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x8000, 0x8fff, 0, 0, aboard_vrom_switch_w );
 
 	/* common init */
 	DRIVER_INIT_CALL(playch10);
@@ -452,18 +454,21 @@ DRIVER_INIT( pcaboard )
 static WRITE8_HANDLER( bboard_rom_switch_w )
 {
 	int bankoffset = 0x10000 + ( ( data & 7 ) * 0x4000 );
+	UINT8 *prg = memory_region( space->machine, "cart" );
 
-	memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[bankoffset], 0x4000 );
+	memcpy( &prg[0x08000], &prg[bankoffset], 0x4000 );
 }
 
 DRIVER_INIT( pcbboard )
 {
+	UINT8 *prg = memory_region( machine, "cart" );
+
 	/* We do manual banking, in case the code falls through */
 	/* Copy the initial banks */
-	memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[0x28000], 0x8000 );
+	memcpy( &prg[0x08000], &prg[0x28000], 0x8000 );
 
 	/* Roms are banked at $8000 to $bfff */
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, bboard_rom_switch_w );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, bboard_rom_switch_w );
 
 	/* common init */
 	DRIVER_INIT_CALL(playch10);
@@ -484,7 +489,7 @@ static WRITE8_HANDLER( cboard_vrom_switch_w )
 DRIVER_INIT( pccboard )
 {
 	/* switches vrom with writes to $6000 */
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x6000, 0x6000, 0, 0, cboard_vrom_switch_w );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x6000, 0x6000, 0, 0, cboard_vrom_switch_w );
 
 	/* common init */
 	DRIVER_INIT_CALL(playch10);
@@ -496,14 +501,16 @@ DRIVER_INIT( pccboard )
 
 DRIVER_INIT( pcdboard )
 {
+	UINT8 *prg = memory_region( machine, "cart" );
+
 	/* We do manual banking, in case the code falls through */
 	/* Copy the initial banks */
-	memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[0x28000], 0x8000 );
+	memcpy( &prg[0x08000], &prg[0x28000], 0x8000 );
 
 	mmc1_rom_mask = 0x07;
 
 	/* MMC mapper at writes to $8000-$ffff */
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, mmc1_rom_switch_w );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, mmc1_rom_switch_w );
 
 	/* common init */
 	DRIVER_INIT_CALL(playch10);
@@ -514,8 +521,8 @@ DRIVER_INIT( pcdboard )
 DRIVER_INIT( pcdboard_2 )
 {
 	/* extra ram at $6000-$7fff */
-	memory_install_readwrite8_handler(1, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MRA8_BANK1, MWA8_BANK1 );
-	memory_set_bankptr(1, auto_malloc(0x2000));
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x6000, 0x7fff, 0, 0, SMH_BANK1, SMH_BANK1 );
+	memory_set_bankptr(machine, 1, auto_malloc(0x2000));
 
 	/* common init */
 	DRIVER_INIT_CALL(pcdboard);
@@ -558,7 +565,8 @@ static WRITE8_HANDLER( eboard_rom_switch_w )
 		case 0x2000: /* code bank switching */
 			{
 				int bankoffset = 0x10000 + ( data & 0x0f ) * 0x2000;
-				memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[bankoffset], 0x2000 );
+				UINT8 *prg = memory_region( space->machine, "cart" );
+				memcpy( &prg[0x08000], &prg[bankoffset], 0x2000 );
 			}
 		break;
 
@@ -595,19 +603,21 @@ static WRITE8_HANDLER( eboard_rom_switch_w )
 
 DRIVER_INIT( pceboard )
 {
+	UINT8 *prg = memory_region( machine, "cart" );
+
 	/* We do manual banking, in case the code falls through */
 	/* Copy the initial banks */
-	memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[0x28000], 0x8000 );
+	memcpy( &prg[0x08000], &prg[0x28000], 0x8000 );
 
 	/* basically a mapper 9 on a nes */
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, eboard_rom_switch_w );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, eboard_rom_switch_w );
 
 	/* ppu_latch callback */
 	ppu_latch = mapper9_latch;
 
 	/* nvram at $6000-$6fff */
-	memory_install_readwrite8_handler(1, ADDRESS_SPACE_PROGRAM, 0x6000, 0x6fff, 0, 0, MRA8_BANK1, MWA8_BANK1 );
-	memory_set_bankptr(1, auto_malloc(0x1000));
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x6000, 0x6fff, 0, 0, SMH_BANK1, SMH_BANK1 );
+	memory_set_bankptr(machine, 1, auto_malloc(0x1000));
 
 	/* common init */
 	DRIVER_INIT_CALL(playch10);
@@ -619,14 +629,16 @@ DRIVER_INIT( pceboard )
 
 DRIVER_INIT( pcfboard )
 {
+	UINT8 *prg = memory_region( machine, "cart" );
+
 	/* We do manual banking, in case the code falls through */
 	/* Copy the initial banks */
-	memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[0x28000], 0x8000 );
+	memcpy( &prg[0x08000], &prg[0x28000], 0x8000 );
 
 	mmc1_rom_mask = 0x07;
 
 	/* MMC mapper at writes to $8000-$ffff */
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, mmc1_rom_switch_w );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, mmc1_rom_switch_w );
 
 	/* common init */
 	DRIVER_INIT_CALL(playch10);
@@ -637,8 +649,8 @@ DRIVER_INIT( pcfboard )
 DRIVER_INIT( pcfboard_2 )
 {
 	/* extra ram at $6000-$6fff */
-	memory_install_readwrite8_handler(1, ADDRESS_SPACE_PROGRAM, 0x6000, 0x6fff, 0, 0, MRA8_BANK1, MWA8_BANK1 );
-	memory_set_bankptr(1, auto_malloc(0x1000));
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x6000, 0x6fff, 0, 0, SMH_BANK1, SMH_BANK1 );
+	memory_set_bankptr(machine, 1, auto_malloc(0x1000));
 
 	/* common init */
 	DRIVER_INIT_CALL(pcfboard);
@@ -652,15 +664,17 @@ static int gboard_scanline_counter;
 static int gboard_scanline_latch;
 static int gboard_banks[2];
 static int gboard_4screen;
+static int gboard_last_bank;
+static int gboard_command;
 
-static void gboard_scanline_cb( int num, int scanline, int vblank, int blanked )
+static void gboard_scanline_cb( running_machine *machine, int num, int scanline, int vblank, int blanked )
 {
 	if ( !vblank && !blanked )
 	{
 		if ( --gboard_scanline_counter == -1 )
 		{
 			gboard_scanline_counter = gboard_scanline_latch;
-			cpunum_set_input_line(Machine, 1, 0, PULSE_LINE );
+			generic_pulse_irq_line(machine->cpu[1], 0);
 		}
 	}
 }
@@ -668,17 +682,16 @@ static void gboard_scanline_cb( int num, int scanline, int vblank, int blanked )
 static WRITE8_HANDLER( gboard_rom_switch_w )
 {
 	/* basically, a MMC3 mapper from the nes */
-	static int last_bank = 0xff;
-	static int gboard_command;
 
 	switch( offset & 0x7001 )
 	{
 		case 0x0000:
 			gboard_command = data;
 
-			if ( last_bank != ( data & 0xc0 ) )
+			if ( gboard_last_bank != ( data & 0xc0 ) )
 			{
 				int bank;
+				UINT8 *prg = memory_region( space->machine, "cart" );
 
 				/* reset the banks */
 				if ( gboard_command & 0x40 )
@@ -686,23 +699,23 @@ static WRITE8_HANDLER( gboard_rom_switch_w )
 					/* high bank */
 					bank = gboard_banks[0] * 0x2000 + 0x10000;
 
-					memcpy( &memory_region( REGION_CPU2 )[0x0c000], &memory_region( REGION_CPU2 )[bank], 0x2000 );
-					memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[0x4c000], 0x2000 );
+					memcpy( &prg[0x0c000], &prg[bank], 0x2000 );
+					memcpy( &prg[0x08000], &prg[0x4c000], 0x2000 );
 				}
 				else
 				{
 					/* low bank */
 					bank = gboard_banks[0] * 0x2000 + 0x10000;
 
-					memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[bank], 0x2000 );
-					memcpy( &memory_region( REGION_CPU2 )[0x0c000], &memory_region( REGION_CPU2 )[0x4c000], 0x2000 );
+					memcpy( &prg[0x08000], &prg[bank], 0x2000 );
+					memcpy( &prg[0x0c000], &prg[0x4c000], 0x2000 );
 				}
 
 				/* mid bank */
 				bank = gboard_banks[1] * 0x2000 + 0x10000;
-				memcpy( &memory_region( REGION_CPU2 )[0x0a000], &memory_region( REGION_CPU2 )[bank], 0x2000 );
+				memcpy( &prg[0x0a000], &prg[bank], 0x2000 );
 
-				last_bank = data & 0xc0;
+				gboard_last_bank = data & 0xc0;
 			}
 		break;
 
@@ -730,14 +743,16 @@ static WRITE8_HANDLER( gboard_rom_switch_w )
 					break;
 
 					case 6: /* program banking */
+					{
+						UINT8 *prg = memory_region( space->machine, "cart" );
 						if ( gboard_command & 0x40 )
 						{
 							/* high bank */
 							gboard_banks[0] = data & 0x1f;
 							bank = ( gboard_banks[0] ) * 0x2000 + 0x10000;
 
-							memcpy( &memory_region( REGION_CPU2 )[0x0c000], &memory_region( REGION_CPU2 )[bank], 0x2000 );
-							memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[0x4c000], 0x2000 );
+							memcpy( &prg[0x0c000], &prg[bank], 0x2000 );
+							memcpy( &prg[0x08000], &prg[0x4c000], 0x2000 );
 						}
 						else
 						{
@@ -745,18 +760,20 @@ static WRITE8_HANDLER( gboard_rom_switch_w )
 							gboard_banks[0] = data & 0x1f;
 							bank = ( gboard_banks[0] ) * 0x2000 + 0x10000;
 
-							memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[bank], 0x2000 );
-							memcpy( &memory_region( REGION_CPU2 )[0x0c000], &memory_region( REGION_CPU2 )[0x4c000], 0x2000 );
+							memcpy( &prg[0x08000], &prg[bank], 0x2000 );
+							memcpy( &prg[0x0c000], &prg[0x4c000], 0x2000 );
 						}
+					}
 					break;
 
 					case 7: /* program banking */
 						{
 							/* mid bank */
+							UINT8 *prg = memory_region( space->machine, "cart" );
 							gboard_banks[1] = data & 0x1f;
 							bank = gboard_banks[1] * 0x2000 + 0x10000;
 
-							memcpy( &memory_region( REGION_CPU2 )[0x0a000], &memory_region( REGION_CPU2 )[bank], 0x2000 );
+							memcpy( &prg[0x0a000], &prg[bank], 0x2000 );
 						}
 					break;
 				}
@@ -797,17 +814,19 @@ static WRITE8_HANDLER( gboard_rom_switch_w )
 
 DRIVER_INIT( pcgboard )
 {
+	UINT8 *prg = memory_region( machine, "cart" );
+
 	/* We do manual banking, in case the code falls through */
 	/* Copy the initial banks */
-	memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[0x4c000], 0x4000 );
-	memcpy( &memory_region( REGION_CPU2 )[0x0c000], &memory_region( REGION_CPU2 )[0x4c000], 0x4000 );
+	memcpy( &prg[0x08000], &prg[0x4c000], 0x4000 );
+	memcpy( &prg[0x0c000], &prg[0x4c000], 0x4000 );
 
 	/* MMC3 mapper at writes to $8000-$ffff */
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, gboard_rom_switch_w );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, gboard_rom_switch_w );
 
 	/* extra ram at $6000-$7fff */
-	memory_install_readwrite8_handler(1, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MRA8_BANK1, MWA8_BANK1 );
-	memory_set_bankptr(1, auto_malloc(0x2000));
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x6000, 0x7fff, 0, 0, SMH_BANK1, SMH_BANK1 );
+	memory_set_bankptr(machine, 1, auto_malloc(0x2000));
 
 	gboard_banks[0] = 0x1e;
 	gboard_banks[1] = 0x1f;
@@ -835,23 +854,26 @@ DRIVER_INIT( pcgboard_type2 )
 static WRITE8_HANDLER( iboard_rom_switch_w )
 {
 	int bank = data & 7;
+	UINT8 *prg = memory_region( space->machine, "cart" );
 
 	if ( data & 0x10 )
 		ppu2c0x_set_mirroring( 0, PPU_MIRROR_HIGH );
 	else
 		ppu2c0x_set_mirroring( 0, PPU_MIRROR_LOW );
 
-	memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[bank * 0x8000 + 0x10000], 0x8000 );
+	memcpy( &prg[0x08000], &prg[bank * 0x8000 + 0x10000], 0x8000 );
 }
 
 DRIVER_INIT( pciboard )
 {
+	UINT8 *prg = memory_region( machine, "cart" );
+
 	/* We do manual banking, in case the code falls through */
 	/* Copy the initial banks */
-	memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[0x10000], 0x8000 );
+	memcpy( &prg[0x08000], &prg[0x10000], 0x8000 );
 
 	/* Roms are banked at $8000 to $bfff */
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, iboard_rom_switch_w );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, iboard_rom_switch_w );
 
 	/* common init */
 	DRIVER_INIT_CALL(playch10);
@@ -861,22 +883,71 @@ DRIVER_INIT( pciboard )
 
 /* H Board games (PinBot) */
 
+static WRITE8_HANDLER( hboard_rom_switch_w )
+{
+	switch( offset & 0x7001 )
+	{
+		case 0x0001:
+			{
+				UINT8 cmd = gboard_command & 0x07;
+				int page = ( gboard_command & 0x80 ) >> 5;
+
+				switch( cmd )
+				{
+					case 0:	/* char banking */
+					case 1: /* char banking */
+						data &= 0xfe;
+						page ^= ( cmd << 1 );
+						if ( data & 0x20 )
+						{
+							ppu2c0x_set_videoram_bank( 0, page, 2, data, 64 );
+						}
+						else
+						{
+							ppu2c0x_set_videorom_bank( 0, page, 2, data, 64 );
+						}
+					return;
+
+					case 2: /* char banking */
+					case 3: /* char banking */
+					case 4: /* char banking */
+					case 5: /* char banking */
+						page ^= cmd + 2;
+						if ( data & 0x40 )
+						{
+							ppu2c0x_set_videoram_bank( 0, page, 1, data, 64 );
+						}
+						else
+						{
+							ppu2c0x_set_videorom_bank( 0, page, 1, data, 64 );
+						}
+					return;
+				}
+			}
+	};
+	gboard_rom_switch_w(space,offset,data);
+};
+
+
 DRIVER_INIT( pchboard )
 {
-	memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[0x4c000], 0x4000 );
-	memcpy( &memory_region( REGION_CPU2 )[0x0c000], &memory_region( REGION_CPU2 )[0x4c000], 0x4000 );
+	UINT8 *prg = memory_region( machine, "cart" );
+	memcpy( &prg[0x08000], &prg[0x4c000], 0x4000 );
+	memcpy( &prg[0x0c000], &prg[0x4c000], 0x4000 );
 
 	/* Roms are banked at $8000 to $bfff */
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, gboard_rom_switch_w );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, hboard_rom_switch_w );
 
 	/* extra ram at $6000-$7fff */
-	memory_install_readwrite8_handler(1, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MRA8_BANK1, MWA8_BANK1 );
-	memory_set_bankptr(1, auto_malloc(0x2000));
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x6000, 0x7fff, 0, 0, SMH_BANK1, SMH_BANK1 );
+	memory_set_bankptr(machine, 1, auto_malloc(0x2000));
 
 	gboard_banks[0] = 0x1e;
 	gboard_banks[1] = 0x1f;
 	gboard_scanline_counter = 0;
 	gboard_scanline_latch = 0;
+	gboard_last_bank = 0xff;
+	gboard_command = 0;
 
 	/* common init */
 	DRIVER_INIT_CALL(playch10);
@@ -888,18 +959,20 @@ DRIVER_INIT( pchboard )
 
 DRIVER_INIT( pckboard )
 {
+	UINT8 *prg = memory_region( machine, "cart" );
+
 	/* We do manual banking, in case the code falls through */
 	/* Copy the initial banks */
-	memcpy( &memory_region( REGION_CPU2 )[0x08000], &memory_region( REGION_CPU2 )[0x48000], 0x8000 );
+	memcpy( &prg[0x08000], &prg[0x48000], 0x8000 );
 
 	mmc1_rom_mask = 0x0f;
 
 	/* extra ram at $6000-$7fff */
-	memory_install_readwrite8_handler(1, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MRA8_BANK1, MWA8_BANK1 );
-	memory_set_bankptr(1, auto_malloc(0x2000));
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x6000, 0x7fff, 0, 0, SMH_BANK1, SMH_BANK1 );
+	memory_set_bankptr(machine, 1, auto_malloc(0x2000));
 
 	/* Roms are banked at $8000 to $bfff */
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, mmc1_rom_switch_w );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, mmc1_rom_switch_w );
 
 	/* common init */
 	DRIVER_INIT_CALL(playch10);
