@@ -48,7 +48,7 @@
 *************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "includes/cchip.h"
 
 static UINT8* CRAM[8];
 
@@ -713,9 +713,9 @@ static void request_world_data(void)
 	}
 }
 
-static void request_goalin_data(void)
+static void request_goalin_data(running_machine *machine)
 {
-	int n = mame_rand(Machine) % 15;
+	int n = mame_rand(machine) % 15;
 
 	CRAM[1][0x14B] = 0x00; /* x coordinates */
 	CRAM[1][0x14D] = 0x10;
@@ -750,7 +750,7 @@ static TIMER_CALLBACK( cchip_timer )
 
 	if (CRAM[1][0x149] == 1)
 	{
-		request_goalin_data();
+		request_goalin_data(machine);
 
 		CRAM[1][0x149] = 0xFF;
 	}
@@ -760,10 +760,10 @@ static TIMER_CALLBACK( cchip_timer )
 	coin_counter_w(1, CRAM[0][8] & 0x20);
 	coin_counter_w(0, CRAM[0][8] & 0x10);
 
-	CRAM[0][3] = readinputportbytag("800007");    /* STARTn + SERVICE1 */
-	CRAM[0][4] = readinputportbytag("800009");    /* COINn */
-	CRAM[0][5] = readinputportbytag("80000B");    /* Player controls + TILT */
-	CRAM[0][6] = readinputportbytag("80000D");    /* Player controls (cocktail) */
+	CRAM[0][3] = input_port_read(machine, "800007");    /* STARTn + SERVICE1 */
+	CRAM[0][4] = input_port_read(machine, "800009");    /* COINn */
+	CRAM[0][5] = input_port_read(machine, "80000B");    /* Player controls + TILT */
+	CRAM[0][6] = input_port_read(machine, "80000D");    /* Player controls (cocktail) */
 }
 
 /*************************************
@@ -813,7 +813,7 @@ READ16_HANDLER( rainbow_cchip_ram_r )
  *
  *************************************/
 
-void rainbow_cchip_init(int version)
+void rainbow_cchip_init(running_machine *machine, int version)
 {
 	int i;
 
@@ -823,10 +823,10 @@ void rainbow_cchip_init(int version)
 	{
 		CRAM[i] = auto_malloc(0x400);
 
-		state_save_register_item_pointer("cchip", i, CRAM[i], 0x400);
+		state_save_register_item_pointer(machine, "cchip", NULL, i, CRAM[i], 0x400);
 	}
 
-	state_save_register_item("cchip", 0, current_bank);
+	state_save_register_item(machine, "cchip", NULL, 0, current_bank);
 
-	timer_pulse(ATTOTIME_IN_HZ(60), NULL, 0, cchip_timer);
+	timer_pulse(machine, ATTOTIME_IN_HZ(60), NULL, 0, cchip_timer);
 }
