@@ -153,10 +153,10 @@ void DSP1_setDr(UINT8 iDr)
 
 //////////////////////////////////////////////////////////////////
 
-void DSP1_reset(void)
+void DSP1_reset(running_machine *machine)
 {
 	UINT32 i;
-	UINT8 *dspin = memory_region(REGION_USER6);
+	UINT8 *dspin = memory_region(machine, "user6");
 
 	mSr = DRC|RQM;
 	mSrLowByteAccess = FALSE;
