@@ -1,5 +1,4 @@
 #include "driver.h"
-#include "deprecat.h"
 #include "system16.h"
 #include "sound/upd7759.h"
 
@@ -9,9 +8,8 @@ UINT16 *sys16_extraram;
 UINT16 *sys16_extraram2;
 UINT16 *sys16_extraram3;
 
-static void patch_codeX( int offset, int data, int cpu ){
+static void patch_codeX( UINT16 *mem, offs_t offset, int data ){
 	int aligned_offset = offset&0xfffffe;
-	UINT16 *mem = (UINT16 *)memory_region(REGION_CPU1+cpu);
 	int old_word = mem[aligned_offset/2];
 
 	if( offset&1 )
@@ -22,8 +20,11 @@ static void patch_codeX( int offset, int data, int cpu ){
 	mem[aligned_offset/2] = data;
 }
 
-void sys16_patch_code( int offset, int data ){
-	patch_codeX(offset,data,0);
+void sys16_patch_code( running_machine *machine, const sys16_patch *data, int count ){
+	int i;
+	UINT16 *mem = (UINT16 *)memory_region(machine, "main");
+	for (i=0; i<count; i++)
+		patch_codeX(mem, data[i].offset, data[i].data);
 }
 
 
@@ -48,21 +49,20 @@ static const gfx_layout charlayout =
 };
 
 GFXDECODE_START( sys16 )
-	GFXDECODE_ENTRY( REGION_GFX1, 0, charlayout,	0, 1024 )
+	GFXDECODE_ENTRY( "gfx1", 0, charlayout,	0, 1024 )
 GFXDECODE_END
 
 
 /* sound */
 
-static void sound_cause_nmi( int chip ){
+static void sound_cause_nmi( const device_config *device, int chip ){
 	/* upd7759 callback */
-	cpunum_set_input_line(Machine, 1, INPUT_LINE_NMI, PULSE_LINE);
+	cpu_set_input_line(device->machine->cpu[1], INPUT_LINE_NMI, PULSE_LINE);
 }
 
 
-const struct upd7759_interface sys16_upd7759_interface =
+const upd7759_interface sys16_upd7759_interface =
 {
-	0,			/* memory region 3 contains the sample data */
 	sound_cause_nmi
 };
 
