@@ -13,8 +13,7 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
-#include "cpu/i8x41/i8x41.h"
+#include "cpu/mcs48/mcs48.h"
 #include "includes/tnzs.h"
 
 static int mcu_type;
@@ -45,30 +44,19 @@ static READ8_HANDLER( mcu_tnzs_r )
 {
 	UINT8 data;
 
-	if (offset == 0)
-	{
-		data = cpunum_get_reg(2, I8X41_DATA);
-		cpu_yield();
-	}
-	else
-	{
-		data = cpunum_get_reg(2, I8X41_STAT);
-		cpu_yield();
-	}
+	data = upi41_master_r(space->machine->cpu[2], offset & 1);
+	cpu_yield(space->cpu);
 
-//  logerror("PC %04x: read %02x from mcu $c00%01x\n", activecpu_get_previouspc(), data, offset);
+//  logerror("PC %04x: read %02x from mcu $c00%01x\n", cpu_get_previouspc(space->cpu), data, offset);
 
 	return data;
 }
 
 static WRITE8_HANDLER( mcu_tnzs_w )
 {
-//  logerror("PC %04x: write %02x to mcu $c00%01x\n", activecpu_get_previouspc(), data, offset);
+//  logerror("PC %04x: write %02x to mcu $c00%01x\n", cpu_get_previouspc(space->cpu), data, offset);
 
-	if (offset == 0)
-		cpunum_set_reg(2, I8X41_DATA, data);
-	else
-		cpunum_set_reg(2, I8X41_CMND, data);
+	upi41_master_w(space->machine->cpu[2], offset & 1, data);
 }
 
 
@@ -78,29 +66,29 @@ READ8_HANDLER( tnzs_port1_r )
 
 	switch (tnzs_input_select & 0x0f)
 	{
-		case 0x0a:	data = input_port_4_r(0); break;
-		case 0x0c:	data = input_port_2_r(0); break;
-		case 0x0d:	data = input_port_3_r(0); break;
+		case 0x0a:	data = input_port_read(space->machine, "IN2"); break;
+		case 0x0c:	data = input_port_read(space->machine, "IN0"); break;
+		case 0x0d:	data = input_port_read(space->machine, "IN1"); break;
 		default:	data = 0xff; break;
 	}
 
-//  logerror("I8742:%04x  Read %02x from port 1\n", activecpu_get_previouspc(), data);
+//  logerror("I8742:%04x  Read %02x from port 1\n", cpu_get_previouspc(space->cpu), data);
 
 	return data;
 }
 
 READ8_HANDLER( tnzs_port2_r )
 {
-	int data = input_port_4_r(0);
+	int data = input_port_read(space->machine, "IN2");
 
-//  logerror("I8742:%04x  Read %02x from port 2\n", activecpu_get_previouspc(), data);
+//  logerror("I8742:%04x  Read %02x from port 2\n", cpu_get_previouspc(space->cpu), data);
 
 	return data;
 }
 
 WRITE8_HANDLER( tnzs_port2_w )
 {
-//  logerror("I8742:%04x  Write %02x to port 2\n", activecpu_get_previouspc(), data);
+//  logerror("I8742:%04x  Write %02x to port 2\n", cpu_get_previouspc(space->cpu), data);
 
 	coin_lockout_w( 0, (data & 0x40) );
 	coin_lockout_w( 1, (data & 0x80) );
@@ -116,9 +104,9 @@ READ8_HANDLER( arknoid2_sh_f000_r )
 {
 	int val;
 
-//  logerror("PC %04x: read input %04x\n", activecpu_get_pc(), 0xf000 + offset);
+//  logerror("PC %04x: read input %04x\n", cpu_get_pc(space->cpu), 0xf000 + offset);
 
-	val = readinputport(7 + offset/2);
+	val = input_port_read_safe(space->machine, (offset/2) ? "AN2" : "AN1", 0);
 	if (offset & 1)
 	{
 		return ((val >> 8) & 0xff);
@@ -220,7 +208,7 @@ static READ8_HANDLER( mcu_arknoid2_r )
 {
 	static const char mcu_startup[] = "\x55\xaa\x5a";
 
-//  logerror("PC %04x: read mcu %04x\n", activecpu_get_pc(), 0xc000 + offset);
+//  logerror("PC %04x: read mcu %04x\n", cpu_get_pc(space->cpu), 0xc000 + offset);
 
 	if (offset == 0)
 	{
@@ -248,7 +236,7 @@ static READ8_HANDLER( mcu_arknoid2_r )
 					}
 					else return mcu_credits;
 				}
-				else return readinputport(2);	/* buttons */
+				else return input_port_read(space->machine, "IN0");	/* buttons */
 
 			default:
 				logerror("error, unknown mcu command\n");
@@ -282,7 +270,7 @@ static WRITE8_HANDLER( mcu_arknoid2_w )
 {
 	if (offset == 0)
 	{
-//      logerror("PC %04x: write %02x to mcu %04x\n", activecpu_get_pc(), data, 0xc000 + offset);
+//      logerror("PC %04x: write %02x to mcu %04x\n", cpu_get_pc(space->cpu), data, 0xc000 + offset);
 		if (mcu_command == 0x41)
 		{
 			mcu_credits = (mcu_credits + data) & 0xff;
@@ -299,7 +287,7 @@ static WRITE8_HANDLER( mcu_arknoid2_w )
         0x80: release coin lockout (issued only in test mode)
         during initialization, a sequence of 4 bytes sets coin/credit settings
         */
-//      logerror("PC %04x: write %02x to mcu %04x\n", activecpu_get_pc(), data, 0xc000 + offset);
+//      logerror("PC %04x: write %02x to mcu %04x\n", cpu_get_pc(space->cpu), data, 0xc000 + offset);
 
 		if (mcu_initializing)
 		{
@@ -325,7 +313,7 @@ static READ8_HANDLER( mcu_extrmatn_r )
 {
 	static const char mcu_startup[] = "\x5a\xa5\x55";
 
-//  logerror("PC %04x: read mcu %04x\n", activecpu_get_pc(), 0xc000 + offset);
+//  logerror("PC %04x: read mcu %04x\n", cpu_get_pc(space->cpu), 0xc000 + offset);
 
 	if (offset == 0)
 	{
@@ -339,16 +327,16 @@ static READ8_HANDLER( mcu_extrmatn_r )
 		switch (mcu_command)
 		{
 			case 0x01:
-				return readinputport(2) ^ 0xff;	/* player 1 joystick + buttons */
+				return input_port_read(space->machine, "IN0") ^ 0xff;	/* player 1 joystick + buttons */
 
 			case 0x02:
-				return readinputport(3) ^ 0xff;	/* player 2 joystick + buttons */
+				return input_port_read(space->machine, "IN1") ^ 0xff;	/* player 2 joystick + buttons */
 
 			case 0x1a:
-				return (readinputport(5) | (readinputport(6) << 1));
+				return (input_port_read(space->machine, "COIN1") | (input_port_read(space->machine, "COIN2") << 1));
 
 			case 0x21:
-				return readinputport(4) & 0x0f;
+				return input_port_read(space->machine, "IN2") & 0x0f;
 
 			case 0x41:
 				return mcu_credits;
@@ -376,7 +364,7 @@ static READ8_HANDLER( mcu_extrmatn_r )
 					else return mcu_credits;
 				}
 				/* buttons */
-				else return ((readinputport(2) & 0xf0) | (readinputport(3) >> 4)) ^ 0xff;
+				else return ((input_port_read(space->machine, "IN0") & 0xf0) | (input_port_read(space->machine, "IN1") >> 4)) ^ 0xff;
 
 			default:
 				logerror("error, unknown mcu command\n");
@@ -410,7 +398,7 @@ static WRITE8_HANDLER( mcu_extrmatn_w )
 {
 	if (offset == 0)
 	{
-//      logerror("PC %04x: write %02x to mcu %04x\n", activecpu_get_pc(), data, 0xc000 + offset);
+//      logerror("PC %04x: write %02x to mcu %04x\n", cpu_get_pc(space->cpu), data, 0xc000 + offset);
 		if (mcu_command == 0x41)
 		{
 			mcu_credits = (mcu_credits + data) & 0xff;
@@ -432,7 +420,7 @@ static WRITE8_HANDLER( mcu_extrmatn_w )
         during initialization, a sequence of 4 bytes sets coin/credit settings
         */
 
-//      logerror("PC %04x: write %02x to mcu %04x\n", activecpu_get_pc(), data, 0xc000 + offset);
+//      logerror("PC %04x: write %02x to mcu %04x\n", cpu_get_pc(space->cpu), data, 0xc000 + offset);
 
 		if (mcu_initializing)
 		{
@@ -508,7 +496,7 @@ static TIMER_CALLBACK( kludge_callback )
 
 static WRITE8_HANDLER( tnzs_sync_kludge_w )
 {
-	timer_call_after_resynch(NULL, data,kludge_callback);
+	timer_call_after_resynch(space->machine, NULL, data,kludge_callback);
 }
 
 
@@ -521,38 +509,20 @@ DRIVER_INIT( plumpop )
 
 DRIVER_INIT( extrmatn )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
-
 	mcu_type = MCU_EXTRMATN;
-
-	/* there's code which falls through from the fixed ROM to bank #7, I have to */
-	/* copy it there otherwise the CPU bank switching support will not catch it. */
-	memcpy(&RAM[0x08000],&RAM[0x2c000],0x4000);
 }
 
 DRIVER_INIT( arknoid2 )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
-
 	mcu_type = MCU_ARKANOID;
-
-	/* there's code which falls through from the fixed ROM to bank #2, I have to */
-	/* copy it there otherwise the CPU bank switching support will not catch it. */
-	memcpy(&RAM[0x08000],&RAM[0x18000],0x4000);
 }
 
 DRIVER_INIT( drtoppel )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
-
 	mcu_type = MCU_DRTOPPEL;
 
-	/* there's code which falls through from the fixed ROM to bank #2, I have to */
-	/* copy it there otherwise the CPU bank switching support will not catch it. */
-	memcpy(&RAM[0x08000],&RAM[0x18000],0x4000);
-
 	/* drtoppel writes to the palette RAM area even if it has PROMs! We have to patch it out. */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xf800, 0xfbff, 0, 0, MWA8_NOP);
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xf800, 0xfbff, 0, 0, SMH_NOP);
 }
 
 DRIVER_INIT( chukatai )
@@ -562,28 +532,17 @@ DRIVER_INIT( chukatai )
 
 DRIVER_INIT( tnzs )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
 	mcu_type = MCU_TNZS;
-
-	/* there's code which falls through from the fixed ROM to bank #7, I have to */
-	/* copy it there otherwise the CPU bank switching support will not catch it. */
-	memcpy(&RAM[0x08000],&RAM[0x2c000],0x4000);
-
 	/* we need to install a kludge to avoid problems with a bug in the original code */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xef10, 0xef10, 0, 0, tnzs_sync_kludge_w);
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xef10, 0xef10, 0, 0, tnzs_sync_kludge_w);
 }
 
 DRIVER_INIT( tnzsb )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
 	mcu_type = MCU_NONE_TNZSB;
 
-	/* there's code which falls through from the fixed ROM to bank #7, I have to */
-	/* copy it there otherwise the CPU bank switching support will not catch it. */
-	memcpy(&RAM[0x08000],&RAM[0x2c000],0x4000);
-
 	/* we need to install a kludge to avoid problems with a bug in the original code */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xef10, 0xef10, 0, 0, tnzs_sync_kludge_w);
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0xef10, 0xef10, 0, 0, tnzs_sync_kludge_w);
 }
 
 DRIVER_INIT( kabukiz )
@@ -596,9 +555,9 @@ DRIVER_INIT( insectx )
 	mcu_type = MCU_NONE_INSECTX;
 
 	/* this game has no mcu, replace the handler with plain input port handlers */
-	memory_install_read8_handler(1, ADDRESS_SPACE_PROGRAM, 0xc000, 0xc000, 0, 0, input_port_2_r );
-	memory_install_read8_handler(1, ADDRESS_SPACE_PROGRAM, 0xc001, 0xc001, 0, 0, input_port_3_r );
-	memory_install_read8_handler(1, ADDRESS_SPACE_PROGRAM, 0xc002, 0xc002, 0, 0, input_port_4_r );
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0xc000, 0xc000, 0, 0, input_port_2_r );
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0xc001, 0xc001, 0, 0, input_port_3_r );
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0xc002, 0xc002, 0, 0, input_port_4_r );
 }
 
 DRIVER_INIT( kageki )
@@ -613,15 +572,15 @@ READ8_HANDLER( tnzs_mcu_r )
 	{
 		case MCU_TNZS:
 		case MCU_CHUKATAI:
-			return mcu_tnzs_r(offset);
+			return mcu_tnzs_r(space,offset);
 			break;
 		case MCU_ARKANOID:
-			return mcu_arknoid2_r(offset);
+			return mcu_arknoid2_r(space,offset);
 			break;
 		case MCU_EXTRMATN:
 		case MCU_DRTOPPEL:
 		case MCU_PLUMPOP:
-			return mcu_extrmatn_r(offset);
+			return mcu_extrmatn_r(space,offset);
 			break;
 		default:
 			return 0xff;
@@ -635,15 +594,15 @@ WRITE8_HANDLER( tnzs_mcu_w )
 	{
 		case MCU_TNZS:
 		case MCU_CHUKATAI:
-			mcu_tnzs_w(offset,data);
+			mcu_tnzs_w(space,offset,data);
 			break;
 		case MCU_ARKANOID:
-			mcu_arknoid2_w(offset,data);
+			mcu_arknoid2_w(space,offset,data);
 			break;
 		case MCU_EXTRMATN:
 		case MCU_DRTOPPEL:
 		case MCU_PLUMPOP:
-			mcu_extrmatn_w(offset,data);
+			mcu_extrmatn_w(space,offset,data);
 			break;
 		default:
 			break;
@@ -661,9 +620,9 @@ INTERRUPT_GEN( arknoid2_interrupt )
 		case MCU_DRTOPPEL:
 		case MCU_PLUMPOP:
 			coin  = 0;
-			coin |= ((readinputport(5) & 1) << 0);
-			coin |= ((readinputport(6) & 1) << 1);
-			coin |= ((readinputport(4) & 3) << 2);
+			coin |= ((input_port_read(device->machine, "COIN1") & 1) << 0);
+			coin |= ((input_port_read(device->machine, "COIN2") & 1) << 1);
+			coin |= ((input_port_read(device->machine, "IN2") & 3) << 2);
 			coin ^= 0x0c;
 			mcu_handle_coins(coin);
 			break;
@@ -671,7 +630,7 @@ INTERRUPT_GEN( arknoid2_interrupt )
 			break;
 	}
 
-	cpunum_set_input_line(machine, 0, 0, HOLD_LINE);
+	cpu_set_input_line(device, 0, HOLD_LINE);
 }
 
 MACHINE_RESET( tnzs )
@@ -693,11 +652,11 @@ MACHINE_RESET( tnzs )
 	{
 		UINT8 *RAM;
 
-		RAM = memory_region(REGION_CPU1);
-		memory_set_bankptr(1,&RAM[0x18000]);
+		RAM = memory_region(machine, "main");
+		memory_set_bankptr(machine, 1,&RAM[0x18000]);
 
-		RAM = memory_region(REGION_CPU2);
-		memory_set_bankptr(2,&RAM[0x10000]);
+		RAM = memory_region(machine, "sub");
+		memory_set_bankptr(machine, 2,&RAM[0x10000]);
 	}
 }
 
@@ -716,25 +675,25 @@ WRITE8_HANDLER( tnzs_sharedram_w )
 
 WRITE8_HANDLER( tnzs_bankswitch_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU1);
+	UINT8 *RAM = memory_region(space->machine, "main");
 
-//  logerror("PC %04x: writing %02x to bankswitch\n", activecpu_get_pc(),data);
+//  logerror("PC %04x: writing %02x to bankswitch\n", cpu_get_pc(space->cpu),data);
 
 	/* bit 4 resets the second CPU */
 	if (data & 0x10)
-		cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, CLEAR_LINE);
+		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, CLEAR_LINE);
 	else
-		cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, ASSERT_LINE);
+		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, ASSERT_LINE);
 
 	/* bits 0-2 select RAM/ROM bank */
-	memory_set_bankptr (1, &RAM[0x10000 + 0x4000 * (data & 0x07)]);
+	memory_set_bankptr (space->machine, 1, &RAM[0x10000 + 0x4000 * (data & 0x07)]);
 }
 
 WRITE8_HANDLER( tnzs_bankswitch1_w )
 {
-	UINT8 *RAM = memory_region(REGION_CPU2);
+	UINT8 *RAM = memory_region(space->machine, "sub");
 
-//  logerror("PC %04x: writing %02x to bankswitch 1\n", activecpu_get_pc(),data);
+//  logerror("PC %04x: writing %02x to bankswitch 1\n", cpu_get_pc(space->cpu),data);
 
 	switch (mcu_type)
 	{
@@ -743,8 +702,8 @@ WRITE8_HANDLER( tnzs_bankswitch1_w )
 				/* bit 2 resets the mcu */
 				if (data & 0x04)
 				{
-					if (Machine->drv->cpu[2].type == CPU_I8X41)
-						cpunum_set_input_line(Machine, 2, INPUT_LINE_RESET, PULSE_LINE);
+					if (space->machine->cpu[2] != NULL && cpu_get_type(space->machine->cpu[2]) == CPU_I8742)
+						cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_RESET, PULSE_LINE);
 				}
 				/* Coin count and lockout is handled by the i8742 */
 				break;
@@ -779,5 +738,5 @@ WRITE8_HANDLER( tnzs_bankswitch1_w )
 	}
 
 	/* bits 0-1 select ROM bank */
-	memory_set_bankptr (2, &RAM[0x10000 + 0x2000 * (data & 3)]);
+	memory_set_bankptr (space->machine, 2, &RAM[0x10000 + 0x2000 * (data & 3)]);
 }
