@@ -8,8 +8,8 @@ Nintendo VS UniSystem and DualSystem - (c) 1984 Nintendo of America
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "video/ppu2c0x.h"
+#include "includes/vsnes.h"
 
 /* Globals */
 static int vsnes_gun_controller;
@@ -20,6 +20,8 @@ static int input_latch[4];
 static const UINT8 *remapped_colortable;
 
 static int sound_fix=0;
+static UINT8 last_bank;
+
 /*************************************
  *
  *  Color Mapping
@@ -85,7 +87,7 @@ static const UINT8 rp2c05004_colortable[] =
 
 
 /* remap callback */
-static int remap_colors( int num, int addr, int data )
+static int remap_colors( running_machine *machine, int num, int addr, int data )
 {
 	/* this is the protection. color codes are shuffled around */
 	/* the ones with value 0xff are unknown */
@@ -117,8 +119,8 @@ WRITE8_HANDLER( vsnes_in0_w )
 	if ( data & 1 )
 	{
 		/* load up the latches */
-		input_latch[0] = readinputport( 0 );
-		input_latch[1] = readinputport( 1 );
+		input_latch[0] = input_port_read(space->machine, "IN0");
+		input_latch[1] = input_port_read(space->machine, "IN1");
 	}
 }
 
@@ -129,8 +131,8 @@ static READ8_HANDLER( gun_in0_r )
 	/* shift */
 	input_latch[0] >>= 1;
 
-	ret |= readinputport( 2 ); 				/* merge coins, etc */
-	ret |= ( readinputport( 3 ) & 3 ) << 3; /* merge 2 dipswitches */
+	ret |= input_port_read(space->machine, "COINS"); 				/* merge coins, etc */
+	ret |= ( input_port_read(space->machine, "DSW0") & 3 ) << 3; /* merge 2 dipswitches */
 
 /* The gun games expect a 1 returned on every 5th read after sound_fix is reset*/
 /* Info Supplied by Ben Parnell <xodnizel@home.com> of FCE Ultra fame */
@@ -155,8 +157,8 @@ READ8_HANDLER( vsnes_in0_r )
 	/* shift */
 	input_latch[0] >>= 1;
 
-	ret |= readinputport( 2 ); 				/* merge coins, etc */
-	ret |= ( readinputport( 3 ) & 3 ) << 3; /* merge 2 dipswitches */
+	ret |= input_port_read(space->machine, "COINS"); 				/* merge coins, etc */
+	ret |= ( input_port_read(space->machine, "DSW0") & 3 ) << 3;	/* merge 2 dipswitches */
 
 	return ret;
 
@@ -167,7 +169,7 @@ READ8_HANDLER( vsnes_in1_r )
 {
 	int ret = ( input_latch[1] ) & 1;
 
-	ret |= readinputport( 3 ) & ~3;			/* merge the rest of the dipswitches */
+	ret |= input_port_read(space->machine, "DSW0") & ~3;			/* merge the rest of the dipswitches */
 
 	/* shift */
 	input_latch[1] >>= 1;
@@ -181,8 +183,8 @@ WRITE8_HANDLER( vsnes_in0_1_w )
 	if ( data & 1 )
 	{
 		/* load up the latches */
-		input_latch[2] = readinputport( 4 );
-		input_latch[3] = readinputport( 5 );
+		input_latch[2] = input_port_read(space->machine, "IN2");
+		input_latch[3] = input_port_read(space->machine, "IN3");
 	}
 }
 
@@ -193,8 +195,8 @@ READ8_HANDLER( vsnes_in0_1_r )
 	/* shift */
 	input_latch[2] >>= 1;
 
-	ret |= readinputport( 6 ); 				/* merge coins, etc */
-	ret |= ( readinputport( 7 ) & 3 ) << 3; /* merge 2 dipswitches */
+	ret |= input_port_read(space->machine, "COINS2"); 				/* merge coins, etc */
+	ret |= ( input_port_read(space->machine, "DSW1") & 3 ) << 3;	/* merge 2 dipswitches */
 	return ret;
 }
 
@@ -202,7 +204,7 @@ READ8_HANDLER( vsnes_in1_1_r )
 {
 	int ret = ( input_latch[3] ) & 1;
 
-	ret |= readinputport( 7 ) & ~3;			/* merge the rest of the dipswitches */
+	ret |= input_port_read(space->machine, "DSW1") & ~3;			/* merge the rest of the dipswitches */
 
 	/* shift */
 	input_latch[3] >>= 1;
@@ -219,11 +221,13 @@ READ8_HANDLER( vsnes_in1_1_r )
 
 MACHINE_RESET( vsnes )
 {
+	last_bank = 0xff;
+	sound_fix = 0;
 	input_latch[0] = input_latch[1] = 0;
 	input_latch[2] = input_latch[3] = 0;
 
 	/* reset the ppu */
-	ppu2c0x_reset( 0, 1 );
+	ppu2c0x_reset( machine, 0, 1 );
 
 	/* if we need to remap, install the callback */
 	if ( remapped_colortable )
@@ -241,8 +245,8 @@ MACHINE_RESET( vsdual )
 	input_latch[2] = input_latch[3] = 0;
 
 	/* reset the ppu */
-	ppu2c0x_reset( 0,1);
-	ppu2c0x_reset( 1,1 );
+	ppu2c0x_reset( machine,0,1 );
+	ppu2c0x_reset( machine,1,1 );
 
 	/* if we need to remap, install the callback */
 	if ( remapped_colortable )
@@ -280,7 +284,7 @@ static WRITE8_HANDLER( vsnormal_vrom_banking )
 	/* bit 1 ( data & 2 ) enables writes to extra ram, we ignore it */
 
 	/* move along */
-	vsnes_in0_w( offset, data );
+	vsnes_in0_w( space, offset, data );
 }
 
 /* Most games switch VROM Banks in controller 0 write */
@@ -288,21 +292,20 @@ static WRITE8_HANDLER( vsnormal_vrom_banking )
 DRIVER_INIT( vsnormal )
 {
 	/* vrom switching is enabled with bit 2 of $4016 */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4016, 0x4016, 0, 0, vsnormal_vrom_banking );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x4016, 0x4016, 0, 0, vsnormal_vrom_banking );
 }
 
 static WRITE8_HANDLER( ppuRC2C05_protection )
 {
 	/* This PPU has registers mapped at $2000 and $2001 inverted */
 	/* and no remapped color */
-
 	if ( offset == 0 )
 	{
-		ppu2c0x_0_w( 1, data );
+		ppu2c0x_0_w( space, 1, data );
 		return;
 	}
 
-	ppu2c0x_0_w( 0, data );
+	ppu2c0x_0_w( space, 0, data );
 }
 
 /**********************************************************************************/
@@ -318,8 +321,8 @@ DRIVER_INIT( suprmrio )
 	DRIVER_INIT_CALL(vsnormal);
 
 	/* extra ram at $6000 is enabled with bit 1 of $4016 */
-	memory_install_readwrite8_handler(0, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MRA8_BANK1, MWA8_BANK1 );
-	memory_set_bankptr(1, auto_malloc(0x2000));
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x6000, 0x7fff, 0, 0, SMH_BANK1, SMH_BANK1 );
+	memory_set_bankptr(machine, 1, auto_malloc(0x2000));
 
 	/* now override the vidaccess callback */
 	/* we need to remap color tables */
@@ -346,15 +349,14 @@ static WRITE8_HANDLER( gun_in0_w )
 	{
 
 		/* load up the latches */
-		input_latch[0] = readinputport( 0 );
+		input_latch[0] = input_port_read(space->machine, "IN0");
 
 		/* do the gun thing */
 		if ( vsnes_gun_controller )
 		{
-			int x = readinputport( 4 );
-			int y = readinputport( 5 );
+			int x = input_port_read(space->machine, "GUNX");
+			int y = input_port_read(space->machine, "GUNY");
 			UINT32 pix, color_base;
-			const pen_t *pens = Machine->pens;
 
 			/* get the pixel at the gun position */
 			pix = ppu2c0x_get_pixel( 0, x, y );
@@ -363,14 +365,14 @@ static WRITE8_HANDLER( gun_in0_w )
 			color_base = ppu2c0x_get_colorbase( 0 );
 
 			/* look at the screen and see if the cursor is over a bright pixel */
-			if ( ( pix == pens[color_base+0x20] ) || ( pix == pens[color_base+0x30] ) ||
-				 ( pix == pens[color_base+0x33] ) || ( pix == pens[color_base+0x34] ) )
+			if ( ( pix == color_base+0x20 ) || ( pix == color_base+0x30 ) ||
+				 ( pix == color_base+0x33 ) || ( pix == color_base+0x34 ) )
 			{
 				input_latch[0] |= 0x40;
 			}
 		}
 
-		input_latch[1] = readinputport( 1 );
+		input_latch[1] = input_port_read(space->machine, "IN1");
 	}
 
     if ( ( zapstore & 1 ) && ( !( data & 1 ) ) )
@@ -384,9 +386,8 @@ static WRITE8_HANDLER( gun_in0_w )
 
 DRIVER_INIT( duckhunt )
 {
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4016, 0x4016, 0, 0, gun_in0_r);
 	/* vrom switching is enabled with bit 2 of $4016 */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4016, 0x4016, 0, 0, gun_in0_w );
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x4016, 0x4016, 0, 0, gun_in0_r, gun_in0_w );
 
 	/* common init */
 	init_vsnes(machine);
@@ -408,15 +409,12 @@ static WRITE8_HANDLER( goonies_rom_banking )
 	switch( reg )
 	{
 		case 0: /* code bank 0 */
-			memcpy( &memory_region( REGION_CPU1 )[0x08000], &memory_region( REGION_CPU1 )[bankoffset], 0x2000 );
-		break;
-
 		case 2: /* code bank 1 */
-			memcpy( &memory_region( REGION_CPU1 )[0x0a000], &memory_region( REGION_CPU1 )[bankoffset], 0x2000 );
-		break;
-
 		case 4: /* code bank 2 */
-			memcpy( &memory_region( REGION_CPU1 )[0x0c000], &memory_region( REGION_CPU1 )[bankoffset], 0x2000 );
+		{
+			UINT8 *prg = memory_region( space->machine, "main" );
+			memcpy( &prg[0x08000 + reg*0x1000], &prg[bankoffset], 0x2000 );
+		}
 		break;
 
 		case 6: /* vrom bank 0 */
@@ -433,10 +431,11 @@ DRIVER_INIT( goonies )
 {
 	/* We do manual banking, in case the code falls through */
 	/* Copy the initial banks */
-	memcpy( &memory_region( REGION_CPU1 )[0x08000], &memory_region( REGION_CPU1 )[0x18000], 0x8000 );
+	UINT8 *prg = memory_region( machine, "main" );
+	memcpy( &prg[0x08000], &prg[0x18000], 0x8000 );
 
 	/* banking is done with writes to the $8000-$ffff area */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, goonies_rom_banking );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, goonies_rom_banking );
 
 	/* common init */
 	init_vsnes(machine);
@@ -449,10 +448,11 @@ DRIVER_INIT( vsgradus )
 {
 	/* We do manual banking, in case the code falls through */
 	/* Copy the initial banks */
-	memcpy( &memory_region( REGION_CPU1 )[0x08000], &memory_region( REGION_CPU1 )[0x18000], 0x8000 );
+	UINT8 *prg = memory_region( machine, "main" );
+	memcpy( &prg[0x08000], &prg[0x18000], 0x8000 );
 
 	/* banking is done with writes to the $8000-$ffff area */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, goonies_rom_banking );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, goonies_rom_banking );
 
 	/* common init */
 	init_vsnes(machine);
@@ -477,9 +477,8 @@ DRIVER_INIT( vspinbal )
 DRIVER_INIT( hogalley )
 {
 
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4016, 0x4016, 0, 0, gun_in0_r);
 	/* vrom switching is enabled with bit 2 of $4016 */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4016, 0x4016, 0, 0, gun_in0_w );
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x4016, 0x4016, 0, 0, gun_in0_r, gun_in0_w );
 
 	/* common init */
 	init_vsnes(machine);
@@ -499,7 +498,7 @@ DRIVER_INIT( hogalley )
 static READ8_HANDLER( vsgshoe_security_r )
 {
 	/* low part must be 0x1c */
-	return ppu2c0x_0_r( 2 ) | 0x1c;
+	return ppu2c0x_0_r( space, 2 ) | 0x1c;
 }
 
 static WRITE8_HANDLER( vsgshoe_gun_in0_w )
@@ -508,26 +507,27 @@ static WRITE8_HANDLER( vsgshoe_gun_in0_w )
 	int addr;
 	if((data & 0x04) != old_bank)
 	{
+		UINT8 *prg = memory_region( space->machine, "main" );
 		old_bank = data & 0x04;
 		addr = old_bank ? 0x12000: 0x10000;
-		memcpy (&memory_region( REGION_CPU1 )[0x08000], &memory_region( REGION_CPU1 )[addr], 0x2000);
+		memcpy (&prg[0x08000], &prg[addr], 0x2000);
 	}
 
-	gun_in0_w(offset, data);
+	gun_in0_w(space, offset, data);
 }
 
 DRIVER_INIT( vsgshoe )
 {
 	/* set up the default bank */
-	memcpy (&memory_region( REGION_CPU1 )[0x08000], &memory_region( REGION_CPU1 )[0x12000], 0x2000);
+	UINT8 *prg = memory_region( machine, "main" );
+	memcpy (&prg[0x08000], &prg[0x12000], 0x2000);
 
 	/* Protection */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2002, 0x2002, 0, 0, vsgshoe_security_r );
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x2001, 0, 0, ppuRC2C05_protection );
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2002, 0x2002, 0, 0, vsgshoe_security_r );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2000, 0x2001, 0, 0, ppuRC2C05_protection );
 
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4016, 0x4016, 0, 0, gun_in0_r);
 	/* vrom switching is enabled with bit 2 of $4016 */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4016, 0x4016, 0, 0, vsgshoe_gun_in0_w );
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x4016, 0x4016, 0, 0, gun_in0_r, vsgshoe_gun_in0_w );
 
 	/* common init */
 	init_vsnes(machine);
@@ -625,11 +625,12 @@ static WRITE8_HANDLER( drmario_rom_banking )
 			case 3:	/* program banking */
 				{
 					int bank = ( drmario_shiftreg & 0x03 ) * 0x4000;
+					UINT8 *prg = memory_region( space->machine, "main" );
 
 					if ( !size16k )
 					{
 						/* switch 32k */
-						memcpy( &memory_region( REGION_CPU1 )[0x08000], &memory_region( REGION_CPU1 )[0x010000+bank], 0x8000 );
+						memcpy( &prg[0x08000], &prg[0x010000+bank], 0x8000 );
 					}
 					else
 					{
@@ -637,12 +638,12 @@ static WRITE8_HANDLER( drmario_rom_banking )
 						if ( switchlow )
 						{
 							/* low */
-							memcpy( &memory_region( REGION_CPU1 )[0x08000], &memory_region( REGION_CPU1 )[0x010000+bank], 0x4000 );
+							memcpy( &prg[0x08000], &prg[0x010000+bank], 0x4000 );
 						}
 						else
 						{
 							/* high */
-							memcpy( &memory_region( REGION_CPU1 )[0x0c000], &memory_region( REGION_CPU1 )[0x010000+bank], 0x4000 );
+							memcpy( &prg[0x0c000], &prg[0x010000+bank], 0x4000 );
 						}
 					}
 				}
@@ -657,11 +658,12 @@ DRIVER_INIT( drmario )
 {
 	/* We do manual banking, in case the code falls through */
 	/* Copy the initial banks */
-	memcpy( &memory_region( REGION_CPU1 )[0x08000], &memory_region( REGION_CPU1 )[0x10000], 0x4000 );
-	memcpy( &memory_region( REGION_CPU1 )[0x0c000], &memory_region( REGION_CPU1 )[0x1c000], 0x4000 );
+	UINT8 *prg = memory_region( machine, "main" );
+	memcpy( &prg[0x08000], &prg[0x10000], 0x4000 );
+	memcpy( &prg[0x0c000], &prg[0x1c000], 0x4000 );
 
 	/* MMC1 mapper at writes to $8000-$ffff */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, drmario_rom_banking );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, drmario_rom_banking );
 
 	drmario_shiftreg = 0;
 	drmario_shiftcount = 0;
@@ -746,17 +748,19 @@ DRIVER_INIT( vsslalom )
 static WRITE8_HANDLER( castlevania_rom_banking )
 {
 	int rombank = 0x10000 + ( data & 7 ) * 0x4000;
+	UINT8 *prg = memory_region( space->machine, "main" );
 
-	memcpy( &memory_region( REGION_CPU1 )[0x08000], &memory_region( REGION_CPU1 )[rombank], 0x4000 );
+	memcpy( &prg[0x08000], &prg[rombank], 0x4000 );
 }
 
 DRIVER_INIT( cstlevna )
 {
 	/* when starting the game, the 1st 16k and the last 16k are loaded into the 2 banks */
-	memcpy( &memory_region( REGION_CPU1 )[0x08000], &memory_region( REGION_CPU1 )[0x28000], 0x8000 );
+	UINT8 *prg = memory_region( machine, "main" );
+	memcpy( &prg[0x08000], &prg[0x28000], 0x8000 );
 
    	/* banking is done with writes to the $8000-$ffff area */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, castlevania_rom_banking );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, castlevania_rom_banking );
 
 	/* common init */
 	init_vsnes(machine);
@@ -774,20 +778,21 @@ DRIVER_INIT( cstlevna )
 static READ8_HANDLER( topgun_security_r )
 {
 	/* low part must be 0x1b */
-	return ppu2c0x_0_r( 2 ) | 0x1b;
+	return ppu2c0x_0_r( space, 2 ) | 0x1b;
 }
 
 DRIVER_INIT( topgun )
 {
 	/* when starting the game, the 1st 16k and the last 16k are loaded into the 2 banks */
-	memcpy( &memory_region( REGION_CPU1 )[0x08000], &memory_region( REGION_CPU1 )[0x28000], 0x8000 );
+	UINT8 *prg = memory_region( machine, "main" );
+	memcpy( &prg[0x08000], &prg[0x28000], 0x8000 );
 
    	/* banking is done with writes to the $8000-$ffff area */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, castlevania_rom_banking );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, castlevania_rom_banking );
 
 	/* tap on the PPU, due to some tricky protection */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2002, 0x2002, 0, 0, topgun_security_r );
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x2001, 0, 0, ppuRC2C05_protection );
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2002, 0x2002, 0, 0, topgun_security_r );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2000, 0x2001, 0, 0, ppuRC2C05_protection );
 
 	/* common init */
 	init_vsnes(machine);
@@ -800,25 +805,26 @@ static int MMC3_chr[6];
 static int MMC3_prg_chunks, MMC3_prg_mask;
 static int IRQ_enable, IRQ_count, IRQ_count_latch;
 
-static void mapper4_set_prg (void)
+static void mapper4_set_prg (const address_space *space)
 {
+	UINT8 *prg = memory_region( space->machine, "main" );
 	MMC3_prg0 &= MMC3_prg_mask;
 	MMC3_prg1 &= MMC3_prg_mask;
 
 	if (MMC3_cmd & 0x40)
 	{
-		memcpy( &memory_region( REGION_CPU1 )[0x8000], &memory_region( REGION_CPU1 )[(MMC3_prg_chunks-1) * 0x4000 + 0x10000], 0x2000 );
-		memcpy( &memory_region( REGION_CPU1 )[0xc000], &memory_region( REGION_CPU1 )[0x2000 * (MMC3_prg0) + 0x10000], 0x2000 );
+		memcpy( &prg[0x8000], &prg[(MMC3_prg_chunks-1) * 0x4000 + 0x10000], 0x2000 );
+		memcpy( &prg[0xc000], &prg[0x2000 * (MMC3_prg0) + 0x10000], 0x2000 );
 	}
 	else
 	{
-		memcpy( &memory_region( REGION_CPU1 )[0x8000], &memory_region( REGION_CPU1 )[0x2000 * (MMC3_prg0) + 0x10000], 0x2000 );
-		memcpy( &memory_region( REGION_CPU1 )[0xc000], &memory_region( REGION_CPU1 )[(MMC3_prg_chunks-1) * 0x4000 + 0x10000], 0x2000 );
+		memcpy( &prg[0x8000], &prg[0x2000 * (MMC3_prg0) + 0x10000], 0x2000 );
+		memcpy( &prg[0xc000], &prg[(MMC3_prg_chunks-1) * 0x4000 + 0x10000], 0x2000 );
 	}
-	memcpy( &memory_region( REGION_CPU1 )[0xa000], &memory_region( REGION_CPU1 )[0x2000 * (MMC3_prg1) + 0x10000], 0x2000 );
+	memcpy( &prg[0xa000], &prg[0x2000 * (MMC3_prg1) + 0x10000], 0x2000 );
 }
 
-static void mapper4_set_chr (void)
+static void mapper4_set_chr (const address_space *space)
 {
 	UINT8 chr_page = (MMC3_cmd & 0x80) >> 5;
 	ppu2c0x_set_videorom_bank(0, chr_page ^ 0, 2, MMC3_chr[0], 1);
@@ -832,7 +838,7 @@ static void mapper4_set_chr (void)
 #define BOTTOM_VISIBLE_SCANLINE	239		/* The bottommost visible scanline */
 #define NUM_SCANLINE 262
 
-static void mapper4_irq ( int num, int scanline, int vblank, int blanked )
+static void mapper4_irq ( running_machine *machine, int num, int scanline, int vblank, int blanked )
 {
 	mame_printf_debug("entra\n");
 	if ((scanline < BOTTOM_VISIBLE_SCANLINE) || (scanline == NUM_SCANLINE-1))
@@ -842,7 +848,7 @@ static void mapper4_irq ( int num, int scanline, int vblank, int blanked )
 			if (IRQ_count == 0)
 			{
 				IRQ_count = IRQ_count_latch;
-				cpunum_set_input_line (Machine, 0, 0, HOLD_LINE);
+				cpu_set_input_line (machine->cpu[0], 0, HOLD_LINE);
 			}
 			IRQ_count --;
 		}
@@ -851,8 +857,6 @@ static void mapper4_irq ( int num, int scanline, int vblank, int blanked )
 
 static WRITE8_HANDLER( mapper4_w )
 {
-	static UINT8 last_bank = 0xff;
-
 	switch (offset & 0x7001)
 	{
 		case 0x0000: /* $8000 */
@@ -862,8 +866,8 @@ static WRITE8_HANDLER( mapper4_w )
 			if (last_bank != (data & 0xc0))
 			{
 				/* Reset the banks */
-				mapper4_set_prg ();
-				mapper4_set_chr ();
+				mapper4_set_prg (space);
+				mapper4_set_chr (space);
 
 			}
 			last_bank = data & 0xc0;
@@ -877,24 +881,24 @@ static WRITE8_HANDLER( mapper4_w )
 				case 0: case 1:
 					data &= 0xfe;
 					MMC3_chr[cmd] = data * 64;
-					mapper4_set_chr ();
+					mapper4_set_chr (space);
 
 					break;
 
 				case 2: case 3: case 4: case 5:
 					MMC3_chr[cmd] = data * 64;
-					mapper4_set_chr ();
+					mapper4_set_chr (space);
 
 					break;
 
 				case 6:
 					MMC3_prg0 = data;
-					mapper4_set_prg ();
+					mapper4_set_prg (space);
 					break;
 
 				case 7:
 					MMC3_prg1 = data;
-					mapper4_set_prg ();
+					mapper4_set_prg (space);
 					break;
 			}
 			break;
@@ -950,26 +954,27 @@ static WRITE8_HANDLER( mapper4_w )
 
 DRIVER_INIT( MMC3 )
 {
+	UINT8 *prg = memory_region( machine, "main" );
 	IRQ_enable = IRQ_count = IRQ_count_latch = 0;
 	MMC3_prg0 = 0xfe;
 	MMC3_prg1 = 0xff;
 	MMC3_cmd = 0;
 
-	MMC3_prg_chunks = (memory_region_length(REGION_CPU1) - 0x10000) / 0x4000;
+	MMC3_prg_chunks = (memory_region_length(machine, "main") - 0x10000) / 0x4000;
 
 	MMC3_prg_mask = ((MMC3_prg_chunks << 1) - 1);
 
-	memcpy( &memory_region( REGION_CPU1 )[0x8000], &memory_region( REGION_CPU1 )[(MMC3_prg_chunks-1) * 0x4000 + 0x10000], 0x2000 );
-	memcpy( &memory_region( REGION_CPU1 )[0xa000], &memory_region( REGION_CPU1 )[(MMC3_prg_chunks-1) * 0x4000 + 0x12000], 0x2000 );
-	memcpy( &memory_region( REGION_CPU1 )[0xc000], &memory_region( REGION_CPU1 )[(MMC3_prg_chunks-1) * 0x4000 + 0x10000], 0x2000 );
-	memcpy( &memory_region( REGION_CPU1 )[0xe000], &memory_region( REGION_CPU1 )[(MMC3_prg_chunks-1) * 0x4000 + 0x12000], 0x2000 );
+	memcpy( &prg[0x8000], &prg[(MMC3_prg_chunks-1) * 0x4000 + 0x10000], 0x2000 );
+	memcpy( &prg[0xa000], &prg[(MMC3_prg_chunks-1) * 0x4000 + 0x12000], 0x2000 );
+	memcpy( &prg[0xc000], &prg[(MMC3_prg_chunks-1) * 0x4000 + 0x10000], 0x2000 );
+	memcpy( &prg[0xe000], &prg[(MMC3_prg_chunks-1) * 0x4000 + 0x12000], 0x2000 );
 
 	/* MMC3 mapper at writes to $8000-$ffff */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, mapper4_w );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, mapper4_w );
 
 	/* extra ram at $6000-$7fff */
-	memory_install_readwrite8_handler(0, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MRA8_BANK1, MWA8_BANK1 );
-	memory_set_bankptr(1, auto_malloc(0x2000));
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x6000, 0x7fff, 0, 0, SMH_BANK1, SMH_BANK1 );
+	memory_set_bankptr(machine, 1, auto_malloc(0x2000));
 
 	/* common init */
 	init_vsnes(machine);
@@ -1013,7 +1018,7 @@ DRIVER_INIT( rbibb )
 	DRIVER_INIT_CALL(MMC3);
 
 	/* RBI Base ball hack */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5e00, 0x5e01, 0, 0, rbi_hack_r) ;
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x5e00, 0x5e01, 0, 0, rbi_hack_r) ;
 
 	remapped_colortable = rp2c04003_colortable;
 }
@@ -1063,10 +1068,10 @@ DRIVER_INIT( supxevs )
 	DRIVER_INIT_CALL(MMC3);
 
 	/* Vs. Super Xevious Protection */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x54ff, 0x54ff, 0, 0, supxevs_read_prot_1_r );
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5678, 0x5678, 0, 0, supxevs_read_prot_2_r );
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x578f, 0x578f, 0, 0, supxevs_read_prot_3_r );
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5567, 0x5567, 0, 0, supxevs_read_prot_4_r );
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x54ff, 0x54ff, 0, 0, supxevs_read_prot_1_r );
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x5678, 0x5678, 0, 0, supxevs_read_prot_2_r );
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x578f, 0x578f, 0, 0, supxevs_read_prot_3_r );
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x5567, 0x5567, 0, 0, supxevs_read_prot_4_r );
 
 	remapped_colortable = rp2c04001_colortable;
 }
@@ -1098,7 +1103,7 @@ DRIVER_INIT( tkoboxng )
 	DRIVER_INIT_CALL(MMC3);
 
 	/* security device at $5e00-$5e01 */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x5e00, 0x5e01, 0, 0, tko_security_r );
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x5e00, 0x5e01, 0, 0, tko_security_r );
 
 	/* now override the vidaccess callback */
 	/* we need to remap color tables */
@@ -1112,8 +1117,7 @@ DRIVER_INIT( vsfdf )
 {
 	DRIVER_INIT_CALL(MMC3);
 
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4016, 0x4016, 0, 0, gun_in0_r );
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4016, 0x4016, 0, 0, gun_in0_w );
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x4016, 0x4016, 0, 0, gun_in0_r, gun_in0_w );
 
 	vsnes_gun_controller = 1;
 	vsnes_do_vrom_bank = 0;
@@ -1146,7 +1150,10 @@ static WRITE8_HANDLER( mapper68_rom_banking ){
 		break;
 
 		case 0x7000:
-		memcpy( &memory_region( REGION_CPU1 )[0x08000], &memory_region( REGION_CPU1 )[0x10000 +data*0x4000], 0x4000 );
+		{
+			UINT8 *prg = memory_region( space->machine, "main" );
+			memcpy( &prg[0x08000], &prg[0x10000 +data*0x4000], 0x4000 );
+		}
 		break;
 
 	}
@@ -1159,10 +1166,11 @@ DRIVER_INIT( platoon )
 	/* when starting a mapper 68 game  the first 16K ROM bank in the cart is loaded into $8000
     the LAST 16K ROM bank is loaded into $C000. The last 16K of ROM cannot be swapped. */
 
-	memcpy( &memory_region( REGION_CPU1 )[0x08000], &memory_region( REGION_CPU1 )[0x10000], 0x4000 );
-	memcpy( &memory_region( REGION_CPU1 )[0x0c000], &memory_region( REGION_CPU1 )[0x2c000], 0x4000 );
+	UINT8 *prg = memory_region( machine, "main" );
+	memcpy( &prg[0x08000], &prg[0x10000], 0x4000 );
+	memcpy( &prg[0x0c000], &prg[0x2c000], 0x4000 );
 
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0xffff, 0, 0, mapper68_rom_banking );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x8000, 0xffff, 0, 0, mapper68_rom_banking );
 
 	init_vsnes(machine);
 
@@ -1177,7 +1185,7 @@ static int ret;
 static WRITE8_HANDLER ( set_bnglngby_irq_w )
 {
 	ret = data;
-	cpunum_set_input_line(Machine, 0, 0, ( data & 2 ) ? ASSERT_LINE : CLEAR_LINE );
+	cpu_set_input_line(space->machine->cpu[0], 0, ( data & 2 ) ? ASSERT_LINE : CLEAR_LINE );
 	/* other values ??? */
 	/* 0, 4, 84 */
 }
@@ -1189,12 +1197,11 @@ static READ8_HANDLER ( set_bnglngby_irq_r )
 
 DRIVER_INIT( bnglngby )
 {
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0231, 0x0231, 0, 0, set_bnglngby_irq_r );
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0231, 0x0231, 0, 0, set_bnglngby_irq_w );
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x0231, 0x0231, 0, 0, set_bnglngby_irq_r, set_bnglngby_irq_w );
 
 	/* extra ram */
-	memory_install_readwrite8_handler(0, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MRA8_BANK1, MWA8_BANK1 );
-	memory_set_bankptr(1, auto_malloc(0x2000));
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x6000, 0x7fff, 0, 0, SMH_BANK1, SMH_BANK1 );
+	memory_set_bankptr(machine, 1, auto_malloc(0x2000));
 
 	ret = 0;
 
@@ -1213,7 +1220,7 @@ DRIVER_INIT( bnglngby )
 static READ8_HANDLER( jajamaru_security_r )
 {
 	/* low part must be 0x40 */
-	return ppu2c0x_0_r( 2 ) | 0x40;
+	return ppu2c0x_0_r( space, 2 ) | 0x40;
 }
 
 DRIVER_INIT( jajamaru )
@@ -1223,8 +1230,8 @@ DRIVER_INIT( jajamaru )
 	//Maybe it should be a DOP (double NOP)
 
 	/* Protection */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2002, 0x2002, 0, 0, jajamaru_security_r );
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x2001, 0, 0, ppuRC2C05_protection );
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2002, 0x2002, 0, 0, jajamaru_security_r );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2000, 0x2001, 0, 0, ppuRC2C05_protection );
 
 	/* common init */
 	init_vsnes(machine);
@@ -1240,14 +1247,14 @@ DRIVER_INIT( jajamaru )
 static READ8_HANDLER( mightybj_security_r )
 {
 	/* low part must be 0x3d */
-	return ppu2c0x_0_r( 2 ) | 0x3d;
+	return ppu2c0x_0_r( space, 2 ) | 0x3d;
 }
 
 DRIVER_INIT( mightybj )
 {
 	/* Protection */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2002, 0x2002, 0, 0, mightybj_security_r );
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x2000, 0x2001, 0, 0, ppuRC2C05_protection );
+	memory_install_read8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2002, 0x2002, 0, 0, mightybj_security_r );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x2000, 0x2001, 0, 0, ppuRC2C05_protection );
 
 	/* common init */
 	init_vsnes(machine);
@@ -1258,34 +1265,34 @@ DRIVER_INIT( mightybj )
 
 static WRITE8_HANDLER( vstennis_vrom_banking )
 {
-	int other_cpu = cpu_getactivecpu() ^ 1;
+	const device_config *other_cpu = (space->cpu == space->machine->cpu[0]) ? space->machine->cpu[1] : space->machine->cpu[0];
 
 	/* switch vrom */
-	ppu2c0x_set_videorom_bank( cpu_getactivecpu(), 0, 8, ( data & 4 ) ? 1 : 0, 512 );
+	ppu2c0x_set_videorom_bank( (space->cpu == space->machine->cpu[0]) ? 0 : 1, 0, 8, ( data & 4 ) ? 1 : 0, 512 );
 
 	/* bit 1 ( data & 2 ) triggers irq on the other cpu */
-	cpunum_set_input_line(Machine, other_cpu, 0, ( data & 2 ) ? CLEAR_LINE : ASSERT_LINE );
+	cpu_set_input_line(other_cpu, 0, ( data & 2 ) ? CLEAR_LINE : ASSERT_LINE );
 
 	/* move along */
-	if ( cpu_getactivecpu() == 0 )
-		vsnes_in0_w( offset, data );
+	if (space->cpu == space->machine->cpu[0])
+		vsnes_in0_w( space, offset, data );
 	else
-		vsnes_in0_1_w( offset, data );
+		vsnes_in0_1_w( space, offset, data );
 }
 
 DRIVER_INIT( vstennis )
 {
+	UINT8 *prg = memory_region( machine, "main" );
+
 	/* vrom switching is enabled with bit 2 of $4016 */
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x4016, 0x4016, 0, 0, vstennis_vrom_banking );
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x4016, 0x4016, 0, 0, vstennis_vrom_banking );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x4016, 0x4016, 0, 0, vstennis_vrom_banking );
+	memory_install_write8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x4016, 0x4016, 0, 0, vstennis_vrom_banking );
 
 	/* shared ram at $6000 */
-	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MRA8_BANK1 );
-	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MWA8_BANK1 );
-	memory_install_read8_handler(1, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MRA8_BANK1 );
-	memory_install_write8_handler(1, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MWA8_BANK1 );
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x6000, 0x7fff, 0, 0, SMH_BANK1, SMH_BANK1 );
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[1], ADDRESS_SPACE_PROGRAM), 0x6000, 0x7fff, 0, 0, SMH_BANK1, SMH_BANK1 );
 
-	memory_set_bankptr(1, &memory_region(REGION_CPU1)[0x6000]);
+	memory_set_bankptr(machine, 1, &prg[0x6000]);
 }
 
 /**********************************************************************/
@@ -1353,8 +1360,8 @@ DRIVER_INIT( btlecity )
 DRIVER_INIT( vstetris )
 {
 	/* extra ram at $6000 is enabled with bit 1 of $4016 */
-	memory_install_readwrite8_handler(0, ADDRESS_SPACE_PROGRAM, 0x6000, 0x7fff, 0, 0, MRA8_BANK1, MWA8_BANK1 );
-	memory_set_bankptr(1, auto_malloc(0x2000));
+	memory_install_readwrite8_handler(cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM), 0x6000, 0x7fff, 0, 0, SMH_BANK1, SMH_BANK1 );
+	memory_set_bankptr(machine, 1, auto_malloc(0x2000));
 
 	init_vsnes(machine);
 	DRIVER_INIT_CALL(vsnormal);
