@@ -5,7 +5,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "audio/williams.h"
 #include "cpu/m6800/m6800.h"
 #include "cpu/m6809/m6809.h"
@@ -32,24 +31,22 @@ static UINT8 vram_bank;
 static UINT16 joust2_current_sound_data;
 
 /* older-Williams routines */
-static void williams_main_irq(int state);
-static void williams_main_firq(int state);
-static void williams_snd_irq(int state);
+static void williams_main_irq(running_machine *machine, int state);
+static void williams_main_firq(running_machine *machine, int state);
+static void williams_snd_irq(running_machine *machine, int state);
 static WRITE8_HANDLER( williams_snd_cmd_w );
 static WRITE8_HANDLER( playball_snd_cmd_w );
 
 /* input port mapping */
 static UINT8 port_select;
 static WRITE8_HANDLER( williams_port_select_w );
-static READ8_HANDLER( williams_input_port_0_3_r );
 static READ8_HANDLER( williams_input_port_49way_0_5_r );
-static READ8_HANDLER( williams_input_port_1_4_r );
 static READ8_HANDLER( williams_49way_port_0_r );
 
 /* newer-Williams routines */
 static WRITE8_HANDLER( williams2_snd_cmd_w );
-static void mysticm_main_irq(int state);
-static void tshoot_main_irq(int state);
+static void mysticm_main_irq(running_machine *machine, int state);
+static void tshoot_main_irq(running_machine *machine, int state);
 
 /* Lotto Fun-specific code */
 static READ8_HANDLER( lottofun_input_port_0_r );
@@ -80,17 +77,11 @@ const pia6821_interface williams_pia_0_intf =
 };
 
 /* Generic muxing PIA 0, maps to input ports 0/3 and 1; port select is CB2 */
+/* Generic dual muxing PIA 0, maps to input ports 0/3 and 1/4; port select is CB2 */
+/* muxing done in williams_mux_r */
 const pia6821_interface williams_muxed_pia_0_intf =
 {
-	/*inputs : A/B,CA/B1,CA/B2 */ williams_input_port_0_3_r, input_port_1_r, 0, 0, 0, 0,
-	/*outputs: A/B,CA/B2       */ 0, 0, 0, williams_port_select_w,
-	/*irqs   : A/B             */ 0, 0
-};
-
-/* Generic dual muxing PIA 0, maps to input ports 0/3 and 1/4; port select is CB2 */
-const pia6821_interface williams_dual_muxed_pia_0_intf =
-{
-	/*inputs : A/B,CA/B1,CA/B2 */ williams_input_port_0_3_r, williams_input_port_1_4_r, 0, 0, 0, 0,
+	/*inputs : A/B,CA/B1,CA/B2 */ input_port_0_r, input_port_1_r, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, 0, 0, williams_port_select_w,
 	/*irqs   : A/B             */ 0, 0
 };
@@ -123,7 +114,7 @@ const pia6821_interface williams_pia_1_intf =
 const pia6821_interface williams_snd_pia_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
-	/*outputs: A/B,CA/B2       */ DAC_0_data_w, 0, 0, 0,
+	/*outputs: A/B,CA/B2       */ dac_0_data_w, 0, 0, 0,
 	/*irqs   : A/B             */ williams_snd_irq, williams_snd_irq
 };
 
@@ -147,7 +138,7 @@ const pia6821_interface lottofun_pia_0_intf =
 const pia6821_interface sinistar_snd_pia_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
-	/*outputs: A/B,CA/B2       */ DAC_0_data_w, 0, hc55516_0_digit_w, hc55516_0_clock_w,
+	/*outputs: A/B,CA/B2       */ dac_0_data_w, 0, hc55516_0_digit_w, hc55516_0_clock_w,
 	/*irqs   : A/B             */ williams_snd_irq, williams_snd_irq
 };
 
@@ -178,7 +169,7 @@ const pia6821_interface spdball_pia_3_intf =
 /* Generic muxing PIA 0, maps to input ports 0/3 and 1; port select is CA2 */
 const pia6821_interface williams2_muxed_pia_0_intf =
 {
-	/*inputs : A/B,CA/B1,CA/B2 */ williams_input_port_0_3_r, input_port_1_r, 0, 0, 0, 0,
+	/*inputs : A/B,CA/B1,CA/B2 */ input_port_0_r, input_port_1_r, 0, 0, 0, 0,
 	/*outputs: A/B,CA/B2       */ 0, 0, williams_port_select_w, 0,
 	/*irqs   : A/B             */ 0, 0
 };
@@ -195,7 +186,7 @@ const pia6821_interface williams2_pia_1_intf =
 const pia6821_interface williams2_snd_pia_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
-	/*outputs: A/B,CA/B2       */ pia_1_portb_w, DAC_0_data_w, pia_1_cb1_w, 0,
+	/*outputs: A/B,CA/B2       */ pia_1_portb_w, dac_0_data_w, pia_1_cb1_w, 0,
 	/*irqs   : A/B             */ williams_snd_irq, williams_snd_irq
 };
 
@@ -243,7 +234,7 @@ const pia6821_interface tshoot_pia_1_intf =
 const pia6821_interface tshoot_snd_pia_intf =
 {
 	/*inputs : A/B,CA/B1,CA/B2 */ 0, 0, 0, 0, 0, 0,
-	/*outputs: A/B,CA/B2       */ pia_1_portb_w, DAC_0_data_w, pia_1_cb1_w, tshoot_maxvol_w,
+	/*outputs: A/B,CA/B2       */ pia_1_portb_w, dac_0_data_w, pia_1_cb1_w, tshoot_maxvol_w,
 	/*irqs   : A/B             */ williams_snd_irq, williams_snd_irq
 };
 
@@ -265,60 +256,65 @@ const pia6821_interface joust2_pia_1_intf =
 
 static TIMER_CALLBACK( williams_va11_callback )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	int scanline = param;
 
 	/* the IRQ signal comes into CB1, and is set to VA11 */
-	pia_1_cb1_w(0, scanline & 0x20);
+	pia_1_cb1_w(space, 0, scanline & 0x20);
 
 	/* set a timer for the next update */
 	scanline += 0x20;
 	if (scanline >= 256) scanline = 0;
-	timer_adjust(scanline_timer, video_screen_get_time_until_pos(0, scanline, 0), scanline, attotime_zero);
+	timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, scanline, 0), scanline);
 }
 
 
 static TIMER_CALLBACK( williams_count240_off_callback )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 	/* the COUNT240 signal comes into CA1, and is set to the logical AND of VA10-VA13 */
-	pia_1_ca1_w(0, 0);
+	pia_1_ca1_w(space, 0, 0);
 }
 
 
 static TIMER_CALLBACK( williams_count240_callback )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 	/* the COUNT240 signal comes into CA1, and is set to the logical AND of VA10-VA13 */
-	pia_1_ca1_w(0, 1);
+	pia_1_ca1_w(space, 0, 1);
 
 	/* set a timer to turn it off once the scanline counter resets */
-	timer_set(video_screen_get_time_until_pos(0, 0, 0), NULL, 0, williams_count240_off_callback);
+	timer_set(machine, video_screen_get_time_until_pos(machine->primary_screen, 0, 0), NULL, 0, williams_count240_off_callback);
 
 	/* set a timer for next frame */
-	timer_adjust(scan240_timer, video_screen_get_time_until_pos(0, 240, 0), 0, attotime_zero);
+	timer_adjust_oneshot(scan240_timer, video_screen_get_time_until_pos(machine->primary_screen, 240, 0), 0);
 }
 
 
-static void williams_main_irq(int state)
+static void williams_main_irq(running_machine *machine, int state)
 {
 	int combined_state = pia_get_irq_a(1) | pia_get_irq_b(1);
 
 	/* IRQ to the main CPU */
-	cpunum_set_input_line(Machine, 0, M6809_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], M6809_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
-static void williams_main_firq(int state)
+static void williams_main_firq(running_machine *machine, int state)
 {
 	/* FIRQ to the main CPU */
-	cpunum_set_input_line(Machine, 0, M6809_FIRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], M6809_FIRQ_LINE, state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
-static void williams_snd_irq(int state)
+static void williams_snd_irq(running_machine *machine, int state)
 {
 	int combined_state = pia_get_irq_a(2) | pia_get_irq_b(2);
 
 	/* IRQ to the sound CPU */
-	cpunum_set_input_line(Machine, 1, M6800_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[1], M6800_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -329,21 +325,21 @@ static void williams_snd_irq(int state)
  *
  *************************************/
 
-static void mysticm_main_irq(int state)
+static void mysticm_main_irq(running_machine *machine, int state)
 {
 	int combined_state = pia_get_irq_b(0) | pia_get_irq_a(1) | pia_get_irq_b(1);
 
 	/* IRQ to the main CPU */
-	cpunum_set_input_line(Machine, 0, M6809_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], M6809_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
-static void tshoot_main_irq(int state)
+static void tshoot_main_irq(running_machine *machine, int state)
 {
 	int combined_state = pia_get_irq_a(0) | pia_get_irq_b(0) | pia_get_irq_a(1) | pia_get_irq_b(1);
 
 	/* IRQ to the main CPU */
-	cpunum_set_input_line(Machine, 0, M6809_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], M6809_IRQ_LINE, combined_state ? ASSERT_LINE : CLEAR_LINE);
 }
 
 
@@ -354,33 +350,33 @@ static void tshoot_main_irq(int state)
  *
  *************************************/
 
-static void williams_common_init(void)
+static MACHINE_RESET( williams_common )
 {
 	/* reset the PIAs */
 	pia_reset();
 
 	/* reset the ticket dispenser (Lotto Fun) */
-	ticket_dispenser_init(70, TICKET_MOTOR_ACTIVE_LOW, TICKET_STATUS_ACTIVE_HIGH);
+	ticket_dispenser_init(machine, 70, TICKET_MOTOR_ACTIVE_LOW, TICKET_STATUS_ACTIVE_HIGH);
 
 	/* set a timer to go off every 16 scanlines, to toggle the VA11 line and update the screen */
-	scanline_timer = timer_alloc(williams_va11_callback, NULL);
-	timer_adjust(scanline_timer, video_screen_get_time_until_pos(0, 0, 0), 0, attotime_zero);
+	scanline_timer = timer_alloc(machine, williams_va11_callback, NULL);
+	timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, 0, 0), 0);
 
 	/* also set a timer to go off on scanline 240 */
-	scan240_timer = timer_alloc(williams_count240_callback, NULL);
-	timer_adjust(scan240_timer, video_screen_get_time_until_pos(0, 240, 0), 0, attotime_zero);
+	scan240_timer = timer_alloc(machine, williams_count240_callback, NULL);
+	timer_adjust_oneshot(scan240_timer, video_screen_get_time_until_pos(machine->primary_screen, 240, 0), 0);
 
-	state_save_register_global(vram_bank);
+	state_save_register_global(machine, vram_bank);
 }
 
 
 MACHINE_RESET( williams )
 {
-	williams_common_init();
+	MACHINE_RESET_CALL(williams_common);
 
 	/* configure the memory bank */
-	memory_configure_bank(1, 0, 1, williams_videoram, 0);
-	memory_configure_bank(1, 1, 1, memory_region(REGION_CPU1) + 0x10000, 0);
+	memory_configure_bank(machine, 1, 0, 1, williams_videoram, 0);
+	memory_configure_bank(machine, 1, 1, 1, memory_region(machine, "main") + 0x10000, 0);
 }
 
 
@@ -393,36 +389,41 @@ MACHINE_RESET( williams )
 
 static TIMER_CALLBACK( williams2_va11_callback )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 	int scanline = param;
 
 	/* the IRQ signal comes into CB1, and is set to VA11 */
-	pia_0_cb1_w(0, scanline & 0x20);
-	pia_1_ca1_w(0, scanline & 0x20);
+	pia_0_cb1_w(space, 0, scanline & 0x20);
+	pia_1_ca1_w(space, 0, scanline & 0x20);
 
 	/* set a timer for the next update */
 	scanline += 0x20;
 	if (scanline >= 256) scanline = 0;
-	timer_adjust(scanline_timer, video_screen_get_time_until_pos(0, scanline, 0), scanline, attotime_zero);
+	timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, scanline, 0), scanline);
 }
 
 
 static TIMER_CALLBACK( williams2_endscreen_off_callback )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 	/* the /ENDSCREEN signal comes into CA1 */
-	pia_0_ca1_w(0, 1);
+	pia_0_ca1_w(space, 0, 1);
 }
 
 
 static TIMER_CALLBACK( williams2_endscreen_callback )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 	/* the /ENDSCREEN signal comes into CA1 */
-	pia_0_ca1_w(0, 0);
+	pia_0_ca1_w(space, 0, 0);
 
 	/* set a timer to turn it off once the scanline counter resets */
-	timer_set(video_screen_get_time_until_pos(0, 8, 0), NULL, 0, williams2_endscreen_off_callback);
+	timer_set(machine, video_screen_get_time_until_pos(machine->primary_screen, 8, 0), NULL, 0, williams2_endscreen_off_callback);
 
 	/* set a timer for next frame */
-	timer_adjust(scan254_timer, video_screen_get_time_until_pos(0, 254, 0), 0, attotime_zero);
+	timer_adjust_oneshot(scan254_timer, video_screen_get_time_until_pos(machine->primary_screen, 254, 0), 0);
 }
 
 
@@ -433,34 +434,37 @@ static TIMER_CALLBACK( williams2_endscreen_callback )
  *
  *************************************/
 
-static void williams2_postload(void)
+static STATE_POSTLOAD( williams2_postload )
 {
-	williams2_bank_select_w(0, vram_bank);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	williams2_bank_select_w(space, 0, vram_bank);
 }
 
 
 MACHINE_RESET( williams2 )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 	/* reset the PIAs */
 	pia_reset();
 
 	/* configure memory banks */
-	memory_configure_bank(1, 0, 1, williams_videoram, 0);
-	memory_configure_bank(1, 1, 4, memory_region(REGION_CPU1) + 0x10000, 0x10000);
+	memory_configure_bank(machine, 1, 0, 1, williams_videoram, 0);
+	memory_configure_bank(machine, 1, 1, 4, memory_region(machine, "main") + 0x10000, 0x10000);
 
 	/* make sure our banking is reset */
-	williams2_bank_select_w(0, 0);
+	williams2_bank_select_w(space, 0, 0);
 
 	/* set a timer to go off every 16 scanlines, to toggle the VA11 line and update the screen */
-	scanline_timer = timer_alloc(williams2_va11_callback, NULL);
-	timer_adjust(scanline_timer, video_screen_get_time_until_pos(0, 0, 0), 0, attotime_zero);
+	scanline_timer = timer_alloc(machine, williams2_va11_callback, NULL);
+	timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, 0, 0), 0);
 
 	/* also set a timer to go off on scanline 254 */
-	scan254_timer = timer_alloc(williams2_endscreen_callback, NULL);
-	timer_adjust(scan254_timer, video_screen_get_time_until_pos(0, 254, 0), 0, attotime_zero);
+	scan254_timer = timer_alloc(machine, williams2_endscreen_callback, NULL);
+	timer_adjust_oneshot(scan254_timer, video_screen_get_time_until_pos(machine->primary_screen, 254, 0), 0);
 
-	state_save_register_global(vram_bank);
-	state_save_register_func_postload(williams2_postload);
+	state_save_register_global(machine, vram_bank);
+	state_save_register_postload(machine, williams2_postload, NULL);
 }
 
 
@@ -475,7 +479,7 @@ WRITE8_HANDLER( williams_vram_select_w )
 {
 	/* VRAM/ROM banking from bit 0 */
 	vram_bank = data & 0x01;
-	memory_set_bank(1, vram_bank);
+	memory_set_bank(space->machine, 1, vram_bank);
 
 	/* cocktail flip from bit 1 */
 	williams_cocktail = data & 0x02;
@@ -491,27 +495,26 @@ WRITE8_HANDLER( williams2_bank_select_w )
 	{
 		/* page 0 is video ram */
 		case 0:
-			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x8fff, 0, 0, MRA8_BANK1);
-			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, MWA8_BANK4);
-			memory_set_bank(1, 0);
-			memory_set_bankptr(4, &williams_videoram[0x8000]);
+			memory_install_read8_handler(space, 0x0000, 0x8fff, 0, 0, SMH_BANK1);
+			memory_install_write8_handler(space, 0x8000, 0x87ff, 0, 0, SMH_BANK4);
+			memory_set_bank(space->machine, 1, 0);
+			memory_set_bankptr(space->machine, 4, &williams_videoram[0x8000]);
 			break;
 
 		/* pages 1 and 2 are ROM */
 		case 1:
 		case 2:
-			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0000, 0x8fff, 0, 0, MRA8_BANK1);
-			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, MWA8_BANK4);
-			memory_set_bank(1, 1 + ((vram_bank & 6) >> 1));
-			memory_set_bankptr(4, &williams_videoram[0x8000]);
+			memory_install_read8_handler(space, 0x0000, 0x8fff, 0, 0, SMH_BANK1);
+			memory_install_write8_handler(space, 0x8000, 0x87ff, 0, 0, SMH_BANK4);
+			memory_set_bank(space->machine, 1, 1 + ((vram_bank & 6) >> 1));
+			memory_set_bankptr(space->machine, 4, &williams_videoram[0x8000]);
 			break;
 
 		/* page 3 accesses palette RAM; the remaining areas are as if page 1 ROM was selected */
 		case 3:
-			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, MRA8_BANK4);
-			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x87ff, 0, 0, williams2_paletteram_w);
-			memory_set_bank(1, 1 + ((vram_bank & 4) >> 1));
-			memory_set_bankptr(4, paletteram);
+			memory_install_readwrite8_handler(space, 0x8000, 0x87ff, 0, 0, SMH_BANK4, williams2_paletteram_w);
+			memory_set_bank(space->machine, 1, 1 + ((vram_bank & 4) >> 1));
+			memory_set_bankptr(space->machine, 4, paletteram);
 			break;
 	}
 }
@@ -526,30 +529,32 @@ WRITE8_HANDLER( williams2_bank_select_w )
 
 static TIMER_CALLBACK( williams_deferred_snd_cmd_w )
 {
-	pia_2_portb_w(0, param);
-	pia_2_cb1_w(0, (param == 0xff) ? 0 : 1);
+	const address_space *space = ptr;
+	pia_2_portb_w(space, 0, param);
+	pia_2_cb1_w(space, 0, (param == 0xff) ? 0 : 1);
 }
 
 WRITE8_HANDLER( williams_snd_cmd_w )
 {
 	/* the high two bits are set externally, and should be 1 */
-	timer_call_after_resynch(NULL, data | 0xc0, williams_deferred_snd_cmd_w);
+	timer_call_after_resynch(space->machine, (void *)space, data | 0xc0, williams_deferred_snd_cmd_w);
 }
 
 WRITE8_HANDLER( playball_snd_cmd_w )
 {
-	timer_call_after_resynch(NULL, data, williams_deferred_snd_cmd_w);
+	timer_call_after_resynch(space->machine, (void *)space, data, williams_deferred_snd_cmd_w);
 }
 
 
 static TIMER_CALLBACK( williams2_deferred_snd_cmd_w )
 {
-	pia_2_porta_w(0, param);
+	const address_space *space = ptr;
+	pia_2_porta_w(space, 0, param);
 }
 
 static WRITE8_HANDLER( williams2_snd_cmd_w )
 {
-	timer_call_after_resynch(NULL, data, williams2_deferred_snd_cmd_w);
+	timer_call_after_resynch(space->machine, (void *)space, data, williams2_deferred_snd_cmd_w);
 }
 
 
@@ -565,19 +570,16 @@ WRITE8_HANDLER( williams_port_select_w )
 	port_select = data;
 }
 
-
-READ8_HANDLER( williams_input_port_0_3_r )
+CUSTOM_INPUT( williams_mux_r )
 {
-	return readinputport(port_select ? 3 : 0);
+	const char *tag = param;
+
+	if (port_select != 0)
+		tag += strlen(tag) + 1;
+
+	return input_port_read(field->port->machine, tag);
 }
 
-
-READ8_HANDLER( williams_input_port_1_4_r )
-{
-	return readinputport(port_select ? 4 : 1);
-}
-
-
 /*
  *  Williams 49-way joystick
  *
@@ -606,16 +608,16 @@ READ8_HANDLER( williams_input_port_1_4_r )
 READ8_HANDLER( williams_49way_port_0_r )
 {
 	static const UINT8 translate49[7] = { 0x0, 0x4, 0x6, 0x7, 0xb, 0x9, 0x8 };
-	return (translate49[readinputportbytag("49WAYX") >> 4] << 4) | translate49[readinputportbytag("49WAYY") >> 4];
+	return (translate49[input_port_read(space->machine, "49WAYX") >> 4] << 4) | translate49[input_port_read(space->machine, "49WAYY") >> 4];
 }
 
 
 READ8_HANDLER( williams_input_port_49way_0_5_r )
 {
 	if (port_select)
-		return williams_49way_port_0_r(0);
+		return williams_49way_port_0_r(space,0);
 	else
-		return readinputport(5);
+		return input_port_read(space->machine, "IN3");
 }
 
 
@@ -651,7 +653,7 @@ WRITE8_HANDLER( williams_watchdog_reset_w )
 {
 	/* yes, the data bits are checked for this specific value */
 	if (data == 0x39)
-		watchdog_reset_w(0,0);
+		watchdog_reset_w(space,0,0);
 }
 
 
@@ -659,7 +661,7 @@ WRITE8_HANDLER( williams2_watchdog_reset_w )
 {
 	/* yes, the data bits are checked for this specific value */
 	if ((data & 0x3f) == 0x14)
-		watchdog_reset_w(0,0);
+		watchdog_reset_w(space,0,0);
 }
 
 
@@ -711,21 +713,24 @@ WRITE8_HANDLER( williams2_7segment_w )
  *
  *************************************/
 
-static void defender_postload(void)
+static STATE_POSTLOAD( defender_postload )
 {
-	defender_bank_select_w(0, vram_bank);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	defender_bank_select_w(space, 0, vram_bank);
 }
 
 
 MACHINE_RESET( defender )
 {
-	williams_common_init();
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	MACHINE_RESET_CALL(williams_common);
 
 	/* configure the banking and make sure it is reset to 0 */
-	memory_configure_bank(1, 0, 9, &memory_region(REGION_CPU1)[0x10000], 0x1000);
-	defender_bank_select_w(0, 0);
+	memory_configure_bank(machine, 1, 0, 9, &memory_region(machine, "main")[0x10000], 0x1000);
+	defender_bank_select_w(space, 0, 0);
 
-	state_save_register_func_postload(defender_postload);
+	state_save_register_postload(machine, defender_postload, NULL);
 }
 
 
@@ -744,7 +749,7 @@ WRITE8_HANDLER( defender_bank_select_w )
 	{
 		/* page 0 is I/O space */
 		case 0:
-			defender_install_io_space();
+			defender_install_io_space(space);
 			break;
 
 		/* pages 1-9 map to ROM banks */
@@ -757,15 +762,13 @@ WRITE8_HANDLER( defender_bank_select_w )
 		case 7:
 		case 8:
 		case 9:
-			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, MRA8_BANK1);
-			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, MWA8_UNMAP);
-			memory_set_bank(1, vram_bank - 1);
+			memory_install_readwrite8_handler(space, 0xc000, 0xcfff, 0, 0, SMH_BANK1, SMH_UNMAP);
+			memory_set_bank(space->machine, 1, vram_bank - 1);
 			break;
 
 		/* pages A-F are not connected */
 		default:
-			memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, MRA8_NOP);
-			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xcfff, 0, 0, MWA8_NOP);
+			memory_install_readwrite8_handler(space, 0xc000, 0xcfff, 0, 0, SMH_NOP, SMH_NOP);
 			break;
 	}
 }
@@ -783,7 +786,7 @@ READ8_HANDLER( mayday_protection_r )
 	/* Mayday does some kind of protection check that is not currently understood  */
 	/* However, the results of that protection check are stored at $a190 and $a191 */
 	/* These are compared against $a193 and $a194, respectively. Thus, to prevent  */
-	/* the protection from resetting the machine, we just return $a193 for $a190,  */
+	/* the protection from resetting the space->machine, we just return $a193 for $a190,  */
 	/* and $a194 for $a191. */
 	return mayday_protection[offset + 3];
 }
@@ -799,7 +802,7 @@ READ8_HANDLER( mayday_protection_r )
 WRITE8_HANDLER( sinistar_vram_select_w )
 {
 	/* low two bits are standard */
-	williams_vram_select_w(offset, data);
+	williams_vram_select_w(space, offset, data);
 
 	/* window enable from bit 2 (clips to 0x7400) */
 	williams_blitter_window_enable = data & 0x04;
@@ -815,23 +818,23 @@ WRITE8_HANDLER( sinistar_vram_select_w )
 
 MACHINE_RESET( blaster )
 {
-	williams_common_init();
+	MACHINE_RESET_CALL(williams_common);
 
 	/* banking is different for blaster */
-	memory_configure_bank(1, 0, 1, williams_videoram, 0);
-	memory_configure_bank(1, 1, 16, memory_region(REGION_CPU1) + 0x18000, 0x4000);
+	memory_configure_bank(machine, 1, 0, 1, williams_videoram, 0);
+	memory_configure_bank(machine, 1, 1, 16, memory_region(machine, "main") + 0x18000, 0x4000);
 
-	memory_configure_bank(2, 0, 1, williams_videoram + 0x4000, 0);
-	memory_configure_bank(2, 1, 16, memory_region(REGION_CPU1) + 0x10000, 0x0000);
+	memory_configure_bank(machine, 2, 0, 1, williams_videoram + 0x4000, 0);
+	memory_configure_bank(machine, 2, 1, 16, memory_region(machine, "main") + 0x10000, 0x0000);
 
-	state_save_register_global(blaster_bank);
+	state_save_register_global(machine, blaster_bank);
 }
 
 
-INLINE void update_blaster_banking(void)
+INLINE void update_blaster_banking(running_machine *machine)
 {
-	memory_set_bank(1, vram_bank * (blaster_bank + 1));
-	memory_set_bank(2, vram_bank * (blaster_bank + 1));
+	memory_set_bank(machine, 1, vram_bank * (blaster_bank + 1));
+	memory_set_bank(machine, 2, vram_bank * (blaster_bank + 1));
 }
 
 
@@ -839,7 +842,7 @@ WRITE8_HANDLER( blaster_vram_select_w )
 {
 	/* VRAM/ROM banking from bit 0 */
 	vram_bank = data & 0x01;
-	update_blaster_banking();
+	update_blaster_banking(space->machine);
 
 	/* cocktail flip from bit 1 */
 	williams_cocktail = data & 0x02;
@@ -852,7 +855,7 @@ WRITE8_HANDLER( blaster_vram_select_w )
 WRITE8_HANDLER( blaster_bank_select_w )
 {
 	blaster_bank = data & 15;
-	update_blaster_banking();
+	update_blaster_banking(space->machine);
 }
 
 
@@ -866,7 +869,7 @@ WRITE8_HANDLER( blaster_bank_select_w )
 static READ8_HANDLER( lottofun_input_port_0_r )
 {
 	/* merge in the ticket dispenser status */
-	return input_port_0_r(offset) | ticket_dispenser_r(offset);
+	return input_port_read(space->machine, "IN0") | ticket_dispenser_r(space,offset);
 }
 
 
@@ -880,16 +883,18 @@ static READ8_HANDLER( lottofun_input_port_0_r )
 static READ8_HANDLER( tshoot_input_port_0_3_r )
 {
 	/* merge in the gun inputs with the standard data */
-	int data = williams_input_port_0_3_r(offset);
+	int data = input_port_read(space->machine, "IN0");
 	int gun = (data & 0x3f) ^ ((data & 0x3f) >> 1);
 	return (data & 0xc0) | gun;
+
+	return 0;
 }
 
 
 static WRITE8_HANDLER( tshoot_maxvol_w )
 {
 	/* something to do with the sound volume */
-	logerror("tshoot maxvol = %d (pc:%x)\n", data, activecpu_get_pc());
+	logerror("tshoot maxvol = %d (pc:%x)\n", data, cpu_get_pc(space->cpu));
 }
 
 
@@ -928,7 +933,7 @@ static WRITE8_HANDLER( tshoot_lamp_w )
 
 MACHINE_START( joust2 )
 {
-	williams_cvsd_init(3);
+	williams_cvsd_init(machine, 3);
 }
 
 
@@ -937,26 +942,27 @@ MACHINE_RESET( joust2 )
 	/* standard init */
 	MACHINE_RESET_CALL(williams2);
 	pia_set_input_ca1(3, 1);
-	state_save_register_global(joust2_current_sound_data);
+	state_save_register_global(machine, joust2_current_sound_data);
 }
 
 
 static TIMER_CALLBACK( joust2_deferred_snd_cmd_w )
 {
-	pia_2_porta_w(0, param & 0xff);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	pia_2_porta_w(space, 0, param & 0xff);
 }
 
 
 static WRITE8_HANDLER( joust2_pia_3_cb1_w )
 {
 	joust2_current_sound_data = (joust2_current_sound_data & ~0x100) | ((data << 8) & 0x100);
-	pia_3_cb1_w(offset, data);
+	pia_3_cb1_w(space, offset, data);
 }
 
 
 static WRITE8_HANDLER( joust2_snd_cmd_w )
 {
 	joust2_current_sound_data = (joust2_current_sound_data & ~0xff) | (data & 0xff);
-	williams_cvsd_data_w(joust2_current_sound_data);
-	timer_call_after_resynch(NULL, joust2_current_sound_data, joust2_deferred_snd_cmd_w);
+	williams_cvsd_data_w(space->machine, joust2_current_sound_data);
+	timer_call_after_resynch(space->machine, NULL, joust2_current_sound_data, joust2_deferred_snd_cmd_w);
 }
