@@ -5,12 +5,9 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "cpu/z80/z80.h"
 #include "includes/astrocde.h"
 #include "sound/astrocde.h"
-#include <math.h> /* for sin() and cos() */
-#include "osd_cpu.h"
 #include "video/resnet.h"
 
 
@@ -93,7 +90,7 @@ static UINT8 profpac_vw;
  *
  *************************************/
 
-static void init_savestate(void);
+static void init_savestate(running_machine *machine);
 static TIMER_CALLBACK( scanline_callback );
 static void init_sparklestar(void);
 
@@ -225,11 +222,11 @@ PALETTE_INIT( profpac )
 VIDEO_START( astrocde )
 {
 	/* allocate a per-scanline timer */
-	scanline_timer = timer_alloc(scanline_callback, NULL);
-	timer_adjust(scanline_timer, video_screen_get_time_until_pos(0, 1, 0), 1, attotime_zero);
+	scanline_timer = timer_alloc(machine, scanline_callback, NULL);
+	timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, 1, 0), 1);
 
 	/* register for save states */
-	init_savestate();
+	init_savestate(machine);
 
 	/* initialize the sparkle and stars */
 	if (astrocade_video_config & AC_STARS)
@@ -240,60 +237,60 @@ VIDEO_START( astrocde )
 VIDEO_START( profpac )
 {
 	/* allocate a per-scanline timer */
-	scanline_timer = timer_alloc(scanline_callback, NULL);
-	timer_adjust(scanline_timer, video_screen_get_time_until_pos(0, 1, 0), 1, attotime_zero);
+	scanline_timer = timer_alloc(machine, scanline_callback, NULL);
+	timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, 1, 0), 1);
 
 	/* allocate videoram */
 	profpac_videoram = auto_malloc(0x4000 * 4 * sizeof(*profpac_videoram));
 
 	/* register for save states */
-	init_savestate();
+	init_savestate(machine);
 
 	/* register our specific save state data */
-	state_save_register_global_pointer(profpac_videoram, 0x4000 * 4);
-	state_save_register_global_array(profpac_palette);
-	state_save_register_global_array(profpac_colormap);
-	state_save_register_global(profpac_intercept);
-	state_save_register_global(profpac_vispage);
-	state_save_register_global(profpac_readpage);
-	state_save_register_global(profpac_readshift);
-	state_save_register_global(profpac_writepage);
-	state_save_register_global(profpac_writemode);
-	state_save_register_global(profpac_writemask);
-	state_save_register_global(profpac_vw);
+	state_save_register_global_pointer(machine, profpac_videoram, 0x4000 * 4);
+	state_save_register_global_array(machine, profpac_palette);
+	state_save_register_global_array(machine, profpac_colormap);
+	state_save_register_global(machine, profpac_intercept);
+	state_save_register_global(machine, profpac_vispage);
+	state_save_register_global(machine, profpac_readpage);
+	state_save_register_global(machine, profpac_readshift);
+	state_save_register_global(machine, profpac_writepage);
+	state_save_register_global(machine, profpac_writemode);
+	state_save_register_global(machine, profpac_writemask);
+	state_save_register_global(machine, profpac_vw);
 }
 
 
-static void init_savestate(void)
+static void init_savestate(running_machine *machine)
 {
-	state_save_register_global_array(astrocade_sparkle);
+	state_save_register_global_array(machine, astrocade_sparkle);
 
-	state_save_register_global(interrupt_enable);
-	state_save_register_global(interrupt_vector);
-	state_save_register_global(interrupt_scanline);
-	state_save_register_global(vertical_feedback);
-	state_save_register_global(horizontal_feedback);
+	state_save_register_global(machine, interrupt_enable);
+	state_save_register_global(machine, interrupt_vector);
+	state_save_register_global(machine, interrupt_scanline);
+	state_save_register_global(machine, vertical_feedback);
+	state_save_register_global(machine, horizontal_feedback);
 
-	state_save_register_global_array(colors);
-	state_save_register_global(colorsplit);
-	state_save_register_global(bgdata);
-	state_save_register_global(vblank);
-	state_save_register_global(video_mode);
+	state_save_register_global_array(machine, colors);
+	state_save_register_global(machine, colorsplit);
+	state_save_register_global(machine, bgdata);
+	state_save_register_global(machine, vblank);
+	state_save_register_global(machine, video_mode);
 
-	state_save_register_global_array(funcgen_expand_color);
-	state_save_register_global(funcgen_control);
-	state_save_register_global(funcgen_expand_count);
-	state_save_register_global(funcgen_rotate_count);
-	state_save_register_global_array(funcgen_rotate_data);
-	state_save_register_global(funcgen_shift_prev_data);
-	state_save_register_global(funcgen_intercept);
+	state_save_register_global_array(machine, funcgen_expand_color);
+	state_save_register_global(machine, funcgen_control);
+	state_save_register_global(machine, funcgen_expand_count);
+	state_save_register_global(machine, funcgen_rotate_count);
+	state_save_register_global_array(machine, funcgen_rotate_data);
+	state_save_register_global(machine, funcgen_shift_prev_data);
+	state_save_register_global(machine, funcgen_intercept);
 
-	state_save_register_global(pattern_source);
-	state_save_register_global(pattern_mode);
-	state_save_register_global(pattern_dest);
-	state_save_register_global(pattern_skip);
-	state_save_register_global(pattern_width);
-	state_save_register_global(pattern_height);
+	state_save_register_global(machine, pattern_source);
+	state_save_register_global(machine, pattern_mode);
+	state_save_register_global(machine, pattern_dest);
+	state_save_register_global(machine, pattern_skip);
+	state_save_register_global(machine, pattern_width);
+	state_save_register_global(machine, pattern_height);
 }
 
 
@@ -311,8 +308,11 @@ VIDEO_UPDATE( astrocde )
 	int y;
 
 	/* compute the starting point of sparkle for the current frame */
+	int width = video_screen_get_width(screen);
+	int height = video_screen_get_height(screen);
+
 	if (astrocade_video_config & AC_STARS)
-		sparklebase = ((UINT64)cpu_getcurrentframe() * (UINT64)(machine->screen[0].width * machine->screen[0].height)) % RNG_PERIOD;
+		sparklebase = (video_screen_get_frame_number(screen) * (UINT64)(width * height)) % RNG_PERIOD;
 
 	/* iterate over scanlines */
 	for (y = cliprect->min_y; y <= cliprect->max_y; y++)
@@ -326,8 +326,8 @@ VIDEO_UPDATE( astrocde )
 		/* compute the star and sparkle offset at the start of this line */
 		if (astrocade_video_config & AC_STARS)
 		{
-			staroffs = ((effy < 0) ? (effy + 262) : effy) * machine->screen[0].width;
-			sparkleoffs = sparklebase + y * machine->screen[0].width;
+			staroffs = ((effy < 0) ? (effy + 262) : effy) * width;
+			sparkleoffs = sparklebase + y * width;
 			if (sparkleoffs >= RNG_PERIOD)
 				sparkleoffs -= RNG_PERIOD;
 		}
@@ -427,7 +427,7 @@ VIDEO_UPDATE( profpac )
 
 static TIMER_CALLBACK( interrupt_off )
 {
-	cpunum_set_input_line(machine, 0, 0, CLEAR_LINE);
+	cpu_set_input_line(machine->cpu[0], 0, CLEAR_LINE);
 }
 
 
@@ -439,13 +439,16 @@ static void astrocade_trigger_lightpen(running_machine *machine, UINT8 vfeedback
 	{
 		/* bit 0 controls the interrupt mode: mode 0 means assert until acknowledged */
 		if ((interrupt_enable & 0x01) == 0)
-			cpunum_set_input_line_and_vector(machine, 0, 0, HOLD_LINE, interrupt_vector & 0xf0);
+		{
+			cpu_set_input_line_and_vector(machine->cpu[0], 0, HOLD_LINE, interrupt_vector & 0xf0);
+			timer_set(machine, video_screen_get_time_until_vblank_end(machine->primary_screen), NULL, 0, interrupt_off);
+		}
 
 		/* mode 1 means assert for 1 instruction */
 		else
 		{
-			cpunum_set_input_line_and_vector(machine, 0, 0, ASSERT_LINE, interrupt_vector & 0xf0);
-			timer_set(ATTOTIME_IN_CYCLES(1, 0), NULL, 0, interrupt_off);
+			cpu_set_input_line_and_vector(machine->cpu[0], 0, ASSERT_LINE, interrupt_vector & 0xf0);
+			timer_set(machine, cpu_clocks_to_attotime(machine->cpu[0], 1), NULL, 0, interrupt_off);
 		}
 
 		/* latch the feedback registers */
@@ -468,20 +471,24 @@ static TIMER_CALLBACK( scanline_callback )
 	int astrocade_scanline = mame_vpos_to_astrocade_vpos(scanline);
 
 	/* force an update against the current scanline */
-	video_screen_update_partial(0, scanline - 1);
+	if (scanline > 0)
+		video_screen_update_partial(machine->primary_screen, scanline - 1);
 
 	/* generate a scanline interrupt if it's time */
 	if (astrocade_scanline == interrupt_scanline && (interrupt_enable & 0x08) != 0)
 	{
 		/* bit 2 controls the interrupt mode: mode 0 means assert until acknowledged */
 		if ((interrupt_enable & 0x04) == 0)
-			cpunum_set_input_line_and_vector(machine, 0, 0, HOLD_LINE, interrupt_vector);
+		{
+			cpu_set_input_line_and_vector(machine->cpu[0], 0, HOLD_LINE, interrupt_vector);
+			timer_set(machine, video_screen_get_time_until_vblank_end(machine->primary_screen), NULL, 0, interrupt_off);
+		}
 
 		/* mode 1 means assert for 1 instruction */
 		else
 		{
-			cpunum_set_input_line_and_vector(machine, 0, 0, ASSERT_LINE, interrupt_vector);
-			timer_set(ATTOTIME_IN_CYCLES(1, 0), NULL, 0, interrupt_off);
+			cpu_set_input_line_and_vector(machine->cpu[0], 0, ASSERT_LINE, interrupt_vector);
+			timer_set(machine, cpu_clocks_to_attotime(machine->cpu[0], 1), NULL, 0, interrupt_off);
 		}
 	}
 
@@ -491,9 +498,9 @@ static TIMER_CALLBACK( scanline_callback )
 
 	/* advance to the next scanline */
 	scanline++;
-	if (scanline >= machine->screen[0].height)
+	if (scanline >= video_screen_get_height(machine->primary_screen))
 		scanline = 0;
-	timer_adjust(scanline_timer, video_screen_get_time_until_pos(0, scanline, 0), scanline, attotime_zero);
+	timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, scanline, 0), scanline);
 }
 
 
@@ -525,35 +532,51 @@ READ8_HANDLER( astrocade_data_chip_register_r )
 			break;
 
 		case 0x10:	/* player 1 handle */
-			result = readinputportbytag_safe("P1HANDLE", 0xff);
+			result = input_port_read_safe(space->machine, "P1HANDLE", 0xff);
 			break;
 
 		case 0x11:	/* player 2 handle */
-			result = readinputportbytag_safe("P2HANDLE", 0xff);
+			result = input_port_read_safe(space->machine, "P2HANDLE", 0xff);
 			break;
 
 		case 0x12:	/* player 3 handle */
-			result = readinputportbytag_safe("P3HANDLE", 0xff);
+			result = input_port_read_safe(space->machine, "P3HANDLE", 0xff);
 			break;
 
 		case 0x13:	/* player 4 handle */
-			result = readinputportbytag_safe("P4HANDLE", 0xff);
+			result = input_port_read_safe(space->machine, "P4HANDLE", 0xff);
 			break;
 
 		case 0x14:	/* keypad column 0 */
-			result = readinputportbytag_safe("KEYPAD0", 0xff);
+			result = input_port_read_safe(space->machine, "KEYPAD0", 0xff);
 			break;
 
 		case 0x15:	/* keypad column 1 */
-			result = readinputportbytag_safe("KEYPAD1", 0xff);
+			result = input_port_read_safe(space->machine, "KEYPAD1", 0xff);
 			break;
 
 		case 0x16:	/* keypad column 2 */
-			result = readinputportbytag_safe("KEYPAD2", 0xff);
+			result = input_port_read_safe(space->machine, "KEYPAD2", 0xff);
 			break;
 
 		case 0x17:	/* keypad column 3 */
-			result = readinputportbytag_safe("KEYPAD3", 0xff);
+			result = input_port_read_safe(space->machine, "KEYPAD3", 0xff);
+			break;
+
+		case 0x1c:	/* player 1 knob */
+			result = input_port_read_safe(space->machine, "P1_KNOB", 0xff);
+			break;
+
+		case 0x1d:	/* player 2 knob */
+			result = input_port_read_safe(space->machine, "P2_KNOB", 0xff);
+			break;
+
+		case 0x1e:	/* player 3 knob */
+			result = input_port_read_safe(space->machine, "P3_KNOB", 0xff);
+			break;
+
+		case 0x1f:	/* player 4 knob */
+			result = input_port_read_safe(space->machine, "P4_KNOB", 0xff);
 			break;
 	}
 
@@ -623,7 +646,7 @@ WRITE8_HANDLER( astrocade_data_chip_register_w )
 		case 0x17:	/* noise volume register */
 		case 0x18:	/* sound block transfer */
 			if (astrocade_video_config & AC_SOUND_PRESENT)
-				astrocade_sound1_w(offset, data);
+				astrocade_sound1_w(space, offset, data);
 			break;
 
 		case 0x19:	/* expand register */
@@ -704,7 +727,7 @@ WRITE8_HANDLER( astrocade_funcgen_w )
 	/* OR/XOR */
 	if (funcgen_control & 0x30)
 	{
-		UINT8 olddata = program_read_byte_8(0x4000 + offset);
+		UINT8 olddata = memory_read_byte(space, 0x4000 + offset);
 
 		/* compute any intercepts */
 		funcgen_intercept &= 0x0f;
@@ -725,7 +748,7 @@ WRITE8_HANDLER( astrocade_funcgen_w )
 	}
 
 	/* write the result */
-	program_write_byte_8(0x4000 + offset, data);
+	memory_write_byte(space, 0x4000 + offset, data);
 }
 
 
@@ -765,7 +788,7 @@ INLINE void increment_dest(UINT8 curwidth)
 }
 
 
-static void execute_blit(void)
+static void execute_blit(const address_space *space)
 {
 	/*
         pattern_source = counter set U7/U16/U25/U34
@@ -819,7 +842,7 @@ static void execute_blit(void)
 			if (curwidth == 0 && (pattern_mode & 0x08) != 0)
 				busdata = 0;
 			else
-				busdata = program_read_byte_8(busaddr);
+				busdata = memory_read_byte(space, busaddr);
 
 			/* increment the appropriate address */
 			if ((pattern_mode & 0x01) == 0)
@@ -831,7 +854,7 @@ static void execute_blit(void)
 
 			/* address is selected between source/dest based on mode.d0 */
 			busaddr = ((pattern_mode & 0x01) != 0) ? pattern_source : pattern_dest;
-			program_write_byte_8(busaddr, busdata);
+			memory_write_byte(space, busaddr, busdata);
 
 			/* increment the appropriate address */
 			if ((pattern_mode & 0x01) == 0)
@@ -857,7 +880,7 @@ static void execute_blit(void)
 	} while (pattern_height-- != 0);
 
 	/* count cycles we ran the bus */
-	activecpu_adjust_icount(-cycles);
+	cpu_adjust_icount(space->cpu, -cycles);
 }
 
 
@@ -892,7 +915,7 @@ WRITE8_HANDLER( astrocade_pattern_board_w )
 
 		case 6:		/* height of blit and initiator */
 			pattern_height = data;
-			execute_blit();
+			execute_blit(cpu_get_address_space(space->cpu, ADDRESS_SPACE_PROGRAM));
 			break;
 	}
 }
