@@ -7,7 +7,6 @@
 ******************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "includes/atari.h"
 #include "video/gtia.h"
 
@@ -761,7 +760,7 @@ VIDEO_START( atari )
 	LOG(("atari prio_init\n"));
     prio_init();
 
-	for( i = 0; i < machine->screen[0].height; i++ )
+	for( i = 0; i < video_screen_get_height(machine->primary_screen); i++ )
     {
 		antic.video[i] = auto_malloc(sizeof(VIDEO));
 		memset(antic.video[i], 0, sizeof(VIDEO));
@@ -781,7 +780,7 @@ VIDEO_UPDATE( atari )
 
 	VIDEO_UPDATE_CALL(generic_bitmapped);
 
-	new_tv_artifacts = readinputportbytag_safe("artifacts", 0);
+	new_tv_artifacts = input_port_read_safe(screen->machine, "artifacts", 0);
 	if( tv_artifacts != new_tv_artifacts )
 	{
 		tv_artifacts = new_tv_artifacts;
@@ -796,7 +795,7 @@ VIDEO_UPDATE( atari )
 	return 0;
 }
 
-static renderer_function antic_renderer = antic_mode_0_xx;
+static atari_renderer_func antic_renderer = antic_mode_0_xx;
 
 static void artifacts_gfx(UINT8 *src, UINT8 *dst, int width)
 {
@@ -804,10 +803,10 @@ static void artifacts_gfx(UINT8 *src, UINT8 *dst, int width)
 	UINT8 n, bits = 0;
 	UINT8 b = gtia.w.colbk & 0xf0;
 	UINT8 c = gtia.w.colpf1 & 0x0f;
-	UINT8 atari_A = Machine->remapped_colortable[((b+0x30)&0xf0)+c];
-	UINT8 atari_B = Machine->remapped_colortable[((b+0x70)&0xf0)+c];
-	UINT8 atari_C = Machine->remapped_colortable[b+c];
-	UINT8 atari_D = Machine->remapped_colortable[gtia.w.colbk];
+	UINT8 atari_A = ((b+0x30)&0xf0)+c;
+	UINT8 atari_B = ((b+0x70)&0xf0)+c;
+	UINT8 atari_C = b+c;
+	UINT8 atari_D = gtia.w.colbk;
 
 	for( x = 0; x < width * 4; x++ )
 	{
@@ -878,10 +877,10 @@ static void artifacts_txt(UINT8 * src, UINT8 * dst, int width)
 	UINT8 n, bits = 0;
 	UINT8 b = gtia.w.colpf2 & 0xf0;
 	UINT8 c = gtia.w.colpf1 & 0x0f;
-	UINT8 atari_A = Machine->remapped_colortable[((b+0x30)&0xf0)+c];
-	UINT8 atari_B = Machine->remapped_colortable[((b+0x70)&0xf0)+c];
-	UINT8 atari_C = Machine->remapped_colortable[b+c];
-	UINT8 atari_D = Machine->remapped_colortable[gtia.w.colpf2];
+	UINT8 atari_A = ((b+0x30)&0xf0)+c;
+	UINT8 atari_B = ((b+0x70)&0xf0)+c;
+	UINT8 atari_C = b+c;
+	UINT8 atari_D = gtia.w.colpf2;
 
 	for( x = 0; x < width * 4; x++ )
 	{
@@ -947,7 +946,7 @@ static void artifacts_txt(UINT8 * src, UINT8 * dst, int width)
 }
 
 
-static void antic_linerefresh(void)
+static void antic_linerefresh(running_machine *machine)
 {
 	int x, y;
 	UINT8 *src;
@@ -955,7 +954,7 @@ static void antic_linerefresh(void)
 	UINT32 scanline[4 + (HCHARS * 2) + 4];
 
 	/* increment the scanline */
-    if( ++antic.scanline == Machine->screen[0].height )
+    if( ++antic.scanline == video_screen_get_height(machine->primary_screen) )
     {
         /* and return to the top if the frame was complete */
         antic.scanline = 0;
@@ -1052,38 +1051,38 @@ static void antic_linerefresh(void)
 	dst[2] = antic.color_lookup[PBK] | antic.color_lookup[PBK] << 16;
 	dst[3] = antic.color_lookup[PBK] | antic.color_lookup[PBK] << 16;
 
-	draw_scanline8(tmpbitmap, 12, y, sizeof(scanline), (const UINT8 *) scanline, Machine->pens, -1);
+	draw_scanline8(tmpbitmap, 12, y, sizeof(scanline), (const UINT8 *) scanline, NULL, -1);
 }
 
-static int cycle(void)
+static int cycle(running_machine *machine)
 {
-	return video_screen_get_hpos(0) * CYCLES_PER_LINE / Machine->screen[0].width;
+	return video_screen_get_hpos(machine->primary_screen) * CYCLES_PER_LINE / video_screen_get_width(machine->primary_screen);
 }
 
-static void after(int cycles, timer_callback function, const char *funcname)
+static void after(running_machine *machine, int cycles, timer_fired_func function, const char *funcname)
 {
-    attotime duration = attotime_make(0, attotime_to_attoseconds(video_screen_get_scan_period(0)) * cycles / CYCLES_PER_LINE);
+    attotime duration = attotime_make(0, attotime_to_attoseconds(video_screen_get_scan_period(machine->primary_screen)) * cycles / CYCLES_PER_LINE);
     (void)funcname;
 	LOG(("           after %3d (%5.1f us) %s\n", cycles, attotime_to_double(duration) * 1.0e6, funcname));
-	timer_set(duration, NULL, 0, function);
+	timer_set(machine, duration, NULL, 0, function);
 }
 
 static TIMER_CALLBACK( antic_issue_dli )
 {
 	if( antic.w.nmien & DLI_NMI )
 	{
-		LOG(("           @cycle #%3d issue DLI\n", cycle()));
+		LOG(("           @cycle #%3d issue DLI\n", cycle(machine)));
 		antic.r.nmist |= DLI_NMI;
-		cpunum_set_input_line(machine, 0, INPUT_LINE_NMI, PULSE_LINE);
+		cpu_set_input_line(machine->cpu[0], INPUT_LINE_NMI, PULSE_LINE);
 	}
 	else
 	{
-		LOG(("           @cycle #%3d DLI not enabled\n", cycle()));
+		LOG(("           @cycle #%3d DLI not enabled\n", cycle(machine)));
     }
 }
 
 
-static const renderer_function renderer[2][19][5] = {
+static const atari_renderer_func renderer[2][19][5] = {
 	/*   no playfield    narrow          normal          wide         */
 	{
 		{antic_mode_0_xx,antic_mode_0_xx,antic_mode_0_xx,antic_mode_0_xx},
@@ -1138,21 +1137,21 @@ static const renderer_function renderer[2][19][5] = {
  *****************************************************************************/
 static TIMER_CALLBACK( antic_line_done )
 {
-	LOG(("           @cycle #%3d antic_line_done\n", cycle()));
+	LOG(("           @cycle #%3d antic_line_done\n", cycle(machine)));
 	if( antic.w.wsync )
     {
-		LOG(("           @cycle #%3d release WSYNC\n", cycle()));
+		LOG(("           @cycle #%3d release WSYNC\n", cycle(machine)));
         /* release the CPU if it was actually waiting for HSYNC */
-        cpu_trigger(machine, TRIGGER_HSYNC);
+        cpuexec_trigger(machine, TRIGGER_HSYNC);
         /* and turn off the 'wait for hsync' flag */
         antic.w.wsync = 0;
     }
-	LOG(("           @cycle #%3d release CPU\n", cycle()));
+	LOG(("           @cycle #%3d release CPU\n", cycle(machine)));
     /* release the CPU (held for emulating cycles stolen by ANTIC DMA) */
-	cpu_trigger(machine, TRIGGER_STEAL);
+	cpuexec_trigger(machine, TRIGGER_STEAL);
 
 	/* refresh the display (translate color clocks to pixels) */
-    antic_linerefresh();
+    antic_linerefresh(machine);
 }
 
 /*****************************************************************************
@@ -1166,10 +1165,10 @@ static TIMER_CALLBACK( antic_line_done )
  *****************************************************************************/
 static TIMER_CALLBACK( antic_steal_cycles )
 {
-	LOG(("           @cycle #%3d steal %d cycles\n", cycle(), antic.steal_cycles));
-	after(antic.steal_cycles, antic_line_done, "antic_line_done");
+	LOG(("           @cycle #%3d steal %d cycles\n", cycle(machine), antic.steal_cycles));
+	after(machine, antic.steal_cycles, antic_line_done, "antic_line_done");
     antic.steal_cycles = 0;
-	cpunum_spinuntil_trigger( 0, TRIGGER_STEAL );
+	cpu_spinuntil_trigger( machine->cpu[0], TRIGGER_STEAL );
 }
 
 
@@ -1183,10 +1182,12 @@ static TIMER_CALLBACK( antic_steal_cycles )
  *****************************************************************************/
 static TIMER_CALLBACK( antic_scanline_render )
 {
-	VIDEO *video = antic.video[antic.scanline];
-	LOG(("           @cycle #%3d render mode $%X lines to go #%d\n", cycle(), (antic.cmd & 0x0f), antic.modelines));
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 
-    (*antic_renderer)(video);
+	VIDEO *video = antic.video[antic.scanline];
+	LOG(("           @cycle #%3d render mode $%X lines to go #%d\n", cycle(machine), (antic.cmd & 0x0f), antic.modelines));
+
+    (*antic_renderer)(space, video);
 
     /* if player/missile graphics is enabled */
     if( antic.scanline < 256 && (antic.w.dmactl & (DMA_PLAYER|DMA_MISSILE)) )
@@ -1198,16 +1199,16 @@ static TIMER_CALLBACK( antic_scanline_render )
             if( antic.w.dmactl & DMA_MISSILE )
             {
                 antic.steal_cycles += 1;
-                atari_gtia_w(0x11, RDPMGFXD(3*256));
+                atari_gtia_w(space, 0x11, RDPMGFXD(space, 3*256));
             }
             /* transport player data to GTIA ? */
             if( antic.w.dmactl & DMA_PLAYER )
             {
                 antic.steal_cycles += 4;
-                atari_gtia_w(0x0d, RDPMGFXD(4*256));
-                atari_gtia_w(0x0e, RDPMGFXD(5*256));
-                atari_gtia_w(0x0f, RDPMGFXD(6*256));
-                atari_gtia_w(0x10, RDPMGFXD(7*256));
+                atari_gtia_w(space, 0x0d, RDPMGFXD(space, 4*256));
+                atari_gtia_w(space, 0x0e, RDPMGFXD(space, 5*256));
+                atari_gtia_w(space, 0x0f, RDPMGFXD(space, 6*256));
+                atari_gtia_w(space, 0x10, RDPMGFXD(space, 7*256));
             }
         }
         else
@@ -1217,17 +1218,17 @@ static TIMER_CALLBACK( antic_scanline_render )
             {
 				if( (antic.scanline & 1) == 0 ) 	 /* even line ? */
 					antic.steal_cycles += 1;
-                atari_gtia_w(0x11, RDPMGFXS(3*128));
+                atari_gtia_w(space, 0x11, RDPMGFXS(space, 3*128));
             }
             /* transport player data to GTIA ? */
             if( antic.w.dmactl & DMA_PLAYER )
             {
 				if( (antic.scanline & 1) == 0 ) 	 /* even line ? */
 					antic.steal_cycles += 4;
-                atari_gtia_w(0x0d, RDPMGFXS(4*128));
-                atari_gtia_w(0x0e, RDPMGFXS(5*128));
-                atari_gtia_w(0x0f, RDPMGFXS(6*128));
-                atari_gtia_w(0x10, RDPMGFXS(7*128));
+                atari_gtia_w(space, 0x0d, RDPMGFXS(space, 4*128));
+                atari_gtia_w(space, 0x0e, RDPMGFXS(space, 5*128));
+                atari_gtia_w(space, 0x0f, RDPMGFXS(space, 6*128));
+                atari_gtia_w(space, 0x10, RDPMGFXS(space, 7*128));
             }
         }
     }
@@ -1236,12 +1237,12 @@ static TIMER_CALLBACK( antic_scanline_render )
 
     antic.steal_cycles += CYCLES_REFRESH;
 	LOG(("           run CPU for %d cycles\n", CYCLES_HSYNC - CYCLES_HSTART - antic.steal_cycles));
-	after(CYCLES_HSYNC - CYCLES_HSTART - antic.steal_cycles, antic_steal_cycles, "antic_steal_cycles");
+	after(machine, CYCLES_HSYNC - CYCLES_HSTART - antic.steal_cycles, antic_steal_cycles, "antic_steal_cycles");
 }
 
 
 
-INLINE void LMS(int new_cmd)
+INLINE void LMS(running_machine *machine, int new_cmd)
 {
     /**************************************************************
      * If the LMS bit (load memory scan) of the current display
@@ -1251,9 +1252,10 @@ INLINE void LMS(int new_cmd)
      **************************************************************/
     if( new_cmd & ANTIC_LMS )
     {
-		int addr = RDANTIC();
+    	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+		int addr = RDANTIC(space);
         antic.doffs = ++antic.doffs & DOFFS;
-        addr += 256 * RDANTIC();
+        addr += 256 * RDANTIC(space);
         antic.doffs = ++antic.doffs & DOFFS;
         antic.vpage = addr & VPAGE;
         antic.voffs = addr & VOFFS;
@@ -1273,9 +1275,10 @@ INLINE void LMS(int new_cmd)
  *  if so, read a new command and set up the renderer function
  *
  *****************************************************************************/
-static void antic_scanline_dma(int param)
+static void antic_scanline_dma(running_machine *machine, int param)
 {
-	LOG(("           @cycle #%3d DMA fetch\n", cycle()));
+   	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	LOG(("           @cycle #%3d DMA fetch\n", cycle(machine)));
 	if (antic.scanline == VBL_END)
 		antic.r.nmist &= ~VBL_NMI;
     if( antic.w.dmactl & DMA_ANTIC )
@@ -1288,7 +1291,7 @@ static void antic_scanline_dma(int param)
 				UINT8 vscrol_subtract = 0;
 				UINT8 new_cmd;
 
-				new_cmd = RDANTIC();
+				new_cmd = RDANTIC(space);
 				antic.doffs = ++antic.doffs & DOFFS;
 				/* steal at one clock cycle from the CPU for fetching the command */
                 antic.steal_cycles += 1;
@@ -1346,27 +1349,27 @@ static void antic_scanline_dma(int param)
 					{
 						/* remove the DLI bit */
 						new_cmd &= ~ANTIC_DLI;
-						after(CYCLES_DLI_NMI, antic_issue_dli, "antic_issue_dli");
+						after(machine, CYCLES_DLI_NMI, antic_issue_dli, "antic_issue_dli");
 					}
 					/* load memory scan bit set ? */
 					if( new_cmd & ANTIC_LMS )
 					{
-						int addr = RDANTIC();
+						int addr = RDANTIC(space);
                         antic.doffs = ++antic.doffs & DOFFS;
-                        addr += 256 * RDANTIC();
+                        addr += 256 * RDANTIC(space);
                         antic.dpage = addr & DPAGE;
                         antic.doffs = addr & DOFFS;
                         /* produce empty scanlines until vblank start */
 						antic.modelines = VBL_START + 1 - antic.scanline;
 						if( antic.modelines < 0 )
-							antic.modelines = Machine->screen[0].height - antic.scanline;
+							antic.modelines = video_screen_get_height(machine->primary_screen) - antic.scanline;
 						LOG(("           JVB $%04x\n", antic.dpage|antic.doffs));
 					}
 					else
 					{
-						int addr = RDANTIC();
+						int addr = RDANTIC(space);
                         antic.doffs = ++antic.doffs & DOFFS;
-                        addr += 256 * RDANTIC();
+                        addr += 256 * RDANTIC(space);
                         antic.dpage = addr & DPAGE;
                         antic.doffs = addr & DOFFS;
                         /* produce a single empty scanline */
@@ -1375,77 +1378,77 @@ static void antic_scanline_dma(int param)
 					}
 					break;
 				case 0x02:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					antic.chbase = (antic.w.chbash & 0xfc) << 8;
 					antic.modelines = 8 - (vscrol_subtract & 7);
 					if( antic.w.chactl & 4 )	/* decrement chbasl? */
 						antic.w.chbasl = antic.modelines - 1;
 					break;
 				case 0x03:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					antic.chbase = (antic.w.chbash & 0xfc) << 8;
 					antic.modelines = 10 - (vscrol_subtract & 9);
 					if( antic.w.chactl & 4 )	/* decrement chbasl? */
 						antic.w.chbasl = antic.modelines - 1;
 					break;
 				case 0x04:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					antic.chbase = (antic.w.chbash & 0xfc) << 8;
 					antic.modelines = 8 - (vscrol_subtract & 7);
 					if( antic.w.chactl & 4 )	/* decrement chbasl? */
 						antic.w.chbasl = antic.modelines - 1;
 					break;
 				case 0x05:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					antic.chbase = (antic.w.chbash & 0xfc) << 8;
 					antic.modelines = 16 - (vscrol_subtract & 15);
 					if( antic.w.chactl & 4 )	/* decrement chbasl? */
 						antic.w.chbasl = antic.modelines - 1;
 					break;
 				case 0x06:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					antic.chbase = (antic.w.chbash & 0xfe) << 8;
 					antic.modelines = 8 - (vscrol_subtract & 7);
 					if( antic.w.chactl & 4 )	/* decrement chbasl? */
 						antic.w.chbasl = antic.modelines - 1;
 					break;
 				case 0x07:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					antic.chbase = (antic.w.chbash & 0xfe) << 8;
 					antic.modelines = 16 - (vscrol_subtract & 15);
 					if( antic.w.chactl & 4 )	/* decrement chbasl? */
 						antic.w.chbasl = antic.modelines - 1;
 					break;
 				case 0x08:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					antic.modelines = 8 - (vscrol_subtract & 7);
 					break;
 				case 0x09:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					antic.modelines = 4 - (vscrol_subtract & 3);
 					break;
 				case 0x0a:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					antic.modelines = 4 - (vscrol_subtract & 3);
 					break;
 				case 0x0b:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					antic.modelines = 2 - (vscrol_subtract & 1);
 					break;
 				case 0x0c:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					antic.modelines = 1;
                     break;
 				case 0x0d:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					antic.modelines = 2 - (vscrol_subtract & 1);
 					break;
 				case 0x0e:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					antic.modelines = 1;
                     break;
 				case 0x0f:
-					LMS(new_cmd);
+					LMS(machine, new_cmd);
 					/* bits 6+7 of the priority select register determine */
 					/* if newer GTIA or plain graphics modes are used */
 					switch (gtia.w.prior >> 6)
@@ -1478,9 +1481,9 @@ static void antic_scanline_dma(int param)
 
 	antic.r.nmist &= ~DLI_NMI;
 	if( antic.modelines == 1 && (antic.cmd & antic.w.nmien & DLI_NMI) )
-		after(CYCLES_DLI_NMI, antic_issue_dli, "antic_issue_dli");
+		after(machine, CYCLES_DLI_NMI, antic_issue_dli, "antic_issue_dli");
 
-	after(CYCLES_HSTART, antic_scanline_render, "antic_scanline_render");
+	after(machine, CYCLES_HSTART, antic_scanline_render, "antic_scanline_render");
 }
 
 /*****************************************************************************
@@ -1492,21 +1495,21 @@ static void antic_scanline_dma(int param)
  *
  *****************************************************************************/
 
-static void generic_atari_interrupt(void (*handle_keyboard)(void), int button_count)
+static void generic_atari_interrupt(running_machine *machine, void (*handle_keyboard)(running_machine *machine), int button_count)
 {
 	int button_port, i;
 
-	LOG(("ANTIC #%3d @cycle #%d scanline interrupt\n", antic.scanline, cycle()));
+	LOG(("ANTIC #%3d @cycle #%d scanline interrupt\n", antic.scanline, cycle(machine)));
 
     if( antic.scanline < VBL_START )
     {
-		antic_scanline_dma(0);
+		antic_scanline_dma(machine, 0);
 		return;
     }
 
     if( antic.scanline == VBL_START )
     {
-		button_port = readinputportbytag_safe("djoy_b", 0);
+		button_port = input_port_read_safe(machine, "djoy_b", 0);
 
 		/* specify buttons relevant to this Atari variant */
 		for (i = 0; i < button_count; i++)
@@ -1520,10 +1523,10 @@ static void generic_atari_interrupt(void (*handle_keyboard)(void), int button_co
 		for (i = button_count; i < 4; i++)
 			gtia.r.but[i] = 1;
 
-		handle_keyboard();
+		handle_keyboard(machine);
 
 		/* do nothing new for the rest of the frame */
-		antic.modelines = Machine->screen[0].height - VBL_START;
+		antic.modelines = video_screen_get_height(machine->primary_screen) - VBL_START;
 		antic_renderer = antic_mode_0_xx;
 
 		/* if the CPU want's to be interrupted at vertical blank... */
@@ -1532,32 +1535,32 @@ static void generic_atari_interrupt(void (*handle_keyboard)(void), int button_co
 			LOG(("           cause VBL NMI\n"));
 			/* set the VBL NMI status bit */
 			antic.r.nmist |= VBL_NMI;
-			cpunum_set_input_line(Machine, 0, INPUT_LINE_NMI, PULSE_LINE);
+			cpu_set_input_line(machine->cpu[0], INPUT_LINE_NMI, PULSE_LINE);
 		}
     }
 
 	/* refresh the display (translate color clocks to pixels) */
-    antic_linerefresh();
+    antic_linerefresh(machine);
 }
 
 
 
 INTERRUPT_GEN( a400_interrupt )
 {
-	generic_atari_interrupt(a800_handle_keyboard, 4);
+	generic_atari_interrupt(device->machine, a800_handle_keyboard, 4);
 }
 
 INTERRUPT_GEN( a800_interrupt )
 {
-	generic_atari_interrupt(a800_handle_keyboard, 4);
+	generic_atari_interrupt(device->machine, a800_handle_keyboard, 4);
 }
 
 INTERRUPT_GEN( a800xl_interrupt )
 {
-	generic_atari_interrupt(a800_handle_keyboard, 2);
+	generic_atari_interrupt(device->machine, a800_handle_keyboard, 2);
 }
 
 INTERRUPT_GEN( a5200_interrupt )
 {
-	generic_atari_interrupt(a5200_handle_keypads, 4);
+	generic_atari_interrupt(device->machine, a5200_handle_keypads, 4);
 }
