@@ -5,7 +5,6 @@
 ****************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "machine/atarigen.h"
 #include "atarisy1.h"
 
@@ -106,7 +105,7 @@ static const gfx_layout objlayout_6bpp =
  *
  *************************************/
 
-static void update_timers(int scanline);
+static void update_timers(running_machine *machine, int scanline);
 static void decode_gfx(running_machine *machine, UINT16 *pflookup, UINT16 *molookup);
 static int get_bank(running_machine *machine, UINT8 prom1, UINT8 prom2, int bpp);
 static TIMER_CALLBACK( int3_callback );
@@ -151,7 +150,7 @@ static TILE_GET_INFO( get_playfield_tile_info )
 
 VIDEO_START( atarisy1 )
 {
-	static const struct atarimo_desc modesc =
+	static const atarimo_desc modesc =
 	{
 		0,					/* index to which gfx system */
 		8,					/* number of motion object banks */
@@ -197,13 +196,13 @@ VIDEO_START( atarisy1 )
 	decode_gfx(machine, playfield_lookup, motable);
 
 	/* initialize the playfield */
-	atarigen_playfield_tilemap = tilemap_create(get_playfield_tile_info, tilemap_scan_rows, TILEMAP_TYPE_PEN, 8,8, 64,64);
+	atarigen_playfield_tilemap = tilemap_create(machine, get_playfield_tile_info, tilemap_scan_rows,  8,8, 64,64);
 
 	/* initialize the motion objects */
 	atarimo_init(machine, 0, &modesc);
 
 	/* initialize the alphanumerics */
-	atarigen_alpha_tilemap = tilemap_create(get_alpha_tile_info, tilemap_scan_rows, TILEMAP_TYPE_PEN, 8,8, 64,32);
+	atarigen_alpha_tilemap = tilemap_create(machine, get_alpha_tile_info, tilemap_scan_rows,  8,8, 64,32);
 	tilemap_set_transparent_pen(atarigen_alpha_tilemap, 0);
 
 	/* modify the motion object code lookup */
@@ -223,9 +222,9 @@ VIDEO_START( atarisy1 )
 	/* reset the statics */
 	atarimo_set_yscroll(0, 256);
 	next_timer_scanline = -1;
-	scanline_timer = timer_alloc(int3_callback, NULL);
-	int3off_timer = timer_alloc(int3off_callback, NULL);
-	yscroll_reset_timer = timer_alloc(reset_yscroll_callback, NULL);
+	scanline_timer = timer_alloc(machine, int3_callback, NULL);
+	int3off_timer = timer_alloc(machine, int3off_callback, NULL);
+	yscroll_reset_timer = timer_alloc(machine, reset_yscroll_callback, NULL);
 }
 
 
@@ -240,7 +239,7 @@ WRITE16_HANDLER( atarisy1_bankselect_w )
 {
 	UINT16 oldselect = *atarisy1_bankselect;
 	UINT16 newselect = oldselect, diff;
-	int scanline = video_screen_get_vpos(0);
+	int scanline = video_screen_get_vpos(space->machine->primary_screen);
 
 	/* update memory */
 	COMBINE_DATA(&newselect);
@@ -249,17 +248,17 @@ WRITE16_HANDLER( atarisy1_bankselect_w )
 	/* sound CPU reset */
 	if (diff & 0x0080)
 	{
-		cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, (newselect & 0x0080) ? CLEAR_LINE : ASSERT_LINE);
-		if (!(newselect & 0x0080)) atarigen_sound_reset();
+		cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, (newselect & 0x0080) ? CLEAR_LINE : ASSERT_LINE);
+		if (!(newselect & 0x0080)) atarigen_sound_reset(space->machine);
 	}
 
 	/* if MO or playfield banks change, force a partial update */
 	if (diff & 0x003c)
-		video_screen_update_partial(0, scanline);
+		video_screen_update_partial(space->machine->primary_screen, scanline);
 
 	/* motion object bank select */
 	atarimo_set_bank(0, (newselect >> 3) & 7);
-	update_timers(scanline);
+	update_timers(space->machine, scanline);
 
 	/* playfield bank select */
 	if (diff & 0x0004)
@@ -288,7 +287,7 @@ WRITE16_HANDLER( atarisy1_priority_w )
 	/* force a partial update in case this changes mid-screen */
 	COMBINE_DATA(&newpens);
 	if (oldpens != newpens)
-		video_screen_update_partial(0, video_screen_get_vpos(0));
+		video_screen_update_partial(space->machine->primary_screen, video_screen_get_vpos(space->machine->primary_screen));
 	playfield_priority_pens = newpens;
 }
 
@@ -308,7 +307,7 @@ WRITE16_HANDLER( atarisy1_xscroll_w )
 	/* force a partial update in case this changes mid-screen */
 	COMBINE_DATA(&newscroll);
 	if (oldscroll != newscroll)
-		video_screen_update_partial(0, video_screen_get_vpos(0));
+		video_screen_update_partial(space->machine->primary_screen, video_screen_get_vpos(space->machine->primary_screen));
 
 	/* set the new scroll value */
 	tilemap_set_scrollx(atarigen_playfield_tilemap, 0, newscroll);
@@ -335,23 +334,23 @@ WRITE16_HANDLER( atarisy1_yscroll_w )
 {
 	UINT16 oldscroll = *atarigen_yscroll;
 	UINT16 newscroll = oldscroll;
-	int scanline = video_screen_get_vpos(0);
+	int scanline = video_screen_get_vpos(space->machine->primary_screen);
 	int adjusted_scroll;
 
 	/* force a partial update in case this changes mid-screen */
 	COMBINE_DATA(&newscroll);
-	video_screen_update_partial(0, scanline);
+	video_screen_update_partial(space->machine->primary_screen, scanline);
 
 	/* because this latches a new value into the scroll base,
        we need to adjust for the scanline */
 	adjusted_scroll = newscroll;
-	if (scanline <= Machine->screen[0].visarea.max_y)
+	if (scanline <= video_screen_get_visible_area(space->machine->primary_screen)->max_y)
 		adjusted_scroll -= (scanline + 1);
 	tilemap_set_scrolly(atarigen_playfield_tilemap, 0, adjusted_scroll);
 
 	/* but since we've adjusted it, we must reset it to the normal value
        once we hit scanline 0 again */
-	timer_adjust(yscroll_reset_timer, video_screen_get_time_until_pos(0, 0, 0), newscroll, attotime_zero);
+	timer_adjust_oneshot(yscroll_reset_timer, video_screen_get_time_until_pos(space->machine->primary_screen, 0, 0), newscroll);
 
 	/* update the data */
 	*atarigen_yscroll = newscroll;
@@ -380,8 +379,8 @@ WRITE16_HANDLER( atarisy1_spriteram_w )
 		    ((offset & 0xc0) == 0x40 && (newword == 0xffff || oldword == 0xffff)))
 		{
 			/* if the timer is in the active bank, update the display list */
-			atarimo_0_spriteram_w(offset, data, 0);
-			update_timers(video_screen_get_vpos(0));
+			atarimo_0_spriteram_w(space, offset, data, 0xffff);
+			update_timers(space->machine, video_screen_get_vpos(space->machine->primary_screen));
 		}
 
 		/* if we're about to modify data in the active sprite bank, make sure the video is up-to-date */
@@ -389,11 +388,11 @@ WRITE16_HANDLER( atarisy1_spriteram_w )
 		/* renders the next scanline's sprites to the line buffers, but Road Runner still glitches */
 		/* without the extra +1 */
 		else
-			video_screen_update_partial(0, video_screen_get_vpos(0) + 2);
+			video_screen_update_partial(space->machine->primary_screen, video_screen_get_vpos(space->machine->primary_screen) + 2);
 	}
 
 	/* let the MO handler do the basic work */
-	atarimo_0_spriteram_w(offset, data, 0);
+	atarimo_0_spriteram_w(space, offset, data, 0xffff);
 }
 
 
@@ -406,8 +405,10 @@ WRITE16_HANDLER( atarisy1_spriteram_w )
 
 static TIMER_CALLBACK( int3off_callback )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 	/* clear the state */
-	atarigen_scanline_int_ack_w(0, 0, 0);
+	atarigen_scanline_int_ack_w(space, 0, 0, 0xffff);
 }
 
 
@@ -416,14 +417,14 @@ static TIMER_CALLBACK( int3_callback )
 	int scanline = param;
 
 	/* update the state */
-	atarigen_scanline_int_gen(machine, 0);
+	atarigen_scanline_int_gen(machine->cpu[0]);
 
 	/* set a timer to turn it off */
-	timer_adjust(int3off_timer, video_screen_get_scan_period(0), 0, attotime_zero);
+	timer_adjust_oneshot(int3off_timer, video_screen_get_scan_period(machine->primary_screen), 0);
 
 	/* determine the time of the next one */
 	next_timer_scanline = -1;
-	update_timers(scanline);
+	update_timers(machine, scanline);
 }
 
 
@@ -447,7 +448,7 @@ READ16_HANDLER( atarisy1_int3state_r )
  *
  *************************************/
 
-static void update_timers(int scanline)
+static void update_timers(running_machine *machine, int scanline)
 {
 	UINT16 *base = &atarimo_0_spriteram[atarimo_get_bank(0) * 64 * 4];
 	int link = 0, best = scanline, found = 0;
@@ -498,9 +499,9 @@ static void update_timers(int scanline)
 
 		/* set a new one */
 		if (best != -1)
-			timer_adjust(scanline_timer, video_screen_get_time_until_pos(0, best, 0), best, attotime_zero);
+			timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, best, 0), best);
 		else
-			timer_adjust(scanline_timer, attotime_never, 0, attotime_zero);
+			timer_adjust_oneshot(scanline_timer, attotime_never, 0);
 	}
 }
 
@@ -514,15 +515,15 @@ static void update_timers(int scanline)
 
 VIDEO_UPDATE( atarisy1 )
 {
-	struct atarimo_rect_list rectlist;
-	mame_bitmap *mobitmap;
+	atarimo_rect_list rectlist;
+	bitmap_t *mobitmap;
 	int x, y, r;
 
 	/* draw the playfield */
 	tilemap_draw(bitmap, cliprect, atarigen_playfield_tilemap, 0, 0);
 
 	/* draw and merge the MO */
-	mobitmap = atarimo_render(machine, 0, cliprect, &rectlist);
+	mobitmap = atarimo_render(0, cliprect, &rectlist);
 	for (r = 0; r < rectlist.numrects; r++, rectlist.rect++)
 		for (y = rectlist.rect->min_y; y <= rectlist.rect->max_y; y++)
 		{
@@ -567,8 +568,8 @@ VIDEO_UPDATE( atarisy1 )
 
 static void decode_gfx(running_machine *machine, UINT16 *pflookup, UINT16 *molookup)
 {
-	UINT8 *prom1 = &memory_region(REGION_PROMS)[0x000];
-	UINT8 *prom2 = &memory_region(REGION_PROMS)[0x200];
+	UINT8 *prom1 = &memory_region(machine, "proms")[0x000];
+	UINT8 *prom2 = &memory_region(machine, "proms")[0x200];
 	int obj, i;
 
 	/* reset the globals */
@@ -657,7 +658,7 @@ static int get_bank(running_machine *machine, UINT8 prom1, UINT8 prom2, int bpp)
 		return bank_gfx[bpp - 4][bank_index];
 
 	/* if the bank is out of range, call it 0 */
-	if (0x80000 * (bank_index - 1) >= memory_region_length(REGION_GFX2))
+	if (0x80000 * (bank_index - 1) >= memory_region_length(machine, "tiles"))
 		return 0;
 
 	/* don't have one? let's make it ... first find any empty slot */
@@ -670,21 +671,21 @@ static int get_bank(running_machine *machine, UINT8 prom1, UINT8 prom2, int bpp)
 	switch (bpp)
 	{
 	case 4:
-		machine->gfx[gfx_index] = allocgfx(&objlayout_4bpp);
+		machine->gfx[gfx_index] = allocgfx(machine, &objlayout_4bpp);
 		break;
 
 	case 5:
-		machine->gfx[gfx_index] = allocgfx(&objlayout_5bpp);
+		machine->gfx[gfx_index] = allocgfx(machine, &objlayout_5bpp);
 		break;
 
 	case 6:
-		machine->gfx[gfx_index] = allocgfx(&objlayout_6bpp);
+		machine->gfx[gfx_index] = allocgfx(machine, &objlayout_6bpp);
 		break;
 
 	default:
 		fatalerror("Unsupported bpp");
 	}
-	decodegfx(machine->gfx[gfx_index], &memory_region(REGION_GFX2)[0x80000 * (bank_index - 1)], 0, machine->gfx[gfx_index]->total_elements);
+	decodegfx(machine->gfx[gfx_index], &memory_region(machine, "tiles")[0x80000 * (bank_index - 1)], 0, machine->gfx[gfx_index]->total_elements);
 
 	/* set the color information */
 	machine->gfx[gfx_index]->color_base = 256;
