@@ -58,17 +58,20 @@ UINT16 *cave_vram_0, *cave_vctrl_0;
 UINT16 *cave_vram_1, *cave_vctrl_1;
 UINT16 *cave_vram_2, *cave_vctrl_2;
 UINT16 *cave_vram_3, *cave_vctrl_3;
+UINT16 *cave_spriteram16_2;
+size_t cave_paletteram_size;
+
 
 /* Variables only used here: */
 
 static tilemap *tilemap_0;
-static int             tiledim_0, old_tiledim_0;
+static int tiledim_0, old_tiledim_0;
 static tilemap *tilemap_1;
-static int             tiledim_1, old_tiledim_1;
+static int tiledim_1, old_tiledim_1;
 static tilemap *tilemap_2;
-static int             tiledim_2, old_tiledim_2;
+static int tiledim_2, old_tiledim_2;
 static tilemap *tilemap_3;
-static int             tiledim_3, old_tiledim_3;
+static int tiledim_3, old_tiledim_3;
 
 
 
@@ -87,7 +90,7 @@ struct sprite_cave {
 	const UINT8 *pen_data;	/* points to top left corner of tile data */
 	int line_offset;
 
-	const pen_t *pal_data;
+	pen_t base_pen;
 	int tile_width, tile_height;
 	int total_width, total_height;	/* in screen coordinates */
 	int x, y, xcount0, ycount0;
@@ -109,7 +112,7 @@ static struct {
 static int num_sprites;
 static struct sprite_cave *sprite_cave;
 static struct sprite_cave *sprite_table[MAX_PRIORITY][MAX_SPRITE_NUM+1];
-static mame_bitmap *sprite_zbuf;
+static bitmap_t *sprite_zbuf;
 static UINT16 sprite_zbuf_baseval = 0x10000-MAX_SPRITE_NUM;
 
 static void (*get_sprite_info)(running_machine *machine);
@@ -124,6 +127,8 @@ static void sprite_draw_donpachi_zbuf( int priority );
 static int spriteram_bank;
 static int spriteram_bank_delay;
 
+static UINT16 *palette_map;
+
 /***************************************************************************
 
                             Palette Init Routines
@@ -133,6 +138,17 @@ static int spriteram_bank_delay;
 
 ***************************************************************************/
 
+PALETTE_INIT( cave )
+{
+	int maxpen = cave_paletteram_size / 2;
+	int pen;
+
+	/* create a 1:1 palette map covering everything */
+	palette_map = auto_malloc(machine->config->total_colors * sizeof(palette_map[0]));
+	for (pen = 0; pen < machine->config->total_colors; pen++)
+		palette_map[pen] = pen % maxpen;
+}
+
 PALETTE_INIT( dfeveron )
 {
 	int color, pen;
@@ -142,9 +158,11 @@ PALETTE_INIT( dfeveron )
        multiplies the color code by $100 (for consistency).
        That's why we need this function.    */
 
-	for( color = 0; color < 0x40; color++ )
-		for( pen = 0; pen < 16; pen++ )
-			colortable[color * 256 + pen] = color * 16 + pen;
+	PALETTE_INIT_CALL(cave);
+
+	for (color = 0; color < 0x40; color++)
+		for (pen = 0; pen < 0x10; pen++)
+			palette_map[(color << 8) | pen] = (color << 4) | pen;
 }
 
 PALETTE_INIT( ddonpach )
@@ -156,64 +174,90 @@ PALETTE_INIT( ddonpach )
        like layer 2, but use the first 16 color of every 256 for
        any given color code. */
 
-	for( color = 0; color < 0x40; color++ )
-		for( pen = 0; pen < 16; pen++ )
-			colortable[color * 16 + pen + 0x8000] = 0x4000 + color * 256 + pen;
+	PALETTE_INIT_CALL(cave);
+
+	for (color = 0; color < 0x40; color++)
+		for (pen = 0; pen < 0x10; pen++)
+			palette_map[0x8000 | (color << 4) | pen] = 0x4000 | (color << 8) | pen;
 }
 
 PALETTE_INIT( mazinger )
 {
 	int color, pen;
 
-	/* Sprites (encrypted) are 4 bit deep */
-	for( color = 0; color < 0x40; color++ )
-		for( pen = 0; pen < 256; pen++ )
-			colortable[color * 256 + pen] = color * 16 + pen;
+	PALETTE_INIT_CALL(cave);
 
-	/* Layer 0 is 6 bit deep, there are 64 color codes but only $400
+	/* sprites (encrypted) are 4 bit deep */
+	for (color = 0; color < 0x40; color++)
+		for (pen = 0; pen < 0x100; pen++)
+			palette_map[(color << 8) | pen] = (color << 4) + pen;	/* yes, PLUS, not OR */
+
+	/* layer 0 is 6 bit deep, there are 64 color codes but only $400
        colors are actually addressable */
-	for( color = 0; color < 0x40; color++ )
-		for( pen = 0; pen < 64; pen++ )
-			colortable[color * 64 + pen + 0x4400] = 0x400 + (color % (64/4)) * 64 + pen;
+	for (color = 0; color < 0x40; color++)
+		for (pen = 0; pen < 0x40; pen++)
+			palette_map[0x4400 | (color << 6) | pen] = 0x400 | ((color & 0x0f) << 6) | pen;
 }
 
 PALETTE_INIT( sailormn )
 {
 	int color, pen;
 
-	/* Sprites (encrypted) are 4 bit deep */
-	for( color = 0; color < 0x40; color++ )
-		for( pen = 0; pen < 256; pen++ )
-			colortable[color * 256 + pen] = color * 16 + pen;
+	PALETTE_INIT_CALL(cave);
 
-	/* Layer 2 is 6 bit deep, there are 64 color codes but only $400
+	/* sprites (encrypted) are 4 bit deep */
+	for (color = 0; color < 0x40; color++)
+		for (pen = 0; pen < 0x100; pen++)
+			palette_map[(color << 8) | pen] = (color << 4) + pen;	/* yes, PLUS, not OR */
+
+	/* layer 2 is 6 bit deep, there are 64 color codes but only $400
        colors are actually addressable */
-	for( color = 0; color < 0x40; color++ )
-		for( pen = 0; pen < 64; pen++ )
-			colortable[color * 64 + pen + 0x4c00] = 0xc00 + (color % (64/4)) * 64 + pen;
+	for (color = 0; color < 0x40; color++)
+		for (pen = 0; pen < 0x40; pen++)
+			palette_map[0x4c00 | (color << 6) | pen] = 0xc00 | ((color & 0x0f) << 6) | pen;
 }
 
 PALETTE_INIT( pwrinst2 )
 {
 	int color, pen;
 
-	for( color = 0; color < 0x80; color++ )
-		for( pen = 0; pen < 16; pen++ )
-			colortable[color * 256 + pen] = color * 16 + pen;
+	PALETTE_INIT_CALL(cave);
 
-	for( color = 0x8000; color < machine->drv->color_table_len; color++ )
-			colortable[color] = (color - 0x8000) % machine->drv->total_colors;
+	for (color = 0; color < 0x80; color++)
+		for (pen = 0; pen < 0x10; pen++)
+			palette_map[(color << 8) | pen] = (color << 4) | pen;
+
+	for (pen = 0x8000; pen < 0xa800; pen++)
+			palette_map[pen] = pen - 0x8000;
 }
 
 PALETTE_INIT( korokoro )
 {
 	int color, pen;
 
-	for( color = 0; color < 0x40; color++ )
-		for( pen = 0; pen < 16; pen++ )
-			colortable[color * 256 + pen] = 0x3c00 + color * 16 + pen;
+	PALETTE_INIT_CALL(cave);
+
+	for (color = 0; color < 0x40; color++)
+		for (pen = 0; pen < 0x10; pen++)
+			palette_map[(color << 8) | pen] = 0x3c00 | (color << 4) | pen;
 }
 
+
+static void set_pens(running_machine *machine)
+{
+	int pen;
+
+	for (pen = 0; pen < machine->config->total_colors; pen++)
+	{
+		UINT16 data = paletteram16[palette_map[pen]];
+
+		rgb_t color = MAKE_RGB(pal5bit(data >> 5), pal5bit(data >> 10), pal5bit(data >> 0));
+
+		palette_set_color(machine, pen, color);
+	}
+}
+
+
 /***************************************************************************
 
                                   Tiles Format
@@ -326,7 +370,7 @@ static TILE_GET_INFO( sailormn_get_tile_info_2 )
 
 INLINE void vram_w(UINT16 *VRAM, tilemap *TILEMAP, ATTR_UNUSED offs_t offset, ATTR_UNUSED UINT16 data, ATTR_UNUSED UINT16 mem_mask)
 {
-	if ((VRAM[offset] & ~mem_mask)==(data & ~mem_mask)) return;
+	if ((VRAM[offset] & mem_mask)==(data & mem_mask)) return;
 	COMBINE_DATA(&VRAM[offset]);
 	offset /= 2;
 	if			 ( offset < 0x1000/4 )	// 16x16 tilemap
@@ -349,7 +393,7 @@ INLINE void vram_w(UINT16 *VRAM, tilemap *TILEMAP, ATTR_UNUSED offs_t offset, AT
 INLINE void vram_8x8_w(UINT16 *VRAM, tilemap *TILEMAP,ATTR_UNUSED offs_t offset, ATTR_UNUSED UINT16 data, ATTR_UNUSED UINT16 mem_mask)
 {
 	offset %= 0x4000/2;
-	if ((VRAM[offset] & ~mem_mask)==(data & ~mem_mask)) return;
+	if ((VRAM[offset] & mem_mask)==(data & mem_mask)) return;
 	COMBINE_DATA(&VRAM[offset + 0x0000/2]);
 	COMBINE_DATA(&VRAM[offset + 0x4000/2]);
 	tilemap_mark_tile_dirty(TILEMAP,offset/2);
@@ -389,6 +433,8 @@ static int background_color;
 
 static void cave_vh_start(running_machine *machine, int num)
 {
+	assert(palette_map != NULL);
+
 	tilemap_0 = 0;
 	tilemap_1 = 0;
 	tilemap_2 = 0;
@@ -409,29 +455,25 @@ static void cave_vh_start(running_machine *machine, int num)
 	switch( num )
 	{
 		case 4:
-			tilemap_3 = tilemap_create(	get_tile_info_3, tilemap_scan_rows,
-										TILEMAP_TYPE_PEN, 8,8, 512/8,512/8 );
+			tilemap_3 = tilemap_create(	machine, get_tile_info_3, tilemap_scan_rows, 8,8, 512/8,512/8 );
 			tilemap_set_transparent_pen(tilemap_3, 0);
 			tilemap_set_scroll_rows(tilemap_3, 1);
 			tilemap_set_scroll_cols(tilemap_3, 1);
 
 		case 3:
-			tilemap_2 = tilemap_create(	get_tile_info_2, tilemap_scan_rows,
-										TILEMAP_TYPE_PEN, 8,8, 512/8,512/8 );
+			tilemap_2 = tilemap_create(	machine, get_tile_info_2, tilemap_scan_rows, 8,8, 512/8,512/8 );
 			tilemap_set_transparent_pen(tilemap_2, 0);
 			tilemap_set_scroll_rows(tilemap_2, 1);
 			tilemap_set_scroll_cols(tilemap_2, 1);
 
 		case 2:
-			tilemap_1 = tilemap_create(	get_tile_info_1, tilemap_scan_rows,
-										TILEMAP_TYPE_PEN, 8,8, 512/8,512/8 );
+			tilemap_1 = tilemap_create(	machine, get_tile_info_1, tilemap_scan_rows, 8,8, 512/8,512/8 );
 			tilemap_set_transparent_pen(tilemap_1, 0);
 			tilemap_set_scroll_rows(tilemap_1, 1);
 			tilemap_set_scroll_cols(tilemap_1, 1);
 
 		case 1:
-			tilemap_0 = tilemap_create(	get_tile_info_0, tilemap_scan_rows,
-										TILEMAP_TYPE_PEN, 8,8, 512/8,512/8 );
+			tilemap_0 = tilemap_create(	machine, get_tile_info_0, tilemap_scan_rows, 8,8, 512/8,512/8 );
 			tilemap_set_transparent_pen(tilemap_0, 0);
 			tilemap_set_scroll_rows(tilemap_0, 1);
 			tilemap_set_scroll_cols(tilemap_0, 1);
@@ -447,9 +489,8 @@ static void cave_vh_start(running_machine *machine, int num)
 	cave_row_effect_offs_n = -1;
 	cave_row_effect_offs_f = 1;
 
-//  background_color =   machine->drv->gfxdecodeinfo[0].color_codes_start;
-	background_color =	 machine->drv->gfxdecodeinfo[0].color_codes_start +
-						(machine->drv->gfxdecodeinfo[0].total_color_codes-1) *
+	background_color =	 machine->config->gfxdecodeinfo[0].color_codes_start +
+						(machine->config->gfxdecodeinfo[0].total_color_codes-1) *
 						 machine->gfx[0]->color_granularity;
 
 	switch(cave_kludge)
@@ -478,8 +519,8 @@ VIDEO_START( sailormn_3_layers )
 	cave_vh_start(machine, 2);
 
 	/* Layer 2 (8x8) needs to be handled differently */
-	tilemap_2 = tilemap_create(	sailormn_get_tile_info_2, tilemap_scan_rows,
-								TILEMAP_TYPE_PEN, 8,8, 512/8,512/8 );
+	tilemap_2 = tilemap_create(	machine, sailormn_get_tile_info_2, tilemap_scan_rows,
+								 8,8, 512/8,512/8 );
 	tilemap_set_transparent_pen(tilemap_2, 0);
 	tilemap_set_scroll_rows(tilemap_2, 1);
 	tilemap_set_scroll_cols(tilemap_2, 1);
@@ -519,22 +560,30 @@ VIDEO_START( sailormn_3_layers )
 
 static void get_sprite_info_cave(running_machine *machine)
 {
-	const int region				=	REGION_GFX1;
+	pen_t          base_pal	=	0;
+	const UINT8  *base_gfx	=	memory_region(machine, "gfx1");
+	int                   code_max	=	memory_region_length(machine, "gfx1") / (16*16);
 
-	const pen_t          *base_pal	=	machine->remapped_colortable + 0;
-	const UINT8  *base_gfx	=	memory_region(region);
-	int                   code_max	=	memory_region_length(region) / (16*16);
 
-	UINT16      *source			=	spriteram16 + ((spriteram_size/2) / 2) * spriteram_bank;
-	UINT16      *finish			=	source + ((spriteram_size/2) / 2);
+
+	UINT16      *source;
+	UINT16      *finish;
 
 	struct sprite_cave *sprite			=	sprite_cave;
 
 	int	glob_flipx	=	cave_videoregs[ 0 ] & 0x8000;
 	int	glob_flipy	=	cave_videoregs[ 1 ] & 0x8000;
 
-	int max_x		=	machine->screen[0].width;
-	int max_y		=	machine->screen[0].height;
+	int max_x		=	video_screen_get_width(machine->primary_screen);
+	int max_y		=	video_screen_get_height(machine->primary_screen);
+
+	source = spriteram16 + ((spriteram_size/2) / 2) * spriteram_bank;
+
+	if (cave_videoregs[ 4 ] & 0x02)
+		if (cave_spriteram16_2) source = cave_spriteram16_2 + ((spriteram_size/2) / 2) * spriteram_bank;
+
+	finish = source + ((spriteram_size/2) / 2);
+
 
 	for (; source < finish; source+=8 )
 	{
@@ -622,7 +671,7 @@ static void get_sprite_info_cave(running_machine *machine)
 		sprite->priority		=	(attr & 0x0030) >> 4;
 		sprite->flags			=	SPRITE_VISIBLE_CAVE;
 		sprite->line_offset		=	sprite->tile_width;
-		sprite->pal_data		=	base_pal + (attr & 0x3f00);	// first 0x4000 colors
+		sprite->base_pen		=	base_pal + (attr & 0x3f00);	// first 0x4000 colors
 
 		if (glob_flipx)	{ x = max_x - x - sprite->total_width;	flipx = !flipx; }
 		if (glob_flipy)	{ y = max_y - y - sprite->total_height;	flipy = !flipy; }
@@ -640,22 +689,27 @@ static void get_sprite_info_cave(running_machine *machine)
 
 static void get_sprite_info_donpachi(running_machine *machine)
 {
-	const int region				=	REGION_GFX1;
+	pen_t          base_pal	=	0;
+	const UINT8  *base_gfx	=	memory_region(machine, "gfx1");
+	int                   code_max	=	memory_region_length(machine, "gfx1") / (16*16);
 
-	const pen_t          *base_pal	=	machine->remapped_colortable + 0;
-	const UINT8  *base_gfx	=	memory_region(region);
-	int                   code_max	=	memory_region_length(region) / (16*16);
-
-	UINT16      *source			=	spriteram16 + ((spriteram_size/2) / 2) * spriteram_bank;
-	UINT16      *finish			=	source + ((spriteram_size/2) / 2);
+	UINT16      *source;
+	UINT16      *finish;
 
 	struct sprite_cave *sprite			=	sprite_cave;
 
 	int	glob_flipx	=	cave_videoregs[ 0 ] & 0x8000;
 	int	glob_flipy	=	cave_videoregs[ 1 ] & 0x8000;
 
-	int max_x		=	machine->screen[0].width;
-	int max_y		=	machine->screen[0].height;
+	int max_x		=	video_screen_get_width(machine->primary_screen);
+	int max_y		=	video_screen_get_height(machine->primary_screen);
+
+	source = spriteram16 + ((spriteram_size/2) / 2) * spriteram_bank;
+
+	if (cave_videoregs[ 4 ] & 0x02)
+		if (cave_spriteram16_2) source = cave_spriteram16_2 + ((spriteram_size/2) / 2) * spriteram_bank;
+
+	finish = source + ((spriteram_size/2) / 2);
 
 	for (; source < finish; source+=8 )
 	{
@@ -692,12 +746,12 @@ static void get_sprite_info_donpachi(running_machine *machine)
 		if (cave_spritetype == 3)	/* pwrinst2 */
 		{
 			sprite->priority		=	((attr & 0x0010) >> 4)+2;
-			sprite->pal_data		=	base_pal + (attr & 0x3f00) + 0x4000*((attr & 0x0020) >> 5);
+			sprite->base_pen		=	base_pal + (attr & 0x3f00) + 0x4000*((attr & 0x0020) >> 5);
 		}
 		else
 		{
 			sprite->priority		=	(attr & 0x0030) >> 4;
-			sprite->pal_data		=	base_pal + (attr & 0x3f00);	// first 0x4000 colors
+			sprite->base_pen		=	base_pal + (attr & 0x3f00);	// first 0x4000 colors
 		}
 
 		sprite->flags			=	SPRITE_VISIBLE_CAVE;
@@ -720,8 +774,8 @@ static void get_sprite_info_donpachi(running_machine *machine)
 
 static void sprite_init_cave(running_machine *machine)
 {
-	screen_width = machine->screen[0].width;
-	screen_height = machine->screen[0].height;
+	screen_width = video_screen_get_width(machine->primary_screen);
+	screen_height = video_screen_get_height(machine->primary_screen);
 
 	if (cave_spritetype == 0 || cave_spritetype == 2)	// most of the games
 	{
@@ -734,7 +788,7 @@ static void sprite_init_cave(running_machine *machine)
 		cave_spritetype2 = 0;
 	}
 
-	sprite_zbuf = auto_bitmap_alloc( machine->screen[0].width, machine->screen[0].height, BITMAP_FORMAT_INDEXED16 );
+	sprite_zbuf = auto_bitmap_alloc(screen_width, screen_height, BITMAP_FORMAT_INDEXED16 );
 	blit.baseaddr_zbuf = sprite_zbuf->base;
 	blit.line_offset_zbuf = sprite_zbuf->rowpixels * sprite_zbuf->bpp / 8;
 
@@ -747,7 +801,7 @@ static void sprite_init_cave(running_machine *machine)
 }
 
 
-static void cave_sprite_check(running_machine *machine, const rectangle *clip )
+static void cave_sprite_check(const device_config *screen, const rectangle *clip )
 {
 	{	/* set clip */
 		int left = clip->min_x;
@@ -767,6 +821,8 @@ static void cave_sprite_check(running_machine *machine, const rectangle *clip )
 		int i[4]={0,0,0,0};
 		int priority_check = 0;
 		int spritetype = cave_spritetype2;
+		const rectangle *visarea = video_screen_get_visible_area(screen);
+
 		while( sprite<finish )
 		{
 			if( sprite->x + sprite->total_width  > blit.clip_left && sprite->x < blit.clip_right  &&
@@ -798,19 +854,19 @@ static void cave_sprite_check(running_machine *machine, const rectangle *clip )
 
 			case CAVE_SPRITETYPE_ZOOM | CAVE_SPRITETYPE_ZBUF:
 				cave_sprite_draw = sprite_draw_cave_zbuf;
-				if (clip->min_y == machine->screen[0].visarea.min_y)
+				if (clip->min_y == visarea->min_y)
 				{
 					if(!(sprite_zbuf_baseval += MAX_SPRITE_NUM))
-						fillbitmap(sprite_zbuf,0,&machine->screen[0].visarea);
+						bitmap_fill(sprite_zbuf,visarea,0);
 				}
 				break;
 
 			case CAVE_SPRITETYPE_ZBUF:
 				cave_sprite_draw = sprite_draw_donpachi_zbuf;
-				if (clip->min_y == machine->screen[0].visarea.min_y)
+				if (clip->min_y == visarea->min_y)
 				{
 					if(!(sprite_zbuf_baseval += MAX_SPRITE_NUM))
-						fillbitmap(sprite_zbuf,0,&machine->screen[0].visarea);
+						bitmap_fill(sprite_zbuf,visarea,0);
 				}
 				break;
 
@@ -880,7 +936,7 @@ static void do_blit_zoom16_cave( const struct sprite_cave *sprite ){
 
 	{
 		const UINT8 *pen_data = sprite->pen_data -1 -sprite->line_offset;
-		const pen_t         *pal_data = sprite->pal_data;
+		pen_t         base_pen = sprite->base_pen;
 		int x,y;
 		UINT8 pen;
 		int pitch = blit.line_offset*dy/2;
@@ -901,7 +957,7 @@ static void do_blit_zoom16_cave( const struct sprite_cave *sprite ){
 						source+=xcount>>16;
 						xcount &= 0xffff;
 						pen = *source;
-						if (pen) dest[x] = pal_data[pen];
+						if (pen) dest[x] = base_pen + pen;
 					}
 					xcount += sprite->zoomx_re;
 				}
@@ -972,7 +1028,7 @@ static void do_blit_zoom16_cave_zb( const struct sprite_cave *sprite ){
 
 	{
 		const UINT8 *pen_data = sprite->pen_data -1 -sprite->line_offset;
-		const pen_t         *pal_data = sprite->pal_data;
+		pen_t         base_pen = sprite->base_pen;
 		int x,y;
 		UINT8 pen;
 		int pitch = blit.line_offset*dy/2;
@@ -997,7 +1053,7 @@ static void do_blit_zoom16_cave_zb( const struct sprite_cave *sprite ){
 						xcount &= 0xffff;
 						pen = *source;
 						if (pen && (zbf[x]<=pri_sp)){
-							dest[x] = pal_data[pen];
+							dest[x] = base_pen + pen;
 							zbf[x] = pri_sp;
 						}
 					}
@@ -1066,7 +1122,7 @@ static void do_blit_16_cave( const struct sprite_cave *sprite ){
 
 	{
 		const UINT8 *pen_data = sprite->pen_data;
-		const pen_t         *pal_data = sprite->pal_data;
+		pen_t         base_pen = sprite->base_pen;
 		int x,y;
 		UINT8 pen;
 		int pitch = blit.line_offset*dy/2;
@@ -1078,7 +1134,7 @@ static void do_blit_16_cave( const struct sprite_cave *sprite ){
 			source = pen_data;
 			for( x=x1; x!=x2; x+=dx ){
 				pen = *source;
-				if (pen) dest[x] = pal_data[pen];
+				if (pen) dest[x] = base_pen + pen;
 				source++;
 			}
 			pen_data += sprite->line_offset;
@@ -1143,7 +1199,7 @@ static void do_blit_16_cave_zb( const struct sprite_cave *sprite ){
 
 	{
 		const UINT8 *pen_data = sprite->pen_data;
-		const pen_t         *pal_data = sprite->pal_data;
+		pen_t         base_pen = sprite->base_pen;
 		int x,y;
 		UINT8 pen;
 		int pitch = blit.line_offset*dy/2;
@@ -1160,7 +1216,7 @@ static void do_blit_16_cave_zb( const struct sprite_cave *sprite ){
 				pen = *source;
 				if ( pen && (zbf[x]<=pri_sp))
 				{
-					dest[x] = pal_data[pen];
+					dest[x] = base_pen + pen;
 					zbf[x] = pri_sp;
 				}
 				source++;
@@ -1271,7 +1327,7 @@ static void sprite_draw_donpachi_zbuf( int priority )
 ***************************************************************************/
 
 INLINE void cave_tilemap_draw(
-	mame_bitmap *bitmap, const rectangle *cliprect,
+	bitmap_t *bitmap, const rectangle *cliprect,
 	tilemap *TILEMAP, UINT16 *VRAM, UINT16 *VCTRL,
 	UINT32 flags, UINT32 priority, UINT32 priority2 )
 {
@@ -1391,13 +1447,13 @@ INLINE void cave_tilemap_draw(
 	}
 }
 
-static void cave_tilemap_0_draw( mame_bitmap *bitmap, const rectangle *cliprect, UINT32 flags, UINT32 priority, UINT32 priority2 )
+static void cave_tilemap_0_draw( bitmap_t *bitmap, const rectangle *cliprect, UINT32 flags, UINT32 priority, UINT32 priority2 )
 {	 cave_tilemap_draw( bitmap, cliprect, tilemap_0, cave_vram_0, cave_vctrl_0, flags, priority, priority2 );	}
-static void cave_tilemap_1_draw( mame_bitmap *bitmap, const rectangle *cliprect, UINT32 flags, UINT32 priority, UINT32 priority2 )
+static void cave_tilemap_1_draw( bitmap_t *bitmap, const rectangle *cliprect, UINT32 flags, UINT32 priority, UINT32 priority2 )
 {	 cave_tilemap_draw( bitmap, cliprect, tilemap_1, cave_vram_1, cave_vctrl_1, flags, priority, priority2 );	}
-static void cave_tilemap_2_draw( mame_bitmap *bitmap, const rectangle *cliprect, UINT32 flags, UINT32 priority, UINT32 priority2 )
+static void cave_tilemap_2_draw( bitmap_t *bitmap, const rectangle *cliprect, UINT32 flags, UINT32 priority, UINT32 priority2 )
 {	 cave_tilemap_draw( bitmap, cliprect, tilemap_2, cave_vram_2, cave_vctrl_2, flags, priority, priority2 );	}
-static void cave_tilemap_3_draw( mame_bitmap *bitmap, const rectangle *cliprect, UINT32 flags, UINT32 priority, UINT32 priority2 )
+static void cave_tilemap_3_draw( bitmap_t *bitmap, const rectangle *cliprect, UINT32 flags, UINT32 priority, UINT32 priority2 )
 {	 cave_tilemap_draw( bitmap, cliprect, tilemap_3, cave_vram_3, cave_vctrl_3, flags, priority, priority2 );	}
 
 
@@ -1406,6 +1462,8 @@ VIDEO_UPDATE( cave )
 	int pri, pri2;
 	int layers_ctrl = -1;
 
+	set_pens(screen->machine);
+
 	blit.baseaddr = bitmap->base;
 	blit.line_offset = bitmap->rowpixels * bitmap->bpp / 8;
 
@@ -1488,9 +1546,9 @@ VIDEO_UPDATE( cave )
 }
 #endif
 
-	cave_sprite_check(machine, cliprect);
+	cave_sprite_check(screen, cliprect);
 
-	fillbitmap(bitmap,machine->remapped_colortable[background_color],cliprect);
+	bitmap_fill(bitmap,cliprect,background_color);
 
 	/*
         Tiles and sprites are ordered by priority (0 back, 3 front) with
