@@ -54,12 +54,12 @@ Note:   if MAME_DEBUG is defined, pressing Z or X with:
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "megasys1.h"
 
 /* Variables only used here: */
 
 static int cischeat_ip_select;
+static int shift_ret = 1;
 
 #ifdef MAME_DEBUG
 static int debugsprites;	// For debug purposes
@@ -74,13 +74,13 @@ UINT16 *f1gpstr2_ioready;
 #define SHOW_READ_ERROR(_format_,_offset_)\
 {\
 	popmessage(_format_,_offset_);\
-	logerror("CPU #0 PC %06X : Warning, ",activecpu_get_pc()); \
+	logerror("CPU #0 PC %06X : Warning, ",cpu_get_pc(space->cpu)); \
 	logerror(_format_ "\n",_offset_);\
 }
 #define SHOW_WRITE_ERROR(_format_,_offset_,_data_)\
 {\
 	popmessage(_format_,_offset_,_data_);\
-	logerror("CPU #0 PC %06X : Warning, ",activecpu_get_pc()); \
+	logerror("CPU #0 PC %06X : Warning, ",cpu_get_pc(space->cpu)); \
 	logerror(_format_ "\n",_offset_,_data_); \
 }
 
@@ -88,12 +88,12 @@ UINT16 *f1gpstr2_ioready;
 
 #define SHOW_READ_ERROR(_format_,_offset_)\
 {\
-	logerror("CPU #0 PC %06X : Warning, ",activecpu_get_pc()); \
+	logerror("CPU #0 PC %06X : Warning, ",cpu_get_pc(space->cpu)); \
 	logerror(_format_ "\n",_offset_);\
 }
 #define SHOW_WRITE_ERROR(_format_,_offset_,_data_)\
 {\
-	logerror("CPU #0 PC %06X : Warning, ",activecpu_get_pc()); \
+	logerror("CPU #0 PC %06X : Warning, ",cpu_get_pc(space->cpu)); \
 	logerror(_format_ "\n",_offset_,_data_); \
 }
 
@@ -142,6 +142,7 @@ static void prepare_shadows(void)
 /* 32 colour codes for the tiles */
 VIDEO_START( cischeat )
 {
+	shift_ret = 1;
 	VIDEO_START_CALL(megasys1);
 
  	megasys1_bits_per_color_code = 5;
@@ -183,18 +184,16 @@ VIDEO_START( bigrun )
 
     and allows the shift to be handled using two buttons */
 
-static int read_shift(void)
+CUSTOM_INPUT( cischeat_shift_r )
 {
-	static int ret = 1; /* start with low shift */
-	switch ( (readinputport(0) >> 2) & 3 )
+	switch ( (input_port_read(field->port->machine, "FAKE") >> 2) & 3 )
 	{
-		case 1 : ret = 1;	break;	// low  shift: button 3
-		case 2 : ret = 0;	break;	// high shift: button 4
+		case 1 : shift_ret = 1;	break;	// low  shift: button 3
+		case 2 : shift_ret = 0;	break;	// high shift: button 4
 	}
-	return ret;
+	return shift_ret;
 }
 
-
 /*
     F1 GP Star has a real pedal, while Cisco Heat's is connected to
     a switch. The Former game stores, during boot, the value that
@@ -204,9 +203,9 @@ static int read_shift(void)
     We support just 2 values for now..
 */
 
-static int read_accelerator(void)
+static int read_accelerator(running_machine *machine)
 {
-	if (readinputport(0) & 1)	return 0x00;	// pedal pressed
+	if (input_port_read(machine, "FAKE") & 1)	return 0x00;	// pedal pressed
 	else						return 0xff;
 }
 
@@ -219,26 +218,25 @@ READ16_HANDLER( bigrun_vregs_r )
 {
 	switch (offset)
 	{
-		case 0x0000/2 : return readinputport(1);	// Coins
-		case 0x0002/2 : return readinputport(2) +
-						(read_shift()<<1);			// Buttons
-		case 0x0004/2 : return readinputport(3);	// Motor Limit Switches
-		case 0x0006/2 : return readinputport(4);	// DSW 1 & 2
+		case 0x0000/2 : return input_port_read(space->machine, "IN1");	// Coins
+		case 0x0002/2 : return input_port_read(space->machine, "IN2");	// Buttons
+		case 0x0004/2 : return input_port_read(space->machine, "IN3");	// Motor Limit Switches
+		case 0x0006/2 : return input_port_read(space->machine, "IN4");	// DSW 1 & 2
 
-		case 0x0008/2 :	return soundlatch2_word_r(0,0);	// From sound cpu
+		case 0x0008/2 :	return soundlatch2_word_r(space,0,0xffff);	// From sound cpu
 
 		case 0x0010/2 :
 			switch (cischeat_ip_select & 0x3)
 			{
-				case 0 : return readinputport(6);		// Driving Wheel
+				case 0 : return input_port_read(space->machine, "IN6");		// Driving Wheel
 				case 1 : return 0xffff;					// Cockpit: Up / Down Position
 				case 2 : return 0xffff;					// Cockpit: Left / Right Position?
-				case 3 : return ~read_accelerator();	// Accelerator (Pedal)
+				case 3 : return ~read_accelerator(space->machine);	// Accelerator (Pedal)
 				default: return 0xffff;
 			}
 
 
-		case 0x2200/2 : return readinputport(5);	// DSW 3 (4 bits)
+		case 0x2200/2 : return input_port_read(space->machine, "IN5");	// DSW 3 (4 bits)
 
 		default:	SHOW_READ_ERROR("vreg %04X read!",offset*2);
 					return megasys1_vregs[offset];
@@ -253,7 +251,7 @@ WRITE16_HANDLER( bigrun_vregs_w )
 	switch (offset)
 	{
  		case 0x0000/2   :	// leds
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 			{
 	 			coin_counter_w(0,new_data & 0x01);
 	 			coin_counter_w(1,new_data & 0x02);
@@ -266,7 +264,7 @@ WRITE16_HANDLER( bigrun_vregs_w )
 			break;
 
  		case 0x0004/2   :	// motor (seat?)
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				set_led_status(2, (new_data != old_data) ? 1 : 0);
  			break;
 
@@ -274,7 +272,7 @@ WRITE16_HANDLER( bigrun_vregs_w )
 			break;
 
 		case 0x000a/2   :	// to sound cpu
-			soundlatch_word_w(0,new_data,0);
+			soundlatch_word_w(space,0,new_data,0xffff);
 			break;
 
 		case 0x000c/2   :	break;	// ??
@@ -298,9 +296,9 @@ WRITE16_HANDLER( bigrun_vregs_w )
 		case 0x2208/2   : break;	// watchdog reset
 
 		/* Not sure about this one.. */
-		case 0x2308/2   :	cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
-							cpunum_set_input_line(Machine, 2, INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
-							cpunum_set_input_line(Machine, 3, INPUT_LINE_RESET, (new_data & 1) ? ASSERT_LINE : CLEAR_LINE );
+		case 0x2308/2   :	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
+							cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
+							cpu_set_input_line(space->machine->cpu[3], INPUT_LINE_RESET, (new_data & 1) ? ASSERT_LINE : CLEAR_LINE );
 							break;
 
 		default: SHOW_WRITE_ERROR("vreg %04X <- %04X",offset*2,data);
@@ -316,23 +314,22 @@ READ16_HANDLER( cischeat_vregs_r )
 {
 	switch (offset)
 	{
-		case 0x0000/2 : return readinputport(1);	// Coins
-		case 0x0002/2 : return readinputport(2) +
-						(read_shift()<<1);			// Buttons
-		case 0x0004/2 : return readinputport(3);	// Motor Limit Switches
-		case 0x0006/2 : return readinputport(4);	// DSW 1 & 2
+		case 0x0000/2 : return input_port_read(space->machine, "IN1");	// Coins
+		case 0x0002/2 : return input_port_read(space->machine, "IN2");	// Buttons
+		case 0x0004/2 : return input_port_read(space->machine, "IN3");	// Motor Limit Switches
+		case 0x0006/2 : return input_port_read(space->machine, "IN4");	// DSW 1 & 2
 
 		case 0x0010/2 :
 			switch (cischeat_ip_select & 0x3)
 			{
-				case 0 : return readinputport(6);	// Driving Wheel
+				case 0 : return input_port_read(space->machine, "IN6");	// Driving Wheel
 				case 1 : return ~0;					// Cockpit: Up / Down Position?
 				case 2 : return ~0;					// Cockpit: Left / Right Position?
 				default: return ~0;
 			}
 
-		case 0x2200/2 : return readinputport(5);	// DSW 3 (4 bits)
-		case 0x2300/2 : return soundlatch2_r(0);	// From sound cpu
+		case 0x2200/2 : return input_port_read(space->machine, "IN5");	// DSW 3 (4 bits)
+		case 0x2300/2 : return soundlatch2_r(space,0);	// From sound cpu
 
 		default:	SHOW_READ_ERROR("vreg %04X read!",offset*2);
 					return megasys1_vregs[offset];
@@ -347,7 +344,7 @@ WRITE16_HANDLER( cischeat_vregs_w )
 	switch (offset)
 	{
  		case 0x0000/2   :	// leds
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 			{
 	 			coin_counter_w(0,new_data & 0x01);
 	 			coin_counter_w(1,new_data & 0x02);
@@ -360,7 +357,7 @@ WRITE16_HANDLER( cischeat_vregs_w )
 			break;
 
  		case 0x0004/2   :	// motor (seat?)
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 				set_led_status(2, (new_data != old_data) ? 1 : 0);
  			break;
 
@@ -386,14 +383,14 @@ WRITE16_HANDLER( cischeat_vregs_w )
 		case 0x2208/2   : break;	// watchdog reset
 
 		case 0x2300/2   :	/* Sound CPU: reads latch during int 4, and stores command */
-							soundlatch_word_w(0,new_data,0);
-							cpunum_set_input_line(Machine, 3,4,HOLD_LINE);
+							soundlatch_word_w(space,0,new_data,0xffff);
+							cpu_set_input_line(space->machine->cpu[3],4,HOLD_LINE);
 							break;
 
 		/* Not sure about this one.. */
-		case 0x2308/2   :	cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
-							cpunum_set_input_line(Machine, 2, INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
-							cpunum_set_input_line(Machine, 3, INPUT_LINE_RESET, (new_data & 1) ? ASSERT_LINE : CLEAR_LINE );
+		case 0x2308/2   :	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
+							cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
+							cpu_set_input_line(space->machine->cpu[3], INPUT_LINE_RESET, (new_data & 1) ? ASSERT_LINE : CLEAR_LINE );
 							break;
 
 		default: SHOW_WRITE_ERROR("vreg %04X <- %04X",offset*2,data);
@@ -410,24 +407,20 @@ READ16_HANDLER( f1gpstar_vregs_r )
 {
 	switch (offset)
 	{
-		case 0x0000/2 :	// DSW 1&2: coinage changes with Country
-		{
-			int val = readinputport(1);
-			if (val & 0x0200)	return readinputport(6) | val; 	// JP, US
-			else				return readinputport(7) | val; 	// UK, FR
-		}
+		case 0x0000/2 :	return input_port_read(space->machine, "IN1");	// DSW 1 & 2
 
 //      case 0x0002/2 : return 0xFFFF;
-		case 0x0004/2 :	return readinputport(2) +
-						       (read_shift()<<5);	// Buttons
 
-		case 0x0006/2 :	return readinputport(3);	// ? Read at boot only
-		case 0x0008/2 :	return soundlatch2_r(0);	// From sound cpu
+		case 0x0004/2 :	return input_port_read(space->machine, "IN2");	// Buttons
 
-		case 0x000c/2 :	return readinputport(4);	// DSW 3
+		case 0x0006/2 :	return input_port_read(space->machine, "IN3");	// ? Read at boot only
+
+		case 0x0008/2 :	return soundlatch2_r(space,0);		// From sound cpu
+
+		case 0x000c/2 :	return input_port_read(space->machine, "IN4");	// DSW 3
 
 		case 0x0010/2 :	// Accel + Driving Wheel
-			return (read_accelerator()&0xff) + ((readinputport(5)&0xff)<<8);
+			return (read_accelerator(space->machine) & 0xff) + ((input_port_read(space->machine, "IN5") & 0xff)<<8);
 
 		default:		SHOW_READ_ERROR("vreg %04X read!",offset*2);
 						return megasys1_vregs[offset];
@@ -445,7 +438,7 @@ READ16_HANDLER( f1gpstr2_vregs_r )
 			return (f1gpstr2_ioready[0]&1) ? 0xff : 0xf0;
 
 		default:
-			return f1gpstar_vregs_r(offset,mem_mask);
+			return f1gpstar_vregs_r(space,offset,mem_mask);
 	}
 }
 
@@ -460,14 +453,14 @@ READ16_HANDLER( wildplt_vregs_r )
 
 	switch (offset)
 	{
-		case 0x0000/2 :	return readinputport(0); // DSW 1 & 2
+		case 0x0000/2 :	return input_port_read(space->machine, "IN0"); // DSW 1 & 2
 
-		case 0x0004/2 :	return readinputport(1); // Buttons
+		case 0x0004/2 :	return input_port_read(space->machine, "IN1"); // Buttons
 
-		case 0x0008/2 :	return soundlatch2_r(0); // From sound cpu
+		case 0x0008/2 :	return soundlatch2_r(space,0); // From sound cpu
 
 		case 0x0010/2 :	// X, Y
-			return readinputport(2) | (readinputport(3)<<8);
+			return input_port_read(space->machine, "IN2") | (input_port_read(space->machine, "IN3")<<8);
 
 		case 0x0018/2 :
 			return (f1gpstr2_ioready[0]&1) ? 0xff : 0xf0;
@@ -492,7 +485,7 @@ CPU #0 PC 00235C : Warning, vreg 0006 <- 0000
 */
 		// "shudder" motors, leds
 		case 0x0004/2   :
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 			{
 	 			coin_counter_w(0,new_data & 0x01);
 	 			coin_counter_w(1,new_data & 0x02);
@@ -505,8 +498,8 @@ CPU #0 PC 00235C : Warning, vreg 0006 <- 0000
 		case 0x0014/2   :	break;
 
 		/* Usually written in sequence, but not always */
-		case 0x0008/2   :	soundlatch_word_w(0,new_data,0);	break;
-		case 0x0018/2   :	cpunum_set_input_line(Machine, 3,4,HOLD_LINE);	break;
+		case 0x0008/2   :	soundlatch_word_w(space,0,new_data,0xffff);	break;
+		case 0x0018/2   :	cpu_set_input_line(space->machine->cpu[3],4,HOLD_LINE);	break;
 
 		case 0x0010/2   :	break;
 
@@ -526,9 +519,9 @@ CPU #0 PC 00235C : Warning, vreg 0006 <- 0000
 		case 0x2208/2   : break;	// watchdog reset
 
 		/* Not sure about this one. Values: $10 then 0, $7 then 0 */
-		case 0x2308/2   :	cpunum_set_input_line(Machine, 1, INPUT_LINE_RESET, (new_data & 1) ? ASSERT_LINE : CLEAR_LINE );
-							cpunum_set_input_line(Machine, 2, INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
-							cpunum_set_input_line(Machine, 3, INPUT_LINE_RESET, (new_data & 4) ? ASSERT_LINE : CLEAR_LINE );
+		case 0x2308/2   :	cpu_set_input_line(space->machine->cpu[1], INPUT_LINE_RESET, (new_data & 1) ? ASSERT_LINE : CLEAR_LINE );
+							cpu_set_input_line(space->machine->cpu[2], INPUT_LINE_RESET, (new_data & 2) ? ASSERT_LINE : CLEAR_LINE );
+							cpu_set_input_line(space->machine->cpu[3], INPUT_LINE_RESET, (new_data & 4) ? ASSERT_LINE : CLEAR_LINE );
 							break;
 
 		default:		SHOW_WRITE_ERROR("vreg %04X <- %04X",offset*2,data);
@@ -546,15 +539,16 @@ WRITE16_HANDLER( f1gpstr2_vregs_w )
 	switch (offset)
 	{
 		case 0x0000/2   :
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 			{
-				cpunum_set_input_line(Machine, 4,4,(new_data & 4)?ASSERT_LINE:CLEAR_LINE);
-				cpunum_set_input_line(Machine, 4,2,(new_data & 2)?ASSERT_LINE:CLEAR_LINE);
+				cpu_set_input_line(space->machine->cpu[4],4,(new_data & 4)?ASSERT_LINE:CLEAR_LINE);
+				cpu_set_input_line(space->machine->cpu[4],2,(new_data & 2)?ASSERT_LINE:CLEAR_LINE);
 			}
 			break;
 
 		default:
-			f1gpstar_vregs_w(offset,data,mem_mask);
+			f1gpstar_vregs_w(space,offset,data,mem_mask);
+			break;
 	}
 }
 
@@ -583,7 +577,7 @@ WRITE16_HANDLER( scudhamm_vregs_w )
 		case 0x100/2+1 : MEGASYS1_VREG_SCROLL(2,y)		break;
 		case 0x100/2+2 : megasys1_set_vreg_flag(2,new_data);break;
 
-		case 0x208/2   : watchdog_reset_w(0,0);	break;
+		case 0x208/2   : watchdog_reset_w(space,0,0);	break;
 
 		default: SHOW_WRITE_ERROR("vreg %04X <- %04X",offset*2,data);
 	}
@@ -628,7 +622,7 @@ WRITE16_HANDLER( scudhamm_vregs_w )
 /*  Draw the road in the given bitmap. The priority1 and priority2 parameters
     specify the range of lines to draw  */
 
-static void cischeat_draw_road(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int road_num, int priority1, int priority2, int transparency)
+static void cischeat_draw_road(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int road_num, int priority1, int priority2, int transparency)
 {
 	int curr_code,sx,sy;
 	int min_priority, max_priority;
@@ -718,7 +712,7 @@ static void cischeat_draw_road(running_machine *machine, mame_bitmap *bitmap, co
 /*  Draw the road in the given bitmap. The priority1 and priority2 parameters
     specify the range of lines to draw  */
 
-static void f1gpstar_draw_road(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int road_num, int priority1, int priority2, int transparency)
+static void f1gpstar_draw_road(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int road_num, int priority1, int priority2, int transparency)
 {
 	int sx,sy;
 	int xstart;
@@ -834,7 +828,7 @@ static void f1gpstar_draw_road(running_machine *machine, mame_bitmap *bitmap, co
     sprites whose priority nibble is between 0 and 15 and whose
     colour code's high bit is set.  */
 
-static void cischeat_draw_sprites(running_machine *machine, mame_bitmap *bitmap , const rectangle *cliprect, int priority1, int priority2)
+static void cischeat_draw_sprites(running_machine *machine, bitmap_t *bitmap , const rectangle *cliprect, int priority1, int priority2)
 {
 	int x, sx, flipx, xzoom, xscale, xdim, xnum, xstart, xend, xinc;
 	int y, sy, flipy, yzoom, yscale, ydim, ynum, ystart, yend, yinc;
@@ -989,7 +983,7 @@ if (input_code_pressed(KEYCODE_X))
 
 ***************************************************************************/
 
-static void bigrun_draw_sprites(running_machine *machine, mame_bitmap *bitmap , const rectangle *cliprect, int priority1, int priority2)
+static void bigrun_draw_sprites(running_machine *machine, bitmap_t *bitmap , const rectangle *cliprect, int priority1, int priority2)
 {
 	int x, sx, flipx, xzoom, xscale, xdim, xnum, xstart, xend, xinc;
 	int y, sy, flipy, yzoom, yscale, ydim, ynum, ystart, yend, yinc;
@@ -1173,12 +1167,12 @@ VIDEO_UPDATE( bigrun )
 	cischeat_tmap_SET_SCROLL(1)
 	cischeat_tmap_SET_SCROLL(2)
 
-	fillbitmap(bitmap,machine->pens[0],cliprect);
+	bitmap_fill(bitmap,cliprect,0);
 
 	for (i = 7; i >= 4; i--)
 	{											/* bitmap, road, min_priority, max_priority, transparency */
-		if (megasys1_active_layers & 0x10)	cischeat_draw_road(machine,bitmap,cliprect,0,i,i,TRANSPARENCY_NONE);
-		if (megasys1_active_layers & 0x20)	cischeat_draw_road(machine,bitmap,cliprect,1,i,i,TRANSPARENCY_PEN);
+		if (megasys1_active_layers & 0x10)	cischeat_draw_road(screen->machine,bitmap,cliprect,0,i,i,TRANSPARENCY_NONE);
+		if (megasys1_active_layers & 0x20)	cischeat_draw_road(screen->machine,bitmap,cliprect,1,i,i,TRANSPARENCY_PEN);
 	}
 
 	flag = 0;
@@ -1187,11 +1181,11 @@ VIDEO_UPDATE( bigrun )
 
 	for (i = 3; i >= 0; i--)
 	{											/* bitmap, road, min_priority, max_priority, transparency */
-		if (megasys1_active_layers & 0x10)	cischeat_draw_road(machine,bitmap,cliprect,0,i,i,TRANSPARENCY_PEN);
-		if (megasys1_active_layers & 0x20)	cischeat_draw_road(machine,bitmap,cliprect,1,i,i,TRANSPARENCY_PEN);
+		if (megasys1_active_layers & 0x10)	cischeat_draw_road(screen->machine,bitmap,cliprect,0,i,i,TRANSPARENCY_PEN);
+		if (megasys1_active_layers & 0x20)	cischeat_draw_road(screen->machine,bitmap,cliprect,1,i,i,TRANSPARENCY_PEN);
 	}
 
-	if (megasys1_active_layers & 0x08)	bigrun_draw_sprites(machine,bitmap,cliprect,15,0);
+	if (megasys1_active_layers & 0x08)	bigrun_draw_sprites(screen->machine,bitmap,cliprect,15,0);
 
 	cischeat_tmap_DRAW(2)
 
@@ -1226,28 +1220,28 @@ VIDEO_UPDATE( cischeat )
 	cischeat_tmap_SET_SCROLL(1)
 	cischeat_tmap_SET_SCROLL(2)
 
-	fillbitmap(bitmap,machine->pens[0],cliprect);
+	bitmap_fill(bitmap,cliprect,0);
 
 										/* bitmap, road, priority, transparency */
-	if (megasys1_active_layers & 0x10)	cischeat_draw_road(machine,bitmap,cliprect,0,7,5,TRANSPARENCY_NONE);
-	if (megasys1_active_layers & 0x20)	cischeat_draw_road(machine,bitmap,cliprect,1,7,5,TRANSPARENCY_PEN);
+	if (megasys1_active_layers & 0x10)	cischeat_draw_road(screen->machine,bitmap,cliprect,0,7,5,TRANSPARENCY_NONE);
+	if (megasys1_active_layers & 0x20)	cischeat_draw_road(screen->machine,bitmap,cliprect,1,7,5,TRANSPARENCY_PEN);
 
 	flag = 0;
 	cischeat_tmap_DRAW(0)
-//  else fillbitmap(bitmap,machine->pens[0],cliprect);
+//  else bitmap_fill(bitmap,cliprect,0);
 	cischeat_tmap_DRAW(1)
 
-	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(machine,bitmap,cliprect,15,3);
-	if (megasys1_active_layers & 0x10)	cischeat_draw_road(machine,bitmap,cliprect,0,4,1,TRANSPARENCY_PEN);
-	if (megasys1_active_layers & 0x20)	cischeat_draw_road(machine,bitmap,cliprect,1,4,1,TRANSPARENCY_PEN);
-	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(machine,bitmap,cliprect,2,2);
-	if (megasys1_active_layers & 0x10)	cischeat_draw_road(machine,bitmap,cliprect,0,0,0,TRANSPARENCY_PEN);
-	if (megasys1_active_layers & 0x20)	cischeat_draw_road(machine,bitmap,cliprect,1,0,0,TRANSPARENCY_PEN);
-	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(machine,bitmap,cliprect,1,0);
+	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(screen->machine,bitmap,cliprect,15,3);
+	if (megasys1_active_layers & 0x10)	cischeat_draw_road(screen->machine,bitmap,cliprect,0,4,1,TRANSPARENCY_PEN);
+	if (megasys1_active_layers & 0x20)	cischeat_draw_road(screen->machine,bitmap,cliprect,1,4,1,TRANSPARENCY_PEN);
+	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(screen->machine,bitmap,cliprect,2,2);
+	if (megasys1_active_layers & 0x10)	cischeat_draw_road(screen->machine,bitmap,cliprect,0,0,0,TRANSPARENCY_PEN);
+	if (megasys1_active_layers & 0x20)	cischeat_draw_road(screen->machine,bitmap,cliprect,1,0,0,TRANSPARENCY_PEN);
+	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(screen->machine,bitmap,cliprect,1,0);
 	cischeat_tmap_DRAW(2)
 
 	/* for the map screen */
-	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(machine,bitmap,cliprect,0+16,0+16);
+	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(screen->machine,bitmap,cliprect,0+16,0+16);
 
 
 	megasys1_active_layers = megasys1_active_layers1;
@@ -1282,32 +1276,32 @@ VIDEO_UPDATE( f1gpstar )
 	cischeat_tmap_SET_SCROLL(1)
 	cischeat_tmap_SET_SCROLL(2)
 
-	fillbitmap(bitmap,machine->pens[0],cliprect);
+	bitmap_fill(bitmap,cliprect,0);
 
 /*  1: clouds 5, grad 7, road 0     2: clouds 5, grad 7, road 0, tunnel roof 0 */
 
 	/* road 1!! 0!! */					/* bitmap, road, min_priority, max_priority, transparency */
-	if (megasys1_active_layers & 0x20)	f1gpstar_draw_road(machine,bitmap,cliprect,1,6,7,TRANSPARENCY_PEN);
-	if (megasys1_active_layers & 0x10)	f1gpstar_draw_road(machine,bitmap,cliprect,0,6,7,TRANSPARENCY_PEN);
+	if (megasys1_active_layers & 0x20)	f1gpstar_draw_road(screen->machine,bitmap,cliprect,1,6,7,TRANSPARENCY_PEN);
+	if (megasys1_active_layers & 0x10)	f1gpstar_draw_road(screen->machine,bitmap,cliprect,0,6,7,TRANSPARENCY_PEN);
 
 	flag = 0;
 	cischeat_tmap_DRAW(0)
-//  else fillbitmap(bitmap,machine->pens[0],cliprect);
+//  else bitmap_fill(bitmap,cliprect,0);
 	cischeat_tmap_DRAW(1)
 
 	/* road 1!! 0!! */					/* bitmap, road, min_priority, max_priority, transparency */
-	if (megasys1_active_layers & 0x20)	f1gpstar_draw_road(machine,bitmap,cliprect,1,1,5,TRANSPARENCY_PEN);
-	if (megasys1_active_layers & 0x10)	f1gpstar_draw_road(machine,bitmap,cliprect,0,1,5,TRANSPARENCY_PEN);
+	if (megasys1_active_layers & 0x20)	f1gpstar_draw_road(screen->machine,bitmap,cliprect,1,1,5,TRANSPARENCY_PEN);
+	if (megasys1_active_layers & 0x10)	f1gpstar_draw_road(screen->machine,bitmap,cliprect,0,1,5,TRANSPARENCY_PEN);
 
-	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(machine,bitmap,cliprect,15,2);
+	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(screen->machine,bitmap,cliprect,15,2);
 
 	/* road 1!! 0!! */					/* bitmap, road, min_priority, max_priority, transparency */
-	if (megasys1_active_layers & 0x20)	f1gpstar_draw_road(machine,bitmap,cliprect,1,0,0,TRANSPARENCY_PEN);
-	if (megasys1_active_layers & 0x10)	f1gpstar_draw_road(machine,bitmap,cliprect,0,0,0,TRANSPARENCY_PEN);
+	if (megasys1_active_layers & 0x20)	f1gpstar_draw_road(screen->machine,bitmap,cliprect,1,0,0,TRANSPARENCY_PEN);
+	if (megasys1_active_layers & 0x10)	f1gpstar_draw_road(screen->machine,bitmap,cliprect,0,0,0,TRANSPARENCY_PEN);
 
-	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(machine,bitmap,cliprect,1,1);
+	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(screen->machine,bitmap,cliprect,1,1);
 	cischeat_tmap_DRAW(2)
-	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(machine,bitmap,cliprect,0,0);
+	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(screen->machine,bitmap,cliprect,0,0);
 
 
 	megasys1_active_layers = megasys1_active_layers1;
@@ -1347,11 +1341,15 @@ if ( input_code_pressed(KEYCODE_Z) || input_code_pressed(KEYCODE_X) )
 
 	if (msk != 0) megasys1_active_layers &= msk;
 #if 1
-	popmessage("Cmd: %04X Pos:%04X Lim:%04X Inp:%04X",
-						scudhamm_motor_command,
-						scudhamm_motor_pos_r(0,0),
-						scudhamm_motor_status_r(0,0),
-						scudhamm_analog_r(0,0) );
+	{
+		const address_space *space = cpu_get_address_space(screen->machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+		popmessage("Cmd: %04X Pos:%04X Lim:%04X Inp:%04X",
+							scudhamm_motor_command,
+							scudhamm_motor_pos_r(space,0,0xffff),
+							scudhamm_motor_status_r(space,0,0xffff),
+							scudhamm_analog_r(space,0,0xffff) );
+	}
 #endif
 
 }
@@ -1361,13 +1359,13 @@ if ( input_code_pressed(KEYCODE_Z) || input_code_pressed(KEYCODE_X) )
 //  cischeat_tmap_SET_SCROLL(1)
 	cischeat_tmap_SET_SCROLL(2)
 
-	fillbitmap(bitmap,machine->pens[0],cliprect);
+	bitmap_fill(bitmap,cliprect,0);
 
 	flag = 0;
 	cischeat_tmap_DRAW(0)
-//  else fillbitmap(bitmap,machine->pens[0],cliprect);
+//  else bitmap_fill(bitmap,cliprect,0);
 //  cischeat_tmap_DRAW(1)
-	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(machine,bitmap,cliprect,0,15);
+	if (megasys1_active_layers & 0x08)	cischeat_draw_sprites(screen->machine,bitmap,cliprect,0,15);
 	cischeat_tmap_DRAW(2)
 
 	megasys1_active_layers = megasys1_active_layers1;
