@@ -140,7 +140,6 @@ Rowscroll style:
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "deco16ic.h"
 #include "ui.h"
 
@@ -163,7 +162,7 @@ static int use_custom_pf1, use_custom_pf2, use_custom_pf3, use_custom_pf4;
 static tilemap *pf1_tilemap_16x16,*pf2_tilemap_16x16,*pf3_tilemap_16x16,*pf4_tilemap_16x16;
 static tilemap *pf1_tilemap_8x8,*pf2_tilemap_8x8;
 
-static mame_bitmap *sprite_priority_bitmap;
+static bitmap_t *sprite_priority_bitmap;
 
 static UINT8 *dirty_palette;
 static int deco16_pf1_bank,deco16_pf2_bank,deco16_pf3_bank,deco16_pf4_bank;
@@ -175,7 +174,8 @@ static int (*deco16_bank_callback_1)(const int bank);
 static int (*deco16_bank_callback_2)(const int bank);
 static int (*deco16_bank_callback_3)(const int bank);
 static int (*deco16_bank_callback_4)(const int bank);
-static void custom_tilemap_draw(mame_bitmap *bitmap,tilemap *tilemap0_8x8,tilemap *tilemap0_16x16,
+static void custom_tilemap_draw(running_machine *machine,
+	bitmap_t *bitmap,tilemap *tilemap0_8x8,tilemap *tilemap0_16x16,
 	tilemap *tilemap1_8x8,tilemap *tilemap1_16x16, const UINT16 *rowscroll_ptr,const UINT16 scrollx,
 	const UINT16 scrolly,const UINT16 control0, const UINT16 control1,int combine_mask,int combine_shift,int trans_mask,int flags,UINT32 priority);
 
@@ -195,7 +195,7 @@ WRITE16_HANDLER( deco16_nonbuffered_palette_w )
 	g = (paletteram16[offset+1] >> 8) & 0xff;
 	r = (paletteram16[offset+1] >> 0) & 0xff;
 
-	palette_set_color(Machine,offset/2,MAKE_RGB(r,g,b));
+	palette_set_color(space->machine,offset/2,MAKE_RGB(r,g,b));
 }
 
 WRITE16_HANDLER( deco16_buffered_palette_w )
@@ -206,7 +206,7 @@ WRITE16_HANDLER( deco16_buffered_palette_w )
 
 WRITE16_HANDLER( deco16_palette_dma_w )
 {
-	const int m=Machine->drv->total_colors;
+	const int m=space->machine->config->total_colors;
 	int r,g,b,i;
 
 	for (i=0; i<m; i++) {
@@ -217,7 +217,7 @@ WRITE16_HANDLER( deco16_palette_dma_w )
 			g = (paletteram16[i*2+1] >> 8) & 0xff;
 			r = (paletteram16[i*2+1] >> 0) & 0xff;
 
-			palette_set_color(Machine,i,MAKE_RGB(r,g,b));
+			palette_set_color(space->machine,i,MAKE_RGB(r,g,b));
 		}
 	}
 }
@@ -516,26 +516,28 @@ WRITE16_HANDLER( deco16_pf4_data_w )
 
 /*****************************************************************************************/
 
-static void deco16_video_init(int pf12_only, int split, int full_width)
+static void deco16_video_init(running_machine *machine, int pf12_only, int split, int full_width)
 {
-	sprite_priority_bitmap = auto_bitmap_alloc( Machine->screen[0].width, Machine->screen[0].height, BITMAP_FORMAT_INDEXED8 );
+	int width = video_screen_get_width(machine->primary_screen);
+	int height = video_screen_get_height(machine->primary_screen);
+	sprite_priority_bitmap = auto_bitmap_alloc(width, height, BITMAP_FORMAT_INDEXED8 );
 
-	pf1_tilemap_16x16 =	tilemap_create(get_pf1_tile_info,   deco16_scan_rows, TILEMAP_TYPE_PEN,16,16,64,32);
-	pf1_tilemap_8x8 =	tilemap_create(get_pf1_tile_info_b, tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,64,32);
+	pf1_tilemap_16x16 =	tilemap_create(machine, get_pf1_tile_info,   deco16_scan_rows, 16,16,64,32);
+	pf1_tilemap_8x8 =	tilemap_create(machine, get_pf1_tile_info_b, tilemap_scan_rows,8,8,64,32);
 
 	if (split)
-		pf2_tilemap_16x16 =	tilemap_create(get_pf2_tile_info,   deco16_scan_rows, TILEMAP_TYPE_PEN,16,16,full_width ? 64 : 32,32);
+		pf2_tilemap_16x16 =	tilemap_create(machine, get_pf2_tile_info,   deco16_scan_rows, 16,16,full_width ? 64 : 32,32);
 	else
-		pf2_tilemap_16x16 =	tilemap_create(get_pf2_tile_info,   deco16_scan_rows, TILEMAP_TYPE_PEN,16,16,full_width ? 64 : 32,32);
-	pf2_tilemap_8x8 =	tilemap_create(get_pf2_tile_info_b, tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,full_width ? 64 : 32,32);
+		pf2_tilemap_16x16 =	tilemap_create(machine, get_pf2_tile_info,   deco16_scan_rows, 16,16,full_width ? 64 : 32,32);
+	pf2_tilemap_8x8 =	tilemap_create(machine, get_pf2_tile_info_b, tilemap_scan_rows,8,8,full_width ? 64 : 32,32);
 
 	dirty_palette = auto_malloc(4096);
 	deco16_raster_display_list=auto_malloc(20 * 256);
 
 	if (!pf12_only)
 	{
-		pf4_tilemap_16x16 =	tilemap_create(get_pf4_tile_info,   deco16_scan_rows, TILEMAP_TYPE_PEN,16,16,full_width ? 64 : 32,32);
-		pf3_tilemap_16x16 =	tilemap_create(get_pf3_tile_info,   deco16_scan_rows, TILEMAP_TYPE_PEN,16,16,full_width ? 64 : 32,32);
+		pf4_tilemap_16x16 =	tilemap_create(machine, get_pf4_tile_info,   deco16_scan_rows, 16,16,full_width ? 64 : 32,32);
+		pf3_tilemap_16x16 =	tilemap_create(machine, get_pf3_tile_info,   deco16_scan_rows, 16,16,full_width ? 64 : 32,32);
 	}
 	else
 	{
@@ -580,25 +582,27 @@ static void deco16_video_init(int pf12_only, int split, int full_width)
 	deco16_raster_display_position=0;
 }
 
-void deco16_1_video_init(void)  /* 1 times playfield generator chip */
+void deco16_1_video_init(running_machine *machine)  /* 1 times playfield generator chip */
 {
-	deco16_video_init(1, 0, 1);
+	deco16_video_init(machine, 1, 0, 1);
 }
 
-void deco16_2_video_init(int split) /* 2 times playfield generator chips */
+void deco16_2_video_init(running_machine *machine, int split) /* 2 times playfield generator chips */
 {
-	deco16_video_init(0, split, 1);
+	deco16_video_init(machine, 0, split, 1);
 }
 
-void deco16_2_video_init_half_width(void) /* 2 times playfield generator chips */
+void deco16_2_video_init_half_width(running_machine *machine) /* 2 times playfield generator chips */
 {
-	deco16_video_init(0, 0, 0);
+	deco16_video_init(machine, 0, 0, 0);
 }
 
-void deco_allocate_sprite_bitmap(void)
+void deco_allocate_sprite_bitmap(running_machine *machine)
 {
 	/* Allow sprite bitmap to be used by Deco32 games as well */
-	sprite_priority_bitmap = auto_bitmap_alloc( Machine->screen[0].width, Machine->screen[0].height, BITMAP_FORMAT_INDEXED8 );
+	int width = video_screen_get_width(machine->primary_screen);
+	int height = video_screen_get_height(machine->primary_screen);
+	sprite_priority_bitmap = auto_bitmap_alloc(width, height, BITMAP_FORMAT_INDEXED16 );
 }
 
 /*****************************************************************************************/
@@ -796,7 +800,7 @@ void deco16_pf34_update(const UINT16 *rowscroll_1_ptr, const UINT16 *rowscroll_2
 
 /*****************************************************************************************/
 
-void deco16_print_debug_info(mame_bitmap *bitmap)
+void deco16_print_debug_info(bitmap_t *bitmap)
 {
 	char buf[64*5];
 
@@ -827,18 +831,19 @@ void deco16_print_debug_info(mame_bitmap *bitmap)
 void deco16_clear_sprite_priority_bitmap(void)
 {
 	if (sprite_priority_bitmap)
-		fillbitmap(sprite_priority_bitmap,0,NULL);
+		bitmap_fill(sprite_priority_bitmap,NULL,0);
 }
 
 /* A special pdrawgfx z-buffered sprite renderer that is needed to properly draw multiple sprite sources with alpha */
-void deco16_pdrawgfx(mame_bitmap *dest,const gfx_element *gfx,
+void deco16_pdrawgfx(running_machine *machine,
+		bitmap_t *dest,const gfx_element *gfx,
 		UINT32 code,UINT32 color,int flipx,int flipy,int sx,int sy,
 		const rectangle *clip,int transparency,int transparent_color,UINT32 pri_mask,UINT32 sprite_mask,UINT8 write_pri)
 {
 	int ox,oy,cx,cy;
 	int x_index,y_index,x,y;
 
-	const pen_t *pal = &Machine->remapped_colortable[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
+	const pen_t *pal = &machine->pens[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
 	int source_base = (code % gfx->total_elements) * gfx->height;
 
 	/* check bounds */
@@ -896,11 +901,11 @@ void deco16_pdrawgfx(mame_bitmap *dest,const gfx_element *gfx,
 
 /*****************************************************************************************/
 
-void deco16_tilemap_1_draw(mame_bitmap *bitmap, const rectangle *cliprect, int flags, UINT32 priority)
+void deco16_tilemap_1_draw(const device_config *screen, bitmap_t *bitmap, const rectangle *cliprect, int flags, UINT32 priority)
 {
 	if (use_custom_pf1)
 	{
-		custom_tilemap_draw(bitmap,pf1_tilemap_8x8,pf1_tilemap_16x16,0,0,pf1_rowscroll_ptr,deco16_pf12_control[1], deco16_pf12_control[2], deco16_pf12_control[5]&0xff, deco16_pf12_control[6]&0xff, 0, 0, deco16_pf1_trans_mask, flags, priority);
+		custom_tilemap_draw(screen->machine, bitmap,pf1_tilemap_8x8,pf1_tilemap_16x16,0,0,pf1_rowscroll_ptr,deco16_pf12_control[1], deco16_pf12_control[2], deco16_pf12_control[5]&0xff, deco16_pf12_control[6]&0xff, 0, 0, deco16_pf1_trans_mask, flags, priority);
 	}
 	else
 	{
@@ -909,11 +914,11 @@ void deco16_tilemap_1_draw(mame_bitmap *bitmap, const rectangle *cliprect, int f
 	}
 }
 
-void deco16_tilemap_2_draw(mame_bitmap *bitmap, const rectangle *cliprect, int flags, UINT32 priority)
+void deco16_tilemap_2_draw(const device_config *screen, bitmap_t *bitmap, const rectangle *cliprect, int flags, UINT32 priority)
 {
 	if (use_custom_pf2)
 	{
-		custom_tilemap_draw(bitmap,pf2_tilemap_8x8,pf2_tilemap_16x16,0,0,pf2_rowscroll_ptr,deco16_pf12_control[3], deco16_pf12_control[4], deco16_pf12_control[5]>>8, deco16_pf12_control[6]>>8, 0, 0, deco16_pf2_trans_mask, flags, priority);
+		custom_tilemap_draw(screen->machine, bitmap,pf2_tilemap_8x8,pf2_tilemap_16x16,0,0,pf2_rowscroll_ptr,deco16_pf12_control[3], deco16_pf12_control[4], deco16_pf12_control[5]>>8, deco16_pf12_control[6]>>8, 0, 0, deco16_pf2_trans_mask, flags, priority);
 	}
 	else
 	{
@@ -922,24 +927,24 @@ void deco16_tilemap_2_draw(mame_bitmap *bitmap, const rectangle *cliprect, int f
 	}
 }
 
-void deco16_tilemap_3_draw(mame_bitmap *bitmap, const rectangle *cliprect, int flags, UINT32 priority)
+void deco16_tilemap_3_draw(const device_config *screen, bitmap_t *bitmap, const rectangle *cliprect, int flags, UINT32 priority)
 {
-	if (use_custom_pf3) custom_tilemap_draw(bitmap,0,pf3_tilemap_16x16,0,0,pf3_rowscroll_ptr,deco16_pf34_control[1], deco16_pf34_control[2], deco16_pf34_control[5]&0xff, deco16_pf34_control[6]&0xff, 0, 0, deco16_pf3_trans_mask, flags, priority);
+	if (use_custom_pf3) custom_tilemap_draw(screen->machine, bitmap,0,pf3_tilemap_16x16,0,0,pf3_rowscroll_ptr,deco16_pf34_control[1], deco16_pf34_control[2], deco16_pf34_control[5]&0xff, deco16_pf34_control[6]&0xff, 0, 0, deco16_pf3_trans_mask, flags, priority);
 	else if (pf3_tilemap_16x16) tilemap_draw(bitmap,cliprect,pf3_tilemap_16x16,flags,priority);
 }
 
-void deco16_tilemap_4_draw(mame_bitmap *bitmap, const rectangle *cliprect, int flags, UINT32 priority)
+void deco16_tilemap_4_draw(const device_config *screen, bitmap_t *bitmap, const rectangle *cliprect, int flags, UINT32 priority)
 {
-	if (use_custom_pf4) custom_tilemap_draw(bitmap,0,pf4_tilemap_16x16,0,0,pf4_rowscroll_ptr,deco16_pf34_control[3], deco16_pf34_control[4], deco16_pf34_control[5]>>8, deco16_pf34_control[6]>>8, 0, 0, deco16_pf4_trans_mask, flags, priority);
+	if (use_custom_pf4) custom_tilemap_draw(screen->machine, bitmap,0,pf4_tilemap_16x16,0,0,pf4_rowscroll_ptr,deco16_pf34_control[3], deco16_pf34_control[4], deco16_pf34_control[5]>>8, deco16_pf34_control[6]>>8, 0, 0, deco16_pf4_trans_mask, flags, priority);
 	else if (pf4_tilemap_16x16) tilemap_draw(bitmap,cliprect,pf4_tilemap_16x16,flags,priority);
 }
 
 /*****************************************************************************************/
 
 // Combines the output of two 4BPP tilemaps into an 8BPP tilemap
-void deco16_tilemap_34_combine_draw(mame_bitmap *bitmap, const rectangle *cliprect, int flags, UINT32 priority)
+void deco16_tilemap_34_combine_draw(const device_config *screen, bitmap_t *bitmap, const rectangle *cliprect, int flags, UINT32 priority)
 {
-	custom_tilemap_draw(bitmap,0,pf3_tilemap_16x16,0,pf4_tilemap_16x16,pf3_rowscroll_ptr,deco16_pf34_control[1], deco16_pf34_control[2], deco16_pf34_control[5]&0xff, deco16_pf34_control[6]&0xff, 0xf, 4, 0xff, flags, priority);
+	custom_tilemap_draw(screen->machine, bitmap,0,pf3_tilemap_16x16,0,pf4_tilemap_16x16,pf3_rowscroll_ptr,deco16_pf34_control[1], deco16_pf34_control[2], deco16_pf34_control[5]&0xff, deco16_pf34_control[6]&0xff, 0xf, 4, 0xff, flags, priority);
 }
 
 /*****************************************************************************************/
@@ -953,7 +958,8 @@ void deco16_tilemap_34_combine_draw(mame_bitmap *bitmap, const rectangle *clipre
 */
 
 static void custom_tilemap_draw(
-	mame_bitmap *bitmap,
+	running_machine *machine,
+	bitmap_t *bitmap,
 	tilemap *tilemap0_8x8,
 	tilemap *tilemap0_16x16,
 	tilemap *tilemap1_8x8,
@@ -971,8 +977,8 @@ static void custom_tilemap_draw(
 {
 	tilemap *tilemap0 = (control1&0x80) ? tilemap0_8x8 : tilemap0_16x16;
 	tilemap *tilemap1 = (control1&0x80) ? tilemap1_8x8 : tilemap1_16x16;
-	const mame_bitmap *src_bitmap0 = tilemap0 ? tilemap_get_pixmap(tilemap0) : NULL;
-	const mame_bitmap *src_bitmap1 = tilemap1 ? tilemap_get_pixmap(tilemap1) : NULL;
+	const bitmap_t *src_bitmap0 = tilemap0 ? tilemap_get_pixmap(tilemap0) : NULL;
+	const bitmap_t *src_bitmap1 = tilemap1 ? tilemap_get_pixmap(tilemap1) : NULL;
 	int width_mask, height_mask, x, y, p;
 	int column_offset, src_x=0, src_y=0;
 	int	row_type=1 << ((control0>>3)&0xf);
@@ -1012,7 +1018,7 @@ static void custom_tilemap_draw(
 				src_x=(src_x+1)&width_mask;
 				if ((flags&TILEMAP_DRAW_OPAQUE) || (p&trans_mask))
 				{
-					*BITMAP_ADDR16(bitmap, y, x) = Machine->pens[p];
+					*BITMAP_ADDR16(bitmap, y, x) = machine->pens[p];
 					if (priority_bitmap)
 					{
 						UINT8 *pri = BITMAP_ADDR8(priority_bitmap, y, 0);
@@ -1037,7 +1043,7 @@ static void custom_tilemap_draw(
 				src_x=(src_x+1)&width_mask;
 				if ((flags&TILEMAP_DRAW_OPAQUE) || (p&trans_mask))
 				{
-					*BITMAP_ADDR32(bitmap, y, x) = Machine->pens[p];
+					*BITMAP_ADDR32(bitmap, y, x) = machine->pens[p];
 					if (priority_bitmap)
 					{
 						UINT8 *pri = BITMAP_ADDR8(priority_bitmap, y, 0);
