@@ -1,5 +1,4 @@
 #include "driver.h"
-#include "deprecat.h"
 #include "deco16ic.h"
 #include "deco32.h"
 
@@ -16,7 +15,7 @@ static int deco32_pf1_bank,deco32_pf2_bank,deco32_pf3_bank,deco32_pf4_bank;
 static int deco32_pf1_flip,deco32_pf2_flip,deco32_pf3_flip,deco32_pf4_flip;
 static int deco32_pf2_colourbank,deco32_pf4_colourbank,deco32_pri;
 
-static mame_bitmap *sprite0_mix_bitmap, *sprite1_mix_bitmap, *tilemap_alpha_bitmap;
+static bitmap_t *sprite0_mix_bitmap, *sprite1_mix_bitmap, *tilemap_alpha_bitmap;
 
 static UINT32 dragngun_sprite_ctrl;
 static int deco32_ace_ram_dirty, has_ace_ram;
@@ -157,7 +156,7 @@ WRITE32_HANDLER( deco32_nonbuffered_palette_w )
 	g = (paletteram32[offset] >> 8) & 0xff;
 	r = (paletteram32[offset] >> 0) & 0xff;
 
-	palette_set_color(Machine,offset,MAKE_RGB(r,g,b));
+	palette_set_color(space->machine,offset,MAKE_RGB(r,g,b));
 }
 
 WRITE32_HANDLER( deco32_buffered_palette_w )
@@ -168,7 +167,7 @@ WRITE32_HANDLER( deco32_buffered_palette_w )
 
 WRITE32_HANDLER( deco32_palette_dma_w )
 {
-	const int m=Machine->drv->total_colors;
+	const int m=space->machine->config->total_colors;
 	int r,g,b,i;
 
 	for (i=0; i<m; i++) {
@@ -185,7 +184,7 @@ WRITE32_HANDLER( deco32_palette_dma_w )
 				g = (paletteram32[i] >> 8) & 0xff;
 				r = (paletteram32[i] >> 0) & 0xff;
 
-				palette_set_color(Machine,i,MAKE_RGB(r,g,b));
+				palette_set_color(space->machine,i,MAKE_RGB(r,g,b));
 			}
 		}
 	}
@@ -193,7 +192,7 @@ WRITE32_HANDLER( deco32_palette_dma_w )
 
 /******************************************************************************/
 
-static void captaven_draw_sprites(running_machine* machine, mame_bitmap *bitmap, const rectangle *cliprect, const UINT32 *spritedata, int gfxbank)
+static void captaven_draw_sprites(running_machine* machine, bitmap_t *bitmap, const rectangle *cliprect, const UINT32 *spritedata, int gfxbank)
 {
 	int offs;
 
@@ -232,7 +231,7 @@ static void captaven_draw_sprites(running_machine* machine, mame_bitmap *bitmap,
 
 		sx = spritedata[offs+1];
 
-		if ((sy&0x2000) && (cpu_getcurrentframe() & 1)) continue;
+		if ((sy&0x2000) && (video_screen_get_frame_number(machine->primary_screen) & 1)) continue;
 
 		colour = (spritedata[offs+2] >>0) & 0x1f;
 
@@ -241,7 +240,7 @@ static void captaven_draw_sprites(running_machine* machine, mame_bitmap *bitmap,
 		fx = !(spritedata[offs+0]&0x4000);
 		fy = !(spritedata[offs+0]&0x8000);
 
-		if (!flip_screen) {
+		if (!flip_screen_get(machine)) {
 			sx = sx & 0x01ff;
 			sy = sy & 0x01ff;
 			if (sx>0x180) sx=-(0x200 - sx);
@@ -278,7 +277,7 @@ static void captaven_draw_sprites(running_machine* machine, mame_bitmap *bitmap,
 	}
 }
 
-static void fghthist_draw_sprites(running_machine* machine, mame_bitmap *bitmap, const rectangle *cliprect, const UINT32 *spritedata, int gfxbank, int mask, int colourmask)
+static void fghthist_draw_sprites(running_machine* machine, bitmap_t *bitmap, const rectangle *cliprect, const UINT32 *spritedata, int gfxbank, int mask, int colourmask)
 {
 	int offs;
 
@@ -291,7 +290,7 @@ static void fghthist_draw_sprites(running_machine* machine, mame_bitmap *bitmap,
 
 		y = spritedata[offs];
 		flash=y&0x1000;
-		if (flash && (cpu_getcurrentframe() & 1)) continue;
+		if (flash && (video_screen_get_frame_number(machine->primary_screen) & 1)) continue;
 
 		trans=TRANSPARENCY_PEN;
 		x = spritedata[offs+2];
@@ -327,7 +326,8 @@ static void fghthist_draw_sprites(running_machine* machine, mame_bitmap *bitmap,
 
 		while (multi >= 0)
 		{
-			deco16_pdrawgfx(bitmap,machine->gfx[gfxbank],
+			deco16_pdrawgfx(machine,
+					bitmap,machine->gfx[gfxbank],
 					sprite - multi * inc,
 					colour,
 					fx,fy,
@@ -344,7 +344,7 @@ static void fghthist_draw_sprites(running_machine* machine, mame_bitmap *bitmap,
     Bottom 8 bits per pixel is palettised sprite data, top 8 is
     colour/alpha/priority.
 */
-static void deco32_draw_sprite(mame_bitmap *dest,const gfx_element *gfx,
+static void deco32_draw_sprite(bitmap_t *dest,const gfx_element *gfx,
 		UINT32 code,UINT32 priority,int flipx,int flipy,int sx,int sy,
 		const rectangle *clip)
 {
@@ -393,7 +393,7 @@ static void deco32_draw_sprite(mame_bitmap *dest,const gfx_element *gfx,
 }
 
 // Merge with Tattass & Fghthist sprite routines later
-static void nslasher_draw_sprites(running_machine* machine, mame_bitmap *bitmap, const rectangle *cliprect, const UINT32 *spritedata, int gfxbank)
+static void nslasher_draw_sprites(running_machine* machine, bitmap_t *bitmap, const rectangle *cliprect, const UINT32 *spritedata, int gfxbank)
 {
 	int offs;
 
@@ -407,7 +407,7 @@ static void nslasher_draw_sprites(running_machine* machine, mame_bitmap *bitmap,
 
 		y = spritedata[offs];
 		flash=y&0x1000;
-		if (flash && (cpu_getcurrentframe() & 1)) continue;
+		if (flash && (video_screen_get_frame_number(machine->primary_screen) & 1)) continue;
 
 		trans=TRANSPARENCY_PEN;
 		x = spritedata[offs+2];
@@ -455,10 +455,11 @@ static void nslasher_draw_sprites(running_machine* machine, mame_bitmap *bitmap,
 	}
 }
 
-INLINE void dragngun_drawgfxzoom( mame_bitmap *dest_bmp,const gfx_element *gfx,
+INLINE void dragngun_drawgfxzoom( running_machine *machine,
+		bitmap_t *dest_bmp,const gfx_element *gfx,
 		UINT32 code,UINT32 color,int flipx,int flipy,int sx,int sy,
 		const rectangle *clip,int transparency,int transparent_color,
-		int scalex, int scaley,mame_bitmap *pri_buffer,UINT32 pri_mask, int sprite_screen_width, int  sprite_screen_height )
+		int scalex, int scaley,bitmap_t *pri_buffer,UINT32 pri_mask, int sprite_screen_width, int  sprite_screen_height )
 {
 	rectangle myclip;
 
@@ -490,7 +491,7 @@ INLINE void dragngun_drawgfxzoom( mame_bitmap *dest_bmp,const gfx_element *gfx,
 	{
 		if( gfx )
 		{
-			const pen_t *pal = &Machine->remapped_colortable[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
+			const pen_t *pal = &machine->pens[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
 			int source_base = (code % gfx->total_elements) * gfx->height;
 
 			if (sprite_screen_width && sprite_screen_height)
@@ -655,7 +656,7 @@ INLINE void dragngun_drawgfxzoom( mame_bitmap *dest_bmp,const gfx_element *gfx,
 	}
 }
 
-static void dragngun_draw_sprites(running_machine* machine, mame_bitmap *bitmap, const rectangle *cliprect, const UINT32 *spritedata)
+static void dragngun_draw_sprites(running_machine* machine, bitmap_t *bitmap, const rectangle *cliprect, const UINT32 *spritedata)
 {
 	const UINT32 *layout_ram;
 	const UINT32 *lookup_ram;
@@ -801,7 +802,8 @@ static void dragngun_draw_sprites(running_machine* machine, mame_bitmap *bitmap,
 				sprite&=0x7fff;
 
 				if (zoomx!=0x10000 || zoomy!=0x10000)
-					dragngun_drawgfxzoom(bitmap,machine->gfx[bank],
+					dragngun_drawgfxzoom(machine,
+						bitmap,machine->gfx[bank],
 						sprite,
 						colour,
 						fx,fy,
@@ -949,10 +951,10 @@ static TILE_GET_INFO( get_ll_pf4_tile_info )
 
 VIDEO_START( captaven )
 {
-	pf1_tilemap = tilemap_create(get_pf1_tile_info,    tilemap_scan_rows,TILEMAP_TYPE_PEN, 8, 8,64,32);
-	pf1a_tilemap =tilemap_create(get_pf1a_tile_info,   deco16_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-	pf2_tilemap = tilemap_create(get_pf2_tile_info,    deco16_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-	pf3_tilemap = tilemap_create(get_ca_pf3_tile_info, tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,32,32);
+	pf1_tilemap = tilemap_create(machine, get_pf1_tile_info,    tilemap_scan_rows, 8, 8,64,32);
+	pf1a_tilemap =tilemap_create(machine, get_pf1a_tile_info,   deco16_scan_rows,16,16,64,32);
+	pf2_tilemap = tilemap_create(machine, get_pf2_tile_info,    deco16_scan_rows,16,16,64,32);
+	pf3_tilemap = tilemap_create(machine, get_ca_pf3_tile_info, tilemap_scan_rows,16,16,32,32);
 	deco32_raster_display_list=auto_malloc(10 * 256);
 	memset(deco32_raster_display_list, 0, 10 * 256);
 
@@ -968,14 +970,14 @@ VIDEO_START( captaven )
 
 VIDEO_START( fghthist )
 {
-	pf1_tilemap = tilemap_create(get_pf1_tile_info, tilemap_scan_rows,TILEMAP_TYPE_PEN, 8, 8,64,32);
-	pf2_tilemap = tilemap_create(get_pf2_tile_info, deco16_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-	pf3_tilemap = tilemap_create(get_pf3_tile_info, deco16_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-	pf4_tilemap = tilemap_create(get_pf4_tile_info, deco16_scan_rows,TILEMAP_TYPE_PEN,     16,16,64,32);
+	pf1_tilemap = tilemap_create(machine, get_pf1_tile_info, tilemap_scan_rows, 8, 8,64,32);
+	pf2_tilemap = tilemap_create(machine, get_pf2_tile_info, deco16_scan_rows,16,16,64,32);
+	pf3_tilemap = tilemap_create(machine, get_pf3_tile_info, deco16_scan_rows,16,16,64,32);
+	pf4_tilemap = tilemap_create(machine, get_pf4_tile_info, deco16_scan_rows,     16,16,64,32);
 	pf1a_tilemap =0;
 	dirty_palette = auto_malloc(4096);
 
-	deco_allocate_sprite_bitmap();
+	deco_allocate_sprite_bitmap(machine);
 
 	tilemap_set_transparent_pen(pf1_tilemap,0);
 	tilemap_set_transparent_pen(pf2_tilemap,0);
@@ -988,11 +990,11 @@ VIDEO_START( fghthist )
 
 VIDEO_START( dragngun )
 {
-	pf1_tilemap = tilemap_create(get_pf1_tile_info,    tilemap_scan_rows,TILEMAP_TYPE_PEN, 8, 8,64,32);
-	pf2_tilemap = tilemap_create(get_pf2_tile_info,    deco16_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-	pf3_tilemap = tilemap_create(get_ll_pf3_tile_info, deco16_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-	pf4_tilemap = tilemap_create(get_ll_pf4_tile_info, deco16_scan_rows,TILEMAP_TYPE_PEN,     16,16,64,32);
-	pf1a_tilemap =tilemap_create(get_pf1a_tile_info,   deco16_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
+	pf1_tilemap = tilemap_create(machine, get_pf1_tile_info,    tilemap_scan_rows, 8, 8,64,32);
+	pf2_tilemap = tilemap_create(machine, get_pf2_tile_info,    deco16_scan_rows,16,16,64,32);
+	pf3_tilemap = tilemap_create(machine, get_ll_pf3_tile_info, deco16_scan_rows,16,16,64,32);
+	pf4_tilemap = tilemap_create(machine, get_ll_pf4_tile_info, deco16_scan_rows,     16,16,64,32);
+	pf1a_tilemap =tilemap_create(machine, get_pf1a_tile_info,   deco16_scan_rows,16,16,64,32);
 	dirty_palette = auto_malloc(4096);
 	deco32_raster_display_list = auto_malloc(10 * 256);
 
@@ -1005,17 +1007,17 @@ VIDEO_START( dragngun )
 	deco32_pf2_colourbank=deco32_pf4_colourbank=0;
 
 	alpha_set_level(0x80);
-	state_save_register_global(dragngun_sprite_ctrl);
+	state_save_register_global(machine, dragngun_sprite_ctrl);
 	has_ace_ram=0;
 }
 
 VIDEO_START( lockload )
 {
-	pf1_tilemap = tilemap_create(get_pf1_tile_info,    tilemap_scan_rows,TILEMAP_TYPE_PEN, 8, 8,64,32);
-	pf2_tilemap = tilemap_create(get_pf2_tile_info,    deco16_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-	pf3_tilemap = tilemap_create(get_ll_pf3_tile_info, deco16_scan_rows,TILEMAP_TYPE_PEN,16,16,32,32);
-	pf4_tilemap = tilemap_create(get_ll_pf4_tile_info, deco16_scan_rows,TILEMAP_TYPE_PEN,     16,16,32,32);
-	pf1a_tilemap =tilemap_create(get_pf1a_tile_info,   deco16_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
+	pf1_tilemap = tilemap_create(machine, get_pf1_tile_info,    tilemap_scan_rows, 8, 8,64,32);
+	pf2_tilemap = tilemap_create(machine, get_pf2_tile_info,    deco16_scan_rows,16,16,64,32);
+	pf3_tilemap = tilemap_create(machine, get_ll_pf3_tile_info, deco16_scan_rows,16,16,32,32);
+	pf4_tilemap = tilemap_create(machine, get_ll_pf4_tile_info, deco16_scan_rows,     16,16,32,32);
+	pf1a_tilemap =tilemap_create(machine, get_pf1a_tile_info,   deco16_scan_rows,16,16,64,32);
 	dirty_palette = auto_malloc(4096);
 	deco32_raster_display_list = auto_malloc(10 * 256);
 	memset(deco32_raster_display_list, 0, 10 * 256);
@@ -1029,22 +1031,26 @@ VIDEO_START( lockload )
 	deco32_pf2_colourbank=deco32_pf4_colourbank=0;
 
 	alpha_set_level(0x80);
-	state_save_register_global(dragngun_sprite_ctrl);
+	state_save_register_global(machine, dragngun_sprite_ctrl);
 	has_ace_ram=0;
 }
 
 VIDEO_START( nslasher )
 {
-	pf1_tilemap = tilemap_create(get_pf1_tile_info, tilemap_scan_rows,TILEMAP_TYPE_PEN, 8, 8,64,32);
-	pf2_tilemap = tilemap_create(get_pf2_tile_info, deco16_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-	pf3_tilemap = tilemap_create(get_pf3_tile_info, deco16_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-	pf4_tilemap = tilemap_create(get_pf4_tile_info, deco16_scan_rows,TILEMAP_TYPE_PEN,     16,16,64,32);
+	int width, height;
+
+	pf1_tilemap = tilemap_create(machine, get_pf1_tile_info, tilemap_scan_rows, 8, 8,64,32);
+	pf2_tilemap = tilemap_create(machine, get_pf2_tile_info, deco16_scan_rows,16,16,64,32);
+	pf3_tilemap = tilemap_create(machine, get_pf3_tile_info, deco16_scan_rows,16,16,64,32);
+	pf4_tilemap = tilemap_create(machine, get_pf4_tile_info, deco16_scan_rows,     16,16,64,32);
 	pf1a_tilemap =0;
 	dirty_palette = auto_malloc(4096);
 
-	sprite0_mix_bitmap=auto_bitmap_alloc( machine->screen[0].width, machine->screen[0].height, BITMAP_FORMAT_INDEXED16 );
-	sprite1_mix_bitmap=auto_bitmap_alloc( machine->screen[0].width, machine->screen[0].height, BITMAP_FORMAT_INDEXED16 );
-	tilemap_alpha_bitmap=auto_bitmap_alloc( machine->screen[0].width, machine->screen[0].height, BITMAP_FORMAT_INDEXED16 );
+	width = video_screen_get_width(machine->primary_screen);
+	height = video_screen_get_height(machine->primary_screen);
+	sprite0_mix_bitmap=auto_bitmap_alloc(width, height, BITMAP_FORMAT_INDEXED16 );
+	sprite1_mix_bitmap=auto_bitmap_alloc(width, height, BITMAP_FORMAT_INDEXED16 );
+	tilemap_alpha_bitmap=auto_bitmap_alloc(width, height, BITMAP_FORMAT_INDEXED16 );
 
 	tilemap_set_transparent_pen(pf1_tilemap,0);
 	tilemap_set_transparent_pen(pf2_tilemap,0);
@@ -1054,7 +1060,7 @@ VIDEO_START( nslasher )
 	deco32_raster_display_list=0;
 	deco32_pf2_colourbank=16;
 	deco32_pf4_colourbank=16;
-	state_save_register_global(deco32_pri);
+	state_save_register_global(machine, deco32_pri);
 	alpha_set_level(0x80);
 	has_ace_ram=1;
 }
@@ -1073,7 +1079,7 @@ VIDEO_EOF( dragngun )
 }
 
 #if 0
-static void print_debug_info(mame_bitmap *bitmap)
+static void print_debug_info(bitmap_t *bitmap)
 {
 	int j;
 	char buf[64*5];
@@ -1091,7 +1097,7 @@ static void print_debug_info(mame_bitmap *bitmap)
 
 #endif
 
-static void tilemap_raster_draw(mame_bitmap *bitmap, const rectangle *cliprect, int flags, int pri)
+static void tilemap_raster_draw(bitmap_t *bitmap, const rectangle *cliprect, int flags, int pri)
 {
 	int ptr=0,sx0,sy0,sx1,sy1,start,end=0;
 	rectangle clip;
@@ -1124,10 +1130,10 @@ static void tilemap_raster_draw(mame_bitmap *bitmap, const rectangle *cliprect,
 	}
 }
 
-static void combined_tilemap_draw(running_machine* machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void combined_tilemap_draw(running_machine* machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
-	const mame_bitmap *bitmap0 = tilemap_get_pixmap(pf3_tilemap);
-	const mame_bitmap *bitmap1 = tilemap_get_pixmap(pf4_tilemap);
+	const bitmap_t *bitmap0 = tilemap_get_pixmap(pf3_tilemap);
+	const bitmap_t *bitmap1 = tilemap_get_pixmap(pf4_tilemap);
 	int x,y,p;
 
 	const UINT16 width_mask=0x3ff;
@@ -1212,8 +1218,8 @@ VIDEO_UPDATE( captaven )
 	int pf1_enable,pf2_enable,pf3_enable;
 	static int last_pf3_bank;
 
-	flip_screen_set(deco32_pf12_control[0]&0x80);
-	tilemap_set_flip(ALL_TILEMAPS,flip_screen ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
+	flip_screen_set(screen->machine, deco32_pf12_control[0]&0x80);
+	tilemap_set_flip(ALL_TILEMAPS,flip_screen_get(screen->machine) ? (TILEMAP_FLIPY | TILEMAP_FLIPX) : 0);
 
 	deco32_setup_scroll(pf1_tilemap, 256,(deco32_pf12_control[5]>>0)&0xff,(deco32_pf12_control[6]>>0)&0xff,deco32_pf12_control[2],deco32_pf12_control[1],deco32_pf1_rowscroll,deco32_pf1_rowscroll+0x200);
 	deco32_setup_scroll(pf1a_tilemap,512,(deco32_pf12_control[5]>>0)&0xff,(deco32_pf12_control[6]>>0)&0xff,deco32_pf12_control[2],deco32_pf12_control[1],deco32_pf1_rowscroll,deco32_pf1_rowscroll+0x200);
@@ -1238,12 +1244,12 @@ VIDEO_UPDATE( captaven )
 	tilemap_set_enable(pf2_tilemap,pf2_enable);
 	tilemap_set_enable(pf3_tilemap,pf3_enable);
 
-	fillbitmap(priority_bitmap,0,cliprect);
+	bitmap_fill(priority_bitmap,cliprect,0);
 	if ((deco32_pri&1)==0) {
 		if (pf3_enable)
 			tilemap_draw(bitmap,cliprect,pf3_tilemap,TILEMAP_DRAW_OPAQUE,0);
 		else
-			fillbitmap(bitmap,get_black_pen(machine),cliprect);
+			bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
 
 		if (deco32_raster_display_position)
 			tilemap_raster_draw(bitmap,cliprect,0,1);
@@ -1257,12 +1263,12 @@ VIDEO_UPDATE( captaven )
 				tilemap_draw(bitmap,cliprect,pf2_tilemap,0,0);
 		}
 		else
-			fillbitmap(bitmap,get_black_pen(machine),cliprect);
+			bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
 
 		tilemap_draw(bitmap,cliprect,pf3_tilemap,0,1);
 	}
 
-	captaven_draw_sprites(machine,bitmap,cliprect,buffered_spriteram32,3);
+	captaven_draw_sprites(screen->machine,bitmap,cliprect,buffered_spriteram32,3);
 
 	/* PF1 can be in 8x8 mode or 16x16 mode */
 	if (deco32_pf12_control[6]&0x80)
@@ -1308,7 +1314,7 @@ VIDEO_UPDATE( dragngun )
 	tilemap_set_enable(pf4_tilemap, deco32_pf34_control[5]&0x8000);
 
 	if ((deco32_pf34_control[5]&0x8000)==0)
-		fillbitmap(bitmap,get_black_pen(machine),cliprect);
+		bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
 
 	tilemap_draw(bitmap,cliprect,pf4_tilemap,0,0);
 	tilemap_draw(bitmap,cliprect,pf3_tilemap,0,0);
@@ -1347,7 +1353,7 @@ VIDEO_UPDATE( dragngun )
 		tilemap_draw(bitmap,cliprect,pf2_tilemap,0,0);
 	}
 
-	dragngun_draw_sprites(machine,bitmap,cliprect,buffered_spriteram32);
+	dragngun_draw_sprites(screen->machine,bitmap,cliprect,buffered_spriteram32);
 
 	/* PF1 can be in 8x8 mode or 16x16 mode */
 	if (deco32_pf12_control[6]&0x80)
@@ -1394,12 +1400,12 @@ VIDEO_UPDATE( fghthist )
 
 	/* Draw screen */
 	deco16_clear_sprite_priority_bitmap();
-	fillbitmap(priority_bitmap,0,cliprect);
-	fillbitmap(bitmap,machine->pens[0x000],cliprect); // Palette index not confirmed
+	bitmap_fill(priority_bitmap,cliprect,0);
+	bitmap_fill(bitmap,cliprect,screen->machine->pens[0x000]); // Palette index not confirmed
 	tilemap_draw(bitmap,cliprect,pf4_tilemap,0,1);
 	tilemap_draw(bitmap,cliprect,pf3_tilemap,0,4);
 	tilemap_draw(bitmap,cliprect,pf2_tilemap,0,16);
-	fghthist_draw_sprites(machine, bitmap, cliprect, buffered_spriteram32,3,0, 0xf);
+	fghthist_draw_sprites(screen->machine, bitmap, cliprect, buffered_spriteram32,3,0, 0xf);
 	tilemap_draw(bitmap,cliprect,pf1_tilemap,0,0);
 	return 0;
 }
@@ -1412,11 +1418,11 @@ VIDEO_UPDATE( fghthist )
     blending support - it can't be done in-place on the final framebuffer
     without a lot of support bitmaps.
 */
-static void mixDualAlphaSprites(running_machine* machine, mame_bitmap *bitmap, const rectangle *cliprect, const gfx_element *gfx0, const gfx_element *gfx1, int mixAlphaTilemap)
+static void mixDualAlphaSprites(running_machine* machine, bitmap_t *bitmap, const rectangle *cliprect, const gfx_element *gfx0, const gfx_element *gfx1, int mixAlphaTilemap)
 {
-	const pen_t *pal0 = &machine->remapped_colortable[gfx0->color_base];
-	const pen_t *pal1 = &machine->remapped_colortable[gfx1->color_base];
-	const pen_t *pal2 = &machine->remapped_colortable[(deco32_pri&1) ? machine->gfx[1]->color_base : machine->gfx[2]->color_base];
+	const pen_t *pal0 = &machine->pens[gfx0->color_base];
+	const pen_t *pal1 = &machine->pens[gfx1->color_base];
+	const pen_t *pal2 = &machine->pens[(deco32_pri&1) ? machine->gfx[1]->color_base : machine->gfx[2]->color_base];
 	int x,y;
 
 	/* Mix sprites into main bitmap, based on priority & alpha */
@@ -1583,27 +1589,27 @@ VIDEO_UPDATE( nslasher )
 		alphaTilemap=1;
 
 	if (deco32_ace_ram_dirty)
-		updateAceRam(machine);
+		updateAceRam(screen->machine);
 
-	fillbitmap(sprite0_mix_bitmap,0,cliprect);
-	fillbitmap(sprite1_mix_bitmap,0,cliprect);
-	fillbitmap(priority_bitmap,0,cliprect);
-	fillbitmap(tilemap_alpha_bitmap,0,cliprect);
+	bitmap_fill(sprite0_mix_bitmap,cliprect,0);
+	bitmap_fill(sprite1_mix_bitmap,cliprect,0);
+	bitmap_fill(priority_bitmap,cliprect,0);
+	bitmap_fill(tilemap_alpha_bitmap,cliprect,0);
 	if ((deco32_pf34_control[5]&0x8000)==0)
-		fillbitmap(bitmap,machine->pens[0x200],cliprect);
+		bitmap_fill(bitmap,cliprect,screen->machine->pens[0x200]);
 
 	/* Draw sprites to temporary bitmaps, saving alpha & priority info for later mixing */
-	nslasher_draw_sprites(machine,sprite0_mix_bitmap,cliprect,buffered_spriteram32,3);
-	nslasher_draw_sprites(machine,sprite1_mix_bitmap,cliprect,buffered_spriteram32_2,4);
+	nslasher_draw_sprites(screen->machine,sprite0_mix_bitmap,cliprect,buffered_spriteram32,3);
+	nslasher_draw_sprites(screen->machine,sprite1_mix_bitmap,cliprect,buffered_spriteram32_2,4);
 
 	/* Render alpha-blended tilemap to seperate buffer for proper mixing */
 	if (alphaTilemap)
-		fillbitmap(tilemap_alpha_bitmap,0,cliprect);
+		bitmap_fill(tilemap_alpha_bitmap,cliprect,0);
 
 	/* Draw playfields & sprites */
 	if (deco32_pri&2)
 	{
-		combined_tilemap_draw(machine,bitmap,cliprect);
+		combined_tilemap_draw(screen->machine,bitmap,cliprect);
 		tilemap_draw(bitmap,cliprect,pf2_tilemap,0,4);
 	}
 	else
@@ -1627,7 +1633,7 @@ VIDEO_UPDATE( nslasher )
 		}
 	}
 
-	mixDualAlphaSprites(machine, bitmap, cliprect, machine->gfx[3], machine->gfx[4], alphaTilemap);
+	mixDualAlphaSprites(screen->machine, bitmap, cliprect, screen->machine->gfx[3], screen->machine->gfx[4], alphaTilemap);
 
 	tilemap_draw(bitmap,cliprect,pf1_tilemap,0,0);
 	return 0;
