@@ -1,7 +1,6 @@
 /* Diver Boy - Video Hardware */
 
 #include "driver.h"
-#include "deprecat.h"
 
 UINT16 *diverboy_spriteram;
 size_t diverboy_spriteram_size;
@@ -11,7 +10,7 @@ VIDEO_START(diverboy)
 {
 }
 
-static void draw_sprites(running_machine* machine, mame_bitmap *bitmap, const rectangle *cliprect )
+static void draw_sprites(running_machine* machine, bitmap_t *bitmap, const rectangle *cliprect )
 {
 	UINT16 *source = diverboy_spriteram;
 	UINT16 *finish = source + (diverboy_spriteram_size/2);
@@ -32,7 +31,7 @@ static void draw_sprites(running_machine* machine, mame_bitmap *bitmap, const re
 
 		bank = (source[1]&0x0002) >> 1;
 
-		if (!flash || (cpu_getcurrentframe() & 1))
+		if (!flash || (video_screen_get_frame_number(machine->primary_screen) & 1))
 		{
 			drawgfx(bitmap,machine->gfx[bank],
 					number,
@@ -48,7 +47,7 @@ static void draw_sprites(running_machine* machine, mame_bitmap *bitmap, const re
 
 VIDEO_UPDATE(diverboy)
 {
-//  fillbitmap(bitmap,get_black_pen(machine),cliprect);
-	draw_sprites(machine,bitmap,cliprect);
+//  bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
+	draw_sprites(screen->machine,bitmap,cliprect);
 	return 0;
 }
