@@ -8,9 +8,9 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "video/resnet.h"
 #include "includes/dkong.h"
+#include "machine/latch8.h"
 
 #define RADARSCP_BCK_COL_OFFSET			256
 #define RADARSCP_GRID_COL_OFFSET		(RADARSCP_BCK_COL_OFFSET + 256)
@@ -61,13 +61,13 @@ static const double cd4049_al = 0.01;
 
 static const res_net_decode_info dkong_decode_info =
 {
-	2,		// there may be two proms needed to construct color
-	0,		// start at 0
-	255,	// end at 255
-	//  R,   G,   B,   R,   G,   B
-	{ 256, 256,   0,   0,   0,   0},		// offsets
-	{   1,  -2,   0,   0,   2,   0},		// shifts
-	{0x07,0x04,0x03,0x00,0x03,0x00}		    // masks
+	2,		/*  there may be two proms needed to construct color */
+	0,		/*  start at 0 */
+	255,	/*  end at 255 */
+	/*  R,   G,   B,   R,   G,   B */
+	{ 256, 256,   0,   0,   0,   0},		/*  offsets */
+	{   1,  -2,   0,   0,   2,   0},		/*  shifts */
+	{0x07,0x04,0x03,0x00,0x03,0x00}		    /*  masks */
 };
 
 static const res_net_info dkong_net_info =
@@ -76,7 +76,7 @@ static const res_net_info dkong_net_info =
 	{
 		{ RES_NET_AMP_DARLINGTON, 470, 0, 3, { 1000, 470, 220 } },
 		{ RES_NET_AMP_DARLINGTON, 470, 0, 3, { 1000, 470, 220 } },
-		{ RES_NET_AMP_EMITTER,    680, 0, 2, {  470, 220,   0 } }  // dkong
+		{ RES_NET_AMP_EMITTER,    680, 0, 2, {  470, 220,   0 } }  /*  dkong */
 	}
 };
 
@@ -92,13 +92,13 @@ static const res_net_info dkong_net_bck_info =
 
 static const res_net_decode_info dkong3_decode_info =
 {
-	1,		// one prom needed to contruct color
-	0,		// start at 0
-	255,	// end at 255
-	//  R,   G,   B
-	{   0,   0, 512 },		// offsets
-	{   4,   0,   0 },		// shifts
-	{0x0F,0x0F,0x0F }		    // masks
+	1,		/*  one prom needed to contruct color */
+	0,		/*  start at 0 */
+	255,	/*  end at 255 */
+	/*   R,   G,   B */
+	{   0,   0, 512 },		/*  offsets */
+	{   4,   0,   0 },		/*  shifts */
+	{0x0F,0x0F,0x0F }		    /*  masks */
 };
 
 static const res_net_info dkong3_net_info =
@@ -125,7 +125,7 @@ static const res_net_info radarscp_net_info =
 	{
 		{ RES_NET_AMP_DARLINGTON, 470,      0, 3, { 1000, 470, 220 } },
 		{ RES_NET_AMP_DARLINGTON, 470,      0, 3, { 1000, 470, 220 } },
-		{ RES_NET_AMP_DARLINGTON, 680, 150000, 2, {  470, 220,   0 } }    // radarscp
+		{ RES_NET_AMP_DARLINGTON, 680, 150000, 2, {  470, 220,   0 } }    /*  radarscp */
 	}
 };
 
@@ -135,7 +135,7 @@ static const res_net_info radarscp_net_bck_info =
 	{
 		{ RES_NET_AMP_DARLINGTON, 470,      0, 0, { 0 } },
 		{ RES_NET_AMP_DARLINGTON, 470,      0, 0, { 0 } },
-		{ RES_NET_AMP_DARLINGTON, 680, 150000, 0, { 0 } }    // radarscp
+		{ RES_NET_AMP_DARLINGTON, 680, 150000, 0, { 0 } }    /*  radarscp */
 	}
 };
 
@@ -164,8 +164,8 @@ static const res_net_info radarscp_stars_net_info =
 	RES_NET_VCC_5V | RES_NET_VBIAS_5V | RES_NET_VIN_TTL_OUT | RES_NET_MONITOR_SANYO_EZV20,
 	{
 		{ RES_NET_AMP_DARLINGTON, 4700, 470, 0, { 0 } },
-		{ RES_NET_AMP_DARLINGTON,    1,   0, 0, { 0 } },	// dummy
-		{ RES_NET_AMP_DARLINGTON,    1,   0, 0, { 0 } },	// dummy
+		{ RES_NET_AMP_DARLINGTON,    1,   0, 0, { 0 } },	/*  dummy */
+		{ RES_NET_AMP_DARLINGTON,    1,   0, 0, { 0 } },	/*  dummy */
 	}
 };
 
@@ -175,9 +175,9 @@ static const res_net_info radarscp_blue_net_info =
 {
 	RES_NET_VCC_5V | RES_NET_VBIAS_5V | RES_NET_VIN_VCC | RES_NET_MONITOR_SANYO_EZV20,
 	{
-		{ RES_NET_AMP_DARLINGTON,  470, 4700, 0, { 0 } },	// bias/gnd exist in schematics, readable in TKG3 schematics
-		{ RES_NET_AMP_DARLINGTON,  470, 4700, 0, { 0 } },	// bias/gnd exist in schematics, readable in TKG3 schematics
-		{ RES_NET_AMP_DARLINGTON,    0,    0, 8, { 128,64,32,16,8,4,2,1 } },	// dummy
+		{ RES_NET_AMP_DARLINGTON,  470, 4700, 0, { 0 } },	/*  bias/gnd exist in schematics, readable in TKG3 schematics */
+		{ RES_NET_AMP_DARLINGTON,  470, 4700, 0, { 0 } },	/*  bias/gnd exist in schematics, readable in TKG3 schematics */
+		{ RES_NET_AMP_DARLINGTON,    0,    0, 8, { 128,64,32,16,8,4,2,1 } },	/*  dummy */
 	}
 };
 
@@ -187,9 +187,9 @@ static const res_net_info radarscp_grid_net_info =
 {
 	RES_NET_VCC_5V | RES_NET_VBIAS_5V | RES_NET_VIN_TTL_OUT | RES_NET_MONITOR_SANYO_EZV20,
 	{
-		{ RES_NET_AMP_DARLINGTON,    0,   0, 1, { 1 } },	// dummy
-		{ RES_NET_AMP_DARLINGTON,    0,   0, 1, { 1 } },	// dummy
-		{ RES_NET_AMP_DARLINGTON,    0,   0, 1, { 1 } },	// dummy
+		{ RES_NET_AMP_DARLINGTON,    0,   0, 1, { 1 } },	/*  dummy */
+		{ RES_NET_AMP_DARLINGTON,    0,   0, 1, { 1 } },	/*  dummy */
+		{ RES_NET_AMP_DARLINGTON,    0,   0, 1, { 1 } },	/*  dummy */
 	}
 };
 
@@ -211,7 +211,7 @@ PALETTE_INIT( dkong2b)
 	/* Now treat tri-state black background generation */
 
 	for (i=0;i<256;i++)
-		if ( (i & 0x03) == 0x00 )  // NOR => CS=1 => Tristate => real black
+		if ( (i & 0x03) == 0x00 )  /*  NOR => CS=1 => Tristate => real black */
 		{
 			int r,g,b;
 			r = compute_res_net( 1, 0, &dkong_net_bck_info );
@@ -251,7 +251,7 @@ PALETTE_INIT( dkong4b )
 	/* Now treat tri-state black background generation */
 
 	for (i=0;i<256;i++)
-		if ( (i & 0x03) == 0x00 )  // NOR => CS=1 => Tristate => real black
+		if ( (i & 0x03) == 0x00 )  /*  NOR => CS=1 => Tristate => real black */
 		{
 			r = compute_res_net( 1, 0, &radarscp_net_bck_info );
 			g = compute_res_net( 1, 1, &radarscp_net_bck_info );
@@ -289,7 +289,7 @@ PALETTE_INIT( radarscp )
 	/* Now treat tri-state black background generation */
 
 	for (i=0;i<256;i++)
-		if ( (i & 0x03) == 0x00 )  // NOR => CS=1 => Tristate => real black
+		if ( (i & 0x03) == 0x00 )  /*  NOR => CS=1 => Tristate => real black */
 		{
 			r = compute_res_net( 1, 0, &radarscp_net_bck_info );
 			g = compute_res_net( 1, 1, &radarscp_net_bck_info );
@@ -353,7 +353,7 @@ PALETTE_INIT( radarsc1 )
 	/* Now treat tri-state black background generation */
 
 	for (i=0;i<256;i++)
-		if ( (i & 0x03) == 0x00 )  // NOR => CS=1 => Tristate => real black
+		if ( (i & 0x03) == 0x00 )  /*  NOR => CS=1 => Tristate => real black */
 		{
 			r = compute_res_net( 0, 0, &radarsc1_net_info );
 			g = compute_res_net( 0, 1, &radarsc1_net_info );
@@ -448,7 +448,7 @@ PALETTE_INIT( dkong3 )
 static TILE_GET_INFO( dkong_bg_tile_info )
 {
 	dkong_state *state = machine->driver_data;
-	int code = videoram[tile_index] + 256 * state->gfx_bank;
+	int code = state->video_ram[tile_index] + 256 * state->gfx_bank;
 	int color = (state->color_codes[tile_index % 32 + 32 * (tile_index / 32 / 4)] & 0x0f) + 0x10 * state->palette_bank;
 
 	SET_TILE_INFO(0, code, color, 0);
@@ -457,7 +457,7 @@ static TILE_GET_INFO( dkong_bg_tile_info )
 static TILE_GET_INFO( radarsc1_bg_tile_info )
 {
 	dkong_state *state = machine->driver_data;
-	int code = videoram[tile_index] + 256 * state->gfx_bank;
+	int code = state->video_ram[tile_index] + 256 * state->gfx_bank;
 	int color = (state->color_codes[tile_index % 32] & 0x0f);
 	color = color | (state->palette_bank<<4);
 
@@ -472,32 +472,18 @@ static TILE_GET_INFO( radarsc1_bg_tile_info )
 
 WRITE8_HANDLER( dkong_videoram_w )
 {
-	dkong_state *state = Machine->driver_data;
+	dkong_state *state = space->machine->driver_data;
 
-	if (videoram[offset] != data)
+	if (state->video_ram[offset] != data)
 	{
-		videoram[offset] = data;
+		state->video_ram[offset] = data;
 		tilemap_mark_tile_dirty(state->bg_tilemap, offset);
 	}
 }
 
-WRITE8_HANDLER( radarscp_snd02_w )
-{
-	dkong_state *state = Machine->driver_data;
-
-	state->snd02_enable = data & 0x01;
-}
-
-WRITE8_HANDLER( radarsc1_ansn_w )
-{
-	dkong_state *state = Machine->driver_data;
-
-	state->sig_ansn = data & 0x01;
-}
-
 WRITE8_HANDLER( dkongjr_gfxbank_w )
 {
-	dkong_state *state = Machine->driver_data;
+	dkong_state *state = space->machine->driver_data;
 
 	if (state->gfx_bank != (data & 0x01))
 	{
@@ -508,7 +494,7 @@ WRITE8_HANDLER( dkongjr_gfxbank_w )
 
 WRITE8_HANDLER( dkong3_gfxbank_w )
 {
-	dkong_state *state = Machine->driver_data;
+	dkong_state *state = space->machine->driver_data;
 
 	if (state->gfx_bank != (~data & 0x01))
 	{
@@ -519,7 +505,7 @@ WRITE8_HANDLER( dkong3_gfxbank_w )
 
 WRITE8_HANDLER( dkong_palettebank_w )
 {
-	dkong_state *state = Machine->driver_data;
+	dkong_state *state = space->machine->driver_data;
 	int newbank;
 
 	newbank = state->palette_bank;
@@ -538,95 +524,149 @@ WRITE8_HANDLER( dkong_palettebank_w )
 
 WRITE8_HANDLER( radarscp_grid_enable_w )
 {
-	dkong_state *state = Machine->driver_data;
+	dkong_state *state = space->machine->driver_data;
 
 	state->grid_on = data & 0x01;
 }
 
 WRITE8_HANDLER( radarscp_grid_color_w )
 {
-	dkong_state *state = Machine->driver_data;
+	dkong_state *state = space->machine->driver_data;
 
 	state->grid_col = (data & 0x07) ^ 0x07;
-	//popmessage("Gridcol: %d", state->grid_col);
+	/* popmessage("Gridcol: %d", state->grid_col); */
 }
 
 WRITE8_HANDLER( dkong_flipscreen_w )
 {
-	flip_screen_set(~data & 0x01);
+	dkong_state *state = space->machine->driver_data;
+
+	state->flip = ~data & 0x01;
 }
 
 WRITE8_HANDLER( dkong_spritebank_w )
 {
-	dkong_state *state = Machine->driver_data;
+	dkong_state *state = space->machine->driver_data;
 
 	state->sprite_bank = data & 0x01;
 }
 
 /***************************************************************************
 
-  Draw the game screen in the given mame_bitmap.
+  Draw the game screen in the given bitmap_t.
 
 ***************************************************************************/
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, UINT32 mask_bank, UINT32 shift_bits)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, UINT32 mask_bank, UINT32 shift_bits)
 {
 	dkong_state *state = machine->driver_data;
 	int offs;
+	int scanline_vf;	/* buffering scanline including flip */
+	int scanline_vfc;  		/* line buffering scanline including flip - this is the cached scanline_vf*/
+	int scanline; 		/* current scanline */
+	int add_y;
+	int add_x;
+	int num_sprt;
 
-	/* Draw the sprites. */
-	for (offs = state->sprite_bank<<9;offs < (state->sprite_bank<<9) + 0x200 /* spriteram_size */; offs += 4)
+	/* Draw the sprites. There are two pecularities which have been mentioned by
+     * a Donkey Kong II author at CAX 2008:
+     * 1) On real hardware, sprites wrap around from the right to the left instead
+     *    of clipping.
+     * 2) On real hardware, there is a limit of 16 sprites per scanline.
+     *    Sprites after the 16th (starting from the left) simply don't show.
+     *
+     * 2) is in line with the real hardware which buffers the sprite data
+     * for one scanline. The ram is 64x9 and a sprite takes 4 bytes.
+     * ==> 16 sprites per scanline.
+     *
+     * TODO: 9th bit is not understood right now.
+     *
+     * 1) is due to limitation of signals to 8 bit.
+     *
+     * This is quite different from galaxian. The dkong hardware updates sprites
+     * only once every frame by dma. The number of sprites can not be processed
+     * directly, Thus the preselection. The buffering takes place during the
+     * active phase of the video signal. The scanline is than rendered into the linebuffer
+     * during HBLANK.
+     *
+     * A sprite will be drawn:
+     * a) FlipQ = 1 : (sprite_y + 0xF9 + scanline) & 0xF0 == 0xF0
+     * b) FlipQ = 0 : (sprite_y + 0xF7 + (scanline ^ 0xFF)) & 0xF0 == 0xF0
+     *
+     * FlipQ = 1 ("Normal Play"):
+     *
+     * sprite_y = 0x20
+     *
+     * scanline
+     * 0x10, 0xEF, 0x208, 0x00
+     * 0x18, 0xE7, 0x200, 0x00
+     * 0x19, 0xE6, 0x1FF, 0xF0
+     * 0x20, 0xDF, 0x1F8, 0xF0
+     *
+     */
+
+	scanline_vf = (cliprect->max_y - 1) & 0xFF;
+	scanline_vfc = (cliprect->max_y - 1) & 0xFF;
+	scanline = cliprect->max_y & 0xFF;
+
+	if (state->flip)
 	{
-		if (spriteram[offs])
+		scanline_vf ^= 0xFF;
+		scanline_vfc ^= 0xFF;
+		add_y = 0xF7;
+		add_x = 0xF7;
+	}
+	else
+	{
+		add_y = 0xF9;
+		add_x = 0xF7;
+	}
+
+	for (offs = state->sprite_bank<<9, num_sprt=0; (num_sprt < 16) && (offs < (state->sprite_bank<<9) + 0x200) /* sprite_ram_size */; offs += 4)
+	{
+		int y = state->sprite_ram[offs];
+		int do_draw = (((y + add_y + 1 + scanline_vf) & 0xF0) == 0xF0) ? 1 : 0;
+
+		if (do_draw)
 		{
-			/* spriteram[offs + 2] & 0x40 is used by Donkey Kong 3 only */
-			/* spriteram[offs + 2] & 0x30 don't seem to be used (they are */
+			/* sprite_ram[offs + 2] & 0x40 is used by Donkey Kong 3 only */
+			/* sprite_ram[offs + 2] & 0x30 don't seem to be used (they are */
 			/* probably not part of the color code, since Mario Bros, which */
 			/* has similar hardware, uses a memory mapped port to change */
 			/* palette bank, so it's limited to 16 color codes) */
 
-			int x,y;
+			int x = state->sprite_ram[offs + 3];
 
-			x = spriteram[offs + 3] - 8;
-			y = 240 - spriteram[offs] + 7;
+			/* On the real board, the x and y are read inverted after the first
+             * buffer stage. This due to the fact that the 82S09 delivers complements
+             * of stored data on read!
+             */
 
-			if (flip_screen)
+			x = (x + add_x + 1) & 0xFF;
+			if (state->flip)
+				x ^= 0xFF;
+			y = (y + add_y + 1 + scanline_vfc) & 0x0F;
+
+			if (state->flip)
 			{
-				x = 240 - x;
-				y = VTOTAL - VBEND - y;
-
 				drawgfx(bitmap,machine->gfx[1],
-						(spriteram[offs + 1] & 0x7f) + ((spriteram[offs + 2] & mask_bank) << shift_bits),
-						(spriteram[offs + 2] & 0x0f) + 16 * state->palette_bank,
-						!(spriteram[offs + 2] & 0x80),!(spriteram[offs + 1] & 0x80),
-						x,y,
-						cliprect,TRANSPARENCY_PEN,0);
-
-				/* draw with wrap around - this fixes the 'beheading' bug */
-				drawgfx(bitmap,machine->gfx[1],
-						(spriteram[offs + 1] & 0x7f) + ((spriteram[offs + 2] & mask_bank) << shift_bits),
-						(spriteram[offs + 2] & 0x0f) + 16 * state->palette_bank,
-						(spriteram[offs + 2] & 0x80),(spriteram[offs + 1] & 0x80),
-						x-256,y,
+						(state->sprite_ram[offs + 1] & 0x7f) + ((state->sprite_ram[offs + 2] & mask_bank) << shift_bits),
+						(state->sprite_ram[offs + 2] & 0x0f) + 16 * state->palette_bank,
+						!(state->sprite_ram[offs + 2] & 0x80),(state->sprite_ram[offs + 1] & 0x80),
+						x-15, scanline-y,
 						cliprect,TRANSPARENCY_PEN,0);
 			}
 			else
 			{
 				drawgfx(bitmap,machine->gfx[1],
-						(spriteram[offs + 1] & 0x7f) + ((spriteram[offs + 2] & mask_bank) << shift_bits),
-						(spriteram[offs + 2] & 0x0f) + 16 * state->palette_bank,
-						(spriteram[offs + 2] & 0x80),(spriteram[offs + 1] & 0x80),
-						x,y,
-						cliprect,TRANSPARENCY_PEN,0);
-
-				/* draw with wrap around - this fixes the 'beheading' bug */
-				drawgfx(bitmap,machine->gfx[1],
-						(spriteram[offs + 1] & 0x7f) + ((spriteram[offs + 2] & mask_bank) << shift_bits),
-						(spriteram[offs + 2] & 0x0f) + 16 * state->palette_bank,
-						(spriteram[offs + 2] & 0x80),(spriteram[offs + 1] & 0x80),
-						x+256,y,
+						(state->sprite_ram[offs + 1] & 0x7f) + ((state->sprite_ram[offs + 2] & mask_bank) << shift_bits),
+						(state->sprite_ram[offs + 2] & 0x0f) + 16 * state->palette_bank,
+						(state->sprite_ram[offs + 2] & 0x80),(state->sprite_ram[offs + 1] & 0x80),
+						x, scanline-y,
 						cliprect,TRANSPARENCY_PEN,0);
 			}
+
+			num_sprt++;
 		}
 	}
 }
@@ -663,17 +703,20 @@ INLINE double CD4049(running_machine *machine, double x)
  * a period of roughly 4.4 ms
  */
 
-#define RC1		(2.2e3 * 22e-6) // 22e-6;
+#define RC1		(2.2e3 * 22e-6) /*  22e-6; */
 #define RC2		(10e3 * 33e-6)
 #define RC31	(18e3 * 33e-6)
 #define RC32	((18e3 + 68e3) * 33e-6)
 #define RC4		(90e3 * 0.47e-6)
 #define dt		(1./60./(double) VTOTAL)
-#define period2 (((INT64)(PIXEL_CLOCK) * ( 33L * 68L )) / (INT32)10000000L / 3)  // period/2 in pixel ...
+#define period2 (((INT64)(PIXEL_CLOCK) * ( 33L * 68L )) / (INT32)10000000L / 3)  /*  period/2 in pixel ... */
 
 static void radarscp_step(running_machine *machine, int line_cnt)
 {
 	dkong_state *state = machine->driver_data;
+	const device_config *dev6h = devtag_get_device(machine, LATCH8, "ls259.6h");
+	const device_config *devvp2 = devtag_get_device(machine, LATCH8, "virtual_p2");
+
 	/* Condensator is illegible in schematics for TRS2 board.
      * TRS1 board states 3.3u.
      */
@@ -697,16 +740,18 @@ static void radarscp_step(running_machine *machine, int line_cnt)
 	if (line_cnt>=512)
 		line_cnt=512-VTOTAL;
 
-	if ( ( !(line_cnt & 0x40) && ((line_cnt+1) & 0x40) ) && (mame_rand(Machine) > RAND_MAX/2))
+	if ( ( !(line_cnt & 0x40) && ((line_cnt+1) & 0x40) ) && (mame_rand(machine) > RAND_MAX/2))
 		state->sig30Hz = (1-state->sig30Hz);
 
-	state->rflip_sig = state->snd02_enable & state->sig30Hz;
+	/* Now mix with SND02 (sound 2) line - on 74ls259, bit2 */
+	state->rflip_sig = latch8_bit2_r(dev6h, 0) & state->sig30Hz;
+
 	sig = state->rflip_sig ^ ((line_cnt & 0x80)>>7);
 
 	if (state->hardware_type == HARDWARE_TRS01)
 		state->rflip_sig = !state->rflip_sig;
 
-	if  (sig) // 128VF
+	if  (sig) /*  128VF */
 		diff = (0.0 - cv1);
 	else
 		diff = (3.4 - cv1);
@@ -728,8 +773,12 @@ static void radarscp_step(running_machine *machine, int line_cnt)
 
 	state->blue_level = (int)(vg3/5.0*255);
 
-	// Grid signal
-	if (state->grid_on && state->sig_ansn)
+	/*
+     * Grid signal
+     *
+     * Mixed with ANS line (bit 5) from Port B of 8039
+     */
+	if (state->grid_on && latch8_bit5_r(devvp2, 0))
 	{
 		diff = (0.0 - cv3);
 		diff = diff - diff*exp(0.0 - (1.0/RC32 * dt) );
@@ -745,7 +794,7 @@ static void radarscp_step(running_machine *machine, int line_cnt)
 	diff = diff - diff*exp(0.0 - (1.0/RC4 * dt) );
 	cv4 += diff;
 
-	if (CD4049(machine, CD4049(machine, vg2 - cv4))>2.4/5.0) //TTL - Level
+	if (CD4049(machine, CD4049(machine, vg2 - cv4))>2.4/5.0) /* TTL - Level */
 		state->grid_sig = 0;
 	else
 		state->grid_sig = 1;
@@ -760,26 +809,25 @@ static void radarscp_step(running_machine *machine, int line_cnt)
 
 }
 
-static void radarscp_draw_background(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void radarscp_draw_background(running_machine *machine, dkong_state *state, bitmap_t *bitmap, const rectangle *cliprect)
 {
-	dkong_state *state = machine->driver_data;
 	const UINT8 	*htable = NULL;
 	int 			x,y;
 	UINT8 			draw_ok;
 	UINT16 			*pixel;
 
 	if (state->hardware_type == HARDWARE_TRS01)
-		htable = memory_region(REGION_GFX4);
+		htable = state->gfx4;
 
-	y = machine->screen[0].visarea.min_y;
-	while (y <= machine->screen[0].visarea.max_y)
+	y = cliprect->min_y;
+	while (y <= cliprect->max_y)
 	{
-		x = machine->screen[0].visarea.min_x;
-		while (x <= machine->screen[0].visarea.max_x)
+		x = cliprect->min_x;
+		while (x <= cliprect->max_x)
 		{
 			pixel = BITMAP_ADDR16(bitmap, y, x);
 			draw_ok = !(*pixel & 0x01) && !(*pixel & 0x02);
-			if (state->hardware_type == HARDWARE_TRS01) // Check again from schematics
+			if (state->hardware_type == HARDWARE_TRS01) /*  Check again from schematics */
 				draw_ok = draw_ok  && !((htable[ (!state->rflip_sig<<7) | (x>>2)] >>2) & 0x01);
 			if (draw_ok)
 				*pixel = *(BITMAP_ADDR16(state->bg_bits, y, x));
@@ -789,67 +837,82 @@ static void radarscp_draw_background(running_machine *machine, mame_bitmap *bitm
 	}
 }
 
-
-static TIMER_CALLBACK( scanline_callback )
+static void radarscp_scanline(running_machine *machine, int scanline)
 {
 	dkong_state *state = machine->driver_data;
-	const UINT8 *table = memory_region(REGION_GFX3);
-	int 		table_len = memory_region_length(REGION_GFX3);
+	const UINT8 *table = state->gfx3;
+	int 		table_len = state->gfx3_len;
 	int 			x,y,offset;
 	UINT16 			*pixel;
 	static int		counter=0;
-	int scanline = param;
+	const rectangle *visarea = video_screen_get_visible_area(machine->primary_screen);
 
 	y = scanline;
 	radarscp_step(machine, y);
-	if (y <= machine->screen[0].visarea.min_y || y > machine->screen[0].visarea.max_y)
+	if (y <= visarea->min_y || y > visarea->max_y)
 		counter = 0;
-	offset = ((-flip_screen) ^ state->rflip_sig) ? 0x000 : 0x400;
+	offset = (state->flip ^ state->rflip_sig) ? 0x000 : 0x400;
 	x = 0;
-	while (x < machine->screen[0].width)
+	while (x < video_screen_get_width(machine->primary_screen))
 	{
 		pixel = BITMAP_ADDR16(state->bg_bits, y, x);
 		if ((counter < table_len) && (x == 4 * (table[counter|offset] & 0x7f)))
 		{
 			if ( state->star_ff && (table[counter|offset] & 0x80) )	/* star */
-				*pixel = machine->pens[RADARSCP_STAR_COL];
+				*pixel = RADARSCP_STAR_COL;
 			else if (state->grid_sig && !(table[counter|offset] & 0x80))			/* radar */
-				*pixel = machine->pens[RADARSCP_GRID_COL_OFFSET+state->grid_col];
+				*pixel = RADARSCP_GRID_COL_OFFSET+state->grid_col;
 			else
-				*pixel = machine->pens[RADARSCP_BCK_COL_OFFSET + state->blue_level];
+				*pixel = RADARSCP_BCK_COL_OFFSET + state->blue_level;
 			counter++;
 		}
 		else
-			*pixel = machine->pens[RADARSCP_BCK_COL_OFFSET + state->blue_level];
+			*pixel = RADARSCP_BCK_COL_OFFSET + state->blue_level;
 		x++;
 	}
 	while ((counter < table_len) && ( x < 4 * (table[counter|offset] & 0x7f)))
 		counter++;
+}
+
+static TIMER_CALLBACK( scanline_callback )
+{
+	dkong_state *state = machine->driver_data;
+	int scanline = param;
+
+	if ((state->hardware_type == HARDWARE_TRS02) || (state->hardware_type == HARDWARE_TRS01))
+		radarscp_scanline(machine, scanline);
+
+	/* update any video up to the current scanline */
+	video_screen_update_now(machine->primary_screen);
+
 	scanline = (scanline+1) % VTOTAL;
 	/* come back at the next appropriate scanline */
-	timer_adjust(state->scanline_timer, video_screen_get_time_until_pos(0, scanline, 0), scanline, attotime_zero);
+	timer_adjust_oneshot(state->scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, scanline, 0), scanline);
 }
 
 static void check_palette(running_machine *machine)
 {
 	dkong_state *state = machine->driver_data;
+	const input_port_config *port;
 	int newset;
-	int num;
 
-	num = port_tag_to_index("VIDHW");
-	if (num>=0)
+	port = input_port_by_tag(machine->portconfig, "VIDHW");
+	if (port != NULL)
 	{
-		newset = readinputport(num);
+		newset = input_port_read_direct(port);
 		if (newset != state->vidhw)
 		{
+			const UINT8 *color_prom;
 			state->vidhw = newset;
 			switch (newset)
 			{
 				case 0x00:
-					palette_init_radarscp(machine, (UINT16 *) machine->game_colortable, memory_region(REGION_PROMS));
+					color_prom = memory_region(machine, "proms");
+					PALETTE_INIT_CALL(radarscp);
 					break;
 				case 0x01:
-					palette_init_dkong2b(machine, (UINT16 *) machine->game_colortable, memory_region(REGION_PROMS));
+					color_prom = memory_region(machine, "proms");
+					PALETTE_INIT_CALL(dkong2b);
 					break;
 			}
 		}
@@ -866,21 +929,15 @@ static VIDEO_START( dkong_base )
 	state->gfx_bank = 0;
 	state->palette_bank = 0;
 	state->sprite_bank = 0;
-	state->sig_ansn = 1;
 	state->vidhw = -1;
 
-	state_save_register_global(state->gfx_bank);
-	state_save_register_global(state->palette_bank);
-	state_save_register_global(state->sprite_bank);
-	state_save_register_global(state->grid_on);
-
-	state_save_register_global(state->snd02_enable);
-	state_save_register_global(state->sig_ansn);
-	state_save_register_global(state->grid_col);
-
-	/* this must be registered here - hmmm */
-	state_save_register_global(flip_screen);
+	state_save_register_global(machine, state->gfx_bank);
+	state_save_register_global(machine, state->palette_bank);
+	state_save_register_global(machine, state->sprite_bank);
+	state_save_register_global(machine, state->grid_on);
 
+	state_save_register_global(machine, state->grid_col);
+	state_save_register_global(machine, state->flip);
 }
 
 VIDEO_START( dkong )
@@ -889,26 +946,30 @@ VIDEO_START( dkong )
 
 	VIDEO_START_CALL(dkong_base);
 
+	state->scanline_timer = timer_alloc(machine, scanline_callback, NULL);
+	timer_adjust_oneshot(state->scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, 0, 0), 0);
+
 	switch (state->hardware_type)
 	{
 		case HARDWARE_TRS02:
-			state->bg_bits = auto_bitmap_alloc(machine->screen[0].width, machine->screen[0].height, machine->screen[0].format);
-			state->scanline_timer = timer_alloc(scanline_callback, NULL);
-			timer_adjust(state->scanline_timer, video_screen_get_time_until_pos(0, 0, 0), 0, attotime_zero);
+			state->bg_bits = video_screen_auto_bitmap_alloc(machine->primary_screen);
+			state->gfx3 = memory_region(machine, "gfx3");
+			state->gfx3_len = memory_region_length(machine, "gfx3");
 		    /* fall through */
 		case HARDWARE_TKG04:
 		case HARDWARE_TKG02:
-			state->bg_tilemap = tilemap_create(dkong_bg_tile_info, tilemap_scan_rows, TILEMAP_TYPE_PEN, 8, 8, 32, 32);
+			state->bg_tilemap = tilemap_create(machine, dkong_bg_tile_info, tilemap_scan_rows,  8, 8, 32, 32);
 			tilemap_set_scrolldx(state->bg_tilemap, 0, 128);
 			break;
 		case HARDWARE_TRS01:
-			state->bg_tilemap = tilemap_create(radarsc1_bg_tile_info, tilemap_scan_rows, TILEMAP_TYPE_PEN, 8, 8, 32, 32);
+			state->bg_tilemap = tilemap_create(machine, radarsc1_bg_tile_info, tilemap_scan_rows,  8, 8, 32, 32);
 			tilemap_set_scrolldx(state->bg_tilemap, 0, 128);
 
-			state->bg_bits = auto_bitmap_alloc(machine->screen[0].width, machine->screen[0].height, machine->screen[0].format);
+			state->bg_bits = video_screen_auto_bitmap_alloc(machine->primary_screen);
+			state->gfx4 = memory_region(machine, "gfx4");
+			state->gfx3 = memory_region(machine, "gfx3");
+			state->gfx3_len = memory_region_length(machine, "gfx3");
 
-			state->scanline_timer = timer_alloc(scanline_callback, NULL);
-			timer_adjust(state->scanline_timer, video_screen_get_time_until_pos(0, 0, 0), 0, attotime_zero);
 			break;
 		default:
 			fatalerror("Invalid hardware type in dkong_video_start");
@@ -917,21 +978,25 @@ VIDEO_START( dkong )
 
 VIDEO_UPDATE( dkong )
 {
-	dkong_state *state = machine->driver_data;
+	dkong_state *state = screen->machine->driver_data;
+
+	tilemap_set_flip(ALL_TILEMAPS, state->flip ? TILEMAP_FLIPX | TILEMAP_FLIPY : 0);
+	tilemap_set_scrollx(state->bg_tilemap, 0, state->flip ?  0 : 0);
+	tilemap_set_scrolly(state->bg_tilemap, 0, state->flip ? -8 : 0);
 
 	switch (state->hardware_type)
 	{
 		case HARDWARE_TKG02:
 		case HARDWARE_TKG04:
-			check_palette(machine);
+			check_palette(screen->machine);
 			tilemap_draw(bitmap, cliprect, state->bg_tilemap, 0, 0);
-			draw_sprites(machine, bitmap, cliprect, 0x40, 1);
+			draw_sprites(screen->machine, bitmap, cliprect, 0x40, 1);
 			break;
 		case HARDWARE_TRS01:
 		case HARDWARE_TRS02:
 			tilemap_draw(bitmap, cliprect, state->bg_tilemap, 0, 0);
-			draw_sprites(machine, bitmap, cliprect, 0x40, 1);
-			radarscp_draw_background(machine, bitmap, cliprect);
+			draw_sprites(screen->machine, bitmap, cliprect, 0x40, 1);
+			radarscp_draw_background(screen->machine, state, bitmap, cliprect);
 			break;
 		default:
 			fatalerror("Invalid hardware type in dkong_video_update");
@@ -941,21 +1006,21 @@ VIDEO_UPDATE( dkong )
 
 VIDEO_UPDATE( pestplce )
 {
-	dkong_state *state = machine->driver_data;
+	dkong_state *state = screen->machine->driver_data;
 	int offs;
 
 	tilemap_draw(bitmap, cliprect, state->bg_tilemap, 0, 0);
 
 	/* Draw the sprites. */
-	for (offs = 0;offs < spriteram_size;offs += 4)
+	for (offs = 0;offs < state->sprite_ram_size;offs += 4)
 	{
-		if (spriteram[offs])
+		if (state->sprite_ram[offs])
 		{
-			drawgfx(bitmap,machine->gfx[1],
-					spriteram[offs + 2],
-					(spriteram[offs + 1] & 0x0f) + 16 * state->palette_bank,
-					spriteram[offs + 1] & 0x80,spriteram[offs + 1] & 0x40,
-					spriteram[offs + 3] - 8,240 - spriteram[offs] + 8,
+			drawgfx(bitmap,screen->machine->gfx[1],
+					state->sprite_ram[offs + 2],
+					(state->sprite_ram[offs + 1] & 0x0f) + 16 * state->palette_bank,
+					state->sprite_ram[offs + 1] & 0x80,state->sprite_ram[offs + 1] & 0x40,
+					state->sprite_ram[offs + 3] - 8,240 - state->sprite_ram[offs] + 8,
 					cliprect,TRANSPARENCY_PEN,0);
 		}
 	}
@@ -964,11 +1029,11 @@ VIDEO_UPDATE( pestplce )
 
 VIDEO_UPDATE( spclforc )
 {
-	dkong_state *state = machine->driver_data;
+	dkong_state *state = screen->machine->driver_data;
 
 	tilemap_draw(bitmap, cliprect, state->bg_tilemap, 0, 0);
 
-	/* it uses spriteram[offs + 2] & 0x10 for sprite bank */
-	draw_sprites(machine, bitmap, cliprect, 0x10, 3);
+	/* it uses sprite_ram[offs + 2] & 0x10 for sprite bank */
+	draw_sprites(screen->machine, bitmap, cliprect, 0x10, 3);
 	return 0;
 }
