@@ -1,4 +1,5 @@
 #include "driver.h"
+#include "includes/dooyong.h"
 
 
 UINT8 *dooyong_txvideoram;
@@ -94,22 +95,22 @@ WRITE8_HANDLER( dooyong_fg2scroll8_w )
 
 WRITE16_HANDLER( dooyong_bgscroll16_w )
 {
-	if (ACCESSING_LSB) dooyong_bgscroll8_w(offset, data & 0x00ff);
+	if (ACCESSING_BITS_0_7) dooyong_bgscroll8_w(space, offset, data & 0x00ff);
 }
 
 WRITE16_HANDLER( dooyong_bg2scroll16_w )
 {
-	if (ACCESSING_LSB) dooyong_bg2scroll8_w(offset, data & 0x00ff);
+	if (ACCESSING_BITS_0_7) dooyong_bg2scroll8_w(space, offset, data & 0x00ff);
 }
 
 WRITE16_HANDLER( dooyong_fgscroll16_w )
 {
-	if (ACCESSING_LSB) dooyong_fgscroll8_w(offset, data & 0x00ff);
+	if (ACCESSING_BITS_0_7) dooyong_fgscroll8_w(space, offset, data & 0x00ff);
 }
 
 WRITE16_HANDLER( dooyong_fg2scroll16_w )
 {
-	if (ACCESSING_LSB) dooyong_fg2scroll8_w(offset, data & 0x00ff);
+	if (ACCESSING_BITS_0_7) dooyong_fg2scroll8_w(space, offset, data & 0x00ff);
 }
 
 
@@ -140,13 +141,13 @@ WRITE8_HANDLER( lastday_ctrl_w )
 	sprites_disabled = data & 0x10;
 
 	/* bit 6 is flip screen */
-	flip_screen_set(data & 0x40);
+	flip_screen_set(space->machine, data & 0x40);
 }
 
 WRITE8_HANDLER( pollux_ctrl_w )
 {
 	/* bit 0 is flip screen */
-	flip_screen_set(data & 0x01);
+	flip_screen_set(space->machine, data & 0x01);
 
 	/* bits 6 and 7 are coin counters */
 	coin_counter_w(0, data & 0x80);
@@ -162,23 +163,23 @@ WRITE8_HANDLER( pollux_ctrl_w )
 WRITE8_HANDLER( primella_ctrl_w )
 {
 	/* bits 0-2 select ROM bank */
-	memory_set_bank(1, data & 0x07);
+	memory_set_bank(space->machine, 1, data & 0x07);
 
 	/* bit 3 disables tx layer */
 	tx_pri = data & 0x08;
 
 	/* bit 4 flips screen */
-	flip_screen_set(data & 0x10);
+	flip_screen_set(space->machine, data & 0x10);
 
 	/* bit 5 used but unknown */
 
-//  logerror("%04x: bankswitch = %02x\n",activecpu_get_pc(),data&0xe0);
+//  logerror("%04x: bankswitch = %02x\n",cpu_get_pc(space->cpu),data&0xe0);
 }
 
 WRITE8_HANDLER( flytiger_ctrl_w )
 {
 	/* bit 0 is flip screen */
-	flip_screen_set(data & 0x01);
+	flip_screen_set(space->machine, data & 0x01);
 
 	/* bits 1, 2, 3 used but unknown */
 
@@ -188,10 +189,10 @@ WRITE8_HANDLER( flytiger_ctrl_w )
 
 WRITE16_HANDLER( rshark_ctrl_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		/* bit 0 flips screen */
-		flip_screen_set(data & 0x0001);
+		flip_screen_set(space->machine, data & 0x0001);
 
 		/* bit 4 changes tilemaps priority */
 		rshark_pri = data & 0x0010;
@@ -344,7 +345,7 @@ static TILE_GET_INFO( get_tx_tile_info )
 }
 
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int pollux_extensions)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int pollux_extensions)
 {
 	/* Sprites take 32 bytes each in memory:
                      MSB   LSB
@@ -413,7 +414,7 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 			}
 		}
 
-		if (flip_screen)
+		if (flip_screen_get(machine))
 		{
 			sx = 498 - sx;
 			sy = 240 - (16 * height) - sy;
@@ -434,7 +435,7 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 	}
 }
 
-static void rshark_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void rshark_draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	/* Sprites take 8 16-bit words each in memory:
                   MSB             LSB
@@ -475,7 +476,7 @@ static void rshark_draw_sprites(running_machine *machine, mame_bitmap *bitmap, c
 			width = buffered_spriteram16[offs+1] & 0x000f;
 			height = (buffered_spriteram16[offs+1] & 0x00f0) >> 4;
 
-			if (flip_screen)
+			if (flip_screen_get(machine))
 			{
 				sx = 498 - (16 * width) - sx;
 				sy = 240 - (16 * height) - sy;
@@ -506,48 +507,48 @@ static void rshark_draw_sprites(running_machine *machine, mame_bitmap *bitmap, c
 
 VIDEO_UPDATE( lastday )
 {
-	fillbitmap(bitmap, get_black_pen(machine), cliprect);
-	fillbitmap(priority_bitmap, 0, cliprect);
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
+	bitmap_fill(priority_bitmap, cliprect, 0);
 
 	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 1);
 	tilemap_draw(bitmap, cliprect, fg_tilemap, 0, 2);
 	tilemap_draw(bitmap, cliprect, tx_tilemap, 0, 4);
 
 	if (!sprites_disabled)
-		draw_sprites(machine, bitmap, cliprect, 0);
+		draw_sprites(screen->machine, bitmap, cliprect, 0);
 	return 0;
 }
 
 VIDEO_UPDATE( gulfstrm )
 {
-	fillbitmap(bitmap, get_black_pen(machine), cliprect);
-	fillbitmap(priority_bitmap, 0, cliprect);
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
+	bitmap_fill(priority_bitmap, cliprect, 0);
 
 	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 1);
 	tilemap_draw(bitmap, cliprect, fg_tilemap, 0, 2);
 	tilemap_draw(bitmap, cliprect, tx_tilemap, 0, 4);
 
-	draw_sprites(machine, bitmap, cliprect, 1);
+	draw_sprites(screen->machine, bitmap, cliprect, 1);
 	return 0;
 }
 
 VIDEO_UPDATE( pollux )
 {
-	fillbitmap(bitmap, get_black_pen(machine), cliprect);
-	fillbitmap(priority_bitmap, 0, cliprect);
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
+	bitmap_fill(priority_bitmap, cliprect, 0);
 
 	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 1);
 	tilemap_draw(bitmap, cliprect, fg_tilemap, 0, 2);
 	tilemap_draw(bitmap, cliprect, tx_tilemap, 0, 4);
 
-	draw_sprites(machine, bitmap, cliprect, 2);
+	draw_sprites(screen->machine, bitmap, cliprect, 2);
 	return 0;
 }
 
 VIDEO_UPDATE( flytiger )
 {
-	fillbitmap(bitmap, get_black_pen(machine), cliprect);
-	fillbitmap(priority_bitmap, 0, cliprect);
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
+	bitmap_fill(priority_bitmap, cliprect, 0);
 
 	if (flytiger_pri)
 	{
@@ -561,28 +562,28 @@ VIDEO_UPDATE( flytiger )
 	}
 	tilemap_draw(bitmap, cliprect, tx_tilemap, 0, 4);
 
-	draw_sprites(machine, bitmap, cliprect, 4);
+	draw_sprites(screen->machine, bitmap, cliprect, 4);
 	return 0;
 }
 
 
 VIDEO_UPDATE( bluehawk )
 {
-	fillbitmap(bitmap, get_black_pen(machine), cliprect);
-	fillbitmap(priority_bitmap, 0, cliprect);
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
+	bitmap_fill(priority_bitmap, cliprect, 0);
 
 	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 1);
 	tilemap_draw(bitmap, cliprect, fg_tilemap, 0, 2);
 	tilemap_draw(bitmap, cliprect, fg2_tilemap, 0, 4);
 	tilemap_draw(bitmap, cliprect, tx_tilemap, 0, 4);
 
-	draw_sprites(machine, bitmap, cliprect, 3);
+	draw_sprites(screen->machine, bitmap, cliprect, 3);
 	return 0;
 }
 
 VIDEO_UPDATE( primella )
 {
-	fillbitmap(bitmap, get_black_pen(machine), cliprect);
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
 
 	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
 	if (tx_pri) tilemap_draw(bitmap, cliprect, tx_tilemap, 0, 0);
@@ -593,26 +594,26 @@ VIDEO_UPDATE( primella )
 
 VIDEO_UPDATE( rshark )
 {
-	fillbitmap(bitmap, get_black_pen(machine), cliprect);
-	fillbitmap(priority_bitmap, 0, cliprect);
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
+	bitmap_fill(priority_bitmap, cliprect, 0);
 
 	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 1);
 	tilemap_draw(bitmap, cliprect, bg2_tilemap, 0, (rshark_pri ? 2 : 1));
 	tilemap_draw(bitmap, cliprect, fg_tilemap, 0, 2);
 	tilemap_draw(bitmap, cliprect, fg2_tilemap, 0, 2);
 
-	rshark_draw_sprites(machine, bitmap, cliprect);
+	rshark_draw_sprites(screen->machine, bitmap, cliprect);
 	return 0;
 }
 
 VIDEO_UPDATE( popbingo )
 {
-	fillbitmap(bitmap, get_black_pen(machine), cliprect);
-	fillbitmap(priority_bitmap, 0, cliprect);
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
+	bitmap_fill(priority_bitmap, cliprect, 0);
 
 	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 1);
 
-	rshark_draw_sprites(machine, bitmap, cliprect);
+	rshark_draw_sprites(screen->machine, bitmap, cliprect);
 	return 0;
 }
 
@@ -620,8 +621,8 @@ VIDEO_UPDATE( popbingo )
 VIDEO_START( lastday )
 {
 	/* Configure tilemap callbacks */
-	bg_tilerom = memory_region(REGION_GFX5);
-	fg_tilerom = memory_region(REGION_GFX6);
+	bg_tilerom = memory_region(machine, "gfx5");
+	fg_tilerom = memory_region(machine, "gfx6");
 	bg_tilerom2 = NULL;
 	fg_tilerom2 = NULL;
 	bg_gfx = 2;
@@ -629,12 +630,12 @@ VIDEO_START( lastday )
 	tx_tilemap_mode = 0;
 
 	/* Create tilemaps */
-	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
-	fg_tilemap = tilemap_create(get_fg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
-	tx_tilemap = tilemap_create(get_tx_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 8, 8, 64, 32);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
+	fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
+	tx_tilemap = tilemap_create(machine, get_tx_tile_info, tilemap_scan_cols,
+		 8, 8, 64, 32);
 
 	/* Configure tilemap transparency */
 	tilemap_set_transparent_pen(fg_tilemap, 15);
@@ -643,17 +644,22 @@ VIDEO_START( lastday )
 	/* Text layer is offset on this machine */
 	tilemap_set_scrolly(tx_tilemap, 0, 8);
 
+	memset(bgscroll8, 0, 0x10);
+	memset(bg2scroll8, 0, 0x10);
+	memset(fgscroll8, 0, 0x10);
+	memset(fg2scroll8, 0, 0x10);
+
 	/* Register for save/restore */
-	state_save_register_global_array(bgscroll8);
-	state_save_register_global_array(fgscroll8);
-	state_save_register_global(sprites_disabled);
+	state_save_register_global_array(machine, bgscroll8);
+	state_save_register_global_array(machine, fgscroll8);
+	state_save_register_global(machine, sprites_disabled);
 }
 
 VIDEO_START( gulfstrm )
 {
 	/* Configure tilemap callbacks */
-	bg_tilerom = memory_region(REGION_GFX5);
-	fg_tilerom = memory_region(REGION_GFX6);
+	bg_tilerom = memory_region(machine, "gfx5");
+	fg_tilerom = memory_region(machine, "gfx6");
 	bg_tilerom2 = NULL;
 	fg_tilerom2 = NULL;
 	bg_gfx = 2;
@@ -661,12 +667,12 @@ VIDEO_START( gulfstrm )
 	tx_tilemap_mode = 0;
 
 	/* Create tilemaps */
-	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
-	fg_tilemap = tilemap_create(get_fg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
-	tx_tilemap = tilemap_create(get_tx_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 8, 8, 64, 32);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
+	fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
+	tx_tilemap = tilemap_create(machine, get_tx_tile_info, tilemap_scan_cols,
+		 8, 8, 64, 32);
 
 	/* Configure tilemap transparency */
 	tilemap_set_transparent_pen(fg_tilemap, 15);
@@ -675,16 +681,21 @@ VIDEO_START( gulfstrm )
 	/* Text layer is offset on this machine */
 	tilemap_set_scrolly(tx_tilemap, 0, 8);
 
+	memset(bgscroll8, 0, 0x10);
+	memset(bg2scroll8, 0, 0x10);
+	memset(fgscroll8, 0, 0x10);
+	memset(fg2scroll8, 0, 0x10);
+
 	/* Register for save/restore */
-	state_save_register_global_array(bgscroll8);
-	state_save_register_global_array(fgscroll8);
+	state_save_register_global_array(machine, bgscroll8);
+	state_save_register_global_array(machine, fgscroll8);
 }
 
 VIDEO_START( pollux )
 {
 	/* Configure tilemap callbacks */
-	bg_tilerom = memory_region(REGION_GFX5);
-	fg_tilerom = memory_region(REGION_GFX6);
+	bg_tilerom = memory_region(machine, "gfx5");
+	fg_tilerom = memory_region(machine, "gfx6");
 	bg_tilerom2 = NULL;
 	fg_tilerom2 = NULL;
 	bg_gfx = 2;
@@ -692,28 +703,33 @@ VIDEO_START( pollux )
 	tx_tilemap_mode = 0;
 
 	/* Create tilemaps */
-	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
-	fg_tilemap = tilemap_create(get_fg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
-	tx_tilemap = tilemap_create(get_tx_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 8, 8, 64, 32);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
+	fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
+	tx_tilemap = tilemap_create(machine, get_tx_tile_info, tilemap_scan_cols,
+		 8, 8, 64, 32);
 
 	/* Configure tilemap transparency */
 	tilemap_set_transparent_pen(fg_tilemap, 15);
 	tilemap_set_transparent_pen(tx_tilemap, 15);
 
+	memset(bgscroll8, 0, 0x10);
+	memset(bg2scroll8, 0, 0x10);
+	memset(fgscroll8, 0, 0x10);
+	memset(fg2scroll8, 0, 0x10);
+
 	/* Register for save/restore */
-	state_save_register_global_array(bgscroll8);
-	state_save_register_global_array(fgscroll8);
+	state_save_register_global_array(machine, bgscroll8);
+	state_save_register_global_array(machine, fgscroll8);
 }
 
 VIDEO_START( bluehawk )
 {
 	/* Configure tilemap callbacks */
-	bg_tilerom = memory_region(REGION_GFX3) + 0x78000;
-	fg_tilerom = memory_region(REGION_GFX4) + 0x78000;
-	fg2_tilerom = memory_region(REGION_GFX5) + 0x38000;
+	bg_tilerom = memory_region(machine, "gfx3") + 0x78000;
+	fg_tilerom = memory_region(machine, "gfx4") + 0x78000;
+	fg2_tilerom = memory_region(machine, "gfx5") + 0x38000;
 	bg_tilerom2 = NULL;
 	fg_tilerom2 = NULL;
 	fg2_tilerom2 = NULL;
@@ -723,31 +739,36 @@ VIDEO_START( bluehawk )
 	tx_tilemap_mode = 1;
 
 	/* Create tilemaps */
-	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
-	fg_tilemap = tilemap_create(get_fg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
-	fg2_tilemap = tilemap_create(get_fg2_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
-	tx_tilemap = tilemap_create(get_tx_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 8, 8, 64, 32);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
+	fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
+	fg2_tilemap = tilemap_create(machine, get_fg2_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
+	tx_tilemap = tilemap_create(machine, get_tx_tile_info, tilemap_scan_cols,
+		 8, 8, 64, 32);
 
 	/* Configure tilemap transparency */
 	tilemap_set_transparent_pen(fg_tilemap, 15);
 	tilemap_set_transparent_pen(fg2_tilemap, 15);
 	tilemap_set_transparent_pen(tx_tilemap, 15);
 
+	memset(bgscroll8, 0, 0x10);
+	memset(bg2scroll8, 0, 0x10);
+	memset(fgscroll8, 0, 0x10);
+	memset(fg2scroll8, 0, 0x10);
+
 	/* Register for save/restore */
-	state_save_register_global_array(bgscroll8);
-	state_save_register_global_array(fgscroll8);
-	state_save_register_global_array(fg2scroll8);
+	state_save_register_global_array(machine, bgscroll8);
+	state_save_register_global_array(machine, fgscroll8);
+	state_save_register_global_array(machine, fg2scroll8);
 }
 
 VIDEO_START( flytiger )
 {
 	/* Configure tilemap callbacks */
-	bg_tilerom = memory_region(REGION_GFX3) + 0x78000;
-	fg_tilerom = memory_region(REGION_GFX4) + 0x78000;
+	bg_tilerom = memory_region(machine, "gfx3") + 0x78000;
+	fg_tilerom = memory_region(machine, "gfx4") + 0x78000;
 	bg_tilerom2 = NULL;
 	fg_tilerom2 = NULL;
 	bg_gfx = 2;
@@ -755,32 +776,34 @@ VIDEO_START( flytiger )
 	tx_tilemap_mode = 0;
 
 	/* Create tilemaps */
-	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
-	fg_tilemap = tilemap_create(flytiger_get_fg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
-	tx_tilemap = tilemap_create(get_tx_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 8, 8, 64, 32);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
+	fg_tilemap = tilemap_create(machine, flytiger_get_fg_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
+	tx_tilemap = tilemap_create(machine, get_tx_tile_info, tilemap_scan_cols,
+		 8, 8, 64, 32);
 
 	/* Configure tilemap transparency */
 	tilemap_set_transparent_pen(bg_tilemap, 15);
 	tilemap_set_transparent_pen(fg_tilemap, 15);
 	tilemap_set_transparent_pen(tx_tilemap, 15);
 
+	memset(bgscroll8, 0, 0x10);
+	memset(bg2scroll8, 0, 0x10);
+	memset(fgscroll8, 0, 0x10);
+	memset(fg2scroll8, 0, 0x10);
+
 	/* Register for save/restore */
-	state_save_register_global_array(bgscroll8);
-	state_save_register_global_array(fgscroll8);
-	state_save_register_global(flytiger_pri);
+	state_save_register_global_array(machine, bgscroll8);
+	state_save_register_global_array(machine, fgscroll8);
+	state_save_register_global(machine, flytiger_pri);
 }
 
 VIDEO_START( primella )
 {
-	/* Configure memory banking */
-	memory_configure_bank(1, 0, 8, memory_region(REGION_CPU1) + 0x10000, 0x4000);
-
 	/* Configure tilemap callbacks */
-	bg_tilerom = memory_region(REGION_GFX2) + memory_region_length(REGION_GFX2) - 0x8000;
-	fg_tilerom = memory_region(REGION_GFX3) + memory_region_length(REGION_GFX3) - 0x8000;
+	bg_tilerom = memory_region(machine, "gfx2") + memory_region_length(machine, "gfx2") - 0x8000;
+	fg_tilerom = memory_region(machine, "gfx3") + memory_region_length(machine, "gfx3") - 0x8000;
 	bg_tilerom2 = NULL;
 	fg_tilerom2 = NULL;
 	bg_gfx = 1;
@@ -788,88 +811,107 @@ VIDEO_START( primella )
 	tx_tilemap_mode = 1;
 
 	/* Create tilemaps */
-	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
-	fg_tilemap = tilemap_create(get_fg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
-	tx_tilemap = tilemap_create(get_tx_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 8, 8, 64, 32);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
+	fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
+	tx_tilemap = tilemap_create(machine, get_tx_tile_info, tilemap_scan_cols,
+		 8, 8, 64, 32);
 
 	/* Configure tilemap transparency */
 	tilemap_set_transparent_pen(fg_tilemap, 15);
 	tilemap_set_transparent_pen(tx_tilemap, 15);
 
+	memset(bgscroll8, 0, 0x10);
+	memset(bg2scroll8, 0, 0x10);
+	memset(fgscroll8, 0, 0x10);
+	memset(fg2scroll8, 0, 0x10);
+
 	/* Register for save/restore */
-	state_save_register_global_array(bgscroll8);
-	state_save_register_global_array(fgscroll8);
-	state_save_register_global(tx_pri);
+	state_save_register_global_array(machine, bgscroll8);
+	state_save_register_global_array(machine, fgscroll8);
+	state_save_register_global(machine, tx_pri);
 }
 
 VIDEO_START( rshark )
 {
 	/* Configure tilemap callbacks */
-	bg_tilerom = memory_region(REGION_GFX5);
-	bg2_tilerom = memory_region(REGION_GFX4);
-	fg_tilerom = memory_region(REGION_GFX3);
-	fg2_tilerom = memory_region(REGION_GFX2);
-	bg_tilerom2 = memory_region(REGION_GFX6) + 0x60000;
-	bg2_tilerom2 = memory_region(REGION_GFX6) + 0x40000;
-	fg_tilerom2 = memory_region(REGION_GFX6) + 0x20000;
-	fg2_tilerom2 = memory_region(REGION_GFX6) + 0x00000;
+	bg_tilerom = memory_region(machine, "gfx5");
+	bg2_tilerom = memory_region(machine, "gfx4");
+	fg_tilerom = memory_region(machine, "gfx3");
+	fg2_tilerom = memory_region(machine, "gfx2");
+	bg_tilerom2 = memory_region(machine, "gfx6") + 0x60000;
+	bg2_tilerom2 = memory_region(machine, "gfx6") + 0x40000;
+	fg_tilerom2 = memory_region(machine, "gfx6") + 0x20000;
+	fg2_tilerom2 = memory_region(machine, "gfx6") + 0x00000;
 	bg_gfx = 4;
 	bg2_gfx = 3;
 	fg_gfx = 2;
 	fg2_gfx = 1;
 
 	/* Create tilemaps */
-	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 16, 16, 64, 32);
-	bg2_tilemap = tilemap_create(get_bg2_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 16, 16, 64, 32);
-	fg_tilemap = tilemap_create(get_fg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 16, 16, 64, 32);
-	fg2_tilemap = tilemap_create(get_fg2_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 16, 16, 64, 32);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_cols,
+		 16, 16, 64, 32);
+	bg2_tilemap = tilemap_create(machine, get_bg2_tile_info, tilemap_scan_cols,
+		 16, 16, 64, 32);
+	fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_cols,
+		 16, 16, 64, 32);
+	fg2_tilemap = tilemap_create(machine, get_fg2_tile_info, tilemap_scan_cols,
+		 16, 16, 64, 32);
 
 	/* Configure tilemap transparency */
 	tilemap_set_transparent_pen(bg2_tilemap, 15);
 	tilemap_set_transparent_pen(fg_tilemap, 15);
 	tilemap_set_transparent_pen(fg2_tilemap, 15);
 
+	memset(bgscroll8, 0, 0x10);
+	memset(bg2scroll8, 0, 0x10);
+	memset(fgscroll8, 0, 0x10);
+	memset(fg2scroll8, 0, 0x10);
+
 	/* Register for save/restore */
-	state_save_register_global_array(bgscroll8);
-	state_save_register_global_array(bg2scroll8);
-	state_save_register_global_array(fgscroll8);
-	state_save_register_global_array(fg2scroll8);
-	state_save_register_global(rshark_pri);
+	state_save_register_global_array(machine, bgscroll8);
+	state_save_register_global_array(machine, bg2scroll8);
+	state_save_register_global_array(machine, fgscroll8);
+	state_save_register_global_array(machine, fg2scroll8);
+	state_save_register_global(machine, rshark_pri);
 }
 
 VIDEO_START( popbingo )
 {
 	/* Configure tilemap callbacks */
-	bg_tilerom = memory_region(REGION_GFX2);
+	bg_tilerom = memory_region(machine, "gfx2");
 	bg_gfx = 1;
 
 	/* Create tilemaps */
-	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_cols,
-		TILEMAP_TYPE_PEN, 32, 32, 32, 8);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_cols,
+		 32, 32, 32, 8);
 	bg2_tilemap = fg_tilemap = fg2_tilemap = NULL;	/* Stop scroll handler from crashing on these */
 
+	memset(bgscroll8, 0, 0x10);
+	memset(bg2scroll8, 0, 0x10);
+	memset(fgscroll8, 0, 0x10);
+	memset(fg2scroll8, 0, 0x10);
+
 	/* Register for save/restore */
-	state_save_register_global_array(bgscroll8);
-	state_save_register_global_array(bg2scroll8);	// Not used atm
-	state_save_register_global_array(fgscroll8);	// Not used atm
-	state_save_register_global_array(fg2scroll8);	// Not used atm
-	state_save_register_global(rshark_pri);
+	state_save_register_global_array(machine, bgscroll8);
+	state_save_register_global_array(machine, bg2scroll8);	// Not used atm
+	state_save_register_global_array(machine, fgscroll8);	// Not used atm
+	state_save_register_global_array(machine, fg2scroll8);	// Not used atm
+	state_save_register_global(machine, rshark_pri);
 }
 
 
 VIDEO_EOF( dooyong )
 {
-	buffer_spriteram_w(0, 0);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	buffer_spriteram_w(space, 0, 0);
 }
 
 VIDEO_EOF( rshark )
 {
-	buffer_spriteram16_w(0, 0, 0);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	buffer_spriteram16_w(space, 0, 0, 0xffff);
 }
