@@ -16,9 +16,8 @@ static UINT8 color;
 
 WRITE8_HANDLER( dotrikun_color_w )
 {
+	video_screen_update_partial(space->machine->primary_screen, video_screen_get_vpos(space->machine->primary_screen));
 	color = data;
-
-	video_screen_update_partial(0, video_screen_get_vpos(0));
 }
 
 
