@@ -30,7 +30,7 @@ PALETTE_INIT( sprtmtch )
 {
 	int i;
 
-	for (i = 0;i < machine->drv->total_colors;i++)
+	for (i = 0;i < machine->config->total_colors;i++)
 	{
 		int x =	(color_prom[i]<<8) + color_prom[0x200+i];
 		/* The bits are in reverse order! */
@@ -55,7 +55,7 @@ static int dynax_blit_scroll_y,		dynax_blit2_scroll_y;
 static int dynax_blit_wrap_enable,	dynax_blit2_wrap_enable;
 static int blit_x,blit_y,			blit2_x,blit2_y;
 static int blit_src,				blit2_src;
-static int dynax_blit_romregion,	dynax_blit2_romregion;
+static const char * dynax_blit_romregion, *dynax_blit2_romregion;
 static int dynax_blit_dest,			dynax_blit2_dest;
 static int dynax_blit_pen,			dynax_blit2_pen;
 static int dynax_blit_palbank,		dynax_blit2_palbank;
@@ -77,7 +77,7 @@ static int flipscreen;
 
 static int layer_layout;
 
-static void (*update_irq_func)(void);	// some games trigger IRQ at blitter end, some don't
+static void (*update_irq_func)(running_machine *machine);	// some games trigger IRQ at blitter end, some don't
 
 // up to 8 layers, 2 images per layer (interleaved on screen)
 static UINT8 *dynax_pixmap[8][2];
@@ -123,7 +123,7 @@ WRITE8_HANDLER( dynax_blit2_dest_w )
 }
 WRITE8_HANDLER( tenkai_blit_dest_w )
 {
-	dynax_blit_dest_w(0, BITSWAP8(data, 7,6,5,4, 0,1,2,3));
+	dynax_blit_dest_w(space, 0, BITSWAP8(data, 7,6,5,4, 0,1,2,3));
 }
 
 /* Background Color */
@@ -245,20 +245,24 @@ WRITE8_HANDLER( dynax_flipscreen_w )
 {
 	flipscreen = data & 1;
 	if (data & ~1)
-		logerror("CPU#0 PC %06X: Warning, flip screen <- %02X\n", activecpu_get_pc(), data);
+		logerror("CPU#0 PC %06X: Warning, flip screen <- %02X\n", cpu_get_pc(space->cpu), data);
 	LOG(("F=%02X ",data));
 }
 
 
+static const char *const gfxregions[] = { "gfx1", "gfx2", "gfx3", "gfx4", "gfx5", "gfx6", "gfx7", "gfx8" };
+
 WRITE8_HANDLER( dynax_blit_romregion_w )
 {
-	dynax_blit_romregion = REGION_GFX1 + data;
+	if (data < ARRAY_LENGTH(gfxregions))
+		dynax_blit_romregion = gfxregions[data];
 	LOG(("GFX%X ",data+1));
 }
 
 WRITE8_HANDLER( dynax_blit2_romregion_w )
 {
-	dynax_blit2_romregion = REGION_GFX2 + data;
+	if (data+1 < ARRAY_LENGTH(gfxregions))
+		dynax_blit2_romregion = gfxregions[data+1];
 	LOG(("GFX%X' ",data+2));
 }
 
@@ -353,12 +357,12 @@ INLINE void blitter_plot_pixel(int layer,int mask, int x, int y, int pen, int wr
 }
 
 
-static int blitter_drawgfx( int layer, int mask, int gfx, int src, int pen, int x, int y, int wrap, int flags )
+static int blitter_drawgfx( running_machine *machine, int layer, int mask, const char *gfx, int src, int pen, int x, int y, int wrap, int flags )
 {
 	UINT8 cmd;
 
-	UINT8 *ROM		=	memory_region( gfx );
-	size_t ROM_size	=	memory_region_length( gfx );
+	UINT8 *ROM		=	memory_region( machine, gfx );
+	size_t ROM_size	=	memory_region_length( machine, gfx );
 
 	int sx;
 
@@ -503,7 +507,7 @@ popmessage("GFXROM OVER %08x",src);
 
 
 
-static void dynax_blitter_start(int flags)
+static void dynax_blitter_start(running_machine *machine, int flags)
 {
 	int blit_newsrc;
 
@@ -511,6 +515,7 @@ static void dynax_blitter_start(int flags)
 
 	blit_newsrc =
 		blitter_drawgfx(
+			machine,
 			0,						// layer
 			dynax_blit_dest,		// layer mask
 			dynax_blit_romregion,	// rom region
@@ -528,11 +533,11 @@ static void dynax_blitter_start(int flags)
 	if (update_irq_func)
 	{
 		dynax_blitter_irq = 1;
-		update_irq_func();
+		update_irq_func(machine);
 	}
 }
 
-static void jantouki_blitter_start(int flags)
+static void jantouki_blitter_start(running_machine *machine, int flags)
 {
 	int blit_newsrc;
 
@@ -540,6 +545,7 @@ static void jantouki_blitter_start(int flags)
 
 	blit_newsrc =
 		blitter_drawgfx(
+			machine,
 			0,						// layer
 			dynax_blit_dest,		// layer mask
 			dynax_blit_romregion,	// rom region
@@ -557,11 +563,11 @@ static void jantouki_blitter_start(int flags)
 	if (update_irq_func)
 	{
 		dynax_blitter_irq = 1;
-		update_irq_func();
+		update_irq_func(machine);
 	}
 }
 
-static void jantouki_blitter2_start(int flags)
+static void jantouki_blitter2_start(running_machine *machine, int flags)
 {
 	int blit2_newsrc;
 
@@ -569,6 +575,7 @@ static void jantouki_blitter2_start(int flags)
 
 	blit2_newsrc =
 		blitter_drawgfx(
+			machine,
 			4,							// layer
 			dynax_blit2_dest,			// layer mask
 			dynax_blit2_romregion,		// rom region
@@ -586,7 +593,7 @@ static void jantouki_blitter2_start(int flags)
 	if (update_irq_func)
 	{
 		dynax_blitter2_irq = 1;
-		update_irq_func();
+		update_irq_func(machine);
 	}
 }
 
@@ -650,13 +657,13 @@ WRITE8_HANDLER( dynax_blitter_rev2_w )
 {
 	switch (offset)
 	{
-		case 0: dynax_blitter_start(data); break;
+		case 0: dynax_blitter_start(space->machine,data); break;
 		case 1:	blit_x		=	data; break;
 		case 2: blit_y		=	data; break;
 		case 3:	blit_src	=	(blit_src & 0xffff00) | (data << 0); break;
 		case 4: blit_src	=	(blit_src & 0xff00ff) | (data << 8); break;
 		case 5: blit_src	=	(blit_src & 0x00ffff) | (data <<16); break;
-		case 6: dynax_blit_scroll_w(0,data); break;
+		case 6: dynax_blit_scroll_w(space,0,data); break;
 	}
 }
 
@@ -665,13 +672,13 @@ WRITE8_HANDLER( tenkai_blitter_rev2_w )
 {
 	switch (offset)
 	{
-		case 0: dynax_blitter_start(data); break;
+		case 0: dynax_blitter_start(space->machine,data); break;
 		case 1:	blit_x		=	data; break;
 		case 2: blit_y		=	data; break;
 		case 3:	blit_src	=	(blit_src & 0xffff00) | (data << 0); break;
 		case 4: blit_src	=	(blit_src & 0xff00ff) | (data << 8); break;
 		case 5: blit_src	=	(blit_src & 0x00ffff) | (data <<16); break;
-		case 6: tenkai_blit_scroll_w(0,data); break;
+		case 6: tenkai_blit_scroll_w(space,0,data); break;
 	}
 }
 
@@ -680,13 +687,13 @@ WRITE8_HANDLER( jantouki_blitter_rev2_w )
 {
 	switch (offset)
 	{
-		case 0: jantouki_blitter_start(data); break;
+		case 0: jantouki_blitter_start(space->machine,data); break;
 		case 1:	blit_x		=	data; break;
 		case 2: blit_y		=	data; break;
 		case 3:	blit_src	=	(blit_src & 0xffff00) | (data << 0); break;
 		case 4: blit_src	=	(blit_src & 0xff00ff) | (data << 8); break;
 		case 5: blit_src	=	(blit_src & 0x00ffff) | (data <<16); break;
-		case 6: dynax_blit_scroll_w(0,data); break;
+		case 6: dynax_blit_scroll_w(space,0,data); break;
 	}
 }
 
@@ -694,13 +701,13 @@ WRITE8_HANDLER( jantouki_blitter2_rev2_w )
 {
 	switch (offset)
 	{
-		case 0: jantouki_blitter2_start(data); break;
+		case 0: jantouki_blitter2_start(space->machine,data); break;
 		case 1:	blit2_x		=	data; break;
 		case 2: blit2_y		=	data; break;
 		case 3:	blit2_src	=	(blit2_src & 0xffff00) | (data << 0); break;
 		case 4: blit2_src	=	(blit2_src & 0xff00ff) | (data << 8); break;
 		case 5: blit2_src	=	(blit2_src & 0x00ffff) | (data <<16); break;
-		case 6: dynax_blit2_scroll_w(0,data); break;
+		case 6: dynax_blit2_scroll_w(space,0,data); break;
 	}
 }
 
@@ -721,7 +728,7 @@ static const int priority_mjelctrn[8] = { 0x0231, 0x0321, 0x2031, 0x2301, 0x3021
 
 static void Video_Reset(void)
 {
-	dynax_blit_romregion = REGION_GFX1;		dynax_blit2_romregion = REGION_GFX1;
+	dynax_blit_romregion = "gfx1";			dynax_blit2_romregion = "gfx1";
 	dynax_blit_dest = -1;					dynax_blit2_dest = -1;
 	dynax_blit_pen = 0x7;					dynax_blit2_pen = 0x7;
 	dynax_blit_palbank = 0;					dynax_blit2_palbank = 0;
@@ -848,7 +855,7 @@ VIDEO_START( neruton )
 
 ***************************************************************************/
 
-static void hanamai_copylayer(mame_bitmap *bitmap,const rectangle *cliprect,int i)
+static void hanamai_copylayer(bitmap_t *bitmap,const rectangle *cliprect,int i)
 {
 	int color;
 	int scrollx,scrolly;
@@ -913,7 +920,7 @@ static void hanamai_copylayer(mame_bitmap *bitmap,const rectangle *cliprect,int
 }
 
 
-static void jantouki_copylayer(mame_bitmap *bitmap,const rectangle *cliprect,int i, int y)
+static void jantouki_copylayer(bitmap_t *bitmap,const rectangle *cliprect,int i, int y)
 {
 	int color,scrollx,scrolly,palettes,palbank;
 
@@ -982,7 +989,7 @@ static void jantouki_copylayer(mame_bitmap *bitmap,const rectangle *cliprect,int
 }
 
 
-static void mjdialq2_copylayer(mame_bitmap *bitmap,const rectangle *cliprect,int i)
+static void mjdialq2_copylayer(bitmap_t *bitmap,const rectangle *cliprect,int i)
 {
 	int color;
 	int scrollx,scrolly;
@@ -1072,14 +1079,14 @@ static int debug_mask(void)
     I,O        -  Change palette (-,+)
     J,K & N,M  -  Change "tile"  (-,+, slow & fast)
     R          -  move "tile" to the next 1/8th of the gfx  */
-static int debug_viewer(running_machine *machine, mame_bitmap *bitmap,const rectangle *cliprect)
+static int debug_viewer(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect)
 {
 #ifdef MAME_DEBUG
 	static int toggle;
 	if (input_code_pressed_once(KEYCODE_T))	toggle = 1-toggle;
 	if (toggle)	{
-		UINT8 *RAM	=	memory_region( REGION_GFX1 );
-		size_t size		=	memory_region_length( REGION_GFX1 );
+		UINT8 *RAM	=	memory_region( machine, "gfx1" );
+		size_t size		=	memory_region_length( machine, "gfx1" );
 		static int i = 0, c = 0, r = 0;
 
 		if (input_code_pressed_once(KEYCODE_I))	c = (c-1) & 0x1f;
@@ -1093,12 +1100,12 @@ static int debug_viewer(running_machine *machine, mame_bitmap *bitmap,const rect
 		dynax_blit_palettes = (c & 0xf) * 0x111;
 		dynax_blit_palbank  = (c >>  4) & 1;
 
-		fillbitmap(bitmap,machine->pens[0],cliprect);
+		bitmap_fill(bitmap,cliprect,0);
 		memset(dynax_pixmap[0][0],0,sizeof(UINT8)*0x100*0x100);
 		if (layer_layout != LAYOUT_MJDIALQ2)
 			memset(dynax_pixmap[0][1],0,sizeof(UINT8)*0x100*0x100);
 		for (hanamai_layer_half = 0; hanamai_layer_half < 2; hanamai_layer_half++)
-			blitter_drawgfx(0,1,REGION_GFX1,i,0,cliprect->min_x,cliprect->min_y,3,0);
+			blitter_drawgfx(machine,0,1,"gfx1",i,0,cliprect->min_x,cliprect->min_y,3,0);
 		if (layer_layout != LAYOUT_MJDIALQ2)	hanamai_copylayer(bitmap, cliprect, 0);
 		else									mjdialq2_copylayer(bitmap,cliprect, 0);
 		popmessage("%06X C%02X",i,c);
@@ -1116,13 +1123,11 @@ VIDEO_UPDATE( hanamai )
 	int layers_ctrl = ~dynax_layer_enable;
 	int lay[4];
 
-	if (debug_viewer(machine,bitmap,cliprect))	return 0;
+	if (debug_viewer(screen->machine,bitmap,cliprect))	return 0;
 	layers_ctrl &= debug_mask();
 
-	fillbitmap(
-		bitmap,
-		machine->pens[(dynax_blit_backpen & 0xff) + (dynax_blit_palbank & 1) * 256],
-		cliprect);
+	bitmap_fill(bitmap, cliprect,
+		(dynax_blit_backpen & 0xff) + (dynax_blit_palbank & 1) * 256);
 
 	/* bit 4 = display enable? */
 	if (!(hanamai_priority & 0x10)) return 0;
@@ -1152,13 +1157,11 @@ VIDEO_UPDATE( hnoridur )
 	int lay[4];
 	int pri;
 
-	if (debug_viewer(machine,bitmap,cliprect))	return 0;
+	if (debug_viewer(screen->machine,bitmap,cliprect))	return 0;
 	layers_ctrl &= debug_mask();
 
-	fillbitmap(
-		bitmap,
-		machine->pens[(dynax_blit_backpen & 0xff) + (dynax_blit_palbank & 0x0f) * 256],
-		cliprect);
+	bitmap_fill(bitmap, cliprect,
+		(dynax_blit_backpen & 0xff) + (dynax_blit_palbank & 0x0f) * 256);
 
 	pri = hanamai_priority >> 4;
 
@@ -1187,13 +1190,11 @@ VIDEO_UPDATE( sprtmtch )
 {
 	int layers_ctrl = ~dynax_layer_enable;
 
-	if (debug_viewer(machine,bitmap,cliprect))	return 0;
+	if (debug_viewer(screen->machine,bitmap,cliprect))	return 0;
 	layers_ctrl &= debug_mask();
 
-	fillbitmap(
-		bitmap,
-		machine->pens[(dynax_blit_backpen & 0xff) + (dynax_blit_palbank & 1) * 256],
-		cliprect);
+	bitmap_fill(bitmap, cliprect,
+		(dynax_blit_backpen & 0xff) + (dynax_blit_palbank & 1) * 256);
 
 	if (layers_ctrl & 1)	hanamai_copylayer( bitmap, cliprect, 0 );
 	if (layers_ctrl & 2)	hanamai_copylayer( bitmap, cliprect, 1 );
@@ -1203,25 +1204,25 @@ VIDEO_UPDATE( sprtmtch )
 
 VIDEO_UPDATE( jantouki )
 {
-
 	int layers_ctrl = dynax_layer_enable;
 
-	if (debug_viewer(machine,bitmap,cliprect))	return 0;
+	const device_config *top_screen    = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "top");
+	const device_config *bottom_screen = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "bottom");
+
+	if (debug_viewer(screen->machine,bitmap,cliprect))	return 0;
 	layers_ctrl &= debug_mask();
 
-	fillbitmap(
-		bitmap,
-		machine->pens[(dynax_blit_backpen & 0xff) + (dynax_blit_palbank & 1) * 256],
-		cliprect);
+	bitmap_fill(bitmap, cliprect,
+		(dynax_blit_backpen & 0xff) + (dynax_blit_palbank & 1) * 256);
 
-	if (screen==0)
+	if (screen == top_screen)
 	{
 	//  if (layers_ctrl & 0x01) jantouki_copylayer( bitmap, cliprect, 3, 0 );
 		if (layers_ctrl & 0x02)	jantouki_copylayer( bitmap, cliprect, 2, 0 );
 		if (layers_ctrl & 0x04)	jantouki_copylayer( bitmap, cliprect, 1, 0 );
 		if (layers_ctrl & 0x08)	jantouki_copylayer( bitmap, cliprect, 0, 0 );
 	}
-	else if (screen==1)
+	else if (screen == bottom_screen)
 	{
 		if (layers_ctrl & 0x01)	jantouki_copylayer( bitmap, cliprect, 3, 0 );
 		if (layers_ctrl & 0x10)	jantouki_copylayer( bitmap, cliprect, 7, 0 );
@@ -1237,13 +1238,11 @@ VIDEO_UPDATE( mjdialq2 )
 {
 	int layers_ctrl = ~dynax_layer_enable;
 
-	if (debug_viewer(machine,bitmap,cliprect))	return 0;
+	if (debug_viewer(screen->machine,bitmap,cliprect))	return 0;
 	layers_ctrl &= debug_mask();
 
-	fillbitmap(
-		bitmap,
-		machine->pens[(dynax_blit_backpen & 0xff) + (dynax_blit_palbank & 1) * 256],
-		cliprect);
+	bitmap_fill(bitmap, cliprect,
+		(dynax_blit_backpen & 0xff) + (dynax_blit_palbank & 1) * 256);
 
 	if (layers_ctrl & 1)	mjdialq2_copylayer( bitmap, cliprect, 0 );
 	if (layers_ctrl & 2)	mjdialq2_copylayer( bitmap, cliprect, 1 );
@@ -1252,29 +1251,26 @@ VIDEO_UPDATE( mjdialq2 )
 
 // htengoku uses the mixer chip from ddenlovr
 
-static mame_bitmap *framebuffer;
-
 VIDEO_START(htengoku)
 {
 	VIDEO_START_CALL(ddenlovr);
 	VIDEO_START_CALL(hnoridur);
-	framebuffer = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
 }
 
-VIDEO_EOF(htengoku)
+VIDEO_UPDATE(htengoku)
 {
 	int layer,x,y;
 
 	// render the layers, one by one, "dynax.c" style. Then convert the pixmaps to "ddenlovr.c"
-	// format and let VIDEO_EOF(ddenlovr) do the final compositing (priorities + palettes)
+	// format and let VIDEO_UPDATE(ddenlovr) do the final compositing (priorities + palettes)
 	for (layer = 0; layer < 4; layer++)
 	{
-		fillbitmap(framebuffer,0,&machine->screen[0].visarea);
-		hanamai_copylayer( framebuffer, &machine->screen[0].visarea, layer );
+		bitmap_fill(bitmap,cliprect,0);
+		hanamai_copylayer( bitmap, cliprect, layer );
 
 		for (y=0; y < 256; y++)
 			for (x=0; x < 512; x++)
-				ddenlovr_pixmap[3-layer][y*512+x] = (UINT8)(*BITMAP_ADDR16(framebuffer, y,x));
+				ddenlovr_pixmap[3-layer][y*512+x] = (UINT8)(*BITMAP_ADDR16(bitmap, y,x));
 	}
-	VIDEO_EOF_CALL(ddenlovr);
+	return VIDEO_UPDATE_CALL(ddenlovr);
 }
