@@ -77,7 +77,7 @@ Multi monitor notes:
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "includes/gaelco2.h"
 
 UINT16 *gaelco2_vregs;
 static UINT16 *gaelco2_videoram;
@@ -241,7 +241,7 @@ WRITE16_HANDLER( gaelco2_palette_w )
 	b = pal5bit(b);
 
 	/* update game palette */
-	palette_set_color(Machine, 4096*0 + offset, MAKE_RGB(r, g, b));
+	palette_set_color(space->machine, 4096*0 + offset, MAKE_RGB(r, g, b));
 
 	/* update shadow/highligh palettes */
 	for (i = 1; i < 16; i++){
@@ -253,7 +253,7 @@ WRITE16_HANDLER( gaelco2_palette_w )
 		auxg = ADJUST_COLOR(g + pen_color_adjust[i]);
 		auxb = ADJUST_COLOR(b + pen_color_adjust[i]);
 
-		palette_set_color(Machine, 4096*i + offset, MAKE_RGB(auxr, auxg, auxb));
+		palette_set_color(space->machine, 4096*i + offset, MAKE_RGB(auxr, auxg, auxb));
 	}
 }
 
@@ -268,8 +268,8 @@ VIDEO_START( gaelco2 )
 	gaelco2_videoram = spriteram16;
 
 	/* create tilemaps */
-	pant[0] = tilemap_create(get_tile_info_gaelco2_screen0,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-	pant[1] = tilemap_create(get_tile_info_gaelco2_screen1,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
+	pant[0] = tilemap_create(machine, get_tile_info_gaelco2_screen0,tilemap_scan_rows,16,16,64,32);
+	pant[1] = tilemap_create(machine, get_tile_info_gaelco2_screen1,tilemap_scan_rows,16,16,64,32);
 
 	/* set tilemap properties */
 	tilemap_set_transparent_pen(pant[0],0);
@@ -288,8 +288,8 @@ VIDEO_START( gaelco2_dual )
 	gaelco2_videoram = spriteram16;
 
 	/* create tilemaps */
-	pant[0] = tilemap_create(get_tile_info_gaelco2_screen0_dual,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-	pant[1] = tilemap_create(get_tile_info_gaelco2_screen1_dual,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
+	pant[0] = tilemap_create(machine, get_tile_info_gaelco2_screen0_dual,tilemap_scan_rows,16,16,64,32);
+	pant[1] = tilemap_create(machine, get_tile_info_gaelco2_screen1_dual,tilemap_scan_rows,16,16,64,32);
 
 	/* set tilemap properties */
 	tilemap_set_transparent_pen(pant[0],0);
@@ -339,17 +339,17 @@ VIDEO_START( gaelco2_dual )
 
 ***************************************************************************/
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int mask, int xoffs)
+static void draw_sprites(const device_config *screen, bitmap_t *bitmap, const rectangle *cliprect, int mask, int xoffs)
 {
 	int j, x, y, ex, ey, px, py;
-	const gfx_element *gfx = machine->gfx[0];
+	const gfx_element *gfx = screen->machine->gfx[0];
 
 	/* get sprite ram start and end offsets */
 	int start_offset = (gaelco2_vregs[1] & 0x10)*0x100;
 	int end_offset = start_offset + 0x1000;
 
 	/* sprite offset is based on the visible area */
-	int spr_x_adjust = (machine->screen[0].visarea.max_x - 320 + 1) - (511 - 320 - 1) - ((gaelco2_vregs[0] >> 4) & 0x01) + xoffs;
+	int spr_x_adjust = (video_screen_get_visible_area(screen)->max_x - 320 + 1) - (511 - 320 - 1) - ((gaelco2_vregs[0] >> 4) & 0x01) + xoffs;
 
 	for (j = start_offset; j < end_offset; j += 8){
 		int data = buffered_spriteram16[(j/2) + 0];
@@ -456,11 +456,11 @@ VIDEO_UPDATE( gaelco2 )
 	}
 
 	/* draw screen */
-	fillbitmap(bitmap, machine->pens[0], cliprect);
+	bitmap_fill(bitmap, cliprect, 0);
 
 	tilemap_draw(bitmap, cliprect, pant[1], 0, 0);
 	tilemap_draw(bitmap, cliprect, pant[0], 0, 0);
-	draw_sprites(machine, bitmap, cliprect, 0, 0);
+	draw_sprites(screen, bitmap, cliprect, 0, 0);
 	return 0;
 }
 
@@ -468,6 +468,9 @@ VIDEO_UPDATE( gaelco2_dual )
 {
 	int i;
 
+	const device_config *left_screen  = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "left");
+	const device_config *right_screen = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "right");
+
 	/* read scroll values */
 	int scroll0x = gaelco2_videoram[0x2802/2] + 0x14;
 	int scroll1x = gaelco2_videoram[0x2806/2] + 0x10;
@@ -485,19 +488,19 @@ VIDEO_UPDATE( gaelco2_dual )
 	}
 
 	/* draw screen */
-	fillbitmap(bitmap, machine->pens[0], cliprect);
+	bitmap_fill(bitmap, cliprect, 0);
 
-	if (screen==1)
+	if (screen == right_screen)
 	{
 		/* monitor 2 output */
 		tilemap_draw(bitmap,cliprect,pant[1], 0, 0);
-		draw_sprites(machine,bitmap,cliprect, 0x8000, 0);
+		draw_sprites(screen,bitmap,cliprect, 0x8000, 0);
 	}
-	else if (screen==0)
+	else if (screen == left_screen)
 	{
 		/* monitor 1 output */
 		tilemap_draw(bitmap,cliprect,pant[0], 0, 0);
-		draw_sprites(machine,bitmap,cliprect, 0x0000, 0);
+		draw_sprites(screen,bitmap,cliprect, 0x0000, 0);
 	}
 
 	return 0;
@@ -506,6 +509,8 @@ VIDEO_UPDATE( gaelco2_dual )
 
 VIDEO_EOF( gaelco2 )
 {
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
 	/* sprites are one frame ahead */
-	buffer_spriteram16_w(0, 0, 0);
+	buffer_spriteram16_w(space, 0, 0, 0xffff);
 }
