@@ -8,14 +8,13 @@
 ***********************************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "genesis.h"
 
 /* in video/segasyse.c */
 VIDEO_START( megaplay_normal );
 VIDEO_UPDATE( megaplay_normal );
 
-static int genesis_screen_number;
+static const device_config *genesis_screen;
 
 
 /******************************************************************************
@@ -49,13 +48,13 @@ static int genesis_screen_number;
     Function Prototypes
 ******************************************************************************/
 
-static int  vdp_data_r(void);
-static void vdp_data_w(int data);
-static int  vdp_control_r(void);
-static void vdp_control_w(int data);
-static void vdp_register_w(int data, int vblank);
-static void vdp_control_dma(int data);
-static void vdp_dma_68k(void);
+static int  vdp_data_r(running_machine *machine);
+static void vdp_data_w(running_machine *machine, int data);
+static int  vdp_control_r(running_machine *machine);
+static void vdp_control_w(const address_space *space, int data);
+static void vdp_register_w(running_machine *machine, int data, int vblank);
+static void vdp_control_dma(const address_space *space, int data);
+static void vdp_dma_68k(const address_space *space);
 static void vdp_dma_fill(int);
 static void vdp_dma_copy(void);
 
@@ -126,7 +125,7 @@ static UINT8		window_width;				/* window width */
 ******************************************************************************/
 
 
-static void start_genesis_vdp(int screen_number)
+static void start_genesis_vdp(const device_config *screen)
 {
 	static const UINT8 vdp_init[24] =
 	{
@@ -136,7 +135,7 @@ static void start_genesis_vdp(int screen_number)
 	};
 	int i;
 
-	genesis_screen_number = screen_number;
+	genesis_screen = screen;
 
 	/* allocate memory for the VDP, the lookup table, and the buffer bitmap */
 	vdp_vram			= auto_malloc(VRAM_SIZE);
@@ -170,46 +169,46 @@ static void start_genesis_vdp(int screen_number)
 
 	/* reset VDP */
     for (i = 0; i < 24; i++)
-        vdp_register_w(0x8000 | (i << 8) | vdp_init[i], 1);
+        vdp_register_w(screen->machine, 0x8000 | (i << 8) | vdp_init[i], 1);
 	vdp_cmdpart = 0;
 	vdp_code    = 0;
 	vdp_address = 0;
 
 	/* Save State Stuff */
-	state_save_register_global_array(genesis_vdp_regs);
-	state_save_register_global_pointer(vdp_vram, 0x10000);
-	state_save_register_global_pointer(vdp_vsram, 0x80);
-	state_save_register_global_array(genesis_bg_pal_lookup);
-	state_save_register_global_array(genesis_sp_pal_lookup);
-	state_save_register_global(display_enable);
-	state_save_register_global(vdp_scrollabase);
-	state_save_register_global(vdp_scrollbbase);
-	state_save_register_global(vdp_windowbase);
-	state_save_register_global(vdp_spritebase);
-	state_save_register_global(vdp_hscrollbase);
-	state_save_register_global(vdp_hscrollmask);
-	state_save_register_global(vdp_hscrollsize);
-	state_save_register_global(vdp_vscrollmode);
-	state_save_register_global(vdp_cmdpart);
-	state_save_register_global(vdp_code);
-	state_save_register_global(vdp_address);
-	state_save_register_global(vdp_dmafill);
-	state_save_register_global(scrollheight);
-	state_save_register_global(scrollwidth);
-	state_save_register_global(bgcol);
-	state_save_register_global(window_down);
-	state_save_register_global(window_vpos);
+	state_save_register_global_array(screen->machine, genesis_vdp_regs);
+	state_save_register_global_pointer(screen->machine, vdp_vram, 0x10000);
+	state_save_register_global_pointer(screen->machine, vdp_vsram, 0x80);
+	state_save_register_global_array(screen->machine, genesis_bg_pal_lookup);
+	state_save_register_global_array(screen->machine, genesis_sp_pal_lookup);
+	state_save_register_global(screen->machine, display_enable);
+	state_save_register_global(screen->machine, vdp_scrollabase);
+	state_save_register_global(screen->machine, vdp_scrollbbase);
+	state_save_register_global(screen->machine, vdp_windowbase);
+	state_save_register_global(screen->machine, vdp_spritebase);
+	state_save_register_global(screen->machine, vdp_hscrollbase);
+	state_save_register_global(screen->machine, vdp_hscrollmask);
+	state_save_register_global(screen->machine, vdp_hscrollsize);
+	state_save_register_global(screen->machine, vdp_vscrollmode);
+	state_save_register_global(screen->machine, vdp_cmdpart);
+	state_save_register_global(screen->machine, vdp_code);
+	state_save_register_global(screen->machine, vdp_address);
+	state_save_register_global(screen->machine, vdp_dmafill);
+	state_save_register_global(screen->machine, scrollheight);
+	state_save_register_global(screen->machine, scrollwidth);
+	state_save_register_global(screen->machine, bgcol);
+	state_save_register_global(screen->machine, window_down);
+	state_save_register_global(screen->machine, window_vpos);
 }
 
 VIDEO_START(genesis)
 {
-	start_genesis_vdp(0);
+	start_genesis_vdp(machine->primary_screen);
 }
 
 
 VIDEO_START( segac2 )
 {
-	start_genesis_vdp(0);
+	start_genesis_vdp(machine->primary_screen);
 
 	/* C2 has separate sprite/background palettes */
 	genesis_sp_pal_lookup[0] = 0x100;
@@ -223,9 +222,9 @@ VIDEO_START( segac2 )
 
 
 
-void start_system18_vdp(void)
+void system18_vdp_start(running_machine *machine)
 {
-	start_genesis_vdp(0);
+	start_genesis_vdp(machine->primary_screen);
 
 	genesis_palette_base = 0x1800;
 	genesis_bg_pal_lookup[0] = genesis_sp_pal_lookup[0] = 0x1800;
@@ -250,10 +249,9 @@ void start_system18_vdp(void)
 ******************************************************************************/
 
 /* set the display enable bit */
-void segac2_enable_display(int enable)
+void segac2_enable_display(running_machine *machine, int enable)
 {
-	if (!video_screen_get_vblank(0))
-		video_screen_update_partial(0, video_screen_get_vpos(0));
+	video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
 	display_enable = enable;
 }
 
@@ -271,7 +269,7 @@ VIDEO_UPDATE( genesis )
 VIDEO_UPDATE( segac2 )
 {
 	if (!display_enable)
-		fillbitmap(bitmap, get_black_pen(machine), cliprect);
+		bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
 	else
 		VIDEO_UPDATE_CALL(genesis);
 	return 0;
@@ -296,7 +294,7 @@ VIDEO_UPDATE( megaplay )
 	return 0;
 }
 
-void update_system18_vdp( mame_bitmap *bitmap, const rectangle *cliprect )
+void system18_vdp_update( bitmap_t *bitmap, const rectangle *cliprect )
 {
 	int y;
 
@@ -337,19 +335,19 @@ READ16_HANDLER( genesis_vdp_r )
 	{
 		case 0x00:	/* Read Data */
 		case 0x01:
-			return vdp_data_r();
+			return vdp_data_r(space->machine);
 
 		case 0x02:	/* Status Register */
 		case 0x03:
-			return vdp_control_r();
+			return vdp_control_r(space->machine);
 
 		case 0x04:	/* HV counter */
 		case 0x05:
 		case 0x06:
 		case 0x07:
 		{
-			int xpos = video_screen_get_hpos(0);
-			int ypos = video_screen_get_vpos(0);
+			int xpos = video_screen_get_hpos(genesis_screen);
+			int ypos = video_screen_get_vpos(genesis_screen);
 
 			/* adjust for the weird counting rules */
 			if (xpos > 0xe9) xpos -= (342 - 0x100);
@@ -371,36 +369,36 @@ WRITE16_HANDLER( genesis_vdp_w )
 	{
 		case 0x00:	/* Write data */
 		case 0x01:
-			if (mem_mask)
+			if (mem_mask != 0xffff)
 			{
-				data &= ~mem_mask;
-				 if (ACCESSING_MSB)
+				data &= mem_mask;
+				 if (ACCESSING_BITS_8_15)
 				 	data |= data >> 8;
 				 else
 				 	data |= data << 8;
 			}
-			vdp_data_w(data);
+			vdp_data_w(space->machine, data);
 			break;
 
 		case 0x02:	/* Control Write */
 		case 0x03:
-			if (mem_mask)
+			if (mem_mask != 0xffff)
 			{
-				data &= ~mem_mask;
-				 if (ACCESSING_MSB)
+				data &= mem_mask;
+				 if (ACCESSING_BITS_8_15)
 				 	data |= data >> 8;
 				 else
 				 	data |= data << 8;
 			}
-			vdp_control_w(data);
+			vdp_control_w(space, data);
 			break;
 
 		case 0x08:	/* SN76489 Write */
 		case 0x09:
 		case 0x0a:
 		case 0x0b:
-			if (ACCESSING_LSB && sndti_exists(SOUND_SN76496, 0))
-				SN76496_0_w(0, data & 0xff);
+			if (ACCESSING_BITS_0_7 && sndti_exists(SOUND_SN76496, 0))
+				sn76496_0_w(space, 0, data & 0xff);
 			break;
 	}
 }
@@ -420,7 +418,7 @@ WRITE16_HANDLER( genesis_vdp_w )
 ******************************************************************************/
 
 /* Games needing Read to Work .. bloxeed (attract) .. puyo puyo .. probably more */
-static int vdp_data_r(void)
+static int vdp_data_r(running_machine *machine)
 {
 	int read = 0;
 
@@ -439,7 +437,7 @@ static int vdp_data_r(void)
 			break;
 
 		default:		/* Illegal read attempt */
-			logerror("%06x: VDP illegal read type %02x\n", activecpu_get_previouspc(), vdp_code);
+			logerror("%s: VDP illegal read type %02x\n", cpuexec_describe_context(machine), vdp_code);
 			read = 0x00;
 			break;
 	}
@@ -450,7 +448,7 @@ static int vdp_data_r(void)
 }
 
 
-static void vdp_data_w(int data)
+static void vdp_data_w(running_machine *machine, int data)
 {
 	/* kill 2nd write pending flag */
 	vdp_cmdpart = 0;
@@ -468,11 +466,10 @@ static void vdp_data_w(int data)
 	{
 		case 0x01:		/* VRAM write */
 
-			/* if the hscroll RAM is changing during screen refresh, force an update */
-			if (!video_screen_get_vblank(0) &&
-				vdp_address >= vdp_hscrollbase &&
+			/* if the hscroll RAM is changing, force an update */
+			if (vdp_address >= vdp_hscrollbase &&
 				vdp_address < vdp_hscrollbase + vdp_hscrollsize)
-				video_screen_update_partial(0, video_screen_get_vpos(0));
+				video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
 
 			/* write to VRAM */
 			if (vdp_address & 1)
@@ -484,15 +481,14 @@ static void vdp_data_w(int data)
 		case 0x03:		/* Palette write */
 			{
 				int offset = (vdp_address/2) % CRAM_SIZE;
-				palette_set_color_rgb(Machine, offset + genesis_palette_base, pal3bit(data >> 1), pal3bit(data >> 5), pal3bit(data >> 9));
+				palette_set_color_rgb(machine, offset + genesis_palette_base, pal3bit(data >> 1), pal3bit(data >> 5), pal3bit(data >> 9));
 			}
 			break;
 
 		case 0x05:		/* VSRAM write */
 
-			/* if the vscroll RAM is changing during screen refresh, force an update */
-			if (!video_screen_get_vblank(0))
-				video_screen_update_partial(0, video_screen_get_vpos(0));
+			/* vscroll RAM is changing, force an update */
+			video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
 
 			/* write to VSRAM */
 			if (vdp_address & 1)
@@ -502,7 +498,7 @@ static void vdp_data_w(int data)
 			break;
 
 		default:		/* Illegal write attempt */
-			logerror("PC:%06x: VDP illegal write type %02x data %04x\n", activecpu_get_previouspc(), vdp_code, data);
+			logerror("%s: VDP illegal write type %02x data %04x\n", cpuexec_describe_context(machine), vdp_code, data);
 			break;
 	}
 
@@ -546,7 +542,7 @@ static void vdp_data_w(int data)
 
 ******************************************************************************/
 
-static int vdp_control_r(void)
+static int vdp_control_r(running_machine *machine)
 {
 	int status = 0x3600; // wwally needs fifo empty set
 
@@ -554,25 +550,25 @@ static int vdp_control_r(void)
 	vdp_cmdpart = 0;
 
 	/* set the VBLANK bit */
-	if (video_screen_get_vblank(0))
+	if (video_screen_get_vblank(machine->primary_screen))
 		status |= 0x0008;
 
 	/* set the HBLANK bit */
-	if (video_screen_get_hblank(0))
+	if (video_screen_get_hblank(machine->primary_screen))
 		status |= 0x0004;
 
 	return (status);
 }
 
 
-static void vdp_control_w(int data)
+static void vdp_control_w(const address_space *space, int data)
 {
 	/* case 1: we're not expecting the 2nd half of a command */
 	if (!vdp_cmdpart)
 	{
 		/* if 10xxxxxx xxxxxxxx this is a register setting command */
 		if ((data & 0xc000) == 0x8000)
-			vdp_register_w(data, video_screen_get_vblank(0));
+			vdp_register_w(space->machine, data, video_screen_get_vblank(space->machine->primary_screen));
 
 		/* otherwise this is the First part of a mode setting command */
 		else
@@ -589,12 +585,12 @@ static void vdp_control_w(int data)
 		vdp_code    = (vdp_code & 0x03) | ((data >> 2) & 0x3c);
 		vdp_address = (vdp_address & 0x3fff) | ((data << 14) & 0xc000);
 		vdp_cmdpart = 0;
-		vdp_control_dma(data);
+		vdp_control_dma(space, data);
 	}
 }
 
 
-static void vdp_register_w(int data, int vblank)
+static void vdp_register_w(running_machine *machine, int data, int vblank)
 {
 	int scrwidth = 0;
 	static const UINT8 is_important[32] = { 0,0,1,1,1,1,0,1,0,0,0,1,0,1,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0 };
@@ -604,10 +600,9 @@ static void vdp_register_w(int data, int vblank)
 
 	genesis_vdp_regs[regnum] = regdat;
 
-	/* these are mostly important writes; force an update if they */
-	/* are written during a screen refresh */
-	if (!vblank && is_important[regnum])
-		video_screen_update_partial(0, video_screen_get_vpos(0));
+	/* these are mostly important writes; force an update if they written */
+	if (is_important[regnum])
+		video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
 
 	/* For quite a few of the registers its a good idea to set a couple of variable based
        upon the writes here */
@@ -670,12 +665,13 @@ static void vdp_register_w(int data, int vblank)
 				break;
 			}
 			{
-				screen_state *state = &Machine->screen[genesis_screen_number];
-				rectangle visarea = state->visarea;
+				int height = video_screen_get_height(genesis_screen);
+				rectangle visarea = *video_screen_get_visible_area(genesis_screen);
+				attoseconds_t refresh = video_screen_get_frame_period(genesis_screen).attoseconds;
 
 				/* this gets called from the init! */
 				visarea.max_x = scrwidth*8-1;
-				video_screen_configure(genesis_screen_number, scrwidth*8, state->height, &visarea, state->refresh);
+				video_screen_configure(genesis_screen, scrwidth*8, height, &visarea, refresh);
 			}
 			break;
 
@@ -704,7 +700,7 @@ static void vdp_register_w(int data, int vblank)
 }
 
 
-static void vdp_control_dma(int data)
+static void vdp_control_dma(const address_space *space, int data)
 {
 	if ((vdp_code & 0x20) && (genesis_vdp_regs[1] & 0x10))
 	{
@@ -712,7 +708,7 @@ static void vdp_control_dma(int data)
 		{
 			case 0x00:
 			case 0x40:		/* 68k -> VRAM Tranfser */
-				vdp_dma_68k();
+				vdp_dma_68k(space);
 				break;
 
 			case 0x80:		/* VRAM fill, can't be done here, requires data write */
@@ -736,7 +732,7 @@ static void vdp_control_dma(int data)
 
 ******************************************************************************/
 
-static void vdp_dma_68k(void)
+static void vdp_dma_68k(const address_space *space)
 {
 	int length = genesis_vdp_regs[19] | (genesis_vdp_regs[20] << 8);
 	int source = (genesis_vdp_regs[21] << 1) | (genesis_vdp_regs[22] << 9) | ((genesis_vdp_regs[23] & 0x7f) << 17);
@@ -749,7 +745,7 @@ static void vdp_dma_68k(void)
 	/* handle the DMA */
 	for (count = 0; count < length; count++)
 	{
-		vdp_data_w(program_read_word(source));
+		vdp_data_w(space->machine, memory_read_word(space, source));
 		source += 2;
 	}
 }
