@@ -1,5 +1,4 @@
 #include "driver.h"
-#include "deprecat.h"
 #include "cpu/sharc/sharc.h"
 #include "machine/konppc.h"
 #include "video/poly.h"
@@ -21,14 +20,12 @@ struct _poly_extra_data
 // defined in drivers/nwk-tr.c
 int K001604_vh_start(running_machine *machine, int chip);
 void K001604_tile_update(running_machine *machine, int chip);
-void K001604_draw_front_layer(int chip, mame_bitmap *bitmap, const rectangle *cliprect);
-void K001604_draw_back_layer(int chip, mame_bitmap *bitmap, const rectangle *cliprect);
+void K001604_draw_front_layer(int chip, bitmap_t *bitmap, const rectangle *cliprect);
+void K001604_draw_back_layer(int chip, bitmap_t *bitmap, const rectangle *cliprect);
 
 extern UINT8 gticlub_led_reg0;
 extern UINT8 gticlub_led_reg1;
 
-static poly_manager *poly;
-
 
 
 /*****************************************************************************/
@@ -36,14 +33,30 @@ static poly_manager *poly;
 
 #define MAX_K001006_CHIPS		2
 
-static UINT16 K001006_pal_ram[MAX_K001006_CHIPS][0x800];
-static UINT16 K001006_unknown_ram[MAX_K001006_CHIPS][0x1000];
+static UINT16 *K001006_pal_ram[MAX_K001006_CHIPS];
+static UINT16 *K001006_unknown_ram[MAX_K001006_CHIPS];
 static UINT32 K001006_addr[MAX_K001006_CHIPS] = { 0, 0 };
 static int K001006_device_sel[MAX_K001006_CHIPS] = { 0, 0 };
 
-static UINT32 K001006_palette[MAX_K001006_CHIPS][0x800];
+static UINT32 *K001006_palette[MAX_K001006_CHIPS];
 
-static UINT32 K001006_r(int chip, int offset, UINT32 mem_mask)
+void K001006_init(running_machine *machine)
+{
+	int i;
+	for (i=0; i<MAX_K001006_CHIPS; i++)
+	{
+		K001006_pal_ram[i] = auto_malloc(0x800*sizeof(UINT16));
+		memset(K001006_pal_ram[i], 0, 0x800*sizeof(UINT16));
+		K001006_unknown_ram[i] = auto_malloc(0x1000*sizeof(UINT16));
+		memset(K001006_unknown_ram[i], 0, 0x1000*sizeof(UINT16));
+		K001006_addr[i] = 0;
+		K001006_device_sel[i] = 0;
+		K001006_palette[i] = auto_malloc(0x800*sizeof(UINT32));
+		memset(K001006_palette[i], 0, 0x800*sizeof(UINT32));
+	}
+}
+
+static UINT32 K001006_r(running_machine *machine, int chip, int offset, UINT32 mem_mask)
 {
 	if (offset == 1)
 	{
@@ -51,7 +64,7 @@ static UINT32 K001006_r(int chip, int offset, UINT32 mem_mask)
 		{
 			case 0x0b:		// CG Board ROM read
 			{
-				UINT16 *rom = (UINT16*)memory_region(REGION_GFX1);
+				UINT16 *rom = (UINT16*)memory_region(machine, "gfx1");
 				return rom[K001006_addr[chip] / 2] << 16;
 			}
 			case 0x0d:		// Palette RAM read
@@ -117,7 +130,7 @@ static void K001006_w(int chip, int offset, UINT32 data, UINT32 mem_mask)
 	}
 	else if (offset == 2)
 	{
-		if (!(mem_mask & 0xffff0000))
+		if (ACCESSING_BITS_16_31)
 		{
 			K001006_device_sel[chip] = (data >> 16) & 0xf;
 		}
@@ -126,7 +139,7 @@ static void K001006_w(int chip, int offset, UINT32 data, UINT32 mem_mask)
 
 READ32_HANDLER(K001006_0_r)
 {
-	return K001006_r(0, offset, mem_mask);
+	return K001006_r(space->machine, 0, offset, mem_mask);
 }
 
 WRITE32_HANDLER(K001006_0_w)
@@ -136,7 +149,7 @@ WRITE32_HANDLER(K001006_0_w)
 
 READ32_HANDLER(K001006_1_r)
 {
-	return K001006_r(1, offset, mem_mask);
+	return K001006_r(space->machine, 1, offset, mem_mask);
 }
 
 WRITE32_HANDLER(K001006_1_w)
@@ -155,11 +168,11 @@ static const int decode_x_zr107[8] = {  0, 16, 1, 17, 2, 18, 3, 19 };
 static const int decode_y_zr107[16] = {  0, 8, 32, 40, 4, 12, 36, 44, 64, 72, 96, 104, 68, 76, 100, 108 };
 
 static UINT32 K001005_status = 0;
-static mame_bitmap *K001005_bitmap[2];
-static mame_bitmap *K001005_zbuffer;
+static bitmap_t *K001005_bitmap[2];
+static bitmap_t *K001005_zbuffer;
 static rectangle K001005_cliprect;
 
-static void render_polygons(void);
+static void render_polygons(running_machine *machine);
 
 static UINT8 *K001005_texture;
 
@@ -176,15 +189,32 @@ static int tex_mirror_table[4][128];
 
 static int K001005_bitmap_page = 0;
 
-void K001005_swap_buffers(void);
+static poly_manager *poly;
+static poly_vertex prev_v[4];
+static int prev_poly_type;
 
-void K001005_init(void)
+static UINT8 *gfxrom;
+
+
+void K001005_swap_buffers(running_machine *machine);
+
+static void K001005_exit(running_machine *machine)
+{
+	poly_free(poly);
+}
+
+void K001005_init(running_machine *machine)
 {
 	int i;
-	K001005_bitmap[0] = auto_bitmap_alloc(Machine->screen[0].width, Machine->screen[0].height, Machine->screen[0].format);
-	K001005_bitmap[1] = auto_bitmap_alloc(Machine->screen[0].width, Machine->screen[0].height, Machine->screen[0].format);
 
-	K001005_zbuffer = auto_bitmap_alloc(Machine->screen[0].width, Machine->screen[0].height, BITMAP_FORMAT_INDEXED32);
+	int width = video_screen_get_width(machine->primary_screen);
+	int height = video_screen_get_height(machine->primary_screen);
+	K001005_zbuffer = auto_bitmap_alloc(width, height, BITMAP_FORMAT_INDEXED32);
+
+	gfxrom = memory_region(machine, "gfx1");
+
+	K001005_bitmap[0] = video_screen_auto_bitmap_alloc(machine->primary_screen);
+	K001005_bitmap[1] = video_screen_auto_bitmap_alloc(machine->primary_screen);
 
 	K001005_texture = auto_malloc(0x800000);
 
@@ -195,6 +225,9 @@ void K001005_init(void)
 
 	K001005_3d_fifo = auto_malloc(0x10000 * sizeof(UINT32));
 
+	poly = poly_alloc(machine, 4000, sizeof(poly_extra_data), POLYFLAG_ALLOW_QUADS);
+	add_exit_callback(machine, K001005_exit);
+
 	for (i=0; i < 128; i++)
 	{
 		tex_mirror_table[0][i] = i & 0x3f;
@@ -202,6 +235,16 @@ void K001005_init(void)
 		tex_mirror_table[2][i] = ((i & 0x3f) >= 0x20) ? (0x1f - (i & 0x1f)) : i & 0x1f;
 		tex_mirror_table[3][i] = ((i & 0x7f) >= 0x40) ? (0x3f - (i & 0x3f)) : i & 0x3f;
 	}
+
+	K001005_status = 0;
+	K001005_ram_ptr = 0;
+	K001005_fifo_read_ptr = 0;
+	K001005_fifo_write_ptr = 0;
+	K001005_3d_fifo_ptr = 0;
+	K001005_bitmap_page = 0;
+
+	memset(prev_v, 0, sizeof(prev_v));
+	prev_poly_type = 0;
 }
 
 // rearranges the texture data to a more practical order
@@ -276,25 +319,19 @@ READ32_HANDLER( K001005_r )
 			{
 				if (K001005_fifo_read_ptr < 0x3ff)
 				{
-					//cpunum_set_input_line(Machine, 2, SHARC_INPUT_FLAG1, CLEAR_LINE);
-					cpuintrf_push_context(2);
-					sharc_set_flag_input(1, CLEAR_LINE);
-					cpuintrf_pop_context();
+					//cpu_set_input_line(space->machine->cpu[2], SHARC_INPUT_FLAG1, CLEAR_LINE);
+					sharc_set_flag_input(space->machine->cpu[2], 1, CLEAR_LINE);
 				}
 				else
 				{
-					//cpunum_set_input_line(Machine, 2, SHARC_INPUT_FLAG1, ASSERT_LINE);
-					cpuintrf_push_context(2);
-					sharc_set_flag_input(1, ASSERT_LINE);
-					cpuintrf_pop_context();
+					//cpu_set_input_line(space->machine->cpu[2], SHARC_INPUT_FLAG1, ASSERT_LINE);
+					sharc_set_flag_input(space->machine->cpu[2], 1, ASSERT_LINE);
 				}
 			}
 			else
 			{
-				//cpunum_set_input_line(Machine, 2, SHARC_INPUT_FLAG1, ASSERT_LINE);
-				cpuintrf_push_context(2);
-				sharc_set_flag_input(1, ASSERT_LINE);
-				cpuintrf_pop_context();
+				//cpu_set_input_line(space->machine->cpu[2], SHARC_INPUT_FLAG1, ASSERT_LINE);
+				sharc_set_flag_input(space->machine->cpu[2], 1, ASSERT_LINE);
 			}
 
 			K001005_fifo_read_ptr++;
@@ -319,7 +356,7 @@ READ32_HANDLER( K001005_r )
 			}
 
 		default:
-			mame_printf_debug("K001005_r: %08X, %08X at %08X\n", offset, mem_mask, activecpu_get_pc());
+			mame_printf_debug("K001005_r: %08X, %08X at %08X\n", offset, mem_mask, cpu_get_pc(space->cpu));
 			break;
 	}
 	return 0;
@@ -335,28 +372,22 @@ WRITE32_HANDLER( K001005_w )
 			{
 				if (K001005_fifo_write_ptr < 0x400)
 				{
-					//cpunum_set_input_line(Machine, 2, SHARC_INPUT_FLAG1, ASSERT_LINE);
-					cpuintrf_push_context(2);
-					sharc_set_flag_input(1, ASSERT_LINE);
-					cpuintrf_pop_context();
+					//cpu_set_input_line(space->machine->cpu[2], SHARC_INPUT_FLAG1, ASSERT_LINE);
+					sharc_set_flag_input(space->machine->cpu[2], 1, ASSERT_LINE);
 				}
 				else
 				{
-					//cpunum_set_input_line(Machine, 2, SHARC_INPUT_FLAG1, CLEAR_LINE);
-					cpuintrf_push_context(2);
-					sharc_set_flag_input(1, CLEAR_LINE);
-					cpuintrf_pop_context();
+					//cpu_set_input_line(space->machine->cpu[2], SHARC_INPUT_FLAG1, CLEAR_LINE);
+					sharc_set_flag_input(space->machine->cpu[2], 1, CLEAR_LINE);
 				}
 			}
 			else
 			{
-				//cpunum_set_input_line(Machine, 2, SHARC_INPUT_FLAG1, ASSERT_LINE);
-				cpuintrf_push_context(2);
-				sharc_set_flag_input(1, ASSERT_LINE);
-				cpuintrf_pop_context();
+				//cpu_set_input_line(space->machine->cpu[2], SHARC_INPUT_FLAG1, ASSERT_LINE);
+				sharc_set_flag_input(space->machine->cpu[2], 1, ASSERT_LINE);
 			}
 
-	    //  mame_printf_debug("K001005 FIFO write: %08X at %08X\n", data, activecpu_get_pc());
+	    //  mame_printf_debug("K001005 FIFO write: %08X at %08X\n", data, cpu_get_pc(space->cpu));
 			K001005_fifo[K001005_fifo_write_ptr] = data;
 			K001005_fifo_write_ptr++;
 			K001005_fifo_write_ptr &= 0x7ff;
@@ -364,16 +395,16 @@ WRITE32_HANDLER( K001005_w )
 			K001005_3d_fifo[K001005_3d_fifo_ptr++] = data;
 
 			// !!! HACK to get past the FIFO B test (GTI Club & Thunder Hurricane) !!!
-			if (activecpu_get_pc() == 0x201ee)
+			if (cpu_get_pc(space->cpu) == 0x201ee)
 			{
 				// This is used to make the SHARC timeout
-				cpu_spinuntil_trigger(10000);
+				cpu_spinuntil_trigger(space->cpu, 10000);
 			}
 			// !!! HACK to get past the FIFO B test (Winding Heat & Midnight Run) !!!
-			if (activecpu_get_pc() == 0x201e6)
+			if (cpu_get_pc(space->cpu) == 0x201e6)
 			{
 				// This is used to make the SHARC timeout
-				cpu_spinuntil_trigger(10000);
+				cpu_spinuntil_trigger(space->cpu, 10000);
 			}
 
 			break;
@@ -392,8 +423,8 @@ WRITE32_HANDLER( K001005_w )
 
 			if (data == 2 && K001005_3d_fifo_ptr > 0)
 			{
-				K001005_swap_buffers();
-				render_polygons();
+				K001005_swap_buffers(space->machine);
+				render_polygons(space->machine);
 				poly_wait(poly, "render_polygons");
 				K001005_3d_fifo_ptr = 0;
 			}
@@ -420,7 +451,7 @@ WRITE32_HANDLER( K001005_w )
 			break;
 
 		default:
-			//mame_printf_debug("K001005_w: %08X, %08X, %08X at %08X\n", data, offset, mem_mask, activecpu_get_pc());
+			//mame_printf_debug("K001005_w: %08X, %08X, %08X at %08X\n", data, offset, mem_mask, cpu_get_pc(space->cpu));
 			break;
 	}
 
@@ -429,7 +460,7 @@ WRITE32_HANDLER( K001005_w )
 static void draw_scanline(void *dest, INT32 scanline, const poly_extent *extent, const void *extradata, int threadid)
 {
 	const poly_extra_data *extra = extradata;
-	mame_bitmap *destmap = dest;
+	bitmap_t *destmap = dest;
 	float z = extent->param[0].start;
 	float dz = extent->param[0].dpdx;
 	UINT32 *fb = BITMAP_ADDR32(destmap, scanline, 0);
@@ -457,8 +488,8 @@ static void draw_scanline(void *dest, INT32 scanline, const poly_extent *extent,
 static void draw_scanline_tex(void *dest, INT32 scanline, const poly_extent *extent, const void *extradata, int threadid)
 {
 	const poly_extra_data *extra = extradata;
-	mame_bitmap *destmap = dest;
-	UINT8 *texrom = memory_region(REGION_GFX1) + (extra->texture_page * 0x40000);
+	bitmap_t *destmap = dest;
+	UINT8 *texrom = gfxrom + (extra->texture_page * 0x40000);
 	int pal_chip = (extra->texture_palette & 0x8) ? 1 : 0;
 	int palette_index = (extra->texture_palette & 0x7) * 256;
 	float z = extent->param[0].start;
@@ -513,12 +544,10 @@ static void draw_scanline_tex(void *dest, INT32 scanline, const poly_extent *ext
 	}
 }
 
-static poly_vertex prev_v[4];
-static int prev_poly_type;
-
-static void render_polygons(void)
+static void render_polygons(running_machine *machine)
 {
 	int i, j;
+	const rectangle *visarea = video_screen_get_visible_area(machine->primary_screen);
 
 //  mame_printf_debug("K001005_fifo_ptr = %08X\n", K001005_3d_fifo_ptr);
 
@@ -559,9 +588,9 @@ static void render_polygons(void)
 			++index;
 
 			extra->color = color;
-			poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline, 1, &v[0], &v[1], &v[2]);
-			poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline, 1, &v[0], &v[2], &v[3]);
-//          poly_render_polygon(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline, 1, 4, v);
+			poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline, 1, &v[0], &v[1], &v[2]);
+			poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline, 1, &v[0], &v[2], &v[3]);
+//          poly_render_polygon(poly, K001005_bitmap[K001005_bitmap_page],  visarea, draw_scanline, 1, 4, v);
 
 			i = index - 1;
 		}
@@ -666,13 +695,13 @@ static void render_polygons(void)
 
 			if (num_verts < 3)
 			{
-				poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline_tex, 4, &prev_v[2], &v[0], &v[1]);
+				poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline_tex, 4, &prev_v[2], &v[0], &v[1]);
 				if (prev_poly_type)
-					poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline_tex, 4, &prev_v[2], &prev_v[3], &v[0]);
+					poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline_tex, 4, &prev_v[2], &prev_v[3], &v[0]);
 //              if (prev_poly_type)
-//                  poly_render_quad(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline_tex, 4, &prev_v[2], &prev_v[3], &v[0], &v[1]);
+//                  poly_render_quad(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline_tex, 4, &prev_v[2], &prev_v[3], &v[0], &v[1]);
 //              else
-//                  poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline_tex, 4, &prev_v[2], &v[0], &v[1]);
+//                  poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline_tex, 4, &prev_v[2], &v[0], &v[1]);
 
 				memcpy(&prev_v[0], &prev_v[2], sizeof(poly_vertex));
 				memcpy(&prev_v[1], &prev_v[3], sizeof(poly_vertex));
@@ -681,10 +710,10 @@ static void render_polygons(void)
 			}
 			else
 			{
-				poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline_tex, 4, &v[0], &v[1], &v[2]);
+				poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline_tex, 4, &v[0], &v[1], &v[2]);
 				if (num_verts > 3)
-					poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline_tex, 4, &v[2], &v[3], &v[0]);
-//              poly_render_polygon(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline_tex, 4, num_verts, v);
+					poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline_tex, 4, &v[2], &v[3], &v[0]);
+//              poly_render_polygon(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline_tex, 4, num_verts, v);
 
 				memcpy(prev_v, v, sizeof(poly_vertex) * 4);
 			}
@@ -765,10 +794,10 @@ static void render_polygons(void)
 
 				extra->color = color;
 
-				poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline_tex, 4, &v[0], &v[1], &v[2]);
+				poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline_tex, 4, &v[0], &v[1], &v[2]);
 				if (new_verts > 1)
-					poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline_tex, 4, &v[2], &v[3], &v[0]);
-//              poly_render_polygon(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline_tex, 4, new_verts + 2, v);
+					poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline_tex, 4, &v[2], &v[3], &v[0]);
+//              poly_render_polygon(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline_tex, 4, new_verts + 2, v);
 
 				memcpy(prev_v, v, sizeof(poly_vertex) * 4);
 			};
@@ -824,10 +853,10 @@ static void render_polygons(void)
 
 			extra->color = color;
 
-			poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline, 1, &v[0], &v[1], &v[2]);
+			poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline, 1, &v[0], &v[1], &v[2]);
 			if (num_verts > 3)
-				poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline, 1, &v[2], &v[3], &v[0]);
-//          poly_render_polygon(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline, 1, num_verts, v);
+				poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline, 1, &v[2], &v[3], &v[0]);
+//          poly_render_polygon(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline, 1, num_verts, v);
 
 			memcpy(prev_v, v, sizeof(poly_vertex) * 4);
 
@@ -883,10 +912,10 @@ static void render_polygons(void)
 
 				extra->color = color;
 
-				poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline, 1, &v[0], &v[1], &v[2]);
+				poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline, 1, &v[0], &v[1], &v[2]);
 				if (new_verts > 1)
-					poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline, 1, &v[0], &v[2], &v[3]);
-//              poly_render_polygon(poly, K001005_bitmap[K001005_bitmap_page], &Machine->screen[0].visarea, draw_scanline, 1, new_verts + 2, v);
+					poly_render_triangle(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline, 1, &v[0], &v[2], &v[3]);
+//              poly_render_polygon(poly, K001005_bitmap[K001005_bitmap_page], visarea, draw_scanline, 1, new_verts + 2, v);
 
 				memcpy(prev_v, v, sizeof(poly_vertex) * 4);
 			};
@@ -911,7 +940,7 @@ static void render_polygons(void)
 	}
 }
 
-void K001005_draw(mame_bitmap *bitmap, const rectangle *cliprect)
+void K001005_draw(bitmap_t *bitmap, const rectangle *cliprect)
 {
 	int i, j;
 
@@ -932,40 +961,35 @@ void K001005_draw(mame_bitmap *bitmap, const rectangle *cliprect)
 	}
 }
 
-void K001005_swap_buffers(void)
+void K001005_swap_buffers(running_machine *machine)
 {
 	K001005_bitmap_page ^= 1;
 
 	//if (K001005_status == 2)
 	{
-		fillbitmap(K001005_bitmap[K001005_bitmap_page], Machine->remapped_colortable[0], &K001005_cliprect);
-		fillbitmap(K001005_zbuffer, 0xffffffff, &K001005_cliprect);
+		bitmap_fill(K001005_bitmap[K001005_bitmap_page], &K001005_cliprect, machine->pens[0]);
+		bitmap_fill(K001005_zbuffer, &K001005_cliprect, 0xffffffff);
 	}
 }
 
-
-
-static void gticlub_exit(running_machine *machine)
-{
-	poly_free(poly);
-}
-
-VIDEO_START( gticlub )
-{
-	poly = poly_alloc(4000, sizeof(poly_extra_data), POLYFLAG_ALLOW_QUADS);
-	add_exit_callback(machine, gticlub_exit);
-
-	K001005_init();
-	K001604_vh_start(machine, 0);
-}
-
 static int tick = 0;
 static int debug_tex_page = 0;
 static int debug_tex_palette = 0;
 
+VIDEO_START( gticlub )
+{
+	tick = 0;
+	debug_tex_page = 0;
+	debug_tex_palette = 0;
+
+	K001006_init(machine);
+	K001005_init(machine);
+	K001604_vh_start(machine, 0);
+}
+
 VIDEO_UPDATE( gticlub )
 {
-	K001604_tile_update(machine, 0);
+	K001604_tile_update(screen->machine, 0);
 	K001604_draw_back_layer(0, bitmap, cliprect);
 
 	K001005_draw(bitmap, cliprect);
@@ -998,7 +1022,7 @@ VIDEO_UPDATE( gticlub )
 			debug_tex_palette = 0;
 	}
 
-	/*
+#if 0
     if (debug_tex_page > 0)
     {
         char string[200];
@@ -1006,7 +1030,7 @@ VIDEO_UPDATE( gticlub )
         int index = (debug_tex_page - 1) * 0x40000;
         int pal = debug_tex_palette & 7;
         int tp = (debug_tex_palette >> 3) & 1;
-        UINT8 *rom = memory_region(REGION_GFX1);
+        UINT8 *rom = memory_region(machine, "gfx1");
 
         for (y=0; y < 384; y++)
         {
@@ -1020,15 +1044,13 @@ VIDEO_UPDATE( gticlub )
         sprintf(string, "Texture page %d\nPalette %d", debug_tex_page, debug_tex_palette);
         //popmessage("%s", string);
     }
-    */
+#endif
 
 	draw_7segment_led(bitmap, 3, 3, gticlub_led_reg0);
 	draw_7segment_led(bitmap, 9, 3, gticlub_led_reg1);
 
-	//cpunum_set_input_line(machine, 2, SHARC_INPUT_FLAG1, ASSERT_LINE);
-	cpuintrf_push_context(2);
-	sharc_set_flag_input(1, ASSERT_LINE);
-	cpuintrf_pop_context();
+	//cpu_set_input_line(screen->machine->cpu[2], SHARC_INPUT_FLAG1, ASSERT_LINE);
+	sharc_set_flag_input(screen->machine->cpu[2], 1, ASSERT_LINE);
 	return 0;
 }
 
