@@ -6,7 +6,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "profiler.h"
 #include "cpu/m68000/m68000.h"
 #include "itech32.h"
@@ -222,8 +221,8 @@ VIDEO_START( itech32 )
 		videoplane[0][i] = videoplane[1][i] = 0xff;
 
 	/* fetch the GROM base */
-	grom_base = memory_region(REGION_GFX1);
-	grom_size = memory_region_length(REGION_GFX1);
+	grom_base = memory_region(machine, "gfx1");
+	grom_size = memory_region_length(machine, "gfx1");
 	grom_bank = 0;
 	grom_bank_mask = grom_size >> 24;
 	if (grom_bank_mask == 2)
@@ -232,7 +231,7 @@ VIDEO_START( itech32 )
 	/* reset statics */
 	memset(itech32_video, 0, 0x80);
 
-	scanline_timer = timer_alloc(scanline_interrupt, NULL);
+	scanline_timer = timer_alloc(machine, scanline_interrupt, NULL);
 	enable_latch[0] = 1;
 	enable_latch[1] = (itech32_planes > 1) ? 1 : 0;
 
@@ -249,7 +248,7 @@ VIDEO_START( itech32 )
 
 WRITE16_HANDLER( timekill_colora_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		enable_latch[0] = (~data >> 5) & 1;
 		enable_latch[1] = (~data >> 7) & 1;
@@ -260,40 +259,40 @@ WRITE16_HANDLER( timekill_colora_w )
 
 WRITE16_HANDLER( timekill_colorbc_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 		color_latch[1] = ((data & 0xf0) << 4) | 0x1000;
 }
 
 
 WRITE16_HANDLER( timekill_intensity_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		double intensity = (double)(data & 0xff) / (double)0x60;
 		int i;
 		for (i = 0; i < 8192; i++)
-			palette_set_brightness(Machine, i, intensity);
+			palette_set_pen_contrast(space->machine, i, intensity);
 	}
 }
 
 
 WRITE16_HANDLER( bloodstm_color1_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 		color_latch[0] = (data & 0x7f) << 8;
 }
 
 
 WRITE16_HANDLER( bloodstm_color2_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 		color_latch[1] = (data & 0x7f) << 8;
 }
 
 
 WRITE16_HANDLER( bloodstm_plane_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		enable_latch[0] = (~data >> 1) & 1;
 		enable_latch[1] = (~data >> 2) & 1;
@@ -303,28 +302,28 @@ WRITE16_HANDLER( bloodstm_plane_w )
 
 WRITE32_HANDLER( drivedge_color0_w )
 {
-	if (!(mem_mask & 0x00ff0000))
+	if (ACCESSING_BITS_16_23)
 		color_latch[0] = ((data >> 16) & 0x7f) << 8;
 }
 
 
 WRITE32_HANDLER( itech020_color1_w )
 {
-	if (ACCESSING_LSB32)
+	if (ACCESSING_BITS_0_7)
 		color_latch[1] = (data & 0x7f) << 8;
 }
 
 
 WRITE32_HANDLER( itech020_color2_w )
 {
-	if (ACCESSING_LSB32)
+	if (ACCESSING_BITS_0_7)
 		color_latch[0] = (data & 0x7f) << 8;
 }
 
 
 WRITE32_HANDLER( itech020_plane_w )
 {
-	if (!(mem_mask & 0x0000ff00))
+	if (ACCESSING_BITS_8_15)
 	{
 		enable_latch[0] = (~data >> 9) & 1;
 		enable_latch[1] = (~data >> 10) & 1;
@@ -350,7 +349,7 @@ WRITE16_HANDLER( timekill_paletteram_w )
 	g = paletteram16[offset & ~1] >> 8;
 	b = paletteram16[offset |  1] >> 8;
 
-	palette_set_color(Machine, offset / 2, MAKE_RGB(r, g, b));
+	palette_set_color(space->machine, offset / 2, MAKE_RGB(r, g, b));
 }
 
 
@@ -359,7 +358,7 @@ WRITE16_HANDLER( bloodstm_paletteram_w )
 	int r, g, b;
 
 	/* in test mode, the LSB is used; in game mode, the MSB is used */
-	if (!ACCESSING_LSB && (offset & 1))
+	if (!ACCESSING_BITS_0_7 && (offset & 1))
 		data >>= 8, mem_mask >>= 8;
 	COMBINE_DATA(&paletteram16[offset]);
 
@@ -367,7 +366,7 @@ WRITE16_HANDLER( bloodstm_paletteram_w )
 	g = paletteram16[offset & ~1] >> 8;
 	b = paletteram16[offset |  1] & 0xff;
 
-	palette_set_color(Machine, offset / 2, MAKE_RGB(r, g, b));
+	palette_set_color(space->machine, offset / 2, MAKE_RGB(r, g, b));
 }
 
 
@@ -381,7 +380,7 @@ WRITE32_HANDLER( drivedge_paletteram_w )
 	g = (paletteram32[offset] >> 8) & 0xff;
 	b = (paletteram32[offset] >> 16) & 0xff;
 
-	palette_set_color(Machine, offset, MAKE_RGB(r, g, b));
+	palette_set_color(space->machine, offset, MAKE_RGB(r, g, b));
 }
 
 
@@ -395,7 +394,7 @@ WRITE32_HANDLER( itech020_paletteram_w )
 	g = (paletteram32[offset] >> 8) & 0xff;
 	b = paletteram32[offset] & 0xff;
 
-	palette_set_color(Machine, offset, MAKE_RGB(r, g, b));
+	palette_set_color(space->machine, offset, MAKE_RGB(r, g, b));
 }
 
 
@@ -463,7 +462,7 @@ static void logblit(const char *tag)
  *
  *************************************/
 
-static void update_interrupts(int fast)
+static void update_interrupts(running_machine *machine, int fast)
 {
 	int scanline_state = 0, blitter_state = 0;
 
@@ -472,21 +471,21 @@ static void update_interrupts(int fast)
 	if (VIDEO_INTSTATE & VIDEO_INTENABLE & VIDEOINT_BLITTER)
 		blitter_state = 1;
 
-	itech32_update_interrupts(-1, blitter_state, scanline_state);
+	itech32_update_interrupts(machine, -1, blitter_state, scanline_state);
 }
 
 
 static TIMER_CALLBACK( scanline_interrupt )
 {
 	/* set timer for next frame */
-	timer_adjust(scanline_timer, video_screen_get_time_until_pos(0, VIDEO_INTSCANLINE, 0), 0, attotime_zero);
+	timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, VIDEO_INTSCANLINE, 0), 0);
 
 	/* set the interrupt bit in the status reg */
-	logerror("-------------- (DISPLAY INT @ %d) ----------------\n", video_screen_get_vpos(0));
+	logerror("-------------- (DISPLAY INT @ %d) ----------------\n", video_screen_get_vpos(machine->primary_screen));
 	VIDEO_INTSTATE |= VIDEOINT_SCANLINE;
 
 	/* update the interrupt state */
-	update_interrupts(0);
+	update_interrupts(machine, 0);
 }
 
 
@@ -1196,7 +1195,7 @@ static void shiftreg_clear(UINT16 *base, UINT16 *zbase)
  *
  *************************************/
 
-static void handle_video_command(void)
+static void handle_video_command(running_machine *machine)
 {
 	/* only 6 known commands */
 	switch (VIDEO_COMMAND)
@@ -1272,7 +1271,7 @@ static void handle_video_command(void)
 
 	/* tell the processor we're done */
 	VIDEO_INTSTATE |= VIDEOINT_BLITTER;
-	update_interrupts(1);
+	update_interrupts(machine, 1);
 }
 
 
@@ -1294,7 +1293,7 @@ WRITE16_HANDLER( itech32_video_w )
 	{
 		case 0x02/2:	/* VIDEO_INTACK */
 			VIDEO_INTSTATE = old & ~data;
-			update_interrupts(1);
+			update_interrupts(space->machine, 1);
 			break;
 
 		case 0x04/2:	/* VIDEO_TRANSFER */
@@ -1319,11 +1318,11 @@ WRITE16_HANDLER( itech32_video_w )
 			break;
 
 		case 0x08/2:	/* VIDEO_COMMAND */
-			handle_video_command();
+			handle_video_command(space->machine);
 			break;
 
 		case 0x0a/2:	/* VIDEO_INTENABLE */
-			update_interrupts(1);
+			update_interrupts(space->machine, 1);
 			break;
 
 		case 0x24/2:	/* VIDEO_LEFTCLIP */
@@ -1347,7 +1346,7 @@ WRITE16_HANDLER( itech32_video_w )
 			break;
 
 		case 0x2c/2:	/* VIDEO_INTSCANLINE */
-			timer_adjust(scanline_timer, video_screen_get_time_until_pos(0, VIDEO_INTSCANLINE, 0), 0, attotime_zero);
+			timer_adjust_oneshot(scanline_timer, video_screen_get_time_until_pos(space->machine->primary_screen, VIDEO_INTSCANLINE, 0), 0);
 			break;
 
 		case 0x32/2:	/* VIDEO_VTOTAL */
@@ -1379,7 +1378,7 @@ WRITE16_HANDLER( itech32_video_w )
 
 				logerror("Configure Screen: HTOTAL: %x  HBSTART: %x  HBEND: %x  VTOTAL: %x  VBSTART: %x  VBEND: %x\n",
 					VIDEO_HTOTAL, VIDEO_HBLANK_START, VIDEO_HBLANK_END, VIDEO_VTOTAL, VIDEO_VBLANK_START, VIDEO_VBLANK_END);
-				video_screen_configure(0, VIDEO_HTOTAL, VIDEO_VTOTAL, &visarea, HZ_TO_ATTOSECONDS(VIDEO_CLOCK) * VIDEO_HTOTAL * VIDEO_VTOTAL);
+				video_screen_configure(space->machine->primary_screen, VIDEO_HTOTAL, VIDEO_VTOTAL, &visarea, HZ_TO_ATTOSECONDS(VIDEO_CLOCK) * VIDEO_HTOTAL * VIDEO_VTOTAL);
 			}
 			break;
 	}
@@ -1394,7 +1393,7 @@ READ16_HANDLER( itech32_video_r )
 	}
 	else if (offset == 3)
 	{
-		return 0xef;/*video_screen_get_vpos(0) - 1;*/
+		return 0xef;/*video_screen_get_vpos(space->machine->primary_screen) - 1;*/
 	}
 
 	return itech32_video[offset];
@@ -1410,22 +1409,22 @@ READ16_HANDLER( itech32_video_r )
 
 WRITE16_HANDLER( bloodstm_video_w )
 {
-	itech32_video_w(offset / 2, data, mem_mask);
+	itech32_video_w(space, offset / 2, data, mem_mask);
 }
 
 
 READ16_HANDLER( bloodstm_video_r )
 {
-	return itech32_video_r(offset / 2,0);
+	return itech32_video_r(space, offset / 2, mem_mask);
 }
 
 
 WRITE32_HANDLER( itech020_video_w )
 {
-	if (ACCESSING_MSW32)
-		itech32_video_w(offset, data >> 16, mem_mask >> 16);
+	if (ACCESSING_BITS_16_31)
+		itech32_video_w(space, offset, data >> 16, mem_mask >> 16);
 	else
-		itech32_video_w(offset, data, mem_mask);
+		itech32_video_w(space, offset, data, mem_mask);
 }
 
 
@@ -1438,7 +1437,7 @@ WRITE32_HANDLER( drivedge_zbuf_control_w )
 
 READ32_HANDLER( itech020_video_r )
 {
-	int result = itech32_video_r(offset,0);
+	int result = itech32_video_r(space, offset, mem_mask);
 	return (result << 16) | result;
 }
 
@@ -1476,12 +1475,12 @@ VIDEO_UPDATE( itech32 )
 			}
 
 			/* draw from the buffer */
-			draw_scanline16(bitmap, cliprect->min_x, y, cliprect->max_x - cliprect->min_x + 1, &scanline[cliprect->min_x], machine->pens, -1);
+			draw_scanline16(bitmap, cliprect->min_x, y, cliprect->max_x - cliprect->min_x + 1, &scanline[cliprect->min_x], NULL, -1);
 		}
 
 		/* otherwise, draw directly from VRAM */
 		else
-			draw_scanline16(bitmap, cliprect->min_x, y, cliprect->max_x - cliprect->min_x + 1, &src1[cliprect->min_x], machine->pens, -1);
+			draw_scanline16(bitmap, cliprect->min_x, y, cliprect->max_x - cliprect->min_x + 1, &src1[cliprect->min_x], NULL, -1);
 	}
 	return 0;
 }
