@@ -88,7 +88,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "video/tms34061.h"
 #include "video/tlc34076.h"
 #include "cpu/m6809/m6809.h"
@@ -155,6 +154,10 @@ static struct tms34061_display tms_state;
 static UINT8 *grom_base;
 static UINT32 grom_size;
 
+static UINT8 grmatch_palcontrol;
+static UINT8 grmatch_xscroll;
+static rgb_t grmatch_palette[2][16];
+
 
 
 /*************************************
@@ -167,13 +170,13 @@ static void generate_interrupt(running_machine *machine, int state)
 {
 	itech8_update_interrupts(machine, -1, state, -1);
 
-	if (FULL_LOGGING && state) logerror("------------ DISPLAY INT (%d) --------------\n", video_screen_get_vpos(0));
+	if (FULL_LOGGING && state) logerror("------------ DISPLAY INT (%d) --------------\n", video_screen_get_vpos(machine->primary_screen));
 }
 
 
 static const struct tms34061_interface tms34061intf =
 {
-	0,						/* the screen we are acting on */
+	"main",					/* the screen we are acting on */
 	8,						/* VRAM address is (row << rowshift) | col */
 	0x40000,				/* size of video RAM */
 	generate_interrupt		/* interrupt gen callback */
@@ -199,8 +202,8 @@ VIDEO_START( itech8 )
 	page_select = 0xc0;
 
 	/* fetch the GROM base */
-	grom_base = memory_region(REGION_GFX1);
-	grom_size = memory_region_length(REGION_GFX1);
+	grom_base = memory_region(machine, "grom");
+	grom_size = memory_region_length(machine, "grom");
 }
 
 
@@ -213,7 +216,7 @@ VIDEO_START( itech8 )
 
 WRITE8_HANDLER( itech8_palette_w )
 {
-	tlc34076_w(offset/2, data);
+	tlc34076_w(space, offset/2, data);
 }
 
 
@@ -226,8 +229,8 @@ WRITE8_HANDLER( itech8_palette_w )
 
 WRITE8_HANDLER( itech8_page_w )
 {
-	video_screen_update_partial(0, video_screen_get_vpos(0));
-	logerror("%04x:display_page = %02X (%d)\n", activecpu_get_pc(), data, video_screen_get_vpos(0));
+	video_screen_update_partial(space->machine->primary_screen, video_screen_get_vpos(space->machine->primary_screen));
+	logerror("%04x:display_page = %02X (%d)\n", cpu_get_pc(space->cpu), data, video_screen_get_vpos(space->machine->primary_screen));
 	page_select = data;
 }
 
@@ -305,7 +308,7 @@ INLINE void consume_rle(int count)
  *
  *************************************/
 
-static void perform_blit(void)
+static void perform_blit(const address_space *space)
 {
 	offs_t addr = tms_state.regs[TMS34061_XYADDRESS] | ((tms_state.regs[TMS34061_XYOFFSET] & 0x300) << 8);
 	UINT8 shift = (BLITTER_FLAGS & BLITFLAG_SHIFT) ? 4 : 0;
@@ -314,7 +317,7 @@ static void perform_blit(void)
 	int xdir = (BLITTER_FLAGS & BLITFLAG_XFLIP) ? -1 : 1;
 	int xflip = (BLITTER_FLAGS & BLITFLAG_XFLIP);
 	int rle = (BLITTER_FLAGS & BLITFLAG_RLE);
-	int color = tms34061_latch_r(0);
+	int color = tms34061_latch_r(space, 0);
 	int width = BLITTER_WIDTH;
 	int height = BLITTER_HEIGHT;
 	UINT8 transmaskhi, transmasklo;
@@ -325,7 +328,7 @@ static void perform_blit(void)
 	/* debugging */
 	if (FULL_LOGGING)
 		logerror("Blit: scan=%d  src=%06x @ (%05x) for %dx%d ... flags=%02x\n",
-				video_screen_get_vpos(0),
+				video_screen_get_vpos(space->machine->primary_screen),
 				(*itech8_grom_bank << 16) | (BLITTER_ADDRHI << 8) | BLITTER_ADDRLO,
 				tms_state.regs[TMS34061_XYADDRESS] | ((tms_state.regs[TMS34061_XYOFFSET] & 0x300) << 8),
 				BLITTER_WIDTH, BLITTER_HEIGHT, BLITTER_FLAGS);
@@ -397,11 +400,12 @@ static void perform_blit(void)
 			/* swap pixels for X flip in 4bpp mode */
 			if (xflip && transmaskhi != 0xff)
 				pix = (pix >> 4) | (pix << 4);
+			pix &= mask;
 
 			/* draw upper pixel */
 			if (!transparent || (pix & transmaskhi))
 			{
-				tms_state.vram[addr] = (tms_state.vram[addr] & (0x0f << shift)) | ((pix & mask & 0xf0) >> shift);
+				tms_state.vram[addr] = (tms_state.vram[addr] & (0x0f << shift)) | ((pix & 0xf0) >> shift);
 				tms_state.latchram[addr] = (tms_state.latchram[addr] & (0x0f << shift)) | ((color & 0xf0) >> shift);
 			}
 
@@ -409,7 +413,7 @@ static void perform_blit(void)
 			if (!transparent || (pix & transmasklo))
 			{
 				offs_t addr1 = addr + shift/4;
-				tms_state.vram[addr1] = (tms_state.vram[addr1] & (0xf0 >> shift)) | ((pix & mask & 0x0f) << shift);
+				tms_state.vram[addr1] = (tms_state.vram[addr1] & (0xf0 >> shift)) | ((pix & 0x0f) << shift);
 				tms_state.latchram[addr1] = (tms_state.latchram[addr1] & (0xf0 >> shift)) | ((color & 0x0f) << shift);
 			}
 
@@ -446,7 +450,7 @@ static TIMER_CALLBACK( blitter_done )
 	blit_in_progress = 0;
 	itech8_update_interrupts(machine, -1, -1, 1);
 
-	if (FULL_LOGGING) logerror("------------ BLIT DONE (%d) --------------\n", video_screen_get_vpos(0));
+	if (FULL_LOGGING) logerror("------------ BLIT DONE (%d) --------------\n", video_screen_get_vpos(machine->primary_screen));
 }
 
 
@@ -460,9 +464,10 @@ static TIMER_CALLBACK( blitter_done )
 READ8_HANDLER( itech8_blitter_r )
 {
 	int result = blitter_data[offset / 2];
+	static const char *const portnames[] = { "AN_C", "AN_D", "AN_E", "AN_F" };
 
 	/* debugging */
-	if (FULL_LOGGING) logerror("%04x:blitter_r(%02x)\n", activecpu_get_previouspc(), offset / 2);
+	if (FULL_LOGGING) logerror("%04x:blitter_r(%02x)\n", cpu_get_previouspc(space->cpu), offset / 2);
 
 	/* low bit seems to be ignored */
 	offset /= 2;
@@ -470,7 +475,7 @@ READ8_HANDLER( itech8_blitter_r )
 	/* a read from offset 3 clears the interrupt and returns the status */
 	if (offset == 3)
 	{
-		itech8_update_interrupts(Machine, -1, -1, 0);
+		itech8_update_interrupts(space->machine, -1, -1, 0);
 		if (blit_in_progress)
 			result |= 0x80;
 		else
@@ -479,7 +484,7 @@ READ8_HANDLER( itech8_blitter_r )
 
 	/* a read from offsets 12-15 return input port values */
 	if (offset >= 12 && offset <= 15)
-		result = readinputport(3 + offset - 12);
+		result = input_port_read_safe(space->machine, portnames[offset - 12], 0x00);
 
 	return result;
 }
@@ -514,15 +519,15 @@ WRITE8_HANDLER( itech8_blitter_w )
 		}
 
 		/* perform the blit */
-		perform_blit();
+		perform_blit(space);
 		blit_in_progress = 1;
 
 		/* set a timer to go off when we're done */
-		timer_set(attotime_mul(ATTOTIME_IN_HZ(12000000/4), BLITTER_WIDTH * BLITTER_HEIGHT + 12), NULL, 0, blitter_done);
+		timer_set(space->machine, attotime_mul(ATTOTIME_IN_HZ(12000000/4), BLITTER_WIDTH * BLITTER_HEIGHT + 12), NULL, 0, blitter_done);
 	}
 
 	/* debugging */
-	if (FULL_LOGGING) logerror("%04x:blitter_w(%02x)=%02x\n", activecpu_get_previouspc(), offset, data);
+	if (FULL_LOGGING) logerror("%04x:blitter_w(%02x)=%02x\n", cpu_get_previouspc(space->cpu), offset, data);
 }
 
 
@@ -544,7 +549,7 @@ WRITE8_HANDLER( itech8_tms34061_w )
 		col ^= 2;
 
 	/* Row address (RA0-RA8) is not dependent on the offset */
-	tms34061_w(col, 0xff, func, data);
+	tms34061_w(space, col, 0xff, func, data);
 }
 
 
@@ -559,7 +564,53 @@ READ8_HANDLER( itech8_tms34061_r )
 		col ^= 2;
 
 	/* Row address (RA0-RA8) is not dependent on the offset */
-	return tms34061_r(col, 0xff, func);
+	return tms34061_r(space, col, 0xff, func);
+}
+
+
+
+/*************************************
+ *
+ *  Special Grudge Match handlers
+ *
+ *************************************/
+
+WRITE8_HANDLER( grmatch_palette_w )
+{
+	/* set the palette control; examined in the scanline callback */
+	grmatch_palcontrol = data;
+}
+
+
+WRITE8_HANDLER( grmatch_xscroll_w )
+{
+	/* update the X scroll value */
+	video_screen_update_now(space->machine->primary_screen);
+	grmatch_xscroll = data;
+}
+
+
+TIMER_DEVICE_CALLBACK( grmatch_palette_update )
+{
+	/* if the high bit is set, we are supposed to latch the palette values */
+	if (grmatch_palcontrol & 0x80)
+	{
+		/* the TMS34070s latch at the start of the frame, based on the first few bytes */
+		UINT32 page_offset = (tms_state.dispstart & 0x0ffff) | grmatch_xscroll;
+		int page, x;
+
+		/* iterate over both pages */
+		for (page = 0; page < 2; page++)
+		{
+			const UINT8 *base = &tms_state.vram[(page * 0x20000 + page_offset) & 0x3ffff];
+			for (x = 0; x < 16; x++)
+			{
+				UINT8 data0 = base[x * 2 + 0];
+				UINT8 data1 = base[x * 2 + 1];
+				grmatch_palette[page][x] = MAKE_RGB(pal4bit(data0 >> 0), pal4bit(data1 >> 4), pal4bit(data1 >> 0));
+			}
+		}
+	}
 }
 
 
@@ -582,7 +633,7 @@ VIDEO_UPDATE( itech8_2layer )
 	/* if we're blanked, just fill with black */
 	if (tms_state.blanked)
 	{
-		fillbitmap(bitmap, get_black_pen(machine), cliprect);
+		bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
 		return 0;
 	}
 
@@ -606,6 +657,53 @@ VIDEO_UPDATE( itech8_2layer )
 }
 
 
+VIDEO_UPDATE( itech8_grmatch )
+{
+	UINT32 page_offset;
+	int x, y;
+
+	/* first get the current display state */
+	tms34061_get_display_state(&tms_state);
+
+	/* if we're blanked, just fill with black */
+	if (tms_state.blanked)
+	{
+		bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
+		return 0;
+	}
+
+	/* there are two layers: */
+	/*    top layer @ 0x00000 is 4bpp, colors come from TMS34070, enabled via palette control */
+	/* bottom layer @ 0x20000 is 4bpp, colors come from TMS34070, enabled via palette control */
+	/* 4bpp pixels are packed 2 to a byte */
+	/* xscroll is set via a separate register */
+	page_offset = (tms_state.dispstart & 0x0ffff) | grmatch_xscroll;
+	for (y = cliprect->min_y; y <= cliprect->max_y; y++)
+	{
+		UINT8 *base0 = &tms_state.vram[0x00000 + ((page_offset + y * 256) & 0xffff)];
+		UINT8 *base2 = &tms_state.vram[0x20000 + ((page_offset + y * 256) & 0xffff)];
+		UINT32 *dest = BITMAP_ADDR32(bitmap, y, 0);
+
+		for (x = cliprect->min_x & ~1; x <= cliprect->max_x; x += 2)
+		{
+			UINT8 pix0 = base0[x / 2];
+			UINT8 pix2 = base2[x / 2];
+
+			if ((pix0 & 0xf0) != 0)
+				dest[x] = grmatch_palette[0][pix0 >> 4];
+			else
+				dest[x] = grmatch_palette[1][pix2 >> 4];
+
+			if ((pix0 & 0x0f) != 0)
+				dest[x + 1] = grmatch_palette[0][pix0 & 0x0f];
+			else
+				dest[x + 1] = grmatch_palette[1][pix2 & 0x0f];
+		}
+	}
+	return 0;
+}
+
+
 VIDEO_UPDATE( itech8_2page )
 {
 	UINT32 page_offset;
@@ -618,7 +716,7 @@ VIDEO_UPDATE( itech8_2page )
 	/* if we're blanked, just fill with black */
 	if (tms_state.blanked)
 	{
-		fillbitmap(bitmap, get_black_pen(machine), cliprect);
+		bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
 		return 0;
 	}
 
@@ -649,7 +747,7 @@ VIDEO_UPDATE( itech8_2page_large )
 	/* if we're blanked, just fill with black */
 	if (tms_state.blanked)
 	{
-		fillbitmap(bitmap, get_black_pen(machine), cliprect);
+		bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
 		return 0;
 	}
 
