@@ -1,8 +1,8 @@
 /* helper function to join two 16-bit ROMs and form a 32-bit data stream */
-void konami_rom_deinterleave_2(int mem_region);
-void konami_rom_deinterleave_2_half(int mem_region);
+void konami_rom_deinterleave_2(running_machine *machine, const char *mem_region);
+void konami_rom_deinterleave_2_half(running_machine *machine, const char *mem_region);
 /* helper function to join four 16-bit ROMs and form a 64-bit data stream */
-void konami_rom_deinterleave_4(int mem_region);
+void konami_rom_deinterleave_4(running_machine *machine, const char *mem_region);
 
 
 #define MAX_K007121 2
@@ -11,12 +11,12 @@ extern UINT8 K007121_ctrlram[MAX_K007121][8];
 void K007121_ctrl_w(int chip,int offset,int data);
 WRITE8_HANDLER( K007121_ctrl_0_w );
 WRITE8_HANDLER( K007121_ctrl_1_w );
-void K007121_sprites_draw(int chip,mame_bitmap *bitmap,gfx_element **gfxs, colortable_t *ctable,
+void K007121_sprites_draw(int chip,bitmap_t *bitmap,gfx_element **gfxs, colortable_t *ctable,
 						  const rectangle *cliprect, const UINT8 *source,int base_color,
 						  int global_x_offset,int bank_base, UINT32 pri_mask);
 
 
-void K007342_vh_start(int gfx_index, void (*callback)(int layer,int bank,int *code,int *color,int *flags));
+void K007342_vh_start(running_machine *machine, int gfx_index, void (*callback)(int layer,int bank,int *code,int *color,int *flags));
 READ8_HANDLER( K007342_r );
 WRITE8_HANDLER( K007342_w );
 READ8_HANDLER( K007342_scroll_r );
@@ -24,14 +24,14 @@ WRITE8_HANDLER( K007342_scroll_w );
 void K007342_tilemap_update(void);
 WRITE8_HANDLER( K007342_vreg_w );
 void K007342_tilemap_set_enable(int layer, int enable);
-void K007342_tilemap_draw(mame_bitmap *bitmap,const rectangle *cliprect,int num,int flags,UINT32 priority);
+void K007342_tilemap_draw(bitmap_t *bitmap,const rectangle *cliprect,int num,int flags,UINT32 priority);
 int K007342_is_INT_enabled(void);
 
 
 void K007420_vh_start(running_machine *machine, int gfxnum, void (*callback)(int *code,int *color));
 READ8_HANDLER( K007420_r );
 WRITE8_HANDLER( K007420_w );
-void K007420_sprites_draw(mame_bitmap *bitmap,const rectangle *cliprect);
+void K007420_sprites_draw(bitmap_t *bitmap,const rectangle *cliprect);
 void K007420_set_banklimit(int limit);
 
 
@@ -65,7 +65,7 @@ The callback must put:
 */
 extern tilemap *K052109_tilemap[3];
 
-void K052109_vh_start(running_machine *machine,int gfx_memory_region,int plane_order,
+void K052109_vh_start(running_machine *machine,const char *gfx_memory_region,int plane_order,
 		void (*callback)(int layer,int bank,int *code,int *color,int *flags,int *priority));
 /* plain 8-bit access */
 READ8_HANDLER( K052109_r );
@@ -94,7 +94,7 @@ The callback must put:
   shadow is preloaded with color & 0x80 so it doesn't need to be changed unless
   the game has special treatment (Aliens)
 */
-void K051960_vh_start(running_machine *machine,int gfx_memory_region,int plane_order,
+void K051960_vh_start(running_machine *machine,const char *gfx_memory_region,int plane_order,
 		void (*callback)(int *code,int *color,int *priority,int *shadow));
 READ8_HANDLER( K051960_r );
 WRITE8_HANDLER( K051960_w );
@@ -104,7 +104,7 @@ READ8_HANDLER( K051937_r );
 WRITE8_HANDLER( K051937_w );
 READ16_HANDLER( K051937_word_r );
 WRITE16_HANDLER( K051937_word_w );
-void K051960_sprites_draw(mame_bitmap *bitmap,const rectangle *cliprect,int min_priority,int max_priority);
+void K051960_sprites_draw(bitmap_t *bitmap,const rectangle *cliprect,int min_priority,int max_priority);
 int K051960_is_IRQ_enabled(void);
 int K051960_is_NMI_enabled(void);
 void K051960_set_sprite_offsets(int dx, int dy);
@@ -114,7 +114,7 @@ READ8_HANDLER( K052109_051960_r );
 WRITE8_HANDLER( K052109_051960_w );
 
 
-void K053245_vh_start(running_machine *machine,int chip, int gfx_memory_region,int plane_order,
+void K053245_vh_start(running_machine *machine,int chip, const char *gfx_memory_region,int plane_order,
 		void (*callback)(int *code,int *color,int *priority_mask));
 READ16_HANDLER( K053245_word_r );
 WRITE16_HANDLER( K053245_word_w );
@@ -129,8 +129,8 @@ WRITE16_HANDLER( K053244_lsb_w );
 READ16_HANDLER( K053244_word_r );
 WRITE16_HANDLER( K053244_word_w );
 void K053244_bankselect(int chip, int bank);	/* used by TMNT2, Asterix and Premier Soccer for ROM testing */
-void K053245_sprites_draw(int chip, mame_bitmap *bitmap,const rectangle *cliprect);
-void K053245_sprites_draw_lethal(running_machine *machine, int chip, mame_bitmap *bitmap,const rectangle *cliprect); /* for lethal enforcers */
+void K053245_sprites_draw(int chip, bitmap_t *bitmap,const rectangle *cliprect);
+void K053245_sprites_draw_lethal(running_machine *machine, int chip, bitmap_t *bitmap,const rectangle *cliprect); /* for lethal enforcers */
 void K053245_clear_buffer(int chip);
 void K053245_set_SpriteOffset(int chip,int offsx, int offsy);
 
@@ -139,7 +139,7 @@ void K053245_set_SpriteOffset(int chip,int offsx, int offsy);
 #define K055673_LAYOUT_LE2 2
 #define K055673_LAYOUT_GX6 3
 
-void K055673_vh_start(running_machine *machine, int gfx_memory_region, int alt_layout, int dx, int dy,
+void K055673_vh_start(running_machine *machine, const char *gfx_memory_region, int alt_layout, int dx, int dy,
 		void (*callback)(int *code,int *color,int *priority));
 READ16_HANDLER( K055673_rom_word_r );
 READ16_HANDLER( K055673_GX6bpp_rom_word_r );
@@ -154,7 +154,7 @@ Callback procedures for non-standard shadows:
 #define K053247_CUSTOMSHADOW	0x20000000
 #define K053247_SHDSHIFT		20
 
-void K053247_vh_start(running_machine *machine, int gfx_memory_region,int dx,int dy,int plane_order,
+void K053247_vh_start(running_machine *machine, const char *gfx_memory_region,int dx,int dy,int plane_order,
 		void (*callback)(int *code,int *color,int *priority_mask));
 READ8_HANDLER( K053247_r );
 WRITE8_HANDLER( K053247_w );
@@ -164,7 +164,7 @@ READ32_HANDLER( K053247_long_r );
 WRITE32_HANDLER( K053247_long_w );
 WRITE16_HANDLER( K053247_reg_word_w ); // "OBJSET2" registers
 WRITE32_HANDLER( K053247_reg_long_w );
-void K053247_sprites_draw(running_machine *machine, mame_bitmap *bitmap,const rectangle *cliprect);
+void K053247_sprites_draw(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect);
 int K053247_read_register(int regnum);
 void K053247_set_SpriteOffset(int offsx, int offsy);
 void K053247_wraparound_enable(int status);
@@ -193,13 +193,13 @@ The callback must put:
 - if necessary, put flags for the TileMap code in the tile_info
   structure (e.g. TILE_FLIPX)
 */
-void K051316_vh_start_0(running_machine *machine,int gfx_memory_region,int bpp,
+void K051316_vh_start_0(running_machine *machine,const char *gfx_memory_region,int bpp,
 		int tilemap_type,int transparent_pen,
 		void (*callback)(int *code,int *color,int *flags));
-void K051316_vh_start_1(running_machine *machine,int gfx_memory_region,int bpp,
+void K051316_vh_start_1(running_machine *machine,const char *gfx_memory_region,int bpp,
 		int tilemap_type,int transparent_pen,
 		void (*callback)(int *code,int *color,int *flags));
-void K051316_vh_start_2(running_machine *machine,int gfx_memory_region,int bpp,
+void K051316_vh_start_2(running_machine *machine,const char *gfx_memory_region,int bpp,
 		int tilemap_type,int transparent_pen,
 		void (*callback)(int *code,int *color,int *flags));
 READ8_HANDLER( K051316_0_r );
@@ -214,17 +214,17 @@ READ8_HANDLER( K051316_rom_2_r );
 WRITE8_HANDLER( K051316_ctrl_0_w );
 WRITE8_HANDLER( K051316_ctrl_1_w );
 WRITE8_HANDLER( K051316_ctrl_2_w );
-void K051316_zoom_draw_0(mame_bitmap *bitmap,const rectangle *cliprect,int flags,UINT32 priority);
-void K051316_zoom_draw_1(mame_bitmap *bitmap,const rectangle *cliprect,int flags,UINT32 priority);
-void K051316_zoom_draw_2(mame_bitmap *bitmap,const rectangle *cliprect,int flags,UINT32 priority);
+void K051316_zoom_draw_0(bitmap_t *bitmap,const rectangle *cliprect,int flags,UINT32 priority);
+void K051316_zoom_draw_1(bitmap_t *bitmap,const rectangle *cliprect,int flags,UINT32 priority);
+void K051316_zoom_draw_2(bitmap_t *bitmap,const rectangle *cliprect,int flags,UINT32 priority);
 void K051316_wraparound_enable(int chip, int status);
 void K051316_set_offset(int chip, int xoffs, int yoffs);
 
 
 extern UINT16 *K053936_0_ctrl,*K053936_0_linectrl;
 extern UINT16 *K053936_1_ctrl,*K053936_1_linectrl;
-void K053936_0_zoom_draw(mame_bitmap *bitmap,const rectangle *cliprect,tilemap *tmap,int flags,UINT32 priority);
-void K053936_1_zoom_draw(mame_bitmap *bitmap,const rectangle *cliprect,tilemap *tmap,int flags,UINT32 priority);
+void K053936_0_zoom_draw(bitmap_t *bitmap,const rectangle *cliprect,tilemap *tmap,int flags,UINT32 priority);
+void K053936_1_zoom_draw(bitmap_t *bitmap,const rectangle *cliprect,tilemap *tmap,int flags,UINT32 priority);
 void K053936_wraparound_enable(int chip, int status);
 void K053936_set_offset(int chip, int xoffs, int yoffs);
 
@@ -241,7 +241,7 @@ enum { K053251_CI0=0,K053251_CI1,K053251_CI2,K053251_CI3,K053251_CI4 };
 int K053251_get_priority(int ci);
 int K053251_get_palette_index(int ci);
 void K053251_set_tilemaps(tilemap *ci0,tilemap *ci1,tilemap *ci2,tilemap *ci3,tilemap *ci4);
-void K053251_vh_start(void);
+void K053251_vh_start(running_machine *machine);
 
 
 WRITE8_HANDLER( K054000_w );
@@ -254,7 +254,7 @@ READ8_HANDLER( K051733_r );
 
 void K056832_SetExtLinescroll(void);	/* Lethal Enforcers */
 
-void K056832_vh_start(running_machine *machine, int gfx_memory_region, int bpp, int big,
+void K056832_vh_start(running_machine *machine, const char *gfx_memory_region, int bpp, int big,
 			int (*scrolld)[4][2],
 			void (*callback)(int layer, int *code, int *color, int *flags),
 			int djmain_hack);
@@ -284,8 +284,8 @@ WRITE8_HANDLER( K056832_w );
 WRITE8_HANDLER( K056832_b_w );
 void K056832_mark_plane_dirty(int num);
 void K056832_MarkAllTilemapsDirty(void);
-void K056832_tilemap_draw(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int num, int flags, UINT32 priority);
-void K056832_tilemap_draw_dj(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int layer, int flags, UINT32 priority);
+void K056832_tilemap_draw(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int num, int flags, UINT32 priority);
+void K056832_tilemap_draw_dj(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int layer, int flags, UINT32 priority);
 void K056832_set_LayerAssociation(int status);
 int  K056832_get_LayerAssociation(void);
 void K056832_set_LayerOffset(int layer, int offsx, int offsy);
@@ -313,7 +313,7 @@ WRITE32_HANDLER( K056832_b_long_w );
 #define K056832_BPP_4dj	4
 #define K056832_BPP_8LE	5
 
-void K055555_vh_start(void); // "PCU2"
+void K055555_vh_start(running_machine *machine); // "PCU2"
 void K055555_write_reg(UINT8 regnum, UINT8 regdat);
 WRITE16_HANDLER( K055555_word_w );
 WRITE32_HANDLER( K055555_long_w );
@@ -386,13 +386,13 @@ int K055555_get_palette_index(int idx);
 #define K55_INP_SUB3		0x80
 
 /* K054338 mixer/alpha blender */
-void K054338_vh_start(void);
+void K054338_vh_start(running_machine *machine);
 WRITE16_HANDLER( K054338_word_w ); // "CLCT" registers
 WRITE32_HANDLER( K054338_long_w );
 int K054338_read_register(int reg);
 void K054338_update_all_shadows(running_machine *machine);			// called at the beginning of VIDEO_UPDATE()
-void K054338_fill_solid_bg(mame_bitmap *bitmap);				// solid backcolor fill
-void K054338_fill_backcolor(running_machine *machine, mame_bitmap *bitmap, int mode);	// unified fill, 0=solid, 1=gradient
+void K054338_fill_solid_bg(bitmap_t *bitmap);				// solid backcolor fill
+void K054338_fill_backcolor(running_machine *machine, bitmap_t *bitmap, int mode);	// unified fill, 0=solid, 1=gradient
 int  K054338_set_alpha_level(int pblend);							// blend style 0-2
 void K054338_invert_alpha(int invert);								// 0=0x00(invis)-0x1f(solid), 1=0x1f(invis)-0x00(solod)
 void K054338_export_config(int **shdRGB);
@@ -411,7 +411,7 @@ void K054338_export_config(int **shdRGB);
 #define K338_CTL_WAILSL		0x10
 #define K338_CTL_CLIPSL		0x20
 
-void K053250_vh_start(int chips, int *region);
+void K053250_vh_start(running_machine *machine, int chips, const char **region);
 WRITE16_HANDLER( K053250_0_w );
 READ16_HANDLER( K053250_0_r );
 WRITE16_HANDLER( K053250_0_ram_w );
@@ -427,10 +427,10 @@ READ16_HANDLER( K053250_1_rom_r );
 #define K053250_WRAP500		0x01
 #define K053250_OVERDRIVE	0x02
 
-void K053250_draw(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int chip, int colorbase, int flags, int pri);
+void K053250_draw(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int chip, int colorbase, int flags, int pri);
 void K053250_set_LayerOffset(int chip, int offsx, int offsy);
-void K053250_unpack_pixels(int region);
-void K053250_dma(int chip, int limiter);
+void K053250_unpack_pixels(running_machine *machine, const char *region);
+void K053250_dma(running_machine *machine, int chip, int limiter);
 
 
 // K053252 CRT and interrupt control unit
