@@ -52,7 +52,6 @@ Note:   if MAME_DEBUG is defined, pressing Z with:
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "video/konamiic.h"
 
 /* Variables that driver has access to: */
@@ -126,12 +125,13 @@ static TILEMAP_MAPPER( tilemap_scan_gstrik2 )
 
 ***************************************************************************/
 
+#ifdef UNUSED_FUNCTION
 WRITE16_HANDLER( metro_paletteram_w )
 {
 	data = COMBINE_DATA(&paletteram16[offset]);
-	/* We need the ^0xff because we had to invert the pens in the gfx */
-	palette_set_color_rgb(Machine,offset^0xff,pal5bit(data >> 6),pal5bit(data >> 11),pal5bit(data >> 1));
+	palette_set_color_rgb(space->machine,offset,pal5bit(data >> 6),pal5bit(data >> 11),pal5bit(data >> 1));
 }
+#endif
 
 
 /***************************************************************************
@@ -203,15 +203,19 @@ INLINE void get_tile_info(running_machine *machine,tile_data *tileinfo,int tile_
 	{
 		int _code = code & 0x000f;
 		tileinfo->pen_data = empty_tiles + _code*16*16;
-		tileinfo->palette_base = ((code & 0x0ff0) ^ 0x0f0) + 0x1000;
+		tileinfo->palette_base = ((code & 0x0ff0)) + 0x1000;
 		tileinfo->flags = 0;
+		tileinfo->group = 0;
 	}
 	else
+	{
+		tileinfo->group = 0;
 		SET_TILE_INFO(
 				0,
 				(tile & 0xfffff) + (code & 0xf),
-				(((tile & 0x0ff00000) >> 20) ^ 0x0f) + 0x100,
+				(((tile & 0x0ff00000) >> 20)) + 0x100,
 				TILE_FLIPXY((code & 0x6000) >> 13));
+	}
 }
 
 
@@ -239,21 +243,28 @@ INLINE void get_tile_info_8bit(running_machine *machine,tile_data *tileinfo,int
 	{
 		int _code = code & 0x000f;
 		tileinfo->pen_data = empty_tiles + _code*16*16;
-		tileinfo->palette_base = ((code & 0x0ff0) ^ 0x0f0) + 0x1000;
+		tileinfo->palette_base = ((code & 0x0ff0)) + 0x1000;
 		tileinfo->flags = 0;
+		tileinfo->group = 0;
 	}
 	else if ((tile & 0x00f00000)==0x00f00000)	/* draw tile as 8bpp */
+	{
+		tileinfo->group = 1;
 		SET_TILE_INFO(
 				1,
 				(tile & 0xfffff) + 2*(code & 0xf),
 				((tile & 0x0f000000) >> 24) + 0x10,
 				TILE_FLIPXY((code & 0x6000) >> 13));
+	}
 	else
+	{
+		tileinfo->group = 0;
 		SET_TILE_INFO(
 				0,
 				(tile & 0xfffff) + (code & 0xf),
-				(((tile & 0x0ff00000) >> 20) ^ 0x0f) + 0x100,
+				(((tile & 0x0ff00000) >> 20)) + 0x100,
 				TILE_FLIPXY((code & 0x6000) >> 13));
+	}
 }
 
 /* 16x16x4 or 16x16x8 tiles. It's the tile's color that decides: if its low 4
@@ -280,21 +291,29 @@ INLINE void get_tile_info_16x16_8bit(running_machine *machine,tile_data *tileinf
 	{
 		int _code = code & 0x000f;
 		tileinfo->pen_data = empty_tiles + _code*16*16;
-		tileinfo->palette_base = ((code & 0x0ff0) ^ 0x0f0) + 0x1000;
+		tileinfo->palette_base = ((code & 0x0ff0)) + 0x1000;
 		tileinfo->flags = 0;
+		tileinfo->group = 0;
 	}
 	else if ((tile & 0x00f00000)==0x00f00000)	/* draw tile as 8bpp */
+	{
+		tileinfo->group = 1;
 		SET_TILE_INFO(
 				3,
 				(tile & 0xfffff) + 8*(code & 0xf),
 				((tile & 0x0f000000) >> 24) + 0x10,
 				TILE_FLIPXY((code & 0x6000) >> 13));
+	}
 	else
+	{
+		tileinfo->group = 0;
 		SET_TILE_INFO(
 				2,
 				(tile & 0xfffff) + 4*(code & 0xf),
-				(((tile & 0x0ff00000) >> 20) ^ 0x0f) + 0x100,
+				(((tile & 0x0ff00000) >> 20)) + 0x100,
 				TILE_FLIPXY((code & 0x6000) >> 13));
+
+	}
 }
 
 
@@ -379,7 +398,7 @@ static void alloc_empty_tiles(void)
 
 	for (code = 0;code < 0x10;code++)
 		for (i = 0;i < 16*16;i++)
-			empty_tiles[16*16*code + i] = code ^ 0x0f;
+			empty_tiles[16*16*code + i] = code;
 }
 
 VIDEO_START( metro_14100 )
@@ -392,17 +411,23 @@ VIDEO_START( metro_14100 )
 	metro_tiletable_old = auto_malloc(metro_tiletable_size);
 	dirtyindex = auto_malloc(metro_tiletable_size/4);
 
-	bg_tilemap[0] = tilemap_create(get_tile_info_0,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,WIN_NX,WIN_NY);
-	bg_tilemap[1] = tilemap_create(get_tile_info_1,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,WIN_NX,WIN_NY);
-	bg_tilemap[2] = tilemap_create(get_tile_info_2,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[0] = tilemap_create(machine, get_tile_info_0,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[1] = tilemap_create(machine, get_tile_info_1,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[2] = tilemap_create(machine, get_tile_info_2,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
 
 	tilemap_16x16[0] = NULL;
 	tilemap_16x16[1] = NULL;
 	tilemap_16x16[2] = NULL;
 
-	tilemap_set_transparent_pen(bg_tilemap[0],0);
-	tilemap_set_transparent_pen(bg_tilemap[1],0);
-	tilemap_set_transparent_pen(bg_tilemap[2],0);
+    tilemap_map_pen_to_layer(bg_tilemap[0], 0, 15,  TILEMAP_PIXEL_TRANSPARENT);
+    tilemap_map_pen_to_layer(bg_tilemap[0], 1, 255, TILEMAP_PIXEL_TRANSPARENT);
+
+    tilemap_map_pen_to_layer(bg_tilemap[1], 0, 15,  TILEMAP_PIXEL_TRANSPARENT);
+    tilemap_map_pen_to_layer(bg_tilemap[1], 1, 255, TILEMAP_PIXEL_TRANSPARENT);
+
+    tilemap_map_pen_to_layer(bg_tilemap[2], 0, 15,  TILEMAP_PIXEL_TRANSPARENT);
+    tilemap_map_pen_to_layer(bg_tilemap[2], 1, 255, TILEMAP_PIXEL_TRANSPARENT);
+
 }
 
 VIDEO_START( metro_14220 )
@@ -415,17 +440,22 @@ VIDEO_START( metro_14220 )
 	metro_tiletable_old = auto_malloc(metro_tiletable_size);
 	dirtyindex = auto_malloc(metro_tiletable_size/4);
 
-	bg_tilemap[0] = tilemap_create(get_tile_info_0_8bit,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,WIN_NX,WIN_NY);
-	bg_tilemap[1] = tilemap_create(get_tile_info_1_8bit,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,WIN_NX,WIN_NY);
-	bg_tilemap[2] = tilemap_create(get_tile_info_2_8bit,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[0] = tilemap_create(machine, get_tile_info_0_8bit,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[1] = tilemap_create(machine, get_tile_info_1_8bit,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[2] = tilemap_create(machine, get_tile_info_2_8bit,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
 
 	tilemap_16x16[0] = NULL;
 	tilemap_16x16[1] = NULL;
 	tilemap_16x16[2] = NULL;
 
-	tilemap_set_transparent_pen(bg_tilemap[0],0);
-	tilemap_set_transparent_pen(bg_tilemap[1],0);
-	tilemap_set_transparent_pen(bg_tilemap[2],0);
+    tilemap_map_pen_to_layer(bg_tilemap[0], 0, 15,  TILEMAP_PIXEL_TRANSPARENT);
+    tilemap_map_pen_to_layer(bg_tilemap[0], 1, 255, TILEMAP_PIXEL_TRANSPARENT);
+
+    tilemap_map_pen_to_layer(bg_tilemap[1], 0, 15,  TILEMAP_PIXEL_TRANSPARENT);
+    tilemap_map_pen_to_layer(bg_tilemap[1], 1, 255, TILEMAP_PIXEL_TRANSPARENT);
+
+    tilemap_map_pen_to_layer(bg_tilemap[2], 0, 15,  TILEMAP_PIXEL_TRANSPARENT);
+    tilemap_map_pen_to_layer(bg_tilemap[2], 1, 255, TILEMAP_PIXEL_TRANSPARENT);
 
 	tilemap_set_scrolldx(bg_tilemap[0], -2, 2);
 	tilemap_set_scrolldx(bg_tilemap[1], -2, 2);
@@ -442,20 +472,33 @@ VIDEO_START( metro_14300 )
 	metro_tiletable_old = auto_malloc(metro_tiletable_size);
 	dirtyindex = auto_malloc(metro_tiletable_size/4);
 
-	bg_tilemap[0] = tilemap_create(get_tile_info_0_8bit,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,WIN_NX,WIN_NY);
-	bg_tilemap[1] = tilemap_create(get_tile_info_1_8bit,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,WIN_NX,WIN_NY);
-	bg_tilemap[2] = tilemap_create(get_tile_info_2_8bit,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[0] = tilemap_create(machine, get_tile_info_0_8bit,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[1] = tilemap_create(machine, get_tile_info_1_8bit,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
+	bg_tilemap[2] = tilemap_create(machine, get_tile_info_2_8bit,tilemap_scan_rows,8,8,WIN_NX,WIN_NY);
 
-	tilemap_16x16[0] = tilemap_create(get_tile_info_0_16x16_8bit,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,WIN_NX,WIN_NY);
-	tilemap_16x16[1] = tilemap_create(get_tile_info_1_16x16_8bit,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,WIN_NX,WIN_NY);
-	tilemap_16x16[2] = tilemap_create(get_tile_info_2_16x16_8bit,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,WIN_NX,WIN_NY);
+	tilemap_16x16[0] = tilemap_create(machine, get_tile_info_0_16x16_8bit,tilemap_scan_rows,16,16,WIN_NX,WIN_NY);
+	tilemap_16x16[1] = tilemap_create(machine, get_tile_info_1_16x16_8bit,tilemap_scan_rows,16,16,WIN_NX,WIN_NY);
+	tilemap_16x16[2] = tilemap_create(machine, get_tile_info_2_16x16_8bit,tilemap_scan_rows,16,16,WIN_NX,WIN_NY);
+
+    tilemap_map_pen_to_layer(bg_tilemap[0], 0, 15,  TILEMAP_PIXEL_TRANSPARENT);
+    tilemap_map_pen_to_layer(bg_tilemap[0], 1, 255, TILEMAP_PIXEL_TRANSPARENT);
+
+    tilemap_map_pen_to_layer(bg_tilemap[1], 0, 15,  TILEMAP_PIXEL_TRANSPARENT);
+    tilemap_map_pen_to_layer(bg_tilemap[1], 1, 255, TILEMAP_PIXEL_TRANSPARENT);
+
+    tilemap_map_pen_to_layer(bg_tilemap[2], 0, 15,  TILEMAP_PIXEL_TRANSPARENT);
+    tilemap_map_pen_to_layer(bg_tilemap[2], 1, 255, TILEMAP_PIXEL_TRANSPARENT);
+
+
+    tilemap_map_pen_to_layer(tilemap_16x16[0], 0, 15,  TILEMAP_PIXEL_TRANSPARENT);
+    tilemap_map_pen_to_layer(tilemap_16x16[0], 1, 255, TILEMAP_PIXEL_TRANSPARENT);
+
+    tilemap_map_pen_to_layer(tilemap_16x16[1], 0, 15,  TILEMAP_PIXEL_TRANSPARENT);
+    tilemap_map_pen_to_layer(tilemap_16x16[1], 1, 255, TILEMAP_PIXEL_TRANSPARENT);
+
+    tilemap_map_pen_to_layer(tilemap_16x16[2], 0, 15,  TILEMAP_PIXEL_TRANSPARENT);
+    tilemap_map_pen_to_layer(tilemap_16x16[2], 1, 255, TILEMAP_PIXEL_TRANSPARENT);
 
-	tilemap_set_transparent_pen(bg_tilemap[0],0);
-	tilemap_set_transparent_pen(bg_tilemap[1],0);
-	tilemap_set_transparent_pen(bg_tilemap[2],0);
-	tilemap_set_transparent_pen(tilemap_16x16[0],0);
-	tilemap_set_transparent_pen(tilemap_16x16[1],0);
-	tilemap_set_transparent_pen(tilemap_16x16[2],0);
 }
 
 VIDEO_START( blzntrnd )
@@ -464,8 +507,8 @@ VIDEO_START( blzntrnd )
 
 	has_zoom = 1;
 
-	metro_K053936_tilemap = tilemap_create(metro_K053936_get_tile_info, tilemap_scan_rows,
-								TILEMAP_TYPE_PEN, 8,8, 256, 512 );
+	metro_K053936_tilemap = tilemap_create(machine, metro_K053936_get_tile_info, tilemap_scan_rows,
+								 8,8, 256, 512 );
 
 	K053936_wraparound_enable(0, 0);
 	K053936_set_offset(0, -69, -21);
@@ -481,8 +524,8 @@ VIDEO_START( gstrik2 )
 
 	has_zoom = 1;
 
-	metro_K053936_tilemap = tilemap_create(metro_K053936_gstrik2_get_tile_info, tilemap_scan_gstrik2,
-								TILEMAP_TYPE_PEN, 16,16, 128, 256 );
+	metro_K053936_tilemap = tilemap_create(machine, metro_K053936_gstrik2_get_tile_info, tilemap_scan_gstrik2,
+								 16,16, 128, 256 );
 
 	K053936_wraparound_enable(0, 0);
 	K053936_set_offset(0, -69, -19);
@@ -554,15 +597,13 @@ VIDEO_START( gstrik2 )
 
 /* Draw sprites */
 
-void metro_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+void metro_draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
-	const int region		=	REGION_GFX1;
+	UINT8 *base_gfx	=	memory_region(machine, "gfx1");
+	UINT8 *gfx_max	=	base_gfx + memory_region_length(machine, "gfx1");
 
-	UINT8 *base_gfx	=	memory_region(region);
-	UINT8 *gfx_max	=	base_gfx + memory_region_length(region);
-
-	int max_x				=	machine->screen[0].width;
-	int max_y				=	machine->screen[0].height;
+	int max_x = video_screen_get_width(machine->primary_screen);
+	int max_y = video_screen_get_height(machine->primary_screen);
 
 	int max_sprites			=	spriteram_size / 8;
 	int sprites				=	metro_videoregs[0x00/2] % max_sprites;
@@ -640,7 +681,7 @@ void metro_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rec
 
 			gfxdata		=	base_gfx + (8*8*4/8) * (((attr & 0x000f) << 16) + code);
 
-			if (flip_screen)
+			if (flip_screen_get(machine))
 			{
 				flipx = !flipx;		x = max_x - x - width;
 				flipy = !flipy;		y = max_y - y - height;
@@ -650,6 +691,7 @@ void metro_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rec
 			{
 				/* prepare GfxElement on the fly */
 				gfx_element gfx;
+				gfx.machine = machine;
 				gfx.width = width;
 				gfx.height = height;
 				gfx.total_elements = 1;
@@ -662,6 +704,7 @@ void metro_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rec
 				gfx.line_modulo = width;
 				gfx.char_modulo = 0;	/* doesn't matter */
 				gfx.flags = 0;
+				gfx.machine = machine;
 
 				/* Bounds checking */
 				if ( (gfxdata + width * height - 1) >= gfx_max )
@@ -672,7 +715,7 @@ void metro_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rec
 								color_start >> 4,
 								flipx, flipy,
 								x, y,
-								cliprect, TRANSPARENCY_PEN, 0,
+								cliprect, TRANSPARENCY_PEN, 255,
 								zoom, zoom,
 								primask[pri]);
 			}
@@ -680,6 +723,7 @@ void metro_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rec
 			{
 				/* prepare GfxElement on the fly */
 				gfx_element gfx;
+				gfx.machine = machine;
 				gfx.width = width;
 				gfx.height = height;
 				gfx.total_elements = 1;
@@ -692,6 +736,7 @@ void metro_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rec
 				gfx.line_modulo = width/2;
 				gfx.char_modulo = 0;	/* doesn't matter */
 				gfx.flags = GFX_ELEMENT_PACKED;
+				gfx.machine = machine;
 
 				/* Bounds checking */
 				if ( (gfxdata + width/2 * height - 1) >= gfx_max )
@@ -699,10 +744,10 @@ void metro_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rec
 
 				pdrawgfxzoom(	bitmap,&gfx,
 								0,
-								(color ^ 0x0f) + color_start,
+								color + color_start,
 								flipx, flipy,
 								x, y,
-								cliprect, TRANSPARENCY_PEN, 0,
+								cliprect, TRANSPARENCY_PEN, 15,
 								zoom, zoom,
 								primask[pri]);
 			}
@@ -728,7 +773,7 @@ void metro_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rec
 
 ***************************************************************************/
 
-static void draw_tilemap(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, tilemap *tmap, UINT32 flags, UINT32 priority,
+static void draw_tilemap(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, tilemap *tmap, UINT32 flags, UINT32 priority,
 		  				 int sx, int sy, int wx, int wy)	// scroll & window values
 {
 #if 1
@@ -737,6 +782,7 @@ static void draw_tilemap(running_machine *machine, mame_bitmap *bitmap, const re
 		tilemap_draw(bitmap,cliprect,tmap, flags, priority);
 #else
 	int x,y,i;
+	const rectangle *visarea = video_screen_get_visible_area(machine->primary_screen);
 
 	/* sub tile placement */
 //  sx      =   sx - (wx & ~7) + (wx & 7);
@@ -765,17 +811,17 @@ static void draw_tilemap(running_machine *machine, mame_bitmap *bitmap, const re
 		clip.max_x	=	clip.min_x + (WIN_NX-1)*8 - 1;
 		clip.max_y	=	clip.min_y + (WIN_NY-1)*8 - 1;
 
-		if (clip.min_x > machine->screen[0].visarea.max_x)	continue;
-		if (clip.min_y > machine->screen[0].visarea.max_y)	continue;
+		if (clip.min_x > visarea->max_x)	continue;
+		if (clip.min_y > visarea->max_y)	continue;
 
-		if (clip.max_x < machine->screen[0].visarea.min_x)	continue;
-		if (clip.max_y < machine->screen[0].visarea.min_y)	continue;
+		if (clip.max_x < visarea->min_x)	continue;
+		if (clip.max_y < visarea->min_y)	continue;
 
-		if (clip.min_x < machine->screen[0].visarea.min_x)	clip.min_x = machine->screen[0].visarea.min_x;
-		if (clip.max_x > machine->screen[0].visarea.max_x)	clip.max_x = machine->screen[0].visarea.max_x;
+		if (clip.min_x < visarea->min_x)	clip.min_x = visarea->min_x;
+		if (clip.max_x > visarea->max_x)	clip.max_x = visarea->max_x;
 
-		if (clip.min_y < machine->screen[0].visarea.min_y)	clip.min_y = machine->screen[0].visarea.min_y;
-		if (clip.max_y > machine->screen[0].visarea.max_y)	clip.max_y = machine->screen[0].visarea.max_y;
+		if (clip.min_y < visarea->min_y)	clip.min_y = visarea->min_y;
+		if (clip.max_y > visarea->max_y)	clip.max_y = visarea->max_y;
 
 		/* The clip region's width must be a multiple of 8!
            This fact renderes the function useless, as far as
@@ -788,7 +834,7 @@ static void draw_tilemap(running_machine *machine, mame_bitmap *bitmap, const re
 
 
 /* Draw all the layers that match the given priority */
-static void draw_layers(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int pri, int layers_ctrl)
+static void draw_layers(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int pri, int layers_ctrl)
 {
 	UINT16 layers_pri = metro_videoregs[0x10/2];
 	int layer;
@@ -868,12 +914,12 @@ VIDEO_UPDATE( metro )
 		}
 	}
 
-	metro_sprite_xoffs	=	metro_videoregs[0x06/2] - machine->screen[0].width  / 2;
-	metro_sprite_yoffs	=	metro_videoregs[0x04/2] - machine->screen[0].height / 2;
+	metro_sprite_xoffs	=	metro_videoregs[0x06/2] - video_screen_get_width(screen)  / 2;
+	metro_sprite_yoffs	=	metro_videoregs[0x04/2] - video_screen_get_height(screen) / 2;
 
 	/* The background color is selected by a register */
-	fillbitmap(priority_bitmap,0,cliprect);
-	fillbitmap(bitmap,machine->pens[((metro_videoregs[0x12/2] & 0x0fff) ^ 0x0ff) + 0x1000],cliprect);
+	bitmap_fill(priority_bitmap,cliprect,0);
+	bitmap_fill(bitmap,cliprect,((metro_videoregs[0x12/2] & 0x0fff)) + 0x1000);
 
 	/*  Screen Control Register:
 
@@ -887,7 +933,7 @@ VIDEO_UPDATE( metro )
         ---- ---- ---- --1-     ? Blank Screen
         ---- ---- ---- ---0     Flip  Screen    */
 	if (screenctrl & 2)	return 0;
-	flip_screen_set(screenctrl & 1);
+	flip_screen_set(screen->machine, screenctrl & 1);
 
 	/* If the game supports 16x16 tiles, make sure that the
        16x16 and 8x8 tilemaps of a given layer are not simultaneously
@@ -915,7 +961,7 @@ if (input_code_pressed(KEYCODE_Z))
 	if (input_code_pressed(KEYCODE_E))	msk |= 4;
 	if (input_code_pressed(KEYCODE_A))	msk |= 8;
 	if (msk != 0)
-	{	fillbitmap(bitmap,0,cliprect);
+	{	bitmap_fill(bitmap,cliprect,0);
 		layers_ctrl &= msk;	}
 
 	popmessage("l %x-%x-%x r %04x %04x %04x",
@@ -929,9 +975,9 @@ if (input_code_pressed(KEYCODE_Z))
 
 
 	for (pri=3; pri>=0; pri--)
-		draw_layers(machine, bitmap,cliprect,pri,layers_ctrl);
+		draw_layers(screen->machine, bitmap,cliprect,pri,layers_ctrl);
 
 	if (layers_ctrl & 0x08)
-		metro_draw_sprites(machine, bitmap,cliprect);
+		metro_draw_sprites(screen->machine, bitmap,cliprect);
 	return 0;
 }
