@@ -5,7 +5,6 @@
 **************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "eminline.h"
 #include "includes/midzeus.h"
 #include "video/poly.h"
@@ -85,11 +84,11 @@ static UINT32 *waveram[2];
 static void exit_handler(running_machine *machine);
 
 static void zeus_pointer_w(UINT32 which, UINT32 data, int logit);
-static void zeus_register16_w(offs_t offset, UINT16 data, int logit);
-static void zeus_register32_w(offs_t offset, UINT32 data, int logit);
-static void zeus_register_update(offs_t offset);
-static int zeus_fifo_process(const UINT32 *data, int numwords);
-static void zeus_draw_model(UINT32 texdata, int logit);
+static void zeus_register16_w(running_machine *machine, offs_t offset, UINT16 data, int logit);
+static void zeus_register32_w(running_machine *machine, offs_t offset, UINT32 data, int logit);
+static void zeus_register_update(running_machine *machine, offs_t offset);
+static int zeus_fifo_process(running_machine *machine, const UINT32 *data, int numwords);
+static void zeus_draw_model(running_machine *machine, UINT32 texdata, int logit);
 static void zeus_draw_quad(const UINT32 *databuffer, UINT32 texdata, int logit);
 
 static void render_poly_4bit(void *dest, INT32 scanline, const poly_extent *extent, const void *extradata, int threadid);
@@ -203,6 +202,7 @@ INLINE void waveram_plot_check_depth(int y, int x, UINT16 color, UINT16 depth)
 	}
 }
 
+#ifdef UNUSED_FUNCTION
 INLINE void waveram_plot_check_depth_nowrite(int y, int x, UINT16 color, UINT16 depth)
 {
 	if (x >= 0 && x <= zeus_cliprect.max_x && y >= 0 && y < zeus_cliprect.max_y)
@@ -212,7 +212,7 @@ INLINE void waveram_plot_check_depth_nowrite(int y, int x, UINT16 color, UINT16
 			WAVERAM_WRITEPIX(zeus_renderbase, y, x, color);
 	}
 }
-
+#endif
 
 
 /*************************************
@@ -255,7 +255,7 @@ VIDEO_START( midzeus )
 		palette_set_color_rgb(machine, i, pal5bit(i >> 10), pal5bit(i >> 5), pal5bit(i >> 0));
 
 	/* initialize polygon engine */
-	poly = poly_alloc(10000, sizeof(poly_extra_data), POLYFLAG_ALLOW_QUADS);
+	poly = poly_alloc(machine, 10000, sizeof(poly_extra_data), POLYFLAG_ALLOW_QUADS);
 
 	/* we need to cleanup on exit */
 	add_exit_callback(machine, exit_handler);
@@ -263,19 +263,19 @@ VIDEO_START( midzeus )
 	zeus_renderbase = waveram[1];
 
 	/* state saving */
-	state_save_register_global_array(zeus_fifo);
-	state_save_register_global(zeus_fifo_words);
-	state_save_register_global_2d_array(zeus_matrix);
-	state_save_register_global_array(zeus_point);
-	state_save_register_global_array(zeus_light);
-	state_save_register_global(zeus_palbase);
-	state_save_register_global(zeus_objdata);
-	state_save_register_global(zeus_cliprect.min_x);
-	state_save_register_global(zeus_cliprect.max_x);
-	state_save_register_global(zeus_cliprect.min_y);
-	state_save_register_global(zeus_cliprect.max_y);
-	state_save_register_global_pointer(waveram[0], WAVERAM0_WIDTH * WAVERAM0_HEIGHT * 8 / sizeof(waveram[0][0]));
-	state_save_register_global_pointer(waveram[1], WAVERAM1_WIDTH * WAVERAM1_HEIGHT * 8 / sizeof(waveram[1][0]));
+	state_save_register_global_array(machine, zeus_fifo);
+	state_save_register_global(machine, zeus_fifo_words);
+	state_save_register_global_2d_array(machine, zeus_matrix);
+	state_save_register_global_array(machine, zeus_point);
+	state_save_register_global_array(machine, zeus_light);
+	state_save_register_global(machine, zeus_palbase);
+	state_save_register_global(machine, zeus_objdata);
+	state_save_register_global(machine, zeus_cliprect.min_x);
+	state_save_register_global(machine, zeus_cliprect.max_x);
+	state_save_register_global(machine, zeus_cliprect.min_y);
+	state_save_register_global(machine, zeus_cliprect.max_y);
+	state_save_register_global_pointer(machine, waveram[0], WAVERAM0_WIDTH * WAVERAM0_HEIGHT * 8 / sizeof(waveram[0][0]));
+	state_save_register_global_pointer(machine, waveram[1], WAVERAM1_WIDTH * WAVERAM1_HEIGHT * 8 / sizeof(waveram[1][0]));
 }
 
 
@@ -317,7 +317,7 @@ VIDEO_UPDATE( midzeus )
 	if (!input_code_pressed(KEYCODE_W))
 	{
 		const void *base = waveram1_ptr_from_expanded_addr(zeusbase[0xcc]);
-		int xoffs = machine->screen[screen].visarea.min_x;
+		int xoffs = video_screen_get_visible_area(screen)->min_x;
 		for (y = cliprect->min_y; y <= cliprect->max_y; y++)
 		{
 			UINT16 *dest = (UINT16 *)bitmap->base + y * bitmap->rowpixels;
@@ -372,18 +372,18 @@ READ32_HANDLER( zeus_r )
 	switch (offset & ~1)
 	{
 		case 0xf0:
-			result = video_screen_get_hpos(0);
+			result = video_screen_get_hpos(space->machine->primary_screen);
 			logit = 0;
 			break;
 
 		case 0xf2:
-			result = video_screen_get_vpos(0);
+			result = video_screen_get_vpos(space->machine->primary_screen);
 			logit = 0;
 			break;
 
 		case 0xf4:
 			result = 6;
-			if (video_screen_get_vblank(0))
+			if (video_screen_get_vblank(space->machine->primary_screen))
 				result |= 0x800;
 			logit = 0;
 			break;
@@ -405,11 +405,11 @@ READ32_HANDLER( zeus_r )
 		if (logit)
 		{
 			if (offset & 1)
-				logerror("%06X:zeus32_r(%02X) = %08X -- unexpected in 32-bit mode\n", activecpu_get_pc(), offset, result);
+				logerror("%06X:zeus32_r(%02X) = %08X -- unexpected in 32-bit mode\n", cpu_get_pc(space->cpu), offset, result);
 			else if (offset != 0xe0)
-				logerror("%06X:zeus32_r(%02X) = %08X\n", activecpu_get_pc(), offset, result);
+				logerror("%06X:zeus32_r(%02X) = %08X\n", cpu_get_pc(space->cpu), offset, result);
 			else
-				logerror("%06X:zeus32_r(%02X) = %08X\n", activecpu_get_pc(), offset, result);
+				logerror("%06X:zeus32_r(%02X) = %08X\n", cpu_get_pc(space->cpu), offset, result);
 		}
 	}
 
@@ -421,7 +421,7 @@ READ32_HANDLER( zeus_r )
 		else
 			result &= 0xffff;
 		if (logit)
-			logerror("%06X:zeus16_r(%02X) = %04X\n", activecpu_get_pc(), offset, result);
+			logerror("%06X:zeus16_r(%02X) = %04X\n", cpu_get_pc(space->cpu), offset, result);
 	}
 	return result;
 }
@@ -439,15 +439,15 @@ WRITE32_HANDLER( zeus_w )
 	int logit = zeus_enable_logging || ((offset < 0xb0 || offset > 0xb7) && (offset < 0xe0 || offset > 0xe1));
 
 	if (logit)
-		logerror("%06X:zeus_w", activecpu_get_pc());
+		logerror("%06X:zeus_w", cpu_get_pc(space->cpu));
 
 	/* 32-bit mode */
 	if (zeusbase[0x80] & 0x00020000)
-		zeus_register32_w(offset, data, logit);
+		zeus_register32_w(space->machine, offset, data, logit);
 
 	/* 16-bit mode */
 	else
-		zeus_register16_w(offset, data, logit);
+		zeus_register16_w(space->machine, offset, data, logit);
 }
 
 
@@ -521,11 +521,11 @@ static void zeus_pointer_w(UINT32 which, UINT32 data, int logit)
  *
  *************************************/
 
-static void zeus_register16_w(offs_t offset, UINT16 data, int logit)
+static void zeus_register16_w(running_machine *machine, offs_t offset, UINT16 data, int logit)
 {
 	/* writes to register $CC need to force a partial update */
 	if ((offset & ~1) == 0xcc)
-		video_screen_update_partial(0, video_screen_get_vpos(0));
+		video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
 
 	/* write to high part on odd addresses */
 	if (offset & 1)
@@ -541,15 +541,15 @@ static void zeus_register16_w(offs_t offset, UINT16 data, int logit)
 
 	/* handle the update */
 	if ((offset & 1) == 0)
-		zeus_register_update(offset);
+		zeus_register_update(machine, offset);
 }
 
 
-static void zeus_register32_w(offs_t offset, UINT32 data, int logit)
+static void zeus_register32_w(running_machine *machine, offs_t offset, UINT32 data, int logit)
 {
 	/* writes to register $CC need to force a partial update */
 	if ((offset & ~1) == 0xcc)
-		video_screen_update_partial(0, video_screen_get_vpos(0));
+		video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
 
 	/* always write to low word? */
 	zeusbase[offset & ~1] = data;
@@ -567,7 +567,7 @@ static void zeus_register32_w(offs_t offset, UINT32 data, int logit)
 
 	/* handle the update */
 	if ((offset & 1) == 0)
-		zeus_register_update(offset);
+		zeus_register_update(machine, offset);
 }
 
 
@@ -578,7 +578,7 @@ static void zeus_register32_w(offs_t offset, UINT32 data, int logit)
  *
  *************************************/
 
-static void zeus_register_update(offs_t offset)
+static void zeus_register_update(running_machine *machine, offs_t offset)
 {
 	/* handle the writes; only trigger on low accesses */
 	switch (offset)
@@ -655,9 +655,9 @@ static void zeus_register_update(offs_t offset)
                 we simply assert immediately if this is enabled. invasn needs this for proper
                 operations */
 			if (zeusbase[0x80] & 0x02000000)
-				cpunum_set_input_line(Machine, 0, 2, ASSERT_LINE);
+				cpu_set_input_line(machine->cpu[0], 2, ASSERT_LINE);
 			else
-				cpunum_set_input_line(Machine, 0, 2, CLEAR_LINE);
+				cpu_set_input_line(machine->cpu[0], 2, CLEAR_LINE);
 			break;
 
 		case 0x84:
@@ -716,7 +716,7 @@ static void zeus_register_update(offs_t offset)
 		case 0xc6:
 		case 0xc8:
 		case 0xca:
-			video_screen_update_partial(0, video_screen_get_vpos(0));
+			video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
 			{
 				int vtotal = zeusbase[0xca] >> 16;
 				int htotal = zeusbase[0xc6] >> 16;
@@ -728,7 +728,7 @@ static void zeus_register_update(offs_t offset)
 				visarea.max_y = zeusbase[0xc8] & 0xffff;
 				if (htotal > 0 && vtotal > 0 && visarea.min_x < visarea.max_x && visarea.max_y < vtotal)
 				{
-					video_screen_configure(0, htotal, vtotal, &visarea, HZ_TO_ATTOSECONDS((double)MIDZEUS_VIDEO_CLOCK / 8.0 / (htotal * vtotal)));
+					video_screen_configure(machine->primary_screen, htotal, vtotal, &visarea, HZ_TO_ATTOSECONDS((double)MIDZEUS_VIDEO_CLOCK / 8.0 / (htotal * vtotal)));
 					zeus_cliprect = visarea;
 					zeus_cliprect.max_x -= zeus_cliprect.min_x;
 					zeus_cliprect.min_x = 0;
@@ -737,13 +737,13 @@ static void zeus_register_update(offs_t offset)
 			break;
 
 		case 0xcc:
-			video_screen_update_partial(0, video_screen_get_vpos(0));
+			video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
 			log_fifo = input_code_pressed(KEYCODE_L);
 			break;
 
 		case 0xe0:
 			zeus_fifo[zeus_fifo_words++] = zeusbase[0xe0];
-			if (zeus_fifo_process(zeus_fifo, zeus_fifo_words))
+			if (zeus_fifo_process(machine, zeus_fifo, zeus_fifo_words))
 				zeus_fifo_words = 0;
 			break;
 	}
@@ -757,7 +757,7 @@ static void zeus_register_update(offs_t offset)
  *
  *************************************/
 
-static int zeus_fifo_process(const UINT32 *data, int numwords)
+static int zeus_fifo_process(running_machine *machine, const UINT32 *data, int numwords)
 {
 	/* handle logging */
 	switch (data[0] >> 24)
@@ -777,14 +777,14 @@ static int zeus_fifo_process(const UINT32 *data, int numwords)
 		case 0x13:	/* invasn */
 			if (log_fifo)
 				log_fifo_command(data, numwords, "");
-			zeus_draw_model((zeusbase[0x06] << 16), log_fifo);
+			zeus_draw_model(machine, (zeusbase[0x06] << 16), log_fifo);
 			break;
 
 		/* 0x17: write 16-bit value to low registers */
 		case 0x17:
 			if (log_fifo)
 				log_fifo_command(data, numwords, " -- reg16");
-			zeus_register16_w((data[0] >> 16) & 0x7f, data[0], log_fifo);
+			zeus_register16_w(machine, (data[0] >> 16) & 0x7f, data[0], log_fifo);
 			break;
 
 		/* 0x18: write 32-bit value to low registers */
@@ -794,7 +794,7 @@ static int zeus_fifo_process(const UINT32 *data, int numwords)
 				return FALSE;
 			if (log_fifo)
 				log_fifo_command(data, numwords, " -- reg32");
-			zeus_register32_w((data[0] >> 16) & 0x7f, data[1], log_fifo);
+			zeus_register32_w(machine, (data[0] >> 16) & 0x7f, data[1], log_fifo);
 			break;
 
 		/* 0x1A: sync pipeline(?) */
@@ -938,7 +938,7 @@ static int zeus_fifo_process(const UINT32 *data, int numwords)
 			if (log_fifo)
 				log_fifo_command(data, numwords, "");
 			zeus_objdata = data[1];
-			zeus_draw_model(data[2], log_fifo);
+			zeus_draw_model(machine, data[2], log_fifo);
 			break;
 
 		default:
@@ -958,7 +958,7 @@ static int zeus_fifo_process(const UINT32 *data, int numwords)
  *
  *************************************/
 
-static void zeus_draw_model(UINT32 texdata, int logit)
+static void zeus_draw_model(running_machine *machine, UINT32 texdata, int logit)
 {
 	UINT32 databuffer[32];
 	int databufcount = 0;
@@ -1017,7 +1017,7 @@ static void zeus_draw_model(UINT32 texdata, int logit)
 					case 0x17:	/* mk4 */
 						if (logit)
 							logerror("reg16");
-						zeus_register16_w((databuffer[0] >> 16) & 0x7f, databuffer[0], logit);
+						zeus_register16_w(machine, (databuffer[0] >> 16) & 0x7f, databuffer[0], logit);
 						if (((databuffer[0] >> 16) & 0x7f) == 0x06)
 							texdata = (texdata & 0xffff) | (zeusbase[0x06] << 16);
 						break;
@@ -1025,7 +1025,7 @@ static void zeus_draw_model(UINT32 texdata, int logit)
 					case 0x19:	/* invasn */
 						if (logit)
 							logerror("reg32");
-						zeus_register32_w((databuffer[0] >> 16) & 0x7f, databuffer[1], logit);
+						zeus_register32_w(machine, (databuffer[0] >> 16) & 0x7f, databuffer[1], logit);
 						if (((databuffer[0] >> 16) & 0x7f) == 0x06)
 							texdata = (texdata & 0xffff) | (zeusbase[0x06] << 16);
 						break;
@@ -1058,7 +1058,7 @@ static void zeus_draw_model(UINT32 texdata, int logit)
 
 static void zeus_draw_quad(const UINT32 *databuffer, UINT32 texdata, int logit)
 {
-	poly_draw_scanline callback;
+	poly_draw_scanline_func callback;
 	poly_extra_data *extra;
 	poly_vertex clipvert[8];
 	poly_vertex vert[4];
