@@ -57,8 +57,6 @@ struct _poly_extra_data
  *
  *************************************/
 
-extern UINT32 *zeusbase;
-
 static poly_manager *poly;
 static UINT8 log_fifo;
 
@@ -104,11 +102,11 @@ static int subregwrite_count[0x100];
 
 static void exit_handler(running_machine *machine);
 
-static void zeus_register32_w(offs_t offset, UINT32 data, int logit);
-static void zeus_register_update(offs_t offset, UINT32 oldval, int logit);
+static void zeus_register32_w(running_machine *machine, offs_t offset, UINT32 data, int logit);
+static void zeus_register_update(running_machine *machine, offs_t offset, UINT32 oldval, int logit);
 static void zeus_pointer_write(UINT8 which, UINT32 value);
-static int zeus_fifo_process(const UINT32 *data, int numwords);
-static void zeus_draw_model(UINT32 baseaddr, UINT16 count, int logit);
+static int zeus_fifo_process(running_machine *machine, const UINT32 *data, int numwords);
+static void zeus_draw_model(running_machine *machine, UINT32 baseaddr, UINT16 count, int logit);
 static void zeus_draw_quad(const UINT32 *databuffer, UINT32 texoffs, int logit);
 static void render_poly_8bit(void *dest, INT32 scanline, const poly_extent *extent, const void *extradata, int threadid);
 
@@ -169,12 +167,13 @@ INLINE void *waveram1_ptr_from_expanded_addr(UINT32 addr)
 	return WAVERAM_BLOCK1(blocknum);
 }
 
+#ifdef UNUSED_FUNCTION
 INLINE void *waveram0_ptr_from_texture_addr(UINT32 addr, int width)
 {
 	UINT32 blocknum = ((addr & ~1) * width) / 8;
 	return WAVERAM_BLOCK0(blocknum);
 }
-
+#endif
 
 
 /*************************************
@@ -183,11 +182,13 @@ INLINE void *waveram0_ptr_from_texture_addr(UINT32 addr, int width)
  *
  *************************************/
 
+#ifdef UNUSED_FUNCTION
 INLINE void waveram_plot(int y, int x, UINT32 color)
 {
 	if (x >= 0 && x <= zeus_cliprect.max_x && y >= 0 && y < zeus_cliprect.max_y)
 		WAVERAM_WRITEPIX(zeus_renderbase, y, x, color);
 }
+#endif
 
 INLINE void waveram_plot_depth(int y, int x, UINT32 color, UINT16 depth)
 {
@@ -198,6 +199,7 @@ INLINE void waveram_plot_depth(int y, int x, UINT32 color, UINT16 depth)
 	}
 }
 
+#ifdef UNUSED_FUNCTION
 INLINE void waveram_plot_check_depth(int y, int x, UINT32 color, UINT16 depth)
 {
 	if (x >= 0 && x <= zeus_cliprect.max_x && y >= 0 && y < zeus_cliprect.max_y)
@@ -210,7 +212,9 @@ INLINE void waveram_plot_check_depth(int y, int x, UINT32 color, UINT16 depth)
 		}
 	}
 }
+#endif
 
+#ifdef UNUSED_FUNCTION
 INLINE void waveram_plot_check_depth_nowrite(int y, int x, UINT32 color, UINT16 depth)
 {
 	if (x >= 0 && x <= zeus_cliprect.max_x && y >= 0 && y < zeus_cliprect.max_y)
@@ -220,7 +224,7 @@ INLINE void waveram_plot_check_depth_nowrite(int y, int x, UINT32 color, UINT16
 			WAVERAM_WRITEPIX(zeus_renderbase, y, x, color);
 	}
 }
-
+#endif
 
 
 /*************************************
@@ -236,12 +240,13 @@ INLINE UINT8 get_texel_8bit(const void *base, int y, int x, int width)
 }
 
 
+#ifdef UNUSED_FUNCTION
 INLINE UINT8 get_texel_4bit(const void *base, int y, int x, int width)
 {
 	UINT32 byteoffs = (y / 2) * (width * 2) + ((x / 8) << 3) + ((y & 1) << 2) + ((x / 2) & 3);
 	return (WAVERAM_READ8(base, byteoffs) >> (4 * (x & 1))) & 0x0f;
 }
-
+#endif
 
 
 /*************************************
@@ -252,7 +257,7 @@ INLINE UINT8 get_texel_4bit(const void *base, int y, int x, int width)
 
 static TIMER_CALLBACK( int_timer_callback )
 {
-	cpunum_set_input_line(machine, 0, 2, ASSERT_LINE);
+	cpu_set_input_line(machine->cpu[0], 2, ASSERT_LINE);
 }
 
 
@@ -263,27 +268,27 @@ VIDEO_START( midzeus2 )
 	waveram[1] = auto_malloc(WAVERAM1_WIDTH * WAVERAM1_HEIGHT * 12);
 
 	/* initialize polygon engine */
-	poly = poly_alloc(10000, sizeof(poly_extra_data), POLYFLAG_ALLOW_QUADS);
+	poly = poly_alloc(machine, 10000, sizeof(poly_extra_data), POLYFLAG_ALLOW_QUADS);
 
 	/* we need to cleanup on exit */
 	add_exit_callback(machine, exit_handler);
 
 	zeus_renderbase = waveram[1];
 
-	int_timer = timer_alloc(int_timer_callback, NULL);
+	int_timer = timer_alloc(machine, int_timer_callback, NULL);
 
 	/* save states */
-	state_save_register_global_pointer(waveram[0], WAVERAM0_WIDTH * WAVERAM0_HEIGHT * 8 / sizeof(waveram[0][0]));
-	state_save_register_global_pointer(waveram[1], WAVERAM1_WIDTH * WAVERAM1_HEIGHT * 12 / sizeof(waveram[1][0]));
-	state_save_register_global_array(zeus_fifo);
-	state_save_register_global(zeus_fifo_words);
-	state_save_register_global(zeus_cliprect.min_x);
-	state_save_register_global(zeus_cliprect.max_x);
-	state_save_register_global(zeus_cliprect.min_y);
-	state_save_register_global(zeus_cliprect.max_y);
-	state_save_register_global_2d_array(zeus_matrix);
-	state_save_register_global_array(zeus_point);
-	state_save_register_global(zeus_texbase);
+	state_save_register_global_pointer(machine, waveram[0], WAVERAM0_WIDTH * WAVERAM0_HEIGHT * 8 / sizeof(waveram[0][0]));
+	state_save_register_global_pointer(machine, waveram[1], WAVERAM1_WIDTH * WAVERAM1_HEIGHT * 12 / sizeof(waveram[1][0]));
+	state_save_register_global_array(machine, zeus_fifo);
+	state_save_register_global(machine, zeus_fifo_words);
+	state_save_register_global(machine, zeus_cliprect.min_x);
+	state_save_register_global(machine, zeus_cliprect.max_x);
+	state_save_register_global(machine, zeus_cliprect.min_y);
+	state_save_register_global(machine, zeus_cliprect.max_y);
+	state_save_register_global_2d_array(machine, zeus_matrix);
+	state_save_register_global_array(machine, zeus_point);
+	state_save_register_global(machine, zeus_texbase);
 }
 
 
@@ -363,7 +368,7 @@ if (input_code_pressed(KEYCODE_DOWN)) { zbase -= 1.0f; popmessage("Zbase = %f",
 	if (!input_code_pressed(KEYCODE_W))
 	{
 		const void *base = waveram1_ptr_from_expanded_addr(zeusbase[0x38]);
-		int xoffs = machine->screen[screen].visarea.min_x;
+		int xoffs = video_screen_get_visible_area(screen)->min_x;
 		for (y = cliprect->min_y; y <= cliprect->max_y; y++)
 		{
 			UINT32 *dest = (UINT32 *)bitmap->base + y * bitmap->rowpixels;
@@ -420,7 +425,7 @@ READ32_HANDLER( zeus2_r )
 #endif
 
 	if (logit)
-		logerror("%06X:zeus2_r(%02X)\n", activecpu_get_pc(), offset);
+		logerror("%06X:zeus2_r(%02X)\n", cpu_get_pc(space->cpu), offset);
 
 	switch (offset)
 	{
@@ -433,7 +438,7 @@ READ32_HANDLER( zeus2_r )
 			/* bits $00080000 is tested in a loop until 0 */
 			/* bit  $00000004 is tested for toggling; probably VBLANK */
 			result = 0x00;
-			if (video_screen_get_vblank(0))
+			if (video_screen_get_vblank(space->machine->primary_screen))
 				result |= 0x04;
 			break;
 
@@ -444,7 +449,7 @@ READ32_HANDLER( zeus2_r )
 
 		case 0x54:
 			/* both upper 16 bits and lower 16 bits seem to be used as vertical counters */
-			result = (video_screen_get_vpos(0) << 16) | video_screen_get_vpos(0);
+			result = (video_screen_get_vpos(space->machine->primary_screen) << 16) | video_screen_get_vpos(space->machine->primary_screen);
 			break;
 	}
 
@@ -466,8 +471,8 @@ WRITE32_HANDLER( zeus2_w )
 				 offset != 0x40 && offset != 0x41 && offset != 0x48 && offset != 0x49 && offset != 0x4e &&
 				 offset != 0x50 && offset != 0x51 && offset != 0x57 && offset != 0x58 && offset != 0x59 && offset != 0x5a && offset != 0x5e);
 	if (logit)
-		logerror("%06X:zeus2_w", activecpu_get_pc());
-	zeus_register32_w(offset, data, logit);
+		logerror("%06X:zeus2_w", cpu_get_pc(space->cpu));
+	zeus_register32_w(space->machine, offset, data, logit);
 }
 
 
@@ -478,7 +483,7 @@ WRITE32_HANDLER( zeus2_w )
  *
  *************************************/
 
-static void zeus_register32_w(offs_t offset, UINT32 data, int logit)
+static void zeus_register32_w(running_machine *machine, offs_t offset, UINT32 data, int logit)
 {
 	UINT32 oldval = zeusbase[offset];
 
@@ -503,7 +508,7 @@ if (regdata_count[offset] < 256)
 
 	/* writes to register $CC need to force a partial update */
 //  if ((offset & ~1) == 0xcc)
-//      video_screen_update_partial(0, video_screen_get_vpos(0));
+//      video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
 
 	/* always write to low word? */
 	zeusbase[offset] = data;
@@ -513,7 +518,7 @@ if (regdata_count[offset] < 256)
 		logerror("(%02X) = %08X\n", offset, data);
 
 	/* handle the update */
-	zeus_register_update(offset, oldval, logit);
+	zeus_register_update(machine, offset, oldval, logit);
 }
 
 
@@ -524,18 +529,18 @@ if (regdata_count[offset] < 256)
  *
  *************************************/
 
-static void zeus_register_update(offs_t offset, UINT32 oldval, int logit)
+static void zeus_register_update(running_machine *machine, offs_t offset, UINT32 oldval, int logit)
 {
 	/* handle the writes; only trigger on low accesses */
 	switch (offset)
 	{
 		case 0x08:
 			zeus_fifo[zeus_fifo_words++] = zeusbase[0x08];
-			if (zeus_fifo_process(zeus_fifo, zeus_fifo_words))
+			if (zeus_fifo_process(machine, zeus_fifo, zeus_fifo_words))
 				zeus_fifo_words = 0;
 
 			/* set the interrupt signal to indicate we can handle more */
-			timer_adjust(int_timer, ATTOTIME_IN_NSEC(500), 0, attotime_zero);
+			timer_adjust_oneshot(int_timer, ATTOTIME_IN_NSEC(500), 0);
 			break;
 
 		case 0x20:
@@ -554,7 +559,7 @@ static void zeus_register_update(offs_t offset, UINT32 oldval, int logit)
 		case 0x35:
 		case 0x36:
 		case 0x37:
-			video_screen_update_partial(0, video_screen_get_vpos(0));
+			video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
 			{
 				int vtotal = zeusbase[0x37] & 0xffff;
 				int htotal = zeusbase[0x34] >> 16;
@@ -566,7 +571,7 @@ static void zeus_register_update(offs_t offset, UINT32 oldval, int logit)
 				visarea.max_y = zeusbase[0x35] & 0xffff;
 				if (htotal > 0 && vtotal > 0 && visarea.min_x < visarea.max_x && visarea.max_y < vtotal)
 				{
-					video_screen_configure(0, htotal, vtotal, &visarea, HZ_TO_ATTOSECONDS((double)MIDZEUS_VIDEO_CLOCK / 4.0 / (htotal * vtotal)));
+					video_screen_configure(machine->primary_screen, htotal, vtotal, &visarea, HZ_TO_ATTOSECONDS((double)MIDZEUS_VIDEO_CLOCK / 4.0 / (htotal * vtotal)));
 					zeus_cliprect = visarea;
 					zeus_cliprect.max_x -= zeus_cliprect.min_x;
 					zeus_cliprect.min_x = 0;
@@ -578,7 +583,7 @@ static void zeus_register_update(offs_t offset, UINT32 oldval, int logit)
 			{
 				UINT32 temp = zeusbase[0x38];
 				zeusbase[0x38] = oldval;
-				video_screen_update_partial(0, video_screen_get_vpos(0));
+				video_screen_update_partial(machine->primary_screen, video_screen_get_vpos(machine->primary_screen));
 				log_fifo = input_code_pressed(KEYCODE_L);
 				zeusbase[0x38] = temp;
 			}
@@ -770,7 +775,7 @@ if (subregdata_count[which] < 256)
  *
  *************************************/
 
-static int zeus_fifo_process(const UINT32 *data, int numwords)
+static int zeus_fifo_process(running_machine *machine, const UINT32 *data, int numwords)
 {
 	int dataoffs = 0;
 
@@ -784,7 +789,7 @@ static int zeus_fifo_process(const UINT32 *data, int numwords)
 			if (log_fifo)
 				log_fifo_command(data, numwords, " -- reg32");
 			if (((data[0] >> 16) & 0x7f) != 0x08)
-				zeus_register32_w((data[0] >> 16) & 0x7f, data[1], log_fifo);
+				zeus_register32_w(machine, (data[0] >> 16) & 0x7f, data[1], log_fifo);
 			break;
 
 		/* 0x08: set matrix and point (thegrid) */
@@ -883,7 +888,7 @@ static int zeus_fifo_process(const UINT32 *data, int numwords)
 				return FALSE;
 			if (log_fifo)
 				log_fifo_command(data, numwords, "");
-			zeus_draw_model(data[1], data[0] & 0xffff, log_fifo);
+			zeus_draw_model(machine, data[1], data[0] & 0xffff, log_fifo);
 			break;
 
 		/* 0x31: sync pipeline? (thegrid) */
@@ -929,7 +934,7 @@ static int zeus_fifo_process(const UINT32 *data, int numwords)
  *
  *************************************/
 
-static void zeus_draw_model(UINT32 baseaddr, UINT16 count, int logit)
+static void zeus_draw_model(running_machine *machine, UINT32 baseaddr, UINT16 count, int logit)
 {
 	UINT32 databuffer[32];
 	int databufcount = 0;
@@ -1001,7 +1006,7 @@ static void zeus_draw_model(UINT32 baseaddr, UINT16 count, int logit)
 					case 0x36:	/* crusnexo */
 						if (logit)
 							logerror("reg32");
-						zeus_register32_w((databuffer[0] >> 16) & 0x7f, databuffer[1], logit);
+						zeus_register32_w(machine, (databuffer[0] >> 16) & 0x7f, databuffer[1], logit);
 						break;
 
 					case 0x38:	/* crusnexo/thegrid */
@@ -1036,7 +1041,7 @@ static void zeus_draw_model(UINT32 baseaddr, UINT16 count, int logit)
 
 static void zeus_draw_quad(const UINT32 *databuffer, UINT32 texoffs, int logit)
 {
-	poly_draw_scanline callback;
+	poly_draw_scanline_func callback;
 	poly_extra_data *extra;
 	poly_vertex clipvert[8];
 	poly_vertex vert[4];
