@@ -1,6 +1,7 @@
 #include "driver.h"
-#include "deprecat.h"
 #include "video/segaic24.h"
+#include "cpu/mb86233/mb86233.h"
+#include "includes/model1.h"
 
 #define LOG_TGP_VIDEO 0
 
@@ -142,7 +143,7 @@ static void project_point_direct(struct point *p)
 }
 
 
-static void draw_hline(mame_bitmap *bitmap, int x1, int x2, int y, int color)
+static void draw_hline(bitmap_t *bitmap, int x1, int x2, int y, int color)
 {
 	UINT16 *base = BITMAP_ADDR16(bitmap, y, 0);
 	while(x1 <= x2) {
@@ -151,7 +152,7 @@ static void draw_hline(mame_bitmap *bitmap, int x1, int x2, int y, int color)
 	}
 }
 
-static void draw_hline_moired(mame_bitmap *bitmap, int x1, int x2, int y, int color)
+static void draw_hline_moired(bitmap_t *bitmap, int x1, int x2, int y, int color)
 {
 	UINT16 *base = BITMAP_ADDR16(bitmap, y, 0);
 	while(x1 <= x2) {
@@ -161,7 +162,7 @@ static void draw_hline_moired(mame_bitmap *bitmap, int x1, int x2, int y, int co
 	}
 }
 
-static void fill_slope(mame_bitmap *bitmap, int color, INT32 x1, INT32 x2, INT32 sl1, INT32 sl2, INT32 y1, INT32 y2, INT32 *nx1, INT32 *nx2)
+static void fill_slope(bitmap_t *bitmap, int color, INT32 x1, INT32 x2, INT32 sl1, INT32 sl2, INT32 y1, INT32 y2, INT32 *nx1, INT32 *nx2)
 {
 	if(y1 > view.y2)
 		return;
@@ -221,7 +222,7 @@ static void fill_slope(mame_bitmap *bitmap, int color, INT32 x1, INT32 x2, INT32
 	*nx2 = x2;
 }
 
-static void fill_line(mame_bitmap *bitmap, int color, INT32 y, INT32 x1, INT32 x2)
+static void fill_line(bitmap_t *bitmap, int color, INT32 y, INT32 x1, INT32 x2)
 {
 	int xx1 = x1>>FRAC_SHIFT;
 	int xx2 = x2>>FRAC_SHIFT;
@@ -242,7 +243,7 @@ static void fill_line(mame_bitmap *bitmap, int color, INT32 y, INT32 x1, INT32 x
 	}
 }
 
-static void fill_quad(mame_bitmap *bitmap, const struct quad *q)
+static void fill_quad(bitmap_t *bitmap, const struct quad *q)
 {
 	INT32 sl1, sl2, cury, limy, x1, x2;
 	int pmin, pmax, i, ps1, ps2;
@@ -343,7 +344,7 @@ static void fill_quad(mame_bitmap *bitmap, const struct quad *q)
 		fill_line(bitmap, color, cury, x1, x2);
 }
 #if 0
-static void draw_line(mame_bitmap *bitmap, int color, int x1, int y1, int x2, int y2)
+static void draw_line(bitmap_t *bitmap, int color, int x1, int y1, int x2, int y2)
 {
 	int s1x, s1y, s2x, s2y;
 	int d1, d2;
@@ -440,7 +441,7 @@ static void unsort_quads(void)
 }
 
 
-static void draw_quads(mame_bitmap *bitmap, const rectangle *cliprect)
+static void draw_quads(bitmap_t *bitmap, const rectangle *cliprect)
 {
 	int count = quadpt - quaddb;
 	int i;
@@ -460,10 +461,10 @@ static void draw_quads(mame_bitmap *bitmap, const rectangle *cliprect)
 
 		fill_quad(bitmap, q);
 #if 0
-		draw_line(bitmap, get_black_pen(machine), q->p[0]->s.x, q->p[0]->s.y, q->p[1]->s.x, q->p[1]->s.y);
-		draw_line(bitmap, get_black_pen(machine), q->p[1]->s.x, q->p[1]->s.y, q->p[2]->s.x, q->p[2]->s.y);
-		draw_line(bitmap, get_black_pen(machine), q->p[2]->s.x, q->p[2]->s.y, q->p[3]->s.x, q->p[3]->s.y);
-		draw_line(bitmap, get_black_pen(machine), q->p[3]->s.x, q->p[3]->s.y, q->p[0]->s.x, q->p[0]->s.y);
+		draw_line(bitmap, get_black_pen(screen->machine), q->p[0]->s.x, q->p[0]->s.y, q->p[1]->s.x, q->p[1]->s.y);
+		draw_line(bitmap, get_black_pen(screen->machine), q->p[1]->s.x, q->p[1]->s.y, q->p[2]->s.x, q->p[2]->s.y);
+		draw_line(bitmap, get_black_pen(screen->machine), q->p[2]->s.x, q->p[2]->s.y, q->p[3]->s.x, q->p[3]->s.y);
+		draw_line(bitmap, get_black_pen(screen->machine), q->p[3]->s.x, q->p[3]->s.y, q->p[0]->s.x, q->p[0]->s.y);
 #endif
 	}
 
@@ -694,7 +695,9 @@ static float max4f(float a, float b, float c, float d)
 	return m;
 }
 
+#ifdef UNUSED_DEFINITION
 static const UINT8 num_of_times[]={1,1,1,1,2,2,2,3};
+#endif
 static float compute_specular(struct vector *normal, struct vector *light,float diffuse,int lmode)
 {
 #if 0
@@ -721,7 +724,7 @@ static float compute_specular(struct vector *normal, struct vector *light,float
 	return 0;
 }
 
-static void push_object(UINT32 tex_adr, UINT32 poly_adr, UINT32 size)
+static void push_object(running_machine *machine, UINT32 tex_adr, UINT32 poly_adr, UINT32 size)
 {
 	int i;
 	UINT32 flags;
@@ -886,8 +889,8 @@ static void push_object(UINT32 tex_adr, UINT32 poly_adr, UINT32 size)
 		{
 			/*float dif=mult_vector(&vn, &view.light);
             float ln=lightparams[lightmode].a + lightparams[lightmode].d*MAX(0.0,dif);
-            cquad.col = scale_color(Machine->pens[0x1000|(tgp_ram[tex_adr-0x40000] & 0x3ff)], MIN(1.0,ln));
-            cquad.col = scale_color(Machine->pens[0x1000|(tgp_ram[tex_adr-0x40000] & 0x3ff)], MIN(1.0,ln));
+            cquad.col = scale_color(machine->pens[0x1000|(tgp_ram[tex_adr-0x40000] & 0x3ff)], MIN(1.0,ln));
+            cquad.col = scale_color(machine->pens[0x1000|(tgp_ram[tex_adr-0x40000] & 0x3ff)], MIN(1.0,ln));
             */
 			float dif=mult_vector(&vn, &view.light);
 			float spec=compute_specular(&vn,&view.light,dif,lightmode);
@@ -1062,7 +1065,7 @@ static UINT16 *push_direct(UINT16 *list)
 			b=(model1_color_xlat[(b<<8)|lumval|0x4000]>>3)&0x1f;
 			cquad.col=(r<<10)|(g<<5)|(b<<0);
 		}
-		//cquad.col  = scale_color(Machine->pens[0x1000|(tgp_ram[tex_adr-0x40000] & 0x3ff)],((float) (lum>>24)) / 128.0);
+		//cquad.col  = scale_color(machine->pens[0x1000|(tgp_ram[tex_adr-0x40000] & 0x3ff)],((float) (lum>>24)) / 128.0);
 		if(flags & 0x00002000)
 			cquad.col |= MOIRE;
 
@@ -1108,7 +1111,7 @@ static UINT16 *skip_direct(UINT16 *list)
 	return list+2;
 }
 
-static void draw_objects(mame_bitmap *bitmap, const rectangle *cliprect)
+static void draw_objects(bitmap_t *bitmap, const rectangle *cliprect)
 {
 	if(quadpt != quaddb) {
 		LOG_TGP(("VIDEO: sort&draw\n"));
@@ -1120,7 +1123,7 @@ static void draw_objects(mame_bitmap *bitmap, const rectangle *cliprect)
 	pointpt = pointdb;
 }
 
-static UINT16 *draw_direct(UINT16 *list, mame_bitmap *bitmap, const rectangle *cliprect)
+static UINT16 *draw_direct(UINT16 *list, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	UINT16 *res;
 
@@ -1150,9 +1153,9 @@ static int get_list_number(void)
 	return listctl[0] & 0x40 ? 0 : 1;
 }
 
-static void end_frame(void)
+static void end_frame(running_machine *machine)
 {
-	if((listctl[0] & 4) && (cpu_getcurrentframe() & 1))
+	if((listctl[0] & 4) && (video_screen_get_frame_number(machine->primary_screen) & 1))
 		listctl[0] ^= 0x40;
 }
 
@@ -1170,7 +1173,7 @@ WRITE16_HANDLER( model1_listctl_w )
 	LOG_TGP(("VIDEO: control=%08x\n", (listctl[1]<<16)|listctl[0]));
 }
 
-static void tgp_render(mame_bitmap *bitmap, const rectangle *cliprect)
+static void tgp_render(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	render_done = 1;
 	if((listctl[1] & 0x1f) == 0x1f) {
@@ -1199,7 +1202,7 @@ static void tgp_render(mame_bitmap *bitmap, const rectangle *cliprect)
 				// 6 = ??  draw object (57bd4, 387460, 2ad)
 
 				if(1 || zz >= 666)
-					push_object(readi(list+2), readi(list+4), readi(list+6));
+					push_object(machine, readi(list+2), readi(list+4), readi(list+6));
 				list += 8;
 				break;
 			case 2:
@@ -1434,7 +1437,7 @@ VIDEO_START(model1)
 
 	sys24_tile_vh_start(machine, 0x3fff);
 
-	poly_rom = (UINT32 *)memory_region(REGION_USER1);
+	poly_rom = (UINT32 *)memory_region(machine, "user1");
 	poly_ram = auto_malloc(0x400000*4);
 	memset(poly_ram, 0, 0x400000*4);
 	tgp_ram = auto_malloc((0x100000-0x40000)*2);
@@ -1450,14 +1453,14 @@ VIDEO_START(model1)
 	quadpt = quaddb;
 	listctl[0] = listctl[1] = 0;
 
-	state_save_register_global_pointer(tgp_ram, 0x100000-0x40000);
-	state_save_register_global_pointer(poly_ram, 0x40000);
-	state_save_register_global_array(listctl);
+	state_save_register_global_pointer(machine, tgp_ram, 0x100000-0x40000);
+	state_save_register_global_pointer(machine, poly_ram, 0x40000);
+	state_save_register_global_array(machine, listctl);
 }
 
 VIDEO_UPDATE(model1)
 {
-	sys24_tile_update(machine);
+	sys24_tile_update(screen->machine);
 #if 0
 	{
 		int mod = 0;
@@ -1504,20 +1507,20 @@ VIDEO_UPDATE(model1)
 	ayyc = cos(ayy);
 	ayys = sin(ayy);
 
-	fillbitmap(priority_bitmap, 0, NULL);
-	fillbitmap(bitmap, machine->pens[0], &machine->screen[0].visarea);
+	bitmap_fill(priority_bitmap, NULL, 0);
+	bitmap_fill(bitmap, cliprect, screen->machine->pens[0]);
 
-	sys24_tile_draw(machine, bitmap, cliprect, 6, 0, 0);
-	sys24_tile_draw(machine, bitmap, cliprect, 4, 0, 0);
-	sys24_tile_draw(machine, bitmap, cliprect, 2, 0, 0);
-	sys24_tile_draw(machine, bitmap, cliprect, 0, 0, 0);
+	sys24_tile_draw(screen->machine, bitmap, cliprect, 6, 0, 0);
+	sys24_tile_draw(screen->machine, bitmap, cliprect, 4, 0, 0);
+	sys24_tile_draw(screen->machine, bitmap, cliprect, 2, 0, 0);
+	sys24_tile_draw(screen->machine, bitmap, cliprect, 0, 0, 0);
 
-	tgp_render(bitmap, cliprect);
+	tgp_render(screen->machine, bitmap, cliprect);
 
-	sys24_tile_draw(machine, bitmap, cliprect, 7, 0, 0);
-	sys24_tile_draw(machine, bitmap, cliprect, 5, 0, 0);
-	sys24_tile_draw(machine, bitmap, cliprect, 3, 0, 0);
-	sys24_tile_draw(machine, bitmap, cliprect, 1, 0, 0);
+	sys24_tile_draw(screen->machine, bitmap, cliprect, 7, 0, 0);
+	sys24_tile_draw(screen->machine, bitmap, cliprect, 5, 0, 0);
+	sys24_tile_draw(screen->machine, bitmap, cliprect, 3, 0, 0);
+	sys24_tile_draw(screen->machine, bitmap, cliprect, 1, 0, 0);
 
 	return 0;
 }
@@ -1525,6 +1528,6 @@ VIDEO_UPDATE(model1)
 VIDEO_EOF(model1)
 {
 	tgp_scan();
-	end_frame();
+	end_frame(machine);
 	LOG_TGP(("TGP: vsync\n"));
 }
