@@ -86,20 +86,13 @@
 
 *********************************************************************************************************************************/
 #include "driver.h"
+#include "eminline.h"
 #include "video/segaic24.h"
 #include "video/poly.h"
-#include "eminline.h"
+#include "includes/model2.h"
 
 #define DEBUG 0
 
-extern UINT32 geo_read_start_address;
-extern UINT32 geo_write_start_address;
-extern UINT32 *model2_bufferram;
-extern UINT32 *model2_colorxlat;
-extern UINT32 *model2_textureram0;
-extern UINT32 *model2_textureram1;
-extern UINT32 *model2_lumaram;
-
 static poly_manager *poly;
 
 #define pz		p[0]
@@ -144,7 +137,7 @@ typedef struct
 	UINT16				z;
 	UINT16				texheader[4];
 	UINT8				luma;
-} quad;
+} _quad;
 
 typedef struct _poly_extra_data poly_extra_data;
 struct _poly_extra_data
@@ -368,7 +361,7 @@ void model2_3d_set_zclip( UINT8 clip )
 
 static void model2_3d_process_quad( UINT32 attr )
 {
-	quad		object;
+	_quad		object;
 	UINT16		*th, *tp;
 	INT32		tho;
 	UINT32		cull, i;
@@ -922,7 +915,7 @@ INLINE UINT16 get_texel( UINT32 base_x, UINT32 base_y, int x, int y, UINT32 *she
 
 /***********************************************************************************************/
 
-static const poly_draw_scanline render_funcs[8] =
+static const poly_draw_scanline_func render_funcs[8] =
 {
 	model2_3d_render_0,	/* checker = 0, textured = 0, translucent = 0 */
 	model2_3d_render_1,	/* checker = 0, textured = 0, translucent = 1 */
@@ -934,7 +927,7 @@ static const poly_draw_scanline render_funcs[8] =
 	model2_3d_render_7	/* checker = 1, textured = 1, translucent = 1 */
 };
 
-static void model2_3d_render( mame_bitmap *bitmap, triangle *tri, const rectangle *cliprect )
+static void model2_3d_render( bitmap_t *bitmap, triangle *tri, const rectangle *cliprect )
 {
 	poly_extra_data *extra = poly_get_extra_data(poly);
 	UINT8		renderer;
@@ -2703,20 +2696,21 @@ static void model2_exit(running_machine *machine)
 
 VIDEO_START(model2)
 {
-	int	width = machine->screen[0].visarea.max_x - machine->screen[0].visarea.min_x;
-	int	height = machine->screen[0].visarea.max_y - machine->screen[0].visarea.min_y;
+	const rectangle *visarea = video_screen_get_visible_area(machine->primary_screen);
+	int	width = visarea->max_x - visarea->min_x;
+	int	height = visarea->max_y - visarea->min_y;
 
 	sys24_tile_vh_start(machine, 0x3fff);
 	sys24_bitmap = bitmap_alloc(width, height+4, BITMAP_FORMAT_INDEXED16);
 
-	poly = poly_alloc(4000, sizeof(poly_extra_data), 0);
+	poly = poly_alloc(machine, 4000, sizeof(poly_extra_data), 0);
 	add_exit_callback(machine, model2_exit);
 
 	/* initialize the geometry engine */
-	geo_init( (UINT32*)memory_region(REGION_USER2) );
+	geo_init( (UINT32*)memory_region(machine, "user2") );
 
 	/* initialize the hardware rasterizer */
-	model2_3d_init( (UINT16*)memory_region(REGION_USER3) );
+	model2_3d_init( (UINT16*)memory_region(machine, "user3") );
 }
 
 static void convert_bitmap( running_machine *machine, bitmap_t *dst, bitmap_t *src, const rectangle *rect )
@@ -2740,16 +2734,16 @@ VIDEO_UPDATE(model2)
 {
 	logerror("--- frame ---\n");
 
-	sys24_tile_update(machine);
-	fillbitmap(bitmap, machine->pens[0], &machine->screen[0].visarea);
-	fillbitmap(sys24_bitmap, 0, &machine->screen[0].visarea);
+	sys24_tile_update(screen->machine);
+	bitmap_fill(bitmap, cliprect, screen->machine->pens[0]);
+	bitmap_fill(sys24_bitmap, cliprect, 0);
 
-	sys24_tile_draw(machine, sys24_bitmap, cliprect, 7, 0, 0);
-	sys24_tile_draw(machine, sys24_bitmap, cliprect, 6, 0, 0);
-	sys24_tile_draw(machine, sys24_bitmap, cliprect, 5, 0, 0);
-	sys24_tile_draw(machine, sys24_bitmap, cliprect, 4, 0, 0);
+	sys24_tile_draw(screen->machine, sys24_bitmap, cliprect, 7, 0, 0);
+	sys24_tile_draw(screen->machine, sys24_bitmap, cliprect, 6, 0, 0);
+	sys24_tile_draw(screen->machine, sys24_bitmap, cliprect, 5, 0, 0);
+	sys24_tile_draw(screen->machine, sys24_bitmap, cliprect, 4, 0, 0);
 
-	convert_bitmap(machine, bitmap, sys24_bitmap, cliprect);
+	convert_bitmap(screen->machine, bitmap, sys24_bitmap, cliprect);
 
 	/* tell the rasterizer we're starting a frame */
 	model2_3d_frame_start();
@@ -2760,13 +2754,13 @@ VIDEO_UPDATE(model2)
 	/* have the rasterizer output the frame */
 	model2_3d_frame_end( bitmap, cliprect );
 
-	fillbitmap(sys24_bitmap, 0, &machine->screen[0].visarea);
-	sys24_tile_draw(machine, sys24_bitmap, cliprect, 3, 0, 0);
-	sys24_tile_draw(machine, sys24_bitmap, cliprect, 2, 0, 0);
-	sys24_tile_draw(machine, sys24_bitmap, cliprect, 1, 0, 0);
-	sys24_tile_draw(machine, sys24_bitmap, cliprect, 0, 0, 0);
+	bitmap_fill(sys24_bitmap, cliprect, 0);
+	sys24_tile_draw(screen->machine, sys24_bitmap, cliprect, 3, 0, 0);
+	sys24_tile_draw(screen->machine, sys24_bitmap, cliprect, 2, 0, 0);
+	sys24_tile_draw(screen->machine, sys24_bitmap, cliprect, 1, 0, 0);
+	sys24_tile_draw(screen->machine, sys24_bitmap, cliprect, 0, 0, 0);
 
-	convert_bitmap(machine, bitmap, sys24_bitmap, cliprect);
+	convert_bitmap(screen->machine, bitmap, sys24_bitmap, cliprect);
 
 	return 0;
 }
