@@ -7,8 +7,8 @@
 ******************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "nb1413m3.h"
+#include "includes/nbmj8688.h"
 
 
 static int mjsikaku_scrolly;
@@ -24,7 +24,7 @@ static int mjsikaku_flipscreen;
 static int mjsikaku_screen_refresh;
 static int mjsikaku_gfxmode;
 
-static mame_bitmap *mjsikaku_tmpbitmap;
+static bitmap_t *mjsikaku_tmpbitmap;
 static UINT16 *mjsikaku_videoram;
 static UINT8 *nbmj8688_clut;
 
@@ -34,7 +34,7 @@ static int HD61830B_addr[2];
 
 
 static void mjsikaku_vramflip(void);
-static void mbmj8688_gfxdraw(int gfxtype);
+static void mbmj8688_gfxdraw(running_machine *machine, int gfxtype);
 
 
 /* the blitter can copy data both in "direct" mode, where every byte of the source
@@ -146,7 +146,7 @@ WRITE8_HANDLER( nbmj8688_blitter_w )
 		case 0x04:	blitter_sizex = data; break;
 		case 0x05:	blitter_sizey = data;
 					/* writing here also starts the blit */
-					mbmj8688_gfxdraw(mjsikaku_gfxmode);
+					mbmj8688_gfxdraw(space->machine, mjsikaku_gfxmode);
 					break;
 		case 0x06:	blitter_direction_x = (data & 0x01) ? 1 : 0;
 					blitter_direction_y = (data & 0x02) ? 1 : 0;
@@ -185,56 +185,60 @@ WRITE8_HANDLER( mjsikaku_scrolly_w )
 
 WRITE8_HANDLER( mjsikaku_romsel_w )
 {
+	int gfxlen = memory_region_length(space->machine, "gfx1");
 	mjsikaku_gfxrom = (data & 0x0f);
 
-	if ((mjsikaku_gfxrom << 17) > (memory_region_length(REGION_GFX1) - 1))
+	if ((mjsikaku_gfxrom << 17) > (gfxlen - 1))
 	{
 #ifdef MAME_DEBUG
 		popmessage("GFXROM BANK OVER!!");
 #endif
-		mjsikaku_gfxrom &= (memory_region_length(REGION_GFX1) / 0x20000 - 1);
+		mjsikaku_gfxrom &= (gfxlen / 0x20000 - 1);
 	}
 }
 
 WRITE8_HANDLER( secolove_romsel_w )
 {
+	int gfxlen = memory_region_length(space->machine, "gfx1");
 	mjsikaku_gfxrom = ((data & 0xc0) >> 4) + (data & 0x03);
-	mjsikaku_gfxflag2_w(0, data);
+	mjsikaku_gfxflag2_w(space, 0, data);
 
-	if ((mjsikaku_gfxrom << 17) > (memory_region_length(REGION_GFX1) - 1))
+	if ((mjsikaku_gfxrom << 17) > (gfxlen - 1))
 	{
 #ifdef MAME_DEBUG
 		popmessage("GFXROM BANK OVER!!");
 #endif
-		mjsikaku_gfxrom &= (memory_region_length(REGION_GFX1) / 0x20000 - 1);
+		mjsikaku_gfxrom &= (gfxlen / 0x20000 - 1);
 	}
 }
 
 WRITE8_HANDLER( crystalg_romsel_w )
 {
+	int gfxlen = memory_region_length(space->machine, "gfx1");
 	mjsikaku_gfxrom = (data & 0x03);
-	mjsikaku_gfxflag2_w(0, data);
+	mjsikaku_gfxflag2_w(space, 0, data);
 
-	if ((mjsikaku_gfxrom << 17) > (memory_region_length(REGION_GFX1) - 1))
+	if ((mjsikaku_gfxrom << 17) > (gfxlen - 1))
 	{
 #ifdef MAME_DEBUG
 		popmessage("GFXROM BANK OVER!!");
 #endif
-		mjsikaku_gfxrom &= (memory_region_length(REGION_GFX1) / 0x20000 - 1);
+		mjsikaku_gfxrom &= (gfxlen / 0x20000 - 1);
 	}
 }
 
 WRITE8_HANDLER( seiha_romsel_w )
 {
+	int gfxlen = memory_region_length(space->machine, "gfx1");
 	mjsikaku_gfxrom = (data & 0x1f);
-	mjsikaku_gfxflag3_w(0, data);
+	mjsikaku_gfxflag3_w(space, 0, data);
 
-	if ((mjsikaku_gfxrom << 17) > (memory_region_length(REGION_GFX1) - 1))
+	if ((mjsikaku_gfxrom << 17) > (gfxlen - 1))
 	{
 #ifdef MAME_DEBUG
 		popmessage("GFXROM BANK OVER!!");
 #endif
-		mjsikaku_gfxrom &= (memory_region_length(REGION_GFX1) / 0x20000 - 1);
+		mjsikaku_gfxrom &= (gfxlen / 0x20000 - 1);
 	}
 }
 
@@ -269,7 +273,7 @@ void mjsikaku_vramflip(void)
 static void update_pixel(int x, int y)
 {
 	int color = mjsikaku_videoram[(y * 512) + x];
-	*BITMAP_ADDR16(mjsikaku_tmpbitmap, y, x) = Machine->pens[color];
+	*BITMAP_ADDR16(mjsikaku_tmpbitmap, y, x) = color;
 }
 
 static void writeram_low(int x, int y, int color)
@@ -291,9 +295,9 @@ static TIMER_CALLBACK( blitter_timer_callback )
 	nb1413m3_busyflag = 1;
 }
 
-static void mbmj8688_gfxdraw(int gfxtype)
+static void mbmj8688_gfxdraw(running_machine *machine, int gfxtype)
 {
-	UINT8 *GFX = memory_region(REGION_GFX1);
+	UINT8 *GFX = memory_region(machine, "gfx1");
 
 	int x, y;
 	int dx1, dx2, dy;
@@ -301,7 +305,7 @@ static void mbmj8688_gfxdraw(int gfxtype)
 	int sizex, sizey;
 	int skipx, skipy;
 	int ctrx, ctry;
-	int gfxaddr;
+	int gfxaddr, gfxlen;
 	UINT16 color, color1, color2;
 
 	if (gfxtype == GFXTYPE_PURE_12BIT)
@@ -336,6 +340,7 @@ static void mbmj8688_gfxdraw(int gfxtype)
 		skipy = -1;
 	}
 
+	gfxlen = memory_region_length(machine, "gfx1");
 	gfxaddr = (mjsikaku_gfxrom << 17) + (blitter_src_addr << 1);
 //popmessage("ADDR:%08X DX:%03d DY:%03d SX:%03d SY:%03d", gfxaddr, startx, starty, sizex, sizey);
 //if (blitter_direction_x|blitter_direction_y) popmessage("ADDR:%08X FX:%01d FY:%01d", gfxaddr, blitter_direction_x, blitter_direction_y);
@@ -344,7 +349,7 @@ static void mbmj8688_gfxdraw(int gfxtype)
 	{
 		for (x = startx, ctrx = sizex; ctrx >= 0; x += skipx, ctrx--)
 		{
-			if ((gfxaddr > (memory_region_length(REGION_GFX1) - 1)))
+			if ((gfxaddr > (gfxlen - 1)))
 			{
 #ifdef MAME_DEBUG
 				popmessage("GFXROM ADDRESS OVER!!");
@@ -543,9 +548,9 @@ static void mbmj8688_gfxdraw(int gfxtype)
 	nb1413m3_busyflag = 0;
 
 	if (gfxtype == GFXTYPE_8BIT)
-		timer_set(attotime_mul(ATTOTIME_IN_HZ(400000), nb1413m3_busyctr), NULL, 0, blitter_timer_callback);
+		timer_set(machine, attotime_mul(ATTOTIME_IN_HZ(400000), nb1413m3_busyctr), NULL, 0, blitter_timer_callback);
 	else
-		timer_set(attotime_mul(ATTOTIME_IN_HZ(400000), nb1413m3_busyctr), NULL, 0, blitter_timer_callback);
+		timer_set(machine, attotime_mul(ATTOTIME_IN_HZ(400000), nb1413m3_busyctr), NULL, 0, blitter_timer_callback);
 }
 
 
@@ -554,9 +559,9 @@ static void mbmj8688_gfxdraw(int gfxtype)
 
 ******************************************************************************/
 
-static void common_video_start(void)
+static void common_video_start(running_machine *machine)
 {
-	mjsikaku_tmpbitmap = auto_bitmap_alloc(512, 256, Machine->screen[0].format);
+	mjsikaku_tmpbitmap = auto_bitmap_alloc(512, 256, video_screen_get_format(machine->primary_screen));
 	mjsikaku_videoram = auto_malloc(512 * 256 * sizeof(UINT16));
 	nbmj8688_clut = auto_malloc(0x20 * sizeof(UINT8));
 	memset(mjsikaku_videoram, 0, (512 * 256 * sizeof(UINT16)));
@@ -567,31 +572,31 @@ static void common_video_start(void)
 VIDEO_START( mbmj8688_8bit )
 {
 	mjsikaku_gfxmode = GFXTYPE_8BIT;
-	common_video_start();
+	common_video_start(machine);
 }
 
 VIDEO_START( mbmj8688_hybrid_12bit )
 {
 	mjsikaku_gfxmode = GFXTYPE_HYBRID_12BIT;
-	common_video_start();
+	common_video_start(machine);
 }
 
 VIDEO_START( mbmj8688_pure_12bit )
 {
 	mjsikaku_gfxmode = GFXTYPE_PURE_12BIT;
-	common_video_start();
+	common_video_start(machine);
 }
 
 VIDEO_START( mbmj8688_hybrid_16bit )
 {
 	mjsikaku_gfxmode = GFXTYPE_HYBRID_16BIT;
-	common_video_start();
+	common_video_start(machine);
 }
 
 VIDEO_START( mbmj8688_pure_16bit )
 {
 	mjsikaku_gfxmode = GFXTYPE_PURE_16BIT;
-	common_video_start();
+	common_video_start(machine);
 }
 
 VIDEO_START( mbmj8688_pure_16bit_LCD )
@@ -601,7 +606,7 @@ VIDEO_START( mbmj8688_pure_16bit_LCD )
 	HD61830B_ram[0] = auto_malloc(0x10000);
 	HD61830B_ram[1] = auto_malloc(0x10000);
 
-	common_video_start();
+	common_video_start(machine);
 }
 
 
@@ -702,9 +707,8 @@ VIDEO_UPDATE( mbmj8688 )
 		copybitmap(bitmap, mjsikaku_tmpbitmap, 0, 0, 0, scrolly - 256, cliprect);
 	}
 	else
-	{
-		fillbitmap(bitmap, machine->pens[0], 0);
-	}
+		bitmap_fill(bitmap, 0, 0);
+
 	return 0;
 }
 
@@ -714,12 +718,14 @@ VIDEO_UPDATE( mbmj8688_LCD )
 {
 	int x, y, b;
 
-	if(screen==0) VIDEO_UPDATE_CALL(mbmj8688);
+	const device_config *main_screen = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "main");
+	const device_config *lcd0_screen = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "lcd0");
+	const device_config *lcd1_screen = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "lcd1");
 
-	if (screen==1)
-	{
+	if (screen == main_screen) VIDEO_UPDATE_CALL(mbmj8688);
+
+	if (screen == lcd0_screen)
 		for (y = 0;y < 64;y++)
-		{
 			for (x = 0;x < 60;x++)
 			{
 				int data = HD61830B_ram[0][y * 60 + x];
@@ -727,13 +733,9 @@ VIDEO_UPDATE( mbmj8688_LCD )
 				for (b = 0;b < 8;b++)
 					*BITMAP_ADDR16(bitmap, y, (8*x+b)) = (data & (1<<b)) ? 0x0000 : 0x18ff;
 			}
-		}
-	}
 
-	if (screen==2)
-	{
+	if (screen == lcd1_screen)
 		for (y = 0;y < 64;y++)
-		{
 			for (x = 0;x < 60;x++)
 			{
 				int data = HD61830B_ram[1][y * 60 + x];
@@ -741,8 +743,6 @@ VIDEO_UPDATE( mbmj8688_LCD )
 				for (b = 0;b < 8;b++)
 					*BITMAP_ADDR16(bitmap, y, (8*x+b)) = (data & (1<<b)) ? 0x0000 : 0x18ff;
 			}
-		}
-	}
 
 	return 0;
 }
