@@ -31,7 +31,8 @@ NES-specific:
 /* constant definitions */
 #define VISIBLE_SCREEN_WIDTH	(32*8)	/* Visible screen width */
 #define VISIBLE_SCREEN_HEIGHT	(30*8)	/* Visible screen height */
-#define VIDEORAM_SIZE			0x4000	/* videoram size */
+#define VIDEOMEM_SIZE			0x4000	/* videomem size */
+#define VIDEOMEM_PAGE_SIZE		0x400	/* videomem page size */
 #define SPRITERAM_SIZE			0x100	/* spriteram size */
 #define SPRITERAM_MASK			(0x100-1)	/* spriteram size */
 #define CHARGEN_NUM_CHARS		512		/* max number of characters handled by the chargen */
@@ -65,7 +66,8 @@ static const pen_t default_colortable[] =
 /* our chip state */
 typedef struct {
 	running_machine 		*machine;				/* execution context */
-	mame_bitmap				*bitmap;				/* target bitmap */
+	bitmap_t				*bitmap;				/* target bitmap */
+	UINT8					*videomem;				/* video mem */
 	UINT8					*videoram;				/* video ram */
 	UINT8					*spriteram;				/* sprite ram */
 	pen_t					*colortable;			/* color table modified at run time */
@@ -81,15 +83,17 @@ typedef struct {
 	ppu2c0x_vidaccess_cb	vidaccess_callback_proc;/* optional video access callback */
 	int						has_videorom;			/* whether we access a video rom or not */
 	int						videorom_banks;			/* number of banks in the videorom (if available) */
+	int						has_videoram;
+	int						videoram_banks_indices[0x2000/VIDEOMEM_PAGE_SIZE];
 	int						regs[PPU_MAX_REG];		/* registers */
 	int						refresh_data;			/* refresh-related */
 	int						refresh_latch;			/* refresh-related */
 	int						x_fine;					/* refresh-related */
 	int						toggle;					/* used to latch hi-lo scroll */
 	int						add;					/* vram increment amount */
-	int						videoram_addr;			/* videoram address pointer */
-	int						addr_latch;				/* videoram address latch */
-	int						data_latch;				/* latched videoram data */
+	int						videomem_addr;			/* videomem address pointer */
+	int						addr_latch;				/* videomem address latch */
+	int						data_latch;				/* latched videomem data */
 	int						buffered_data;
 	int						tile_page;				/* current tile page */
 	int						sprite_page;			/* current sprite page */
@@ -108,7 +112,7 @@ static ppu2c0x_interface *intf;
 /* chips state - allocated at init time */
 static ppu2c0x_chip *chips = 0;
 
-static void update_scanline(int num );
+static void update_scanline(running_machine *machine, int num );
 
 static TIMER_CALLBACK( scanline_callback );
 static TIMER_CALLBACK( hblank_callback );
@@ -295,38 +299,53 @@ void ppu2c0x_init(running_machine *machine, const ppu2c0x_interface *interface )
 		}
 
 		/* initialize the scanline handling portion */
-		chips[i].scanline_timer = timer_alloc(scanline_callback, NULL);
-		chips[i].hblank_timer = timer_alloc(hblank_callback, NULL);
-		chips[i].nmi_timer = timer_alloc(nmi_callback, NULL);
+		chips[i].scanline_timer = timer_alloc(machine, scanline_callback, NULL);
+		chips[i].hblank_timer = timer_alloc(machine, hblank_callback, NULL);
+		chips[i].nmi_timer = timer_alloc(machine, nmi_callback, NULL);
 		chips[i].scanline = 0;
 		chips[i].scan_scale = 1;
 
-		/* allocate a screen bitmap, videoram and spriteram, a dirtychar array and the monochromatic colortable */
-		chips[i].bitmap = auto_bitmap_alloc( VISIBLE_SCREEN_WIDTH, VISIBLE_SCREEN_HEIGHT, machine->screen[0].format );
-		chips[i].videoram = auto_malloc( VIDEORAM_SIZE );
+		/* allocate a screen bitmap, videomem and spriteram, a dirtychar array and the monochromatic colortable */
+		chips[i].bitmap = auto_bitmap_alloc( VISIBLE_SCREEN_WIDTH, VISIBLE_SCREEN_HEIGHT, video_screen_get_format(machine->primary_screen));
+		chips[i].videomem = auto_malloc( VIDEOMEM_SIZE );
+		chips[i].videoram = auto_malloc( VIDEOMEM_SIZE );
 		chips[i].spriteram = auto_malloc( SPRITERAM_SIZE );
 		chips[i].dirtychar = auto_malloc( CHARGEN_NUM_CHARS );
 		chips[i].colortable = auto_malloc( sizeof( default_colortable ) );
 		chips[i].colortable_mono = auto_malloc( sizeof( default_colortable_mono ) );
 
-		/* clear videoram & spriteram */
-		memset( chips[i].videoram, 0, VIDEORAM_SIZE );
+		/* clear videomem & spriteram */
+		memset( chips[i].videomem, 0, VIDEOMEM_SIZE );
+		memset( chips[i].videoram, 0, VIDEOMEM_SIZE );
 		memset( chips[i].spriteram, 0, SPRITERAM_SIZE );
+		memset( chips[i].videoram_banks_indices, 0xff, sizeof(chips[i].videoram_banks_indices) );
 
 		/* set all characters dirty */
 		memset( chips[i].dirtychar, 1, CHARGEN_NUM_CHARS );
 
+		if ( intf->vram_enabled[i] )
+		{
+			chips[i].has_videoram = 1;
+		}
+
 		/* initialize the video ROM portion, if available */
-		if ( ( intf->vrom_region[i] != REGION_INVALID ) && ( memory_region( intf->vrom_region[i] ) != 0 ) )
+		if ( ( intf->vrom_region[i] != NULL ) && ( memory_region( machine, intf->vrom_region[i] ) != 0 ) )
 		{
 			/* mark that we have a videorom */
 			chips[i].has_videorom = 1;
 
 			/* find out how many banks */
-			chips[i].videorom_banks = memory_region_length( intf->vrom_region[i] ) / 0x2000;
+			chips[i].videorom_banks = memory_region_length( machine, intf->vrom_region[i] ) / 0x2000;
 
 			/* tweak the layout accordingly */
-			total = chips[i].videorom_banks * CHARGEN_NUM_CHARS;
+			if ( chips[i].has_videoram )
+			{
+				total = CHARGEN_NUM_CHARS;
+			}
+			else
+			{
+				total = chips[i].videorom_banks * CHARGEN_NUM_CHARS;
+			}
 		}
 		else
 		{
@@ -339,16 +358,16 @@ void ppu2c0x_init(running_machine *machine, const ppu2c0x_interface *interface )
 		/* now create the gfx region */
 		{
 			gfx_layout gl;
-			UINT8 *src = chips[i].has_videorom ? memory_region( intf->vrom_region[i] ) : chips[i].videoram;
+			UINT8 *src = (chips[i].has_videorom && !chips[i].has_videoram) ? memory_region( machine, intf->vrom_region[i] ) : chips[i].videomem;
 
 			memcpy(&gl, &ppu_charlayout, sizeof(gl));
 			gl.total = total;
-			machine->gfx[intf->gfx_layout_number[i]] = allocgfx( &gl );
+			machine->gfx[intf->gfx_layout_number[i]] = allocgfx( machine, &gl );
 			decodegfx( machine->gfx[intf->gfx_layout_number[i]], src, 0, machine->gfx[intf->gfx_layout_number[i]]->total_elements );
 			machine->gfx[intf->gfx_layout_number[i]]->total_colors = 8;
 		}
 
-		/* setup our videoram handlers based on mirroring */
+		/* setup our videomem handlers based on mirroring */
 		ppu2c0x_set_mirroring( i, intf->mirroring[i] );
 	}
 }
@@ -362,12 +381,12 @@ static TIMER_CALLBACK( hblank_callback )
 	int blanked = ( ppu_regs[PPU_CONTROL1] & ( PPU_CONTROL1_BACKGROUND | PPU_CONTROL1_SPRITES ) ) == 0;
 	int vblank = ((this_ppu->scanline >= PPU_VBLANK_FIRST_SCANLINE-1) && (this_ppu->scanline < this_ppu->scanlines_per_frame-1)) ? 1 : 0;
 
-//  update_scanline (num);
+//  update_scanline (machine, num);
 
 	if (this_ppu->hblank_callback_proc)
-		(*this_ppu->hblank_callback_proc) (num, this_ppu->scanline, vblank, blanked);
+		(*this_ppu->hblank_callback_proc) (machine, num, this_ppu->scanline, vblank, blanked);
 
-	timer_adjust(chips[num].hblank_timer, attotime_never, num, attotime_never);
+	timer_adjust_oneshot(chips[num].hblank_timer, attotime_never, num);
 }
 
 static TIMER_CALLBACK( nmi_callback )
@@ -377,15 +396,15 @@ static TIMER_CALLBACK( nmi_callback )
 
 	// Actually fire the VMI
 	if (intf->nmi_handler[num])
-		(*intf->nmi_handler[num]) (num, ppu_regs);
+		(*intf->nmi_handler[num]) (machine, num, ppu_regs);
 
-	timer_adjust(chips[num].nmi_timer, attotime_never, num, attotime_never);
+	timer_adjust_oneshot(chips[num].nmi_timer, attotime_never, num);
 }
 
-static void draw_background(const int num, UINT8 *line_priority )
+static void draw_background(running_machine *machine, int num, UINT8 *line_priority )
 {
 	/* cache some values locally */
-	mame_bitmap *bitmap = chips[num].bitmap;
+	bitmap_t *bitmap = chips[num].bitmap;
 	const int *ppu_regs = &chips[num].regs[0];
 	const int scanline = chips[num].scanline;
 	const int refresh_data = chips[num].refresh_data;
@@ -423,7 +442,7 @@ static void draw_background(const int num, UINT8 *line_priority )
 	}
 
 	/* cache the background pen */
-	back_pen = chips[num].machine->pens[(chips[num].back_color & color_mask)+intf->color_base[num]];
+	back_pen = (chips[num].back_color & color_mask)+intf->color_base[num];
 
 	/* determine where in the nametable to start drawing from */
 	/* based on the current scanline and scroll regs */
@@ -521,10 +540,10 @@ static void draw_background(const int num, UINT8 *line_priority )
 	}
 }
 
-static void draw_sprites(const int num, UINT8 *line_priority )
+static void draw_sprites(running_machine *machine, int num, UINT8 *line_priority )
 {
 	/* cache some values locally */
-	mame_bitmap *bitmap = chips[num].bitmap;
+	bitmap_t *bitmap = chips[num].bitmap;
 	const int scanline = chips[num].scanline;
 	const int gfx_bank = intf->gfx_layout_number[num];
 	const int total_elements = chips[num].machine->gfx[gfx_bank]->total_elements;
@@ -707,7 +726,7 @@ static void draw_sprites(const int num, UINT8 *line_priority )
  *  Scanline Rendering and Update
  *
  *************************************/
-static void render_scanline(int num)
+static void render_scanline(running_machine *machine, int num)
 {
 	UINT8	line_priority[VISIBLE_SCREEN_WIDTH];
 	int		*ppu_regs = &chips[num].regs[0];
@@ -723,10 +742,10 @@ static void render_scanline(int num)
 
 	/* see if we need to render the background */
 	if ( ppu_regs[PPU_CONTROL1] & PPU_CONTROL1_BACKGROUND )
-		draw_background(num, line_priority );
+		draw_background(machine, num, line_priority );
 	else
 	{
-		mame_bitmap *bitmap = chips[num].bitmap;
+		bitmap_t *bitmap = chips[num].bitmap;
 		const int scanline = chips[num].scanline;
 		UINT8 color_mask;
 		UINT16 back_pen;
@@ -739,7 +758,7 @@ static void render_scanline(int num)
 			color_mask = 0xff;
 
 		/* cache the background pen */
-		back_pen = chips[num].machine->pens[(chips[num].back_color & color_mask)+intf->color_base[num]];
+		back_pen = (chips[num].back_color & color_mask)+intf->color_base[num];
 
 		// Fill this scanline with the background pen.
 		for (i = 0; i < bitmap->width; i ++)
@@ -748,13 +767,13 @@ static void render_scanline(int num)
 
 	/* if sprites are on, draw them */
 	if ( ppu_regs[PPU_CONTROL1] & PPU_CONTROL1_SPRITES )
-		draw_sprites( num, line_priority );
+		draw_sprites( machine, num, line_priority );
 
  	/* done updating, whew */
 	profiler_mark(PROFILER_END);
 }
 
-static void update_scanline(int num )
+static void update_scanline(running_machine *machine, int num )
 {
 	ppu2c0x_chip* this_ppu;
 	int scanline = chips[num].scanline;
@@ -773,11 +792,11 @@ static void update_scanline(int num )
 			this_ppu->refresh_data |= ( this_ppu->refresh_latch & 0x041f );
 
 //logerror("   updating refresh_data: %04x (scanline: %d)\n", this_ppu->refresh_data, this_ppu->scanline);
-			render_scanline( num );
+			render_scanline( machine, num );
 		}
 		else
 		{
-			mame_bitmap *bitmap = this_ppu->bitmap;
+			bitmap_t *bitmap = this_ppu->bitmap;
 			const int scanline = this_ppu->scanline;
 			UINT8 color_mask;
 			UINT16 back_pen;
@@ -790,7 +809,7 @@ static void update_scanline(int num )
 				color_mask = 0xff;
 
 			/* cache the background pen */
-			if (this_ppu->videoram_addr >= 0x3f00)
+			if (this_ppu->videomem_addr >= 0x3f00)
 			{
 				// If the PPU's VRAM address happens to point into palette ram space while
 				// both the sprites and background are disabled, the PPU paints the scanline
@@ -798,15 +817,15 @@ static void update_scanline(int num )
 				// pen. Micro Machines makes use of this feature.
 				int penNum;
 
-				if (this_ppu->videoram_addr & 0x03)
-					penNum = this_ppu->videoram[this_ppu->videoram_addr & 0x3f1f] & 0x3f;
+				if (this_ppu->videomem_addr & 0x03)
+					penNum = this_ppu->videomem[this_ppu->videomem_addr & 0x3f1f] & 0x3f;
 				else
-					penNum = this_ppu->videoram[this_ppu->videoram_addr & 0x3f00] & 0x3f;
+					penNum = this_ppu->videomem[this_ppu->videomem_addr & 0x3f00] & 0x3f;
 
-				back_pen = chips[num].machine->pens[penNum + intf->color_base[num]];
+				back_pen = penNum + intf->color_base[num];
 			}
 			else
-				back_pen = chips[num].machine->pens[(this_ppu->back_color & color_mask)+intf->color_base[num]];
+				back_pen = (this_ppu->back_color & color_mask)+intf->color_base[num];
 
 			// Fill this scanline with the background pen.
 			for (i = 0; i < bitmap->width; i ++)
@@ -847,15 +866,15 @@ static TIMER_CALLBACK( scanline_callback )
 
 	/* if a callback is available, call it */
 	if ( this_ppu->scanline_callback_proc )
-		(*this_ppu->scanline_callback_proc)( num, this_ppu->scanline, vblank, blanked );
+		(*this_ppu->scanline_callback_proc)( machine, num, this_ppu->scanline, vblank, blanked );
 
 	/* update the scanline that just went by */
-	update_scanline( num );
+	update_scanline( machine, num );
 
 	/* increment our scanline count */
 	this_ppu->scanline++;
 
-//logerror("starting scanline %d (MAME %d, beam %d)\n", this_ppu->scanline, video_screen_get_vpos(0), video_screen_get_hpos(0));
+//logerror("starting scanline %d (MAME %d, beam %d)\n", this_ppu->scanline, video_screen_get_vpos(machine->primary_screen), video_screen_get_hpos(machine->primary_screen));
 
 	/* Note: this is called at the _end_ of each scanline */
 	if (this_ppu->scanline == PPU_VBLANK_FIRST_SCANLINE)
@@ -871,18 +890,18 @@ logerror("vlbank starting\n");
 			// a game can read the high bit of $2002 before the NMI is called (potentially resetting the bit
 			// via a read from $2002 in the NMI handler).
 			// B-Wings is an example game that needs this.
-			timer_adjust(this_ppu->nmi_timer, ATTOTIME_IN_CYCLES(4, 0), num, attotime_never);
+			timer_adjust_oneshot(this_ppu->nmi_timer, cpu_clocks_to_attotime(machine->cpu[0], 4), num);
 		}
 	}
 
 	/* decode any dirty chars if we're using vram */
 
 	/* first, check the master dirty char flag */
-	if ( !this_ppu->has_videorom && this_ppu->chars_are_dirty )
+	if ( (!this_ppu->has_videorom || this_ppu->has_videoram) && this_ppu->chars_are_dirty )
 	{
 		/* cache some values */
 		UINT8 *dirtyarray = this_ppu->dirtychar;
-		UINT8 *vram = this_ppu->videoram;
+		UINT8 *vram = this_ppu->videomem;
 		gfx_element *gfx = chips[num].machine->gfx[intf->gfx_layout_number[num]];
 
 		/* then iterate and decode */
@@ -922,10 +941,10 @@ logerror("vlbank ending\n");
 		next_scanline = 0;
 
 	// Call us back when the hblank starts for this scanline
-	timer_adjust(this_ppu->hblank_timer, ATTOTIME_IN_CYCLES(86.67, 0), num, attotime_never); // ??? FIXME - hardcoding NTSC, need better calculation
+	timer_adjust_oneshot(this_ppu->hblank_timer, cpu_clocks_to_attotime(machine->cpu[0], 86.67), num); // ??? FIXME - hardcoding NTSC, need better calculation
 
 	// trigger again at the start of the next scanline
-	timer_adjust(this_ppu->scanline_timer, video_screen_get_time_until_pos(0, next_scanline * this_ppu->scan_scale, 0), num, attotime_zero);
+	timer_adjust_oneshot(this_ppu->scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, next_scanline * this_ppu->scan_scale, 0), num);
 }
 
 /*************************************
@@ -933,7 +952,7 @@ logerror("vlbank ending\n");
  *  PPU Reset
  *
  *************************************/
-void ppu2c0x_reset(int num, int scan_scale )
+void ppu2c0x_reset(running_machine *machine, int num, int scan_scale)
 {
 	int i;
 
@@ -950,13 +969,13 @@ void ppu2c0x_reset(int num, int scan_scale )
 	/* set the scan scale (this is for dual monitor vertical setups) */
 	chips[num].scan_scale = scan_scale;
 
-	timer_adjust(chips[num].nmi_timer, attotime_never, num, attotime_never);
+	timer_adjust_oneshot(chips[num].nmi_timer, attotime_never, num);
 
 	// Call us back when the hblank starts for this scanline
-	timer_adjust(chips[num].hblank_timer, ATTOTIME_IN_CYCLES(86.67, 0), num, attotime_never); // ??? FIXME - hardcoding NTSC, need better calculation
+	timer_adjust_oneshot(chips[num].hblank_timer, cpu_clocks_to_attotime(machine->cpu[0], 86.67), num); // ??? FIXME - hardcoding NTSC, need better calculation
 
 	// Call us back at the start of the next scanline
-	timer_adjust(chips[num].scanline_timer, video_screen_get_time_until_pos(0, 1, 0), num, attotime_zero);
+	timer_adjust_oneshot(chips[num].scanline_timer, video_screen_get_time_until_pos(machine->primary_screen, 1, 0), num);
 
 	/* reset the callbacks */
 	chips[num].scanline_callback_proc = 0;
@@ -971,7 +990,7 @@ void ppu2c0x_reset(int num, int scan_scale )
 	chips[num].x_fine = 0;
 	chips[num].toggle = 0;
 	chips[num].add = 1;
-	chips[num].videoram_addr = 0;
+	chips[num].videomem_addr = 0;
 	chips[num].addr_latch = 0;
 	chips[num].data_latch = 0;
 	chips[num].tile_page = 0;
@@ -986,10 +1005,10 @@ void ppu2c0x_reset(int num, int scan_scale )
 		for( i = 0; i < ARRAY_LENGTH( default_colortable_mono ); i++ )
 		{
 			/* monochromatic table */
-			chips[num].colortable_mono[i] = chips[num].machine->pens[default_colortable_mono[i] + color_base];
+			chips[num].colortable_mono[i] = default_colortable_mono[i] + color_base;
 
 			/* color table */
-			chips[num].colortable[i] = chips[num].machine->pens[default_colortable[i] + color_base];
+			chips[num].colortable[i] = default_colortable[i] + color_base;
 		}
 	}
 
@@ -1007,7 +1026,7 @@ void ppu2c0x_reset(int num, int scan_scale )
  *  PPU Registers Read
  *
  *************************************/
-int ppu2c0x_r( int num, offs_t offset )
+int ppu2c0x_r( const address_space *space, offs_t offset, int num )
 {
 	ppu2c0x_chip* this_ppu;
 
@@ -1047,9 +1066,9 @@ int ppu2c0x_r( int num, offs_t offset )
 			break;
 
 		case PPU_DATA:
-			if ( this_ppu->videoram_addr >= 0x3f00  )
+			if ( this_ppu->videomem_addr >= 0x3f00  )
 			{
-				this_ppu->data_latch = this_ppu->videoram[this_ppu->videoram_addr & 0x3F1F];
+				this_ppu->data_latch = this_ppu->videomem[this_ppu->videomem_addr & 0x3F1F];
 				if (this_ppu->regs[PPU_CONTROL1] & PPU_CONTROL1_DISPLAY_MONO)
 					this_ppu->data_latch &= 0x30;
 			}
@@ -1057,14 +1076,14 @@ int ppu2c0x_r( int num, offs_t offset )
 				this_ppu->data_latch = this_ppu->buffered_data;
 
 			if ( ppu_latch )
-				(*ppu_latch)( this_ppu->videoram_addr & 0x3fff );
+				(*ppu_latch)( this_ppu->videomem_addr & 0x3fff );
 
-			if ( ( this_ppu->videoram_addr >= 0x2000 ) && ( this_ppu->videoram_addr <= 0x3fff ) )
-				this_ppu->buffered_data = this_ppu->ppu_page[ ( this_ppu->videoram_addr & 0xc00) >> 10][ this_ppu->videoram_addr & 0x3ff ];
+			if ( ( this_ppu->videomem_addr >= 0x2000 ) && ( this_ppu->videomem_addr <= 0x3fff ) )
+				this_ppu->buffered_data = this_ppu->ppu_page[ ( this_ppu->videomem_addr & 0xc00) >> 10][ this_ppu->videomem_addr & 0x3ff ];
 			else
-				this_ppu->buffered_data = this_ppu->videoram[ this_ppu->videoram_addr & 0x3fff ];
+				this_ppu->buffered_data = this_ppu->videomem[ this_ppu->videomem_addr & 0x3fff ];
 
-			this_ppu->videoram_addr += this_ppu->add;
+			this_ppu->videomem_addr += this_ppu->add;
 			break;
 
 		default:
@@ -1080,7 +1099,7 @@ int ppu2c0x_r( int num, offs_t offset )
  *  PPU Registers Write
  *
  *************************************/
-void ppu2c0x_w( int num, offs_t offset, UINT8 data )
+void ppu2c0x_w( const address_space *space, offs_t offset, UINT8 data, int num )
 {
 	ppu2c0x_chip* this_ppu;
 	int color_base;
@@ -1103,7 +1122,10 @@ void ppu2c0x_w( int num, offs_t offset, UINT8 data )
 
 #ifdef MAME_DEBUG
 	if (this_ppu->scanline <= PPU_BOTTOM_VISIBLE_SCANLINE)
-		logerror("  PPU register %d write %02x during non-vblank scanline %d (MAME %d, beam pos: %d)\n", offset, data, this_ppu->scanline, video_screen_get_vpos(0), video_screen_get_hpos(0));
+	{
+		const device_config *screen = space->machine->primary_screen;
+		logerror("  PPU register %d write %02x during non-vblank scanline %d (MAME %d, beam pos: %d)\n", offset, data, this_ppu->scanline, video_screen_get_vpos(screen), video_screen_get_hpos(screen));
+	}
 #endif
 
 	switch( offset & 7 )
@@ -1130,9 +1152,9 @@ void ppu2c0x_w( int num, offs_t offset, UINT8 data )
 				int i;
 				for (i = 0; i <= 0x1f; i ++)
 				{
-					UINT8 oldColor = this_ppu->videoram[i+0x3f00];
+					UINT8 oldColor = this_ppu->videomem[i+0x3f00];
 
-					this_ppu->colortable[i] = chips[num].machine->pens[color_base + oldColor + (data & PPU_CONTROL1_COLOR_EMPHASIS)*2];
+					this_ppu->colortable[i] = color_base + oldColor + (data & PPU_CONTROL1_COLOR_EMPHASIS)*2;
 				}
 			}
 
@@ -1182,7 +1204,7 @@ void ppu2c0x_w( int num, offs_t offset, UINT8 data )
 				this_ppu->refresh_latch |= data;
 				this_ppu->refresh_data = this_ppu->refresh_latch;
 
-				this_ppu->videoram_addr = this_ppu->refresh_latch;
+				this_ppu->videomem_addr = this_ppu->refresh_latch;
 //logerror("   vram addr write 2: %02x, %04x (scanline: %d)\n", data, this_ppu->refresh_latch, this_ppu->scanline);
 			}
 			else
@@ -1198,20 +1220,20 @@ void ppu2c0x_w( int num, offs_t offset, UINT8 data )
 
 		case PPU_DATA:
 			{
-				int tempAddr = this_ppu->videoram_addr & 0x3fff;
+				int tempAddr = this_ppu->videomem_addr & 0x3fff;
 
 				if ( ppu_latch )
 					(*ppu_latch)( tempAddr );
 
 				/* if there's a callback, call it now */
 				if ( this_ppu->vidaccess_callback_proc )
-					data = (*this_ppu->vidaccess_callback_proc)( num, tempAddr, data );
+					data = (*this_ppu->vidaccess_callback_proc)( space->machine, num, tempAddr, data );
 
 				/* see if it's on the chargen portion */
 				if ( tempAddr < 0x2000 )
 				{
 					/* if we have a videorom mapped there, dont write and log the problem */
-					if ( this_ppu->has_videorom )
+					if ( this_ppu->has_videorom && !this_ppu->has_videoram )
 					{
 						/* if there is a vidaccess callback, assume it coped with it */
 						if ( this_ppu->vidaccess_callback_proc == NULL )
@@ -1220,7 +1242,7 @@ void ppu2c0x_w( int num, offs_t offset, UINT8 data )
 					else
 					{
 						/* store the data */
-						this_ppu->videoram[tempAddr] = data;
+						this_ppu->videomem[tempAddr] = data;
 
 						/* setup the master dirty switch */
 						this_ppu->chars_are_dirty = 1;
@@ -1236,11 +1258,11 @@ void ppu2c0x_w( int num, offs_t offset, UINT8 data )
 
 					/* store the data */
 					if (tempAddr & 0x03)
-						this_ppu->videoram[tempAddr & 0x3F1F] = data;
+						this_ppu->videomem[tempAddr & 0x3F1F] = data;
 					else
 					{
-						this_ppu->videoram[0x3F10+(tempAddr&0xF)] = data;
-						this_ppu->videoram[0x3F00+(tempAddr&0xF)] = data;
+						this_ppu->videomem[0x3F10+(tempAddr&0xF)] = data;
+						this_ppu->videomem[0x3F00+(tempAddr&0xF)] = data;
 					}
 
 					/* As usual, some games attempt to write values > the number of colors so we must mask the data. */
@@ -1248,8 +1270,8 @@ void ppu2c0x_w( int num, offs_t offset, UINT8 data )
 
 					if ( tempAddr & 0x03 )
 					{
-						this_ppu->colortable[ tempAddr & 0x1f ] = chips[num].machine->pens[color_base + data + colorEmphasis];
-						this_ppu->colortable_mono[tempAddr & 0x1f] = chips[num].machine->pens[color_base + (data & 0xf0) + colorEmphasis];
+						this_ppu->colortable[ tempAddr & 0x1f ] = color_base + data + colorEmphasis;
+						this_ppu->colortable_mono[tempAddr & 0x1f] = color_base + (data & 0xf0) + colorEmphasis;
 					}
 
 					/* The only valid background colors are writes to 0x3f00 and 0x3f10 */
@@ -1261,8 +1283,8 @@ void ppu2c0x_w( int num, offs_t offset, UINT8 data )
 						this_ppu->back_color = data;
 						for( i = 0; i < 32; i += 4 )
 						{
-							this_ppu->colortable[ i ] = chips[num].machine->pens[color_base + data + colorEmphasis];
-							this_ppu->colortable_mono[i] = chips[num].machine->pens[color_base + (data & 0xf0) + colorEmphasis];
+							this_ppu->colortable[ i ] = color_base + data + colorEmphasis;
+							this_ppu->colortable_mono[i] = color_base + (data & 0xf0) + colorEmphasis;
 						}
 					}
 				}
@@ -1278,7 +1300,7 @@ void ppu2c0x_w( int num, offs_t offset, UINT8 data )
 				}
 
 				/* increment the address */
-				this_ppu->videoram_addr += this_ppu->add;
+				this_ppu->videomem_addr += this_ppu->add;
 			}
 			break;
 
@@ -1293,7 +1315,7 @@ void ppu2c0x_w( int num, offs_t offset, UINT8 data )
  *  Sprite DMA
  *
  *************************************/
-void ppu2c0x_spriteram_dma (int num, const UINT8 page)
+void ppu2c0x_spriteram_dma (const address_space *space, int num, const UINT8 page)
 {
 	int i;
 	int address = page << 8;
@@ -1308,12 +1330,12 @@ void ppu2c0x_spriteram_dma (int num, const UINT8 page)
 //logerror("   sprite DMA: %d (scanline: %d)\n", page, chips[num].scanline);
 	for (i = 0; i < SPRITERAM_SIZE; i++)
 	{
-		UINT8 spriteData = program_read_byte_8 (address + i);
-		ppu2c0x_w (num, PPU_SPRITE_DATA, spriteData);
+		UINT8 spriteData = memory_read_byte(space, address + i);
+		ppu2c0x_w (space, PPU_SPRITE_DATA, spriteData, num);
 	}
 
 	// should last 513 CPU cycles.
-	activecpu_adjust_icount(-513);
+	cpu_adjust_icount(space->cpu, -513);
 
 	// ????TODO : need to account for PPU rendering - this is roughly 4.5 scanlines eaten up.
 	// Because the DMA is only useful during vblank, this may not be strictly necessary since
@@ -1335,7 +1357,7 @@ void ppu2c0x_spriteram_dma (int num, const UINT8 page)
  *  PPU Rendering
  *
  *************************************/
-void ppu2c0x_render( int num, mame_bitmap *bitmap, int flipx, int flipy, int sx, int sy )
+void ppu2c0x_render( int num, bitmap_t *bitmap, int flipx, int flipy, int sx, int sy )
 {
 	/* check bounds */
 	if ( num >= intf->num )
@@ -1371,15 +1393,76 @@ void ppu2c0x_set_videorom_bank( int num, int start_page, int num_pages, int bank
 
 	bank &= ( chips[num].videorom_banks * ( CHARGEN_NUM_CHARS / bank_size ) ) - 1;
 
-	for( i = start_page; i < ( start_page + num_pages ); i++ )
-		chips[num].nes_vram[i] = bank * bank_size + 64 * ( i - start_page );
+	if (chips[num].has_videoram)
+	{
+		for ( i = start_page; i < start_page + num_pages; i++ )
+		{
+			if ( chips[num].videoram_banks_indices[i] != -1 )
+			{
+				memcpy( &chips[num].videoram[chips[num].videoram_banks_indices[i]*0x400], &chips[num].videomem[i*0x400], 0x400);
+			}
+			chips[num].videoram_banks_indices[i] = -1;
+			memset( &chips[num].dirtychar[start_page*0x400 >> 4], 1, (num_pages*0x400 >> 4));
+		}
+		chips[num].chars_are_dirty = 1;
+	}
+	else
+	{
+		for( i = start_page; i < ( start_page + num_pages ); i++ )
+			chips[num].nes_vram[i] = bank * bank_size + 64 * ( i - start_page );
+	}
 
 	{
 		int vram_start = start_page * 0x400;
 		int count = num_pages * 0x400;
 		int rom_start = bank * bank_size * 16;
 
-		memcpy( &chips[num].videoram[vram_start], &memory_region( intf->vrom_region[num] )[rom_start], count );
+		memcpy( &chips[num].videomem[vram_start], &memory_region( chips[num].machine, intf->vrom_region[num] )[rom_start], count );
+	}
+}
+
+/*************************************
+ *
+ *  PPU VideoRAM banking
+ *
+ *************************************/
+void ppu2c0x_set_videoram_bank( int num, int start_page, int num_pages, int bank, int bank_size )
+{
+	int i;
+
+	/* check bounds */
+	if ( num >= intf->num )
+	{
+		logerror( "PPU(set vrom bank): Attempting to access an unmapped chip\n" );
+		return;
+	}
+
+	if ( !chips[num].has_videoram )
+	{
+		logerror( "PPU(set vram bank): Attempting to switch videoram banks and no ram is mapped\n" );
+		return;
+	}
+
+	bank &= ( CHARGEN_NUM_CHARS / bank_size ) - 1;
+
+	for ( i = start_page; i < start_page + num_pages; i++ )
+	{
+		if ( chips[num].videoram_banks_indices[i] != -1 )
+		{
+			memcpy( &chips[num].videoram[chips[num].videoram_banks_indices[i]*0x400], &chips[num].videomem[i*0x400], 0x400);
+		}
+		chips[num].videoram_banks_indices[i] = (bank * bank_size * 16)/0x400 + (i - start_page);
+		memset( &chips[num].dirtychar[start_page*0x400 >> 4], 1, (num_pages*0x400 >> 4));
+	}
+	chips[num].chars_are_dirty = 1;
+
+	{
+		int vram_start = start_page * 0x400;
+		int count = num_pages * 0x400;
+		int ram_start = bank * bank_size * 16;
+
+		logerror( "ppu2c0x_set_videoram_bank: vram_start = %04x, count = %04x, ram_start = %04x\n", vram_start, count, ram_start );
+		memcpy( &chips[num].videomem[vram_start], &chips[num].videoram[ram_start], count );
 	}
 }
 
@@ -1449,44 +1532,44 @@ void ppu2c0x_set_mirroring( int num, int mirroring )
 	if (this_ppu->mirror_state == PPU_MIRROR_4SCREEN)
 		return;
 
-	/* setup our videoram handlers based on mirroring */
+	/* setup our videomem handlers based on mirroring */
 	switch( mirroring )
 	{
 		case PPU_MIRROR_VERT:
-			this_ppu->ppu_page[0] = &(this_ppu->videoram[0x2000]);
-			this_ppu->ppu_page[1] = &(this_ppu->videoram[0x2400]);
-			this_ppu->ppu_page[2] = &(this_ppu->videoram[0x2000]);
-			this_ppu->ppu_page[3] = &(this_ppu->videoram[0x2400]);
+			this_ppu->ppu_page[0] = &(this_ppu->videomem[0x2000]);
+			this_ppu->ppu_page[1] = &(this_ppu->videomem[0x2400]);
+			this_ppu->ppu_page[2] = &(this_ppu->videomem[0x2000]);
+			this_ppu->ppu_page[3] = &(this_ppu->videomem[0x2400]);
 			break;
 
 		case PPU_MIRROR_HORZ:
-			this_ppu->ppu_page[0] = &(this_ppu->videoram[0x2000]);
-			this_ppu->ppu_page[1] = &(this_ppu->videoram[0x2000]);
-			this_ppu->ppu_page[2] = &(this_ppu->videoram[0x2400]);
-			this_ppu->ppu_page[3] = &(this_ppu->videoram[0x2400]);
+			this_ppu->ppu_page[0] = &(this_ppu->videomem[0x2000]);
+			this_ppu->ppu_page[1] = &(this_ppu->videomem[0x2000]);
+			this_ppu->ppu_page[2] = &(this_ppu->videomem[0x2400]);
+			this_ppu->ppu_page[3] = &(this_ppu->videomem[0x2400]);
 			break;
 
 		case PPU_MIRROR_HIGH:
-			this_ppu->ppu_page[0] = &(this_ppu->videoram[0x2400]);
-			this_ppu->ppu_page[1] = &(this_ppu->videoram[0x2400]);
-			this_ppu->ppu_page[2] = &(this_ppu->videoram[0x2400]);
-			this_ppu->ppu_page[3] = &(this_ppu->videoram[0x2400]);
+			this_ppu->ppu_page[0] = &(this_ppu->videomem[0x2400]);
+			this_ppu->ppu_page[1] = &(this_ppu->videomem[0x2400]);
+			this_ppu->ppu_page[2] = &(this_ppu->videomem[0x2400]);
+			this_ppu->ppu_page[3] = &(this_ppu->videomem[0x2400]);
 			break;
 
 		case PPU_MIRROR_LOW:
-			this_ppu->ppu_page[0] = &(this_ppu->videoram[0x2000]);
-			this_ppu->ppu_page[1] = &(this_ppu->videoram[0x2000]);
-			this_ppu->ppu_page[2] = &(this_ppu->videoram[0x2000]);
-			this_ppu->ppu_page[3] = &(this_ppu->videoram[0x2000]);
+			this_ppu->ppu_page[0] = &(this_ppu->videomem[0x2000]);
+			this_ppu->ppu_page[1] = &(this_ppu->videomem[0x2000]);
+			this_ppu->ppu_page[2] = &(this_ppu->videomem[0x2000]);
+			this_ppu->ppu_page[3] = &(this_ppu->videomem[0x2000]);
 			break;
 
 		case PPU_MIRROR_NONE:
 		case PPU_MIRROR_4SCREEN:
 		default:
-			this_ppu->ppu_page[0] = &(this_ppu->videoram[0x2000]);
-			this_ppu->ppu_page[1] = &(this_ppu->videoram[0x2400]);
-			this_ppu->ppu_page[2] = &(this_ppu->videoram[0x2800]);
-			this_ppu->ppu_page[3] = &(this_ppu->videoram[0x2c00]);
+			this_ppu->ppu_page[0] = &(this_ppu->videomem[0x2000]);
+			this_ppu->ppu_page[1] = &(this_ppu->videomem[0x2400]);
+			this_ppu->ppu_page[2] = &(this_ppu->videomem[0x2800]);
+			this_ppu->ppu_page[3] = &(this_ppu->videomem[0x2c00]);
 			break;
 	}
 
@@ -1563,20 +1646,20 @@ void ppu2c0x_set_scanlines_per_frame( int num, int scanlines )
 
 READ8_HANDLER( ppu2c0x_0_r )
 {
-	return ppu2c0x_r( 0, offset );
+	return ppu2c0x_r( space, offset, 0 );
 }
 
 READ8_HANDLER( ppu2c0x_1_r )
 {
-	return ppu2c0x_r( 1, offset );
+	return ppu2c0x_r( space, offset, 1 );
 }
 
 WRITE8_HANDLER( ppu2c0x_0_w )
 {
-	ppu2c0x_w( 0, offset, data );
+	ppu2c0x_w( space, offset, data, 0 );
 }
 
 WRITE8_HANDLER( ppu2c0x_1_w )
 {
-	ppu2c0x_w( 1, offset, data );
+	ppu2c0x_w( space, offset, data, 1 );
 }
