@@ -90,18 +90,17 @@ sol divide doesn't seem to make much use of tilemaps at all, it uses them to fad
 */
 
 #include "driver.h"
-#include "deprecat.h"
 #include "profiler.h"
 #include "psikyosh.h"
 
 /* Needed for psikyosh_drawgfxzoom */
-static mame_bitmap *zoom_bitmap, *z_bitmap;
+static bitmap_t *zoom_bitmap, *z_bitmap;
 
 /* Psikyo PS6406B */
 /* --- BACKGROUNDS --- */
 
 /* 'Normal' layers, no line/columnscroll. No per-line effects */
-static void draw_bglayer(running_machine *machine, int layer, mame_bitmap *bitmap, const rectangle *cliprect )
+static void draw_bglayer(running_machine *machine, int layer, bitmap_t *bitmap, const rectangle *cliprect )
 {
 	gfx_element *gfx;
 	int offs=0, sx, sy;
@@ -167,7 +166,7 @@ static void draw_bglayer(running_machine *machine, int layer, mame_bitmap *bitma
 
 /* This is a complete bodge for the daraku text layers. There is not enough info to be sure how it is supposed to work */
 /* It appears that there are row/column scroll values for 2 seperate layers, just drawing it twice using one of each of the sets of values for now */
-static void draw_bglayertext(running_machine *machine, int layer, mame_bitmap *bitmap, const rectangle *cliprect )
+static void draw_bglayertext(running_machine *machine, int layer, bitmap_t *bitmap, const rectangle *cliprect )
 {
 	gfx_element *gfx;
 	int offs, sx, sy;
@@ -257,7 +256,7 @@ static void draw_bglayertext(running_machine *machine, int layer, mame_bitmap *b
 
 /* Row Scroll and/or Column Scroll/Zoom, has per-column Alpha/Bank/Priority. This isn't correct, just testing */
 /* For now I'm just using the first alpha/bank/priority values and sodding the rest of it */
-static void draw_bglayerscroll(running_machine *machine, int layer, mame_bitmap *bitmap, const rectangle *cliprect )
+static void draw_bglayerscroll(running_machine *machine, int layer, bitmap_t *bitmap, const rectangle *cliprect )
 {
 	gfx_element *gfx;
 	int offs, sx, sy;
@@ -295,7 +294,7 @@ static void draw_bglayerscroll(running_machine *machine, int layer, mame_bitmap
 /* Looks better with blending and one scroll value than with 1D linescroll and no zoom */
 #if 0
 		int bg_scrollx[256], bg_scrolly[512];
-		fillbitmap(zoom_bitmap, get_black_pen(machine), NULL);
+		bitmap_fill(zoom_bitmap, NULL, get_black_pen(screen->machine));
 		for (offs=0; offs<(0x400/4); offs++) /* 224 values for each */
 		{
 			bg_scrollx[offs] = (psikyosh_bgram[(scrollbank*0x800)/4 + offs - 0x4000/4] & 0x000001ff) >> 0;
@@ -335,7 +334,7 @@ static void draw_bglayerscroll(running_machine *machine, int layer, mame_bitmap
 }
 
 /* 3 BG layers, with priority */
-static void draw_background(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, UINT8 req_pri )
+static void draw_background(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, UINT8 req_pri )
 {
 	int i;
 
@@ -393,7 +392,8 @@ static void draw_background(running_machine *machine, mame_bitmap *bitmap, const
 /* sx and sy is top-left of entire sprite regardless of flip */
 /* Note that Level 5-4 of sbomberb boss is perfect! (Alpha blended zoomed) as well as S1945II logo */
 /* pixel is only plotted if z is >= priority_buffer[y][x] */
-static void psikyosh_drawgfxzoom( mame_bitmap *dest_bmp,const gfx_element *gfx,
+static void psikyosh_drawgfxzoom( running_machine *machine,
+		bitmap_t *dest_bmp,const gfx_element *gfx,
 		UINT32 code,UINT32 color,int flipx,int flipy,int offsx,int offsy,
 		const rectangle *clip,int transparency,int transparent_color,
 		int zoomx, int zoomy, int wide, int high, UINT32 z)
@@ -443,7 +443,7 @@ static void psikyosh_drawgfxzoom( mame_bitmap *dest_bmp,const gfx_element *gfx,
 			{
 				for (xtile = xstart; xtile != xend; xtile += xinc )
 				{
-					const pen_t *pal = &Machine->remapped_colortable[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
+					const pen_t *pal = &machine->pens[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
 					int source_base = ((code + code_offset++) % gfx->total_elements) * gfx->height;
 
 					int x_index_base, y_index, sx, sy, ex, ey;
@@ -707,7 +707,7 @@ static void psikyosh_drawgfxzoom( mame_bitmap *dest_bmp,const gfx_element *gfx,
 		/* Start drawing */
 		if( gfx )
 		{
-			const pen_t *pal = &Machine->remapped_colortable[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
+			const pen_t *pal = &machine->pens[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
 
 			int sprite_screen_height = ((high*gfx->height*(0x400*0x400))/zoomy + 0x200)>>10; /* Round up to nearest pixel */
 			int sprite_screen_width = ((wide*gfx->width*(0x400*0x400))/zoomx + 0x200)>>10;
@@ -930,7 +930,7 @@ static void psikyosh_drawgfxzoom( mame_bitmap *dest_bmp,const gfx_element *gfx,
 
 #define SPRITE_PRI(n) (((psikyosh_vidregs[2] << (4*n)) & 0xf0000000 ) >> 28)
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, UINT8 req_pri )
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, UINT8 req_pri )
 {
 	/*- Sprite Format 0x0000 - 0x37ff -**
 
@@ -1021,7 +1021,7 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 			/* start drawing */
 			if( zoom_table[BYTE_XOR_BE(zoomy)] && zoom_table[BYTE_XOR_BE(zoomx)] ) /* Avoid division-by-zero when table contains 0 (Uninitialised/Bug) */
 			{
-				psikyosh_drawgfxzoom(bitmap,gfx,tnum,colr,flpx,flpy,xpos,ypos,cliprect,trans,0,
+				psikyosh_drawgfxzoom(machine, bitmap,gfx,tnum,colr,flpx,flpy,xpos,ypos,cliprect,trans,0,
 									(UINT32)zoom_table[BYTE_XOR_BE(zoomx)], (UINT32)zoom_table[BYTE_XOR_BE(zoomy)], wide, high, listcntr);
 
 #if 0
@@ -1034,7 +1034,7 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 					sprintf(buf, "%X",xdim/16); /* Display Zoom in 16.16 */
 					if (machine->gamedrv->flags & ORIENTATION_SWAP_XY) {
 						x = ypos;
-						y = machine->screen[0].visarea.max_x - xpos; /* ORIENTATION_FLIP_Y */
+						y = video_screen_get_visible_area(machine->primary_screen)->max_x - xpos; /* ORIENTATION_FLIP_Y */
 					}
 					else {
 						x = xpos;
@@ -1054,10 +1054,12 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 
 VIDEO_START( psikyosh )
 {
-	zoom_bitmap = auto_bitmap_alloc(16*16, 16*16, BITMAP_FORMAT_INDEXED8);
+	int width = video_screen_get_width(machine->primary_screen);
+	int height = video_screen_get_height(machine->primary_screen);
+	z_bitmap = auto_bitmap_alloc(width, height, BITMAP_FORMAT_INDEXED16);
 
 	/* Need 16-bit z-buffer */
-	z_bitmap = auto_bitmap_alloc(machine->screen[0].width, machine->screen[0].height, BITMAP_FORMAT_INDEXED16);
+	zoom_bitmap = auto_bitmap_alloc(16*16, 16*16, BITMAP_FORMAT_INDEXED8);
 
 	machine->gfx[1]->color_granularity=16; /* 256 colour sprites with palette selectable on 16 colour boundaries */
 
@@ -1073,7 +1075,7 @@ VIDEO_START( psikyosh )
 
 }
 
-static void psikyosh_prelineblend( mame_bitmap *bitmap, const rectangle *cliprect )
+static void psikyosh_prelineblend( bitmap_t *bitmap, const rectangle *cliprect )
 {
 	/* There are 224 values for pre-lineblending. Using one for every row currently */
 	/* I suspect that it should be blended against black by the amount specified as
@@ -1097,7 +1099,7 @@ static void psikyosh_prelineblend( mame_bitmap *bitmap, const rectangle *cliprec
 	profiler_mark(PROFILER_END);
 }
 
-static void psikyosh_postlineblend( mame_bitmap *bitmap, const rectangle *cliprect )
+static void psikyosh_postlineblend( bitmap_t *bitmap, const rectangle *cliprect )
 {
 	/* There are 224 values for post-lineblending. Using one for every row currently */
 	UINT32 *dstline;
@@ -1128,14 +1130,14 @@ static void psikyosh_postlineblend( mame_bitmap *bitmap, const rectangle *clipre
 VIDEO_UPDATE( psikyosh ) /* Note the z-buffer on each sprite to get correct priority */
 {
 		int i;
-		fillbitmap(bitmap,get_black_pen(machine),cliprect);
-	fillbitmap(z_bitmap,0,cliprect); /* z-buffer */
+		bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
+	bitmap_fill(z_bitmap,cliprect,0); /* z-buffer */
 
 		psikyosh_prelineblend(bitmap, cliprect);
 
 		for (i=0; i<=7; i++) {
-		draw_sprites(machine, bitmap, cliprect, i); // When same priority bg's have higher pri
-		draw_background(machine, bitmap, cliprect, i);
+		draw_sprites(screen->machine, bitmap, cliprect, i); // When same priority bg's have higher pri
+		draw_background(screen->machine, bitmap, cliprect, i);
 			if((psikyosh_vidregs[2]&0xf) == i) psikyosh_postlineblend(bitmap, cliprect);
 		}
 	return 0;
@@ -1143,7 +1145,9 @@ VIDEO_UPDATE( psikyosh ) /* Note the z-buffer on each sprite to get correct prio
 
 VIDEO_EOF( psikyosh )
 {
-	buffer_spriteram32_w(0,0,0);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	buffer_spriteram32_w(space,0,0,0xffffffff);
 }
 
 /*popmessage   ("Regs %08x %08x %08x\n     %08x %08x %08x",
