@@ -20,27 +20,26 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "realbrk.h"
 
 //UINT16 *realbrk_vram_0, *realbrk_vram_1, *realbrk_vram_2, *realbrk_vregs;
 UINT16 *realbrk_vram_0, *realbrk_vram_1, *realbrk_vram_2, *realbrk_vregs, *realbrk_vram_0ras, *realbrk_vram_1ras;
-static mame_bitmap *tmpbitmap0 = NULL;
-static mame_bitmap *tmpbitmap1 = NULL;
+static bitmap_t *tmpbitmap0 = NULL;
+static bitmap_t *tmpbitmap1 = NULL;
 
 static int disable_video;
 
 WRITE16_HANDLER( realbrk_flipscreen_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		coin_counter_w(0,	data & 0x0001);
 		coin_counter_w(1,	data & 0x0004);
 
-		flip_screen_set(	data & 0x0080);
+		flip_screen_set(space->machine, 	data & 0x0080);
 	}
 
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		disable_video	=	data & 0x8000;
 	}
@@ -154,33 +153,18 @@ WRITE16_HANDLER( realbrk_vram_2_w )
 VIDEO_START(realbrk)
 {
 	/* Backgrounds */
-	tilemap_0 = tilemap_create(	get_tile_info_0, tilemap_scan_rows,
-								TILEMAP_TYPE_PEN,
-								16,16,
-								0x40, 0x20);
-
-	tilemap_1 = tilemap_create(	get_tile_info_1, tilemap_scan_rows,
-								TILEMAP_TYPE_PEN,
-								16,16,
-								0x40, 0x20);
+	tilemap_0 = tilemap_create(machine, get_tile_info_0, tilemap_scan_rows, 16, 16, 0x40, 0x20);
+	tilemap_1 = tilemap_create(machine, get_tile_info_1, tilemap_scan_rows, 16, 16, 0x40, 0x20);
 
 	/* Text */
-	tilemap_2 = tilemap_create(	get_tile_info_2, tilemap_scan_rows,
-								TILEMAP_TYPE_PEN,
-								8,8,
-								0x40, 0x20);
+	tilemap_2 = tilemap_create(machine, get_tile_info_2, tilemap_scan_rows,  8,  8, 0x40, 0x20);
 
 	tilemap_set_transparent_pen(tilemap_0,0);
 	tilemap_set_transparent_pen(tilemap_1,0);
 	tilemap_set_transparent_pen(tilemap_2,0);
 
-	tmpbitmap0 = auto_bitmap_alloc(	32,
-									32,
-									machine->screen[0].format);
-
-	tmpbitmap1 = auto_bitmap_alloc(	32,
-									32,
-									machine->screen[0].format);
+	tmpbitmap0 = auto_bitmap_alloc(32,32, video_screen_get_format(machine->primary_screen));
+	tmpbitmap1 = auto_bitmap_alloc(32,32, video_screen_get_format(machine->primary_screen));
 }
 
 /***************************************************************************
@@ -228,12 +212,12 @@ VIDEO_START(realbrk)
 
 ***************************************************************************/
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap,const rectangle *cliprect)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect)
 {
 	int offs;
 
-	int max_x		=	machine->screen[0].width;
-	int max_y		=	machine->screen[0].height;
+	int max_x = video_screen_get_width(machine->primary_screen);
+	int max_y = video_screen_get_height(machine->primary_screen);
 
 	rectangle spritetile_clip;
 	spritetile_clip.min_x = 0;
@@ -278,8 +262,8 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap,const rec
 		xdim	=		((zoom & 0x00ff) >> 0) << (16-6+4);
 		ydim	=		((zoom & 0xff00) >> 8) << (16-6+4);
 
-		if (flip_screen_x)	{	flipx = !flipx;		sx = (max_x << 16) - sx - xnum * xdim;	}
-		if (flip_screen_y)	{	flipy = !flipy;		sy = (max_y << 16) - sy - ynum * ydim;	}
+		if (flip_screen_x_get(machine))	{	flipx = !flipx;		sx = (max_x << 16) - sx - xnum * xdim;	}
+		if (flip_screen_y_get(machine))	{	flipy = !flipy;		sy = (max_y << 16) - sy - ynum * ydim;	}
 
 		if (flipx)	{ xstart = xnum-1;  xend = -1;    xinc = -1; }
 		else		{ xstart = 0;       xend = xnum;  xinc = +1; }
@@ -313,8 +297,8 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap,const rec
 				// buffer the tile and rotate it into bitmap
 				if( rot )
 				{
-					fillbitmap( tmpbitmap0, machine->pens[0], &spritetile_clip );
-					fillbitmap( tmpbitmap1, machine->pens[0], &spritetile_clip );
+					bitmap_fill( tmpbitmap0, &spritetile_clip , 0);
+					bitmap_fill( tmpbitmap1, &spritetile_clip , 0);
 					drawgfxzoom(	tmpbitmap0,machine->gfx[gfx],
 									code++,
 									color,
@@ -395,12 +379,12 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap,const rec
 
 /* DaiDaiKakumei */
 /* layer : 0== bghigh<spr    1== bglow<spr<bghigh     2==spr<bglow    3==boarder */
-static void dai2kaku_draw_sprites( mame_bitmap *bitmap,const rectangle *cliprect, int layer)
+static void dai2kaku_draw_sprites(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect, int layer)
 {
 	int offs;
 
-	int max_x		=	Machine->screen[0].width;
-	int max_y		=	Machine->screen[0].height;
+	int max_x = video_screen_get_width(machine->primary_screen);
+	int max_y = video_screen_get_height(machine->primary_screen);
 
 	for ( offs = 0x3000/2; offs < 0x3600/2; offs += 2/2 )
 	{
@@ -440,8 +424,8 @@ static void dai2kaku_draw_sprites( mame_bitmap *bitmap,const rectangle *cliprect
 		xdim	=		((zoom & 0x00ff) >> 0) << (16-6+4);
 		ydim	=		((zoom & 0xff00) >> 8) << (16-6+4);
 
-		if (flip_screen_x)	{	flipx = !flipx;		sx = (max_x << 16) - sx - xnum * xdim;	}
-		if (flip_screen_y)	{	flipy = !flipy;		sy = (max_y << 16) - sy - ynum * ydim;	}
+		if (flip_screen_x_get(machine))	{	flipx = !flipx;		sx = (max_x << 16) - sx - xnum * xdim;	}
+		if (flip_screen_y_get(machine))	{	flipy = !flipy;		sy = (max_y << 16) - sy - ynum * ydim;	}
 
 		if (flipx)	{ xstart = xnum-1;  xend = -1;    xinc = -1; }
 		else		{ xstart = 0;       xend = xnum;  xinc = +1; }
@@ -459,7 +443,7 @@ static void dai2kaku_draw_sprites( mame_bitmap *bitmap,const rectangle *cliprect
 				int scalex = (sx + (x + 1) * xdim) / 0x10000 - currx;
 				int scaley = (sy + (y + 1) * ydim) / 0x10000 - curry;
 
-				drawgfxzoom(	bitmap,Machine->gfx[gfx],
+				drawgfxzoom(	bitmap,machine->gfx[gfx],
 								code++,
 								color,
 								flipx, flipy,
@@ -532,16 +516,16 @@ if ( input_code_pressed(KEYCODE_Z) )
 
 	if (disable_video)
 	{
-		fillbitmap(bitmap,get_black_pen(machine),cliprect);
+		bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
 		return 0;
 	}
 	else
-		fillbitmap(bitmap,machine->pens[realbrk_vregs[0xc/2] & 0x7fff],cliprect);
+		bitmap_fill(bitmap,cliprect,realbrk_vregs[0xc/2] & 0x7fff);
 
 	if (layers_ctrl & 2)	tilemap_draw(bitmap,cliprect,tilemap_1,0,0);
 	if (layers_ctrl & 1)	tilemap_draw(bitmap,cliprect,tilemap_0,0,0);
 
-	if (layers_ctrl & 8)	draw_sprites(machine,bitmap,cliprect);
+	if (layers_ctrl & 8)	draw_sprites(screen->machine,bitmap,cliprect);
 
 	if (layers_ctrl & 4)	tilemap_draw(bitmap,cliprect,tilemap_2,0,0);
 
@@ -600,16 +584,16 @@ if ( input_code_pressed(KEYCODE_Z) )
 
 	if (disable_video)
 	{
-		fillbitmap(bitmap,get_black_pen(machine),cliprect);
+		bitmap_fill(bitmap,cliprect,get_black_pen(screen->machine));
 		return 0;
 	}
 	else
-		fillbitmap(bitmap,machine->pens[realbrk_vregs[0xc/2] & 0x7fff],cliprect);
+		bitmap_fill(bitmap,cliprect,realbrk_vregs[0xc/2] & 0x7fff);
 
 
 
 	// spr 0
-	if (layers_ctrl & 8)	dai2kaku_draw_sprites(bitmap,cliprect,2);
+	if (layers_ctrl & 8)	dai2kaku_draw_sprites(screen->machine,bitmap,cliprect,2);
 
 	// bglow
 	if( realbrk_vregs[8/2] & (0x8000)){
@@ -619,7 +603,7 @@ if ( input_code_pressed(KEYCODE_Z) )
 	}
 
 	// spr 1
-	if (layers_ctrl & 8)	dai2kaku_draw_sprites(bitmap,cliprect,1);
+	if (layers_ctrl & 8)	dai2kaku_draw_sprites(screen->machine,bitmap,cliprect,1);
 
 	// bghigh
 	if( realbrk_vregs[8/2] & (0x8000)){
@@ -629,7 +613,7 @@ if ( input_code_pressed(KEYCODE_Z) )
 	}
 
 	// spr 2
-	if (layers_ctrl & 8)	dai2kaku_draw_sprites(bitmap,cliprect,0);
+	if (layers_ctrl & 8)	dai2kaku_draw_sprites(screen->machine,bitmap,cliprect,0);
 
 	// fix
 	if (layers_ctrl & 4)	tilemap_draw(bitmap,cliprect,tilemap_2,0,0);
