@@ -23,7 +23,6 @@ System 24      68000x2  315-5292   315-5293  315-5294  315-5242        ym2151 da
 */
 
 #include "driver.h"
-#include "deprecat.h"
 #include "segaic24.h"
 
 
@@ -40,10 +39,18 @@ static void set_color(running_machine *machine, int color, UINT8 r, UINT8 g, UIN
 		g = 0.6*g;
 		b = 0.6*b;
 	}
-	palette_set_color(machine,color+machine->drv->total_colors/2, MAKE_RGB(r, g, b));
+	palette_set_color(machine,color+machine->config->total_colors/2, MAKE_RGB(r, g, b));
 }
 
 // 315-5242
+
+// qgh expects to be able to read the palette shared between CPUs
+READ16_HANDLER( system24temp_sys16_paletteram1_r )
+{
+	return paletteram16[offset];
+}
+
+
 WRITE16_HANDLER (system24temp_sys16_paletteram1_w)
 {
 	int r, g, b;
@@ -65,7 +72,7 @@ WRITE16_HANDLER (system24temp_sys16_paletteram1_w)
 	r |= r >> 5;
 	g |= g >> 5;
 	b |= b >> 5;
-	set_color(Machine, offset, r, g, b, data & 0x8000);
+	set_color(space->machine, offset, r, g, b, data & 0x8000);
 }
 
 // - System 24
@@ -128,7 +135,7 @@ static TILE_GET_INFO( sys24_tile_info_1w )
 	SET_TILE_INFO(sys24_char_gfx_index, val & sys24_tile_mask, (val >> 7) & 0xff, 0);
 }
 
-static void sys24_tile_dirtyall(void)
+static STATE_POSTLOAD( sys24_tile_dirtyall )
 {
 	memset(sys24_char_dirtymap, 1, SYS24_TILES);
 	sys24_char_dirty = 1;
@@ -149,10 +156,10 @@ void sys24_tile_vh_start(running_machine *machine, UINT16 tile_mask)
 
 	sys24_char_dirtymap = auto_malloc(SYS24_TILES);
 
-	sys24_tile_layer[0] = tilemap_create(sys24_tile_info_0s, tilemap_scan_rows, TILEMAP_TYPE_PEN, 8, 8, 64, 64);
-	sys24_tile_layer[1] = tilemap_create(sys24_tile_info_0w, tilemap_scan_rows, TILEMAP_TYPE_PEN, 8, 8, 64, 64);
-	sys24_tile_layer[2] = tilemap_create(sys24_tile_info_1s, tilemap_scan_rows, TILEMAP_TYPE_PEN, 8, 8, 64, 64);
-	sys24_tile_layer[3] = tilemap_create(sys24_tile_info_1w, tilemap_scan_rows, TILEMAP_TYPE_PEN, 8, 8, 64, 64);
+	sys24_tile_layer[0] = tilemap_create(machine, sys24_tile_info_0s, tilemap_scan_rows,  8, 8, 64, 64);
+	sys24_tile_layer[1] = tilemap_create(machine, sys24_tile_info_0w, tilemap_scan_rows,  8, 8, 64, 64);
+	sys24_tile_layer[2] = tilemap_create(machine, sys24_tile_info_1s, tilemap_scan_rows,  8, 8, 64, 64);
+	sys24_tile_layer[3] = tilemap_create(machine, sys24_tile_info_1w, tilemap_scan_rows,  8, 8, 64, 64);
 
 	tilemap_set_transparent_pen(sys24_tile_layer[0], 0);
 	tilemap_set_transparent_pen(sys24_tile_layer[1], 0);
@@ -164,16 +171,13 @@ void sys24_tile_vh_start(running_machine *machine, UINT16 tile_mask)
 	memset(sys24_char_dirtymap, 1, SYS24_TILES);
 	sys24_char_dirty = 1;
 
-	machine->gfx[sys24_char_gfx_index] = allocgfx(&sys24_char_layout);
+	machine->gfx[sys24_char_gfx_index] = allocgfx(machine, &sys24_char_layout);
 
-	if (machine->drv->color_table_len)
-		machine->gfx[sys24_char_gfx_index]->total_colors = machine->drv->color_table_len / 16;
-	else
-		machine->gfx[sys24_char_gfx_index]->total_colors = machine->drv->total_colors / 16;
+	machine->gfx[sys24_char_gfx_index]->total_colors = machine->config->total_colors / 16;
 
-	state_save_register_global_pointer(sys24_tile_ram, 0x10000/2);
-	state_save_register_global_pointer(sys24_char_ram, 0x80000/2);
-	state_save_register_func_postload(sys24_tile_dirtyall);
+	state_save_register_global_pointer(machine, sys24_tile_ram, 0x10000/2);
+	state_save_register_global_pointer(machine, sys24_char_ram, 0x80000/2);
+	state_save_register_postload(machine, sys24_tile_dirtyall, NULL);
 }
 
 void sys24_tile_update(running_machine *machine)
@@ -194,7 +198,7 @@ void sys24_tile_update(running_machine *machine)
 	}
 }
 
-static void sys24_tile_draw_rect(running_machine *machine, mame_bitmap *bm, mame_bitmap *tm, mame_bitmap *dm, const UINT16 *mask,
+static void sys24_tile_draw_rect(running_machine *machine, bitmap_t *bm, bitmap_t *tm, bitmap_t *dm, const UINT16 *mask,
 								 UINT16 tpri, UINT8 lpri, int win, int sx, int sy, int xx1, int yy1, int xx2, int yy2)
 {
 	int y;
@@ -328,7 +332,7 @@ static void sys24_tile_draw_rect(running_machine *machine, mame_bitmap *bm, mame
 // about sprite priority hence the lack of support for the
 // priority_bitmap
 
-static void sys24_tile_draw_rect_rgb(running_machine *machine, mame_bitmap *bm, mame_bitmap *tm, mame_bitmap *dm, const UINT16 *mask,
+static void sys24_tile_draw_rect_rgb(running_machine *machine, bitmap_t *bm, bitmap_t *tm, bitmap_t *dm, const UINT16 *mask,
 									 UINT16 tpri, UINT8 lpri, int win, int sx, int sy, int xx1, int yy1, int xx2, int yy2)
 {
 	int y;
@@ -440,7 +444,7 @@ static void sys24_tile_draw_rect_rgb(running_machine *machine, mame_bitmap *bm,
 	}
 }
 
-void sys24_tile_draw(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int layer, int lpri, int flags)
+void sys24_tile_draw(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int layer, int lpri, int flags)
 {
 	UINT16 hscr = sys24_tile_ram[0x5000+(layer >> 1)];
 	UINT16 vscr = sys24_tile_ram[0x5004+(layer >> 1)];
@@ -514,8 +518,8 @@ void sys24_tile_draw(running_machine *machine, mame_bitmap *bitmap, const rectan
 		};
 
 	} else {
-		mame_bitmap *bm, *tm;
-		void (*draw)(running_machine *machine, mame_bitmap *, mame_bitmap *, mame_bitmap *, const UINT16 *,
+		bitmap_t *bm, *tm;
+		void (*draw)(running_machine *machine, bitmap_t *, bitmap_t *, bitmap_t *, const UINT16 *,
 					 UINT16, UINT8, int, int, int, int, int, int, int);
 		int win = layer & 1;
 
@@ -607,35 +611,35 @@ WRITE16_HANDLER(sys24_char_w)
 
 READ32_HANDLER(sys24_tile32_r)
 {
-	return sys24_tile_r(offset*2, mem_mask&0xffff) | sys24_tile_r((offset*2)+1, mem_mask>>16)<<16;
+	return sys24_tile_r(space, offset*2, mem_mask&0xffff) | sys24_tile_r(space, (offset*2)+1, mem_mask>>16)<<16;
 }
 
 READ32_HANDLER(sys24_char32_r)
 {
-	return sys24_char_r(offset*2, mem_mask&0xffff) | sys24_char_r((offset*2)+1, mem_mask>>16)<<16;
+	return sys24_char_r(space, offset*2, mem_mask&0xffff) | sys24_char_r(space, (offset*2)+1, mem_mask>>16)<<16;
 }
 
 WRITE32_HANDLER(sys24_tile32_w)
 {
-	sys24_tile_w(offset*2, data&0xffff, mem_mask&0xffff);
-	sys24_tile_w((offset*2)+1, data>>16, mem_mask>>16);
+	sys24_tile_w(space, offset*2, data&0xffff, mem_mask&0xffff);
+	sys24_tile_w(space, (offset*2)+1, data>>16, mem_mask>>16);
 }
 
 WRITE32_HANDLER(sys24_char32_w)
 {
-	sys24_char_w(offset*2, data&0xffff, mem_mask&0xffff);
-	sys24_char_w((offset*2)+1, data>>16, mem_mask>>16);
+	sys24_char_w(space,offset*2, data&0xffff, mem_mask&0xffff);
+	sys24_char_w(space,(offset*2)+1, data>>16, mem_mask>>16);
 }
 
 // - System 24
 
 static UINT16 *sys24_sprite_ram;
 
-void sys24_sprite_vh_start(void)
+void sys24_sprite_vh_start(running_machine *machine)
 {
 	sys24_sprite_ram = auto_malloc(0x40000);
 
-	state_save_register_global_pointer(sys24_sprite_ram, 0x40000/2);
+	state_save_register_global_pointer(machine, sys24_sprite_ram, 0x40000/2);
 	//  kc = 0;
 }
 
@@ -659,7 +663,7 @@ void sys24_sprite_vh_start(void)
     0   11------    --------
 */
 
-void sys24_sprite_draw(mame_bitmap *bitmap, const rectangle *cliprect, const int *spri)
+void sys24_sprite_draw(bitmap_t *bitmap, const rectangle *cliprect, const int *spri)
 {
 	UINT16 curspr = 0;
 	int countspr = 0;
@@ -873,10 +877,10 @@ READ16_HANDLER(sys24_sprite_r)
 
 static UINT16 sys24_mixer_reg[0x10];
 
-void sys24_mixer_vh_start(void)
+void sys24_mixer_vh_start(running_machine *machine)
 {
 	memset(sys24_mixer_reg, 0, sizeof(sys24_mixer_reg));
-	state_save_register_global_array(sys24_mixer_reg);
+	state_save_register_global_array(machine, sys24_mixer_reg);
 }
 
 WRITE16_HANDLER (sys24_mixer_w)
