@@ -136,7 +136,6 @@ Note:   if MAME_DEBUG is defined, pressing Z with:
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "sound/x1_010.h"
 #include "seta.h"
 
@@ -153,6 +152,7 @@ int seta_tiles_offset;
 UINT16 *seta_vram_0, *seta_vctrl_0;
 UINT16 *seta_vram_2, *seta_vctrl_2;
 UINT16 *seta_vregs;
+size_t seta_paletteram_size;
 
 UINT16 *seta_workram; // Used for zombraid crosshair hack
 
@@ -207,6 +207,7 @@ static const struct x_offset game_offsets[] =
 	{ "triplfun", {  0,  0 }, { -1, -1 } },	// correct (test mode) flip screen not supported?
 	{ "wrofaero", {  0,  0 }, {  0,  0 } },	// unknown
 	{ "jjsquawk", {  1,  1 }, { -1, -1 } },	// correct (test mode)
+	{ "jjsquawb", {  1,  1 }, { -1, -1 } },	// correct (test mode)
 	{ "kamenrid", {  0,  0 }, { -2, -2 } },	// correct (map, banpresto logo)
 	{ "extdwnhl", {  0,  0 }, { -2, -2 } },	// correct (test grid, background images)
 	{ "sokonuke", {  0,  0 }, { -2, -2 } },	// correct (game selection, test grid)
@@ -226,17 +227,17 @@ static const struct x_offset *global_offsets;
     ---- --1-       Coin #1 Counter
     ---- ---0       Coin #0 Counter     */
 
-void seta_coin_lockout_w(int data)
+void seta_coin_lockout_w(running_machine *machine, int data)
 {
 	static int seta_coin_lockout = 1;
 	static const game_driver *seta_driver = NULL;
 	static const char *const seta_nolockout[8] = { "blandia", "gundhara", "kamenrid", "zingzip", "eightfrc", "extdwnhl", "sokonuke", "zombraid"};
 
 	/* Only compute seta_coin_lockout when confronted with a new gamedrv */
-	if (seta_driver != Machine->gamedrv)
+	if (seta_driver != machine->gamedrv)
 	{
 		int i;
-		seta_driver = Machine->gamedrv;
+		seta_driver = machine->gamedrv;
 
 		seta_coin_lockout = 1;
 		for (i=0; i<ARRAY_LENGTH(seta_nolockout); i++)
@@ -276,9 +277,9 @@ WRITE16_HANDLER( seta_vregs_w )
         ---- ---- ---- -2--     Coin #0 Lock Out
         ---- ---- ---- --1-     Coin #1 Counter
         ---- ---- ---- ---0     Coin #0 Counter     */
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 			{
-				seta_coin_lockout_w (data & 0x0f);
+				seta_coin_lockout_w (space->machine, data & 0x0f);
 				if (sndti_exists(SOUND_X1_010, 0))
 					seta_sound_enable_w (data & 0x20);
 				coin_counter_w(0,data & 0x01);
@@ -287,7 +288,7 @@ WRITE16_HANDLER( seta_vregs_w )
 			break;
 
 		case 2/2:
-			if (ACCESSING_LSB)
+			if (ACCESSING_BITS_0_7)
 			{
 				int new_bank;
 
@@ -304,8 +305,8 @@ WRITE16_HANDLER( seta_vregs_w )
 
 				if (new_bank != seta_samples_bank)
 				{
-					UINT8 *rom = memory_region(REGION_SOUND1);
-					int samples_len = memory_region_length(REGION_SOUND1);
+					UINT8 *rom = memory_region(space->machine, "x1");
+					int samples_len = memory_region_length(space->machine, "x1");
 					int addr;
 
 					seta_samples_bank = new_bank;
@@ -318,7 +319,7 @@ WRITE16_HANDLER( seta_vregs_w )
 						if ( (samples_len > 0x100000) && ((addr+0x40000) <= samples_len) )
 							memcpy(&rom[0xc0000],&rom[addr],0x40000);
 						else
-							logerror("PC %06X - Invalid samples bank %02X !\n", activecpu_get_pc(), new_bank);
+							logerror("PC %06X - Invalid samples bank %02X !\n", cpu_get_pc(space->cpu), new_bank);
 					}
 					else if (samples_len == 0x480000)	/* zombraid */
 					{
@@ -418,7 +419,7 @@ WRITE16_HANDLER( seta_vram_2_w )
 
 WRITE16_HANDLER( twineagl_tilebank_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		data &= 0xff;
 		if (twineagl_tilebank[offset] != data)
@@ -445,19 +446,19 @@ VIDEO_START( seta_2_layers )
        at any given time */
 
 	/* layer 0 */
-	tilemap_0 = tilemap_create(	get_tile_info_0, tilemap_scan_rows,
-								TILEMAP_TYPE_PEN, 16,16, 64,32 );
+	tilemap_0 = tilemap_create(	machine, get_tile_info_0, tilemap_scan_rows,
+								 16,16, 64,32 );
 
-	tilemap_1 = tilemap_create(	get_tile_info_1, tilemap_scan_rows,
-								TILEMAP_TYPE_PEN, 16,16, 64,32 );
+	tilemap_1 = tilemap_create(	machine, get_tile_info_1, tilemap_scan_rows,
+								 16,16, 64,32 );
 
 
 	/* layer 1 */
-	tilemap_2 = tilemap_create(	get_tile_info_2, tilemap_scan_rows,
-								TILEMAP_TYPE_PEN, 16,16, 64,32 );
+	tilemap_2 = tilemap_create(	machine, get_tile_info_2, tilemap_scan_rows,
+								 16,16, 64,32 );
 
-	tilemap_3 = tilemap_create(	get_tile_info_3, tilemap_scan_rows,
-								TILEMAP_TYPE_PEN, 16,16, 64,32 );
+	tilemap_3 = tilemap_create(	machine, get_tile_info_3, tilemap_scan_rows,
+								 16,16, 64,32 );
 
 		tilemaps_flip = 0;
 
@@ -478,11 +479,11 @@ VIDEO_START( seta_1_layer )
        at any given time */
 
 	/* layer 0 */
-	tilemap_0 = tilemap_create(	get_tile_info_0, tilemap_scan_rows,
-								TILEMAP_TYPE_PEN, 16,16, 64,32 );
+	tilemap_0 = tilemap_create(	machine, get_tile_info_0, tilemap_scan_rows,
+								 16,16, 64,32 );
 
-	tilemap_1 = tilemap_create(	get_tile_info_1, tilemap_scan_rows,
-								TILEMAP_TYPE_PEN, 16,16, 64,32 );
+	tilemap_1 = tilemap_create(	machine, get_tile_info_1, tilemap_scan_rows,
+								 16,16, 64,32 );
 
 
 	/* NO layer 1 */
@@ -504,11 +505,11 @@ VIDEO_START( twineagl_1_layer )
        at any given time */
 
 	/* layer 0 */
-	tilemap_0 = tilemap_create(	twineagl_get_tile_info_0, tilemap_scan_rows,
-								TILEMAP_TYPE_PEN, 16,16, 64,32 );
+	tilemap_0 = tilemap_create(	machine, twineagl_get_tile_info_0, tilemap_scan_rows,
+								 16,16, 64,32 );
 
-	tilemap_1 = tilemap_create(	twineagl_get_tile_info_1, tilemap_scan_rows,
-								TILEMAP_TYPE_PEN, 16,16, 64,32 );
+	tilemap_1 = tilemap_create(	machine, twineagl_get_tile_info_1, tilemap_scan_rows,
+								 16,16, 64,32 );
 
 
 	/* NO layer 1 */
@@ -562,11 +563,15 @@ VIDEO_START( oisipuzl_2_layers )
 PALETTE_INIT( blandia )
 {
 	int color, pen;
-	for( color = 0; color < 32; color++ )
-		for( pen = 0; pen < 64; pen++ )
+
+	/* allocate the colortable */
+	machine->colortable = colortable_alloc(machine, 0x600);
+
+	for (color = 0; color < 0x20; color++)
+		for (pen = 0; pen < 0x40; pen++)
 		{
-			colortable[color * 64 + pen + 16*32]       = (pen % 16) + color * 0x10 + 16*32*1;
-			colortable[color * 64 + pen + 16*32+64*32] = pen        + 16*32*2;
+			colortable_entry_set_value(machine->colortable, 0x200 + ((color << 6) | pen), 0x200 + ((color << 4) | (pen & 0x0f)));
+			colortable_entry_set_value(machine->colortable, 0xa00 + ((color << 6) | pen), 0x400 + pen);
 		}
 }
 
@@ -577,11 +582,15 @@ PALETTE_INIT( blandia )
 PALETTE_INIT( gundhara )
 {
 	int color, pen;
-	for( color = 0; color < 32; color++ )
-		for( pen = 0; pen < 64; pen++ )
+
+	/* allocate the colortable */
+	machine->colortable = colortable_alloc(machine, 0x600);
+
+	for (color = 0; color < 0x20; color++)
+		for (pen = 0; pen < 0x40; pen++)
 		{
-			colortable[color * 64 + pen + 32*16 + 32*64*0] = (((color&~3) * 16 + pen)%(32*16)) + 32*16*2;
-			colortable[color * 64 + pen + 32*16 + 32*64*1] = (((color&~3) * 16 + pen)%(32*16)) + 32*16*1;
+			colortable_entry_set_value(machine->colortable, 0x200 + ((color << 6) | pen), 0x400 + ((((color & ~3) << 4) + pen) & 0x1ff));
+			colortable_entry_set_value(machine->colortable, 0xa00 + ((color << 6) | pen), 0x200 + ((((color & ~3) << 4) + pen) & 0x1ff));
 		}
 }
 
@@ -591,11 +600,15 @@ PALETTE_INIT( gundhara )
 PALETTE_INIT( jjsquawk )
 {
 	int color, pen;
-	for( color = 0; color < 32; color++ )
-		for( pen = 0; pen < 64; pen++ )
+
+	/* allocate the colortable */
+	machine->colortable = colortable_alloc(machine, 0x600);
+
+	for (color = 0; color < 0x20; color++)
+		for (pen = 0; pen < 0x40; pen++)
 		{
-			colortable[color * 64 + pen + 32*16 + 32*64*0] = ((color * 16 + pen)%(32*16)) + 32*16*2;
-			colortable[color * 64 + pen + 32*16 + 32*64*1] = ((color * 16 + pen)%(32*16)) + 32*16*1;
+			colortable_entry_set_value(machine->colortable, 0x200 + ((color << 6) | pen), 0x400 + (((color << 4) + pen) & 0x1ff));
+			colortable_entry_set_value(machine->colortable, 0xa00 + ((color << 6) | pen), 0x200 + (((color << 4) + pen) & 0x1ff));
 		}
 }
 
@@ -604,9 +617,13 @@ PALETTE_INIT( jjsquawk )
 PALETTE_INIT( zingzip )
 {
 	int color, pen;
-	for( color = 0; color < 32; color++ )
-		for( pen = 0; pen < 64; pen++ )
-			colortable[color * 64 + pen + 32*16*2] = ((color * 16 + pen)%(32*16)) + 32*16*2;
+
+	/* allocate the colortable */
+	machine->colortable = colortable_alloc(machine, 0x600);
+
+	for (color = 0; color < 0x20; color++)
+		for (pen = 0; pen < 0x40; pen++)
+			colortable_entry_set_value(machine->colortable, 0x400 + ((color << 6) | pen), 0x400 + (((color << 4) + pen) & 0x1ff));
 }
 
 // color prom
@@ -625,24 +642,62 @@ PALETTE_INIT( usclssic )
 	int color, pen;
 	int x;
 
+	/* allocate the colortable */
+	machine->colortable = colortable_alloc(machine, 0x400);
+
 	/* DECODE PROM */
-	for (x = 0x000; x < 0x200 ; x++)
+	for (x = 0; x < 0x200 ; x++)
 	{
-		int data;
+		UINT16 data = (color_prom[x*2] <<8) | color_prom[x*2+1];
 
-		data = (color_prom[x*2] <<8) | color_prom[x*2+1];
+		rgb_t color = MAKE_RGB(pal5bit(data >> 10), pal5bit(data >> 5), pal5bit(data >> 0));
 
-		if (x>=0x100) palette_set_color_rgb(machine,x,pal5bit(data >> 10),pal5bit(data >> 5),pal5bit(data >> 0));
-		else palette_set_color_rgb(machine,x+0x300,pal5bit(data >> 10),pal5bit(data >> 5),pal5bit(data >> 0));
+		if (x >= 0x100)
+			colortable_palette_set_color(machine->colortable, x + 0x000, color);
+		else
+			colortable_palette_set_color(machine->colortable, x + 0x300, color);
 	}
 
-	for( color = 0; color < 32; color++ )
-		for( pen = 0; pen < 64; pen++ )
-			colortable[color * 64 + pen + 512] =  ((((color & 0x1f) * 16 + pen)%512)+512);
-
+	for (color = 0; color < 0x20; color++)
+		for (pen = 0; pen < 0x40; pen++)
+			colortable_entry_set_value(machine->colortable, 0x200 + ((color << 6) | pen), 0x200 + (((color << 4) + pen) & 0x1ff));
 }
 
 
+static void set_pens(running_machine *machine)
+{
+	offs_t i;
+
+	for (i = 0; i < seta_paletteram_size / 2; i++)
+	{
+		UINT16 data = paletteram16[i];
+
+		rgb_t color = MAKE_RGB(pal5bit(data >> 10), pal5bit(data >> 5), pal5bit(data >> 0));
+
+		if (machine->colortable != NULL)
+			colortable_palette_set_color(machine->colortable, i, color);
+		else
+			palette_set_color(machine, i, color);
+	}
+}
+
+
+static void usclssic_set_pens(colortable_t *colortable)
+{
+	offs_t i;
+
+	for (i = 0; i < 0x200; i++)
+	{
+		UINT16 data = paletteram16[i];
+
+		rgb_t color = MAKE_RGB(pal5bit(data >> 10), pal5bit(data >> 5), pal5bit(data >> 0));
+
+		if (i >= 0x100)
+			colortable_palette_set_color(colortable, i - 0x100, color);
+		else
+			colortable_palette_set_color(colortable, i + 0x200, color);
+	}
+}
 
 
 
@@ -655,12 +710,12 @@ PALETTE_INIT( usclssic )
 ***************************************************************************/
 
 
-static void draw_sprites_map(running_machine *machine, mame_bitmap *bitmap,const rectangle *cliprect)
+static void draw_sprites_map(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect)
 {
 	int offs, col;
 	int xoffs, yoffs;
 
-	int total_color_codes	=	machine->drv->gfxdecodeinfo[0].total_color_codes;
+	int total_color_codes	=	machine->config->gfxdecodeinfo[0].total_color_codes;
 
 	int ctrl	=	spriteram16[ 0x600/2 ];
 	int ctrl2	=	spriteram16[ 0x602/2 ];
@@ -759,12 +814,12 @@ twineagl:   000 027 00 0f   (test mode)
 
 
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap,const rectangle *cliprect)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect)
 {
 	int offs;
 	int xoffs, yoffs;
 
-	int total_color_codes	=	machine->drv->gfxdecodeinfo[0].total_color_codes;
+	int total_color_codes	=	machine->config->gfxdecodeinfo[0].total_color_codes;
 
 	int ctrl	=	spriteram16[ 0x600/2 ];
 	int ctrl2	=	spriteram16[ 0x602/2 ];
@@ -798,7 +853,7 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap,const rec
 
 		if (flip)
 		{
-			y = (0x100 - machine->screen[0].height) + max_y - y;
+			y = (0x100 - video_screen_get_height(machine->primary_screen)) + max_y - y;
 			flipx = !flipx;
 			flipy = !flipy;
 		}
@@ -832,14 +887,15 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap,const rec
 /* For games without tilemaps */
 VIDEO_UPDATE( seta_no_layers )
 {
-	fillbitmap(bitmap,machine->pens[0x1f0],cliprect);
-	draw_sprites(machine,bitmap,cliprect);
+	set_pens(screen->machine);
+	bitmap_fill(bitmap,cliprect,0x1f0);
+	draw_sprites(screen->machine,bitmap,cliprect);
 	return 0;
 }
 
 
 /* For games with 1 or 2 tilemaps */
-VIDEO_UPDATE( seta )
+static VIDEO_UPDATE( seta_layers )
 {
 	int layers_ctrl = -1;
 	int enab_0, enab_1, x_0, x_1, y_0, y_1;
@@ -847,7 +903,8 @@ VIDEO_UPDATE( seta )
 	int order	= 	0;
 	int flip	=	(spriteram16[ 0x600/2 ] & 0x40) >> 6;
 
-	int vis_dimy = machine->screen[0].visarea.max_y - machine->screen[0].visarea.min_y + 1;
+	const rectangle *visarea = video_screen_get_visible_area(screen);
+	int vis_dimy = visarea->max_y - visarea->min_y + 1;
 
 	flip ^= tilemaps_flip;
 
@@ -921,7 +978,7 @@ if (input_code_pressed(KEYCODE_Z))
 }
 #endif
 
-	fillbitmap(bitmap,machine->pens[0],cliprect);
+	bitmap_fill(bitmap,cliprect,0);
 
 	if (order & 1)	// swap the layers?
 	{
@@ -933,7 +990,7 @@ if (input_code_pressed(KEYCODE_Z))
 
 		if (order & 2)	// layer-sprite priority?
 		{
-			if (layers_ctrl & 8)	draw_sprites(machine,bitmap,cliprect);
+			if (layers_ctrl & 8)	draw_sprites(screen->machine,bitmap,cliprect);
 			if (layers_ctrl & 1)	tilemap_draw(bitmap,cliprect, tilemap_0,  0, 0);
 			if (layers_ctrl & 1)	tilemap_draw(bitmap,cliprect, tilemap_1,  0, 0);
 		}
@@ -941,7 +998,7 @@ if (input_code_pressed(KEYCODE_Z))
 		{
 			if (layers_ctrl & 1)	tilemap_draw(bitmap,cliprect, tilemap_0,  0, 0);
 			if (layers_ctrl & 1)	tilemap_draw(bitmap,cliprect, tilemap_1,  0, 0);
-			if (layers_ctrl & 8)	draw_sprites(machine, bitmap,cliprect);
+			if (layers_ctrl & 8)	draw_sprites(screen->machine, bitmap,cliprect);
 		}
 	}
 	else
@@ -951,7 +1008,7 @@ if (input_code_pressed(KEYCODE_Z))
 
 		if (order & 2)	// layer-sprite priority?
 		{
-			if (layers_ctrl & 8)	draw_sprites(machine, bitmap,cliprect);
+			if (layers_ctrl & 8)	draw_sprites(screen->machine, bitmap,cliprect);
 
 			if (tilemap_2)
 			{
@@ -967,8 +1024,29 @@ if (input_code_pressed(KEYCODE_Z))
 				if (layers_ctrl & 2)	tilemap_draw(bitmap,cliprect, tilemap_3,  0, 0);
 			}
 
-			if (layers_ctrl & 8)	draw_sprites(machine, bitmap,cliprect);
+			if (layers_ctrl & 8)	draw_sprites(screen->machine, bitmap,cliprect);
 		}
 	}
 	return 0;
 }
+
+
+VIDEO_UPDATE( seta )
+{
+	set_pens(screen->machine);
+	return VIDEO_UPDATE_CALL(seta_layers);
+}
+
+
+VIDEO_UPDATE( usclssic )
+{
+	usclssic_set_pens(screen->machine->colortable);
+	return VIDEO_UPDATE_CALL(seta_layers);
+}
+
+
+VIDEO_UPDATE( inttoote )
+{
+	/* no palette to set */
+	return VIDEO_UPDATE_CALL(seta_layers);
+}
