@@ -1,5 +1,4 @@
 #include "driver.h"
-#include "deprecat.h"
 
 static int gfxbank;
 
@@ -15,13 +14,13 @@ WRITE8_HANDLER( sichuan2_bankswitch_w )
 {
 	int bankaddress;
 	int bank;
-	UINT8 *RAM = memory_region(REGION_CPU1);
+	UINT8 *RAM = memory_region(space->machine, "main");
 
 	if (data & 0xc0) logerror("bank switch %02x\n",data);
 
 	/* bits 0-2 select ROM bank */
 	bankaddress = 0x10000 + (data & 0x07) * 0x4000;
-	memory_set_bankptr(1, &RAM[bankaddress]);
+	memory_set_bankptr(space->machine, 1, &RAM[bankaddress]);
 
 	/* bits 3-5 select gfx bank */
 	bank = (data & 0x38) >> 3;
@@ -41,7 +40,7 @@ WRITE8_HANDLER( sichuan2_paletteram_w )
 
 	offset &= 0xff;
 
-	palette_set_color_rgb(Machine, offset, pal5bit(paletteram[offset + 0x000]), pal5bit(paletteram[offset + 0x100]), pal5bit(paletteram[offset + 0x200]));
+	palette_set_color_rgb(space->machine, offset, pal5bit(paletteram[offset + 0x000]), pal5bit(paletteram[offset + 0x100]), pal5bit(paletteram[offset + 0x200]));
 }
 
 static TILE_GET_INFO( get_bg_tile_info )
@@ -55,12 +54,18 @@ static TILE_GET_INFO( get_bg_tile_info )
 
 VIDEO_START( sichuan2 )
 {
-	bg_tilemap = tilemap_create(get_bg_tile_info, tilemap_scan_rows,
-		TILEMAP_TYPE_PEN, 8, 8, 64, 32);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info, tilemap_scan_rows,
+		 8, 8, 64, 32);
 }
 
 VIDEO_UPDATE( sichuan2 )
 {
-	tilemap_draw(bitmap, &machine->screen[0].visarea, bg_tilemap, 0, 0);
+	// on Irem boards, screen flip is handled in both hardware and software.
+	// this game doesn't have cocktail mode so if there's software control we don't
+	// know where it is mapped.
+	flip_screen_set(screen->machine, ~input_port_read(screen->machine, "DSW2") & 1);
+
+
+	tilemap_draw(bitmap, cliprect, bg_tilemap, 0, 0);
 	return 0;
 }
