@@ -4,7 +4,6 @@
 ************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "st0016.h"
 
 UINT8 *st0016_charram,*st0016_spriteram,*st0016_paletteram;
@@ -15,14 +14,13 @@ UINT32 st0016_game;
 
 static INT32 st0016_spr_bank,st0016_spr2_bank,st0016_pal_bank,st0016_char_bank;
 static int spr_dx,spr_dy;
+static UINT8 *chardirty;
 
 static UINT8 st0016_vregs[0xc0];
 static int st0016_ramgfx;
 
 //super eagle shot
-static mame_bitmap *speglsht_bitmap;
-extern UINT32 *speglsht_framebuffer;
-extern UINT32  speglsht_videoreg;
+static bitmap_t *speglsht_bitmap;
 
 static const gfx_layout charlayout =
 {
@@ -105,8 +103,8 @@ WRITE8_HANDLER (st0016_palette_ram_w)
 	st0016_paletteram[ST0016_PAL_BANK_SIZE*st0016_pal_bank+offset]=data;
 	val=st0016_paletteram[color*2]+(st0016_paletteram[color*2+1]<<8);
 	if(!color)
-		palette_set_color_rgb(Machine,UNUSED_PEN,pal5bit(val >> 0),pal5bit(val >> 5),pal5bit(val >> 10)); /* same as color 0 - bg ? */
-	palette_set_color_rgb(Machine,color,pal5bit(val >> 0),pal5bit(val >> 5),pal5bit(val >> 10));
+		palette_set_color_rgb(space->machine,UNUSED_PEN,pal5bit(val >> 0),pal5bit(val >> 5),pal5bit(val >> 10)); /* same as color 0 - bg ? */
+	palette_set_color_rgb(space->machine,color,pal5bit(val >> 0),pal5bit(val >> 5),pal5bit(val >> 10));
 }
 
 READ8_HANDLER(st0016_character_ram_r)
@@ -117,7 +115,7 @@ READ8_HANDLER(st0016_character_ram_r)
 WRITE8_HANDLER(st0016_character_ram_w)
 {
 	st0016_charram[ST0016_CHAR_BANK_SIZE*st0016_char_bank+offset]=data;
-	decodechar(Machine->gfx[st0016_ramgfx], st0016_char_bank,(UINT8 *) st0016_charram);
+	chardirty[st0016_char_bank] = 1;
 }
 
 READ8_HANDLER(st0016_vregs_r)
@@ -144,7 +142,7 @@ READ8_HANDLER(st0016_vregs_r)
 	{
 		case 0:
 		case 1:
-			return mame_rand(Machine);
+			return mame_rand(space->machine);
 	}
 
 	return st0016_vregs[offset];
@@ -191,12 +189,14 @@ WRITE8_HANDLER(st0016_vregs_w)
 		UINT32 srcadr=(st0016_vregs[0xa0]|(st0016_vregs[0xa1]<<8)|(st0016_vregs[0xa2]<<16))<<1;
 		UINT32 dstadr=(st0016_vregs[0xa3]|(st0016_vregs[0xa4]<<8)|(st0016_vregs[0xa5]<<16))<<1;
 		UINT32 length=((st0016_vregs[0xa6]|(st0016_vregs[0xa7]<<8)|((st0016_vregs[0xa8]&0x1f)<<16))+1)<<1;
+		UINT32 srclen = (memory_region_length(space->machine, "main")-0x10000);
+		UINT8 *mem = memory_region(space->machine, "main");
 		while(length>0)
 		{
-			if( srcadr < (memory_region_length(REGION_CPU1)-0x10000) && (dstadr < ST0016_MAX_CHAR_BANK*ST0016_CHAR_BANK_SIZE))
+			if( srcadr < srclen && (dstadr < ST0016_MAX_CHAR_BANK*ST0016_CHAR_BANK_SIZE))
 			{
 				st0016_char_bank=dstadr>>5;
-				st0016_character_ram_w(dstadr&0x1f,memory_region(REGION_CPU1)[0x10000+srcadr]);
+				st0016_character_ram_w(space,dstadr&0x1f,mem[0x10000+srcadr]);
 				srcadr++;
 				dstadr++;
 				length--;
@@ -205,14 +205,14 @@ WRITE8_HANDLER(st0016_vregs_w)
 			{
 				/* samples ? sound dma ? */
 				// speaglsht:  unknown DMA copy : src - 2B6740, dst - 4400, len - 1E400
-				logerror("unknown DMA copy : src - %X, dst - %X, len - %X, PC - %X\n",srcadr,dstadr,length,activecpu_get_previouspc());
+				logerror("unknown DMA copy : src - %X, dst - %X, len - %X, PC - %X\n",srcadr,dstadr,length,cpu_get_previouspc(space->cpu));
 				break;
 			}
 		}
 	}
 }
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	/*
     object ram :
@@ -257,6 +257,7 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 
     */
 
+	gfx_element *gfx = machine->gfx[st0016_ramgfx];
 	int i,j,lx,ly,x,y,code,offset,length,sx,sy,color,flipx,flipy,scrollx,scrolly,plx,ply;
 
 
@@ -352,13 +353,18 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 							int yloop,xloop;
 							int ypos, xpos;
 							int tileno;
-							const gfx_element *gfx = machine->gfx[0];
 							UINT8 *srcgfx;
 							int gfxoffs;
 							ypos = sy+y0*8+spr_dy;
 							xpos = sx+x0*8+spr_dx;
 							tileno = (code+i0++)&ST0016_CHAR_BANK_MASK ;
 
+							if (chardirty[tileno])
+							{
+								chardirty[tileno] = 0;
+								decodechar(gfx, tileno, (UINT8 *) st0016_charram);
+							}
+
 							gfxoffs = 0;
 							srcgfx= gfx->gfxdata+(64*tileno);
 
@@ -418,27 +424,27 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 	}
 }
 
-static void st0016_postload(void)
+static STATE_POSTLOAD( st0016_postload )
 {
-	int i;
-	st0016_rom_bank_w(0,st0016_rom_bank);
-	for(i=0;i<ST0016_MAX_CHAR_BANK;i++)
-		decodechar(Machine->gfx[st0016_ramgfx], i,(UINT8 *) st0016_charram);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+
+	st0016_rom_bank_w(space,0,st0016_rom_bank);
+	memset(chardirty, 1, ST0016_MAX_CHAR_BANK);
 }
 
 
-void st0016_save_init(void)
+void st0016_save_init(running_machine *machine)
 {
-	state_save_register_global(st0016_spr_bank);
-	state_save_register_global(st0016_spr2_bank);
-	state_save_register_global(st0016_pal_bank);
-	state_save_register_global(st0016_char_bank);
-	state_save_register_global(st0016_rom_bank);
-	state_save_register_global_array(st0016_vregs);
-	state_save_register_global_pointer(st0016_charram, ST0016_MAX_CHAR_BANK*ST0016_CHAR_BANK_SIZE);
-	state_save_register_global_pointer(st0016_paletteram, ST0016_MAX_PAL_BANK*ST0016_PAL_BANK_SIZE);
-	state_save_register_global_pointer(st0016_spriteram, ST0016_MAX_SPR_BANK*ST0016_SPR_BANK_SIZE);
-	state_save_register_func_postload(st0016_postload);
+	state_save_register_global(machine, st0016_spr_bank);
+	state_save_register_global(machine, st0016_spr2_bank);
+	state_save_register_global(machine, st0016_pal_bank);
+	state_save_register_global(machine, st0016_char_bank);
+	state_save_register_global(machine, st0016_rom_bank);
+	state_save_register_global_array(machine, st0016_vregs);
+	state_save_register_global_pointer(machine, st0016_charram, ST0016_MAX_CHAR_BANK*ST0016_CHAR_BANK_SIZE);
+	state_save_register_global_pointer(machine, st0016_paletteram, ST0016_MAX_PAL_BANK*ST0016_PAL_BANK_SIZE);
+	state_save_register_global_pointer(machine, st0016_spriteram, ST0016_MAX_SPR_BANK*ST0016_SPR_BANK_SIZE);
+	state_save_register_postload(machine, st0016_postload, NULL);
 }
 
 
@@ -457,7 +463,9 @@ VIDEO_START( st0016 )
 	assert(gfx_index != MAX_GFX_ELEMENTS);
 
 	/* create the char set (gfx will then be updated dynamically from RAM) */
-	machine->gfx[gfx_index] = allocgfx(&charlayout);
+	machine->gfx[gfx_index] = allocgfx(machine, &charlayout);
+	chardirty = auto_malloc(ST0016_MAX_CHAR_BANK);
+	memset(chardirty, 1, ST0016_MAX_CHAR_BANK);
 
 	/* set the color information */
 	machine->gfx[gfx_index]->color_base = 0;
@@ -470,13 +478,13 @@ VIDEO_START( st0016 )
 	switch(st0016_game&0x3f)
 	{
 		case 0: //renju kizoku
-			video_screen_set_visarea(0, 0, 40*8-1, 0, 30*8-1);
+			video_screen_set_visarea(machine->primary_screen, 0, 40*8-1, 0, 30*8-1);
 			spr_dx=0;
 			spr_dy=0;
 		break;
 
 		case 1: //neratte chu!
-			video_screen_set_visarea(0, 8,41*8-1,0,30*8-1);
+			video_screen_set_visarea(machine->primary_screen, 8,41*8-1,0,30*8-1);
 			spr_dx=0;
 			spr_dy=8;
 		break;
@@ -486,25 +494,26 @@ VIDEO_START( st0016 )
 		break;
 
 		case 4: //mayjinsen 1&2
-			video_screen_set_visarea(0, 0,32*8-1,0,28*8-1);
+			video_screen_set_visarea(machine->primary_screen, 0,32*8-1,0,28*8-1);
 		break;
 
 		case 10:
-			video_screen_set_visarea(0, 0,383,0,255);
+			video_screen_set_visarea(machine->primary_screen, 0,383,0,255);
 		break;
 
 		case 11:
-			video_screen_set_visarea(0, 0,383,0,383);
+			video_screen_set_visarea(machine->primary_screen, 0,383,0,383);
 		break;
 
 	}
 
-	st0016_save_init();
+	st0016_save_init(machine);
 }
 
 
-static void draw_bgmap(running_machine *machine, mame_bitmap *bitmap,const rectangle *cliprect, int priority)
+static void draw_bgmap(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect, int priority)
 {
+	gfx_element *gfx = machine->gfx[st0016_ramgfx];
 	int j;
 	//for(j=0x40-8;j>=0;j-=8)
 	for(j=0;j<0x40;j+=8)
@@ -522,9 +531,15 @@ static void draw_bgmap(running_machine *machine, mame_bitmap *bitmap,const recta
 	 				flipx=st0016_spriteram[i+3]&0x80;
 					flipy=st0016_spriteram[i+3]&0x40;
 
+					if (chardirty[code])
+					{
+						chardirty[code] = 0;
+						decodechar(gfx, code, (UINT8 *) st0016_charram);
+					}
+
 				 	if(priority)
 				 	{
-				 		drawgfx(bitmap,machine->gfx[0],
+				 		drawgfx(bitmap,gfx,
 										code,
 										color,
 										flipx,flipy,
@@ -536,13 +551,12 @@ static void draw_bgmap(running_machine *machine, mame_bitmap *bitmap,const recta
 							UINT16 *destline;
 							int yloop,xloop;
 							int ypos, xpos;
-							const gfx_element *gfx = machine->gfx[0];
 							UINT8 *srcgfx;
 							int gfxoffs;
 							ypos = y*8+spr_dy;//+((st0016_vregs[j+2]==0xaf)?0x50:0);//hack for mayjinsen title screen
 							xpos = x*8+spr_dx;
 							gfxoffs = 0;
-							srcgfx= gfx->gfxdata+(64*code);
+							srcgfx= gfx->gfxdata+(gfx->char_modulo*code);
 
 							for (yloop=0; yloop<8; yloop++)
 							{
@@ -635,7 +649,7 @@ VIDEO_UPDATE( st0016 )
 		//super eagle shot
 		int x,y,dy;
 
-		fillbitmap(speglsht_bitmap,machine->pens[0],&machine->screen[0].visarea);
+		bitmap_fill(speglsht_bitmap,NULL,0);
 		dy=(speglsht_videoreg&0x20)?(256*512):0; //visible frame
 
 		for(y=0;y<256;y++)
@@ -648,9 +662,9 @@ VIDEO_UPDATE( st0016 )
 		}
 
 		//draw st0016 gfx to temporary bitmap (indexed 16)
-		draw_bgmap(machine, speglsht_bitmap,cliprect,0);
- 		draw_sprites(machine, speglsht_bitmap,cliprect);
-		draw_bgmap(machine, speglsht_bitmap,cliprect,1);
+		draw_bgmap(screen->machine, speglsht_bitmap,cliprect,0);
+ 		draw_sprites(screen->machine, speglsht_bitmap,cliprect);
+		draw_bgmap(screen->machine, speglsht_bitmap,cliprect,1);
 
 		//copy temporary bitmap to rgb 32 bit bitmap
 		for(y=cliprect->min_y; y<cliprect->max_y;y++)
@@ -660,7 +674,7 @@ VIDEO_UPDATE( st0016 )
 			{
 				if(srcline[x])
 				{
-					rgb_t color=palette_get_color(machine, srcline[x]);
+					rgb_t color=palette_get_color(screen->machine, srcline[x]);
 					PLOT_PIXEL_RGB(x,y,RGB_RED(color),RGB_GREEN(color),RGB_BLUE(color));
 				}
 			}
@@ -670,16 +684,16 @@ VIDEO_UPDATE( st0016 )
 	{
 		if(ISMACS1)
 		{
-			if(!(readinputportbytag("SYS1")&1))	//fake coins - MACS2 system
+			if(!(input_port_read(screen->machine, "SYS1")&1))	//fake coins - MACS2 system
 			{
 				macs_ram2[0]++;
 			}
 		}
 
-		fillbitmap(bitmap,machine->pens[UNUSED_PEN],&machine->screen[0].visarea);
-		draw_bgmap(machine, bitmap,cliprect,0);
- 		draw_sprites(machine, bitmap,cliprect);
-		draw_bgmap(machine, bitmap,cliprect,1);
+		bitmap_fill(bitmap,cliprect,UNUSED_PEN);
+		draw_bgmap(screen->machine, bitmap,cliprect,0);
+ 		draw_sprites(screen->machine, bitmap,cliprect);
+		draw_bgmap(screen->machine, bitmap,cliprect,1);
 	}
 	return 0;
 }
