@@ -17,16 +17,15 @@ Framebuffer todo:
 
 
 #include "driver.h"
-#include "deprecat.h"
+#include "sound/scsp.h"
+#include "includes/stv.h"
 
 static int vdp1_sprite_log = 0;
 
 UINT32 *stv_vdp1_vram;
 static UINT32 *stv_vdp1_regs;
 UINT8* stv_vdp1_gfx_decode;
-
-extern UINT32 *stv_scu;
-extern int stv_vblank;
+extern UINT8 get_vblank(running_machine *machine);
 
 static UINT16	 *stv_framebuffer[2];
 static UINT16	 **stv_framebuffer_draw_lines;
@@ -186,7 +185,7 @@ struct shaded_point
 
 
 
-static void stv_vdp1_process_list(void);
+static void stv_vdp1_process_list(running_machine *machine);
 
 READ32_HANDLER( stv_vdp1_regs_r )
 {
@@ -194,7 +193,7 @@ READ32_HANDLER( stv_vdp1_regs_r )
 
 //  x ^= 0x00020000;
 
-	logerror ("cpu #%d (PC=%08X) VDP1: Read from Registers, Offset %04x\n",cpu_getactivecpu(), activecpu_get_pc(), offset);
+	logerror ("cpu %s (PC=%08X) VDP1: Read from Registers, Offset %04x\n", space->cpu->tag, cpu_get_pc(space->cpu), offset);
 //  if (offset == 0x04) return x;
 
 	return stv_vdp1_regs[offset];
@@ -287,7 +286,7 @@ WRITE32_HANDLER( stv_vdp1_regs_w )
 	if ( offset == 0 )
 	{
 		stv_set_framebuffer_config();
-		if ( ACCESSING_LSW32 )
+		if ( ACCESSING_BITS_0_15 )
 		{
 			if ( vdp1_sprite_log ) logerror( "VDP1: Access to register FBCR = %1X\n", STV_VDP1_FBCR );
 			stv_vdp1_fbcr_accessed = 1;
@@ -295,46 +294,40 @@ WRITE32_HANDLER( stv_vdp1_regs_w )
 		else
 		{
 			if ( vdp1_sprite_log ) logerror( "VDP1: Access to register TVMR = %1X\n", STV_VDP1_TVMR );
-			if ( STV_VDP1_VBE && stv_vblank )
+			if ( STV_VDP1_VBE && get_vblank(space->machine) )
 			{
 				stv_vdp1_clear_framebuffer_on_next_frame = 1;
 			}
 
 			/* needed by pblbeach, it doesn't clear local coordinates in its sprite list...*/
-			if ( !strcmp(Machine->gamedrv->name, "pblbeach") )
-			{
-				stvvdp1_local_x = stvvdp1_local_y = 0;
-			}
+			//if ( !strcmp(space->machine->gamedrv->name, "pblbeach") )
+			//{
+			//  stvvdp1_local_x = stvvdp1_local_y = 0;
+			//}
 		}
 	}
 	else if ( offset == 1 )
 	{
-		if ( ACCESSING_MSW32 )
+		if ( ACCESSING_BITS_16_31 )
 		{
 			if ( STV_VDP1_PTMR == 1 )
 			{
 				if ( vdp1_sprite_log ) logerror( "VDP1: Access to register PTMR = %1X\n", STV_VDP1_PTMR );
-				stv_vdp1_process_list( );
-
-				if(!(stv_scu[40] & 0x2000)) /*Sprite draw end irq*/
-				{
-					logerror( "Interrupt: Sprite draw end, Vector 0x4d, Level 0x02\n" );
-					cpunum_set_input_line_and_vector(Machine, 0, 2, HOLD_LINE , 0x4d);
-				}
+				stv_vdp1_process_list( space->machine );
 			}
 		}
-		else if ( ACCESSING_LSW32 )
+		else if ( ACCESSING_BITS_0_15 )
 		{
 			if ( vdp1_sprite_log ) logerror( "VDP1: Erase data set %08X\n", data );
 		}
 	}
 	else if ( offset == 2 )
 	{
-		if ( ACCESSING_MSW32 )
+		if ( ACCESSING_BITS_16_31 )
 		{
 			if ( vdp1_sprite_log ) logerror( "VDP1: Erase upper-left coord set: %08X\n", data );
 		}
-		else if ( ACCESSING_LSW32 )
+		else if ( ACCESSING_BITS_0_15 )
 		{
 			if ( vdp1_sprite_log ) logerror( "VDP1: Erase lower-right coord set: %08X\n", data );
 		}
@@ -356,7 +349,7 @@ WRITE32_HANDLER ( stv_vdp1_vram_w )
 
 //  if (((offset * 4) > 0xdf) && ((offset * 4) < 0x140))
 //  {
-//      logerror("cpu #%d (PC=%08X): VRAM dword write to %08X = %08X & %08X\n", cpu_getactivecpu(), activecpu_get_pc(), offset*4, data, mem_mask ^ 0xffffffff);
+//      logerror("cpu %s (PC=%08X): VRAM dword write to %08X = %08X & %08X\n", space->cpu->tag, cpu_get_pc(space->cpu), offset*4, data, mem_mask);
 //  }
 
 	data = stv_vdp1_vram[offset];
@@ -377,11 +370,11 @@ WRITE32_HANDLER ( stv_vdp1_framebuffer0_w )
 	else
 	{
 		/* 16-bit mode */
-		if ( ACCESSING_MSW32 )
+		if ( ACCESSING_BITS_16_31 )
 		{
 			stv_framebuffer[stv_vdp1_current_draw_framebuffer][offset*2] = (data >> 16) & 0xffff;
 		}
-		if ( ACCESSING_LSW32 )
+		if ( ACCESSING_BITS_0_15 )
 		{
 			stv_framebuffer[stv_vdp1_current_draw_framebuffer][offset*2+1] = data & 0xffff;
 		}
@@ -399,11 +392,11 @@ READ32_HANDLER ( stv_vdp1_framebuffer0_r )
 	else
 	{
 		/* 16-bit mode */
-		if ( ACCESSING_MSW32 )
+		if ( ACCESSING_BITS_16_31 )
 		{
 			result |= (stv_framebuffer[stv_vdp1_current_draw_framebuffer][offset*2] << 16);
 		}
-		if ( ACCESSING_LSW32 )
+		if ( ACCESSING_BITS_0_15 )
 		{
 			result |= stv_framebuffer[stv_vdp1_current_draw_framebuffer][offset*2+1];
 		}
@@ -549,7 +542,7 @@ INLINE INT32 _shading( INT32 color, INT32 correction )
 	if ( color > 0x1f ) color = 0x1f;
 
 	return color;
-};
+}
 
 static UINT16 stv_vdp1_apply_gouraud_shading( int x, int y, UINT16 pix )
 {
@@ -858,20 +851,18 @@ to the framebuffer we CAN'T frameskip the vdp1 drawing as the hardware can READ
 and if we skip the drawing the content could be incorrect when it reads it, although i have no idea
 why they would want to */
 
-extern UINT32* stv_vdp2_cram;
-
 static UINT8* gfxdata;
 static UINT16 sprite_colorbank;
 
 
-static void (*drawpixel)(int x, int y, int patterndata, int offsetcnt);
+static void (*drawpixel)(running_machine *machine, int x, int y, int patterndata, int offsetcnt);
 
-static void drawpixel_poly(int x, int y, int patterndata, int offsetcnt)
+static void drawpixel_poly(running_machine *machine, int x, int y, int patterndata, int offsetcnt)
 {
 	stv_framebuffer_draw_lines[y][x] = stv2_current_sprite.CMDCOLR;
 }
 
-static void drawpixel_8bpp_trans(int x, int y, int patterndata, int offsetcnt)
+static void drawpixel_8bpp_trans(running_machine *machine, int x, int y, int patterndata, int offsetcnt)
 {
 	UINT16 pix;
 
@@ -880,9 +871,9 @@ static void drawpixel_8bpp_trans(int x, int y, int patterndata, int offsetcnt)
 	{
 		stv_framebuffer_draw_lines[y][x] = pix | sprite_colorbank;
 	}
-};
+}
 
-static void drawpixel_4bpp_notrans(int x, int y, int patterndata, int offsetcnt)
+static void drawpixel_4bpp_notrans(running_machine *machine, int x, int y, int patterndata, int offsetcnt)
 {
 	UINT16 pix;
 
@@ -891,7 +882,7 @@ static void drawpixel_4bpp_notrans(int x, int y, int patterndata, int offsetcnt)
 	stv_framebuffer_draw_lines[y][x] = pix | sprite_colorbank;
 }
 
-static void drawpixel_4bpp_trans(int x, int y, int patterndata, int offsetcnt)
+static void drawpixel_4bpp_trans(running_machine *machine, int x, int y, int patterndata, int offsetcnt)
 {
 	UINT16 pix;
 
@@ -901,7 +892,7 @@ static void drawpixel_4bpp_trans(int x, int y, int patterndata, int offsetcnt)
 		stv_framebuffer_draw_lines[y][x] = pix | sprite_colorbank;
 }
 
-static void drawpixel_generic(int x, int y, int patterndata, int offsetcnt)
+static void drawpixel_generic(running_machine *machine, int x, int y, int patterndata, int offsetcnt)
 {
 	int pix,mode,transmask, spd = stv2_current_sprite.CMDPMOD & 0x40;
 	int mesh = stv2_current_sprite.CMDPMOD & 0x100;
@@ -972,7 +963,7 @@ static void drawpixel_generic(int x, int y, int patterndata, int offsetcnt)
 				pix = pix+(stv2_current_sprite.CMDCOLR&0xff80);
 				transmask = 0x7f;
 				mode = 3;
-			//  pix = mame_rand(Machine);
+			//  pix = mame_rand(machine);
 				break;
 			case 0x0020: // mode 4 256 colour bank mode (8bits) (hanagumi title)
 				pix = gfxdata[patterndata+offsetcnt];
@@ -986,7 +977,7 @@ static void drawpixel_generic(int x, int y, int patterndata, int offsetcnt)
 				transmask = 0xffff;
 				break;
 			default: // other settings illegal
-				pix = mame_rand(Machine);
+				pix = mame_rand(machine);
 				mode = 0;
 				transmask = 0xff;
 		}
@@ -1091,7 +1082,7 @@ static void stv_vdp1_set_drawpixel(void)
 }
 
 
-static void vdp1_fill_slope(const rectangle *cliprect, int patterndata, int xsize,
+static void vdp1_fill_slope(running_machine *machine, const rectangle *cliprect, int patterndata, int xsize,
 							INT32 x1, INT32 x2, INT32 sl1, INT32 sl2, INT32 *nx1, INT32 *nx2,
 							INT32 u1, INT32 u2, INT32 slu1, INT32 slu2, INT32 *nu1, INT32 *nu2,
 							INT32 v1, INT32 v2, INT32 slv1, INT32 slv2, INT32 *nv1, INT32 *nv2,
@@ -1181,7 +1172,7 @@ static void vdp1_fill_slope(const rectangle *cliprect, int patterndata, int xsiz
 					xx2 = cliprect->max_x;
 
 				while(xx1 <= xx2) {
-					drawpixel(xx1,_y1,
+					drawpixel(machine,xx1,_y1,
 							  patterndata,
 							  (v>>FRAC_SHIFT)*xsize+(u>>FRAC_SHIFT));
 					xx1++;
@@ -1207,7 +1198,7 @@ static void vdp1_fill_slope(const rectangle *cliprect, int patterndata, int xsiz
 	*nv2 = v2;
 }
 
-static void vdp1_fill_line(const rectangle *cliprect, int patterndata, int xsize, INT32 y,
+static void vdp1_fill_line(running_machine *machine, const rectangle *cliprect, int patterndata, int xsize, INT32 y,
 						   INT32 x1, INT32 x2, INT32 u1, INT32 u2, INT32 v1, INT32 v2)
 {
 	int xx1 = x1>>FRAC_SHIFT;
@@ -1235,7 +1226,7 @@ static void vdp1_fill_line(const rectangle *cliprect, int patterndata, int xsize
 			xx2 = cliprect->max_x;
 
 		while(xx1 <= xx2) {
-			drawpixel(xx1,y,
+			drawpixel(machine,xx1,y,
 					  patterndata,
 					  (v>>FRAC_SHIFT)*xsize+(u>>FRAC_SHIFT));
 			xx1++;
@@ -1245,7 +1236,7 @@ static void vdp1_fill_line(const rectangle *cliprect, int patterndata, int xsize
 	}
 }
 
-static void vdp1_fill_quad(const rectangle *cliprect, int patterndata, int xsize, const struct spoint *q)
+static void vdp1_fill_quad(running_machine *machine, const rectangle *cliprect, int patterndata, int xsize, const struct spoint *q)
 {
 	INT32 sl1, sl2, slu1, slu2, slv1, slv2, cury, limy, x1, x2, u1, u2, v1, v2, delta;
 	int pmin, pmax, i, ps1, ps2;
@@ -1285,7 +1276,7 @@ static void vdp1_fill_quad(const rectangle *cliprect, int patterndata, int xsize
 				v2 = p[i].v;
 			}
 		}
-		vdp1_fill_line(cliprect, patterndata, xsize, cury, x1, x2, u1, u2, v1, v2);
+		vdp1_fill_line(machine, cliprect, patterndata, xsize, cury, x1, x2, u1, u2, v1, v2);
 		return;
 	}
 
@@ -1304,7 +1295,7 @@ static void vdp1_fill_quad(const rectangle *cliprect, int patterndata, int xsize
 
 	for(;;) {
 		if(p[ps1-1].y == p[ps2+1].y) {
-			vdp1_fill_slope(cliprect, patterndata, xsize,
+			vdp1_fill_slope(machine, cliprect, patterndata, xsize,
 							x1, x2, sl1, sl2, &x1, &x2,
 							u1, u2, slu1, slu2, &u1, &u2,
 							v1, v2, slv1, slv2, &v1, &v2,
@@ -1337,7 +1328,7 @@ static void vdp1_fill_quad(const rectangle *cliprect, int patterndata, int xsize
 			slu2 = (u2-p[ps2+1].u)/delta;
 			slv2 = (v2-p[ps2+1].v)/delta;
 		} else if(p[ps1-1].y < p[ps2+1].y) {
-			vdp1_fill_slope(cliprect, patterndata, xsize,
+			vdp1_fill_slope(machine, cliprect, patterndata, xsize,
 							x1, x2, sl1, sl2, &x1, &x2,
 							u1, u2, slu1, slu2, &u1, &u2,
 							v1, v2, slv1, slv2, &v1, &v2,
@@ -1357,7 +1348,7 @@ static void vdp1_fill_quad(const rectangle *cliprect, int patterndata, int xsize
 			slu1 = (u1-p[ps1-1].u)/delta;
 			slv1 = (v1-p[ps1-1].v)/delta;
 		} else {
-			vdp1_fill_slope(cliprect, patterndata, xsize,
+			vdp1_fill_slope(machine, cliprect, patterndata, xsize,
 							x1, x2, sl1, sl2, &x1, &x2,
 							u1, u2, slu1, slu2, &u1, &u2,
 							v1, v2, slv1, slv2, &v1, &v2,
@@ -1379,7 +1370,7 @@ static void vdp1_fill_quad(const rectangle *cliprect, int patterndata, int xsize
 		}
 	}
 	if(cury == limy)
-		vdp1_fill_line(cliprect, patterndata, xsize, cury, x1, x2, u1, u2, v1, v2);
+		vdp1_fill_line(machine, cliprect, patterndata, xsize, cury, x1, x2, u1, u2, v1, v2);
 }
 
 static int x2s(int v)
@@ -1392,7 +1383,7 @@ static int y2s(int v)
 	return (INT32)(INT16)v + stvvdp1_local_y;
 }
 
-static void stv_vdp1_draw_line( const rectangle *cliprect)
+static void stv_vdp1_draw_line(running_machine *machine, const rectangle *cliprect)
 {
 	struct spoint q[4];
 
@@ -1408,10 +1399,10 @@ static void stv_vdp1_draw_line( const rectangle *cliprect)
 	q[0].u = q[3].u = q[1].u = q[2].u = 0;
 	q[0].v = q[1].v = q[2].v = q[3].v = 0;
 
-	vdp1_fill_quad(cliprect, 0, 1, q);
+	vdp1_fill_quad(machine, cliprect, 0, 1, q);
 }
 
-static void stv_vdp1_draw_poly_line( const rectangle *cliprect)
+static void stv_vdp1_draw_poly_line(running_machine *machine, const rectangle *cliprect)
 {
 	struct spoint q[4];
 
@@ -1427,7 +1418,7 @@ static void stv_vdp1_draw_poly_line( const rectangle *cliprect)
 	q[0].u = q[3].u = q[1].u = q[2].u = 0;
 	q[0].v = q[1].v = q[2].v = q[3].v = 0;
 
-	vdp1_fill_quad(cliprect, 0, 1, q);
+	vdp1_fill_quad(machine, cliprect, 0, 1, q);
 
 	q[0].x = x2s(stv2_current_sprite.CMDXB);
 	q[0].y = y2s(stv2_current_sprite.CMDYB);
@@ -1441,7 +1432,7 @@ static void stv_vdp1_draw_poly_line( const rectangle *cliprect)
 	q[0].u = q[3].u = q[1].u = q[2].u = 0;
 	q[0].v = q[1].v = q[2].v = q[3].v = 0;
 
-	vdp1_fill_quad(cliprect, 0, 1, q);
+	vdp1_fill_quad(machine, cliprect, 0, 1, q);
 
 	q[0].x = x2s(stv2_current_sprite.CMDXC);
 	q[0].y = y2s(stv2_current_sprite.CMDYC);
@@ -1455,7 +1446,7 @@ static void stv_vdp1_draw_poly_line( const rectangle *cliprect)
 	q[0].u = q[3].u = q[1].u = q[2].u = 0;
 	q[0].v = q[1].v = q[2].v = q[3].v = 0;
 
-	vdp1_fill_quad(cliprect, 0, 1, q);
+	vdp1_fill_quad(machine, cliprect, 0, 1, q);
 
 	q[0].x = x2s(stv2_current_sprite.CMDXD);
 	q[0].y = y2s(stv2_current_sprite.CMDYD);
@@ -1470,11 +1461,11 @@ static void stv_vdp1_draw_poly_line( const rectangle *cliprect)
 	q[0].v = q[1].v = q[2].v = q[3].v = 0;
 
 	stv_vdp1_setup_shading(q, cliprect);
-	vdp1_fill_quad(cliprect, 0, 1, q);
+	vdp1_fill_quad(machine, cliprect, 0, 1, q);
 
 }
 
-static void stv_vpd1_draw_distorted_sprite(const rectangle *cliprect)
+static void stv_vpd1_draw_distorted_sprite(running_machine *machine, const rectangle *cliprect)
 {
 	struct spoint q[4];
 
@@ -1529,10 +1520,10 @@ static void stv_vpd1_draw_distorted_sprite(const rectangle *cliprect)
 	}
 
 	stv_vdp1_setup_shading(q, cliprect);
-	vdp1_fill_quad(cliprect, patterndata, xsize, q);
+	vdp1_fill_quad(machine, cliprect, patterndata, xsize, q);
 }
 
-static void stv_vpd1_draw_scaled_sprite(const rectangle *cliprect)
+static void stv_vpd1_draw_scaled_sprite(running_machine *machine, const rectangle *cliprect)
 {
 	struct spoint q[4];
 
@@ -1676,11 +1667,11 @@ static void stv_vpd1_draw_scaled_sprite(const rectangle *cliprect)
 	}
 
 	stv_vdp1_setup_shading(q, cliprect);
-	vdp1_fill_quad(cliprect, patterndata, xsize, q);
+	vdp1_fill_quad(machine, cliprect, patterndata, xsize, q);
 }
 
 
-static void stv_vpd1_draw_normal_sprite(const rectangle *cliprect, int sprite_type)
+static void stv_vpd1_draw_normal_sprite(running_machine *machine, const rectangle *cliprect, int sprite_type)
 {
 	UINT16 *destline;
 
@@ -1759,14 +1750,14 @@ static void stv_vpd1_draw_normal_sprite(const rectangle *cliprect, int sprite_ty
 		su = u;
 		for (drawxpos = x; drawxpos <= maxdrawxpos; drawxpos++ )
 		{
-			drawpixel( drawxpos, drawypos, patterndata, u );
+			drawpixel( machine, drawxpos, drawypos, patterndata, u );
 			u += dux;
 		}
 		u = su + duy;
 	}
 }
 
-void stv_vdp1_process_list()
+static void stv_vdp1_process_list(running_machine *machine)
 {
 	int position;
 	int spritecount;
@@ -1921,37 +1912,37 @@ void stv_vdp1_process_list()
 				case 0x0000:
 					if (vdp1_sprite_log) logerror ("Sprite List Normal Sprite\n");
 					stv2_current_sprite.ispoly = 0;
-					stv_vpd1_draw_normal_sprite(cliprect, 0);
+					stv_vpd1_draw_normal_sprite(machine, cliprect, 0);
 					break;
 
 				case 0x0001:
 					if (vdp1_sprite_log) logerror ("Sprite List Scaled Sprite\n");
 					stv2_current_sprite.ispoly = 0;
-					stv_vpd1_draw_scaled_sprite(cliprect);
+					stv_vpd1_draw_scaled_sprite(machine, cliprect);
 					break;
 
 				case 0x0002:
 					if (vdp1_sprite_log) logerror ("Sprite List Distorted Sprite\n");
 					stv2_current_sprite.ispoly = 0;
-					stv_vpd1_draw_distorted_sprite(cliprect);
+					stv_vpd1_draw_distorted_sprite(machine, cliprect);
 					break;
 
 				case 0x0004:
 					if (vdp1_sprite_log) logerror ("Sprite List Polygon\n");
 					stv2_current_sprite.ispoly = 1;
-					stv_vpd1_draw_distorted_sprite(cliprect);
+					stv_vpd1_draw_distorted_sprite(machine, cliprect);
 					break;
 
 				case 0x0005:
 					if (vdp1_sprite_log) logerror ("Sprite List Polyline\n");
 					stv2_current_sprite.ispoly = 1;
-					stv_vdp1_draw_poly_line(cliprect);
+					stv_vdp1_draw_poly_line(machine, cliprect);
 					break;
 
 				case 0x0006:
 					if (vdp1_sprite_log) logerror ("Sprite List Line\n");
 					stv2_current_sprite.ispoly = 1;
-					stv_vdp1_draw_line(cliprect);
+					stv_vdp1_draw_line(machine, cliprect);
 					break;
 
 				case 0x0008:
@@ -1997,7 +1988,7 @@ void stv_vdp1_process_list()
 
 	/* not here! this is done every frame drawn even if the cpu isn't running eg in the debugger */
 //  if(!(stv_scu[40] & 0x2000)) /*Sprite draw end irq*/
-//      cpunum_set_input_line_and_vector(Machine, 0, 2, HOLD_LINE , 0x4d);
+//      cpu_set_input_line_and_vector(machine->cpu[0], 2, HOLD_LINE , 0x4d);
 
 	if (vdp1_sprite_log) logerror ("End of list processing!\n");
 }
@@ -2072,7 +2063,7 @@ void video_update_vdp1(running_machine *machine)
 			break;
 		case 2:/*Automatic Draw*/
 			if ( framebufer_changed )
-				stv_vdp1_process_list();
+				stv_vdp1_process_list(machine);
 			break;
 		case 3:	/*<invalid>*/
 			logerror("Warning: Invalid PTM mode set for VDP1!\n");
@@ -2081,7 +2072,7 @@ void video_update_vdp1(running_machine *machine)
 	//popmessage("%04x %04x",STV_VDP1_EWRR_X3,STV_VDP1_EWRR_Y3);
 }
 
-static void stv_vdp1_state_save_postload(void)
+static STATE_POSTLOAD( stv_vdp1_state_save_postload )
 {
 	UINT8 *vdp1 = stv_vdp1_gfx_decode;
 	int offset;
@@ -2103,7 +2094,7 @@ static void stv_vdp1_state_save_postload(void)
 	}
 }
 
-int stv_vdp1_start ( void )
+int stv_vdp1_start ( running_machine *machine )
 {
 	stv_vdp1_regs = auto_malloc ( 0x040000 );
 	stv_vdp1_vram = auto_malloc ( 0x100000 );
@@ -2135,14 +2126,14 @@ int stv_vdp1_start ( void )
 	stv_vdp1_user_cliprect.min_y = stv_vdp1_user_cliprect.max_y = 0;
 
 	// save state
-	state_save_register_global_pointer(stv_vdp1_regs, 0x040000/4);
-	state_save_register_global_pointer(stv_vdp1_vram, 0x100000/4);
-	state_save_register_global(stv_vdp1_fbcr_accessed);
-	state_save_register_global(stv_vdp1_current_display_framebuffer);
-	state_save_register_global(stv_vdp1_current_draw_framebuffer);
-	state_save_register_global(stv_vdp1_clear_framebuffer_on_next_frame);
-	state_save_register_global(stvvdp1_local_x);
-	state_save_register_global(stvvdp1_local_y);
-	state_save_register_func_postload(stv_vdp1_state_save_postload);
+	state_save_register_global_pointer(machine, stv_vdp1_regs, 0x040000/4);
+	state_save_register_global_pointer(machine, stv_vdp1_vram, 0x100000/4);
+	state_save_register_global(machine, stv_vdp1_fbcr_accessed);
+	state_save_register_global(machine, stv_vdp1_current_display_framebuffer);
+	state_save_register_global(machine, stv_vdp1_current_draw_framebuffer);
+	state_save_register_global(machine, stv_vdp1_clear_framebuffer_on_next_frame);
+	state_save_register_global(machine, stvvdp1_local_x);
+	state_save_register_global(machine, stvvdp1_local_y);
+	state_save_register_postload(machine, stv_vdp1_state_save_postload, NULL);
 	return 0;
 }
