@@ -15,29 +15,119 @@ Tilemap flip flags were reversed
 */
 
 #include "driver.h"
-#include "deprecat.h"
+#include "includes/suprnova.h"
+
+static bitmap_t *sprite_bitmap;
+
+static bitmap_t *tilemap_bitmap_lower;
+static bitmap_t *tilemap_bitmapflags_lower;
+
+static bitmap_t *tilemap_bitmap_higher;
+static bitmap_t *tilemap_bitmapflags_higher;
+
+
+/* draws ROZ with linescroll OR columnscroll to 16-bit indexed bitmap */
+static void suprnova_draw_roz(bitmap_t* bitmap, bitmap_t* bitmapflags, const rectangle *cliprect, tilemap *tmap, UINT32 startx, UINT32 starty, int incxx, int incxy, int incyx, int incyy, int wraparound, int columnscroll, UINT32* scrollram)
+{
+	//bitmap_t *destbitmap = bitmap;
+	bitmap_t *srcbitmap = tilemap_get_pixmap(tmap);
+	bitmap_t *srcbitmapflags = tilemap_get_flagsmap(tmap);
+	const int xmask = srcbitmap->width-1;
+	const int ymask = srcbitmap->height-1;
+	const int widthshifted = srcbitmap->width << 16;
+	const int heightshifted = srcbitmap->height << 16;
+	UINT32 cx;
+	UINT32 cy;
+	int x;
+	int sx;
+	int sy;
+	int ex;
+	int ey;
+	UINT16 *dest;
+	UINT8* destflags;
+//  UINT8 *pri;
+	//const UINT16 *src;
+	//const UINT8 *maskptr;
+	//int destadvance = destbitmap->bpp / 8;
+
+	/* pre-advance based on the cliprect */
+	startx += cliprect->min_x * incxx + cliprect->min_y * incyx;
+	starty += cliprect->min_x * incxy + cliprect->min_y * incyy;
+
+	/* extract start/end points */
+	sx = cliprect->min_x;
+	sy = cliprect->min_y;
+	ex = cliprect->max_x;
+	ey = cliprect->max_y;
+
+	{
+		/* loop over rows */
+		while (sy <= ey)
+		{
+
+			/* initialize X counters */
+			x = sx;
+			cx = startx;
+			cy = starty;
+
+			/* get dest and priority pointers */
+			dest = BITMAP_ADDR16( bitmap, sy, sx);
+			destflags = BITMAP_ADDR8( bitmapflags, sy, sx);
+
+			/* loop over columns */
+			while (x <= ex)
+			{
+				if ((wraparound) || (cx < widthshifted && cy < heightshifted)) // not sure how this will cope with no wraparound, but row/col scroll..
+				{
+					if (columnscroll)
+					{
+						dest[0] = BITMAP_ADDR16(srcbitmap, ((cy >> 16) - scrollram[(cx>>16)&0x3ff]) & ymask, (cx >> 16) & xmask)[0];
+						destflags[0] = BITMAP_ADDR8(srcbitmapflags, ((cy >> 16) - scrollram[(cx>>16)&0x3ff]) & ymask, (cx >> 16) & xmask)[0];
+					}
+					else
+					{
+						dest[0] = BITMAP_ADDR16(srcbitmap, (cy >> 16) & ymask, ((cx >> 16) - scrollram[(cy>>16)&0x3ff]) & xmask)[0];
+						destflags[0] = BITMAP_ADDR8(srcbitmapflags, (cy >> 16) & ymask, ((cx >> 16) - scrollram[(cy>>16)&0x3ff]) & xmask)[0];
+					}
+				}
+
+				/* advance in X */
+				cx += incxx;
+				cy += incxy;
+				x++;
+				dest++;
+				destflags++;
+//              pri++;
+			}
+
+			/* advance in Y */
+			startx += incyx;
+			starty += incyy;
+			sy++;
+		}
+	}
+}
+
 
 #define SUPRNOVA_DECODE_BUFFER_SIZE 0x2000
 
-extern UINT32 *skns_tilemapA_ram, *skns_tilemapB_ram, *skns_v3slc_ram;
-extern UINT32 *skns_palette_ram, *skns_v3t_ram, *skns_main_ram, *skns_cache_ram;
-extern UINT32 *skns_pal_regs, *skns_v3_regs, *skns_spc_regs;
-extern UINT32 skns_v3t_dirty[0x4000]; // allocate this elsewhere?
-extern UINT32 skns_v3t_4bppdirty[0x8000]; // allocate this elsewhere?
-extern int skns_v3t_somedirty,skns_v3t_4bpp_somedirty;
-
 static UINT8 decodebuffer[SUPRNOVA_DECODE_BUFFER_SIZE];
-static int old_depthA=0, depthA=0;
-static int old_depthB=0, depthB=0;
+static int depthA=0;
+static int depthB=0;
 
 static int sprite_kludge_x=0, sprite_kludge_y=0;
-static int use_spc_bright, use_v3_bright;
+static int use_spc_bright, use_v3_bright; // makes sarukani rather dark, but should be default..
 static UINT8 bright_spc_b=0x00, bright_spc_g=0x00, bright_spc_r=0x00;
-static UINT8 bright_v3_b=0x00,  bright_v3_g=0x00,  bright_v3_r=0x00;
 
+static UINT8 bright_spc_b_trans=0x00, bright_spc_g_trans=0x00, bright_spc_r_trans=0x00;
+
+
+static UINT8 bright_v3_b=0x00,  bright_v3_g=0x00,  bright_v3_r=0x00;
+static UINT8 bright_v3_b_trans = 0x00, bright_v3_g_trans = 0x00, bright_v3_r_trans = 0x00;
 
 // This ignores the alpha values atm.
 static int spc_changed=0, v3_changed=0, palette_updated=0;
+int suprnova_alt_enable_background, suprnova_alt_enable_sprites;
 
 WRITE32_HANDLER ( skns_pal_regs_w )
 {
@@ -46,54 +136,81 @@ WRITE32_HANDLER ( skns_pal_regs_w )
 
 	switch ( offset )
 	{
+	/* RWRA regs are for SPRITES */
+
 	case (0x00/4): // RWRA0
 		if( use_spc_bright != (data&1) ) {
 			use_spc_bright = data&1;
 			spc_changed = 1;
 		}
+		suprnova_alt_enable_sprites = (data>>8)&1;
+
+
 		break;
 	case (0x04/4): // RWRA1
 		if( bright_spc_g != (data&0xff) ) {
 			bright_spc_g = data&0xff;
 			spc_changed = 1;
 		}
+		bright_spc_g_trans = (data>>8) &0xff;
+
+
 		break;
 	case (0x08/4): // RWRA2
 		if( bright_spc_r != (data&0xff) ) {
 			bright_spc_r = data&0xff;
 			spc_changed = 1;
 		}
+		bright_spc_r_trans = (data>>8) &0xff;
+
 		break;
 	case (0x0C/4): // RWRA3
 		if( bright_spc_b != (data&0xff) ) {
 			bright_spc_b = data&0xff;
 			spc_changed = 1;
 		}
+		bright_spc_b_trans = (data>>8)&0xff;
+
+
 		break;
 
+	/* RWRB regs are for BACKGROUND */
+
 	case (0x10/4): // RWRB0
 		if( use_v3_bright != (data&1) ) {
 			use_v3_bright = data&1;
 			v3_changed = 1;
 		}
+
+		suprnova_alt_enable_background = (data>>8)&1;
+
 		break;
 	case (0x14/4): // RWRB1
 		if( bright_v3_g != (data&0xff) ) {
 			bright_v3_g = data&0xff;
 			v3_changed = 1;
 		}
+
+		bright_v3_g_trans = (data>>8)&0xff;
+
 		break;
 	case (0x18/4): // RWRB2
 		if( bright_v3_r != (data&0xff) ) {
 			bright_v3_r = data&0xff;
 			v3_changed = 1;
 		}
+
+		bright_v3_r_trans = (data>>8)&0xff;
+
 		break;
 	case (0x1C/4): // RWRB3
 		if( bright_v3_b != (data&0xff) ) {
 			bright_v3_b = data&0xff;
 			v3_changed = 1;
 		}
+
+		bright_v3_b_trans = (data>>8)&0xff;
+
 		break;
 	}
 }
@@ -138,7 +255,7 @@ WRITE32_HANDLER ( skns_palette_ram_w )
 		r <<= 3;
 	}
 
-	palette_set_color(Machine,offset,MAKE_RGB(r,g,b));
+	palette_set_color(space->machine,offset,MAKE_RGB(r,g,b));
 }
 
 
@@ -193,23 +310,23 @@ static void palette_update(running_machine *machine)
 }
 
 
-static int skns_rle_decode ( int romoffset, int size )
+static int skns_rle_decode ( running_machine *machine, int romoffset, int size, UINT8*gfx_source, size_t gfx_length )
 {
-	UINT8 *src = memory_region (REGION_GFX1);
-	size_t srcsize = memory_region_length (REGION_GFX1);
+	UINT8 *src = gfx_source;
+	size_t srcsize = gfx_length;
 	UINT8 *dst = decodebuffer;
 	int decodeoffset = 0;
 
 	while(size>0) {
 		UINT8 code = src[(romoffset++)%srcsize];
 		size -= (code & 0x7f) + 1;
-		if(code & 0x80) {
+		if(code & 0x80) { /* (code & 0x7f) normal values will follow */
 			code &= 0x7f;
 			do {
 				dst[(decodeoffset++)%SUPRNOVA_DECODE_BUFFER_SIZE] = src[(romoffset++)%srcsize];
 				code--;
 			} while(code != 0xff);
-		} else {
+		} else {  /* repeat next value (code & 0x7f) times */
 			UINT8 val = src[(romoffset++)%srcsize];
 			do {
 				dst[(decodeoffset++)%SUPRNOVA_DECODE_BUFFER_SIZE] = val;
@@ -217,7 +334,7 @@ static int skns_rle_decode ( int romoffset, int size )
 			} while(code != 0xff);
 		}
 	}
-	return &src[romoffset%srcsize]-memory_region (REGION_GFX1);
+	return &src[romoffset%srcsize]-gfx_source;
 }
 
 void skns_sprite_kludge(int x, int y)
@@ -325,7 +442,7 @@ void skns_sprite_kludge(int x, int y)
 		old2 += 0x40;				\
 	}
 
-static void blit_nf_z(mame_bitmap *bitmap, const rectangle *cliprect, const UINT8 *src, int x, int y, int sx, int sy, UINT16 zx, UINT16 zy, int colour)
+static void blit_nf_z(bitmap_t *bitmap, const rectangle *cliprect, const UINT8 *src, int x, int y, int sx, int sy, UINT16 zx, UINT16 zy, int colour)
 {
 	z_decls(sx);
 	z_clamp_x_min();
@@ -339,7 +456,7 @@ static void blit_nf_z(mame_bitmap *bitmap, const rectangle *cliprect, const UINT
 	}
 }
 
-static void blit_fy_z(mame_bitmap *bitmap, const rectangle *cliprect, const UINT8 *src, int x, int y, int sx, int sy, UINT16 zx, UINT16 zy, int colour)
+static void blit_fy_z(bitmap_t *bitmap, const rectangle *cliprect, const UINT8 *src, int x, int y, int sx, int sy, UINT16 zx, UINT16 zy, int colour)
 {
 	z_decls(sx);
 	z_clamp_x_min();
@@ -353,7 +470,7 @@ static void blit_fy_z(mame_bitmap *bitmap, const rectangle *cliprect, const UINT
 	}
 }
 
-static void blit_fx_z(mame_bitmap *bitmap, const rectangle *cliprect, const UINT8 *src, int x, int y, int sx, int sy, UINT16 zx, UINT16 zy, int colour)
+static void blit_fx_z(bitmap_t *bitmap, const rectangle *cliprect, const UINT8 *src, int x, int y, int sx, int sy, UINT16 zx, UINT16 zy, int colour)
 {
 	z_decls(sx);
 	z_clamp_x_max();
@@ -367,7 +484,7 @@ static void blit_fx_z(mame_bitmap *bitmap, const rectangle *cliprect, const UINT
 	}
 }
 
-static void blit_fxy_z(mame_bitmap *bitmap, const rectangle *cliprect, const UINT8 *src, int x, int y, int sx, int sy, UINT16 zx, UINT16 zy, int colour)
+static void blit_fxy_z(bitmap_t *bitmap, const rectangle *cliprect, const UINT8 *src, int x, int y, int sx, int sy, UINT16 zx, UINT16 zy, int colour)
 {
 	z_decls(sx);
 	z_clamp_x_max();
@@ -381,14 +498,14 @@ static void blit_fxy_z(mame_bitmap *bitmap, const rectangle *cliprect, const UIN
 	}
 }
 
-static void (*const blit_z[4])(mame_bitmap *bitmap, const rectangle *cliprect, const UINT8 *src, int x, int y, int sx, int sy, UINT16 zx, UINT16 zy, int colour) = {
+static void (*const blit_z[4])(bitmap_t *bitmap, const rectangle *cliprect, const UINT8 *src, int x, int y, int sx, int sy, UINT16 zx, UINT16 zy, int colour) = {
 	blit_nf_z,
 	blit_fy_z,
 	blit_fx_z,
 	blit_fxy_z,
 };
 
-void skns_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+void skns_draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, UINT32* spriteram_source, size_t spriteram_size, UINT8* gfx_source, size_t gfx_length, UINT32* sprite_regs)
 {
 	/*- SPR RAM Format -**
 
@@ -424,7 +541,10 @@ void skns_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rect
 
 	/* sprite ram start / end is not really fixed registers change it */
 
-	UINT32 *source = buffered_spriteram32;
+	//printf ("addr %08x\n", (sprite_regs[0x14/4]));
+
+
+	UINT32 *source = spriteram_source;
 	UINT32 *finish = source + spriteram_size/4;
 
 	int group_x_offset[4];
@@ -434,42 +554,43 @@ void skns_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rect
 	int sprite_flip;
 	int sprite_x_scroll;
 	int sprite_y_scroll;
-	int disabled = skns_spc_regs[0x04/4] & 0x08; // RWR1
+	int disabled = sprite_regs[0x04/4] & 0x08; // RWR1
 	int xsize,ysize, size, xpos=0,ypos=0, pri=0, romoffset, colour=0, xflip,yflip, joint;
 	int sx,sy;
-	int endromoffs=0;
+	int endromoffs=0, gfxlen;
+	int grow;
 	UINT16 zoomx, zoomy;
 
 
-	if (!disabled){
+	if ((!disabled) && suprnova_alt_enable_sprites){
 
-		group_enable    = (skns_spc_regs[0x00/4] & 0x0040) >> 6; // RWR0
+		group_enable    = (sprite_regs[0x00/4] & 0x0040) >> 6; // RWR0
 
 		/* Sengekis uses global flip */
-		sprite_flip = (skns_spc_regs[0x04/4] & 0x03); // RWR1
+		sprite_flip = (sprite_regs[0x04/4] & 0x03); // RWR1
 
-		sprite_y_scroll = ((skns_spc_regs[0x08/4] & 0x7fc0) >> 6); // RWR2
-		sprite_x_scroll = ((skns_spc_regs[0x10/4] & 0x7fc0) >> 6); // RWR4
+		sprite_y_scroll = ((sprite_regs[0x08/4] & 0x7fc0) >> 6); // RWR2
+		sprite_x_scroll = ((sprite_regs[0x10/4] & 0x7fc0) >> 6); // RWR4
 		if (sprite_y_scroll&0x100) sprite_y_scroll -= 0x200; // Signed
 		if (sprite_x_scroll&0x100) sprite_x_scroll -= 0x200; // Signed
 
-		group_x_offset[0] = (skns_spc_regs[0x18/4] & 0xffc0) >> 6; // RWR6
-		group_y_offset[0] = (skns_spc_regs[0x1c/4] & 0xffc0) >> 6; // RWR7
+		group_x_offset[0] = (sprite_regs[0x18/4] & 0xffc0) >> 6; // RWR6
+		group_y_offset[0] = (sprite_regs[0x1c/4] & 0xffc0) >> 6; // RWR7
 		if (group_x_offset[0]&0x200) group_x_offset[0] -= 0x400; // Signed
 		if (group_y_offset[0]&0x200) group_y_offset[0] -= 0x400; // Signed
 
-		group_x_offset[1] = (skns_spc_regs[0x20/4] & 0xffc0) >> 6; // RWR8
-		group_y_offset[1] = (skns_spc_regs[0x24/4] & 0xffc0) >> 6; // RWR9
+		group_x_offset[1] = (sprite_regs[0x20/4] & 0xffc0) >> 6; // RWR8
+		group_y_offset[1] = (sprite_regs[0x24/4] & 0xffc0) >> 6; // RWR9
 		if (group_x_offset[1]&0x200) group_x_offset[1] -= 0x400; // Signed
 		if (group_y_offset[1]&0x200) group_y_offset[1] -= 0x400; // Signed
 
-		group_x_offset[2] = (skns_spc_regs[0x28/4] & 0xffc0) >> 6; // RWR10
-		group_y_offset[2] = (skns_spc_regs[0x2c/4] & 0xffc0) >> 6; // RWR11
+		group_x_offset[2] = (sprite_regs[0x28/4] & 0xffc0) >> 6; // RWR10
+		group_y_offset[2] = (sprite_regs[0x2c/4] & 0xffc0) >> 6; // RWR11
 		if (group_x_offset[2]&0x200) group_x_offset[2] -= 0x400; // Signed
 		if (group_y_offset[2]&0x200) group_y_offset[2] -= 0x400; // Signed
 
-		group_x_offset[3] = (skns_spc_regs[0x30/4] & 0xffc0) >> 6; // RWR12
-		group_y_offset[3] = (skns_spc_regs[0x34/4] & 0xffc0) >> 6; // RWR13
+		group_x_offset[3] = (sprite_regs[0x30/4] & 0xffc0) >> 6; // RWR12
+		group_y_offset[3] = (sprite_regs[0x34/4] & 0xffc0) >> 6; // RWR13
 		if (group_x_offset[3]&0x200) group_x_offset[3] -= 0x400; // Signed
 		if (group_y_offset[3]&0x200) group_y_offset[3] -= 0x400; // Signed
 
@@ -489,6 +610,7 @@ void skns_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rect
 		sprite_y_scroll += sprite_kludge_y;
 
 
+		gfxlen = gfx_length;
 		while( source<finish )
 		{
 			xflip = (source[0] & 0x00000200) >> 9;
@@ -550,12 +672,12 @@ void skns_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rect
 			if (sprite_flip&2)
 			{
 				xflip ^= 1;
-				sx = machine->screen[0].visarea.max_x+1 - sx;
+				sx = video_screen_get_visible_area(machine->primary_screen)->max_x+1 - sx;
 			}
 			if (sprite_flip&1)
 			{
 				yflip ^= 1;
-				sy = machine->screen[0].visarea.max_y+1 - sy;
+				sy = video_screen_get_visible_area(machine->primary_screen)->max_y+1 - sy;
 			}
 
 			/* Palette linking */
@@ -573,18 +695,41 @@ void skns_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rect
 				romoffset = endromoffs;
 			}
 
-			zoomx = source[2] >> 16;
-			zoomy = source[3] >> 16;
+			grow = (source[0]>>23) & 1;
 
-			romoffset &= memory_region_length (REGION_GFX1)-1;
+			if (!grow)
+			{
+				zoomx = (source[2] >> 16)&0xfcfc;
+				zoomy = (source[3] >> 16)&0xfcfc;
+			}
+			else
+			{
+				// the bad sprites in sengekis all have this not set..
+				// we need to handle sprite shrink properly
+				zoomx = 0;
+				zoomy = 0;
+			}
 
-			endromoffs = skns_rle_decode ( romoffset, size );
+
+			romoffset &= gfxlen-1;
+
+			endromoffs = skns_rle_decode ( machine, romoffset, size, gfx_source, gfx_length );
+
+			// in Cyvern
+
+			//  train in tunnel pri = 0x00
+			//  nothing?         = 0x01
+			//  players etc. pri = 0x02
+			//  pickups etc. pri = 0x03
 
 			// PriTest
 //          if(!( (keyboard_pressed(KEYCODE_Q)&&(pri==0)) || (keyboard_pressed(KEYCODE_W)&&(pri==1)) || (keyboard_pressed(KEYCODE_E)&&(pri==2)) || (keyboard_pressed(KEYCODE_D)&&(pri==3)) ))
 //          if( !(keyboard_pressed(KEYCODE_Q) && ((source[0] & 0x00800000)>>24)) )
+
+
+
 			{
-				int NewColour = colour*256;
+				int NewColour = (colour<<8) | (pri << 14);
 
 				if(zoomx || zoomy)
 				{
@@ -688,7 +833,7 @@ static TILE_GET_INFO( get_tilemap_A_tile_info )
 {
 	int code = ((skns_tilemapA_ram[tile_index] & 0x001fffff) >> 0 );
 	int colr = ((skns_tilemapA_ram[tile_index] & 0x3f000000) >> 24 );
-//  int pri  = ((skns_tilemapA_ram[tile_index] & 0x00e00000) >> 21 );
+	int pri  = ((skns_tilemapA_ram[tile_index] & 0x00e00000) >> 21 );
 	int depth = (skns_v3_regs[0x0c/4] & 0x0001) << 1;
 	int flags = 0;
 
@@ -700,7 +845,9 @@ static TILE_GET_INFO( get_tilemap_A_tile_info )
 			code,
 			0x40+colr,
 			flags);
-//  tileinfo->category = pri;
+	tileinfo->category = pri;
+
+	//if (pri) popmessage("pri A!! %02x\n", pri);
 }
 
 WRITE32_HANDLER ( skns_tilemapA_w )
@@ -713,7 +860,7 @@ static TILE_GET_INFO( get_tilemap_B_tile_info )
 {
 	int code = ((skns_tilemapB_ram[tile_index] & 0x001fffff) >> 0 );
 	int colr = ((skns_tilemapB_ram[tile_index] & 0x3f000000) >> 24 );
-//  int pri  = ((skns_tilemapA_ram[tile_index] & 0x00e00000) >> 21 );
+	int pri  = ((skns_tilemapB_ram[tile_index] & 0x00e00000) >> 21 );
 	int depth = (skns_v3_regs[0x0c/4] & 0x0100) >> 7;
 	int flags = 0;
 
@@ -725,7 +872,9 @@ static TILE_GET_INFO( get_tilemap_B_tile_info )
 			code,
 			0x40+colr,
 			flags);
-//  tileinfo->category = pri;
+	tileinfo->category = pri;
+
+	//if (pri) popmessage("pri B!! %02x\n", pri); // 02 on cyvern
 }
 
 WRITE32_HANDLER ( skns_tilemapB_w )
@@ -741,8 +890,8 @@ WRITE32_HANDLER ( skns_v3_regs_w )
 	/* if the depth changes we need to dirty the tilemap */
 	if (offset == 0x0c/4)
 	{
-		old_depthA = depthA;
-		old_depthB = depthB;
+		int old_depthA = depthA;
+		int old_depthB = depthB;
 
 		depthA = (skns_v3_regs[0x0c/4] & 0x0001) << 1;
 		depthB = (skns_v3_regs[0x0c/4] & 0x0100) >> 7;
@@ -756,117 +905,87 @@ WRITE32_HANDLER ( skns_v3_regs_w )
 
 VIDEO_START(skns)
 {
-	skns_tilemap_A = tilemap_create(get_tilemap_A_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,64, 64);
+	skns_tilemap_A = tilemap_create(machine, get_tilemap_A_tile_info,tilemap_scan_rows,16,16,64, 64);
 		tilemap_set_transparent_pen(skns_tilemap_A,0);
 
-	skns_tilemap_B = tilemap_create(get_tilemap_B_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,64, 64);
+	skns_tilemap_B = tilemap_create(machine, get_tilemap_B_tile_info,tilemap_scan_rows,16,16,64, 64);
 		tilemap_set_transparent_pen(skns_tilemap_B,0);
 
+	sprite_bitmap = auto_bitmap_alloc(1024,1024,BITMAP_FORMAT_INDEXED16);
+
+	tilemap_bitmap_lower = auto_bitmap_alloc(320,240,BITMAP_FORMAT_INDEXED16);
+	tilemap_bitmapflags_lower = auto_bitmap_alloc(320,240,BITMAP_FORMAT_INDEXED8);
+
+	tilemap_bitmap_higher = auto_bitmap_alloc(320,240,BITMAP_FORMAT_INDEXED16);
+	tilemap_bitmapflags_higher = auto_bitmap_alloc(320,240,BITMAP_FORMAT_INDEXED8);
+
 	machine->gfx[2]->color_granularity=256;
 	machine->gfx[3]->color_granularity=256;
 }
 
-static void supernova_draw_a( mame_bitmap *bitmap, const rectangle *cliprect, int tran )
+VIDEO_RESET( skns )
 {
-		int enable_a  = (skns_v3_regs[0x10/4] >> 0) & 0x0001;
+	depthA = depthB = 0;
+	use_spc_bright = use_v3_bright = 1;
+	bright_spc_b= bright_spc_g = bright_spc_r = 0x00;
+	bright_spc_b_trans = bright_spc_g_trans = bright_spc_r_trans = 0x00;
+	bright_v3_b = bright_v3_g = bright_v3_r = 0x00;
+	bright_v3_b_trans = bright_v3_g_trans = bright_v3_r_trans = 0x00;
+
+	spc_changed = v3_changed = palette_updated = 0;
+	suprnova_alt_enable_background = suprnova_alt_enable_sprites = 1;
+}
+
+static void supernova_draw_a( bitmap_t *bitmap, bitmap_t* bitmap_flags, const rectangle *cliprect, int tran )
+{
+	int enable_a  = (skns_v3_regs[0x10/4] >> 0) & 0x0001;
+	int nowrap_a = (skns_v3_regs[0x10/4] >> 0) & 0x0004;
+
+
 	UINT32 startx,starty;
 	int incxx,incxy,incyx,incyy;
+	int columnscroll;
 
-	if (enable_a)
+	//if(nowrap_a) printf("a\n");
+
+	if (enable_a && suprnova_alt_enable_background)
 	{
 		startx = skns_v3_regs[0x1c/4];
-			incyy  = skns_v3_regs[0x30/4]; // was xx, changed for sarukani
+		incyy  = skns_v3_regs[0x30/4]; // was xx, changed for sarukani
 		incyx  = skns_v3_regs[0x2c/4];
 		starty = skns_v3_regs[0x20/4];
 		incxy  = skns_v3_regs[0x28/4];
-			incxx  = skns_v3_regs[0x24/4]; // was yy, changed for sarukani
+		incxx  = skns_v3_regs[0x24/4]; // was yy, changed for sarukani
 
-		if( (incxx == 1<<8) && !incxy & !incyx && (incyy == 1<<8) ) // No Roz, only scroll.
-		{
-			int columnscroll_a = (skns_v3_regs[0x0c/4] >> 1) & 0x0001;
-			int offs;
+		columnscroll = (skns_v3_regs[0x0c/4] >> 1) & 0x0001;
 
-			startx >>= 8; // Lose Floating point
-			starty >>= 8;
-
-			if(columnscroll_a) {
-				tilemap_set_scroll_rows(skns_tilemap_A,1);
-				tilemap_set_scroll_cols(skns_tilemap_A,0x400);
-
-				tilemap_set_scrollx( skns_tilemap_A, 0, startx );
-				for(offs=0; offs<(0x1000/4); offs++)
-					tilemap_set_scrolly( skns_tilemap_A, offs, starty - (skns_v3slc_ram[offs]&0x3ff) );
-			}
-			else
-			{
-				tilemap_set_scroll_rows(skns_tilemap_A,0x400);
-				tilemap_set_scroll_cols(skns_tilemap_A,1);
-
-				tilemap_set_scrolly( skns_tilemap_A, 0, starty );
-				for(offs=0; offs<(0x1000/4); offs++)
-					tilemap_set_scrollx( skns_tilemap_A, offs, startx - (skns_v3slc_ram[offs]&0x3ff) );
-			}
-				tilemap_draw(bitmap,cliprect,skns_tilemap_A,tran ? 0 : TILEMAP_DRAW_OPAQUE,0);
-		}
-		else
-		{
-			tilemap_draw_roz(bitmap,cliprect,skns_tilemap_A,startx << 8,starty << 8,
-					incxx << 8,incxy << 8,incyx << 8,incyy << 8,
-					1,	/* wraparound */
-						tran ? 0 : TILEMAP_DRAW_OPAQUE,0);
-		}
+		suprnova_draw_roz(bitmap,bitmap_flags,cliprect, skns_tilemap_A, startx << 8,starty << 8,	incxx << 8,incxy << 8,incyx << 8,incyy << 8, !nowrap_a, columnscroll, &skns_v3slc_ram[0]);
+		//tilemap_copy_bitmap(bitmap, tilemap_bitmap_lower, tilemap_bitmapflags_lower);
 	}
 }
 
-static void supernova_draw_b( mame_bitmap *bitmap, const rectangle *cliprect, int tran )
+static void supernova_draw_b( bitmap_t *bitmap, bitmap_t* bitmap_flags, const rectangle *cliprect, int tran )
 {
-		int enable_b  = (skns_v3_regs[0x34/4] >> 0) & 0x0001;
+	int enable_b  = (skns_v3_regs[0x34/4] >> 0) & 0x0001;
+	int nowrap_b = (skns_v3_regs[0x34/4] >> 0) & 0x0004;
+
+
 	UINT32 startx,starty;
 	int incxx,incxy,incyx,incyy;
+	int columnscroll;
 
-	if (enable_b)
+	//if(nowrap_b) printf("b\n");
+
+	if (enable_b && suprnova_alt_enable_background)
 	{
 		startx = skns_v3_regs[0x40/4];
-			incyy  = skns_v3_regs[0x54/4];
+		incyy  = skns_v3_regs[0x54/4];
 		incyx  = skns_v3_regs[0x50/4];
 		starty = skns_v3_regs[0x44/4];
 		incxy  = skns_v3_regs[0x4c/4];
-			incxx  = skns_v3_regs[0x48/4];
-
-		if( (incxx == 1<<8) && !incxy & !incyx && (incyy == 1<<8) ) // No Roz, only scroll.
-		{
-			int columnscroll_b = (skns_v3_regs[0x0c/4] >> 9) & 0x0001;
-			int offs;
-
-			startx >>= 8;
-			starty >>= 8;
-
-			if(columnscroll_b) {
-				tilemap_set_scroll_rows(skns_tilemap_B,1);
-				tilemap_set_scroll_cols(skns_tilemap_B,0x400);
-
-				tilemap_set_scrollx( skns_tilemap_B, 0, startx );
-				for(offs=0; offs<(0x1000/4); offs++)
-					tilemap_set_scrolly( skns_tilemap_B, offs, starty - (skns_v3slc_ram[offs+(0x1000/4)]&0x3ff) );
-			}
-			else
-			{
-				tilemap_set_scroll_rows(skns_tilemap_B,0x400);
-				tilemap_set_scroll_cols(skns_tilemap_B,1);
-
-				tilemap_set_scrolly( skns_tilemap_B, 0, starty );
-				for(offs=0; offs<(0x1000/4); offs++)
-					tilemap_set_scrollx( skns_tilemap_B, offs, startx - (skns_v3slc_ram[offs+(0x1000/4)]&0x3ff) );
-			}
-				tilemap_draw(bitmap,cliprect,skns_tilemap_B,tran ? 0 : TILEMAP_DRAW_OPAQUE,0);
-		}
-		else
-		{
-			tilemap_draw_roz(bitmap,cliprect,skns_tilemap_B,startx << 8,starty << 8,
-					incxx << 8,incxy << 8,incyx << 8,incyy << 8,
-					1,	/* wraparound */
-						tran ? 0 : TILEMAP_DRAW_OPAQUE,0);
-		}
+		incxx  = skns_v3_regs[0x48/4];
+		columnscroll = (skns_v3_regs[0x0c/4] >> 9) & 0x0001; // selects column scroll or rowscroll
+		suprnova_draw_roz(bitmap,bitmap_flags, cliprect, skns_tilemap_B, startx << 8,starty << 8,	incxx << 8,incxy << 8,incyx << 8,incyy << 8, !nowrap_b, columnscroll, &skns_v3slc_ram[0x1000/4]);
 	}
 }
 
@@ -877,9 +996,9 @@ VIDEO_UPDATE(skns)
 	UINT8 *btiles;
 
 
-	palette_update(machine);
+	palette_update(screen->machine);
 
-	btiles = memory_region (REGION_GFX3);
+	btiles = memory_region (screen->machine, "gfx3");
 
 //  if (!(skns_v3_regs[0x0c/4] & 0x0100)); // if tilemap b is in 8bpp mode
 	{
@@ -899,7 +1018,7 @@ VIDEO_UPDATE(skns)
 			{
 				if (skns_v3t_dirty[i] == 1)
 				{
-					decodechar(machine->gfx[1], i, (UINT8*)btiles);
+					decodechar(screen->machine->gfx[1], i, (UINT8*)btiles);
 
 					skns_v3t_dirty[i] = 0;
 				}
@@ -925,7 +1044,7 @@ VIDEO_UPDATE(skns)
 			{
 				if (skns_v3t_4bppdirty[i] == 1)
 				{
-					decodechar(machine->gfx[3], i, (UINT8*)btiles);
+					decodechar(screen->machine->gfx[3], i, (UINT8*)btiles);
 
 					skns_v3t_4bppdirty[i] = 0;
 				}
@@ -933,42 +1052,183 @@ VIDEO_UPDATE(skns)
 		}
 	}
 
-	fillbitmap(bitmap, get_black_pen(machine), cliprect);
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
+	bitmap_fill(tilemap_bitmap_lower, NULL, 0);
+	bitmap_fill(tilemap_bitmapflags_lower, NULL, 0);
+	bitmap_fill(tilemap_bitmap_higher, NULL, 0);
+	bitmap_fill(tilemap_bitmapflags_higher, NULL, 0);
 
 	{
 		int supernova_pri_a;
 		int supernova_pri_b;
 		int tran = 0;
 
-		supernova_pri_a = skns_v3_regs[0x10/4] & 0x0002;
-		supernova_pri_b = skns_v3_regs[0x34/4] & 0x0002;
+		supernova_pri_a = (skns_v3_regs[0x10/4] & 0x0002)>>1;
+		supernova_pri_b = (skns_v3_regs[0x34/4] & 0x0002)>>1;
 
+		//popmessage("pri %d %d\n", supernova_pri_a, supernova_pri_b);
+
+		/*if (!supernova_pri_b) { */
+		supernova_draw_b(tilemap_bitmap_lower, tilemap_bitmapflags_lower, cliprect,tran);// tran = 1;
+		supernova_draw_a(tilemap_bitmap_higher,tilemap_bitmapflags_higher,cliprect,tran);// tran = 1;
 
-		/* needed until we have the per tile priorities sorted out */
-		if (!strcmp(machine->gamedrv->name,"vblokbrk") ||
-			!strcmp(machine->gamedrv->name,"sarukani") ||
-			!strcmp(machine->gamedrv->name,"sengekis") ||
-			!strcmp(machine->gamedrv->name,"sengekij"))
 		{
-			supernova_pri_b = 0;
-			supernova_pri_a = 1;
+			int x,y;
+			UINT8* srcflags, *src2flags;
+			UINT16* src, *src2, *src3;
+			UINT32* dst;
+			UINT16 pri, pri2, pri3;
+			UINT16 bgpri;
+			const pen_t *clut = &screen->machine->pens[0];
+//          int drawpri;
+
+
+			for (y=0;y<240;y++)
+			{
+				src = BITMAP_ADDR16(tilemap_bitmap_lower, y, 0);
+				srcflags = BITMAP_ADDR8(tilemap_bitmapflags_lower, y, 0);
+
+				src2 = BITMAP_ADDR16(tilemap_bitmap_higher, y, 0);
+				src2flags = BITMAP_ADDR8(tilemap_bitmapflags_higher, y, 0);
+
+				src3 = BITMAP_ADDR16(sprite_bitmap, y, 0);
+
+				dst = BITMAP_ADDR32(bitmap, y, 0);
+
+
+				for (x=0;x<320;x++)
+				{
+					UINT16 pendata  = src[x]&0x7fff;
+					UINT16 pendata2 = src2[x]&0x7fff;
+					UINT16 bgpendata;
+					UINT16 pendata3 = src3[x]&0x3fff;
+
+					UINT32 coldat;
+
+					pri = ((srcflags[x] & 0x07)<<1) | (supernova_pri_b);
+					pri2= ((src2flags[x] & 0x07)<<1) | (supernova_pri_a);
+					pri3 = ((src3[x]&0xc000)>>12)+3;
+
+					// work out which layers bg pixel has the higher priority
+					//  note, can the bg layers be blended?? sarukani uses an alpha pen for
+					//        some of them.. and registers indicate it might be possible..
+
+					// this priority mixing is almost certainly still incorrect
+					// bg colour / prioirty handling is now wrong
+
+					if (pri<=pri2) // <= is good for last level of cyvern.. < seem better for galpanis kaneko logo
+					{
+						if (pendata2&0xff)
+						{
+							bgpendata = pendata2&0x7fff;
+							bgpri = pri2;
+						}
+						else if (pendata&0xff)
+						{
+							bgpendata = pendata&0x7fff;
+							bgpri = pri;
+						}
+						else
+						{
+							bgpendata = pendata2&0x7fff;
+							bgpri = 0;;
+						}
+					}
+					else
+					{
+						if (pendata&0xff)
+						{
+							bgpendata = pendata&0x7fff;
+							bgpri = pri;
+						}
+						else if (pendata2&0xff)
+						{
+							bgpendata = pendata2&0x7fff;
+							bgpri = pri2;
+						}
+						else
+						{
+							bgpendata = 0;
+							bgpri = 0;;
+						}
+					}
+
+					// if the sprites are higher than the bg pixel
+					if (pri3 > bgpri)
+					{
+
+						if (pendata3&0xff)
+						{
+
+							UINT16 palvalue = skns_palette_ram[pendata3];
+
+							coldat = clut[pendata3];
+
+							if (palvalue&0x8000)
+							{
+								UINT32 srccolour = clut[bgpendata&0x7fff];
+								UINT32 dstcolour = clut[pendata3&0x3fff];
+
+								int r,g,b;
+								int r2,g2,b2;
+
+								r = (srccolour & 0x000000ff)>> 0;
+								g = (srccolour & 0x0000ff00)>> 8;
+								b = (srccolour & 0x00ff0000)>> 16;
+
+								r2 = (dstcolour & 0x000000ff)>> 0;
+								g2 = (dstcolour & 0x0000ff00)>> 8;
+								b2 = (dstcolour & 0x00ff0000)>> 16;
+
+								r2 = (r2 * bright_spc_r_trans) >> 8;
+								g2 = (g2 * bright_spc_g_trans) >> 8;
+								b2 = (b2 * bright_spc_b_trans) >> 8;
+
+								r = (r+r2);
+								if (r>255) r = 255;
+
+								g = (g+g2);
+								if (g>255) g = 255;
+
+								b = (b+b2);
+								if (b>255) b = 255;
+
+								dst[x] = (r << 0) | (g << 8) | (b << 16);
+
+
+							}
+
+							else
+							{
+								coldat = clut[pendata3];
+								dst[x] = coldat;
+							}
+						}
+						else
+						{
+							coldat = clut[bgpendata];
+							dst[x] = coldat;
+						}
+					}
+					else
+					{
+						coldat = clut[bgpendata];
+						dst[x] = coldat;
+					}
+
+				}
+			}
 		}
-
-
-		if (!supernova_pri_a) { supernova_draw_a(bitmap,cliprect,tran); tran = 1;}
-		if (!supernova_pri_b) { supernova_draw_b(bitmap,cliprect,tran); tran = 1;}
-		if (supernova_pri_a) { supernova_draw_a(bitmap,cliprect,tran); tran = 1;}
-		if (supernova_pri_b) { supernova_draw_b(bitmap,cliprect,tran); tran = 1;}
-
-
 	}
 
+	bitmap_fill(sprite_bitmap, cliprect, 0x0000);
+	skns_draw_sprites(screen->machine, sprite_bitmap, cliprect, spriteram32, spriteram_size, memory_region(screen->machine,"gfx1"), memory_region_length (screen->machine, "gfx1"), skns_spc_regs );
+
 
-	skns_draw_sprites(machine, bitmap, cliprect);
 	return 0;
 }
 
 VIDEO_EOF(skns)
 {
-	buffer_spriteram32_w(0,0,0);
+
 }
