@@ -8,7 +8,6 @@
 *************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "system1.h"
 
 UINT8 *system1_scroll_y;
@@ -26,7 +25,7 @@ static int background_scrollx=0,background_scrolly=0;
 static UINT8 *bg_dirtybuffer;
 
 static int scrollx_row[32];
-static mame_bitmap *tmp_bitmap;
+static bitmap_t *tmp_bitmap;
 
 //static int system1_pixel_mode = 0
 static UINT8 system1_background_memory,system1_video_mode=0;
@@ -105,10 +104,10 @@ WRITE8_HANDLER( system1_paletteram_w )
 		b = pal2bit(data >> 6);
 	}
 
-	palette_set_color(Machine,offset,MAKE_RGB(r,g,b));
+	palette_set_color(space->machine,offset,MAKE_RGB(r,g,b));
 }
 
-static void system1_postload(void)
+static STATE_POSTLOAD( system1_postload )
 {
 	memset(sprite_onscreen_map, 255, 256*256);
 	memset(bg_dirtybuffer, 1, 1024);
@@ -122,11 +121,11 @@ VIDEO_START( system1 )
 	bg_dirtybuffer = auto_malloc(1024);
 	memset(bg_dirtybuffer,1,1024);
 
-	tmp_bitmap = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
+	tmp_bitmap = video_screen_auto_bitmap_alloc(machine->primary_screen);
 
-	state_save_register_func_postload(system1_postload);
-	state_save_register_global(system1_background_memory);
-	state_save_register_global(system1_video_mode);
+	state_save_register_postload(machine, system1_postload, NULL);
+	state_save_register_global(machine, system1_background_memory);
+	state_save_register_global(machine, system1_video_mode);
 
 	system1_sprite_xoffset = 1;
 }
@@ -141,17 +140,17 @@ VIDEO_START( wbml )
 	wbml_paged_videoram = auto_malloc(0x4000);	/* Allocate 16k for background banked ram */
 	memset(wbml_paged_videoram,0,0x4000);
 
-	tmp_bitmap = auto_bitmap_alloc(machine->screen[0].width,machine->screen[0].height,machine->screen[0].format);
+	tmp_bitmap = video_screen_auto_bitmap_alloc(machine->primary_screen);
 
 	system1_sprite_xoffset = 1+7*2;
 
-	state_save_register_func_postload(system1_postload);
-	state_save_register_global(system1_background_memory);
-	state_save_register_global(system1_video_mode);
+	state_save_register_postload(machine, system1_postload, NULL);
+	state_save_register_global(machine, system1_background_memory);
+	state_save_register_global(machine, system1_video_mode);
 
-	state_save_register_global_pointer(wbml_paged_videoram, 0x4000);
-	state_save_register_global(wbml_videoram_bank);
-	state_save_register_global(wbml_videoram_bank_latch);
+	state_save_register_global_pointer(machine, wbml_paged_videoram, 0x4000);
+	state_save_register_global(machine, wbml_videoram_bank);
+	state_save_register_global(machine, wbml_videoram_bank_latch);
 }
 
 WRITE8_HANDLER( system1_videomode_w )
@@ -165,7 +164,7 @@ if (data & 0x6e) logerror("videomode = %02x\n",data);
 	system1_video_mode = data;
 
 	/* bit 7 is flip screen */
-	flip_screen_set(data & 0x80);
+	flip_screen_set(space->machine, data & 0x80);
 }
 
 READ8_HANDLER( system1_videomode_r )
@@ -179,21 +178,23 @@ void system1_define_background_memory(int mode)
 }
 
 
+#ifdef UNUSED_FUNCTION
 INLINE int get_sprite_bottom_y(int spr_number)
 {
 	return  spriteram[0x10 * spr_number + SPR_Y_BOTTOM];
 }
+#endif
 
-INLINE void draw_pixel(mame_bitmap *bitmap,
+INLINE void draw_pixel(running_machine *machine, bitmap_t *bitmap,
 				  	   int x,int y,int x_flipped,int y_flipped,
 				  	   int spr_number,int color)
 {
 	int xr,yr;
 	int sprite_onscreen;
+	const rectangle *visarea = video_screen_get_visible_area(machine->primary_screen);
 
-
-	if (x < 0 || x >= Machine->screen[0].width ||
-		y < 0 || y >= Machine->screen[0].height)
+	if (x < 0 || x >= video_screen_get_width(machine->primary_screen) ||
+		y < 0 || y >= video_screen_get_height(machine->primary_screen))
 		return;
 
 	if (sprite_onscreen_map[256*y+x] != 255)
@@ -204,10 +205,10 @@ INLINE void draw_pixel(mame_bitmap *bitmap,
 
 	sprite_onscreen_map[256*y+x] = spr_number;
 
-	if (x_flipped >= Machine->screen[0].visarea.min_x ||
-		x_flipped <= Machine->screen[0].visarea.max_x ||
-		y_flipped >= Machine->screen[0].visarea.min_y ||
-		y_flipped <= Machine->screen[0].visarea.max_y)
+	if (x_flipped >= visarea->min_x ||
+		x_flipped <= visarea->max_x ||
+		y_flipped >= visarea->min_y ||
+		y_flipped <= visarea->max_y)
 	{
 		*BITMAP_ADDR16(bitmap, y_flipped, x_flipped) = color;
 	}
@@ -252,11 +253,11 @@ WRITE8_HANDLER( system1_sprites_collisionram_w )
 	system1_sprites_collisionram[offset] = 0x7e;
 }
 
-static void draw_sprite(mame_bitmap *bitmap,int spr_number)
+static void draw_sprite(running_machine *machine, bitmap_t *bitmap,int spr_number)
 {
 	int sy,row,height,src,bank;
 	UINT8 *sprite_base;
-	const pen_t *sprite_palette;
+	int sprite_palette_base;
 	INT16 skip;	/* bytes to skip before drawing each row (can be negative) */
 	UINT8 *gfx;
 
@@ -265,16 +266,16 @@ static void draw_sprite(mame_bitmap *bitmap,int spr_number)
 
 	src = sprite_base[SPR_GFXOFS_LO] + (sprite_base[SPR_GFXOFS_HI] << 8);
 	bank = 0x8000 * (((sprite_base[SPR_X_HI] & 0x80) >> 7) + ((sprite_base[SPR_X_HI] & 0x40) >> 5));
-	bank &= (memory_region_length(REGION_GFX2)-1);	/* limit to the range of available ROMs */
+	bank &= (memory_region_length(machine, "gfx2")-1);	/* limit to the range of available ROMs */
 	skip = sprite_base[SPR_SKIP_LO] + (sprite_base[SPR_SKIP_HI] << 8);
 
 	height = sprite_base[SPR_Y_BOTTOM] - sprite_base[SPR_Y_TOP];
-	sprite_palette = Machine->remapped_colortable + 0x10 * spr_number;
+	sprite_palette_base = 0x10 * spr_number;
 
 	sy = sprite_base[SPR_Y_TOP] + 1;
 
 	/* graphics region #2 contains the packed sprite data */
-	gfx = &memory_region(REGION_GFX2)[bank];
+	gfx = &memory_region(machine, "gfx2")[bank];
 
 	for (row = 0;row < height;row++)
 	{
@@ -288,7 +289,7 @@ static void draw_sprite(mame_bitmap *bitmap,int spr_number)
 		x_flipped = x;
 		y = y_flipped = sy+row;
 
-		if (flip_screen)
+		if (flip_screen_get(machine))
 		{
 			y_flipped = 258 - sy - height + row;
 			x_flipped = (252*2) - x;
@@ -320,21 +321,21 @@ static void draw_sprite(mame_bitmap *bitmap,int spr_number)
 
 			if (color1 == 15) break;
 			if (color1)
-				draw_pixel(bitmap,x,y,x_flipped,y_flipped,spr_number,sprite_palette[color1]);
+				draw_pixel(machine,bitmap,x,y,x_flipped,y_flipped,spr_number,sprite_palette_base+color1);
 			x++;
-			x_flipped += flip_screen ? -1 : 1;
+			x_flipped += flip_screen_get(machine) ? -1 : 1;
 
 			if (color2 == 15) break;
 			if (color2)
-				draw_pixel(bitmap,x,y,x_flipped,y_flipped,spr_number,sprite_palette[color2]);
+				draw_pixel(machine,bitmap,x,y,x_flipped,y_flipped,spr_number,sprite_palette_base+color2);
 			x++;
-			x_flipped += flip_screen ? -1 : 1;
+			x_flipped += flip_screen_get(machine) ? -1 : 1;
 		}
 	}
 }
 
 
-static void draw_sprites(mame_bitmap *bitmap)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap)
 {
 	int spr_number,sprite_bottom_y,sprite_top_y;
 	UINT8 *sprite_base;
@@ -348,7 +349,7 @@ static void draw_sprites(mame_bitmap *bitmap)
 		sprite_top_y = sprite_base[SPR_Y_TOP];
 		sprite_bottom_y = sprite_base[SPR_Y_BOTTOM];
 		if (sprite_bottom_y && (sprite_bottom_y-sprite_top_y > 0))
-			draw_sprite(bitmap,spr_number);
+			draw_sprite(machine, bitmap,spr_number);
 	}
 }
 
@@ -361,7 +362,7 @@ WRITE8_HANDLER( system1_backgroundram_w )
 }
 
 
-static int system1_draw_fg(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int priority)
+static int system1_draw_fg(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int priority)
 {
 	int sx,sy,offs;
 	int drawn = 0;
@@ -382,7 +383,7 @@ static int system1_draw_fg(running_machine *machine, mame_bitmap *bitmap, const
 			sx = (offs/2) % 32;
 			sy = (offs/2) / 32;
 
-			if (flip_screen)
+			if (flip_screen_get(machine))
 			{
 				sx = 31 - sx;
 				sy = 31 - sy;
@@ -396,7 +397,7 @@ static int system1_draw_fg(running_machine *machine, mame_bitmap *bitmap, const
 				drawgfx(bitmap,machine->gfx[0],
 						code,
 						color,
-						flip_screen,flip_screen,
+						flip_screen_get(machine),flip_screen_get(machine),
 						8*sx + blockgal_kludgeoffset,8*sy,
 						cliprect,TRANSPARENCY_PEN,0);
 			}
@@ -406,7 +407,7 @@ static int system1_draw_fg(running_machine *machine, mame_bitmap *bitmap, const
 	return drawn;
 }
 
-static void system1_draw_bg(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int priority)
+static void system1_draw_bg(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int priority)
 {
 	int sx,sy,offs;
 	int background_scrollx_flip, background_scrolly_flip;
@@ -441,7 +442,7 @@ static void system1_draw_bg(running_machine *machine, mame_bitmap *bitmap, const
 				sx = (offs/2) % 32;
 				sy = (offs/2) / 32;
 
-				if (flip_screen)
+				if (flip_screen_get(machine))
 				{
 					sx = 31 - sx;
 					sy = 31 - sy;
@@ -450,14 +451,14 @@ static void system1_draw_bg(running_machine *machine, mame_bitmap *bitmap, const
 				drawgfx(tmp_bitmap,machine->gfx[0],
 						code,
 						color,
-						flip_screen,flip_screen,
+						flip_screen_get(machine),flip_screen_get(machine),
 						8*sx,8*sy,
 						0,TRANSPARENCY_NONE,0);
 			}
 		}
 
 		/* copy the temporary bitmap to the screen */
-		if (flip_screen)
+		if (flip_screen_get(machine))
 			copyscrollbitmap(bitmap,tmp_bitmap,1,&background_scrollx_flip,1,&background_scrolly_flip,cliprect);
 		else
 			copyscrollbitmap(bitmap,tmp_bitmap,1,&background_scrollx,1,&background_scrolly,cliprect);
@@ -479,7 +480,7 @@ static void system1_draw_bg(running_machine *machine, mame_bitmap *bitmap, const
 				sx = (offs/2) % 32;
 				sy = (offs/2) / 32;
 
-				if (flip_screen)
+				if (flip_screen_get(machine))
 				{
 					sx = 8*(31-sx) + background_scrollx_flip;
 					sy = 8*(31-sy) + background_scrolly_flip;
@@ -494,25 +495,25 @@ static void system1_draw_bg(running_machine *machine, mame_bitmap *bitmap, const
 				drawgfx(bitmap,machine->gfx[0],
 						code,
 						color,
-						flip_screen,flip_screen,
+						flip_screen_get(machine),flip_screen_get(machine),
 						sx,sy,
 						cliprect,TRANSPARENCY_PEN,0);
 				drawgfx(bitmap,machine->gfx[0],
 						code,
 						color,
-						flip_screen,flip_screen,
+						flip_screen_get(machine),flip_screen_get(machine),
 						sx-256,sy,
 						cliprect,TRANSPARENCY_PEN,0);
 				drawgfx(bitmap,machine->gfx[0],
 						code,
 						color,
-						flip_screen,flip_screen,
+						flip_screen_get(machine),flip_screen_get(machine),
 						sx,sy-256,
 						cliprect,TRANSPARENCY_PEN,0);
 				drawgfx(bitmap,machine->gfx[0],
 						code,
 						color,
-						flip_screen,flip_screen,
+						flip_screen_get(machine),flip_screen_get(machine),
 						sx-256,sy-256,
 						cliprect,TRANSPARENCY_PEN,0);
 			}
@@ -525,17 +526,17 @@ VIDEO_UPDATE( system1 )
 	int drawn;
 
 
-	system1_draw_bg(machine, bitmap, cliprect, -1);
-	drawn = system1_draw_fg(machine, bitmap, cliprect, 0);
+	system1_draw_bg(screen->machine, bitmap, cliprect, -1);
+	drawn = system1_draw_fg(screen->machine, bitmap, cliprect, 0);
 	/* redraw low priority bg tiles if necessary */
-	if (drawn) system1_draw_bg(machine, bitmap, cliprect, 0);
-	draw_sprites(bitmap);
-	system1_draw_bg(machine, bitmap, cliprect, 1);
-	system1_draw_fg(machine, bitmap, cliprect, 1);
+	if (drawn) system1_draw_bg(screen->machine, bitmap, cliprect, 0);
+	draw_sprites(screen->machine, bitmap);
+	system1_draw_bg(screen->machine, bitmap, cliprect, 1);
+	system1_draw_fg(screen->machine, bitmap, cliprect, 1);
 
 	/* even if screen is off, sprites must still be drawn to update the collision table */
 	if (system1_video_mode & 0x10)  /* screen off */
-		fillbitmap(bitmap,machine->pens[0],cliprect);
+		bitmap_fill(bitmap,cliprect,0);
 	return 0;
 }
 
@@ -554,7 +555,7 @@ WRITE8_HANDLER( choplifter_scroll_x_w )
 	scrollx_row[offset/2] = (system1_scrollx_ram[offset & ~1] >> 1) + ((system1_scrollx_ram[offset | 1] & 1) << 7);
 }
 
-static void chplft_draw_bg(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int priority)
+static void chplft_draw_bg(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int priority)
 {
 	int sx,sy,offs;
 	int choplifter_scroll_x_on = (system1_scrollx_ram[0] == 0xe5 && system1_scrollx_ram[1] == 0xff) ? 0 : 1;
@@ -583,7 +584,7 @@ static void chplft_draw_bg(running_machine *machine, mame_bitmap *bitmap, const
 				sx = (offs/2) % 32;
 				sy = (offs/2) / 32;
 
-				if (flip_screen)
+				if (flip_screen_get(machine))
 				{
 					sx = 31 - sx;
 					sy = 31 - sy;
@@ -592,7 +593,7 @@ static void chplft_draw_bg(running_machine *machine, mame_bitmap *bitmap, const
 				drawgfx(tmp_bitmap,machine->gfx[0],
 						code,
 						color,
-						flip_screen,flip_screen,
+						flip_screen_get(machine),flip_screen_get(machine),
 						8*sx,8*sy,
 						0,TRANSPARENCY_NONE,0);
 			}
@@ -601,7 +602,7 @@ static void chplft_draw_bg(running_machine *machine, mame_bitmap *bitmap, const
 		/* copy the temporary bitmap to the screen */
 		if (choplifter_scroll_x_on)
 		{
-			if (flip_screen)
+			if (flip_screen_get(machine))
 			{
 				int scrollx_row_flip[32],i;
 
@@ -633,7 +634,7 @@ static void chplft_draw_bg(running_machine *machine, mame_bitmap *bitmap, const
 				sx = (offs/2) % 32;
 				sy = (offs/2) / 32;
 
-				if (flip_screen)
+				if (flip_screen_get(machine))
 				{
 					sx = 8*(31-sx);
 
@@ -653,7 +654,7 @@ static void chplft_draw_bg(running_machine *machine, mame_bitmap *bitmap, const
 				drawgfx(bitmap,machine->gfx[0],
 						code,
 						color,
-						flip_screen,flip_screen,
+						flip_screen_get(machine),flip_screen_get(machine),
 						sx,8*sy,
 						cliprect,TRANSPARENCY_PEN,0);
 			}
@@ -666,23 +667,23 @@ VIDEO_UPDATE( choplifter )
 	int drawn;
 
 
-	chplft_draw_bg(machine, bitmap, cliprect, -1);
-	drawn = system1_draw_fg(machine, bitmap, cliprect, 0);
+	chplft_draw_bg(screen->machine, bitmap, cliprect, -1);
+	drawn = system1_draw_fg(screen->machine, bitmap, cliprect, 0);
 	/* redraw low priority bg tiles if necessary */
-	if (drawn) chplft_draw_bg(machine, bitmap, cliprect, 0);
-	draw_sprites(bitmap);
-	chplft_draw_bg(machine, bitmap, cliprect, 1);
-	system1_draw_fg(machine, bitmap, cliprect, 1);
+	if (drawn) chplft_draw_bg(screen->machine, bitmap, cliprect, 0);
+	draw_sprites(screen->machine, bitmap);
+	chplft_draw_bg(screen->machine, bitmap, cliprect, 1);
+	system1_draw_fg(screen->machine, bitmap, cliprect, 1);
 
 	/* even if screen is off, sprites must still be drawn to update the collision table */
 	if (system1_video_mode & 0x10)  /* screen off */
-		fillbitmap(bitmap,machine->pens[0],cliprect);
+		bitmap_fill(bitmap,cliprect,0);
 
 
 #ifdef MAME_DEBUG
 	if (input_code_pressed(KEYCODE_SPACE))		// goto next level
 	{
-		memory_region(REGION_CPU1)[0xC085]=33;
+		memory_region(screen->machine, "main")[0xC085]=33;
 	}
 #endif
 	return 0;
@@ -711,7 +712,7 @@ WRITE8_HANDLER( wbml_paged_videoram_w )
 	wbml_paged_videoram[0x1000*wbml_videoram_bank + offset] = data;
 }
 
-static void wbml_draw_bg(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int trasp)
+static void wbml_draw_bg(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int trasp)
 {
 	int page;
 
@@ -736,7 +737,7 @@ static void wbml_draw_bg(running_machine *machine, mame_bitmap *bitmap, const re
 				if (x > 256) x -= 512;
 				if (y > 224) y -= 512;
 
-				if (flip_screen)
+				if (flip_screen_get(machine))
 				{
 					x = 248 - x;
 					y = 248 - y;
@@ -750,14 +751,14 @@ static void wbml_draw_bg(running_machine *machine, mame_bitmap *bitmap, const re
 					drawgfx(bitmap,machine->gfx[0],
 							code,
 							((code >> 5) & 0x3f) + 64,
-							flip_screen,flip_screen,
+							flip_screen_get(machine),flip_screen_get(machine),
 							x,y,
 							cliprect, TRANSPARENCY_NONE, 0);
 				else if (priority)
 					drawgfx(bitmap,machine->gfx[0],
 							code,
 							((code >> 5) & 0x3f) + 64,
-							flip_screen,flip_screen,
+							flip_screen_get(machine),flip_screen_get(machine),
 							x,y,
 							cliprect, TRANSPARENCY_PEN, 0);
 
@@ -767,7 +768,7 @@ static void wbml_draw_bg(running_machine *machine, mame_bitmap *bitmap, const re
 	} /* next page */
 }
 
-static void wbml_draw_fg(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void wbml_draw_fg(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	int offs;
 
@@ -782,7 +783,7 @@ static void wbml_draw_fg(running_machine *machine, mame_bitmap *bitmap, const re
 		code = wbml_paged_videoram[offs] | (wbml_paged_videoram[offs+1] << 8);
 		code = ((code >> 4) & 0x800) | (code & 0x7ff);
 
-		if (flip_screen)
+		if (flip_screen_get(machine))
 		{
 			sx = 31 - sx;
 			sy = 31 - sy;
@@ -791,7 +792,7 @@ static void wbml_draw_fg(running_machine *machine, mame_bitmap *bitmap, const re
 		drawgfx(bitmap,machine->gfx[0],
 				code,
 				(code >> 5) & 0x3f,
-				flip_screen,flip_screen,
+				flip_screen_get(machine),flip_screen_get(machine),
 				8*sx,8*sy,
 				cliprect,TRANSPARENCY_PEN,0);
 	}
@@ -800,19 +801,19 @@ static void wbml_draw_fg(running_machine *machine, mame_bitmap *bitmap, const re
 
 VIDEO_UPDATE( wbml )
 {
-	wbml_draw_bg(machine, bitmap, cliprect, 0);
-	draw_sprites(bitmap);
-	wbml_draw_bg(machine, bitmap, cliprect, 1);
-	wbml_draw_fg(machine, bitmap, cliprect);
+	wbml_draw_bg(screen->machine, bitmap, cliprect, 0);
+	draw_sprites(screen->machine, bitmap);
+	wbml_draw_bg(screen->machine, bitmap, cliprect, 1);
+	wbml_draw_fg(screen->machine, bitmap, cliprect);
 
 	/* even if screen is off, sprites must still be drawn to update the collision table */
 	if (system1_video_mode & 0x10)  /* screen off */
-		fillbitmap(bitmap,machine->pens[0],cliprect);
+		bitmap_fill(bitmap,cliprect,0);
 	return 0;
 }
 
 /* same as wbml but with rows scroll */
-static void ufosensi_draw_bg(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int trasp)
+static void ufosensi_draw_bg(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int trasp)
 {
 	int page;
 
@@ -837,7 +838,7 @@ static void ufosensi_draw_bg(running_machine *machine, mame_bitmap *bitmap, cons
 				if (x > 256) x -= 512;
 				if (y > 224) y -= 512;
 
-				if (flip_screen)
+				if (flip_screen_get(machine))
 				{
 					x = 248 - x;
 					y = 248 - y;
@@ -851,14 +852,14 @@ static void ufosensi_draw_bg(running_machine *machine, mame_bitmap *bitmap, cons
 					drawgfx(bitmap,machine->gfx[0],
 							code,
 							((code >> 5) & 0x3f) + 64,
-							flip_screen,flip_screen,
+							flip_screen_get(machine),flip_screen_get(machine),
 							x,y,
 							cliprect, TRANSPARENCY_NONE, 0);
 				else if (priority)
 					drawgfx(bitmap,machine->gfx[0],
 							code,
 							((code >> 5) & 0x3f) + 64,
-							flip_screen,flip_screen,
+							flip_screen_get(machine),flip_screen_get(machine),
 							x,y,
 							cliprect, TRANSPARENCY_PEN, 0);
 
@@ -870,14 +871,14 @@ static void ufosensi_draw_bg(running_machine *machine, mame_bitmap *bitmap, cons
 
 VIDEO_UPDATE( ufosensi )
 {
-	ufosensi_draw_bg(machine, bitmap, cliprect, 0);
-	draw_sprites(bitmap);
-	ufosensi_draw_bg(machine, bitmap, cliprect, 1);
-	wbml_draw_fg(machine, bitmap, cliprect);
+	ufosensi_draw_bg(screen->machine, bitmap, cliprect, 0);
+	draw_sprites(screen->machine, bitmap);
+	ufosensi_draw_bg(screen->machine, bitmap, cliprect, 1);
+	wbml_draw_fg(screen->machine, bitmap, cliprect);
 
 	/* even if screen is off, sprites must still be drawn to update the collision table */
 	if (system1_video_mode & 0x10)  /* screen off */
-		fillbitmap(bitmap,machine->pens[0],cliprect);
+		bitmap_fill(bitmap,cliprect,0);
 	return 0;
 }
 
@@ -888,17 +889,17 @@ VIDEO_UPDATE( blockgal )
 
 	blockgal_kludgeoffset = -8;
 
-	system1_draw_bg(machine, bitmap, cliprect, -1);
-	drawn = system1_draw_fg(machine, bitmap, cliprect, 0);
+	system1_draw_bg(screen->machine, bitmap, cliprect, -1);
+	drawn = system1_draw_fg(screen->machine, bitmap, cliprect, 0);
 	/* redraw low priority bg tiles if necessary */
-	if (drawn) system1_draw_bg(machine, bitmap, cliprect, 0);
-	draw_sprites(bitmap);
-	system1_draw_bg(machine, bitmap, cliprect, 1);
-	system1_draw_fg(machine, bitmap, cliprect, 1);
+	if (drawn) system1_draw_bg(screen->machine, bitmap, cliprect, 0);
+	draw_sprites(screen->machine, bitmap);
+	system1_draw_bg(screen->machine, bitmap, cliprect, 1);
+	system1_draw_fg(screen->machine, bitmap, cliprect, 1);
 
 	/* even if screen is off, sprites must still be drawn to update the collision table */
 	if (system1_video_mode & 0x10)  /* screen off */
-		fillbitmap(bitmap,machine->pens[0],cliprect);
+		bitmap_fill(bitmap,cliprect,0);
 
 	blockgal_kludgeoffset = 0;
 	return 0;
