@@ -1,6 +1,6 @@
 #include "driver.h"
-#include "deprecat.h"
 #include "profiler.h"
+#include "includes/taito_b.h"
 
 UINT16 *taitob_scroll;
 UINT16 *TC0180VCU_ram;
@@ -11,7 +11,7 @@ static tilemap *bg_tilemap, *fg_tilemap, *tx_tilemap;
 static UINT16 bg_rambank[2],fg_rambank[2],tx_rambank;
 
 /* framebuffer is a raw bitmap, remapped as a last step */
-static mame_bitmap *framebuffer[2],*pixel_bitmap;
+static bitmap_t *framebuffer[2],*pixel_bitmap;
 
 static UINT16 pixel_scroll[2];
 
@@ -96,7 +96,7 @@ WRITE16_HANDLER( taitob_v_control_w )
 
 	COMBINE_DATA (&TC0180VCU_ctrl[offset]);
 
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		switch(offset)
 		{
@@ -144,12 +144,12 @@ WRITE16_HANDLER( hitice_pixelram_w )
 
   COMBINE_DATA(&taitob_pixelram[offset]);
 
-  if (ACCESSING_LSB)
+  if (ACCESSING_BITS_0_7)
   {
     /* bit 15 of pixel_scroll[0] is probably flip screen */
 
-	*BITMAP_ADDR16(pixel_bitmap, sy, 2*sx+0) = Machine->pens[b_fg_color_base * 16 + (data & 0xff)];
-	*BITMAP_ADDR16(pixel_bitmap, sy, 2*sx+1) = Machine->pens[b_fg_color_base * 16 + (data & 0xff)];
+	*BITMAP_ADDR16(pixel_bitmap, sy, 2*sx+0) = b_fg_color_base * 16 + (data & 0xff);
+	*BITMAP_ADDR16(pixel_bitmap, sy, 2*sx+1) = b_fg_color_base * 16 + (data & 0xff);
   }
 }
 
@@ -158,12 +158,13 @@ WRITE16_HANDLER( hitice_pixel_scroll_w )
 	COMBINE_DATA(&pixel_scroll[offset]);
 }
 
-static void hitice_clear_pixel_bitmap(void)
+static void hitice_clear_pixel_bitmap(running_machine *machine)
 {
 	int i;
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
 
     for (i = 0;i < 0x40000;i++)
-		hitice_pixelram_w(i,0,0);
+		hitice_pixelram_w(space,i,0,0xffff);
 }
 
 static TILE_GET_INFO( get_bg_tile_info )
@@ -204,13 +205,13 @@ static TILE_GET_INFO( get_tx_tile_info )
 
 static VIDEO_START( taitob_core )
 {
-	framebuffer[0] = auto_bitmap_alloc(512,256,machine->screen[0].format);
-	framebuffer[1] = auto_bitmap_alloc(512,256,machine->screen[0].format);
+	framebuffer[0] = auto_bitmap_alloc(512,256, video_screen_get_format(machine->primary_screen));
+	framebuffer[1] = auto_bitmap_alloc(512,256, video_screen_get_format(machine->primary_screen));
 	pixel_bitmap = NULL;  /* only hitice needs this */
 
-	bg_tilemap = tilemap_create(get_bg_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,     16,16,64,64);
-	fg_tilemap = tilemap_create(get_fg_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,64,64);
-	tx_tilemap = tilemap_create(get_tx_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN, 8, 8,64,32);
+	bg_tilemap = tilemap_create(machine, get_bg_tile_info,tilemap_scan_rows,     16,16,64,64);
+	fg_tilemap = tilemap_create(machine, get_fg_tile_info,tilemap_scan_rows,16,16,64,64);
+	tx_tilemap = tilemap_create(machine, get_tx_tile_info,tilemap_scan_rows, 8, 8,64,32);
 
 	tilemap_set_transparent_pen(fg_tilemap,0);
 	tilemap_set_transparent_pen(tx_tilemap,0);
@@ -220,18 +221,18 @@ static VIDEO_START( taitob_core )
 	tilemap_set_scrolldx(tx_tilemap,0,24*8);
 
 
-	state_save_register_global_array(bg_rambank);
-	state_save_register_global_array(fg_rambank);
-	state_save_register_global(tx_rambank);
+	state_save_register_global_array(machine, bg_rambank);
+	state_save_register_global_array(machine, fg_rambank);
+	state_save_register_global(machine, tx_rambank);
 
-	state_save_register_global_array(pixel_scroll);
-	state_save_register_global(framebuffer_page);
+	state_save_register_global_array(machine, pixel_scroll);
+	state_save_register_global(machine, framebuffer_page);
 
-	state_save_register_global(video_control);
-	state_save_register_global_array(TC0180VCU_ctrl);
+	state_save_register_global(machine, video_control);
+	state_save_register_global_array(machine, TC0180VCU_ctrl);
 
-	state_save_register_global_bitmap(framebuffer[0]);
-	state_save_register_global_bitmap(framebuffer[1]);
+	state_save_register_global_bitmap(machine, framebuffer[0]);
+	state_save_register_global_bitmap(machine, framebuffer[1]);
 }
 
 VIDEO_START( taitob_color_order0 )
@@ -278,15 +279,15 @@ VIDEO_START( hitice )
 {
   VIDEO_START_CALL(taitob_color_order0);
 
-  pixel_bitmap = auto_bitmap_alloc(1024,512,machine->screen[0].format);
+  pixel_bitmap = auto_bitmap_alloc(1024,512,video_screen_get_format(machine->primary_screen));
 
-  state_save_register_global_bitmap(pixel_bitmap);
+  state_save_register_global_bitmap(machine, pixel_bitmap);
 }
 
 VIDEO_RESET( hitice )
 {
 	/* kludge: clear the bitmap on startup */
-	hitice_clear_pixel_bitmap();
+	hitice_clear_pixel_bitmap(machine);
 }
 
 
@@ -321,14 +322,14 @@ WRITE16_HANDLER( TC0180VCU_framebuffer_word_w )
   int sy = offset >> 8;
   int sx = 2*(offset & 0xff);
 
-  if (ACCESSING_MSB)
+  if (ACCESSING_BITS_8_15)
 	*BITMAP_ADDR16(framebuffer[sy >> 8], sy & 0xff, sx + 0) = data >> 8;
-  if (ACCESSING_LSB)
+  if (ACCESSING_BITS_0_7)
 	*BITMAP_ADDR16(framebuffer[sy >> 8], sy & 0xff, sx + 1) = data & 0xff;
 }
 
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap,const rectangle *cliprect)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap,const rectangle *cliprect)
 {
 /*  Sprite format: (16 bytes per sprite)
   offs:             bits:
@@ -451,7 +452,7 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap,const rec
 }
 
 
-static void TC0180VCU_tilemap_draw(mame_bitmap *bitmap,const rectangle *cliprect,tilemap *tmap,int plane)
+static void TC0180VCU_tilemap_draw(bitmap_t *bitmap,const rectangle *cliprect,tilemap *tmap,int plane)
 {
 /*plane = 0 fg tilemap*/
 /*plane = 1 bg tilemap*/
@@ -492,7 +493,7 @@ static void TC0180VCU_tilemap_draw(mame_bitmap *bitmap,const rectangle *cliprect
 }
 
 
-static void draw_framebuffer(running_machine *machine, mame_bitmap *bitmap,const rectangle *cliprect,int priority)
+static void draw_framebuffer(bitmap_t *bitmap,const rectangle *cliprect,int priority)
 {
   rectangle myclip = *cliprect;
   int x,y;
@@ -521,7 +522,7 @@ profiler_mark(PROFILER_USER1);
 					UINT16 c = *src++;
 
 					if (c != 0)
-						*dst = machine->pens[b_sp_color_base + c];
+						*dst = b_sp_color_base + c;
 
 					dst--;
 				}
@@ -539,7 +540,7 @@ profiler_mark(PROFILER_USER1);
 					UINT16 c = *src++;
 
 					if (c != 0)
-						*dst = machine->pens[b_sp_color_base + c];
+						*dst = b_sp_color_base + c;
 
 					dst++;
 				}
@@ -563,7 +564,7 @@ profiler_mark(PROFILER_USER1);
 					UINT16 c = *src++;
 
 					if (c != 0 && (c & 0x10) == priority)
-						*dst = machine->pens[b_sp_color_base + c];
+						*dst = b_sp_color_base + c;
 
 					dst--;
 				}
@@ -581,7 +582,7 @@ profiler_mark(PROFILER_USER1);
 					UINT16 c = *src++;
 
 					if (c != 0 && (c & 0x10) == priority)
-						*dst = machine->pens[b_sp_color_base + c];
+						*dst = b_sp_color_base + c;
 
 					dst++;
 				}
@@ -595,14 +596,14 @@ VIDEO_UPDATE( taitob )
 {
   if ((video_control & 0x20) == 0)
   {
-    fillbitmap(bitmap,machine->pens[0],cliprect);
+    bitmap_fill(bitmap,cliprect,0);
     return 0;
   }
 
   /* Draw playfields */
   TC0180VCU_tilemap_draw(bitmap,cliprect,bg_tilemap,1);
 
-  draw_framebuffer(machine, bitmap,cliprect,1);
+  draw_framebuffer(bitmap,cliprect,1);
 
   TC0180VCU_tilemap_draw(bitmap,cliprect,fg_tilemap,0);
 
@@ -612,10 +613,10 @@ VIDEO_UPDATE( taitob )
     int scrolly = -pixel_scroll[1]; //+240;
     /* bit 15 of pixel_scroll[0] is probably flip screen */
 
-    copyscrollbitmap_trans(bitmap,pixel_bitmap,1,&scrollx,1,&scrolly,cliprect,machine->pens[b_fg_color_base * 16]);
+    copyscrollbitmap_trans(bitmap,pixel_bitmap,1,&scrollx,1,&scrolly,cliprect,b_fg_color_base * 16);
   }
 
-  draw_framebuffer(machine, bitmap,cliprect,0);
+  draw_framebuffer(bitmap,cliprect,0);
 
   tilemap_draw(bitmap,cliprect,tx_tilemap,0,0);
 	return 0;
@@ -626,11 +627,11 @@ VIDEO_UPDATE( taitob )
 VIDEO_EOF( taitob )
 {
   if (~video_control & 0x01)
-    fillbitmap(framebuffer[framebuffer_page],0,&machine->screen[0].visarea);
+    bitmap_fill(framebuffer[framebuffer_page],video_screen_get_visible_area(machine->primary_screen),0);
 
   if (~video_control & 0x80)
     framebuffer_page ^= 1;
 
-  draw_sprites(machine, framebuffer[framebuffer_page],&machine->screen[0].visarea);
+  draw_sprites(machine, framebuffer[framebuffer_page],video_screen_get_visible_area(machine->primary_screen));
 }
 
