@@ -198,13 +198,13 @@ Line ram memory map:
 Playfield tile info:
     0xc000 0000 - X/Y Flip
     0x3000 ffff - Tile index
-    0x0dff 0000 - Colour (top 2 bits use not clear, always set)
+    0x0c00 0000 - Extra planes enable (00 = 4bpp, 01 = 5bpp, 10 = unused?, 11 = 6bpp)
     0x0200 0000 - Alpha blend mode
+    0x01ff 0000 - Colour
 
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "taito_f3.h"
 #include "ui.h"
 
@@ -220,6 +220,8 @@ static int pivot_changed,vram_changed;
 static UINT32 f3_control_0[8];
 static UINT32 f3_control_1[8];
 static int flipscreen;
+static UINT8 sprite_extra_planes;
+static UINT8 sprite_pen_mask;
 
 static UINT8 *pivot_dirty;
 
@@ -243,39 +245,39 @@ static const struct F3config *f3_game_config;
 
 static const struct F3config f3_config_table[] =
 {
-	/* Name    Extend  Sprite Lag */
-	{ RINGRAGE,  0,       2 },
-	{ ARABIANM,  0,       2 },
-	{ RIDINGF,   1,       1 },
-	{ GSEEKER,   0,       1 },
-	{ TRSTAR,    1,       0 },
-	{ GUNLOCK,   1,       2 },
-	{ TWINQIX,   1,       1 },
-	{ SCFINALS,  0,       1 },
-	{ LIGHTBR,   1,       2 },
-	{ KAISERKN,  0,       2 },
-	{ DARIUSG,   0,       2 },
-	{ BUBSYMPH,  1,       1 },
-	{ SPCINVDX,  1,       1 },
-	{ QTHEATER,  1,       1 },
-	{ HTHERO95,  0,       1 },
-	{ SPCINV95,  0,       1 },
-	{ EACTION2,  1,       2 },
-	{ QUIZHUHU,  1,       1 },
-	{ PBOBBLE2,  0,       1 },
-	{ GEKIRIDO,  0,       1 },
-	{ KTIGER2,   0,       0 },
-	{ BUBBLEM,   1,       1 },
-	{ CLEOPATR,  0,       1 },
-	{ PBOBBLE3,  0,       1 },
-	{ ARKRETRN,  1,       1 },
-	{ KIRAMEKI,  0,       1 },
-	{ PUCHICAR,  1,       1 },
-	{ PBOBBLE4,  0,       1 },
-	{ POPNPOP,   1,       1 },
-	{ LANDMAKR,  1,       1 },
-	{ RECALH,    1,       1 },
-	{ COMMANDW,  1,       1 },
+	/* Name    Extend  Lag */
+	{ RINGRAGE,  0,     2 },
+	{ ARABIANM,  0,     2 },
+	{ RIDINGF,   1,     1 },
+	{ GSEEKER,   0,     1 },
+	{ COMMANDW,  1,     1 },
+	{ SCFINALS,  0,     1 },
+	{ TRSTAR,    1,     0 },
+	{ GUNLOCK,   1,     2 },
+	{ LIGHTBR,   1,     2 },
+	{ KAISERKN,  0,     2 },
+	{ DARIUSG,   0,     2 },
+	{ BUBSYMPH,  1,     1 },
+	{ SPCINVDX,  1,     1 },
+	{ HTHERO95,  0,     1 },
+	{ QTHEATER,  1,     1 },
+	{ EACTION2,  1,     2 },
+	{ RECALH,    1,     1 },
+	{ SPCINV95,  0,     1 },
+	{ TWINQIX,   1,     1 },
+	{ QUIZHUHU,  1,     1 },
+	{ PBOBBLE2,  0,     1 },
+	{ GEKIRIDO,  0,     1 },
+	{ KTIGER2,   0,     0 },
+	{ BUBBLEM,   1,     1 },
+	{ CLEOPATR,  0,     1 },
+	{ PBOBBLE3,  0,     1 },
+	{ ARKRETRN,  1,     1 },
+	{ KIRAMEKI,  0,     1 },
+	{ PUCHICAR,  1,     1 },
+	{ PBOBBLE4,  0,     1 },
+	{ POPNPOP,   1,     1 },
+	{ LANDMAKR,  1,     1 },
 	{0}
 };
 
@@ -292,7 +294,7 @@ static struct tempsprite *spritelist;
 static const struct tempsprite *sprite_end;
 
 static void get_sprite_info(running_machine *machine, const UINT32 *spriteram32_ptr);
-static int sprite_lag=1;
+static int sprite_lag;
 static UINT8 sprite_pri_usage=0;
 
 struct f3_playfield_line_inf
@@ -334,7 +336,7 @@ static struct f3_playfield_line_inf *pf_line_inf;
 static struct f3_spritealpha_line_inf *sa_line_inf;
 
 
-static mame_bitmap *pri_alp_bitmap;
+static bitmap_t *pri_alp_bitmap;
 /*
 pri_alp_bitmap
 ---- ---1    sprite priority 0
@@ -347,26 +349,73 @@ pri_alp_bitmap
 1--- ----    alpha level b b000
 1111 1111    opaque pixel
 */
-static int f3_alpha_level_2as=127;
-static int f3_alpha_level_2ad=127;
-static int f3_alpha_level_3as=127;
-static int f3_alpha_level_3ad=127;
-static int f3_alpha_level_2bs=127;
-static int f3_alpha_level_2bd=127;
-static int f3_alpha_level_3bs=127;
-static int f3_alpha_level_3bd=127;
+static int f3_alpha_level_2as;
+static int f3_alpha_level_2ad;
+static int f3_alpha_level_3as;
+static int f3_alpha_level_3ad;
+static int f3_alpha_level_2bs;
+static int f3_alpha_level_2bd;
+static int f3_alpha_level_3bs;
+static int f3_alpha_level_3bd;
+static int alpha_level_last;
 
 static void init_alpha_blend_func(void);
 
-static int width_mask=0x1ff;
-static int twidth_mask=0x1f,twidth_mask_bit=5;
+static int width_mask;
+static int twidth_mask;
+static int twidth_mask_bit;
+
 static UINT8 *tile_opaque_sp;
-static UINT8 *tile_opaque_pf;
+static UINT8 *tile_opaque_pf[4];
+
+
+static UINT8 add_sat[256][256];
+
+static int alpha_s_1_1;
+static int alpha_s_1_2;
+static int alpha_s_1_4;
+static int alpha_s_1_5;
+static int alpha_s_1_6;
+static int alpha_s_1_8;
+static int alpha_s_1_9;
+static int alpha_s_1_a;
+
+static int alpha_s_2a_0;
+static int alpha_s_2a_4;
+static int alpha_s_2a_8;
+
+static int alpha_s_2b_0;
+static int alpha_s_2b_4;
+static int alpha_s_2b_8;
+
+static int alpha_s_3a_0;
+static int alpha_s_3a_1;
+static int alpha_s_3a_2;
+
+static int alpha_s_3b_0;
+static int alpha_s_3b_1;
+static int alpha_s_3b_2;
+
+static UINT32 dval;
+static UINT8 pval;
+static UINT8 tval;
+static UINT8 pdest_2a;
+static UINT8 pdest_2b;
+static int tr_2a;
+static int tr_2b;
+static UINT8 pdest_3a;
+static UINT8 pdest_3b;
+static int tr_3a;
+static int tr_3b;
+
+static int (*dpix_n[8][16])(UINT32 s_pix);
+static int (**dpix_lp[5])(UINT32 s_pix);
+static int (**dpix_sp[9])(UINT32 s_pix);
 
 
 /******************************************************************************/
 
-static void print_debug_info(mame_bitmap *bitmap)
+static void print_debug_info(bitmap_t *bitmap)
 {
 	int l[16];
 	char buf[64*16];
@@ -443,14 +492,19 @@ static void print_debug_info(mame_bitmap *bitmap)
 INLINE void get_tile_info(running_machine *machine, tile_data *tileinfo, int tile_index, UINT32 *gfx_base)
 {
 	UINT32 tile=gfx_base[tile_index];
-	UINT8 abtype=(tile>>(16+9))&0x1f;
+	UINT8 abtype=(tile>>(16+9)) & 1;
+	// tiles can be configured to use 4, 5, or 6 bpp data.
+	// if tiles use more than 4bpp, the bottom bits of the color code must be masked out.
+	// This fixes (at least) the rain in round 6 of Arabian Magic.
+	UINT8 extra_planes = ((tile>>(16+10)) & 3);	// 0 = 4bpp, 1 = 5bpp, 2 = unused?, 3 = 6bpp
 
 	SET_TILE_INFO(
 			1,
 			tile&0xffff,
-			(tile>>16)&0x1ff,
+			(tile>>16) & 0x1ff & (~extra_planes),
 			TILE_FLIPYX( tile >> 30 ));
 	tileinfo->category =  abtype&1;		/* alpha blending type */
+	tileinfo->pen_mask = (extra_planes << 4) | 0x0f;
 }
 
 static TILE_GET_INFO( get_tile_info1 )
@@ -545,7 +599,26 @@ VIDEO_EOF( f3 )
 VIDEO_START( f3 )
 {
 	const struct F3config *pCFG=&f3_config_table[0];
-	int tile;
+	int tile, width, height, i;
+
+	f3_alpha_level_2as=127;
+	f3_alpha_level_2ad=127;
+	f3_alpha_level_3as=127;
+	f3_alpha_level_3ad=127;
+	f3_alpha_level_2bs=127;
+	f3_alpha_level_2bd=127;
+	f3_alpha_level_3bs=127;
+	f3_alpha_level_3bd=127;
+	alpha_level_last = -1;
+
+	pdest_2a = 0x10;
+	pdest_2b = 0x20;
+	tr_2a = 0;
+	tr_2b = 1;
+	pdest_3a = 0x40;
+	pdest_3b = 0x80;
+	tr_3a = 0;
+	tr_3b = 1;
 
 	spritelist=0;
 	spriteram32_buffered=0;
@@ -553,7 +626,6 @@ VIDEO_START( f3 )
 	pf_line_inf=0;
 	pri_alp_bitmap=0;
 	tile_opaque_sp=0;
-	tile_opaque_pf=0;
 
 	/* Setup individual game */
 	do {
@@ -567,10 +639,10 @@ VIDEO_START( f3 )
 	f3_game_config=pCFG;
 
 	if (f3_game_config->extend) {
-		pf1_tilemap = tilemap_create(get_tile_info1,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-		pf2_tilemap = tilemap_create(get_tile_info2,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-		pf3_tilemap = tilemap_create(get_tile_info3,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
-		pf4_tilemap = tilemap_create(get_tile_info4,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,64,32);
+		pf1_tilemap = tilemap_create(machine, get_tile_info1,tilemap_scan_rows,16,16,64,32);
+		pf2_tilemap = tilemap_create(machine, get_tile_info2,tilemap_scan_rows,16,16,64,32);
+		pf3_tilemap = tilemap_create(machine, get_tile_info3,tilemap_scan_rows,16,16,64,32);
+		pf4_tilemap = tilemap_create(machine, get_tile_info4,tilemap_scan_rows,16,16,64,32);
 
 		f3_pf_data_1=f3_pf_data+0x0000;
 		f3_pf_data_2=f3_pf_data+0x0800;
@@ -582,10 +654,10 @@ VIDEO_START( f3 )
 		twidth_mask_bit=6;
 
 	} else {
-		pf1_tilemap = tilemap_create(get_tile_info1,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,32,32);
-		pf2_tilemap = tilemap_create(get_tile_info2,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,32,32);
-		pf3_tilemap = tilemap_create(get_tile_info3,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,32,32);
-		pf4_tilemap = tilemap_create(get_tile_info4,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,32,32);
+		pf1_tilemap = tilemap_create(machine, get_tile_info1,tilemap_scan_rows,16,16,32,32);
+		pf2_tilemap = tilemap_create(machine, get_tile_info2,tilemap_scan_rows,16,16,32,32);
+		pf3_tilemap = tilemap_create(machine, get_tile_info3,tilemap_scan_rows,16,16,32,32);
+		pf4_tilemap = tilemap_create(machine, get_tile_info4,tilemap_scan_rows,16,16,32,32);
 
 		f3_pf_data_1=f3_pf_data+0x0000;
 		f3_pf_data_2=f3_pf_data+0x0400;
@@ -600,14 +672,17 @@ VIDEO_START( f3 )
 	spriteram32_buffered = (UINT32 *)auto_malloc(0x10000);
 	spritelist = auto_malloc(0x400 * sizeof(*spritelist));
 	sprite_end = spritelist;
-	vram_layer = tilemap_create(get_tile_info_vram,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,64,64);
-	pixel_layer = tilemap_create(get_tile_info_pixel,tilemap_scan_cols,TILEMAP_TYPE_PEN,8,8,64,32);
+	vram_layer = tilemap_create(machine, get_tile_info_vram,tilemap_scan_rows,8,8,64,64);
+	pixel_layer = tilemap_create(machine, get_tile_info_pixel,tilemap_scan_cols,8,8,64,32);
 	pivot_dirty = (UINT8 *)auto_malloc(2048);
 	pf_line_inf = auto_malloc(5 * sizeof(struct f3_playfield_line_inf));
 	sa_line_inf = auto_malloc(1 * sizeof(struct f3_spritealpha_line_inf));
-	pri_alp_bitmap = auto_bitmap_alloc( machine->screen[0].width, machine->screen[0].height, BITMAP_FORMAT_INDEXED8 );
+	width = video_screen_get_width(machine->primary_screen);
+	height = video_screen_get_height(machine->primary_screen);
+	pri_alp_bitmap = auto_bitmap_alloc(width, height, BITMAP_FORMAT_INDEXED8 );
 	tile_opaque_sp = (UINT8 *)auto_malloc(machine->gfx[2]->total_elements);
-	tile_opaque_pf = (UINT8 *)auto_malloc(machine->gfx[1]->total_elements);
+	for (i=0; i<4; i++)
+		tile_opaque_pf[i] = (UINT8 *)auto_malloc(machine->gfx[1]->total_elements);
 
 	tilemap_set_transparent_pen(pf1_tilemap,0);
 	tilemap_set_transparent_pen(pf2_tilemap,0);
@@ -616,7 +691,8 @@ VIDEO_START( f3 )
 	tilemap_set_transparent_pen(vram_layer,0);
 	tilemap_set_transparent_pen(pixel_layer,0);
 
-	/* Palettes have 4 bpp indexes despite up to 6 bpp data */
+	/* Palettes have 4 bpp indexes despite up to 6 bpp data. The unused */
+	/* top bits in the gfx data are cleared later.                      */
 	machine->gfx[1]->color_granularity=16;
 	machine->gfx[2]->color_granularity=16;
 
@@ -624,8 +700,8 @@ VIDEO_START( f3 )
 	memset(spriteram32_buffered,0,spriteram_size);
 	memset(spriteram32,0,spriteram_size);
 
-	state_save_register_global_array(f3_control_0);
-	state_save_register_global_array(f3_control_1);
+	state_save_register_global_array(machine, f3_control_0);
+	state_save_register_global_array(machine, f3_control_1);
 
 	for (tile = 0;tile < 256;tile++)
 		vram_dirty[tile]=1;
@@ -669,18 +745,27 @@ VIDEO_START( f3 )
 		for (c = 0;c < pf_gfx->total_elements;c++)
 		{
 			int x,y;
-			int chk_trans_or_opa=0;
-			UINT8 *dp = pf_gfx->gfxdata + c * pf_gfx->char_modulo;
-			for (y = 0;y < pf_gfx->height;y++)
+			int extra_planes; /* 0 = 4bpp, 1=5bpp, 2=?, 3=6bpp */
+
+			for (extra_planes=0; extra_planes<4; extra_planes++)
 			{
-				for (x = 0;x < pf_gfx->width;x++)
+				int chk_trans_or_opa=0;
+				UINT8 extra_mask = ((extra_planes << 4) | 0x0f);
+				UINT8 *dp = pf_gfx->gfxdata + c * pf_gfx->char_modulo;
+
+				for (y = 0;y < pf_gfx->height;y++)
 				{
-					if(!dp[x]) chk_trans_or_opa|=2;
-					else	   chk_trans_or_opa|=1;
+					for (x = 0;x < pf_gfx->width;x++)
+					{
+						if(!(dp[x] & extra_mask))
+							chk_trans_or_opa|=2;
+						else
+							chk_trans_or_opa|=1;
+					}
+					dp += pf_gfx->line_modulo;
 				}
-				dp += pf_gfx->line_modulo;
+				tile_opaque_pf[extra_planes][c]=chk_trans_or_opa;
 			}
-			tile_opaque_pf[c]=chk_trans_or_opa;
 		}
 	}
 }
@@ -811,54 +896,11 @@ WRITE32_HANDLER( f3_palette_24bit_w )
 		b = (paletteram32[offset] >> 0) & 0xff;
 	}
 
-	palette_set_color(Machine,offset,MAKE_RGB(r,g,b));
+	palette_set_color(space->machine,offset,MAKE_RGB(r,g,b));
 }
 
 /******************************************************************************/
 
-static UINT8 add_sat[256][256];
-
-static int alpha_s_1_1;
-static int alpha_s_1_2;
-static int alpha_s_1_4;
-static int alpha_s_1_5;
-static int alpha_s_1_6;
-static int alpha_s_1_8;
-static int alpha_s_1_9;
-static int alpha_s_1_a;
-
-static int alpha_s_2a_0;
-static int alpha_s_2a_4;
-static int alpha_s_2a_8;
-
-static int alpha_s_2b_0;
-static int alpha_s_2b_4;
-static int alpha_s_2b_8;
-
-static int alpha_s_3a_0;
-static int alpha_s_3a_1;
-static int alpha_s_3a_2;
-
-static int alpha_s_3b_0;
-static int alpha_s_3b_1;
-static int alpha_s_3b_2;
-
-static UINT32 dval;
-static UINT8 pval;
-static UINT8 tval;
-static UINT8 pdest_2a = 0x10;
-static UINT8 pdest_2b = 0x20;
-static int tr_2a = 0;
-static int tr_2b = 1;
-static UINT8 pdest_3a = 0x40;
-static UINT8 pdest_3b = 0x80;
-static int tr_3a = 0;
-static int tr_3b = 1;
-
-static int (*dpix_n[8][16])(UINT32 s_pix);
-static int (**dpix_lp[5])(UINT32 s_pix);
-static int (**dpix_sp[9])(UINT32 s_pix);
-
 /*============================================================================*/
 
 #define SET_ALPHA_LEVEL(d,s)			\
@@ -1355,28 +1397,46 @@ static void init_alpha_blend_func(void)
 	} \
 }
 
+#define UPDATE_PIXMAP_SP(pf_num) \
+	if(cx>=clip_als && cx<clip_ars && !(cx>=clip_bls && cx<clip_brs)) \
+	{ \
+		sprite_pri=sprite[pf_num]&pval; \
+		if(sprite_pri) \
+		{ \
+			if(sprite[pf_num]&0x100) break; \
+			if(!dpix_sp[sprite_pri]) \
+			{ \
+				if(!(pval&0xf0)) break; \
+				else {dpix_1_sprite(*dsti);*dsti=dval;break;} \
+			} \
+			if(dpix_sp[sprite_pri][pval>>4](*dsti)) {*dsti=dval;break;} \
+		} \
+	}
+
+#define UPDATE_PIXMAP_LP(pf_num) \
+	if (cx>=clip_al##pf_num && cx<clip_ar##pf_num && !(cx>=clip_bl##pf_num && cx<clip_br##pf_num)) \
+	{ \
+		tval=*tsrc##pf_num; \
+		if(tval&0xf0) \
+			if(dpix_lp[pf_num][pval>>4](clut[*src##pf_num])) {*dsti=dval;break;} \
+	}
+
+
 /*============================================================================*/
 
 INLINE void draw_scanlines(running_machine *machine,
-		mame_bitmap *bitmap,int xsize,INT16 *draw_line_num,
+		bitmap_t *bitmap,int xsize,INT16 *draw_line_num,
 		const struct f3_playfield_line_inf **line_t,
 		const int *sprite,
 		UINT32 orient,
 		int skip_layer_num)
 {
-	const pen_t *clut = &machine->remapped_colortable[0];
+	const pen_t *clut = &machine->pens[0];
 	UINT32 bgcolor=clut[0];
 	int length;
 
 	const int x=46;
 
-	UINT32 sprite_noalp_0=sprite[0]&0x100;
-	UINT32 sprite_noalp_1=sprite[1]&0x100;
-	UINT32 sprite_noalp_2=sprite[2]&0x100;
-	UINT32 sprite_noalp_3=sprite[3]&0x100;
-	UINT32 sprite_noalp_4=sprite[4]&0x100;
-	UINT32 sprite_noalp_5=sprite[5]&0x100;
-
 	static UINT16 *src0=0,*src_s0=0,*src_e0=0,clip_al0=0,clip_ar0=0,clip_bl0=0,clip_br0=0;
 	static UINT8 *tsrc0=0,*tsrc_s0=0;
 	static UINT32 x_count0=0,x_zoom0=0;
@@ -1455,80 +1515,12 @@ INLINE void draw_scanlines(running_machine *machine,
 					UINT8 sprite_pri;
 					switch(skip_layer_num)
 					{
-						case 0: if(cx>=clip_als && cx<clip_ars && !(cx>=clip_bls && cx<clip_brs) && (sprite_pri=sprite[0]&pval))
-								{
-									if(sprite_noalp_0) break;
-									if(!dpix_sp[sprite_pri]) break;
-									if(dpix_sp[sprite_pri][pval>>4](*dsti)) {*dsti=dval;break;}
-								}
-								if (cx>=clip_al0 && cx<clip_ar0 && !(cx>=clip_bl0 && cx<clip_br0)) {tval=*tsrc0;if(tval&0xf0) if(dpix_lp[0][pval>>4](clut[*src0])) {*dsti=dval;break;}}
-						case 1: if(cx>=clip_als && cx<clip_ars && !(cx>=clip_bls && cx<clip_brs) && (sprite_pri=sprite[1]&pval))
-								{
-									if(sprite_noalp_1) break;
-									if(!dpix_sp[sprite_pri])
-									{
-										if(!(pval&0xf0)) break;
-										else {dpix_1_sprite(*dsti);*dsti=dval;break;}
-									}
-									if(dpix_sp[sprite_pri][pval>>4](*dsti)) {*dsti=dval;break;}
-								}
-								if (cx>=clip_al1 && cx<clip_ar1 && !(cx>=clip_bl1 && cx<clip_br1)) {tval=*tsrc1;if(tval&0xf0) if(dpix_lp[1][pval>>4](clut[*src1])) {*dsti=dval;break;}}
-						case 2: if(cx>=clip_als && cx<clip_ars && !(cx>=clip_bls && cx<clip_brs) && (sprite_pri=sprite[2]&pval))
-								{
-									if(sprite_noalp_2) break;
-									if(!dpix_sp[sprite_pri])
-									{
-										if(!(pval&0xf0)) break;
-										else {dpix_1_sprite(*dsti);*dsti=dval;break;}
-									}
-									if(dpix_sp[sprite_pri][pval>>4](*dsti)) {*dsti=dval;break;}
-								}
-								if (cx>=clip_al2 && cx<clip_ar2 && !(cx>=clip_bl2 && cx<clip_br2)) {tval=*tsrc2;if(tval&0xf0) if(dpix_lp[2][pval>>4](clut[*src2])) {*dsti=dval;break;}}
-						case 3: if(cx>=clip_als && cx<clip_ars && !(cx>=clip_bls && cx<clip_brs) && (sprite_pri=sprite[3]&pval))
-								{
-									if(sprite_noalp_3) break;
-									if(!dpix_sp[sprite_pri])
-									{
-										if(!(pval&0xf0)) break;
-										else {dpix_1_sprite(*dsti);*dsti=dval;break;}
-									}
-									if(dpix_sp[sprite_pri][pval>>4](*dsti)) {*dsti=dval;break;}
-								}
-								if (cx>=clip_al3 && cx<clip_ar3 && !(cx>=clip_bl3 && cx<clip_br3)) {tval=*tsrc3;if(tval&0xf0) if(dpix_lp[3][pval>>4](clut[*src3])) {*dsti=dval;break;}}
-
-						case 4: if(cx>=clip_als && cx<clip_ars && !(cx>=clip_bls && cx<clip_brs) && (sprite_pri=sprite[4]&pval))
-								{
-									if(sprite_noalp_4) break;
-									if(!dpix_sp[sprite_pri])
-									{
-										if(!(pval&0xf0)) break;
-										else {dpix_1_sprite(*dsti);*dsti=dval;break;}
-									}
-									if(dpix_sp[sprite_pri][pval>>4](*dsti)) {*dsti=dval;break;}
-								}
-								if (cx>=clip_al4 && cx<clip_ar4 && !(cx>=clip_bl4 && cx<clip_br4)) {
-									tval=*tsrc4;
-									if(tval&0xf0)
-									{
-										if(dpix_lp[4][pval>>4](clut[*src4]))
-										{
-											*dsti=dval;
-											break;
-										}
-									}
-								}
-
-
-						case 5: if(cx>=clip_als && cx<clip_ars && !(cx>=clip_bls && cx<clip_brs) && (sprite_pri=sprite[5]&pval))
-								{
-									if(sprite_noalp_5) break;
-									if(!dpix_sp[sprite_pri])
-									{
-										if(!(pval&0xf0)) break;
-										else {dpix_1_sprite(*dsti);*dsti=dval;break;}
-									}
-									if(dpix_sp[sprite_pri][pval>>4](*dsti)) {*dsti=dval;break;}
-								}
+						case 0: UPDATE_PIXMAP_SP(0) UPDATE_PIXMAP_LP(0)
+						case 1: UPDATE_PIXMAP_SP(1) UPDATE_PIXMAP_LP(1)
+						case 2: UPDATE_PIXMAP_SP(2) UPDATE_PIXMAP_LP(2)
+						case 3: UPDATE_PIXMAP_SP(3) UPDATE_PIXMAP_LP(3)
+						case 4: UPDATE_PIXMAP_SP(4) UPDATE_PIXMAP_LP(4)
+						case 5: UPDATE_PIXMAP_SP(5)
 								if(!bgcolor) {if(!(pval&0xf0)) {*dsti=0;break;}}
 								else dpix_bg(bgcolor);
 								*dsti=dval;
@@ -1586,7 +1578,8 @@ static void visible_tile_check(running_machine *machine,
 	int opaque_all;
 	int total_elements;
 
-	if(!(alpha_mode=line_t->alpha_mode[line])) return;
+	alpha_mode=line_t->alpha_mode[line];
+	if(!alpha_mode) return;
 
 	total_elements=machine->gfx[1]->total_elements;
 
@@ -1608,12 +1601,13 @@ static void visible_tile_check(running_machine *machine,
 	for(i=0;i<tile_num;i++)
 	{
 		UINT32 tile=pf_base[(tile_index)&twidth_mask];
+		UINT8  extra_planes = (tile>>(16+10)) & 3;
 		if(tile&0xffff)
 		{
 			trans_all=0;
 			if(opaque_all)
 			{
-				if(tile_opaque_pf[(tile&0xffff)%total_elements]!=1) opaque_all=0;
+				if(tile_opaque_pf[extra_planes][(tile&0xffff)%total_elements]!=1) opaque_all=0;
 			}
 
 			if(alpha_mode==1)
@@ -1870,8 +1864,8 @@ static void get_spritealphaclip_info(void)
 static void get_line_ram_info(running_machine *machine, tilemap *tmap, int sx, int sy, int pos, UINT32 *f3_pf_data_n)
 {
 	struct f3_playfield_line_inf *line_t=&pf_line_inf[pos];
-	const mame_bitmap *srcbitmap;
-	const mame_bitmap *flagsbitmap;
+	const bitmap_t *srcbitmap;
+	const bitmap_t *flagsbitmap;
 
 	int y,y_start,y_end,y_inc;
 	int line_base,zoom_base,col_base,pri_base,inc;
@@ -2091,8 +2085,8 @@ static void get_vram_info(tilemap *vram_tilemap, tilemap *pixel_tilemap, int sx,
 {
 	const struct f3_spritealpha_line_inf *sprite_alpha_line_t=&sa_line_inf[0];
 	struct f3_playfield_line_inf *line_t=&pf_line_inf[4];
-	const mame_bitmap *srcbitmap_pixel, *srcbitmap_vram;
-	const mame_bitmap *flagsbitmap_pixel, *flagsbitmap_vram;
+	const bitmap_t *srcbitmap_pixel, *srcbitmap_vram;
+	const bitmap_t *flagsbitmap_pixel, *flagsbitmap_vram;
 
 	int y,y_start,y_end,y_inc;
 	int pri_base,inc;
@@ -2215,7 +2209,7 @@ static void get_vram_info(tilemap *vram_tilemap, tilemap *pixel_tilemap, int sx,
 
 /******************************************************************************/
 
-static void scanline_draw(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void scanline_draw(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	int i,j,y,ys,ye;
 	int y_start,y_end,y_start_next,y_end_next;
@@ -2242,7 +2236,6 @@ static void scanline_draw(running_machine *machine, mame_bitmap *bitmap, const r
 
 	while(1)
 	{
-		static int alpha_level_last=-1;
 		int pos;
 		int pri[5],alpha_mode[5],alpha_mode_flag[5],alpha_level;
 		UINT16 sprite_alpha;
@@ -2417,6 +2410,9 @@ static void scanline_draw(running_machine *machine, mame_bitmap *bitmap, const r
 				{
 					if(alpha_type==1)
 					{
+						/* if (f3_alpha_level_2as==0   && f3_alpha_level_2ad==255)
+                         *     alpha_mode[i]=3; alpha_mode_flag[i] |= 0x80;}
+                         * will display continue screen in gseeker (mt 00026) */
 						if     (f3_alpha_level_2as==0   && f3_alpha_level_2ad==255) alpha_mode[i]=0;
 						else if(f3_alpha_level_2as==255 && f3_alpha_level_2ad==0  ) alpha_mode[i]=1;
 					}
@@ -2564,11 +2560,13 @@ static void scanline_draw(running_machine *machine, mame_bitmap *bitmap, const r
 
 				/*
                     sprite priority==playfield priority
+                        GSEEKER (plane leaving hangar) --> sprite
                         BUBSYMPH (title)       ---> sprite
                         DARIUSG (ZONE V' BOSS) ---> playfield
                 */
 
 				if (f3_game == BUBSYMPH ) sp++;		//BUBSYMPH (title)
+				if (f3_game == GSEEKER ) sp++;		//GSEEKER (plane leaving hangar)
 
 					 if(		  sp>l0) sprite[0]|=sflg;
 				else if(sp<=l0 && sp>l1) sprite[1]|=sflg;
@@ -2613,7 +2611,7 @@ static void scanline_draw(running_machine *machine, mame_bitmap *bitmap, const r
 /******************************************************************************/
 
 #define PSET_T					\
-	c = *source;				\
+	c = *source & sprite_pen_mask;	\
 	if(c)						\
 	{							\
 		p=*pri;					\
@@ -2628,7 +2626,7 @@ static void scanline_draw(running_machine *machine, mame_bitmap *bitmap, const r
 	p=*pri;						\
 	if(!p || p==0xff)			\
 	{							\
-		*dest = pal[*source];	\
+		*dest = pal[*source & sprite_pen_mask];	\
 		*pri = pri_dst;			\
 	}
 
@@ -2637,7 +2635,8 @@ static void scanline_draw(running_machine *machine, mame_bitmap *bitmap, const r
 	dest++;						\
 	pri++;
 
-INLINE void f3_drawgfx( mame_bitmap *dest_bmp,const gfx_element *gfx,
+INLINE void f3_drawgfx( running_machine *machine,
+		bitmap_t *dest_bmp,const gfx_element *gfx,
 		UINT32 code,
 		UINT32 color,
 		int flipx,int flipy,
@@ -2668,7 +2667,7 @@ INLINE void f3_drawgfx( mame_bitmap *dest_bmp,const gfx_element *gfx,
 
 	if( gfx )
 	{
-		const pen_t *pal = &Machine->remapped_colortable[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
+		const pen_t *pal = &machine->pens[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
 		int source_base = (code % gfx->total_elements) * 16;
 
 		{
@@ -2800,7 +2799,8 @@ INLINE void f3_drawgfx( mame_bitmap *dest_bmp,const gfx_element *gfx,
 #undef NEXT_P
 
 
-INLINE void f3_drawgfxzoom(mame_bitmap *dest_bmp,const gfx_element *gfx,
+INLINE void f3_drawgfxzoom(running_machine *machine,
+		bitmap_t *dest_bmp,const gfx_element *gfx,
 		UINT32 code,
 		UINT32 color,
 		int flipx,int flipy,
@@ -2832,7 +2832,7 @@ INLINE void f3_drawgfxzoom(mame_bitmap *dest_bmp,const gfx_element *gfx,
 
 	if( gfx )
 	{
-		const pen_t *pal = &Machine->remapped_colortable[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
+		const pen_t *pal = &machine->pens[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
 		int source_base = (code % gfx->total_elements) * 16;
 
 		{
@@ -2907,7 +2907,7 @@ INLINE void f3_drawgfxzoom(mame_bitmap *dest_bmp,const gfx_element *gfx,
 						int x, x_index = x_index_base;
 						for( x=sx; x<ex; x++ )
 						{
-							int c = source[x_index>>16];
+							int c = source[x_index>>16] & sprite_pen_mask;
 							if(c)
 							{
 								UINT8 p=pri[x];
@@ -2937,8 +2937,9 @@ INLINE void f3_drawgfxzoom(mame_bitmap *dest_bmp,const gfx_element *gfx,
 
 static void get_sprite_info(running_machine *machine, const UINT32 *spriteram32_ptr)
 {
-	const int min_x=machine->screen[0].visarea.min_x,max_x=machine->screen[0].visarea.max_x;
-	const int min_y=machine->screen[0].visarea.min_y,max_y=machine->screen[0].visarea.max_y;
+	const rectangle *visarea = video_screen_get_visible_area(machine->primary_screen);
+	const int min_x=visarea->min_x,max_x=visarea->max_x;
+	const int min_y=visarea->min_y,max_y=visarea->max_y;
 	int offs,spritecont,flipx,flipy,old_x,old_y,color,x,y;
 	int sprite,global_x=0,global_y=0,subglobal_x=0,subglobal_y=0;
 	int block_x=0, block_y=0;
@@ -2984,6 +2985,9 @@ static void get_sprite_info(running_machine *machine, const UINT32 *spriteram32_
                 cntrl&0x0020 = ???
             */
 
+			sprite_extra_planes = (cntrl & 0x0300) >> 8;	// 0 = 4bpp, 1 = 5bpp, 2 = unused?, 3 = 6bpp
+			sprite_pen_mask = (sprite_extra_planes << 4) | 0x0f;
+
 			/* Sprite bank select */
 			if (cntrl&1) {
 				offs=offs|0x2000;
@@ -3198,13 +3202,17 @@ static void get_sprite_info(running_machine *machine, const UINT32 *spriteram32_
 #undef CALC_ZOOM
 
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 	const struct tempsprite *sprite_ptr;
 	const gfx_element *sprite_gfx = machine->gfx[2];
 
 	sprite_ptr = sprite_end;
 	sprite_pri_usage=0;
+
+	// if sprites use more than 4bpp, the bottom bits of the color code must be masked out.
+	// This fixes (at least) stage 1 battle ships and attract mode explosions in Ray Force.
+
 	while (sprite_ptr != spritelist)
 	{
 		int pri;
@@ -3214,17 +3222,19 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 		sprite_pri_usage|=1<<pri;
 
 		if(sprite_ptr->zoomx==16 && sprite_ptr->zoomy==16)
-			f3_drawgfx(bitmap,sprite_gfx,
+			f3_drawgfx(machine,
+					bitmap,sprite_gfx,
 					sprite_ptr->code,
-					sprite_ptr->color,
+					sprite_ptr->color & (~sprite_extra_planes),
 					sprite_ptr->flipx,sprite_ptr->flipy,
 					sprite_ptr->x,sprite_ptr->y,
 					cliprect,
 					pri);
 		else
-			f3_drawgfxzoom(bitmap,sprite_gfx,
+			f3_drawgfxzoom(machine,
+					bitmap,sprite_gfx,
 					sprite_ptr->code,
-					sprite_ptr->color,
+					sprite_ptr->color & (~sprite_extra_planes),
 					sprite_ptr->flipx,sprite_ptr->flipy,
 					sprite_ptr->x,sprite_ptr->y,
 					cliprect,
@@ -3247,7 +3257,7 @@ VIDEO_UPDATE( f3 )
 	if (vram_changed)
 		for (tile = 0;tile < 256;tile++)
 			if (vram_dirty[tile]) {
-				decodechar(machine->gfx[0],tile,(UINT8 *)f3_vram);
+				decodechar(screen->machine->gfx[0],tile,(UINT8 *)f3_vram);
 				tilemap_mark_all_tiles_dirty(vram_layer); // TODO
 				//tilemap_mark_tile_dirty(vram_layer,tile);
 				vram_dirty[tile]=0;
@@ -3257,7 +3267,7 @@ VIDEO_UPDATE( f3 )
 	if (pivot_changed)
 		for (tile = 0;tile < 2048;tile++)
 			if (pivot_dirty[tile]) {
-				decodechar(machine->gfx[3],tile,(UINT8 *)f3_pivot_ram);
+				decodechar(screen->machine->gfx[3],tile,(UINT8 *)f3_pivot_ram);
 				tilemap_mark_tile_dirty(pixel_layer,tile);
 				pivot_dirty[tile]=0;
 			}
@@ -3294,27 +3304,27 @@ VIDEO_UPDATE( f3 )
 		sy_fix[4]=-sy_fix[4];
 	}
 
-	fillbitmap(pri_alp_bitmap,0,cliprect);
+	bitmap_fill(pri_alp_bitmap,cliprect,0);
 
 	/* sprites */
 	if (sprite_lag==0)
-		get_sprite_info(machine, spriteram32);
+		get_sprite_info(screen->machine, spriteram32);
 
 	/* Update sprite buffer */
-	draw_sprites(machine, bitmap,cliprect);
+	draw_sprites(screen->machine, bitmap,cliprect);
 
 	/* Parse sprite, alpha & clipping parts of lineram */
 	get_spritealphaclip_info();
 
 	/* Parse playfield effects */
-	get_line_ram_info(machine, pf1_tilemap,sx_fix[0],sy_fix[0],0,f3_pf_data_1);
-	get_line_ram_info(machine, pf2_tilemap,sx_fix[1],sy_fix[1],1,f3_pf_data_2);
-	get_line_ram_info(machine, pf3_tilemap,sx_fix[2],sy_fix[2],2,f3_pf_data_3);
-	get_line_ram_info(machine, pf4_tilemap,sx_fix[3],sy_fix[3],3,f3_pf_data_4);
+	get_line_ram_info(screen->machine, pf1_tilemap,sx_fix[0],sy_fix[0],0,f3_pf_data_1);
+	get_line_ram_info(screen->machine, pf2_tilemap,sx_fix[1],sy_fix[1],1,f3_pf_data_2);
+	get_line_ram_info(screen->machine, pf3_tilemap,sx_fix[2],sy_fix[2],2,f3_pf_data_3);
+	get_line_ram_info(screen->machine, pf4_tilemap,sx_fix[3],sy_fix[3],3,f3_pf_data_4);
 	get_vram_info(vram_layer,pixel_layer,sx_fix[4],sy_fix[4]);
 
 	/* Draw final framebuffer */
-	scanline_draw(machine, bitmap,cliprect);
+	scanline_draw(screen->machine, bitmap,cliprect);
 
 	if (VERBOSE)
 		print_debug_info(bitmap);
