@@ -39,11 +39,9 @@ To Do:
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
+#include "includes/tetrisp2.h"
 
 
-extern UINT16 tetrisp2_systemregs[0x10];
-
 /* Variables needed by driver: */
 
 UINT16 *tetrisp2_vram_bg, *tetrisp2_scroll_bg;
@@ -58,6 +56,7 @@ UINT16 *rocknms_sub_vram_rot, *rocknms_sub_rotregs;
 
 UINT16 *rocknms_sub_priority;
 
+static int flipscreen_old;
 
 /***************************************************************************
 
@@ -72,14 +71,14 @@ WRITE16_HANDLER( tetrisp2_palette_w )
 {
 	data = COMBINE_DATA(&paletteram16[offset]);
 	if ((offset & 1) == 0)
-		palette_set_color_rgb(Machine,offset/2,pal5bit(data >> 1),pal5bit(data >> 6),pal5bit(data >> 11));
+		palette_set_color_rgb(space->machine,offset/2,pal5bit(data >> 1),pal5bit(data >> 6),pal5bit(data >> 11));
 }
 
 WRITE16_HANDLER( rocknms_sub_palette_w )
 {
 	data = COMBINE_DATA(&paletteram16_2[offset]);
 	if ((offset & 1) == 0)
-		palette_set_color_rgb(Machine,(0x8000 + (offset/2)),pal5bit(data >> 1),pal5bit(data >> 6),pal5bit(data >> 11));
+		palette_set_color_rgb(space->machine,(0x8000 + (offset/2)),pal5bit(data >> 1),pal5bit(data >> 6),pal5bit(data >> 11));
 }
 
 
@@ -105,7 +104,7 @@ READ16_HANDLER( rocknms_sub_priority_r )
 
 WRITE16_HANDLER( tetrisp2_priority_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		data |= ((data & 0xff00) >> 8);
 		tetrisp2_priority[offset] = data;
@@ -115,7 +114,7 @@ WRITE16_HANDLER( tetrisp2_priority_w )
 
 WRITE16_HANDLER( rockn_priority_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		tetrisp2_priority[offset] = data;
 	}
@@ -123,12 +122,16 @@ WRITE16_HANDLER( rockn_priority_w )
 
 WRITE16_HANDLER( rocknms_sub_priority_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		rocknms_sub_priority[offset] = data;
 	}
 }
 
+READ16_HANDLER( nndmseal_priority_r )
+{
+	return tetrisp2_priority[offset] | 0xff00;
+}
 
 
 /***************************************************************************
@@ -267,16 +270,18 @@ WRITE16_HANDLER( rocknms_sub_vram_rot_w )
 
 VIDEO_START( tetrisp2 )
 {
-	tilemap_bg = tilemap_create(	get_tile_info_bg,tilemap_scan_rows,
-								TILEMAP_TYPE_PEN,
+	flipscreen_old = -1;
+
+	tilemap_bg = tilemap_create(	machine, get_tile_info_bg,tilemap_scan_rows,
+
 								16,16,NX_0,NY_0);
 
-	tilemap_fg = tilemap_create(	get_tile_info_fg,tilemap_scan_rows,
-								TILEMAP_TYPE_PEN,
+	tilemap_fg = tilemap_create(	machine, get_tile_info_fg,tilemap_scan_rows,
+
 								8,8,NX_1,NY_1);
 
-	tilemap_rot = tilemap_create(	get_tile_info_rot,tilemap_scan_rows,
-								TILEMAP_TYPE_PEN,
+	tilemap_rot = tilemap_create(	machine, get_tile_info_rot,tilemap_scan_rows,
+
 								16,16,NX_0*2,NY_0*2);
 
 	tilemap_set_transparent_pen(tilemap_bg,0);
@@ -284,18 +289,26 @@ VIDEO_START( tetrisp2 )
 	tilemap_set_transparent_pen(tilemap_rot,0);
 }
 
+VIDEO_START( nndmseal )
+{
+	VIDEO_START_CALL( tetrisp2 );
+	tilemap_set_scrolldx(tilemap_bg, -4,-4);
+}
+
 VIDEO_START( rockntread )
 {
-	tilemap_bg = tilemap_create(	get_tile_info_bg,tilemap_scan_rows,
-								TILEMAP_TYPE_PEN,
+	flipscreen_old = -1;
+
+	tilemap_bg = tilemap_create(	machine, get_tile_info_bg,tilemap_scan_rows,
+
 								16, 16, 256, 16);	// rockn ms(main),1,2,3,4
 
-	tilemap_fg = tilemap_create(	get_tile_info_fg,tilemap_scan_rows,
-								TILEMAP_TYPE_PEN,
+	tilemap_fg = tilemap_create(	machine, get_tile_info_fg,tilemap_scan_rows,
+
 								8, 8, 64, 64);
 
-	tilemap_rot = tilemap_create(	get_tile_info_rot,tilemap_scan_rows,
-								TILEMAP_TYPE_PEN,
+	tilemap_rot = tilemap_create(	machine, get_tile_info_rot,tilemap_scan_rows,
+
 								16, 16, 128, 128);
 
 	tilemap_set_transparent_pen(tilemap_bg, 0);
@@ -306,33 +319,19 @@ VIDEO_START( rockntread )
 
 VIDEO_START( rocknms )
 {
-	tilemap_bg = tilemap_create(get_tile_info_bg,tilemap_scan_rows,
-					TILEMAP_TYPE_PEN,
-					16, 16, 256, 16);	// rockn ms(main),1,2,3,4
+	VIDEO_START_CALL( rockntread );
 
-	tilemap_fg = tilemap_create(get_tile_info_fg,tilemap_scan_rows,
-					TILEMAP_TYPE_PEN,
-					8, 8, 64, 64);
+	tilemap_sub_bg = tilemap_create(machine, get_tile_info_rocknms_sub_bg,tilemap_scan_rows,
 
-	tilemap_rot = tilemap_create(get_tile_info_rot,tilemap_scan_rows,
-					TILEMAP_TYPE_PEN,
-					16, 16, 128, 128);
-
-	tilemap_sub_bg = tilemap_create(get_tile_info_rocknms_sub_bg,tilemap_scan_rows,
-					TILEMAP_TYPE_PEN,
 					16, 16, 32, 256);	// rockn ms(sub)
 
-	tilemap_sub_fg = tilemap_create(get_tile_info_rocknms_sub_fg,tilemap_scan_rows,
-					TILEMAP_TYPE_PEN,
+	tilemap_sub_fg = tilemap_create(machine, get_tile_info_rocknms_sub_fg,tilemap_scan_rows,
+
 					8, 8, 64, 64);
 
-	tilemap_sub_rot = tilemap_create( get_tile_info_rocknms_sub_rot,tilemap_scan_rows,
-					TILEMAP_TYPE_PEN,
-					16, 16, 128, 128);
+	tilemap_sub_rot = tilemap_create( machine, get_tile_info_rocknms_sub_rot,tilemap_scan_rows,
 
-	tilemap_set_transparent_pen(tilemap_bg, 0);
-	tilemap_set_transparent_pen(tilemap_fg, 0);
-	tilemap_set_transparent_pen(tilemap_rot, 0);
+					16, 16, 128, 128);
 
 	tilemap_set_transparent_pen(tilemap_sub_bg, 0);
 	tilemap_set_transparent_pen(tilemap_sub_fg, 0);
@@ -379,7 +378,7 @@ VIDEO_START( rocknms )
 
 ***************************************************************************/
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, UINT16 *sprram_top, size_t sprram_size, int gfxnum)
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, UINT16 *sprram_top, size_t sprram_size, int gfxnum)
 {
 	int x, y, tx, ty, sx, sy, flipx, flipy;
 	int xsize, ysize, xnum, ynum;
@@ -509,7 +508,6 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 
 VIDEO_UPDATE( tetrisp2 )
 {
-	static int flipscreen_old = -1;
 	int flipscreen;
 	int asc_pri;
 	int scr_pri;
@@ -519,8 +517,8 @@ VIDEO_UPDATE( tetrisp2 )
 	flipscreen = (tetrisp2_systemregs[0x00] & 0x02);
 
 	/* Black background color */
-	fillbitmap(bitmap, machine->pens[0x0000], cliprect);
-	fillbitmap(priority_bitmap, 0, NULL);
+	bitmap_fill(bitmap, cliprect, 0);
+	bitmap_fill(priority_bitmap, NULL, 0);
 
 	/* Flip Screen */
 	if (flipscreen != flipscreen_old)
@@ -588,13 +586,12 @@ VIDEO_UPDATE( tetrisp2 )
 	else if (asc_pri == 2)
 		tilemap_draw(bitmap,cliprect, tilemap_fg,  0, 1 << 2);
 
-	draw_sprites(machine, bitmap,cliprect, spriteram16, spriteram_size, 0);
+	draw_sprites(screen->machine, bitmap,cliprect, spriteram16, spriteram_size, 0);
 	return 0;
 }
 
 VIDEO_UPDATE( rockntread )
 {
-	static int flipscreen_old = -1;
 	int flipscreen;
 	int asc_pri;
 	int scr_pri;
@@ -604,8 +601,8 @@ VIDEO_UPDATE( rockntread )
 	flipscreen = (tetrisp2_systemregs[0x00] & 0x02);
 
 	/* Black background color */
-	fillbitmap(bitmap, machine->pens[0x0000], cliprect);
-	fillbitmap(priority_bitmap, 0, NULL);
+	bitmap_fill(bitmap, cliprect, 0);
+	bitmap_fill(priority_bitmap, NULL, 0);
 
 	/* Flip Screen */
 	if (flipscreen != flipscreen_old)
@@ -673,7 +670,7 @@ VIDEO_UPDATE( rockntread )
 	else if (asc_pri == 2)
 		tilemap_draw(bitmap,cliprect, tilemap_fg,  0, 1 << 2);
 
-	draw_sprites(machine, bitmap,cliprect, spriteram16, spriteram_size, 0);
+	draw_sprites(screen->machine, bitmap,cliprect, spriteram16, spriteram_size, 0);
 	return 0;
 }
 
@@ -686,9 +683,11 @@ VIDEO_UPDATE( rocknms )
 	int scr_pri;
 	int rot_pri;
 
+	const device_config *left_screen  = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "left");
+	const device_config *right_screen = device_list_find_by_tag(screen->machine->config->devicelist, VIDEO_SCREEN, "right");
 
 	/* Black background color */
-	if (screen==0)
+	if (screen == left_screen)
 	{
 		tilemap_set_scrollx(tilemap_sub_bg, 0, rocknms_sub_scroll_bg[ 2 ] + 0x000);
 		tilemap_set_scrolly(tilemap_sub_bg, 0, rocknms_sub_scroll_bg[ 5 ] + 0x000);
@@ -697,8 +696,8 @@ VIDEO_UPDATE( rocknms )
 		tilemap_set_scrollx(tilemap_sub_rot, 0, rocknms_sub_rotregs[ 0 ] + 0x400);
 		tilemap_set_scrolly(tilemap_sub_rot, 0, rocknms_sub_rotregs[ 2 ] + 0x400);
 
-		fillbitmap(bitmap, machine->pens[0x0000], cliprect);
-		fillbitmap(priority_bitmap, 0, cliprect);
+		bitmap_fill(bitmap, cliprect, screen->machine->pens[0x0000]);
+		bitmap_fill(priority_bitmap, cliprect, 0);
 
 		asc_pri = scr_pri = rot_pri = 0;
 
@@ -738,9 +737,9 @@ VIDEO_UPDATE( rocknms )
 		else if (asc_pri == 2)
 			tilemap_draw(bitmap,cliprect, tilemap_sub_fg,  0, 1 << 2);
 
-		draw_sprites(machine, bitmap,cliprect, spriteram16_2, spriteram_2_size, 4);
+		draw_sprites(screen->machine, bitmap,cliprect, spriteram16_2, spriteram_2_size, 4);
 	}
-	else if (screen==1) /* game screen */
+	else if (screen == right_screen) /* game screen */
 	{
 		tilemap_set_scrollx(tilemap_bg, 0, tetrisp2_scroll_bg[ 2 ] + 0x000);
 		tilemap_set_scrolly(tilemap_bg, 0, tetrisp2_scroll_bg[ 5 ] + 0x000);
@@ -750,8 +749,8 @@ VIDEO_UPDATE( rocknms )
 		tilemap_set_scrolly(tilemap_rot, 0, tetrisp2_rotregs[ 2 ] + 0x400);
 
 		/* Black background color */
-		fillbitmap(bitmap, machine->pens[0x0000], cliprect);
-		fillbitmap(priority_bitmap, 0, cliprect);
+		bitmap_fill(bitmap, cliprect, screen->machine->pens[0x0000]);
+		bitmap_fill(priority_bitmap, cliprect, 0);
 
 		asc_pri = scr_pri = rot_pri = 0;
 
@@ -791,7 +790,7 @@ VIDEO_UPDATE( rocknms )
 		else if (asc_pri == 2)
 			tilemap_draw(bitmap,cliprect, tilemap_fg,  0, 1 << 2);
 
-		draw_sprites(machine, bitmap,cliprect, spriteram16, spriteram_size, 0);
+		draw_sprites(screen->machine, bitmap,cliprect, spriteram16, spriteram_size, 0);
 	}
 
 	return 0;
