@@ -5,7 +5,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "tia.h"
 #include "sound/tiaintf.h"
 
@@ -107,7 +106,7 @@ static UINT8 HMBL_latch;
 static UINT8 REFLECT;		/* Should playfield be reflected or not */
 static UINT8 NUSIZx_changed;
 
-static mame_bitmap *helper[3];
+static bitmap_t *helper[3];
 
 static UINT16 screen_height;
 
@@ -123,9 +122,9 @@ static const int nusiz[8][3] =
 	{ 1, 4, 0 }
 };
 
-static read16_handler	tia_read_input_port;
-static read8_handler	tia_get_databus;
-static write16_handler	tia_vsync_callback;
+static read16_space_func	tia_read_input_port;
+static read8_space_func	tia_get_databus;
+static write16_space_func	tia_vsync_callback;
 
 static void extend_palette(running_machine *machine) {
 	int	i,j;
@@ -272,18 +271,18 @@ PALETTE_INIT( tia_PAL )
 
 VIDEO_START( tia )
 {
-	int cx = machine->screen[0].width;
+	int cx = video_screen_get_width(machine->primary_screen);
 
-	screen_height = machine->screen[0].height;
-	helper[0] = auto_bitmap_alloc(cx, TIA_MAX_SCREEN_HEIGHT, machine->screen[0].format);
-	helper[1] = auto_bitmap_alloc(cx, TIA_MAX_SCREEN_HEIGHT, machine->screen[0].format);
-	helper[2] = auto_bitmap_alloc(cx, TIA_MAX_SCREEN_HEIGHT, machine->screen[0].format);
+	screen_height = video_screen_get_height(machine->primary_screen);
+	helper[0] = auto_bitmap_alloc(cx, TIA_MAX_SCREEN_HEIGHT, video_screen_get_format(machine->primary_screen));
+	helper[1] = auto_bitmap_alloc(cx, TIA_MAX_SCREEN_HEIGHT, video_screen_get_format(machine->primary_screen));
+	helper[2] = auto_bitmap_alloc(cx, TIA_MAX_SCREEN_HEIGHT, video_screen_get_format(machine->primary_screen));
 }
 
 
 VIDEO_UPDATE( tia )
 {
-	screen_height = machine->screen[0].height;
+	screen_height = video_screen_get_height(screen);
 	copybitmap(bitmap, helper[2], 0, 0, 0, 0, cliprect);
 	return 0;
 }
@@ -507,15 +506,15 @@ static int collision_check(UINT8* p1, UINT8* p2, int x1, int x2)
 }
 
 
-INLINE int current_x(void)
+INLINE int current_x(const address_space *space)
 {
-	return 3 * ((activecpu_gettotalcycles() - frame_cycles) % 76) - 68;
+	return 3 * ((cpu_get_total_cycles(space->cpu) - frame_cycles) % 76) - 68;
 }
 
 
-INLINE int current_y(void)
+INLINE int current_y(const address_space *space)
 {
-	return (activecpu_gettotalcycles() - frame_cycles) / 76;
+	return (cpu_get_total_cycles(space->cpu) - frame_cycles) / 76;
 }
 
 
@@ -854,11 +853,11 @@ static void update_bitmap(int next_x, int next_y)
 
 static WRITE8_HANDLER( WSYNC_w )
 {
-	int cycles = activecpu_gettotalcycles() - frame_cycles;
+	int cycles = cpu_get_total_cycles(space->cpu) - frame_cycles;
 
 	if (cycles % 76)
 	{
-		activecpu_adjust_icount(cycles % 76 - 76);
+		cpu_adjust_icount(space->cpu, cycles % 76 - 76);
 	}
 }
 
@@ -869,21 +868,21 @@ static WRITE8_HANDLER( VSYNC_w )
 	{
 		if (!(VSYNC & 2))
 		{
-			int curr_y = current_y();
+			int curr_y = current_y(space);
 
 			if ( curr_y > 5 )
 				update_bitmap(
-					Machine->screen[0].width,
-					Machine->screen[0].height);
+					video_screen_get_width(space->machine->primary_screen),
+					video_screen_get_height(space->machine->primary_screen));
 
 			if ( tia_vsync_callback ) {
-				tia_vsync_callback( 0, curr_y, 0xFFFF );
+				tia_vsync_callback( space, 0, curr_y, 0xFFFF );
 			}
 
 			prev_y = 0;
 			prev_x = 0;
 
-			frame_cycles += 76 * current_y();
+			frame_cycles += 76 * current_y(space);
 		}
 	}
 
@@ -895,7 +894,7 @@ static WRITE8_HANDLER( VBLANK_w )
 {
 	if (data & 0x80)
 	{
-		paddle_cycles = activecpu_gettotalcycles();
+		paddle_cycles = cpu_get_total_cycles(space->cpu);
 	}
 	if ( ! ( VBLANK & 0x40 ) ) {
 		INPT4 = 0x80;
@@ -907,7 +906,7 @@ static WRITE8_HANDLER( VBLANK_w )
 
 static WRITE8_HANDLER( CTRLPF_w )
 {
-	int curr_x = current_x();
+	int curr_x = current_x(space);
 
 	CTRLPF = data;
 	if ( curr_x < 80 ) {
@@ -917,7 +916,7 @@ static WRITE8_HANDLER( CTRLPF_w )
 
 static WRITE8_HANDLER( HMP0_w )
 {
-	int curr_x = current_x();
+	int curr_x = current_x(space);
 
 	data &= 0xF0;
 
@@ -949,7 +948,7 @@ static WRITE8_HANDLER( HMP0_w )
 
 static WRITE8_HANDLER( HMP1_w )
 {
-	int curr_x = current_x();
+	int curr_x = current_x(space);
 
 	data &= 0xF0;
 
@@ -981,7 +980,7 @@ static WRITE8_HANDLER( HMP1_w )
 
 static WRITE8_HANDLER( HMM0_w )
 {
-	int curr_x = current_x();
+	int curr_x = current_x(space);
 
 	data &= 0xF0;
 
@@ -1012,7 +1011,7 @@ static WRITE8_HANDLER( HMM0_w )
 
 static WRITE8_HANDLER( HMM1_w )
 {
-	int curr_x = current_x();
+	int curr_x = current_x(space);
 
 	data &= 0xF0;
 
@@ -1043,7 +1042,7 @@ static WRITE8_HANDLER( HMM1_w )
 
 static WRITE8_HANDLER( HMBL_w )
 {
-	int curr_x = current_x();
+	int curr_x = current_x(space);
 
 	data &= 0xF0;
 
@@ -1074,8 +1073,8 @@ static WRITE8_HANDLER( HMBL_w )
 
 static WRITE8_HANDLER( HMOVE_w )
 {
-	int curr_x = current_x();
-	int curr_y = current_y();
+	int curr_x = current_x(space);
+	int curr_y = current_y(space);
 
 	HMOVE_started = curr_x;
 
@@ -1205,7 +1204,7 @@ static WRITE8_HANDLER( RSYNC_w )
 
 static WRITE8_HANDLER( NUSIZ0_w )
 {
-	int curr_x = current_x();
+	int curr_x = current_x(space);
 
 	/* Check if relevant bits have changed */
 	if ( ( data & 7 ) != ( NUSIZ0 & 7 ) ) {
@@ -1220,7 +1219,7 @@ static WRITE8_HANDLER( NUSIZ0_w )
 						/* This copy has started drawing */
 						if ( p0gfx.size[i] == 1 && nusiz[data & 7][1] > 1 ) {
 							int delay = 1 + ( ( p0gfx.start_pixel[i] + ( curr_x - p0gfx.start_drawing[i] ) ) & 1 );
-							update_bitmap( curr_x + delay, current_y() );
+							update_bitmap( curr_x + delay, current_y(space) );
 							p0gfx.start_pixel[i] += ( curr_x + delay - p0gfx.start_drawing[i] );
 							if ( p0gfx.start_pixel[i] > 8 )
 								p0gfx.start_pixel[i] = 8;
@@ -1230,7 +1229,7 @@ static WRITE8_HANDLER( NUSIZ0_w )
 							if ( delay ) {
 								delay = p0gfx.size[i] - delay;
 							}
-							update_bitmap( curr_x + delay, current_y() );
+							update_bitmap( curr_x + delay, current_y(space) );
 							p0gfx.start_pixel[i] += ( curr_x - p0gfx.start_drawing[i] ) / p0gfx.size[i];
 							p0gfx.start_drawing[i] = curr_x + delay;
 						} else {
@@ -1283,7 +1282,7 @@ static WRITE8_HANDLER( NUSIZ0_w )
 
 static WRITE8_HANDLER( NUSIZ1_w )
 {
-	int curr_x = current_x();
+	int curr_x = current_x(space);
 
 	/* Check if relevant bits have changed */
 	if ( ( data & 7 ) != ( NUSIZ1 & 7 ) ) {
@@ -1298,7 +1297,7 @@ static WRITE8_HANDLER( NUSIZ1_w )
 						/* This copy has started drawing */
 						if ( p1gfx.size[i] == 1 && nusiz[data & 7][1] > 1 ) {
 							int delay = 1 + ( ( p0gfx.start_pixel[i] + ( curr_x - p0gfx.start_drawing[i] ) ) & 1 );
-							update_bitmap( curr_x + delay, current_y() );
+							update_bitmap( curr_x + delay, current_y(space) );
 							p1gfx.start_pixel[i] += ( curr_x + delay - p1gfx.start_drawing[i] );
 							if ( p1gfx.start_pixel[i] > 8 )
 								p1gfx.start_pixel[i] = 8;
@@ -1308,7 +1307,7 @@ static WRITE8_HANDLER( NUSIZ1_w )
 							if ( delay ) {
 								delay = p1gfx.size[i] - delay;
 							}
-							update_bitmap( curr_x + delay, current_y() );
+							update_bitmap( curr_x + delay, current_y(space) );
 							p1gfx.start_pixel[i] += ( curr_x - p1gfx.start_drawing[i] ) / p1gfx.size[i];
 							p1gfx.start_drawing[i] = curr_x + delay;
 						} else {
@@ -1361,11 +1360,11 @@ static WRITE8_HANDLER( NUSIZ1_w )
 
 static WRITE8_HANDLER( HMCLR_w )
 {
-	HMP0_w( offset, 0 );
-	HMP1_w( offset, 0 );
-	HMM0_w( offset, 0 );
-	HMM1_w( offset, 0 );
-	HMBL_w( offset, 0 );
+	HMP0_w( space, offset, 0 );
+	HMP1_w( space, offset, 0 );
+	HMM0_w( space, offset, 0 );
+	HMM1_w( space, offset, 0 );
+	HMBL_w( space, offset, 0 );
 }
 
 
@@ -1406,7 +1405,7 @@ static WRITE8_HANDLER( CXCLR_w )
 
 static WRITE8_HANDLER( RESP0_w )
 {
-	int curr_x = current_x();
+	int curr_x = current_x(space);
 	int new_horzP0;
 
 	/* Check if HMOVE is activated during this line */
@@ -1466,7 +1465,7 @@ static WRITE8_HANDLER( RESP0_w )
 
 static WRITE8_HANDLER( RESP1_w )
 {
-	int curr_x = current_x();
+	int curr_x = current_x(space);
 	int new_horzP1;
 
 	/* Check if HMOVE is activated during this line */
@@ -1526,7 +1525,7 @@ static WRITE8_HANDLER( RESP1_w )
 
 static WRITE8_HANDLER( RESM0_w )
 {
-	int curr_x = current_x();
+	int curr_x = current_x(space);
 	int new_horzM0;
 
 	/* Check if HMOVE is activated during this line */
@@ -1548,7 +1547,7 @@ static WRITE8_HANDLER( RESM0_w )
 
 static WRITE8_HANDLER( RESM1_w )
 {
-	int curr_x = current_x();
+	int curr_x = current_x(space);
 	int new_horzM1;
 
 	/* Check if HMOVE is activated during this line */
@@ -1570,7 +1569,7 @@ static WRITE8_HANDLER( RESM1_w )
 
 static WRITE8_HANDLER( RESBL_w )
 {
-	int curr_x = current_x();
+	int curr_x = current_x(space);
 
 	/* Check if HMOVE is activated during this line */
 	if ( HMOVE_started != HMOVE_INACTIVE ) {
@@ -1648,12 +1647,11 @@ static WRITE8_HANDLER( GRP1_w )
 
 static READ8_HANDLER( INPT_r )
 {
-	UINT64 elapsed = activecpu_gettotalcycles() - paddle_cycles;
+	UINT64 elapsed = cpu_get_total_cycles(space->cpu) - paddle_cycles;
 	int input = TIA_INPUT_PORT_ALWAYS_ON;
-
 	if ( tia_read_input_port )
 	{
-		input = tia_read_input_port(offset & 3, 0xFFFF);
+		input = tia_read_input_port(space, offset & 3, 0xFFFF);
 	}
 
 	if ( input == TIA_INPUT_PORT_ALWAYS_ON )
@@ -1676,12 +1674,12 @@ READ8_HANDLER( tia_r )
 
 	if ( tia_get_databus )
 	{
-		data = tia_get_databus(offset) & 0x3f;
+		data = tia_get_databus(space, offset) & 0x3f;
 	}
 
 	if (!(offset & 0x8))
 	{
-		update_bitmap(current_x(), current_y());
+		update_bitmap(current_x(space), current_y(space));
 	}
 
 	switch (offset & 0xF)
@@ -1703,22 +1701,22 @@ READ8_HANDLER( tia_r )
 	case 0x7:
 		return data | CXPPMM;
 	case 0x8:
-		return data | INPT_r(0);
+		return data | INPT_r(space,0);
 	case 0x9:
-		return data | INPT_r(1);
+		return data | INPT_r(space,1);
 	case 0xA:
-		return data | INPT_r(2);
+		return data | INPT_r(space,2);
 	case 0xB:
-		return data | INPT_r(3);
+		return data | INPT_r(space,3);
 	case 0xC:
 		{
-			int	button = tia_read_input_port ? ( tia_read_input_port(4,0xFFFF) & 0x80 ) : 0x80;
+			int	button = tia_read_input_port ? ( tia_read_input_port(space,4,0xFFFF) & 0x80 ) : 0x80;
 			INPT4 = ( VBLANK & 0x40) ? ( INPT4 & button ) : button;
 		}
 		return data | INPT4;
 	case 0xD:
 		{
-			int button = tia_read_input_port ? ( tia_read_input_port(5,0xFFFF) & 0x80 ) : 0x80;
+			int button = tia_read_input_port ? ( tia_read_input_port(space,5,0xFFFF) & 0x80 ) : 0x80;
 			INPT5 = ( VBLANK & 0x40) ? ( INPT5 & button ) : button;
 		}
 		return data | INPT5;
@@ -1778,9 +1776,8 @@ WRITE8_HANDLER( tia_w )
 		 0,	// HMCLR
 		 0,	// CXCLR
 	};
-
-	int curr_x = current_x();
-	int curr_y = current_y();
+	int curr_x = current_x(space);
+	int curr_y = current_y(space);
 
 	offset &= 0x3F;
 
@@ -1797,22 +1794,22 @@ WRITE8_HANDLER( tia_w )
 	switch (offset)
 	{
 	case 0x00:
-		VSYNC_w(offset, data);
+		VSYNC_w(space, offset, data);
 		break;
 	case 0x01:
-		VBLANK_w(offset, data);
+		VBLANK_w(space, offset, data);
 		break;
 	case 0x02:
-		WSYNC_w(offset, data);
+		WSYNC_w(space, offset, data);
 		break;
 	case 0x03:
-		RSYNC_w(offset, data);
+		RSYNC_w(space, offset, data);
 		break;
 	case 0x04:
-		NUSIZ0_w(offset, data);
+		NUSIZ0_w(space, offset, data);
 		break;
 	case 0x05:
-		NUSIZ1_w(offset, data);
+		NUSIZ1_w(space, offset, data);
 		break;
 	case 0x06:
 		COLUP0 = data;
@@ -1827,7 +1824,7 @@ WRITE8_HANDLER( tia_w )
 		COLUBK = data;
 		break;
 	case 0x0A:
-		CTRLPF_w(offset, data);
+		CTRLPF_w(space, offset, data);
 		break;
 	case 0x0B:
 		REFP0 = data;
@@ -1845,19 +1842,19 @@ WRITE8_HANDLER( tia_w )
 		PF2 = data;
 		break;
 	case 0x10:
-		RESP0_w(offset, data);
+		RESP0_w(space, offset, data);
 		break;
 	case 0x11:
-		RESP1_w(offset, data);
+		RESP1_w(space, offset, data);
 		break;
 	case 0x12:
-		RESM0_w(offset, data);
+		RESM0_w(space, offset, data);
 		break;
 	case 0x13:
-		RESM1_w(offset, data);
+		RESM1_w(space, offset, data);
 		break;
 	case 0x14:
-		RESBL_w(offset, data);
+		RESBL_w(space, offset, data);
 		break;
 
 	case 0x15: /* AUDC0 */
@@ -1866,14 +1863,14 @@ WRITE8_HANDLER( tia_w )
 	case 0x18: /* AUDF1 */
 	case 0x19: /* AUDV0 */
 	case 0x1A: /* AUDV1 */
-		tia_sound_w(offset, data);
+		tia_sound_w(space, offset, data);
 		break;
 
 	case 0x1B:
-		GRP0_w(offset, data);
+		GRP0_w(space, offset, data);
 		break;
 	case 0x1C:
-		GRP1_w(offset, data);
+		GRP1_w(space, offset, data);
 		break;
 	case 0x1D:
 		ENAM0 = data;
@@ -1885,19 +1882,19 @@ WRITE8_HANDLER( tia_w )
 		ENABL = data;
 		break;
 	case 0x20:
-		HMP0_w(offset, data);
+		HMP0_w(space, offset, data);
 		break;
 	case 0x21:
-		HMP1_w(offset, data);
+		HMP1_w(space, offset, data);
 		break;
 	case 0x22:
-		HMM0_w(offset, data);
+		HMM0_w(space, offset, data);
 		break;
 	case 0x23:
-		HMM1_w(offset, data);
+		HMM1_w(space, offset, data);
 		break;
 	case 0x24:
-		HMBL_w(offset, data);
+		HMBL_w(space, offset, data);
 		break;
 	case 0x25:
 		VDELP0 = data;
@@ -1909,19 +1906,19 @@ WRITE8_HANDLER( tia_w )
 		VDELBL = data;
 		break;
 	case 0x28:
-		RESMP0_w(offset, data);
+		RESMP0_w(space, offset, data);
 		break;
 	case 0x29:
-		RESMP1_w(offset, data);
+		RESMP1_w(space, offset, data);
 		break;
 	case 0x2A:
-		HMOVE_w(offset, data);
+		HMOVE_w(space, offset, data);
 		break;
 	case 0x2B:
-		HMCLR_w(offset, data);
+		HMCLR_w(space, offset, data);
 		break;
 	case 0x2C:
-		CXCLR_w(offset, 0);
+		CXCLR_w(space, offset, 0);
 		break;
 	}
 }
@@ -1982,9 +1979,9 @@ static void tia_reset(running_machine *machine)
 
 
 
-void tia_init(const struct tia_interface* ti)
+void tia_init(running_machine *machine, const struct tia_interface* ti)
 {
-	assert_always(mame_get_phase(Machine) == MAME_PHASE_INIT, "Can only call tia_init at init time!");
+	assert_always(mame_get_phase(machine) == MAME_PHASE_INIT, "Can only call tia_init at init time!");
 
 	if ( ti ) {
 		tia_read_input_port = ti->read_input_port;
@@ -1996,8 +1993,8 @@ void tia_init(const struct tia_interface* ti)
 		tia_vsync_callback = NULL;
 	}
 
-	tia_reset( Machine );
+	tia_reset( machine );
 
-	add_reset_callback(Machine, tia_reset);
+	add_reset_callback(machine, tia_reset);
 }
 
