@@ -1,7 +1,7 @@
 #include "driver.h"
-#include "deprecat.h"
 #include "machine/eeprom.h"
 #include "video/konamiic.h"
+#include "includes/tmnt.h"
 
 
 static int layer_colorbase[3],sprite_colorbase,bg_colorbase;
@@ -19,7 +19,7 @@ static int glfgreat_roz_rom_bank,glfgreat_roz_char_bank,glfgreat_roz_rom_mode;
 
 static TILE_GET_INFO( glfgreat_get_roz_tile_info )
 {
-	UINT8 *rom = memory_region(REGION_USER1);
+	UINT8 *rom = memory_region(machine, "user1");
 	int code;
 
 	tile_index += 0x40000 * glfgreat_roz_rom_bank;
@@ -31,7 +31,7 @@ static TILE_GET_INFO( glfgreat_get_roz_tile_info )
 
 static TILE_GET_INFO( prmrsocr_get_roz_tile_info )
 {
-	UINT8 *rom = memory_region(REGION_USER1);
+	UINT8 *rom = memory_region(machine, "user1");
 	int code = rom[tile_index+0x20000] + 256*rom[tile_index];
 
 	SET_TILE_INFO(0,code & 0x1fff,code >> 13,0);
@@ -213,8 +213,8 @@ VIDEO_START( mia )
 	layer_colorbase[1] = 32;
 	layer_colorbase[2] = 40;
 	sprite_colorbase = 16;
-	K052109_vh_start(machine,REGION_GFX1,NORMAL_PLANE_ORDER,mia_tile_callback);
-	K051960_vh_start(machine,REGION_GFX2,REVERSE_PLANE_ORDER,mia_sprite_callback);
+	K052109_vh_start(machine,"gfx1",NORMAL_PLANE_ORDER,mia_tile_callback);
+	K051960_vh_start(machine,"gfx2",REVERSE_PLANE_ORDER,mia_sprite_callback);
 }
 
 VIDEO_START( cuebrick )
@@ -223,8 +223,8 @@ VIDEO_START( cuebrick )
 	layer_colorbase[1] = 32;
 	layer_colorbase[2] = 40;
 	sprite_colorbase = 16;
-	K052109_vh_start(machine,REGION_GFX1,NORMAL_PLANE_ORDER,cuebrick_tile_callback);
-	K051960_vh_start(machine,REGION_GFX2,REVERSE_PLANE_ORDER,mia_sprite_callback);
+	K052109_vh_start(machine,"gfx1",NORMAL_PLANE_ORDER,cuebrick_tile_callback);
+	K051960_vh_start(machine,"gfx2",REVERSE_PLANE_ORDER,mia_sprite_callback);
 }
 
 VIDEO_START( tmnt )
@@ -233,54 +233,54 @@ VIDEO_START( tmnt )
 	layer_colorbase[1] = 32;
 	layer_colorbase[2] = 40;
 	sprite_colorbase = 16;
-	K052109_vh_start(machine,REGION_GFX1,NORMAL_PLANE_ORDER,tmnt_tile_callback);
-	K051960_vh_start(machine,REGION_GFX2,REVERSE_PLANE_ORDER,tmnt_sprite_callback);
+	K052109_vh_start(machine,"gfx1",NORMAL_PLANE_ORDER,tmnt_tile_callback);
+	K051960_vh_start(machine,"gfx2",REVERSE_PLANE_ORDER,tmnt_sprite_callback);
 }
 
 VIDEO_START( punkshot )
 {
-	K053251_vh_start();
-	K052109_vh_start(machine,REGION_GFX1,NORMAL_PLANE_ORDER,tmnt_tile_callback);
-	K051960_vh_start(machine,REGION_GFX2,NORMAL_PLANE_ORDER,punkshot_sprite_callback);
+	K053251_vh_start(machine);
+	K052109_vh_start(machine,"gfx1",NORMAL_PLANE_ORDER,tmnt_tile_callback);
+	K051960_vh_start(machine,"gfx2",NORMAL_PLANE_ORDER,punkshot_sprite_callback);
 }
 
 VIDEO_START( lgtnfght )	/* also tmnt2, ssriders */
 {
-	K053251_vh_start();
-	K052109_vh_start(machine,REGION_GFX1,NORMAL_PLANE_ORDER,tmnt_tile_callback);
-	K053245_vh_start(machine,0, REGION_GFX2,NORMAL_PLANE_ORDER,lgtnfght_sprite_callback);
+	K053251_vh_start(machine);
+	K052109_vh_start(machine,"gfx1",NORMAL_PLANE_ORDER,tmnt_tile_callback);
+	K053245_vh_start(machine,0, "gfx2",NORMAL_PLANE_ORDER,lgtnfght_sprite_callback);
 
 	K05324x_set_z_rejection(0);
 
 	dim_c = dim_v = lastdim = lasten = 0;
 
-	state_save_register_global(dim_c);
-	state_save_register_global(dim_v);
-	state_save_register_global(lastdim);
-	state_save_register_global(lasten);
+	state_save_register_global(machine, dim_c);
+	state_save_register_global(machine, dim_v);
+	state_save_register_global(machine, lastdim);
+	state_save_register_global(machine, lasten);
 }
 
 VIDEO_START( sunsetbl )
 {
-	K053251_vh_start();
-	K052109_vh_start(machine,REGION_GFX1,NORMAL_PLANE_ORDER,ssbl_tile_callback);
-	K053245_vh_start(machine,0, REGION_GFX2,NORMAL_PLANE_ORDER,lgtnfght_sprite_callback);
+	K053251_vh_start(machine);
+	K052109_vh_start(machine,"gfx1",NORMAL_PLANE_ORDER,ssbl_tile_callback);
+	K053245_vh_start(machine,0, "gfx2",NORMAL_PLANE_ORDER,lgtnfght_sprite_callback);
 }
 
 VIDEO_START( blswhstl )
 {
-	K053251_vh_start();
-	K052109_vh_start(machine,REGION_GFX1,NORMAL_PLANE_ORDER,blswhstl_tile_callback);
-	K053245_vh_start(machine,0, REGION_GFX2,NORMAL_PLANE_ORDER,blswhstl_sprite_callback);
+	K053251_vh_start(machine);
+	K052109_vh_start(machine,"gfx1",NORMAL_PLANE_ORDER,blswhstl_tile_callback);
+	K053245_vh_start(machine,0, "gfx2",NORMAL_PLANE_ORDER,blswhstl_sprite_callback);
 }
 
 VIDEO_START( glfgreat )
 {
-	K053251_vh_start();
-	K052109_vh_start(machine,REGION_GFX1,NORMAL_PLANE_ORDER,tmnt_tile_callback);
-	K053245_vh_start(machine,0, REGION_GFX2,NORMAL_PLANE_ORDER,lgtnfght_sprite_callback);
+	K053251_vh_start(machine);
+	K052109_vh_start(machine,"gfx1",NORMAL_PLANE_ORDER,tmnt_tile_callback);
+	K053245_vh_start(machine,0, "gfx2",NORMAL_PLANE_ORDER,lgtnfght_sprite_callback);
 
-	roz_tilemap = tilemap_create(glfgreat_get_roz_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,512,512);
+	roz_tilemap = tilemap_create(machine, glfgreat_get_roz_tile_info,tilemap_scan_rows,16,16,512,512);
 
 	tilemap_set_transparent_pen(roz_tilemap,0);
 
@@ -290,18 +290,18 @@ VIDEO_START( glfgreat )
 
 VIDEO_START( thndrx2 )
 {
-	K053251_vh_start();
-	K052109_vh_start(machine,REGION_GFX1,NORMAL_PLANE_ORDER,tmnt_tile_callback);
-	K051960_vh_start(machine,REGION_GFX2,NORMAL_PLANE_ORDER,thndrx2_sprite_callback);
+	K053251_vh_start(machine);
+	K052109_vh_start(machine,"gfx1",NORMAL_PLANE_ORDER,tmnt_tile_callback);
+	K051960_vh_start(machine,"gfx2",NORMAL_PLANE_ORDER,thndrx2_sprite_callback);
 }
 
 VIDEO_START( prmrsocr )
 {
-	K053251_vh_start();
-	K052109_vh_start(machine,REGION_GFX1,NORMAL_PLANE_ORDER,tmnt_tile_callback);
-	K053245_vh_start(machine,0, REGION_GFX2,NORMAL_PLANE_ORDER,prmrsocr_sprite_callback);
+	K053251_vh_start(machine);
+	K052109_vh_start(machine,"gfx1",NORMAL_PLANE_ORDER,tmnt_tile_callback);
+	K053245_vh_start(machine,0, "gfx2",NORMAL_PLANE_ORDER,prmrsocr_sprite_callback);
 
-	roz_tilemap = tilemap_create(prmrsocr_get_roz_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,16,16,512,256);
+	roz_tilemap = tilemap_create(machine, prmrsocr_get_roz_tile_info,tilemap_scan_rows,16,16,512,256);
 
 	tilemap_set_transparent_pen(roz_tilemap,0);
 
@@ -323,14 +323,14 @@ WRITE16_HANDLER( tmnt_paletteram_word_w )
 	offset &= ~1;
 
 	data = (paletteram16[offset] << 8) | paletteram16[offset+1];
-	palette_set_color_rgb(Machine,offset / 2,pal5bit(data >> 0),pal5bit(data >> 5),pal5bit(data >> 10));
+	palette_set_color_rgb(space->machine,offset / 2,pal5bit(data >> 0),pal5bit(data >> 5),pal5bit(data >> 10));
 }
 
 
 
 WRITE16_HANDLER( tmnt_0a0000_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		static int last;
 
@@ -340,12 +340,12 @@ WRITE16_HANDLER( tmnt_0a0000_w )
 
 		/* bit 3 high then low triggers irq on sound CPU */
 		if (last == 0x08 && (data & 0x08) == 0)
-			cpunum_set_input_line_and_vector(Machine, 1,0,HOLD_LINE,0xff);
+			cpu_set_input_line_and_vector(space->machine->cpu[1],0,HOLD_LINE,0xff);
 
 		last = data & 0x08;
 
 		/* bit 5 = irq enable */
-		interrupt_enable_w(0,data & 0x20);
+		interrupt_enable_w(space,0,data & 0x20);
 
 		/* bit 7 = enable char ROM reading through the video RAM */
 		K052109_set_RMRD_line((data & 0x80) ? ASSERT_LINE : CLEAR_LINE);
@@ -356,7 +356,7 @@ WRITE16_HANDLER( tmnt_0a0000_w )
 
 WRITE16_HANDLER( punkshot_0a0020_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		static int last;
 
@@ -366,7 +366,7 @@ WRITE16_HANDLER( punkshot_0a0020_w )
 
 		/* bit 2 = trigger irq on sound CPU */
 		if (last == 0x04 && (data & 0x04) == 0)
-			cpunum_set_input_line_and_vector(Machine, 1,0,HOLD_LINE,0xff);
+			cpu_set_input_line_and_vector(space->machine->cpu[1],0,HOLD_LINE,0xff);
 
 		last = data & 0x04;
 
@@ -377,7 +377,7 @@ WRITE16_HANDLER( punkshot_0a0020_w )
 
 WRITE16_HANDLER( lgtnfght_0a0018_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		static int last;
 
@@ -388,7 +388,7 @@ WRITE16_HANDLER( lgtnfght_0a0018_w )
 
 		/* bit 2 = trigger irq on sound CPU */
 		if (last == 0x00 && (data & 0x04) == 0x04)
-			cpunum_set_input_line_and_vector(Machine, 1,0,HOLD_LINE,0xff);
+			cpu_set_input_line_and_vector(space->machine->cpu[1],0,HOLD_LINE,0xff);
 
 		last = data & 0x04;
 
@@ -399,7 +399,7 @@ WRITE16_HANDLER( lgtnfght_0a0018_w )
 
 WRITE16_HANDLER( blswhstl_700300_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		/* bit 0,1 = coin counter */
 		coin_counter_w(0,data & 0x01);
@@ -423,17 +423,20 @@ WRITE16_HANDLER( blswhstl_700300_w )
 READ16_HANDLER( glfgreat_rom_r )
 {
 	if (glfgreat_roz_rom_mode)
-		return memory_region(REGION_GFX3)[glfgreat_roz_char_bank * 0x80000 + offset];
+		return memory_region(space->machine, "gfx3")[glfgreat_roz_char_bank * 0x80000 + offset];
 	else if (offset < 0x40000)
-		return memory_region(REGION_USER1)[offset + 0x80000 + glfgreat_roz_rom_bank * 0x40000] +
-				256 * memory_region(REGION_USER1)[offset + glfgreat_roz_rom_bank * 0x40000];
+	{
+		UINT8 *usr = memory_region(space->machine, "user1");
+		return usr[offset + 0x80000 + glfgreat_roz_rom_bank * 0x40000] +
+				256 * usr[offset + glfgreat_roz_rom_bank * 0x40000];
+	}
 	else
-		return memory_region(REGION_USER1)[((offset & 0x3ffff) >> 2) + 0x100000 + glfgreat_roz_rom_bank * 0x10000];
+		return memory_region(space->machine, "user1")[((offset & 0x3ffff) >> 2) + 0x100000 + glfgreat_roz_rom_bank * 0x10000];
 }
 
 WRITE16_HANDLER( glfgreat_122000_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		/* bit 0,1 = coin counter */
 		coin_counter_w(0,data & 0x01);
@@ -454,7 +457,7 @@ WRITE16_HANDLER( glfgreat_122000_w )
 
 		/* other bits unknown */
 	}
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		/* bit 8 = 53596 char/rom selection for ROM test */
 		glfgreat_roz_rom_mode = data & 0x100;
@@ -464,14 +467,14 @@ WRITE16_HANDLER( glfgreat_122000_w )
 
 WRITE16_HANDLER( ssriders_eeprom_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		/* bit 0 is data */
 		/* bit 1 is cs (active low) */
 		/* bit 2 is clock (active high) */
-		EEPROM_write_bit(data & 0x01);
-		EEPROM_set_cs_line((data & 0x02) ? CLEAR_LINE : ASSERT_LINE);
-		EEPROM_set_clock_line((data & 0x04) ? ASSERT_LINE : CLEAR_LINE);
+		eeprom_write_bit(data & 0x01);
+		eeprom_set_cs_line((data & 0x02) ? CLEAR_LINE : ASSERT_LINE);
+		eeprom_set_clock_line((data & 0x04) ? ASSERT_LINE : CLEAR_LINE);
 
 		/* bits 3-4 control palette dimming */
 		/* 4 = DIMPOL = when set, negate SHAD */
@@ -485,7 +488,7 @@ WRITE16_HANDLER( ssriders_eeprom_w )
 
 WRITE16_HANDLER( ssriders_1c0300_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		/* bit 0,1 = coin counter */
 		coin_counter_w(0,data & 0x01);
@@ -501,7 +504,7 @@ WRITE16_HANDLER( ssriders_1c0300_w )
 
 WRITE16_HANDLER( prmrsocr_122000_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		/* bit 0,1 = coin counter */
 		coin_counter_w(0,data & 0x01);
@@ -524,14 +527,17 @@ WRITE16_HANDLER( prmrsocr_122000_w )
 READ16_HANDLER( prmrsocr_rom_r )
 {
 	if(glfgreat_roz_char_bank)
-		return memory_region(REGION_GFX3)[offset];
+		return memory_region(space->machine, "gfx3")[offset];
 	else
-		return 256 * memory_region(REGION_USER1)[offset] + memory_region(REGION_USER1)[offset + 0x020000];
+	{
+		UINT8 *usr = memory_region(space->machine, "user1");
+		return 256 * usr[offset] + usr[offset + 0x020000];
+	}
 }
 
 WRITE16_HANDLER( tmnt_priority_w )
 {
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		/* bit 2/3 = priority; other bits unused */
 		/* bit2 = PRI bit3 = PRI2
@@ -623,7 +629,7 @@ VIDEO_UPDATE( punkshot )
 
 	sortlayers(sorted_layer,layerpri);
 
-	fillbitmap(priority_bitmap,0,cliprect);
+	bitmap_fill(priority_bitmap,cliprect,0);
 	tilemap_draw(bitmap,cliprect,K052109_tilemap[sorted_layer[0]],TILEMAP_DRAW_OPAQUE,1);
 	tilemap_draw(bitmap,cliprect,K052109_tilemap[sorted_layer[1]],0,2);
 	tilemap_draw(bitmap,cliprect,K052109_tilemap[sorted_layer[2]],0,4);
@@ -652,8 +658,8 @@ VIDEO_UPDATE( lgtnfght )
 
 	sortlayers(sorted_layer,layerpri);
 
-	fillbitmap(priority_bitmap,0,cliprect);
-	fillbitmap(bitmap,machine->pens[16 * bg_colorbase],cliprect);
+	bitmap_fill(priority_bitmap,cliprect,0);
+	bitmap_fill(bitmap,cliprect,16 * bg_colorbase);
 	tilemap_draw(bitmap,cliprect,K052109_tilemap[sorted_layer[0]],0,1);
 	tilemap_draw(bitmap,cliprect,K052109_tilemap[sorted_layer[1]],0,2);
 	tilemap_draw(bitmap,cliprect,K052109_tilemap[sorted_layer[2]],0,4);
@@ -697,8 +703,8 @@ VIDEO_UPDATE( glfgreat )
 
 	/* not sure about the 053936 priority, but it seems to work */
 
-	fillbitmap(priority_bitmap,0,cliprect);
-	fillbitmap(bitmap,machine->pens[16 * bg_colorbase],cliprect);
+	bitmap_fill(priority_bitmap,cliprect,0);
+	bitmap_fill(bitmap,cliprect,16 * bg_colorbase);
 	tilemap_draw(bitmap,cliprect,K052109_tilemap[sorted_layer[0]],0,1);
 	if (layerpri[0] >= 0x30 && layerpri[1] < 0x30)
 	{
@@ -751,21 +757,21 @@ VIDEO_UPDATE( tmnt2 )
 
 		// dim all colors before it
 		for (i=0; i<cb; i++)
-			palette_set_brightness(machine,i,brt);
+			palette_set_pen_contrast(screen->machine,i,brt);
 
 		// reset all colors in range
 		for (i=cb; i<ce; i++)
-			palette_set_brightness(machine,i,1.0);
+			palette_set_pen_contrast(screen->machine,i,1.0);
 
 		// dim all colors after it
 		for (i=ce; i<2048; i++)
-			palette_set_brightness(machine,i,brt);
+			palette_set_pen_contrast(screen->machine,i,brt);
 
 		// toggle shadow/highlight
 		if (~dim_c & 0x10)
-			palette_set_shadow_mode(machine, 1);
+			palette_set_shadow_mode(screen->machine, 1);
 		else
-			palette_set_shadow_mode(machine, 0);
+			palette_set_shadow_mode(screen->machine, 0);
 	}
 
 	VIDEO_UPDATE_CALL(lgtnfght);
@@ -792,8 +798,8 @@ VIDEO_UPDATE( thndrx2 )
 
 	sortlayers(sorted_layer,layerpri);
 
-	fillbitmap(priority_bitmap,0,cliprect);
-	fillbitmap(bitmap,machine->pens[16 * bg_colorbase],cliprect);
+	bitmap_fill(priority_bitmap,cliprect,0);
+	bitmap_fill(bitmap,cliprect,16 * bg_colorbase);
 	tilemap_draw(bitmap,cliprect,K052109_tilemap[sorted_layer[0]],0,1);
 	tilemap_draw(bitmap,cliprect,K052109_tilemap[sorted_layer[1]],0,2);
 	tilemap_draw(bitmap,cliprect,K052109_tilemap[sorted_layer[2]],0,4);
