@@ -119,7 +119,6 @@ Abnormalities:
 
 
 #include "driver.h"
-#include "deprecat.h"
 #include "toaplan1.h"
 #include "cpu/m68000/m68000.h"
 
@@ -254,12 +253,12 @@ static TILE_GET_INFO( get_pf4_tile_info )
 
 ***************************************************************************/
 
-static void toaplan1_create_tilemaps(void)
+static void toaplan1_create_tilemaps(running_machine *machine)
 {
-	pf1_tilemap = tilemap_create(get_pf1_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,64,64);
-	pf2_tilemap = tilemap_create(get_pf2_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,64,64);
-	pf3_tilemap = tilemap_create(get_pf3_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,64,64);
-	pf4_tilemap = tilemap_create(get_pf4_tile_info,tilemap_scan_rows,TILEMAP_TYPE_PEN,8,8,64,64);
+	pf1_tilemap = tilemap_create(machine, get_pf1_tile_info,tilemap_scan_rows,8,8,64,64);
+	pf2_tilemap = tilemap_create(machine, get_pf2_tile_info,tilemap_scan_rows,8,8,64,64);
+	pf3_tilemap = tilemap_create(machine, get_pf3_tile_info,tilemap_scan_rows,8,8,64,64);
+	pf4_tilemap = tilemap_create(machine, get_pf4_tile_info,tilemap_scan_rows,8,8,64,64);
 
 	tilemap_set_transparent_pen(pf1_tilemap,0);
 	tilemap_set_transparent_pen(pf2_tilemap,0);
@@ -317,20 +316,22 @@ static void toaplan1_set_scrolls(void)
 	tilemap_set_scrolly(pf4_tilemap,0,(pf4_scrolly >> 7) - (tiles_offsety - scrolly_offs));
 }
 
-static void rallybik_flipscreen(void)
+static STATE_POSTLOAD( rallybik_flipscreen )
 {
-	rallybik_bcu_flipscreen_w(0, bcu_flipscreen, 0);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	rallybik_bcu_flipscreen_w(space, 0, bcu_flipscreen, 0xffff);
 }
 
-static void toaplan1_flipscreen(void)
+static STATE_POSTLOAD( toaplan1_flipscreen )
 {
-	toaplan1_bcu_flipscreen_w(0, bcu_flipscreen, 0);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	toaplan1_bcu_flipscreen_w(space, 0, bcu_flipscreen, 0xffff);
 }
 
 
 VIDEO_START( rallybik )
 {
-	toaplan1_create_tilemaps();
+	toaplan1_create_tilemaps(machine);
 	toaplan1_paletteram_alloc();
 	toaplan1_vram_alloc();
 
@@ -343,37 +344,37 @@ VIDEO_START( rallybik )
 	bcu_flipscreen = -1;
 	toaplan1_reset = 0;
 
-	state_save_register_global_pointer(paletteram16, (toaplan1_colorram1_size + toaplan1_colorram2_size)/2);
-	state_save_register_global_pointer(pf1_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
-	state_save_register_global_pointer(pf2_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
-	state_save_register_global_pointer(pf3_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
-	state_save_register_global_pointer(pf4_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
+	state_save_register_global_pointer(machine, paletteram16, (toaplan1_colorram1_size + toaplan1_colorram2_size)/2);
+	state_save_register_global_pointer(machine, pf1_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
+	state_save_register_global_pointer(machine, pf2_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
+	state_save_register_global_pointer(machine, pf3_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
+	state_save_register_global_pointer(machine, pf4_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
 
-	state_save_register_global(scrollx_offs1);
-	state_save_register_global(scrollx_offs2);
-	state_save_register_global(scrollx_offs3);
-	state_save_register_global(scrollx_offs4);
-	state_save_register_global(scrolly_offs);
-	state_save_register_global(bcu_flipscreen);
-	state_save_register_global(pf1_scrollx);
-	state_save_register_global(pf1_scrolly);
-	state_save_register_global(pf2_scrollx);
-	state_save_register_global(pf2_scrolly);
-	state_save_register_global(pf3_scrollx);
-	state_save_register_global(pf3_scrolly);
-	state_save_register_global(pf4_scrollx);
-	state_save_register_global(pf4_scrolly);
-	state_save_register_global(tiles_offsetx);
-	state_save_register_global(tiles_offsety);
-	state_save_register_global(pf_voffs);
-	state_save_register_global(spriteram_offs);
+	state_save_register_global(machine, scrollx_offs1);
+	state_save_register_global(machine, scrollx_offs2);
+	state_save_register_global(machine, scrollx_offs3);
+	state_save_register_global(machine, scrollx_offs4);
+	state_save_register_global(machine, scrolly_offs);
+	state_save_register_global(machine, bcu_flipscreen);
+	state_save_register_global(machine, pf1_scrollx);
+	state_save_register_global(machine, pf1_scrolly);
+	state_save_register_global(machine, pf2_scrollx);
+	state_save_register_global(machine, pf2_scrolly);
+	state_save_register_global(machine, pf3_scrollx);
+	state_save_register_global(machine, pf3_scrolly);
+	state_save_register_global(machine, pf4_scrollx);
+	state_save_register_global(machine, pf4_scrolly);
+	state_save_register_global(machine, tiles_offsetx);
+	state_save_register_global(machine, tiles_offsety);
+	state_save_register_global(machine, pf_voffs);
+	state_save_register_global(machine, spriteram_offs);
 
-	state_save_register_func_postload(rallybik_flipscreen);
+	state_save_register_postload(machine, rallybik_flipscreen, NULL);
 }
 
 VIDEO_START( toaplan1 )
 {
-	toaplan1_create_tilemaps();
+	toaplan1_create_tilemaps(machine);
 	toaplan1_paletteram_alloc();
 	toaplan1_vram_alloc();
 	toaplan1_spritevram_alloc();
@@ -388,37 +389,37 @@ VIDEO_START( toaplan1 )
 	fcu_flipscreen = 0;
 	toaplan1_reset = 1;
 
-	state_save_register_global_pointer(paletteram16, (toaplan1_colorram1_size + toaplan1_colorram2_size)/2);
-	state_save_register_global_pointer(pf1_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
-	state_save_register_global_pointer(pf2_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
-	state_save_register_global_pointer(pf3_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
-	state_save_register_global_pointer(pf4_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
-	state_save_register_global_pointer(spriteram16, TOAPLAN1_SPRITERAM_SIZE/2);
-	state_save_register_global_pointer(buffered_spriteram16, TOAPLAN1_SPRITERAM_SIZE/2);
-	state_save_register_global_pointer(toaplan1_spritesizeram16, TOAPLAN1_SPRITESIZERAM_SIZE/2);
-	state_save_register_global_pointer(toaplan1_buffered_spritesizeram16, TOAPLAN1_SPRITESIZERAM_SIZE/2);
+	state_save_register_global_pointer(machine, paletteram16, (toaplan1_colorram1_size + toaplan1_colorram2_size)/2);
+	state_save_register_global_pointer(machine, pf1_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
+	state_save_register_global_pointer(machine, pf2_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
+	state_save_register_global_pointer(machine, pf3_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
+	state_save_register_global_pointer(machine, pf4_tilevram16, TOAPLAN1_TILEVRAM_SIZE/2);
+	state_save_register_global_pointer(machine, spriteram16, TOAPLAN1_SPRITERAM_SIZE/2);
+	state_save_register_global_pointer(machine, buffered_spriteram16, TOAPLAN1_SPRITERAM_SIZE/2);
+	state_save_register_global_pointer(machine, toaplan1_spritesizeram16, TOAPLAN1_SPRITESIZERAM_SIZE/2);
+	state_save_register_global_pointer(machine, toaplan1_buffered_spritesizeram16, TOAPLAN1_SPRITESIZERAM_SIZE/2);
 
-	state_save_register_global(scrollx_offs1);
-	state_save_register_global(scrollx_offs2);
-	state_save_register_global(scrollx_offs3);
-	state_save_register_global(scrollx_offs4);
-	state_save_register_global(scrolly_offs);
-	state_save_register_global(bcu_flipscreen);
-	state_save_register_global(fcu_flipscreen);
-	state_save_register_global(pf1_scrollx);
-	state_save_register_global(pf1_scrolly);
-	state_save_register_global(pf2_scrolly);
-	state_save_register_global(pf2_scrollx);
-	state_save_register_global(pf3_scrollx);
-	state_save_register_global(pf3_scrolly);
-	state_save_register_global(pf4_scrollx);
-	state_save_register_global(pf4_scrolly);
-	state_save_register_global(tiles_offsetx);
-	state_save_register_global(tiles_offsety);
-	state_save_register_global(pf_voffs);
-	state_save_register_global(spriteram_offs);
+	state_save_register_global(machine, scrollx_offs1);
+	state_save_register_global(machine, scrollx_offs2);
+	state_save_register_global(machine, scrollx_offs3);
+	state_save_register_global(machine, scrollx_offs4);
+	state_save_register_global(machine, scrolly_offs);
+	state_save_register_global(machine, bcu_flipscreen);
+	state_save_register_global(machine, fcu_flipscreen);
+	state_save_register_global(machine, pf1_scrollx);
+	state_save_register_global(machine, pf1_scrolly);
+	state_save_register_global(machine, pf2_scrolly);
+	state_save_register_global(machine, pf2_scrollx);
+	state_save_register_global(machine, pf3_scrollx);
+	state_save_register_global(machine, pf3_scrolly);
+	state_save_register_global(machine, pf4_scrollx);
+	state_save_register_global(machine, pf4_scrolly);
+	state_save_register_global(machine, tiles_offsetx);
+	state_save_register_global(machine, tiles_offsety);
+	state_save_register_global(machine, pf_voffs);
+	state_save_register_global(machine, spriteram_offs);
 
-	state_save_register_func_postload(toaplan1_flipscreen);
+	state_save_register_postload(machine, toaplan1_flipscreen, NULL);
 }
 
 
@@ -430,7 +431,7 @@ VIDEO_START( toaplan1 )
 
 READ16_HANDLER( toaplan1_frame_done_r )
 {
-	return video_screen_get_vblank(0);
+	return video_screen_get_vblank(space->machine->primary_screen);
 }
 
 WRITE16_HANDLER( toaplan1_tile_offsets_w )
@@ -451,7 +452,7 @@ WRITE16_HANDLER( toaplan1_tile_offsets_w )
 
 WRITE16_HANDLER( rallybik_bcu_flipscreen_w )
 {
-	if (ACCESSING_LSB && (data != bcu_flipscreen))
+	if (ACCESSING_BITS_0_7 && (data != bcu_flipscreen))
 	{
 		logerror("Setting BCU controller flipscreen port to %04x\n",data);
 		bcu_flipscreen = data & 0x01;		/* 0x0001 = flip, 0x0000 = no flip */
@@ -478,7 +479,7 @@ WRITE16_HANDLER( rallybik_bcu_flipscreen_w )
 
 WRITE16_HANDLER( toaplan1_bcu_flipscreen_w )
 {
-	if (ACCESSING_LSB && (data != bcu_flipscreen))
+	if (ACCESSING_BITS_0_7 && (data != bcu_flipscreen))
 	{
 		logerror("Setting BCU controller flipscreen port to %04x\n",data);
 		bcu_flipscreen = data & 0x01;		/* 0x0001 = flip, 0x0000 = no flip */
@@ -505,7 +506,7 @@ WRITE16_HANDLER( toaplan1_bcu_flipscreen_w )
 
 WRITE16_HANDLER( toaplan1_fcu_flipscreen_w )
 {
-	if (ACCESSING_MSB)
+	if (ACCESSING_BITS_8_15)
 	{
 		logerror("Setting FCU controller flipscreen port to %04x\n",data);
 		fcu_flipscreen = data & 0x8000;	/* 0x8000 = flip, 0x0000 = no flip */
@@ -532,7 +533,7 @@ READ16_HANDLER( toaplan1_colorram1_r )
 WRITE16_HANDLER( toaplan1_colorram1_w )
 {
 	COMBINE_DATA(&toaplan1_colorram1[offset]);
-	paletteram16_xBBBBBGGGGGRRRRR_word_w(offset, data, mem_mask);
+	paletteram16_xBBBBBGGGGGRRRRR_word_w(space,offset, data, mem_mask);
 }
 
 /* sprite palette */
@@ -544,7 +545,7 @@ READ16_HANDLER( toaplan1_colorram2_r )
 WRITE16_HANDLER( toaplan1_colorram2_w )
 {
 	COMBINE_DATA(&toaplan1_colorram2[offset]);
-	paletteram16_xBBBBBGGGGGRRRRR_word_w(offset+(toaplan1_colorram1_size/2), data, mem_mask);
+	paletteram16_xBBBBBGGGGGRRRRR_word_w(space,offset+(toaplan1_colorram1_size/2), data, mem_mask);
 }
 
 READ16_HANDLER( toaplan1_spriteram16_r )
@@ -600,7 +601,7 @@ WRITE16_HANDLER( toaplan1_bcu_control_w )
 	if (toaplan1_unk_reset_port && toaplan1_reset)
 	{
 		toaplan1_reset = 0;
-		toaplan1_reset_sound(0,0,0);
+		toaplan1_reset_sound(space,0,0,0);
 	}
 }
 
@@ -650,7 +651,7 @@ READ16_HANDLER( toaplan1_tileram16_r )
 
 READ16_HANDLER( rallybik_tileram16_r )
 {
-	UINT16 data = toaplan1_tileram16_r(offset, mem_mask);
+	UINT16 data = toaplan1_tileram16_r(space, offset, mem_mask);
 
 	if (offset == 0)	/* some bit lines may be stuck to others */
 	{
@@ -942,11 +943,11 @@ static void toaplan1_log_vram(void)
 ***************************************************************************/
 
 // custom function to draw a single sprite. needed to keep correct sprites - sprites and sprites - tilemaps priorities
-static void toaplan1_draw_sprite_custom(mame_bitmap *dest_bmp,const gfx_element *gfx,
+static void toaplan1_draw_sprite_custom(bitmap_t *dest_bmp,const gfx_element *gfx,
 		UINT32 code,UINT32 color,int flipx,int flipy,int sx,int sy,
 		const rectangle *clip,int priority)
 {
-	const pen_t *pal = &Machine->remapped_colortable[gfx->color_base + gfx->color_granularity * (color % gfx->total_colors)];
+	int pal_base = gfx->color_base + gfx->color_granularity * (color % gfx->total_colors);
 	UINT8 *source_base = gfx->gfxdata + (code % gfx->total_elements) * gfx->char_modulo;
 
 	int sprite_screen_height = ((1<<16)*gfx->height+0x8000)>>16;
@@ -1028,7 +1029,7 @@ static void toaplan1_draw_sprite_custom(mame_bitmap *dest_bmp,const gfx_element
 					if( c != 0 )
 					{
 						if (pri[x] < priority)
-							dest[x] = pal[c];
+							dest[x] = pal_base+c;
 						pri[x] = 0xff; // mark it "already drawn"
 					}
 					x_index += dx;
@@ -1041,7 +1042,7 @@ static void toaplan1_draw_sprite_custom(mame_bitmap *dest_bmp,const gfx_element
 }
 
 
-static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect )
+static void draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect )
 {
 	UINT16 *source = (UINT16 *)(buffered_spriteram16);
 	UINT16 *size   = (UINT16 *)(toaplan1_buffered_spritesizeram16);
@@ -1107,7 +1108,7 @@ static void draw_sprites(running_machine *machine, mame_bitmap *bitmap, const re
 }
 
 
-static void rallybik_draw_sprites(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int priority )
+static void rallybik_draw_sprites(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int priority )
 {
 	int offs;
 
@@ -1141,7 +1142,7 @@ static void rallybik_draw_sprites(running_machine *machine, mame_bitmap *bitmap,
 
 
 /***************************************************************************
-    Draw the game screen in the given mame_bitmap.
+    Draw the game screen in the given bitmap_t.
 ***************************************************************************/
 
 VIDEO_UPDATE( rallybik )
@@ -1152,7 +1153,7 @@ VIDEO_UPDATE( rallybik )
 	toaplan1_log_vram();
 #endif
 
-	fillbitmap(bitmap,machine->pens[0],cliprect);
+	bitmap_fill(bitmap,cliprect,0);
 
 	tilemap_draw(bitmap,cliprect,pf1_tilemap,TILEMAP_DRAW_OPAQUE | 0,0);
 	tilemap_draw(bitmap,cliprect,pf1_tilemap,TILEMAP_DRAW_OPAQUE | 1,0);
@@ -1163,7 +1164,7 @@ VIDEO_UPDATE( rallybik )
 		tilemap_draw(bitmap,cliprect,pf3_tilemap,priority,0);
 		tilemap_draw(bitmap,cliprect,pf2_tilemap,priority,0);
 		tilemap_draw(bitmap,cliprect,pf1_tilemap,priority,0);
-		rallybik_draw_sprites(machine, bitmap,cliprect,priority << 8);
+		rallybik_draw_sprites(screen->machine, bitmap,cliprect,priority << 8);
 	}
 	return 0;
 }
@@ -1176,8 +1177,8 @@ VIDEO_UPDATE( toaplan1 )
 	toaplan1_log_vram();
 #endif
 
-	fillbitmap(priority_bitmap,0,cliprect);
-	fillbitmap(bitmap,machine->pens[0x120],cliprect);
+	bitmap_fill(priority_bitmap,cliprect,0);
+	bitmap_fill(bitmap,cliprect,0x120);
 
 	tilemap_draw(bitmap,cliprect,pf4_tilemap,TILEMAP_DRAW_OPAQUE,0);
 	for (priority = 8; priority < 16; priority++)
@@ -1191,7 +1192,7 @@ VIDEO_UPDATE( toaplan1 )
 		tilemap_draw_primask(bitmap,cliprect,pf1_tilemap,priority,priority,0);
 	}
 
-	draw_sprites(machine, bitmap,cliprect);
+	draw_sprites(screen->machine, bitmap,cliprect);
 	return 0;
 }
 
@@ -1203,8 +1204,8 @@ VIDEO_UPDATE( demonwld )
 	toaplan1_log_vram();
 #endif
 
-	fillbitmap(priority_bitmap,0,cliprect);
-	fillbitmap(bitmap,machine->pens[0x120],cliprect);
+	bitmap_fill(priority_bitmap,cliprect,0);
+	bitmap_fill(bitmap,cliprect,0x120);
 
 	tilemap_draw(bitmap,cliprect,pf1_tilemap,TILEMAP_DRAW_OPAQUE | 0,0);
 	tilemap_draw(bitmap,cliprect,pf1_tilemap,TILEMAP_DRAW_OPAQUE | 1,0);
@@ -1217,7 +1218,7 @@ VIDEO_UPDATE( demonwld )
 		tilemap_draw_primask(bitmap,cliprect,pf1_tilemap,priority,priority,0);
 	}
 
-	draw_sprites(machine, bitmap,cliprect);
+	draw_sprites(screen->machine, bitmap,cliprect);
 	return 0;
 }
 
@@ -1230,18 +1231,21 @@ VIDEO_UPDATE( demonwld )
 
 VIDEO_EOF( rallybik )
 {
-	buffer_spriteram16_w(0, 0, 0);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	buffer_spriteram16_w(space, 0, 0, 0xffff);
 }
 
 VIDEO_EOF( toaplan1 )
 {
-	buffer_spriteram16_w(0, 0, 0);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	buffer_spriteram16_w(space, 0, 0, 0xffff);
 	memcpy(toaplan1_buffered_spritesizeram16, toaplan1_spritesizeram16, TOAPLAN1_SPRITESIZERAM_SIZE);
 }
 
 VIDEO_EOF( samesame )
 {
-	buffer_spriteram16_w(0, 0, 0);
+	const address_space *space = cpu_get_address_space(machine->cpu[0], ADDRESS_SPACE_PROGRAM);
+	buffer_spriteram16_w(space, 0, 0, 0xffff);
 	memcpy(toaplan1_buffered_spritesizeram16, toaplan1_spritesizeram16, TOAPLAN1_SPRITESIZERAM_SIZE);
-	cpunum_set_input_line(machine, 0, MC68000_IRQ_2, HOLD_LINE);	/* Frame done */
+	cpu_set_input_line(machine->cpu[0], M68K_IRQ_2, HOLD_LINE);	/* Frame done */
 }
