@@ -5,7 +5,6 @@
 *************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "turbo.h"
 #include "video/resnet.h"
 
@@ -179,7 +178,7 @@ VIDEO_START( turbo )
 	turbo_state *state = machine->driver_data;
 
 	/* initialize the foreground tilemap */
-	state->fg_tilemap = tilemap_create(get_fg_tile_info, tilemap_scan_rows, TILEMAP_TYPE_PEN, 8,8, 32,32);
+	state->fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_rows,  8,8, 32,32);
 }
 
 
@@ -188,11 +187,11 @@ VIDEO_START( buckrog )
 	turbo_state *state = machine->driver_data;
 
 	/* initialize the foreground tilemap */
-	state->fg_tilemap = tilemap_create(get_fg_tile_info, tilemap_scan_rows, TILEMAP_TYPE_PEN, 8,8, 32,32);
+	state->fg_tilemap = tilemap_create(machine, get_fg_tile_info, tilemap_scan_rows,  8,8, 32,32);
 
 	/* allocate the bitmap RAM */
 	state->buckrog_bitmap_ram = auto_malloc(0xe000);
-	state_save_register_global_pointer(state->buckrog_bitmap_ram, 0xe000);
+	state_save_register_global_pointer(machine, state->buckrog_bitmap_ram, 0xe000);
 }
 
 
@@ -205,11 +204,11 @@ VIDEO_START( buckrog )
 
 WRITE8_HANDLER( turbo_videoram_w )
 {
-	turbo_state *state = Machine->driver_data;
+	turbo_state *state = space->machine->driver_data;
 	state->videoram[offset] = data;
 	if (offset < 0x400)
 	{
-		video_screen_update_partial(0, video_screen_get_vpos(0));
+		video_screen_update_partial(space->machine->primary_screen, video_screen_get_vpos(space->machine->primary_screen));
 		tilemap_mark_tile_dirty(state->fg_tilemap, offset);
 	}
 }
@@ -217,7 +216,7 @@ WRITE8_HANDLER( turbo_videoram_w )
 
 WRITE8_HANDLER( buckrog_bitmap_w )
 {
-	turbo_state *state = Machine->driver_data;
+	turbo_state *state = space->machine->driver_data;
 	state->buckrog_bitmap_ram[offset] = data & 1;
 }
 
@@ -274,9 +273,9 @@ INLINE UINT32 sprite_xscale(UINT8 dacinput, double vr1, double vr2, double cext)
  *
  *************************************/
 
-static void turbo_prepare_sprites(turbo_state *state, UINT8 y, sprite_info *info)
+static void turbo_prepare_sprites(running_machine *machine, turbo_state *state, UINT8 y, sprite_info *info)
 {
-	const UINT8 *pr1119 = memory_region(REGION_PROMS) + 0x200;
+	const UINT8 *pr1119 = memory_region(machine, "proms") + 0x200;
 	int sprnum;
 
 	/* initialize the line enable signals to 0 */
@@ -334,15 +333,15 @@ static void turbo_prepare_sprites(turbo_state *state, UINT8 y, sprite_info *info
                     VR1 = 310 Ohm
                     VR2 = 910 Ohm
             */
-			info->step[level] = sprite_xscale(xscale, 1.0e3 * readinputportbytag("VR1") / 100.0, 1.0e3 * readinputportbytag("VR2") / 100.0, 100e-12);
+			info->step[level] = sprite_xscale(xscale, 1.0e3 * input_port_read(machine, "VR1") / 100.0, 1.0e3 * input_port_read(machine, "VR2") / 100.0, 100e-12);
 		}
 	}
 }
 
 
-static UINT32 turbo_get_sprite_bits(UINT8 road, sprite_info *sprinfo)
+static UINT32 turbo_get_sprite_bits(running_machine *machine, UINT8 road, sprite_info *sprinfo)
 {
-	const UINT8 *sprite_gfxdata = memory_region(REGION_GFX1);
+	const UINT8 *sprite_gfxdata = memory_region(machine, "gfx1");
 	UINT8 sprlive = sprinfo->lst;
 	UINT32 sprdata = 0;
 	int level;
@@ -397,10 +396,10 @@ static UINT32 turbo_get_sprite_bits(UINT8 road, sprite_info *sprinfo)
 
 VIDEO_UPDATE( turbo )
 {
-	turbo_state *state = machine->driver_data;
-	mame_bitmap *fgpixmap = tilemap_get_pixmap(state->fg_tilemap);
-	const UINT8 *road_gfxdata = memory_region(REGION_GFX3);
-	const UINT8 *prom_base = memory_region(REGION_PROMS);
+	turbo_state *state = screen->machine->driver_data;
+	bitmap_t *fgpixmap = tilemap_get_pixmap(state->fg_tilemap);
+	const UINT8 *road_gfxdata = memory_region(screen->machine, "gfx3");
+	const UINT8 *prom_base = memory_region(screen->machine, "proms");
 	const UINT8 *pr1114 = prom_base + 0x000;
 	const UINT8 *pr1115 = prom_base + 0x020;
 	const UINT8 *pr1116 = prom_base + 0x040;
@@ -428,7 +427,7 @@ VIDEO_UPDATE( turbo )
 
 		/* compute the sprite information; we use y-1 since this info was computed during HBLANK */
 		/* on the previous scanline */
-		turbo_prepare_sprites(state, y, &sprinfo);
+		turbo_prepare_sprites(screen->machine, state, y, &sprinfo);
 
 		/* loop over columns */
 		for (x = 0; x <= cliprect->max_x; x += TURBO_X_SCALE)
@@ -524,7 +523,7 @@ VIDEO_UPDATE( turbo )
 				/*    CDG0-7 = D8 -D15 */
 				/*    CDR0-7 = D16-D23 */
 				/*    PLB0-7 = D24-D31 */
-				sprbits = turbo_get_sprite_bits(road, &sprinfo);
+				sprbits = turbo_get_sprite_bits(screen->machine, road, &sprinfo);
 
 				/* perform collision detection here via lookup in IC20/PR1116 (p. 144) */
 				state->turbo_collision |= pr1116[((sprbits >> 24) & 7) | (slipar_acciar >> 1)];
@@ -633,9 +632,9 @@ VIDEO_UPDATE( turbo )
 
 */
 
-static void subroc3d_prepare_sprites(turbo_state *state, UINT8 y, sprite_info *info)
+static void subroc3d_prepare_sprites(running_machine *machine, turbo_state *state, UINT8 y, sprite_info *info)
 {
-	const UINT8 *pr1449 = memory_region(REGION_PROMS) + 0x300;
+	const UINT8 *pr1449 = memory_region(machine, "proms") + 0x300;
 	int sprnum;
 
 	/* initialize the line enable signals to 0 */
@@ -693,7 +692,7 @@ static void subroc3d_prepare_sprites(turbo_state *state, UINT8 y, sprite_info *i
 }
 
 
-static UINT32 subroc3d_get_sprite_bits(sprite_info *sprinfo, UINT8 *plb)
+static UINT32 subroc3d_get_sprite_bits(running_machine *machine, sprite_info *sprinfo, UINT8 *plb)
 {
 	/* see logic on each sprite:
         END = (CDA == 1 && (CDA ^ CDB) == 0 && (CDC ^ CDD) == 0)
@@ -701,7 +700,7 @@ static UINT32 subroc3d_get_sprite_bits(sprite_info *sprinfo, UINT8 *plb)
        end is in bit 1, plb in bit 0
     */
 	static const UINT8 plb_end[16] = { 0,1,1,2, 1,1,1,1, 1,1,1,1, 0,1,1,2 };
-	const UINT8 *sprite_gfxdata = memory_region(REGION_GFX1);
+	const UINT8 *sprite_gfxdata = memory_region(machine, "gfx1");
 	UINT32 sprdata = 0;
 	int level;
 
@@ -752,9 +751,9 @@ static UINT32 subroc3d_get_sprite_bits(sprite_info *sprinfo, UINT8 *plb)
 
 VIDEO_UPDATE( subroc3d )
 {
-	turbo_state *state = machine->driver_data;
-	mame_bitmap *fgpixmap = tilemap_get_pixmap(state->fg_tilemap);
-	const UINT8 *prom_base = memory_region(REGION_PROMS);
+	turbo_state *state = screen->machine->driver_data;
+	bitmap_t *fgpixmap = tilemap_get_pixmap(state->fg_tilemap);
+	const UINT8 *prom_base = memory_region(screen->machine, "proms");
 	const UINT8 *pr1419 = prom_base + 0x000;
 	const UINT8 *pr1620 = prom_base + 0x200;
 	const UINT8 *pr1450 = prom_base + 0x500;
@@ -770,7 +769,7 @@ VIDEO_UPDATE( subroc3d )
 
 		/* compute the sprite information; we use y-1 since this info was computed during HBLANK */
 		/* on the previous scanline */
-		subroc3d_prepare_sprites(state, y, &sprinfo);
+		subroc3d_prepare_sprites(screen->machine, state, y, &sprinfo);
 
 		/* loop over columns */
 		for (x = 0; x <= cliprect->max_x; x += TURBO_X_SCALE)
@@ -810,7 +809,7 @@ VIDEO_UPDATE( subroc3d )
 				/*    CDB0-7 = D8 -D15 */
 				/*    CDC0-7 = D16-D23 */
 				/*    CDD0-7 = D24-D31 */
-				sprbits = subroc3d_get_sprite_bits(&sprinfo, &plb);
+				sprbits = subroc3d_get_sprite_bits(screen->machine, &sprinfo, &plb);
 
 				/* MUX0-3 is selected by PLY0-3 and the sprite enable bits, and is the output */
 				/* of IC21/PR1450 (p. 141), unless MPLB = 0, in which case the values are grounded (p. 141) */
@@ -852,9 +851,9 @@ VIDEO_UPDATE( subroc3d )
  *
  *************************************/
 
-static void buckrog_prepare_sprites(turbo_state *state, UINT8 y, sprite_info *info)
+static void buckrog_prepare_sprites(running_machine *machine, turbo_state *state, UINT8 y, sprite_info *info)
 {
-	const UINT8 *pr5196 = memory_region(REGION_PROMS) + 0x100;
+	const UINT8 *pr5196 = memory_region(machine, "proms") + 0x100;
 	int sprnum;
 
 	/* initialize the line enable signals to 0 */
@@ -912,7 +911,7 @@ static void buckrog_prepare_sprites(turbo_state *state, UINT8 y, sprite_info *in
 }
 
 
-static UINT32 buckrog_get_sprite_bits(sprite_info *sprinfo, UINT8 *plb)
+static UINT32 buckrog_get_sprite_bits(running_machine *machine, sprite_info *sprinfo, UINT8 *plb)
 {
 	/* see logic on each sprite:
         END = (CDA == 1 && (CDA ^ CDB) == 0 && (CDC ^ CDD) == 0)
@@ -920,7 +919,7 @@ static UINT32 buckrog_get_sprite_bits(sprite_info *sprinfo, UINT8 *plb)
        end is in bit 1, plb in bit 0
     */
 	static const UINT8 plb_end[16] = { 0,1,1,1, 1,1,1,1, 1,1,1,1, 1,1,1,2 };
-	const UINT8 *sprite_gfxdata = memory_region(REGION_GFX1);
+	const UINT8 *sprite_gfxdata = memory_region(machine, "gfx1");
 	UINT32 sprdata = 0;
 	int level;
 
@@ -971,10 +970,10 @@ static UINT32 buckrog_get_sprite_bits(sprite_info *sprinfo, UINT8 *plb)
 
 VIDEO_UPDATE( buckrog )
 {
-	turbo_state *state = machine->driver_data;
-	mame_bitmap *fgpixmap = tilemap_get_pixmap(state->fg_tilemap);
-	const UINT8 *bgcolor = memory_region(REGION_GFX3);
-	const UINT8 *prom_base = memory_region(REGION_PROMS);
+	turbo_state *state = screen->machine->driver_data;
+	bitmap_t *fgpixmap = tilemap_get_pixmap(state->fg_tilemap);
+	const UINT8 *bgcolor = memory_region(screen->machine, "gfx3");
+	const UINT8 *prom_base = memory_region(screen->machine, "proms");
 	const UINT8 *pr5194 = prom_base + 0x000;
 	const UINT8 *pr5198 = prom_base + 0x500;
 	const UINT8 *pr5199 = prom_base + 0x700;
@@ -989,7 +988,7 @@ VIDEO_UPDATE( buckrog )
 
 		/* compute the sprite information; we use y-1 since this info was computed during HBLANK */
 		/* on the previous scanline */
-		buckrog_prepare_sprites(state, y, &sprinfo);
+		buckrog_prepare_sprites(screen->machine, state, y, &sprinfo);
 
 		/* loop over columns */
 		for (x = 0; x <= cliprect->max_x; x += TURBO_X_SCALE)
@@ -1026,7 +1025,7 @@ VIDEO_UPDATE( buckrog )
 				/*    CDB0-7 = D8 -D15 */
 				/*    CDC0-7 = D16-D23 */
 				/*    CDD0-7 = D24-D31 */
-				sprbits = buckrog_get_sprite_bits(&sprinfo, &plb);
+				sprbits = buckrog_get_sprite_bits(screen->machine, &sprinfo, &plb);
 
 				/* the PLB bits go into an LS148 8-to-1 decoder and become MUX0-3 (PROM board SH 2/10) */
 				if (plb == 0)
