@@ -5,7 +5,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "victory.h"
 
 
@@ -55,11 +54,11 @@ static struct
 
 /* function prototypes */
 static int command2(void);
-static int command3(void);
-static int command4(void);
-static int command5(void);
+static int command3(running_machine *machine);
+static int command4(running_machine *machine);
+static int command5(running_machine *machine);
 static int command6(void);
-static int command7(void);
+static int command7(running_machine *machine);
 
 
 
@@ -87,10 +86,10 @@ VIDEO_START( victory )
 	scrollx = scrolly = 0;
 	video_control = 0;
 	memset(&micro, 0, sizeof(micro));
-	micro.timer = timer_alloc(NULL, NULL);
+	micro.timer = timer_alloc(machine, NULL, NULL);
 
 	/* register for state saving */
-	state_save_register_global_array(victory_paletteram);
+	state_save_register_global_array(machine, victory_paletteram);
 }
 
 
@@ -101,12 +100,12 @@ VIDEO_START( victory )
  *
  *************************************/
 
-static void victory_update_irq(void)
+static void victory_update_irq(running_machine *machine)
 {
 	if (vblank_irq || fgcoll || (bgcoll && (video_control & 0x20)))
-		cpunum_set_input_line(Machine, 0, 0, ASSERT_LINE);
+		cpu_set_input_line(machine->cpu[0], 0, ASSERT_LINE);
 	else
-		cpunum_set_input_line(Machine, 0, 0, CLEAR_LINE);
+		cpu_set_input_line(machine->cpu[0], 0, CLEAR_LINE);
 }
 
 
@@ -114,7 +113,7 @@ INTERRUPT_GEN( victory_vblank_interrupt )
 {
 	vblank_irq = 1;
 
-	victory_update_irq();
+	victory_update_irq(device->machine);
 }
 
 
@@ -159,7 +158,7 @@ READ8_HANDLER( victory_video_control_r )
 	{
 		case 0x00:	/* 5XFIQ */
 			result = fgcollx;
-			if (LOG_COLLISION) logerror("%04X:5XFIQ read = %02X\n", activecpu_get_previouspc(), result);
+			if (LOG_COLLISION) logerror("%04X:5XFIQ read = %02X\n", cpu_get_previouspc(space->cpu), result);
 			return result;
 
 		case 0x01:	/* 5CLFIQ */
@@ -167,14 +166,14 @@ READ8_HANDLER( victory_video_control_r )
 			if (fgcoll)
 			{
 				fgcoll = 0;
-				victory_update_irq();
+				victory_update_irq(space->machine);
 			}
-			if (LOG_COLLISION) logerror("%04X:5CLFIQ read = %02X\n", activecpu_get_previouspc(), result);
+			if (LOG_COLLISION) logerror("%04X:5CLFIQ read = %02X\n", cpu_get_previouspc(space->cpu), result);
 			return result;
 
 		case 0x02:	/* 5BACKX */
 			result = bgcollx & 0xfc;
-			if (LOG_COLLISION) logerror("%04X:5BACKX read = %02X\n", activecpu_get_previouspc(), result);
+			if (LOG_COLLISION) logerror("%04X:5BACKX read = %02X\n", cpu_get_previouspc(space->cpu), result);
 			return result;
 
 		case 0x03:	/* 5BACKY */
@@ -182,9 +181,9 @@ READ8_HANDLER( victory_video_control_r )
 			if (bgcoll)
 			{
 				bgcoll = 0;
-				victory_update_irq();
+				victory_update_irq(space->machine);
 			}
-			if (LOG_COLLISION) logerror("%04X:5BACKY read = %02X\n", activecpu_get_previouspc(), result);
+			if (LOG_COLLISION) logerror("%04X:5BACKY read = %02X\n", cpu_get_previouspc(space->cpu), result);
 			return result;
 
 		case 0x04:	/* 5STAT */
@@ -198,12 +197,12 @@ READ8_HANDLER( victory_video_control_r )
 			result |= (~fgcoll & 1) << 6;
 			result |= (~vblank_irq & 1) << 5;
 			result |= (~bgcoll & 1) << 4;
-			result |= (video_screen_get_vpos(0) & 0x100) >> 5;
-			if (LOG_COLLISION) logerror("%04X:5STAT read = %02X\n", activecpu_get_previouspc(), result);
+			result |= (video_screen_get_vpos(space->machine->primary_screen) & 0x100) >> 5;
+			if (LOG_COLLISION) logerror("%04X:5STAT read = %02X\n", cpu_get_previouspc(space->cpu), result);
 			return result;
 
 		default:
-			logerror("%04X:victory_video_control_r(%02X)\n", activecpu_get_previouspc(), offset);
+			logerror("%04X:victory_video_control_r(%02X)\n", cpu_get_previouspc(space->cpu), offset);
 			break;
 	}
 	return 0;
@@ -222,22 +221,22 @@ WRITE8_HANDLER( victory_video_control_w )
 	switch (offset)
 	{
 		case 0x00:	/* LOAD IL */
-			if (LOG_MICROCODE) logerror("%04X:IL=%02X\n", activecpu_get_previouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:IL=%02X\n", cpu_get_previouspc(space->cpu), data);
 			micro.i = (micro.i & 0xff00) | (data & 0x00ff);
 			break;
 
 		case 0x01:	/* LOAD IH */
-			if (LOG_MICROCODE) logerror("%04X:IH=%02X\n", activecpu_get_previouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:IH=%02X\n", cpu_get_previouspc(space->cpu), data);
 			micro.i = (micro.i & 0x00ff) | ((data << 8) & 0xff00);
 			if (micro.cmdlo == 5)
 			{
 				if (LOG_MICROCODE) logerror("  Command 5 triggered by write to IH\n");
-				command5();
+				command5(space->machine);
 			}
 			break;
 
 		case 0x02:	/* LOAD CMD */
-			if (LOG_MICROCODE) logerror("%04X:CMD=%02X\n", activecpu_get_previouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:CMD=%02X\n", cpu_get_previouspc(space->cpu), data);
 			micro.cmd = data;
 			micro.cmdlo = data & 7;
 			if (micro.cmdlo == 0)
@@ -252,37 +251,37 @@ WRITE8_HANDLER( victory_video_control_w )
 			break;
 
 		case 0x03:	/* LOAD G */
-			if (LOG_MICROCODE) logerror("%04X:G=%02X\n", activecpu_get_previouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:G=%02X\n", cpu_get_previouspc(space->cpu), data);
 			micro.g = data;
 			break;
 
 		case 0x04:	/* LOAD X */
-			if (LOG_MICROCODE) logerror("%04X:X=%02X\n", activecpu_get_previouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:X=%02X\n", cpu_get_previouspc(space->cpu), data);
 			micro.xp = data;
 			if (micro.cmdlo == 3)
 			{
 				if (LOG_MICROCODE) logerror(" Command 3 triggered by write to X\n");
-				command3();
+				command3(space->machine);
 			}
 			break;
 
 		case 0x05:	/* LOAD Y */
-			if (LOG_MICROCODE) logerror("%04X:Y=%02X\n", activecpu_get_previouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:Y=%02X\n", cpu_get_previouspc(space->cpu), data);
 			micro.yp = data;
 			if (micro.cmdlo == 4)
 			{
 				if (LOG_MICROCODE) logerror("  Command 4 triggered by write to Y\n");
-				command4();
+				command4(space->machine);
 			}
 			break;
 
 		case 0x06:	/* LOAD R */
-			if (LOG_MICROCODE) logerror("%04X:R=%02X\n", activecpu_get_previouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:R=%02X\n", cpu_get_previouspc(space->cpu), data);
 			micro.r = data;
 			break;
 
 		case 0x07:	/* LOAD B */
-			if (LOG_MICROCODE) logerror("%04X:B=%02X\n", activecpu_get_previouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:B=%02X\n", cpu_get_previouspc(space->cpu), data);
 			micro.b = data;
 			if (micro.cmdlo == 2)
 			{
@@ -292,17 +291,17 @@ WRITE8_HANDLER( victory_video_control_w )
 			else if (micro.cmdlo == 7)
 			{
 				if (LOG_MICROCODE) logerror("  Command 7 triggered by write to B\n");
-				command7();
+				command7(space->machine);
 			}
 			break;
 
 		case 0x08:	/* SCROLLX */
-			if (LOG_MICROCODE) logerror("%04X:SCROLLX write = %02X\n", activecpu_get_previouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:SCROLLX write = %02X\n", cpu_get_previouspc(space->cpu), data);
 			scrollx = data;
 			break;
 
 		case 0x09:	/* SCROLLY */
-			if (LOG_MICROCODE) logerror("%04X:SCROLLY write = %02X\n", activecpu_get_previouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:SCROLLY write = %02X\n", cpu_get_previouspc(space->cpu), data);
 			scrolly = data;
 			break;
 
@@ -314,18 +313,18 @@ WRITE8_HANDLER( victory_video_control_w )
 			// D3 = SINVERT
 			// D2 = BIR12
 			// D1 = SELOVER
-			if (LOG_MICROCODE) logerror("%04X:CONTROL write = %02X\n", activecpu_get_previouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:CONTROL write = %02X\n", cpu_get_previouspc(space->cpu), data);
 			video_control = data;
 			break;
 
 		case 0x0b:	/* CLRVIRQ */
-			if (LOG_MICROCODE) logerror("%04X:CLRVIRQ write = %02X\n", activecpu_get_previouspc(), data);
+			if (LOG_MICROCODE) logerror("%04X:CLRVIRQ write = %02X\n", cpu_get_previouspc(space->cpu), data);
 			vblank_irq = 0;
-			victory_update_irq();
+			victory_update_irq(space->machine);
 			break;
 
 		default:
-			if (LOG_MICROCODE) logerror("%04X:victory_video_control_w(%02X) = %02X\n", activecpu_get_previouspc(), offset, data);
+			if (LOG_MICROCODE) logerror("%04X:victory_video_control_w(%02X) = %02X\n", cpu_get_previouspc(space->cpu), offset, data);
 			break;
 	}
 }
@@ -531,13 +530,13 @@ INLINE void count_states(int states)
 
 	if (!micro.timer)
 	{
-		timer_adjust(micro.timer, attotime_never, 0, attotime_zero);
+		timer_adjust_oneshot(micro.timer, attotime_never, 0);
 		micro.timer_active = 1;
 		micro.endtime = state_time;
 	}
 	else if (attotime_compare(timer_timeelapsed(micro.timer), micro.endtime) > 0)
 	{
-		timer_adjust(micro.timer, attotime_never, 0, attotime_zero);
+		timer_adjust_oneshot(micro.timer, attotime_never, 0);
 		micro.timer_active = 1;
 		micro.endtime = state_time;
 	}
@@ -585,7 +584,7 @@ static int command2(void)
  *
  *************************************/
 
-static int command3(void)
+static int command3(running_machine *machine)
 {
 /*
     Actual microcode:
@@ -674,7 +673,7 @@ static int command3(void)
 					rram[dstoffs + 0] ^= src >> shift;
 					rram[dstoffs + 1] ^= src << nshift;
 				}
-				if (fgcoll) victory_update_irq();
+				if (fgcoll) victory_update_irq(machine);
 			}
 		}
 	}
@@ -692,7 +691,7 @@ static int command3(void)
  *
  *************************************/
 
-static int command4(void)
+static int command4(running_machine *machine)
 {
 /*
     Actual microcode:
@@ -734,11 +733,11 @@ static int command4(void)
 			case 0:												break;
 			case 1:												break;
 			case 2:	keep_going = command2();					break;
-			case 3:	keep_going = command3();					break;
+			case 3:	keep_going = command3(machine);				break;
 			case 4:	micro.pc = micro.yp << 1; keep_going = 1;	break;
-			case 5:	keep_going = command5();					break;
+			case 5:	keep_going = command5(machine);				break;
 			case 6:	keep_going = command6();					break;
-			case 7:	keep_going = command7();					break;
+			case 7:	keep_going = command7(machine);				break;
 		}
 	} while (keep_going);
 
@@ -755,7 +754,7 @@ static int command4(void)
  *
  *************************************/
 
-static int command5(void)
+static int command5(running_machine *machine)
 {
 /*
     Actual microcode:
@@ -874,7 +873,7 @@ static int command5(void)
 			}
 			acc &= 0xff;
 		}
-		if (fgcoll) victory_update_irq();
+		if (fgcoll) victory_update_irq(machine);
 	}
 
 	micro.xp = x;
@@ -941,7 +940,7 @@ static int command6(void)
  *
  *************************************/
 
-static int command7(void)
+static int command7(running_machine *machine)
 {
 /*
     Actual microcode:
@@ -1004,7 +1003,7 @@ static int command7(void)
 			rram[addr + 0] ^= micro.r >> shift;
 			rram[addr + 1] ^= micro.r << nshift;
 		}
-		if (fgcoll) victory_update_irq();
+		if (fgcoll) victory_update_irq(machine);
 	}
 
 	count_states(4);
@@ -1087,7 +1086,7 @@ static TIMER_CALLBACK( bgcoll_irq_callback )
 	bgcollx = param & 0xff;
 	bgcolly = param >> 8;
 	bgcoll = 1;
-	victory_update_irq();
+	victory_update_irq(machine);
 }
 
 
@@ -1105,7 +1104,7 @@ VIDEO_UPDATE( victory )
 	int x, y;
 
 	/* copy the palette from palette RAM */
-	set_palette(machine);
+	set_palette(screen->machine);
 
 	/* update the foreground & background */
 	update_foreground();
@@ -1126,11 +1125,11 @@ VIDEO_UPDATE( victory )
 			int bpix = bg[(x + scrollx) & 255];
 			scanline[x] = bpix | (fpix << 3);
 			if (fpix && (bpix & bgcollmask) && count++ < 128)
-				timer_set(video_screen_get_time_until_pos(0, y, x), NULL, x | (y << 8), bgcoll_irq_callback);
+				timer_set(screen->machine, video_screen_get_time_until_pos(screen, y, x), NULL, x | (y << 8), bgcoll_irq_callback);
 		}
 
 		/* draw the scanline */
-		draw_scanline8(bitmap, 0, y, 256, scanline, machine->pens, -1);
+		draw_scanline8(bitmap, 0, y, 256, scanline, NULL, -1);
 	}
 
 	return 0;
