@@ -8,7 +8,6 @@
 ***************************************************************************/
 
 #include "driver.h"
-#include "deprecat.h"
 #include "video/konamiic.h"
 
 #define BMP_PAD		8
@@ -28,6 +27,7 @@ struct sprite
 	int line_offset;
 
 	const pen_t *pal_data;
+	rgb_t pal_base;
 
 	int x_offset, y_offset;
 	int tile_width, tile_height;
@@ -106,9 +106,9 @@ static struct sprite *sprite_list_create(int num_sprites)
 
 static void get_sprite_info(running_machine *machine)
 {
-	const pen_t *base_pal = machine->remapped_colortable;
-	UINT8 *base_gfx = memory_region(REGION_GFX1);
-	int gfx_max     = memory_region_length(REGION_GFX1);
+	const pen_t *base_pal = machine->pens;
+	UINT8 *base_gfx = memory_region(machine, "gfx1");
+	int gfx_max     = memory_region_length(machine, "gfx1");
 
 	UINT16 *source = spriteram16;
 
@@ -137,7 +137,8 @@ static void get_sprite_info(running_machine *machine)
 		code = source[0x06/2];
 		zoom = source[0x08/2];
 
-		sprite->pal_data = base_pal + ((source[0x0e/2] & 0xff) << 4);
+		sprite->pal_base = (source[0x0e/2] & 0xff) << 4;
+		sprite->pal_data = base_pal + sprite->pal_base;
 
 		gfx = (wecleman_gfx_bank[bank] << 15) + (code & 0x7fff);
 
@@ -198,7 +199,7 @@ static void sortsprite(int *idx_array, int *key_array, int size)
 }
 
 // draws a 8bpp palette sprites on a 16bpp direct RGB target (sub-par implementation)
-static void do_blit_zoom16(mame_bitmap *bitmap, const rectangle *cliprect, struct sprite *sprite)
+static void do_blit_zoom32(bitmap_t *bitmap, const rectangle *cliprect, struct sprite *sprite)
 {
 #define PRECISION_X 20
 #define PRECISION_Y 20
@@ -275,56 +276,80 @@ static void do_blit_zoom16(mame_bitmap *bitmap, const rectangle *cliprect, struc
 	// pre-loop assignments and adjustments
 	pal_base = sprite->pal_data;
 
-	x1 -= dx;
-	x2 -= dx;
+	if (x1 > cliprect->min_x)
+	{
+		x1 -= dx;
+		x2 -= dx;
+	}
 
 	for (sy = y1; sy != y2; sy += dy)
 	{
 		UINT8 *row_base = sprite->pen_data + (src_f0y>>PRECISION_Y) * sprite->line_offset;
-		UINT16 *dst_ptr = BITMAP_ADDR16(bitmap, sy, 0);
 		src_fpx = src_f0x;
 
-		if (!sprite->shadow_mode)
+		if (bitmap->format == BITMAP_FORMAT_RGB32)	// Wec Le Mans
 		{
-			for (sx = x1; sx != x2; sx += dx)
+			UINT32 *dst_ptr = BITMAP_ADDR32(bitmap, sy, 0);
+
+			if (!sprite->shadow_mode)
 			{
-				int pix = row_base[src_fpx >> PRECISION_X];
-				if (pix & 0x80) break;
-				if (pix)
-					dst_ptr[sx] = pal_base[pix];
-				src_fpx += src_fdx;
-			}
-		}
-		else if (gameid == 0)	// Wec Le Mans
-		{
-			for (sx = x1; sx != x2; sx += dx)
-			{
-				int pix = row_base[src_fpx >> PRECISION_X];
-				if (pix & 0x80) break;
-				if (pix)
+				for (sx = x1; sx != x2; sx += dx)
 				{
-					if (pix != 0xa)
+					int pix = row_base[src_fpx >> PRECISION_X];
+					if (pix & 0x80) break;
+					if (pix)
 						dst_ptr[sx] = pal_base[pix];
-					else
-						dst_ptr[sx] = rgb_half[dst_ptr[sx]];
+					src_fpx += src_fdx;
+				}
+			}
+			else
+			{
+				for (sx = x1; sx != x2; sx += dx)
+				{
+					int pix = row_base[src_fpx >> PRECISION_X];
+					if (pix & 0x80) break;
+					if (pix)
+					{
+						if (pix != 0xa)
+							dst_ptr[sx] = pal_base[pix];
+						else
+							dst_ptr[sx] = (dst_ptr[sx] >> 1) & MAKE_RGB(0x7f,0x7f,0x7f);
+					}
+					src_fpx += src_fdx;
 				}
-				src_fpx += src_fdx;
 			}
 		}
 		else	// Hot Chase
 		{
-			for (sx = x1; sx != x2; sx += dx)
+			UINT16 *dst_ptr = BITMAP_ADDR16(bitmap, sy, 0);
+			pen_t base = sprite->pal_base;
+
+			if (!sprite->shadow_mode)
 			{
-				int pix = row_base[src_fpx >> PRECISION_X];
-				if (pix & 0x80) break;
-				if (pix)
+				for (sx = x1; sx != x2; sx += dx)
 				{
-					if (pix != 0xa)
-						dst_ptr[sx] = pal_base[pix];
-					else
-						dst_ptr[sx] |= 0x800;
+					int pix = row_base[src_fpx >> PRECISION_X];
+					if (pix & 0x80) break;
+					if (pix)
+						dst_ptr[sx] = base + pix;
+					src_fpx += src_fdx;
+				}
+			}
+			else
+			{
+				for (sx = x1; sx != x2; sx += dx)
+				{
+					int pix = row_base[src_fpx >> PRECISION_X];
+					if (pix & 0x80) break;
+					if (pix)
+					{
+						if (pix != 0xa)
+							dst_ptr[sx] = base + pix;
+						else
+							dst_ptr[sx] |= 0x800;
+					}
+					src_fpx += src_fdx;
 				}
-				src_fpx += src_fdx;
 			}
 		}
 
@@ -332,7 +357,7 @@ static void do_blit_zoom16(mame_bitmap *bitmap, const rectangle *cliprect, struc
 	}
 }
 
-static void sprite_draw(mame_bitmap *bitmap, const rectangle *cliprect)
+static void sprite_draw(bitmap_t *bitmap, const rectangle *cliprect)
 {
 	int i;
 
@@ -340,11 +365,11 @@ static void sprite_draw(mame_bitmap *bitmap, const rectangle *cliprect)
 	{
 		sortsprite(spr_idx_list, spr_pri_list, spr_count);
 
-		for (i=0; i<spr_count; i++) do_blit_zoom16(bitmap, cliprect, spr_ptr_list[spr_idx_list[i]]);
+		for (i=0; i<spr_count; i++) do_blit_zoom32(bitmap, cliprect, spr_ptr_list[spr_idx_list[i]]);
 	}
 	else	// Hot Chase
 	{
-		for (i=0; i<spr_count; i++) do_blit_zoom16(bitmap, cliprect, spr_ptr_list[i]);
+		for (i=0; i<spr_count; i++) do_blit_zoom32(bitmap, cliprect, spr_ptr_list[i]);
 	}
 }
 
@@ -535,7 +560,7 @@ WRITE16_HANDLER( wecleman_pageram_w )
 
 ------------------------------------------------------------------------*/
 
-static void wecleman_draw_road(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect, int priority)
+static void wecleman_draw_road(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect, int priority)
 {
 // must be powers of 2
 #define XSIZE 512
@@ -566,15 +591,16 @@ static void wecleman_draw_road(running_machine *machine, mame_bitmap *bitmap, co
 	int scrollx, sy, sx;
 	int mdy, tdy, i;
 
-	rgb_ptr = machine->remapped_colortable;
+	rgb_ptr = machine->pens;
 
 	if (priority == 0x02)
 	{
 		// draw sky; each scanline is assumed to be dword aligned
 		for (sy=cliprect->min_y-BMP_PAD; sy<DST_HEIGHT; sy++)
 		{
-			UINT16 *dst = BITMAP_ADDR16(bitmap, sy+BMP_PAD, BMP_PAD);
-			UINT16 pix, road;
+			UINT32 *dst = BITMAP_ADDR32(bitmap, sy+BMP_PAD, BMP_PAD);
+			UINT32 pix;
+			UINT16 road;
 
 			road = wecleman_roadram[sy];
 			if ((road>>8) != 0x02) continue;
@@ -599,8 +625,9 @@ static void wecleman_draw_road(running_machine *machine, mame_bitmap *bitmap, co
 
 		for (sy=cliprect->min_y-BMP_PAD; sy<DST_HEIGHT; sy++)
 		{
-			UINT16 *dst = BITMAP_ADDR16(bitmap, sy+BMP_PAD, BMP_PAD);
-			UINT16 pix, road;
+			UINT32 *dst = BITMAP_ADDR32(bitmap, sy+BMP_PAD, BMP_PAD);
+			UINT32 pix;
+			UINT16 road;
 
 			road = wecleman_roadram[sy];
 			if ((road>>8) != 0x04) continue;
@@ -644,7 +671,7 @@ static void wecleman_draw_road(running_machine *machine, mame_bitmap *bitmap, co
 ------------------------------------------------------------------------*/
 
 // blends two 8x8x16bpp direct RGB tilemaps
-static void draw_cloud(running_machine *machine, mame_bitmap *bitmap,
+static void draw_cloud(running_machine *machine, bitmap_t *bitmap,
 				 gfx_element *gfx,
 				 UINT16 *tm_base,
 				 int x0, int y0,				// target coordinate
@@ -654,12 +681,13 @@ static void draw_cloud(running_machine *machine, mame_bitmap *bitmap,
 				 int alpha, int pal_offset )	// alpha(0-3f), # of color codes to shift
 {
 	UINT8 *src_base, *src_ptr;
-	UINT16 *tmap_ptr, *dst_base, *dst_ptr;
+	UINT16 *tmap_ptr;
+	UINT32 *dst_base, *dst_ptr;
 	const pen_t *pal_base, *pal_ptr;
 
 	int tilew, tileh;
 	int tmskipx, tmskipy, tmscanx, tmmaskx, tmmasky;
-	int dx, dy, dst_pitch;
+	int dx, dy;
 	int i, j, tx, ty;
 
 	if (alpha > 0x1f) return;
@@ -680,10 +708,9 @@ static void draw_cloud(running_machine *machine, mame_bitmap *bitmap,
 
 	src_base = gfx->gfxdata;
 
-	dst_pitch = bitmap->rowpixels;
-	dst_base = (UINT16 *)bitmap->base + (y0+dy)*dst_pitch + (x0+dx);
+	dst_base = BITMAP_ADDR32(bitmap, y0+dy, x0+dx);
 
-	pal_base = machine->remapped_colortable + pal_offset * gfx->color_granularity;
+	pal_base = machine->pens + pal_offset * gfx->color_granularity;
 
 	alpha <<= 6;
 
@@ -716,24 +743,24 @@ static void draw_cloud(running_machine *machine, mame_bitmap *bitmap,
 					{
 						UINT8 srcpix = *src_ptr++;
 						pen_t srcrgb = pal_ptr[srcpix];
-						UINT16 dstrgb = dst_ptr[tx];
+						UINT32 dstrgb = dst_ptr[tx];
 						int sr, sg, sb, dr, dg, db;
 
-						sr = (srcrgb >> 0) & 0x1f;
-						sg = (srcrgb >> 5) & 0x1f;
-						sb = (srcrgb >> 10) & 0x1f;
+						sr = (srcrgb >> 3) & 0x1f;
+						sg = (srcrgb >> 11) & 0x1f;
+						sb = (srcrgb >> 19) & 0x1f;
 
-						dr = (dstrgb >> 0) & 0x1f;
-						dg = (dstrgb >> 5) & 0x1f;
-						db = (dstrgb >> 10) & 0x1f;
+						dr = (dstrgb >> 3) & 0x1f;
+						dg = (dstrgb >> 11) & 0x1f;
+						db = (dstrgb >> 19) & 0x1f;
 
 						dr = (t32x32pm[dr - sr + alpha] >> 5) + dr;
 						dg = (t32x32pm[dg - sg + alpha] >> 5) + dg;
 						db = (t32x32pm[db - sb + alpha] >> 5) + db;
 
-						dst_ptr[tx] = dr | (dg << 5) | (db << 10);
+						dst_ptr[tx] = MAKE_RGB(pal5bit(db), pal5bit(dg), pal5bit(dr));
 					}
-					dst_ptr += dst_pitch;
+					dst_ptr += bitmap->rowpixels;
 				}
 			}
 
@@ -744,12 +771,12 @@ static void draw_cloud(running_machine *machine, mame_bitmap *bitmap,
 				{
 					for (tx = 0; tx < tilew; tx++)
 						dst_ptr[tx] = pal_ptr[*src_ptr++];
-					dst_ptr += dst_pitch;
+					dst_ptr += bitmap->rowpixels;
 				}
 			}
 		}
 
-		dst_base += dst_pitch * tileh;
+		dst_base += bitmap->rowpixels * tileh;
 	}
 }
 
@@ -780,16 +807,17 @@ static void draw_cloud(running_machine *machine, mame_bitmap *bitmap,
 
 ------------------------------------------------------------------------*/
 
-static void hotchase_draw_road(running_machine *machine, mame_bitmap *bitmap, const rectangle *cliprect)
+static void hotchase_draw_road(running_machine *machine, bitmap_t *bitmap, const rectangle *cliprect)
 {
 /* Referred to what's in the ROMs */
 #define XSIZE 512
 #define YSIZE 512
 
 	int sx, sy;
+	const rectangle *visarea = video_screen_get_visible_area(machine->primary_screen);
 
 	/* Let's draw from the top to the bottom of the visible screen */
-	for (sy = machine->screen[0].visarea.min_y;sy <= machine->screen[0].visarea.max_y;sy++)
+	for (sy = visarea->min_y;sy <= visarea->max_y;sy++)
 	{
 		int code    = wecleman_roadram[sy*4/2+2/2] + (wecleman_roadram[sy*4/2+0/2] << 16);
 		int color   = ((code & 0x00f00000) >> 20) + 0x70;
@@ -827,7 +855,7 @@ WRITE16_HANDLER( wecleman_videostatus_w )
 
 	// bit0-6: background transition, 0=off, 1=on
 	// bit7: palette being changed, 0=no, 1=yes
-	if (ACCESSING_LSB)
+	if (ACCESSING_BITS_0_7)
 	{
 		if ((data & 0x7f) == 0 && !cloud_ds)
 			cloud_ds = BLEND_INC;
@@ -851,9 +879,9 @@ WRITE16_HANDLER( hotchase_paletteram16_SBGRBBBBGGGGRRRR_word_w )
 	g = ((newword >> 3) & 0x1E ) | ((newword >> 13) & 0x01);
 	b = ((newword >> 7) & 0x1E ) | ((newword >> 14) & 0x01);
 
-	palette_set_color_rgb(Machine, offset, pal5bit(r), pal5bit(g), pal5bit(b));
+	palette_set_color_rgb(space->machine, offset, pal5bit(r), pal5bit(g), pal5bit(b));
 	r>>=1; g>>=1; b>>=1;
-	palette_set_color_rgb(Machine, offset+0x800, pal5bit(r)/2, pal5bit(g)/2, pal5bit(b)/2);
+	palette_set_color_rgb(space->machine, offset+0x800, pal5bit(r)/2, pal5bit(g)/2, pal5bit(b)/2);
 }
 
 WRITE16_HANDLER( wecleman_paletteram16_SSSSBBBBGGGGRRRR_word_w )
@@ -862,7 +890,7 @@ WRITE16_HANDLER( wecleman_paletteram16_SSSSBBBBGGGGRRRR_word_w )
 
 	// the highest nibble has some unknown functions
 //  if (newword & 0xf000) logerror("MSN set on color %03x: %1x\n", offset, newword>>12);
-	palette_set_color_rgb(Machine, offset, pal4bit(newword >> 0), pal4bit(newword >> 4), pal4bit(newword >> 8));
+	palette_set_color_rgb(space->machine, offset, pal4bit(newword >> 0), pal4bit(newword >> 4), pal4bit(newword >> 8));
 }
 
 
@@ -887,7 +915,7 @@ VIDEO_START( wecleman )
 	UINT8 *buffer;
 	int i, j;
 
-	assert(machine->screen[0].format == BITMAP_FORMAT_RGB15);
+	assert(video_screen_get_format(machine->primary_screen) == BITMAP_FORMAT_RGB32);
 	buffer = auto_malloc(0x12c00);	// working buffer for sprite operations
 
 	gameid = 0;
@@ -920,21 +948,21 @@ VIDEO_START( wecleman )
 
 	sprite_list = sprite_list_create(NUM_SPRITES);
 
-	bg_tilemap = tilemap_create(wecleman_get_bg_tile_info,
+	bg_tilemap = tilemap_create(machine, wecleman_get_bg_tile_info,
 								tilemap_scan_rows,
-								TILEMAP_TYPE_PEN,	/* We draw part of the road below */
+									/* We draw part of the road below */
 								8,8,
 								PAGE_NX * 2, PAGE_NY * 2 );
 
-	fg_tilemap = tilemap_create(wecleman_get_fg_tile_info,
+	fg_tilemap = tilemap_create(machine, wecleman_get_fg_tile_info,
 								tilemap_scan_rows,
-								TILEMAP_TYPE_PEN,
+
 								8,8,
 								PAGE_NX * 2, PAGE_NY * 2);
 
-	txt_tilemap = tilemap_create(wecleman_get_txt_tile_info,
+	txt_tilemap = tilemap_create(machine, wecleman_get_txt_tile_info,
 								 tilemap_scan_rows,
-								 TILEMAP_TYPE_PEN,
+
 								 8,8,
 								 PAGE_NX * 1, PAGE_NY * 1);
 
@@ -958,8 +986,8 @@ VIDEO_START( wecleman )
 }
 
 //  Callbacks for the K051316
-#define ZOOMROM0_MEM_REGION REGION_GFX2
-#define ZOOMROM1_MEM_REGION REGION_GFX3
+#define ZOOMROM0_MEM_REGION "gfx2"
+#define ZOOMROM1_MEM_REGION "gfx3"
 
 static void zoom_callback_0(int *code,int *color,int *flags)
 {
@@ -1022,7 +1050,7 @@ VIDEO_UPDATE ( wecleman )
 	int cloud_sx, cloud_sy;
 	int i, j, k;
 
-	mrct = machine->remapped_colortable;
+	mrct = screen->machine->pens;
 
 	video_on = wecleman_irqctrl & 0x40;
 
@@ -1054,12 +1082,12 @@ VIDEO_UPDATE ( wecleman )
 	/* palette hacks! */
 	((pen_t *)mrct)[0x27] = mrct[0x24];
 
-	get_sprite_info(machine);
+	get_sprite_info(screen->machine);
 
-	fillbitmap(bitmap, get_black_pen(machine), cliprect);
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
 
 	/* Draw the road (lines which have priority 0x02) */
-	if (video_on) wecleman_draw_road(machine, bitmap, cliprect, 0x02);
+	if (video_on) wecleman_draw_road(screen->machine, bitmap, cliprect, 0x02);
 
 	/* Draw the background */
 	if (video_on) tilemap_draw(bitmap,cliprect, bg_tilemap, 0, 0);
@@ -1071,9 +1099,9 @@ VIDEO_UPDATE ( wecleman )
 		((pen_t *)mrct)[0] = ((pen_t *)mrct)[0x40] = ((pen_t *)mrct)[0x200] = ((pen_t *)mrct)[0x205];
 
 		if (video_on)
-			draw_cloud(machine,
+			draw_cloud(screen->machine,
 			bitmap,
-			machine->gfx[0],
+			screen->machine->gfx[0],
 			wecleman_pageram+0x1800,
 			BMP_PAD, BMP_PAD,
 			41, 20,
@@ -1093,7 +1121,7 @@ VIDEO_UPDATE ( wecleman )
 	if (video_on) tilemap_draw(bitmap,cliprect, fg_tilemap, 0, 0);
 
 	/* Draw the road (lines which have priority 0x04) */
-	if (video_on) wecleman_draw_road(machine, bitmap,cliprect, 0x04);
+	if (video_on) wecleman_draw_road(screen->machine, bitmap,cliprect, 0x04);
 
 	/* Draw the sprites */
 	if (video_on) sprite_draw(bitmap,cliprect);
@@ -1115,15 +1143,15 @@ VIDEO_UPDATE( hotchase )
 
 	set_led_status(0, wecleman_selected_ip & 0x04);	// Start lamp
 
-	get_sprite_info(machine);
+	get_sprite_info(screen->machine);
 
-	fillbitmap(bitmap, get_black_pen(machine), cliprect);
+	bitmap_fill(bitmap, cliprect, get_black_pen(screen->machine));
 
 	/* Draw the background */
 	if (video_on) K051316_zoom_draw_0(bitmap,cliprect, 0, 0);
 
 	/* Draw the road */
-	if (video_on) hotchase_draw_road(machine, bitmap, cliprect);
+	if (video_on) hotchase_draw_road(screen->machine, bitmap, cliprect);
 
 	/* Draw the sprites */
 	if (video_on) sprite_draw(bitmap,cliprect);
