@@ -14,12 +14,15 @@
 #include <stdlib.h>
 
 // MAME headers
-#include "driver.h"
-#include "window.h"
-#include "options.h"
+#include "osdepend.h"
+#include "mame.h"
 #include "clifront.h"
-#include "input.h"
+#include "emuopts.h"
 
+// OSD headers
+#include "video.h"
+#include "input.h"
+#include "output.h"
 #include "osdsdl.h"
 
 // we override SDL's normal startup on Win32
@@ -99,16 +102,20 @@ static const options_entry mame_sdl_options[] =
 	{ SDLOPTION_VIDEO,                   SDLOPTVAL_SOFT,  0,                 "video output method: soft or opengl" },
 	{ SDLOPTION_NUMSCREENS,                   "1",        0,                 "number of screens to create; SDLMAME only supports 1 at this time" },
 	{ SDLOPTION_WINDOW ";w",                  "0",        OPTION_BOOLEAN,    "enable window mode; otherwise, full screen mode is assumed" },
+	{ SDLOPTION_MAXIMIZE ";max",              "1",        OPTION_BOOLEAN,    "default to maximized windows; otherwise, windows will be minimized" },
 	{ SDLOPTION_KEEPASPECT ";ka",             "1",        OPTION_BOOLEAN,    "constrain to the proper aspect ratio" },
 	{ SDLOPTION_UNEVENSTRETCH ";ues",         "1",        OPTION_BOOLEAN,    "allow non-integer stretch factors" },
 	{ SDLOPTION_EFFECT,                  SDLOPTVAL_NONE,  0,                 "name of a PNG file to use for visual effects, or 'none'" },
 	{ SDLOPTION_CENTERH,                      "1",        OPTION_BOOLEAN,    "center horizontally within the view area" },
 	{ SDLOPTION_CENTERV,                      "1",        OPTION_BOOLEAN,    "center vertically within the view area" },
-	#if (SDL_VERSIONNUM(SDL_MAJOR_VERSION, SDL_MINOR_VERSION, SDL_PATCHLEVEL) >= 1210)
+	#if (SDL_VERSION_ATLEAST(1,2,10))
 	{ SDLOPTION_WAITVSYNC,                    "0",        OPTION_BOOLEAN,    "enable waiting for the start of VBLANK before flipping screens; reduces tearing effects" },
 	#endif
-	{ SDLOPTION_YUVMODE ";ym",           SDLOPTVAL_NONE,  0,                 "YUV mode: none, yv12, yuy2, yv12x2, yuy2x2 (-video soft only)" },
-
+#if (SDL_VERSION_ATLEAST(1,3,0))
+	{ SDLOPTION_SCALEMODE ";sm",         SDLOPTVAL_NONE,  0,                 "Scale mode: none, hwblit, hwbest, yv12, yuy2, yv12x2, yuy2x2 (-video soft only)" },
+#else
+	{ SDLOPTION_SCALEMODE ";sm",         SDLOPTVAL_NONE,  0,                 "Scale mode: none, async, yv12, yuy2, yv12x2, yuy2x2 (-video soft only)" },
+#endif
 #if USE_OPENGL
 	// OpenGL specific options
 	{ NULL,                                   NULL,   OPTION_HEADER,  "OpenGL-SPECIFIC OPTIONS" },
@@ -195,14 +202,77 @@ static const options_entry mame_sdl_options[] =
 
 	// joystick mapping
 	{ NULL, 		                         NULL,   OPTION_HEADER,     "SDL JOYSTICK MAPPING" },
-	{ SDLOPTION_JOYMAP,                      "0",    OPTION_BOOLEAN,    "enable physical to logical joystick mapping" },
-	{ SDLOPTION_JOYMAP_FILE,                "joymap.dat", 0,            "joymap filename" },
-	{ SDLOPTION_SIXAXIS,			        "0",	 OPTION_BOOLEAN,    "Use special handling for PS3 Sixaxis controllers" },
+	{ SDLOPTION_JOYINDEX "1",                SDLOPTVAL_AUTO, 0,         "name of joystick mapped to joystick #1" },
+	{ SDLOPTION_JOYINDEX "2",                SDLOPTVAL_AUTO, 0,         "name of joystick mapped to joystick #2" },
+	{ SDLOPTION_JOYINDEX "3",                SDLOPTVAL_AUTO, 0,         "name of joystick mapped to joystick #3" },
+	{ SDLOPTION_JOYINDEX "4",                SDLOPTVAL_AUTO, 0,         "name of joystick mapped to joystick #4" },
+	{ SDLOPTION_JOYINDEX "5",                SDLOPTVAL_AUTO, 0,         "name of joystick mapped to joystick #5" },
+	{ SDLOPTION_JOYINDEX "6",                SDLOPTVAL_AUTO, 0,         "name of joystick mapped to joystick #6" },
+	{ SDLOPTION_JOYINDEX "7",                SDLOPTVAL_AUTO, 0,         "name of joystick mapped to joystick #7" },
+	{ SDLOPTION_JOYINDEX "8",                SDLOPTVAL_AUTO, 0,         "name of joystick mapped to joystick #8" },
+	{ SDLOPTION_SIXAXIS,			         "0",	 OPTION_BOOLEAN,    "Use special handling for PS3 Sixaxis controllers" },
+
+#if (SDL_VERSION_ATLEAST(1,3,0))
+	{ NULL, 		                         NULL,   OPTION_HEADER,     "SDL MOUSE MAPPING" },
+	{ SDLOPTION_MOUSEINDEX "1",              SDLOPTVAL_AUTO, 0,         "name of mouse mapped to mouse #1" },
+	{ SDLOPTION_MOUSEINDEX "2",              SDLOPTVAL_AUTO, 0,         "name of mouse mapped to mouse #2" },
+	{ SDLOPTION_MOUSEINDEX "3",              SDLOPTVAL_AUTO, 0,         "name of mouse mapped to mouse #3" },
+	{ SDLOPTION_MOUSEINDEX "4",              SDLOPTVAL_AUTO, 0,         "name of mouse mapped to mouse #4" },
+	{ SDLOPTION_MOUSEINDEX "5",              SDLOPTVAL_AUTO, 0,         "name of mouse mapped to mouse #5" },
+	{ SDLOPTION_MOUSEINDEX "6",              SDLOPTVAL_AUTO, 0,         "name of mouse mapped to mouse #6" },
+	{ SDLOPTION_MOUSEINDEX "7",              SDLOPTVAL_AUTO, 0,         "name of mouse mapped to mouse #7" },
+	{ SDLOPTION_MOUSEINDEX "8",              SDLOPTVAL_AUTO, 0,         "name of mouse mapped to mouse #8" },
+
+	{ NULL, 		                         NULL,   OPTION_HEADER,     "SDL KEYBOARD MAPPING" },
+	{ SDLOPTION_KEYBINDEX "1",               SDLOPTVAL_AUTO, 0,         "name of keyboard mapped to keyboard #1" },
+	{ SDLOPTION_KEYBINDEX "2",               SDLOPTVAL_AUTO, 0,         "name of keyboard mapped to keyboard #2" },
+	{ SDLOPTION_KEYBINDEX "3",               SDLOPTVAL_AUTO, 0,         "name of keyboard mapped to keyboard #3" },
+	{ SDLOPTION_KEYBINDEX "4",               SDLOPTVAL_AUTO, 0,         "name of keyboard mapped to keyboard #4" },
+	{ SDLOPTION_KEYBINDEX "5",               SDLOPTVAL_AUTO, 0,         "name of keyboard mapped to keyboard #5" },
+	{ SDLOPTION_KEYBINDEX "6",               SDLOPTVAL_AUTO, 0,         "name of keyboard mapped to keyboard #6" },
+	{ SDLOPTION_KEYBINDEX "7",               SDLOPTVAL_AUTO, 0,         "name of keyboard mapped to keyboard #7" },
+	{ SDLOPTION_KEYBINDEX "8",               SDLOPTVAL_AUTO, 0,         "name of keyboard mapped to keyboard #8" },
+#endif
+	// SDL low level driver options
+	{ NULL, 		                         NULL,   OPTION_HEADER,     "SDL LOWLEVEL DRIVER OPTIONS" },
+	{ SDLOPTION_VIDEODRIVER ";vd",           SDLOPTVAL_AUTO,  0,        "sdl video driver to use ('x11', 'directfb', ... or 'auto' for SDL default" },
+#if (SDL_VERSION_ATLEAST(1,3,0))
+	{ SDLOPTION_RENDERDRIVER ";rd",          SDLOPTVAL_AUTO,  0,        "sdl render driver to use ('software', 'opengl', 'directfb' ... or 'auto' for SDL default" },
+#endif
+	{ SDLOPTION_AUDIODRIVER ";ad",           SDLOPTVAL_AUTO,  0,        "sdl audio driver to use ('alsa', 'arts', ... or 'auto' for SDL default" },
+#if USE_OPENGL
+ 	{ SDLOPTION_GL_LIB,                      SDLOPTVAL_GLLIB, 0,        "alternative libGL.so to use; 'auto' for system default" },
+#endif
+
+	// End of list
 	{ NULL }
 };
 
-#ifdef MESS
-void sdl_mess_options_parse(void);
+#ifdef SDLMAME_WIN32
+
+/* mingw has no setenv */
+
+int setenv(const char *name, const char *value, int overwrite)
+{
+	char *buf;
+	int result;
+	
+	if (!overwrite)
+	{
+		if (getenv(name) != NULL)
+			return 0;
+	}
+	buf = malloc(strlen(name)+strlen(value)+2);
+	sprintf(buf, "%s=%s", name, value);
+	result = putenv(buf);
+	
+	/* will be referenced by environment 
+	 * Therefore it is not freed here
+	 */
+	
+	return result;
+}
+
 #endif
 
 //============================================================
@@ -217,7 +287,7 @@ static void ShowError(const char *title, const char *message)
 	fprintf(stderr, "%s: %s\n", title, message);
 }
 
-#ifdef SDLMAME_WIN32
+#if defined(SDLMAME_WIN32)
 int SDL_main(int argc, char **argv);
 
 static BOOL OutOfMemory(void)
@@ -230,9 +300,11 @@ int main(int argc, char *argv[])
 {
 	size_t n;
 	char *bufp, *appname;
+
 	int status;
 
 	/* Get the class name from argv[0] */
+
 	appname = argv[0];
 	if ( (bufp=SDL_strrchr(argv[0], '\\')) != NULL ) {
 		appname = bufp+1;
@@ -278,7 +350,7 @@ int main(int argc, char *argv[])
 }
 #endif
 
-#ifndef SDLMAME_WIN32
+#if !defined(SDLMAME_WIN32)
 int main(int argc, char **argv)
 #else
 int SDL_main(int argc, char **argv)
@@ -305,7 +377,7 @@ int SDL_main(int argc, char **argv)
 			char buf[130];
 			if (XMatchVisualInfo(display, DefaultScreen(display), 24, TrueColor, &vi)) {
 				snprintf(buf, sizeof(buf), "0x%lx", vi.visualid);
-				setenv(SDLENV_IDENTIFIER, buf, 0);
+				setenv(SDLENV_VISUALID, buf, 0);
 			}
 		}
 		if (display)
@@ -349,9 +421,8 @@ static void output_oslog(running_machine *machine, const char *buffer)
 static void osd_exit(running_machine *machine)
 {
 
-	#ifndef SDLMAME_WIN32
-	SDL_Quit();
-	#endif
+	if (!SDLMAME_INIT_IN_WORKER_THREAD)
+		SDL_Quit();
 }
 
 //============================================================
@@ -372,6 +443,7 @@ static void defines_verbose(void)
 	mame_printf_verbose("Build version:      %s\n", build_version);
 	mame_printf_verbose("Build architecure:  ");
 	MACRO_VERBOSE(SDLMAME_ARCH);
+	MACRO_VERBOSE(DISTRO);
 	mame_printf_verbose("\n");
 	mame_printf_verbose("Build defines:      ");
 	MACRO_VERBOSE(SDLMAME_UNIX);
@@ -388,7 +460,6 @@ static void defines_verbose(void)
 	MACRO_VERBOSE(PTR64);
 	MACRO_VERBOSE(MAME_DEBUG);
 	MACRO_VERBOSE(NDEBUG);
-	MACRO_VERBOSE(ENABLE_DEBUGGER);
 	MACRO_VERBOSE(VODOO_DRC);
 	mame_printf_verbose("\n");
 	mame_printf_verbose("SDL/OpenGL defines: ");
@@ -410,24 +481,134 @@ static void defines_verbose(void)
 	MACRO_VERBOSE(__ppc__);
 	MACRO_VERBOSE(__ppc64__);
 	mame_printf_verbose("\n");
+	mame_printf_verbose("Compiler defines C: ");
+	MACRO_VERBOSE(_FORTIFY_SOURCE);
+	MACRO_VERBOSE(__USE_FORTIFY_LEVEL);
+	mame_printf_verbose("\n");
 }
 
+//============================================================
+//	osd_sdl_info
+//============================================================
+
+static void osd_sdl_info(void)
+{
+#if SDL_VERSION_ATLEAST(1,3,0)
+	int i, cur, num = SDL_GetNumVideoDrivers();
+	
+	mame_printf_verbose("Available videodrivers: ");
+	for (i=0;i<num;i++)
+	{
+		const char *name = SDL_GetVideoDriver(i);
+		mame_printf_verbose("%s ", name);
+	}
+	mame_printf_verbose("\n");
+	mame_printf_verbose("Current Videodriver: %s\n", SDL_GetCurrentVideoDriver());
+	num = SDL_GetNumVideoDisplays();
+	cur = SDL_GetCurrentVideoDisplay();
+	for (i=0;i<num;i++)
+	{
+		SDL_DisplayMode mode;
+		int j;
+		
+		SDL_SelectVideoDisplay(i);
+		mame_printf_verbose("\tDisplay #%d\n", i);
+		if (SDL_GetDesktopDisplayMode(&mode));
+			mame_printf_verbose("\t\tDesktop Mode:         %dx%d-%d@%d\n", mode.w, mode.h, SDL_BITSPERPIXEL(mode.format), mode.refresh_rate);
+		if (SDL_GetFullscreenDisplayMode(&mode));
+			mame_printf_verbose("\t\tFullscreen Mode:      %dx%d-%d@%d\n", mode.w, mode.h, SDL_BITSPERPIXEL(mode.format), mode.refresh_rate);
+		if (SDL_GetCurrentDisplayMode(&mode));
+			mame_printf_verbose("\t\tCurrent Display Mode: %dx%d-%d@%d\n", mode.w, mode.h, SDL_BITSPERPIXEL(mode.format), mode.refresh_rate);
+		mame_printf_verbose("\t\tRenderdrivers:\n");
+		for (j=0; j<SDL_GetNumRenderDrivers(); j++)
+		{
+			SDL_RendererInfo info;
+			SDL_GetRenderDriverInfo(j, &info);
+			mame_printf_verbose("\t\t\t%10s (%dx%d)\n", info.name, info.max_texture_width, info.max_texture_height);
+		}
+	}
+	SDL_SelectVideoDisplay(cur);
+
+	mame_printf_verbose("Available audio drivers: \n");
+	num = SDL_GetNumAudioDrivers();
+	for (i=0;i<num;i++)
+	{
+		mame_printf_verbose("\t%-20s\n", SDL_GetAudioDriver(i));
+	}
+#endif
+}
+
+
 //============================================================
 //	osd_init
 //============================================================
+
 void osd_init(running_machine *machine)
 {
-	#ifndef SDLMAME_WIN32
-	if (SDL_Init(SDL_INIT_TIMER|SDL_INIT_AUDIO| SDL_INIT_VIDEO| SDL_INIT_JOYSTICK|SDL_INIT_NOPARACHUTE)) {
-		/* mame_printf_* not fully initialized yet */
-		ShowError("Could not initialize SDL: %s.\n", SDL_GetError());
-		exit(-1);
+	const char *stemp;
+
+	// Some driver options - must be before audio init!
+	stemp = options_get_string(mame_options(), SDLOPTION_AUDIODRIVER);
+	if (stemp != NULL && strcmp(stemp, SDLOPTVAL_AUTO) != 0)
+	{
+		mame_printf_verbose("Setting SDL audiodriver '%s' ...\n", stemp);
+		setenv(SDLENV_AUDIODRIVER, stemp, 1);
+	}
+
+	stemp = options_get_string(mame_options(), SDLOPTION_VIDEODRIVER);
+	if (stemp != NULL && strcmp(stemp, SDLOPTVAL_AUTO) != 0)
+	{
+		mame_printf_verbose("Setting SDL videodriver '%s' ...\n", stemp);
+		setenv(SDLENV_VIDEODRIVER, stemp, 1);
+	}
+
+	if (SDL_VERSION_ATLEAST(1,3,0))
+	{
+		stemp = options_get_string(mame_options(), SDLOPTION_RENDERDRIVER);
+		if (stemp != NULL && strcmp(stemp, SDLOPTVAL_AUTO) != 0)
+		{
+			mame_printf_verbose("Setting SDL renderdriver '%s' ...\n", stemp);
+			setenv(SDLENV_RENDERDRIVER, stemp, 1);
+		}
+	}
+
+	/* Set the SDL environment variable for drivers wanting to load the
+	 * lib at startup.
+	 */
+	/* FIXME: move lib loading code from drawogl.c here */
+
+	stemp = options_get_string(mame_options(), SDLOPTION_GL_LIB);
+	if (stemp != NULL && strcmp(stemp, SDLOPTVAL_AUTO) != 0)
+	{
+		setenv("SDL_VIDEO_GL_DRIVER", stemp, 1);
+		mame_printf_verbose("Setting SDL_VIDEO_GL_DRIVER = '%s' ...\n", stemp);
+	}
+	
+	if (!SDLMAME_INIT_IN_WORKER_THREAD)
+	{
+#if (SDL_VERSION_ATLEAST(1,3,0))
+		if (SDL_InitSubSystem(SDL_INIT_TIMER|SDL_INIT_AUDIO| SDL_INIT_VIDEO| SDL_INIT_JOYSTICK|SDL_INIT_NOPARACHUTE)) {
+#else
+		if (SDL_Init(SDL_INIT_TIMER|SDL_INIT_AUDIO| SDL_INIT_VIDEO| SDL_INIT_JOYSTICK|SDL_INIT_NOPARACHUTE)) {
+#endif
+			/* mame_printf_* not fully initialized yet */
+			ShowError("Could not initialize SDL", SDL_GetError());
+			exit(-1);
+		}
+		osd_sdl_info();
 	}
-	#endif
 	// must be before sdlvideo_init!
 	add_exit_callback(machine, osd_exit);
 
 	defines_verbose();
+
+	if (!SDLMAME_HAS_DEBUGGER)
+		if (options_get_bool(mame_options(), OPTION_DEBUG))
+		{
+			osd_exit(machine);
+			ShowError("sdlmame", "-debug not supported on X11-less builds\n\n");
+			exit(-1);		
+		}
 	
 	if (sdlvideo_init(machine))
 	{
@@ -437,22 +618,21 @@ void osd_init(running_machine *machine)
 		fflush(stdout);
 		exit(-1);
 	}
-	if (sdl_use_unsupported())
-		sdlled_init();
-
-	#ifdef MESS
-	sdl_mess_options_parse();
-	#endif
 
 	sdlinput_init(machine);
+	
 	sdlaudio_init(machine);
 
+	sdloutput_init(machine);
+	
 	if (options_get_bool(mame_options(), SDLOPTION_OSLOG))
 		add_logerror_callback(machine, output_oslog);
 
-	#ifdef MESS
-	SDL_EnableUNICODE(1);
-	#endif
+#if (SDL_VERSION_ATLEAST(1,3,0))
+	SDL_EventState(SDL_TEXTINPUT, SDL_TRUE);
+#else
+	SDL_EnableUNICODE(SDL_TRUE);
+#endif
 }
 
 #ifdef MESS
