@@ -12,8 +12,6 @@
 // MinGW does not have pthreads, defer to Aaron's implementation on that platform
 #if defined(SDLMAME_WIN32)
 #include "../windows/winwork.c"
-#elif defined(SDLMAME_OS2)	// use separate OS/2 implementation
-#include "os2work.c"
 #else
 
 #include "osdcore.h"
@@ -34,15 +32,21 @@
 
 #define KEEP_STATISTICS			(0)
 
-
-
 //============================================================
 //  PARAMETERS
 //============================================================
 
-#define INFINITE				(osd_ticks_per_second()*10000)
-#define SPIN_LOOP_TIME			(osd_ticks_per_second() / 1000)
+#define SDLENV_PROCESSORS				"OSDPROCESSORS"
+#define SDLENV_CPUMASKS					"OSDCPUMASKS"
 
+#define INFINITE				(osd_ticks_per_second() *  (osd_ticks_t) 10000)
+#ifndef NO_THREAD_COOPERATIVE
+//FIXME: depends on <THREADS>/<PHYS PROCESSORS>
+#define SPIN_LOOP_TIME			(osd_ticks_per_second() / 10000)
+//#define SPIN_LOOP_TIME			((osd_ticks_t) 0)
+#else
+#define SPIN_LOOP_TIME			(osd_ticks_per_second() / 1000)
+#endif
 
 
 //============================================================
@@ -68,12 +72,16 @@
 typedef struct _scalable_lock scalable_lock;
 struct _scalable_lock
 {
-   struct
-   {
-      volatile INT32 	haslock;		// do we have the lock?
-      INT32 			filler[64/4-1];	// assumes a 64-byte cache line
-   } slot[WORK_MAX_THREADS];			// one slot per thread
-   volatile INT32 		nextindex;		// index of next slot to use
+#ifndef NO_THREAD_COOPERATIVE
+	osd_lock			*lock;
+#else
+	struct
+	{
+		volatile INT32 	haslock;		// do we have the lock?
+		INT32 			filler[64/4-1];	// assumes a 64-byte cache line
+	} slot[WORK_MAX_THREADS];			// one slot per thread
+	volatile INT32 		nextindex;		// index of next slot to use
+#endif
 };
 
 
@@ -138,6 +146,9 @@ typedef void *PVOID;
 //============================================================
 
 static int effective_num_processors(void);
+#ifndef NO_THREAD_COOPERATIVE
+static UINT32 effective_cpu_mask(int index);
+#endif
 static void * worker_thread_entry(void *param);
 static void worker_thread_process(osd_work_queue *queue, work_thread_info *thread);
 
@@ -175,13 +186,21 @@ INLINE INT32 interlocked_add(INT32 volatile *ptr, INT32 add)
 
 INLINE void scalable_lock_init(scalable_lock *lock)
 {
+#ifndef NO_THREAD_COOPERATIVE
+	lock->lock = osd_lock_alloc();
+#else
 	memset(lock, 0, sizeof(*lock));
 	lock->slot[0].haslock = TRUE;
+#endif
 }
 
 
 INLINE INT32 scalable_lock_acquire(scalable_lock *lock)
 {
+#ifndef NO_THREAD_COOPERATIVE
+	osd_lock_acquire(lock->lock);
+	return 0;
+#else
 	INT32 myslot = (atomic_increment32(&lock->nextindex) - 1) & (WORK_MAX_THREADS - 1);
 
 #if defined(__i386__) || defined(__x86_64__)
@@ -234,11 +253,16 @@ INLINE INT32 scalable_lock_acquire(scalable_lock *lock)
 	}
 #endif
 	return myslot;
+#endif
 }
 
 
 INLINE void scalable_lock_release(scalable_lock *lock, INT32 myslot)
 {
+#ifndef NO_THREAD_COOPERATIVE
+	osd_lock_release(lock->lock);
+	return;
+#else
 #if defined(__i386__) || defined(__x86_64__)
 	register INT32 tmp = TRUE;
 	__asm__ __volatile__ (
@@ -253,8 +277,17 @@ INLINE void scalable_lock_release(scalable_lock *lock, INT32 myslot)
 #else
 	osd_exchange32(&lock->slot[(myslot + 1) & (WORK_MAX_THREADS - 1)].haslock, TRUE);
 #endif
+#endif
 }
 
+INLINE void scalable_lock_free(scalable_lock *lock)
+{
+#ifndef NO_THREAD_COOPERATIVE
+	osd_lock_free(lock->lock);
+#endif
+}
+
+
 
 //============================================================
 //  osd_work_queue_alloc
@@ -326,6 +359,16 @@ osd_work_queue *osd_work_queue_alloc(int flags)
 			osd_thread_adjust_priority(thread->handle, 0);	// TODO: specify appropriate priority
 		else
 			osd_thread_adjust_priority(thread->handle, 0);	// TODO: specify appropriate priority
+
+#ifndef NO_THREAD_COOPERATIVE
+		// Bind main thread to cpu 0
+		osd_thread_cpu_affinity(NULL, effective_cpu_mask(0));
+		
+		if (flags & WORK_QUEUE_FLAG_IO)
+			osd_thread_cpu_affinity(thread->handle, effective_cpu_mask(1));
+		else
+			osd_thread_cpu_affinity(thread->handle, effective_cpu_mask(2+threadnum) );
+#endif
 	}
 
 	// start a timer going for "waittime" on the main thread
@@ -380,7 +423,11 @@ int osd_work_queue_wait(osd_work_queue *queue, osd_ticks_t timeout)
 			// spin until we're done
 			begin_timing(thread->spintime);
 			while (queue->items != 0 && osd_ticks() < stopspin)
-				osd_yield_processor();
+			{
+				int spin = 10000;
+				while (--spin && queue->items != 0)
+					osd_yield_processor();
+			}
 			end_timing(thread->spintime);
 
 			begin_timing(thread->waittime);
@@ -455,11 +502,12 @@ void osd_work_queue_free(osd_work_queue *queue)
 					(UINT32) total);
 		}
 #endif
-
-		// free the list
-		free(queue->thread);
 	}
 
+	// free the list
+	if (queue->thread != NULL)
+		free(queue->thread);
+
 	// free all the events
 	if (queue->doneevent != NULL)
 		osd_event_free(queue->doneevent);
@@ -491,6 +539,7 @@ void osd_work_queue_free(osd_work_queue *queue)
 	printf("Spin loops     = %9d\n", queue->spinloops);
 #endif
 
+	scalable_lock_free(&queue->lock);
 	// free the queue itself
 	free(queue);
 }
@@ -502,7 +551,7 @@ void osd_work_queue_free(osd_work_queue *queue)
 
 osd_work_item *osd_work_item_queue_multiple(osd_work_queue *queue, osd_work_callback callback, INT32 numitems, void *parambase, INT32 paramstep, UINT32 flags)
 {
-	osd_work_item *itemlist = NULL;
+	osd_work_item *itemlist = NULL, *lastitem = NULL;
 	osd_work_item **item_tailptr = &itemlist;
 	INT32 lockslot;
 	int itemnum;
@@ -538,6 +587,7 @@ osd_work_item *osd_work_item_queue_multiple(osd_work_queue *queue, osd_work_call
 		item->done = FALSE;
 
 		// advance to the next
+		lastitem = item;
 		*item_tailptr = item;
 		item_tailptr = &item->next;
 	}
@@ -583,7 +633,8 @@ osd_work_item *osd_work_item_queue_multiple(osd_work_queue *queue, osd_work_call
 		begin_timing(queue->thread[0].waittime);
 	}
 	// only return the item if it won't get released automatically
-	return (flags & WORK_ITEM_FLAG_AUTO_RELEASE) ? NULL : itemlist;
+	return (flags & WORK_ITEM_FLAG_AUTO_RELEASE) ? NULL : lastitem;
+	//return (flags & WORK_ITEM_FLAG_AUTO_RELEASE) ? NULL : itemlist;
 }
 
 
@@ -604,6 +655,7 @@ int osd_work_item_wait(osd_work_item *item, osd_ticks_t timeout)
 		 osd_event_reset(item->event);
 
 	// if we don't have an event, we need to spin (shouldn't ever really happen)
+	// FIXME: there is still a bug in winwork.c. The following is OK.
 	if (item->event == NULL)
 	{
 		osd_ticks_t stopspin = osd_ticks() + timeout;
@@ -660,7 +712,7 @@ static int effective_num_processors(void)
 	int numprocs = 0;
 
 	// if the OSDPROCESSORS environment variable is set, use that value if valid
-	procsoverride = getenv("OSDPROCESSORS");
+	procsoverride = getenv(SDLENV_PROCESSORS);
 	if (procsoverride != NULL && sscanf(procsoverride, "%d", &numprocs) == 1 && numprocs > 0)
 		return numprocs;
 
@@ -668,6 +720,45 @@ static int effective_num_processors(void)
 	return osd_num_processors();
 }
 
+//============================================================
+//  effective_cpu_mask
+//============================================================
+
+#ifndef NO_THREAD_COOPERATIVE
+static UINT32 effective_cpu_mask(int index)
+{
+	char 	*s;
+	char	buf[5];
+	UINT32	mask = 0xFFFF;
+
+	s = getenv(SDLENV_CPUMASKS);
+	if (s != NULL && strcmp(s,"none"))
+	{
+		if (!strcmp(s,"auto"))
+		{
+			if (index<2)
+				mask = 0x01; /* main thread and io threads on cpu #0 */
+			else
+				mask = (1 << (((index - 1) % (osd_num_processors() - 1)) + 1));
+		}
+		else
+		{
+			if (strlen(s) % 4 != 0 || strlen(s) < (index+1)*4)
+			{
+				fprintf(stderr,"Invalid cpu mask: %s\n", s);
+			}
+			else
+			{
+				memcpy(buf,s+4*index,4);
+				buf[4] = 0;
+				if (sscanf(buf, "%x", &mask) != 1)
+					fprintf(stderr,"Invalid cpu mask element %d: %s\n", index, buf);
+			}
+		}
+	}
+	return mask;
+}
+#endif
 
 //============================================================
 //  worker_thread_entry
@@ -711,7 +802,11 @@ static void *worker_thread_entry(void *param)
 				begin_timing(thread->spintime);
 				stopspin = osd_ticks() + SPIN_LOOP_TIME;
 				while (queue->list == NULL && osd_ticks() < stopspin)
-					osd_yield_processor();
+				{
+					int spin = 10000;
+					while (--spin && queue->list == NULL)
+						osd_yield_processor();
+				}
 				end_timing(thread->spintime);
 			}
 
