@@ -49,6 +49,7 @@
 #include "video.h"
 #include "window.h"
 #include "input.h"
+#include "uiinput.h"
 
 #include "osdsdl.h"
 
@@ -62,9 +63,6 @@
 //  CONSTANTS
 //============================================================
 
-// refresh rate while paused
-#define PAUSED_REFRESH_RATE			(60)
-
 
 //============================================================
 //  GLOBAL VARIABLES
@@ -85,7 +83,7 @@ osd_gl_dispatch *gl_dispatch;
 static sdl_monitor_info *primary_monitor;
 static sdl_monitor_info *sdl_monitor_list;
 
-static mame_bitmap *effect_bitmap;
+static bitmap_t *effect_bitmap;
 
 //============================================================
 //  PROTOTYPES
@@ -95,7 +93,7 @@ static void video_exit(running_machine *machine);
 static void init_monitors(void);
 static sdl_monitor_info *pick_monitor(int index);
 
-static void check_osd_inputs(void);
+static void check_osd_inputs(running_machine *machine);
 
 static void extract_video_config(running_machine *machine);
 static void load_effect_overlay(running_machine *machine, const char *filename);
@@ -113,7 +111,7 @@ int sdlvideo_init(running_machine *machine)
 
 	// extract data from the options
 	extract_video_config(machine);
-	
+
 	// ensure we get called on the way out
 	add_exit_callback(machine, video_exit);
 
@@ -123,7 +121,7 @@ int sdlvideo_init(running_machine *machine)
 	// we need the beam width in a float, contrary to what the core does.
 	video_config.beamwidth = options_get_float(mame_options(), OPTION_BEAM);
 
-	if (machine->drv->video_attributes & VIDEO_TYPE_VECTOR)
+	if (machine->config->video_attributes & SCREEN_TYPE_VECTOR)
 	{
 		video_config.isvector = 1;
 	}
@@ -136,7 +134,7 @@ int sdlvideo_init(running_machine *machine)
 	if (sdlwindow_init(machine))
 		goto error;
 
-	tc = machine->drv->total_colors;
+	tc = machine->config->total_colors;
 
 	// create the windows
 	for (index = 0; index < video_config.numscreens; index++)
@@ -173,43 +171,29 @@ static void video_exit(running_machine *machine)
 		free(temp);
 	}
 
-#if USE_OPENGL
-	{
-		int i;
-
-		for(i=0; i<video_config.glsl_shader_mamebm_num; i++)
-		{
-			if ( NULL!=video_config.glsl_shader_mamebm[i])
-			{
-				free(video_config.glsl_shader_mamebm[i]);
-				video_config.glsl_shader_mamebm[i] = NULL;
-			}
-		}
-		for(i=0; i<video_config.glsl_shader_scrn_num; i++)
-		{
-			if ( NULL!=video_config.glsl_shader_scrn[i])
-			{
-				free(video_config.glsl_shader_scrn[i]);
-				video_config.glsl_shader_scrn[i] = NULL;
-			}
-		}
-	}
-#endif
-	
 }
 
 
-
 //============================================================
 //  sdlvideo_monitor_refresh
 //============================================================
 
 void sdlvideo_monitor_refresh(sdl_monitor_info *monitor)
 {
+	#if (SDL_VERSION_ATLEAST(1,3,0))
+	SDL_DisplayMode dmode;
+	
+	SDL_SelectVideoDisplay(monitor->handle);
+	SDL_GetDesktopDisplayMode(&dmode);
+	monitor->monitor_width = dmode.w;
+	monitor->monitor_height = dmode.h;
+	monitor->center_width = dmode.w;
+	monitor->center_height = dmode.h;
+	#else
 	#if defined(SDLMAME_WIN32)	// Win32 version
 	MONITORINFOEX info;
 	info.cbSize = sizeof(info);	
-        GetMonitorInfo((HMONITOR)monitor->handle, (LPMONITORINFO)&info);
+    GetMonitorInfo((HMONITOR)monitor->handle, (LPMONITORINFO)&info);
 	monitor->center_width = monitor->monitor_width = info.rcMonitor.right - info.rcMonitor.left;
 	monitor->center_height = monitor->monitor_height = info.rcMonitor.bottom - info.rcMonitor.top;
 	strcpy(monitor->monitor_device, info.szDevice);
@@ -227,8 +211,6 @@ void sdlvideo_monitor_refresh(sdl_monitor_info *monitor)
     #elif defined(SDLMAME_X11) || defined(SDLMAME_NO_X11)       // X11 version
 	{
 		#if defined(SDLMAME_X11)
-		//FIXME: The code below fails for SDL1.3
-		#if (SDL_VERSIONNUM(SDL_MAJOR_VERSION, SDL_MINOR_VERSION, SDL_PATCHLEVEL) < 1300)
 		// X11 version
 		int screen;
 		SDL_SysWMinfo info;
@@ -260,8 +242,7 @@ void sdlvideo_monitor_refresh(sdl_monitor_info *monitor)
 			}
 		}
  		else
-		#endif
- 		#endif
+		#endif // defined(SDLMAME_X11)
 		{
 			static int first_call=0;
 			static int cw, ch;
@@ -273,13 +254,10 @@ void sdlvideo_monitor_refresh(sdl_monitor_info *monitor)
 				const SDL_VideoInfo *sdl_vi;
 				
 				sdl_vi = SDL_GetVideoInfo();
-				#if (SDL_VERSIONNUM(SDL_MAJOR_VERSION, SDL_MINOR_VERSION, SDL_PATCHLEVEL) >= 1210)
-				//FIXME: File a bug for SDL 1.3
-				#if (SDL_VERSIONNUM(SDL_MAJOR_VERSION, SDL_MINOR_VERSION, SDL_PATCHLEVEL) < 1300)
+				#if (SDL_VERSION_ATLEAST(1,2,10))
 				cw = sdl_vi->current_w;
 				ch = sdl_vi->current_h;
 				#endif
-				#endif
 				first_call=1;
 				if ((cw==0) || (ch==0))
 				{
@@ -321,6 +299,7 @@ void sdlvideo_monitor_refresh(sdl_monitor_info *monitor)
 			info_shown = 1;
 		}
 	}
+	#endif //  (SDL_VERSION_ATLEAST(1,3,0))
 }
 
 
@@ -357,11 +336,12 @@ sdl_monitor_info *sdlvideo_monitor_from_handle(UINT32 hmonitor)
 	return NULL;
 }
 
+
 //============================================================
 //  osd_update
 //============================================================
 
-void osd_update(int skip_redraw)
+void osd_update(running_machine *machine, int skip_redraw)
 {
 	sdl_window_info *window;
 
@@ -370,23 +350,24 @@ void osd_update(int skip_redraw)
 	{
 		profiler_mark(PROFILER_BLIT);
 		for (window = sdl_window_list; window != NULL; window = window->next)
-			sdlwindow_video_window_update(window);
+			sdlwindow_video_window_update(machine, window);
 		profiler_mark(PROFILER_END);
 	}
 
 	// poll the joystick values here
-	sdlinput_poll();
-	check_osd_inputs();
+	sdlinput_poll(machine);
+	check_osd_inputs(machine);
 
-#ifdef ENABLE_DEBUGGER
-	debugwin_update_during_game();
-#endif
+	if (machine->debug_flags & DEBUG_FLAG_ENABLED)
+		debugwin_update_during_game(machine);
 }
 
+
 //============================================================
 //  add_primary_monitor
 //============================================================
-#ifndef SDLMAME_WIN32
+
+#if !defined(SDLMAME_WIN32) && !(SDL_VERSION_ATLEAST(1,3,0))
 static void add_primary_monitor(void *data)
 {
 	sdl_monitor_info ***tailptr = (sdl_monitor_info ***)data;
@@ -413,10 +394,12 @@ static void add_primary_monitor(void *data)
 } 
 #endif
 
+
 //============================================================
 //  monitor_enum_callback
 //============================================================
-#ifdef SDLMAME_WIN32
+
+#if defined(SDLMAME_WIN32) && !(SDL_VERSION_ATLEAST(1,3,0))
 static BOOL CALLBACK monitor_enum_callback(HMONITOR handle, HDC dc, LPRECT rect, LPARAM data)
 {
 	sdl_monitor_info ***tailptr = (sdl_monitor_info ***)data;
@@ -434,14 +417,19 @@ static BOOL CALLBACK monitor_enum_callback(HMONITOR handle, HDC dc, LPRECT rect,
 	memset(monitor, 0, sizeof(*monitor));
 
 	// copy in the data
-        monitor->handle = (UINT32)handle;
+    monitor->handle = (UINT32)handle;
 	monitor->monitor_width = info.rcMonitor.right - info.rcMonitor.left;
 	monitor->monitor_height = info.rcMonitor.bottom - info.rcMonitor.top;
 	strcpy(monitor->monitor_device, info.szDevice);
 
 	// guess the aspect ratio assuming square pixels
 	monitor->aspect = (float)(info.rcMonitor.right - info.rcMonitor.left) / (float)(info.rcMonitor.bottom - info.rcMonitor.top);
-
+	
+	// SDL will crash if monitors are queried here
+	// This will be done in window.c (Ughh, ugly)
+	
+	monitor->modes = NULL;
+	
 	// save the primary monitor handle
 	if (info.dwFlags & MONITORINFOF_PRIMARY)
 		primary_monitor = monitor;
@@ -455,6 +443,7 @@ static BOOL CALLBACK monitor_enum_callback(HMONITOR handle, HDC dc, LPRECT rect,
 }
 #endif
 
+
 //============================================================
 //  init_monitors
 //============================================================
@@ -467,42 +456,78 @@ static void init_monitors(void)
 	sdl_monitor_list = NULL;
 	tailptr = &sdl_monitor_list;
 
-	#ifdef SDLMAME_WIN32
+	#if (SDL_VERSION_ATLEAST(1,3,0))
+	{
+		int i, temp;
+
+		temp = SDL_GetCurrentVideoDisplay();
+
+		for (i = 0; i < SDL_GetNumVideoDisplays(); i++)
+		{
+			sdl_monitor_info *monitor;
+	 		SDL_DisplayMode dmode;
+
+			// allocate a new monitor info
+			monitor = malloc_or_die(sizeof(*monitor));
+			memset(monitor, 0, sizeof(*monitor));
+
+			snprintf(monitor->monitor_device, sizeof(monitor->monitor_device)-1, "%s%d", SDLOPTION_SCREEN(""),i);
+	 	
+			SDL_SelectVideoDisplay(i);
+			SDL_GetDesktopDisplayMode(&dmode);
+			monitor->monitor_width = dmode.w;
+			monitor->monitor_height = dmode.h;
+			monitor->center_width = dmode.w;
+			monitor->center_height = dmode.h;
+	        monitor->handle = i;
+	        // guess the aspect ratio assuming square pixels
+	        monitor->aspect = (float)(dmode.w) / (float)(dmode.h);
+	        mame_printf_verbose("Adding monitor %s (%d x %d)\n", monitor->monitor_device, dmode.w, dmode.h);
+
+	        // save the primary monitor handle
+	        if (i == 0)
+	        	primary_monitor = monitor;
+
+			// hook us into the list
+			*tailptr = monitor;
+			tailptr = &monitor->next;
+		}
+		SDL_SelectVideoDisplay(temp);
+	}
+	#elif defined(SDLMAME_WIN32)
 	EnumDisplayMonitors(NULL, NULL, monitor_enum_callback, (LPARAM)&tailptr);
 	#else
 	add_primary_monitor((void *)&tailptr);
+	sdl_monitor_list->modes = SDL_ListModes(NULL, SDL_FULLSCREEN | SDL_DOUBLEBUF);
 	#endif
 }
 
+
 //============================================================
 //  pick_monitor
 //============================================================
 
+#if (SDL_VERSION_ATLEAST(1,3,0)) || defined(SDLMAME_WIN32)
 static sdl_monitor_info *pick_monitor(int index)
 {
 	sdl_monitor_info *monitor;
-	#if SDL_MULTIMON || defined(SDLMAME_WIN32)
 	const char *scrname;
 	int moncount = 0;
-	#endif
 	char option[20];
 	float aspect;
 
 	// get the screen option
-	#if SDL_MULTIMON || defined(SDLMAME_WIN32)
 	sprintf(option, SDLOPTION_SCREEN("%d"), index);
 	scrname = options_get_string(mame_options(), option);
-	#endif
 
 	// get the aspect ratio
 	sprintf(option, SDLOPTION_ASPECT("%d"), index);
 	aspect = get_aspect(option, TRUE);
 
 	// look for a match in the name first
-	#if SDL_MULTIMON || defined(SDLMAME_WIN32)
 	if (scrname != NULL)
-                for (monitor = sdl_monitor_list; monitor != NULL; monitor = monitor->next)
-		{
+		for (monitor = sdl_monitor_list; monitor != NULL; monitor = monitor->next)
+		{	
 			moncount++;
 			if (strcmp(scrname, monitor->monitor_device) == 0)
 				goto finishit;
@@ -510,72 +535,96 @@ static sdl_monitor_info *pick_monitor(int index)
 
 	// didn't find it; alternate monitors until we hit the jackpot
 	index %= moncount;
-        for (monitor = sdl_monitor_list; monitor != NULL; monitor = monitor->next)
+    for (monitor = sdl_monitor_list; monitor != NULL; monitor = monitor->next)
 		if (index-- == 0)
 			goto finishit;
-	#endif
 
 	// return the primary just in case all else fails
 	monitor = primary_monitor;
 
-#if SDL_MULTIMON || defined(SDLMAME_WIN32)
 finishit:
-#endif
 	if (aspect != 0)
 	{
 		monitor->aspect = aspect;
 	}
 	return monitor;
 }
+#else
+static sdl_monitor_info *pick_monitor(int index)
+{
+	sdl_monitor_info *monitor;
+	char option[20];
+	float aspect;
+
+	// get the aspect ratio
+	sprintf(option, SDLOPTION_ASPECT("%d"), index);
+	aspect = get_aspect(option, TRUE);
+
+	// return the primary just in case all else fails
+	monitor = primary_monitor;
+
+	if (aspect != 0)
+	{
+		monitor->aspect = aspect;
+	}
+	return monitor;
+}
+#endif
+
 
 //============================================================
 //  check_osd_inputs
 //============================================================
 
-static void check_osd_inputs(void)
+static void check_osd_inputs(running_machine *machine)
 {
+	sdl_window_info *window = sdlinput_get_focus_window(machine);
+
 	// check for toggling fullscreen mode
-	if (input_ui_pressed(IPT_OSD_1))
-		sdlwindow_toggle_full_screen();
+	if (ui_input_pressed(machine, IPT_OSD_1))
+		sdlwindow_toggle_full_screen(machine, window);
 	
-	if (input_ui_pressed(IPT_OSD_2))
+	if (ui_input_pressed(machine, IPT_OSD_2))
 	{
+		//FIXME: on a per window basis
 		video_config.fullstretch = !video_config.fullstretch;
 		ui_popup_time(1, "Uneven stretch %s", video_config.fullstretch? "enabled":"disabled");
 	}
 	
-	if (input_ui_pressed(IPT_OSD_4))
+	if (ui_input_pressed(machine, IPT_OSD_4))
 	{
+		//FIXME: on a per window basis
 		video_config.keepaspect = !video_config.keepaspect;
 		ui_popup_time(1, "Keepaspect %s", video_config.keepaspect? "enabled":"disabled");
 	}
 	
-#if USE_OPENGL
-	if (input_ui_pressed(IPT_OSD_5))
+	if (USE_OPENGL || SDL_VERSION_ATLEAST(1,3,0))
 	{
-		video_config.filter = !video_config.filter;
-		ui_popup_time(1, "Filter %s", video_config.filter? "enabled":"disabled");
+		//FIXME: on a per window basis
+		if (ui_input_pressed(machine, IPT_OSD_5))
+		{
+			video_config.filter = !video_config.filter;
+			ui_popup_time(1, "Filter %s", video_config.filter? "enabled":"disabled");
+		}
 	}
-#endif
 
-	if (input_ui_pressed(IPT_OSD_6))
-		sdlwindow_modify_prescale(-1);
+	if (ui_input_pressed(machine, IPT_OSD_6))
+		sdlwindow_modify_prescale(machine, window, -1);
 
-	if (input_ui_pressed(IPT_OSD_7))
-		sdlwindow_modify_prescale(1);
+	if (ui_input_pressed(machine, IPT_OSD_7))
+		sdlwindow_modify_prescale(machine, window, 1);
 
-	if (input_ui_pressed(IPT_OSD_8))
-		sdlwindow_modify_effect(-1);
+	if (ui_input_pressed(machine, IPT_OSD_8))
+		sdlwindow_modify_effect(machine, window, -1);
 
-	if (input_ui_pressed(IPT_OSD_9))
-		sdlwindow_modify_effect(1);
+	if (ui_input_pressed(machine, IPT_OSD_9))
+		sdlwindow_modify_effect(machine, window, 1);
 
-	if (input_ui_pressed(IPT_OSD_10))
-		sdlwindow_toggle_draw();
+	if (ui_input_pressed(machine, IPT_OSD_10))
+		sdlwindow_toggle_draw(machine, window);
 }
 
 
-
 //============================================================
 //  extract_video_config
 //============================================================
@@ -596,11 +645,9 @@ static void extract_video_config(running_machine *machine)
 	#endif
 
 
-#ifdef ENABLE_DEBUGGER
-	// if we are in debug mode, never go full screen
 	if (options_get_bool(mame_options(), OPTION_DEBUG))
 		video_config.windowed = TRUE;
-#endif
+
 	stemp = options_get_string(mame_options(), SDLOPTION_EFFECT);
 	if (stemp != NULL && strcmp(stemp, "none") != 0)
 		load_effect_overlay(machine, stemp);
@@ -626,15 +673,18 @@ static void extract_video_config(running_machine *machine)
 		if (options_get_int(mame_options(), OPTION_SECONDS_TO_RUN) == 0)
 			mame_printf_warning("Warning: -video none doesn't make much sense without -seconds_to_run\n");
 	}
-#if USE_OPENGL
-	else if (strcmp(stemp, SDLOPTVAL_OPENGL) == 0)
+	else if (USE_OPENGL && (strcmp(stemp, SDLOPTVAL_OPENGL) == 0))
 		video_config.mode = VIDEO_MODE_OPENGL;
-	else if (strcmp(stemp, SDLOPTVAL_OPENGL16) == 0)
+	else if (USE_OPENGL && (strcmp(stemp, SDLOPTVAL_OPENGL16) == 0))
 	{
  		video_config.mode = VIDEO_MODE_OPENGL;
  		video_config.prefer16bpp_tex = 1;
 	}
-#endif
+	else if (SDL_VERSION_ATLEAST(1,3,0) && (strcmp(stemp, SDLOPTVAL_SDL13) == 0))
+	{
+ 		video_config.mode = VIDEO_MODE_SDL13;
+ 		video_config.prefer16bpp_tex = 1;
+	}
 	else
 	{
 		mame_printf_warning("Invalid video value %s; reverting to software\n", stemp);
@@ -644,127 +694,131 @@ static void extract_video_config(running_machine *machine)
 	video_config.switchres     = options_get_bool(mame_options(), SDLOPTION_SWITCHRES);
 	video_config.centerh       = options_get_bool(mame_options(), SDLOPTION_CENTERH);
 	video_config.centerv       = options_get_bool(mame_options(), SDLOPTION_CENTERV);
+	video_config.waitvsync     = options_get_bool(mame_options(), SDLOPTION_WAITVSYNC);
 
-#if USE_OPENGL
-	video_config.prescale      = options_get_int(mame_options(), SDLOPTION_PRESCALE);
-	if (video_config.prescale < 1 || video_config.prescale > 3)
+	if (USE_OPENGL || SDL_VERSION_ATLEAST(1,3,0))
 	{
-		mame_printf_warning("Invalid prescale option, reverting to '1'\n");
-		video_config.prescale = 1;
+		video_config.filter        = options_get_bool(mame_options(), SDLOPTION_FILTER);
 	}
-	// default to working video please
-	video_config.prefer16bpp_tex = 0;
-	video_config.filter        = options_get_bool(mame_options(), SDLOPTION_FILTER);
-	video_config.forcepow2texture = options_get_bool(mame_options(), SDLOPTION_GL_FORCEPOW2TEXTURE)==1;
-	video_config.allowtexturerect = options_get_bool(mame_options(), SDLOPTION_GL_NOTEXTURERECT)==0;
-	video_config.vbo         = options_get_bool(mame_options(), SDLOPTION_GL_VBO);
-	video_config.pbo         = options_get_bool(mame_options(), SDLOPTION_GL_PBO);
-	video_config.glsl        = options_get_bool(mame_options(), SDLOPTION_GL_GLSL);
-	if ( video_config.glsl )
+
+	if (USE_OPENGL)
 	{
-		int i;
-		static char buffer[20]; // gl_glsl_filter[0..9]?
-
-		video_config.glsl_filter = options_get_int (mame_options(), SDLOPTION_GLSL_FILTER);
-
-		video_config.glsl_shader_mamebm_num=0;
-
-		for(i=0; i<GLSL_SHADER_MAX; i++)
+		video_config.prescale      = options_get_int(mame_options(), SDLOPTION_PRESCALE);
+		if (video_config.prescale < 1 || video_config.prescale > 3)
 		{
-			snprintf(buffer, 18, SDLOPTION_SHADER_MAME("%d"), i); buffer[17]=0;
-
-			stemp = options_get_string(mame_options(), buffer);
-			if (stemp && strcmp(stemp, SDLOPTVAL_NONE) != 0 && strlen(stemp)>0)
+			mame_printf_warning("Invalid prescale option, reverting to '1'\n");
+			video_config.prescale = 1;
+		}
+		// default to working video please
+		video_config.prefer16bpp_tex = 0;
+		video_config.forcepow2texture = options_get_bool(mame_options(), SDLOPTION_GL_FORCEPOW2TEXTURE)==1;
+		video_config.allowtexturerect = options_get_bool(mame_options(), SDLOPTION_GL_NOTEXTURERECT)==0;
+		video_config.vbo         = options_get_bool(mame_options(), SDLOPTION_GL_VBO);
+		video_config.pbo         = options_get_bool(mame_options(), SDLOPTION_GL_PBO);
+		video_config.glsl        = options_get_bool(mame_options(), SDLOPTION_GL_GLSL);
+		if ( video_config.glsl )
+		{
+			int i;
+			static char buffer[20]; // gl_glsl_filter[0..9]?
+	
+			video_config.glsl_filter = options_get_int (mame_options(), SDLOPTION_GLSL_FILTER);
+	
+			video_config.glsl_shader_mamebm_num=0;
+	
+			for(i=0; i<GLSL_SHADER_MAX; i++)
+			{
+				snprintf(buffer, 18, SDLOPTION_SHADER_MAME("%d"), i); buffer[17]=0;
+	
+				stemp = options_get_string(mame_options(), buffer);
+				if (stemp && strcmp(stemp, SDLOPTVAL_NONE) != 0 && strlen(stemp)>0)
+				{
+					video_config.glsl_shader_mamebm[i] = (char *) malloc(strlen(stemp)+1);
+					strcpy(video_config.glsl_shader_mamebm[i], stemp);
+					video_config.glsl_shader_mamebm_num++;
+				} else {
+					video_config.glsl_shader_mamebm[i] = NULL;
+				}
+			}
+	
+			video_config.glsl_shader_scrn_num=0;
+	
+			for(i=0; i<GLSL_SHADER_MAX; i++)
+			{
+				snprintf(buffer, 20, SDLOPTION_SHADER_SCREEN("%d"), i); buffer[19]=0;
+	
+				stemp = options_get_string(mame_options(), buffer);
+				if (stemp && strcmp(stemp, SDLOPTVAL_NONE) != 0 && strlen(stemp)>0)
+				{
+					video_config.glsl_shader_scrn[i] = (char *) malloc(strlen(stemp)+1);
+					strcpy(video_config.glsl_shader_scrn[i], stemp);
+					video_config.glsl_shader_scrn_num++;
+				} else {
+					video_config.glsl_shader_scrn[i] = NULL;
+				}
+			}
+	
+			video_config.glsl_vid_attributes = options_get_int (mame_options(), SDLOPTION_GL_GLSL_VID_ATTR);
+			{
+				// Disable feature: glsl_vid_attributes, as long we have the gamma calculation
+				// disabled within the direct shaders .. -> too slow.
+				// IMHO the gamma setting should be done global anyways, and for the whole system,
+				// not just MAME ..
+				float gamma = options_get_float(mame_options(), OPTION_GAMMA);
+				if (gamma != 1.0 && video_config.glsl_vid_attributes && video_config.glsl)
+				{
+					video_config.glsl_vid_attributes = FALSE;
+					mame_printf_warning("OpenGL: GLSL - disable handling of brightness and contrast, gamma is set to %f\n", gamma);
+				}
+			}
+		} else {
+			int i;
+			video_config.glsl_filter = 0;
+			video_config.glsl_shader_mamebm_num=0;
+			for(i=0; i<GLSL_SHADER_MAX; i++)
 			{
-				video_config.glsl_shader_mamebm[i] = (char *) malloc(strlen(stemp)+1);
-				strcpy(video_config.glsl_shader_mamebm[i], stemp);
-				video_config.glsl_shader_mamebm_num++;
-			} else {
 				video_config.glsl_shader_mamebm[i] = NULL;
 			}
-		}
-
-		video_config.glsl_shader_scrn_num=0;
-
-		for(i=0; i<GLSL_SHADER_MAX; i++)
-		{
-			snprintf(buffer, 20, SDLOPTION_SHADER_SCREEN("%d"), i); buffer[19]=0;
-
-			stemp = options_get_string(mame_options(), buffer);
-			if (stemp && strcmp(stemp, SDLOPTVAL_NONE) != 0 && strlen(stemp)>0)
+			video_config.glsl_shader_scrn_num=0;
+			for(i=0; i<GLSL_SHADER_MAX; i++)
 			{
-				video_config.glsl_shader_scrn[i] = (char *) malloc(strlen(stemp)+1);
-				strcpy(video_config.glsl_shader_scrn[i], stemp);
-				video_config.glsl_shader_scrn_num++;
-			} else {
 				video_config.glsl_shader_scrn[i] = NULL;
 			}
+			video_config.glsl_vid_attributes = 0;
 		}
-
-		video_config.glsl_vid_attributes = options_get_int (mame_options(), SDLOPTION_GL_GLSL_VID_ATTR);
-		{
-			// Disable feature: glsl_vid_attributes, as long we have the gamma calculation
-			// disabled within the direct shaders .. -> too slow.
-			// IMHO the gamma setting should be done global anyways, and for the whole system,
-			// not just MAME ..
-			float gamma = options_get_float(mame_options(), OPTION_GAMMA);
-			if (gamma != 1.0 && video_config.glsl_vid_attributes && video_config.glsl)
-			{
-				video_config.glsl_vid_attributes = FALSE;
-				mame_printf_warning("OpenGL: GLSL - disable handling of brightness and contrast, gamma is set to %f\n", gamma);
-			}
-		}
-	} else {
-		int i;
-		video_config.glsl_filter = 0;
-		video_config.glsl_shader_mamebm_num=0;
-		for(i=0; i<GLSL_SHADER_MAX; i++)
-		{
-			video_config.glsl_shader_mamebm[i] = NULL;
-		}
-		video_config.glsl_shader_scrn_num=0;
-		for(i=0; i<GLSL_SHADER_MAX; i++)
-		{
-			video_config.glsl_shader_scrn[i] = NULL;
-		}
-		video_config.glsl_vid_attributes = 0;
+	
+		if (osd_use_unsupported())
+			video_config.prescale_effect = options_get_int(mame_options(), SDLOPTION_PRESCALE_EFFECT);
+		else
+			video_config.prescale_effect = 0;
 	}
-
-	if (sdl_use_unsupported())
-		video_config.prescale_effect = options_get_int(mame_options(), SDLOPTION_PRESCALE_EFFECT);
-	else
-		video_config.prescale_effect = 0;
-#endif
 	// misc options: sanity check values
 
 	// global options: sanity check values
+#if (!SDL_VERSION_ATLEAST(1,3,0))
 	if (video_config.numscreens < 1 || video_config.numscreens > 1) //MAX_VIDEO_WINDOWS)
 	{
 		mame_printf_warning("Invalid numscreens value %d; reverting to 1\n", video_config.numscreens);
 		video_config.numscreens = 1;
 	}
-
+#else
+	if (video_config.numscreens < 1 || video_config.numscreens > MAX_VIDEO_WINDOWS)
+	{
+		mame_printf_warning("Invalid numscreens value %d; reverting to 1\n", video_config.numscreens);
+		video_config.numscreens = 1;
+	}
+#endif
 	// yuv settings ...
-	stemp = options_get_string(mame_options(), SDLOPTION_YUVMODE);
-	if (strcmp(stemp, SDLOPTVAL_NONE) == 0)
-		video_config.yuv_mode = VIDEO_YUV_MODE_NONE;
-	else if (strcmp(stemp, SDLOPTVAL_YV12) == 0)
-		video_config.yuv_mode = VIDEO_YUV_MODE_YV12;
-	else if (strcmp(stemp, SDLOPTVAL_YV12x2) == 0)
-		video_config.yuv_mode = VIDEO_YUV_MODE_YV12X2;
-	else if (strcmp(stemp, SDLOPTVAL_YUY2) == 0)
-		video_config.yuv_mode = VIDEO_YUV_MODE_YUY2;
-	else if (strcmp(stemp, SDLOPTVAL_YUY2x2) == 0)
-		video_config.yuv_mode = VIDEO_YUV_MODE_YUY2X2;
-	else
+	stemp = options_get_string(mame_options(), SDLOPTION_SCALEMODE);
+	video_config.scale_mode = drawsdl_scale_mode(stemp);
+	if (video_config.scale_mode < 0)
 	{
 		mame_printf_warning("Invalid yuvmode value %s; reverting to none\n", stemp);
-		video_config.yuv_mode = VIDEO_YUV_MODE_NONE;
+		video_config.scale_mode = VIDEO_SCALE_MODE_NONE;
 	}
-	if ( (video_config.mode != VIDEO_MODE_SOFT) && (video_config.yuv_mode != VIDEO_YUV_MODE_NONE) )
+	if ( (video_config.mode != VIDEO_MODE_SOFT) && (video_config.scale_mode != VIDEO_SCALE_MODE_NONE) )
 	{
-		mame_printf_warning("yuvmode is only for -video soft, overriding\n");
-		video_config.yuv_mode = VIDEO_YUV_MODE_NONE;
+		mame_printf_warning("scalemode is only for -video soft, overriding\n");
+		video_config.scale_mode = VIDEO_SCALE_MODE_NONE;
 	}
 }
 
@@ -775,8 +829,8 @@ static void extract_video_config(running_machine *machine)
 
 static void load_effect_overlay(running_machine *machine, const char *filename)
 {
+	const device_config *screen;
 	char *tempstr = malloc_or_die(strlen(filename) + 5);
-	int scrnum;
 	char *dest;
 
 	// append a .PNG extension
@@ -796,9 +850,8 @@ static void load_effect_overlay(running_machine *machine, const char *filename)
 	}
 
 	// set the overlay on all screens
-	for (scrnum = 0; scrnum < MAX_SCREENS; scrnum++)
-		if (machine->drv->screen[scrnum].tag != NULL)
-			render_container_set_overlay(render_container_get_screen(scrnum), effect_bitmap);
+	for (screen = video_screen_first(machine->config); screen != NULL; screen = video_screen_next(screen))
+		render_container_set_overlay(render_container_get_screen(screen), effect_bitmap);
 
 	free(tempstr);
 }
@@ -826,21 +879,27 @@ static float get_aspect(const char *name, int report_error)
 }
 
 
-
 //============================================================
 //  get_resolution
 //============================================================
 
 static void get_resolution(const char *name, sdl_window_config *config, int report_error)
 {
+	const char *defdata = options_get_string(mame_options(), SDLOPTION_RESOLUTION(""));
 	const char *data = options_get_string(mame_options(), name);
 
 	config->width = config->height = config->depth = config->refresh = 0;
 	if (strcmp(data, SDLOPTVAL_AUTO) == 0)
 	{
-		return;
+		if (strcmp(defdata, SDLOPTVAL_AUTO) == 0)
+		{
+			return;
+		}
+
+		data = defdata;
 	}
-	else if (sscanf(data, "%dx%dx%d@%d", &config->width, &config->height, &config->depth, &config->refresh) < 2 && report_error)
+	
+	if (sscanf(data, "%dx%dx%d@%d", &config->width, &config->height, &config->depth, &config->refresh) < 2 && report_error)
 		mame_printf_error("Illegal resolution value for %s = %s\n", name, data);
 }
 
