@@ -29,7 +29,6 @@
 #include "render.h"
 #include "rendutil.h"
 #include "options.h"
-#include "deprecat.h"
 
 // MAMEOS headers
 #include "d3dintf.h"
@@ -90,7 +89,8 @@ struct _texture_info
 	float					vstart, vstop;				// beginning/ending V coordinates
 	int						rawwidth, rawheight;		// raw width/height of the texture
 	int						type;						// what type of texture are we?
-	int						borderpix;					// do we have a 1 pixel border?
+	int						xborderpix;					// number of border pixels in X
+	int						yborderpix;					// number of border pixels in Y
 	int						xprescale;					// what is our X prescale factor?
 	int						yprescale;					// what is our Y prescale factor?
 	d3d_texture *			d3dtex;						// Direct3D texture pointer
@@ -167,7 +167,7 @@ struct _d3d_info
 	int						last_wrap;					// previous wrap state
 	DWORD					last_modmode;				// previous texture modulation
 
-	mame_bitmap *			vector_bitmap;				// experimental: bitmap for vectors
+	bitmap_t *				vector_bitmap;				// experimental: bitmap for vectors
 	texture_info *			vector_texture;				// experimental: texture for vectors
 };
 
@@ -455,9 +455,11 @@ int drawd3d_init(win_draw_callbacks *callbacks)
 	if (version >= 9)
 		d3dintf = drawd3d9_init();
 
+#if DIRECT3D_VERSION < 0x0900
 	// if that didn't work, try Direct3D 8
 	if (d3dintf == NULL && version >= 8)
 		d3dintf = drawd3d8_init();
+#endif
 
 	// if we failed, note the error
 	if (d3dintf == NULL)
@@ -507,7 +509,7 @@ static int drawd3d_window_init(win_window_info *window)
 	d3d->vector_bitmap = render_load_png(NULL, "vector.png", NULL, NULL);
 	if (d3d->vector_bitmap != NULL)
 	{
-		fillbitmap(d3d->vector_bitmap, MAKE_ARGB(0xff,0xff,0xff,0xff), NULL);
+		bitmap_fill(d3d->vector_bitmap, NULL, MAKE_ARGB(0xff,0xff,0xff,0xff));
 		d3d->vector_bitmap = render_load_png(NULL, "vector.png", d3d->vector_bitmap, NULL);
 	}
 
@@ -735,7 +737,7 @@ try_again:
 	d3d->presentation.MultiSampleType				= D3DMULTISAMPLE_NONE;
 	d3d->presentation.SwapEffect					= D3DSWAPEFFECT_DISCARD;
 	d3d->presentation.hDeviceWindow					= window->hwnd;
-	d3d->presentation.Windowed						= !window->fullscreen || HAS_WINDOW_MENU;
+	d3d->presentation.Windowed						= !window->fullscreen || win_has_menu(window);
 	d3d->presentation.EnableAutoDepthStencil		= FALSE;
 	d3d->presentation.AutoDepthStencilFormat		= D3DFMT_D16;
 	d3d->presentation.Flags							= 0;
@@ -765,6 +767,7 @@ try_again:
 
 	// set the max texture size
 	render_target_set_max_texture_size(window->target, d3d->texture_max_width, d3d->texture_max_height);
+	mame_printf_verbose("Direct3D: Max texture size = %dx%d\n", (int)d3d->texture_max_width, (int)d3d->texture_max_height);
 
 	// set the gamma if we need to
 	if (window->fullscreen)
@@ -1147,7 +1150,7 @@ static int config_adapter_mode(win_window_info *window)
 	}
 
 	// choose a resolution: window mode case
-	if (!window->fullscreen || !video_config.switchres || HAS_WINDOW_MENU)
+	if (!window->fullscreen || !video_config.switchres || win_has_menu(window))
 	{
 		RECT client;
 
@@ -1238,7 +1241,8 @@ static int get_adapter_for_monitor(d3d_info *d3d, win_monitor_info *monitor)
 
 static void pick_best_mode(win_window_info *window)
 {
-	double target_refresh = ATTOSECONDS_TO_HZ(Machine->screen[0].refresh);
+	const device_config *primary_screen = video_screen_first(window->machine->config);
+	double target_refresh = 60.0;
 	INT32 target_width, target_height;
 	d3d_info *d3d = window->drawdata;
 	INT32 minwidth, minheight;
@@ -1246,6 +1250,13 @@ static void pick_best_mode(win_window_info *window)
 	int maxmodes;
 	int modenum;
 
+	// determine the refresh rate of the primary screen
+	if (primary_screen != NULL)
+	{
+		const screen_config *config = primary_screen->inline_config;
+		target_refresh = ATTOSECONDS_TO_HZ(config->refresh);
+	}
+
 	// determine the minimum width/height for the selected target
 	// note: technically we should not be calling this from an alternate window
 	// thread; however, it is only done during init time, and the init code on
@@ -1678,6 +1689,7 @@ static texture_info *texture_create(d3d_info *d3d, const render_texinfo *texsour
 		DWORD usage = d3d->dynamic_supported ? D3DUSAGE_DYNAMIC : 0;
 		DWORD pool = d3d->dynamic_supported ? D3DPOOL_DEFAULT : D3DPOOL_MANAGED;
 		int maxdim = MAX(d3d->presentation.BackBufferWidth, d3d->presentation.BackBufferHeight);
+		int attempt;
 
 		// pick the format
 		if (PRIMFLAG_GET_TEXFORMAT(flags) == TEXFORMAT_YUY16)
@@ -1699,45 +1711,62 @@ static texture_info *texture_create(d3d_info *d3d, const render_texinfo *texsour
 		if (texture->xprescale != video_config.prescale || texture->yprescale != video_config.prescale)
 			mame_printf_verbose("Direct3D: adjusting prescale from %dx%d to %dx%d\n", video_config.prescale, video_config.prescale, texture->xprescale, texture->yprescale);
 
-		// screen textures with no prescaling are pretty easy
-		if (texture->xprescale == 1 && texture->yprescale == 1)
+		// loop until we allocate something or error
+		for (attempt = 0; attempt < 2; attempt++)
 		{
-			result = (*d3dintf->device.create_texture)(d3d->device, texture->rawwidth, texture->rawheight, 1, usage, format, pool, &texture->d3dtex);
-			if (result != D3D_OK)
-				goto error;
-			texture->d3dfinaltex = texture->d3dtex;
-			texture->type = d3d->dynamic_supported ? TEXTURE_TYPE_DYNAMIC : TEXTURE_TYPE_PLAIN;
-		}
+			// second attempt is always 1:1
+			if (attempt == 1)
+				texture->xprescale = texture->yprescale = 1;
 
-		// screen textures with prescaling require two allocations
-		else
-		{
-			int scwidth, scheight;
-
-			// use an offscreen plain surface for stretching if supported
-			if (d3d->stretch_supported)
-			{
-				result = (*d3dintf->device.create_offscreen_plain_surface)(d3d->device, texture->rawwidth, texture->rawheight, format, D3DPOOL_DEFAULT, &texture->d3dsurface);
-				if (result != D3D_OK)
-					goto error;
-				texture->type = TEXTURE_TYPE_SURFACE;
-			}
-
-			// otherwise, we allocate a dynamic texture for the source
-			else
+			// screen textures with no prescaling are pretty easy
+			if (texture->xprescale == 1 && texture->yprescale == 1)
 			{
 				result = (*d3dintf->device.create_texture)(d3d->device, texture->rawwidth, texture->rawheight, 1, usage, format, pool, &texture->d3dtex);
-				if (result != D3D_OK)
-					goto error;
-				texture->type = d3d->dynamic_supported ? TEXTURE_TYPE_DYNAMIC : TEXTURE_TYPE_PLAIN;
+				if (result == D3D_OK)
+				{
+					texture->d3dfinaltex = texture->d3dtex;
+					texture->type = d3d->dynamic_supported ? TEXTURE_TYPE_DYNAMIC : TEXTURE_TYPE_PLAIN;
+					break;
+				}
 			}
 
-			// for the target surface, we allocate a render target texture
-			scwidth = texture->rawwidth * texture->xprescale;
-			scheight = texture->rawheight * texture->yprescale;
-			result = (*d3dintf->device.create_texture)(d3d->device, scwidth, scheight, 1, D3DUSAGE_RENDERTARGET, format, D3DPOOL_DEFAULT, &texture->d3dfinaltex);
-			if (result != D3D_OK)
-				goto error;
+			// screen textures with prescaling require two allocations
+			else
+			{
+				int scwidth, scheight;
+				int finalfmt;
+
+				// use an offscreen plain surface for stretching if supported
+				// (won't work for YUY textures)
+				if (d3d->stretch_supported && PRIMFLAG_GET_TEXFORMAT(flags) != TEXFORMAT_YUY16)
+				{
+					result = (*d3dintf->device.create_offscreen_plain_surface)(d3d->device, texture->rawwidth, texture->rawheight, format, D3DPOOL_DEFAULT, &texture->d3dsurface);
+					if (result != D3D_OK)
+						continue;
+					texture->type = TEXTURE_TYPE_SURFACE;
+				}
+
+				// otherwise, we allocate a dynamic texture for the source
+				else
+				{
+					result = (*d3dintf->device.create_texture)(d3d->device, texture->rawwidth, texture->rawheight, 1, usage, format, pool, &texture->d3dtex);
+					if (result != D3D_OK)
+						continue;
+					texture->type = d3d->dynamic_supported ? TEXTURE_TYPE_DYNAMIC : TEXTURE_TYPE_PLAIN;
+				}
+
+				// for the target surface, we allocate a render target texture
+				scwidth = texture->rawwidth * texture->xprescale;
+				scheight = texture->rawheight * texture->yprescale;
+
+				// target surfaces typically cannot be YCbCr, so we always pick RGB in that case
+ 				finalfmt = (format != d3d->yuv_format) ? format : D3DFMT_A8R8G8B8;
+				result = (*d3dintf->device.create_texture)(d3d->device, scwidth, scheight, 1, D3DUSAGE_RENDERTARGET, finalfmt, D3DPOOL_DEFAULT, &texture->d3dfinaltex);
+				if (result == D3D_OK)
+					break;
+				(*d3dintf->texture.release)(texture->d3dtex);
+				texture->d3dtex = NULL;
+			}
 		}
 	}
 
@@ -1769,18 +1798,20 @@ static void texture_compute_size(d3d_info *d3d, int texwidth, int texheight, tex
 	int finalheight = texheight;
 	int finalwidth = texwidth;
 
-	// if we're not wrapping, add a 1 pixel border on all sides
-#if ENABLE_BORDER_PIX
-	texture->borderpix = !(texture->flags & PRIMFLAG_TEXWRAP_MASK);
-#else
-	texture->borderpix = FALSE;
-#endif
-	if (texture->borderpix)
+	// if we're not wrapping, add a 1-2 pixel border on all sides
+	texture->xborderpix = 0;
+	texture->yborderpix = 0;
+	if (ENABLE_BORDER_PIX && !(texture->flags & PRIMFLAG_TEXWRAP_MASK))
 	{
-		finalwidth += 2;
-		finalheight += 2;
+		// note we need 2 pixels in X for YUY textures
+		texture->xborderpix = (PRIMFLAG_GET_TEXFORMAT(texture->flags) == TEXFORMAT_YUY16) ? 2 : 1;
+		texture->yborderpix = 1;
 	}
 
+	// compute final texture size
+	finalwidth += 2 * texture->xborderpix;
+	finalheight += 2 * texture->yborderpix;
+
 	// round width/height up to nearest power of 2 if we need to
 	if (!(d3d->texture_caps & D3DPTEXTURECAPS_NONPOW2CONDITIONAL))
 	{
@@ -1821,13 +1852,13 @@ static void texture_compute_size(d3d_info *d3d, int texwidth, int texheight, tex
 		finalheight *= 2;
 
 	// if we added pixels for the border, and that just barely pushed us over, take it back
-	if (texture->borderpix &&
-		((finalwidth > d3d->texture_max_width && finalwidth - 2 <= d3d->texture_max_width) ||
-		 (finalheight > d3d->texture_max_height && finalheight - 2 <= d3d->texture_max_height)))
+	if ((finalwidth > d3d->texture_max_width && finalwidth - 2 * texture->xborderpix <= d3d->texture_max_width) ||
+		(finalheight > d3d->texture_max_height && finalheight - 2 * texture->yborderpix <= d3d->texture_max_height))
 	{
-		texture->borderpix = FALSE;
-		finalwidth -= 2;
-		finalheight -= 2;
+		finalwidth -= 2 * texture->xborderpix;
+		finalheight -= 2 * texture->yborderpix;
+		texture->xborderpix = 0;
+		texture->yborderpix = 0;
 	}
 
 	// if we're above the max width/height, do what?
@@ -1839,20 +1870,10 @@ static void texture_compute_size(d3d_info *d3d, int texwidth, int texheight, tex
 	}
 
 	// compute the U/V scale factors
-	if (texture->borderpix)
-	{
-		texture->ustart = 1.0f / (float)finalwidth;
-		texture->ustop = (float)(texwidth + 1) / (float)finalwidth;
-		texture->vstart = 1.0f / (float)finalheight;
-		texture->vstop = (float)(texheight + 1) / (float)finalheight;
-	}
-	else
-	{
-		texture->ustart = 0.0f;
-		texture->ustop = (float)texwidth / (float)finalwidth;
-		texture->vstart = 0.0f;
-		texture->vstop = (float)texheight / (float)finalheight;
-	}
+	texture->ustart = (float)texture->xborderpix / (float)finalwidth;
+	texture->ustop = (float)(texwidth + texture->xborderpix) / (float)finalwidth;
+	texture->vstart = (float)texture->yborderpix / (float)finalheight;
+	texture->vstop = (float)(texheight + texture->yborderpix) / (float)finalheight;
 
 	// set the final values
 	texture->rawwidth = finalwidth;
@@ -1865,15 +1886,16 @@ static void texture_compute_size(d3d_info *d3d, int texwidth, int texheight, tex
 //  copyline_palette16
 //============================================================
 
-INLINE void copyline_palette16(UINT32 *dst, const UINT16 *src, int width, const rgb_t *palette, int borderpix)
+INLINE void copyline_palette16(UINT32 *dst, const UINT16 *src, int width, const rgb_t *palette, int xborderpix)
 {
 	int x;
 
-	if (borderpix)
+	assert(xborderpix == 0 || xborderpix == 1);
+	if (xborderpix)
 		*dst++ = 0xff000000 | palette[*src];
 	for (x = 0; x < width; x++)
 		*dst++ = 0xff000000 | palette[*src++];
-	if (borderpix)
+	if (xborderpix)
 		*dst++ = 0xff000000 | palette[*--src];
 }
 
@@ -1883,15 +1905,16 @@ INLINE void copyline_palette16(UINT32 *dst, const UINT16 *src, int width, const
 //  copyline_palettea16
 //============================================================
 
-INLINE void copyline_palettea16(UINT32 *dst, const UINT16 *src, int width, const rgb_t *palette, int borderpix)
+INLINE void copyline_palettea16(UINT32 *dst, const UINT16 *src, int width, const rgb_t *palette, int xborderpix)
 {
 	int x;
 
-	if (borderpix)
+	assert(xborderpix == 0 || xborderpix == 1);
+	if (xborderpix)
 		*dst++ = palette[*src];
 	for (x = 0; x < width; x++)
 		*dst++ = palette[*src++];
-	if (borderpix)
+	if (xborderpix)
 		*dst++ = palette[*--src];
 }
 
@@ -1901,14 +1924,16 @@ INLINE void copyline_palettea16(UINT32 *dst, const UINT16 *src, int width, const
 //  copyline_rgb15
 //============================================================
 
-INLINE void copyline_rgb15(UINT32 *dst, const UINT16 *src, int width, const rgb_t *palette, int borderpix)
+INLINE void copyline_rgb15(UINT32 *dst, const UINT16 *src, int width, const rgb_t *palette, int xborderpix)
 {
 	int x;
 
+	assert(xborderpix == 0 || xborderpix == 1);
+
 	// palette (really RGB map) case
 	if (palette != NULL)
 	{
-		if (borderpix)
+		if (xborderpix)
 		{
 			UINT16 pix = *src;
 			*dst++ = 0xff000000 | palette[0x40 + ((pix >> 10) & 0x1f)] | palette[0x20 + ((pix >> 5) & 0x1f)] | palette[0x00 + ((pix >> 0) & 0x1f)];
@@ -1918,7 +1943,7 @@ INLINE void copyline_rgb15(UINT32 *dst, const UINT16 *src, int width, const rgb_
 			UINT16 pix = *src++;
 			*dst++ = 0xff000000 | palette[0x40 + ((pix >> 10) & 0x1f)] | palette[0x20 + ((pix >> 5) & 0x1f)] | palette[0x00 + ((pix >> 0) & 0x1f)];
 		}
-		if (borderpix)
+		if (xborderpix)
 		{
 			UINT16 pix = *--src;
 			*dst++ = 0xff000000 | palette[0x40 + ((pix >> 10) & 0x1f)] | palette[0x20 + ((pix >> 5) & 0x1f)] | palette[0x00 + ((pix >> 0) & 0x1f)];
@@ -1928,7 +1953,7 @@ INLINE void copyline_rgb15(UINT32 *dst, const UINT16 *src, int width, const rgb_
 	// direct case
 	else
 	{
-		if (borderpix)
+		if (xborderpix)
 		{
 			UINT16 pix = *src;
 			UINT32 color = ((pix & 0x7c00) << 9) | ((pix & 0x03e0) << 6) | ((pix & 0x001f) << 3);
@@ -1940,7 +1965,7 @@ INLINE void copyline_rgb15(UINT32 *dst, const UINT16 *src, int width, const rgb_
 			UINT32 color = ((pix & 0x7c00) << 9) | ((pix & 0x03e0) << 6) | ((pix & 0x001f) << 3);
 			*dst++ = 0xff000000 | color | ((color >> 5) & 0x070707);
 		}
-		if (borderpix)
+		if (xborderpix)
 		{
 			UINT16 pix = *--src;
 			UINT32 color = ((pix & 0x7c00) << 9) | ((pix & 0x03e0) << 6) | ((pix & 0x001f) << 3);
@@ -1955,14 +1980,16 @@ INLINE void copyline_rgb15(UINT32 *dst, const UINT16 *src, int width, const rgb_
 //  copyline_rgb32
 //============================================================
 
-INLINE void copyline_rgb32(UINT32 *dst, const UINT32 *src, int width, const rgb_t *palette, int borderpix)
+INLINE void copyline_rgb32(UINT32 *dst, const UINT32 *src, int width, const rgb_t *palette, int xborderpix)
 {
 	int x;
 
+	assert(xborderpix == 0 || xborderpix == 1);
+
 	// palette (really RGB map) case
 	if (palette != NULL)
 	{
-		if (borderpix)
+		if (xborderpix)
 		{
 			UINT32 srcpix = *src;
 			*dst++ = 0xff000000 | palette[0x200 + RGB_RED(srcpix)] | palette[0x100 + RGB_GREEN(srcpix)] | palette[RGB_BLUE(srcpix)];
@@ -1972,7 +1999,7 @@ INLINE void copyline_rgb32(UINT32 *dst, const UINT32 *src, int width, const rgb_
 			UINT32 srcpix = *src++;
 			*dst++ = 0xff000000 | palette[0x200 + RGB_RED(srcpix)] | palette[0x100 + RGB_GREEN(srcpix)] | palette[RGB_BLUE(srcpix)];
 		}
-		if (borderpix)
+		if (xborderpix)
 		{
 			UINT32 srcpix = *--src;
 			*dst++ = 0xff000000 | palette[0x200 + RGB_RED(srcpix)] | palette[0x100 + RGB_GREEN(srcpix)] | palette[RGB_BLUE(srcpix)];
@@ -1982,11 +2009,11 @@ INLINE void copyline_rgb32(UINT32 *dst, const UINT32 *src, int width, const rgb_
 	// direct case
 	else
 	{
-		if (borderpix)
+		if (xborderpix)
 			*dst++ = 0xff000000 | *src;
 		for (x = 0; x < width; x++)
 			*dst++ = 0xff000000 | *src++;
-		if (borderpix)
+		if (xborderpix)
 			*dst++ = 0xff000000 | *--src;
 	}
 }
@@ -1997,14 +2024,16 @@ INLINE void copyline_rgb32(UINT32 *dst, const UINT32 *src, int width, const rgb_
 //  copyline_argb32
 //============================================================
 
-INLINE void copyline_argb32(UINT32 *dst, const UINT32 *src, int width, const rgb_t *palette, int borderpix)
+INLINE void copyline_argb32(UINT32 *dst, const UINT32 *src, int width, const rgb_t *palette, int xborderpix)
 {
 	int x;
 
+	assert(xborderpix == 0 || xborderpix == 1);
+
 	// palette (really RGB map) case
 	if (palette != NULL)
 	{
-		if (borderpix)
+		if (xborderpix)
 		{
 			UINT32 srcpix = *src;
 			*dst++ = (srcpix & 0xff000000) | palette[0x200 + RGB_RED(srcpix)] | palette[0x100 + RGB_GREEN(srcpix)] | palette[RGB_BLUE(srcpix)];
@@ -2014,7 +2043,7 @@ INLINE void copyline_argb32(UINT32 *dst, const UINT32 *src, int width, const rgb
 			UINT32 srcpix = *src++;
 			*dst++ = (srcpix & 0xff000000) | palette[0x200 + RGB_RED(srcpix)] | palette[0x100 + RGB_GREEN(srcpix)] | palette[RGB_BLUE(srcpix)];
 		}
-		if (borderpix)
+		if (xborderpix)
 		{
 			UINT32 srcpix = *--src;
 			*dst++ = (srcpix & 0xff000000) | palette[0x200 + RGB_RED(srcpix)] | palette[0x100 + RGB_GREEN(srcpix)] | palette[RGB_BLUE(srcpix)];
@@ -2024,11 +2053,11 @@ INLINE void copyline_argb32(UINT32 *dst, const UINT32 *src, int width, const rgb
 	// direct case
 	else
 	{
-		if (borderpix)
+		if (xborderpix)
 			*dst++ = *src;
 		for (x = 0; x < width; x++)
 			*dst++ = *src++;
-		if (borderpix)
+		if (xborderpix)
 			*dst++ = *--src;
 	}
 }
@@ -2039,47 +2068,62 @@ INLINE void copyline_argb32(UINT32 *dst, const UINT32 *src, int width, const rgb
 //  copyline_yuy16_to_yuy2
 //============================================================
 
-INLINE void copyline_yuy16_to_yuy2(UINT16 *dst, const UINT16 *src, int width, const rgb_t *palette, int borderpix)
+INLINE void copyline_yuy16_to_yuy2(UINT16 *dst, const UINT16 *src, int width, const rgb_t *palette, int xborderpix)
 {
 	int x;
 
+	assert(xborderpix == 0 || xborderpix == 2);
+	assert(width % 2 == 0);
+
 	// palette (really RGB map) case
 	if (palette != NULL)
 	{
-		if (borderpix)
+		if (xborderpix)
 		{
-			UINT16 srcpix = *src;
-			*dst++ = palette[0x000 + (srcpix >> 8)] | (srcpix << 8);
+			UINT16 srcpix0 = *src++;
+			UINT16 srcpix1 = *src--;
+			*dst++ = palette[0x000 + (srcpix0 >> 8)] | (srcpix0 << 8);
+			*dst++ = palette[0x000 + (srcpix0 >> 8)] | (srcpix1 << 8);
 		}
-		for (x = 0; x < width; x++)
+		for (x = 0; x < width; x += 2)
 		{
-			UINT16 srcpix = *src++;
-			*dst++ = palette[0x000 + (srcpix >> 8)] | (srcpix << 8);
+			UINT16 srcpix0 = *src++;
+			UINT16 srcpix1 = *src++;
+			*dst++ = palette[0x000 + (srcpix0 >> 8)] | (srcpix0 << 8);
+			*dst++ = palette[0x000 + (srcpix1 >> 8)] | (srcpix1 << 8);
 		}
-		if (borderpix)
+		if (xborderpix)
 		{
-			UINT16 srcpix = *--src;
-			*dst++ = palette[0x000 + (srcpix >> 8)] | (srcpix << 8);
+			UINT16 srcpix1 = *--src;
+			UINT16 srcpix0 = *--src;
+			*dst++ = palette[0x000 + (srcpix1 >> 8)] | (srcpix0 << 8);
+			*dst++ = palette[0x000 + (srcpix1 >> 8)] | (srcpix1 << 8);
 		}
 	}
 
 	// direct case
 	else
 	{
-		if (borderpix)
+		if (xborderpix)
 		{
-			UINT16 srcpix = *src;
-			*dst++ = (srcpix >> 8) | (srcpix << 8);
+			UINT16 srcpix0 = *src++;
+			UINT16 srcpix1 = *src--;
+			*dst++ = (srcpix0 >> 8) | (srcpix0 << 8);
+			*dst++ = (srcpix0 >> 8) | (srcpix1 << 8);
 		}
-		for (x = 0; x < width; x++)
+		for (x = 0; x < width; x += 2)
 		{
-			UINT16 srcpix = *src++;
-			*dst++ = (srcpix >> 8) | (srcpix << 8);
+			UINT16 srcpix0 = *src++;
+			UINT16 srcpix1 = *src++;
+			*dst++ = (srcpix0 >> 8) | (srcpix0 << 8);
+			*dst++ = (srcpix1 >> 8) | (srcpix1 << 8);
 		}
-		if (borderpix)
+		if (xborderpix)
 		{
-			UINT16 srcpix = *--src;
-			*dst++ = (srcpix >> 8) | (srcpix << 8);
+			UINT16 srcpix1 = *--src;
+			UINT16 srcpix0 = *--src;
+			*dst++ = (srcpix1 >> 8) | (srcpix0 << 8);
+			*dst++ = (srcpix1 >> 8) | (srcpix1 << 8);
 		}
 	}
 }
@@ -2090,47 +2134,60 @@ INLINE void copyline_yuy16_to_yuy2(UINT16 *dst, const UINT16 *src, int width, co
 //  copyline_yuy16_to_uyvy
 //============================================================
 
-INLINE void copyline_yuy16_to_uyvy(UINT16 *dst, const UINT16 *src, int width, const rgb_t *palette, int borderpix)
+INLINE void copyline_yuy16_to_uyvy(UINT16 *dst, const UINT16 *src, int width, const rgb_t *palette, int xborderpix)
 {
 	int x;
 
+	assert(xborderpix == 0 || xborderpix == 2);
+	assert(width % 2 == 0);
+
 	// palette (really RGB map) case
 	if (palette != NULL)
 	{
-		if (borderpix)
+		if (xborderpix)
 		{
-			UINT16 srcpix = *src;
-			*dst++ = palette[0x100 + (srcpix >> 8)] | (srcpix & 0xff);
+			UINT16 srcpix0 = *src++;
+			UINT16 srcpix1 = *src--;
+			*dst++ = palette[0x100 + (srcpix0 >> 8)] | (srcpix0 & 0xff);
+			*dst++ = palette[0x100 + (srcpix0 >> 8)] | (srcpix1 & 0xff);
 		}
-		for (x = 0; x < width; x++)
+		for (x = 0; x < width; x += 2)
 		{
-			UINT16 srcpix = *src++;
-			*dst++ = palette[0x100 + (srcpix >> 8)] | (srcpix & 0xff);
+			UINT16 srcpix0 = *src++;
+			UINT16 srcpix1 = *src++;
+			*dst++ = palette[0x100 + (srcpix0 >> 8)] | (srcpix0 & 0xff);
+			*dst++ = palette[0x100 + (srcpix1 >> 8)] | (srcpix1 & 0xff);
 		}
-		if (borderpix)
+		if (xborderpix)
 		{
-			UINT16 srcpix = *--src;
-			*dst++ = palette[0x100 + (srcpix >> 8)] | (srcpix & 0xff);
+			UINT16 srcpix1 = *--src;
+			UINT16 srcpix0 = *--src;
+			*dst++ = palette[0x100 + (srcpix1 >> 8)] | (srcpix0 & 0xff);
+			*dst++ = palette[0x100 + (srcpix1 >> 8)] | (srcpix1 & 0xff);
 		}
 	}
 
 	// direct case
 	else
 	{
-		if (borderpix)
+		if (xborderpix)
 		{
-			UINT16 srcpix = *src;
-			*dst++ = (srcpix >> 8) | (srcpix << 8);
+			UINT16 srcpix0 = src[0];
+			UINT16 srcpix1 = src[1];
+			*dst++ = srcpix0;
+			*dst++ = (srcpix0 & 0xff00) | (srcpix1 & 0x00ff);
 		}
-		for (x = 0; x < width; x++)
+		for (x = 0; x < width; x += 2)
 		{
-			UINT16 srcpix = *src++;
-			*dst++ = (srcpix >> 8) | (srcpix << 8);
+			*dst++ = *src++;
+			*dst++ = *src++;
 		}
-		if (borderpix)
+		if (xborderpix)
 		{
-			UINT16 srcpix = *--src;
-			*dst++ = (srcpix >> 8) | (srcpix << 8);
+			UINT16 srcpix1 = *--src;
+			UINT16 srcpix0 = *--src;
+			*dst++ = (srcpix1 & 0xff00) | (srcpix0 & 0x00ff);
+			*dst++ = srcpix1;
 		}
 	}
 }
@@ -2141,20 +2198,24 @@ INLINE void copyline_yuy16_to_uyvy(UINT16 *dst, const UINT16 *src, int width, co
 //  copyline_yuy16_to_argb
 //============================================================
 
-INLINE void copyline_yuy16_to_argb(UINT32 *dst, const UINT16 *src, int width, const rgb_t *palette, int borderpix)
+INLINE void copyline_yuy16_to_argb(UINT32 *dst, const UINT16 *src, int width, const rgb_t *palette, int xborderpix)
 {
 	int x;
 
+	assert(xborderpix == 0 || xborderpix == 2);
+	assert(width % 2 == 0);
+
 	// palette (really RGB map) case
 	if (palette != NULL)
 	{
-		if (borderpix)
+		if (xborderpix)
 		{
 			UINT16 srcpix0 = src[0];
 			UINT16 srcpix1 = src[1];
 			UINT8 cb = srcpix0 & 0xff;
 			UINT8 cr = srcpix1 & 0xff;
 			*dst++ = ycc_to_rgb(palette[0x000 + (srcpix0 >> 8)], cb, cr);
+			*dst++ = ycc_to_rgb(palette[0x000 + (srcpix0 >> 8)], cb, cr);
 		}
 		for (x = 0; x < width / 2; x++)
 		{
@@ -2165,28 +2226,30 @@ INLINE void copyline_yuy16_to_argb(UINT32 *dst, const UINT16 *src, int width, co
 			*dst++ = ycc_to_rgb(palette[0x000 + (srcpix0 >> 8)], cb, cr);
 			*dst++ = ycc_to_rgb(palette[0x000 + (srcpix1 >> 8)], cb, cr);
 		}
-		if (borderpix)
+		if (xborderpix)
 		{
 			UINT16 srcpix1 = *--src;
 			UINT16 srcpix0 = *--src;
 			UINT8 cb = srcpix0 & 0xff;
 			UINT8 cr = srcpix1 & 0xff;
 			*dst++ = ycc_to_rgb(palette[0x000 + (srcpix1 >> 8)], cb, cr);
+			*dst++ = ycc_to_rgb(palette[0x000 + (srcpix1 >> 8)], cb, cr);
 		}
 	}
 
 	// direct case
 	else
 	{
-		if (borderpix)
+		if (xborderpix)
 		{
 			UINT16 srcpix0 = src[0];
 			UINT16 srcpix1 = src[1];
 			UINT8 cb = srcpix0 & 0xff;
 			UINT8 cr = srcpix1 & 0xff;
 			*dst++ = ycc_to_rgb(srcpix0 >> 8, cb, cr);
+			*dst++ = ycc_to_rgb(srcpix0 >> 8, cb, cr);
 		}
-		for (x = 0; x < width / 2; x++)
+		for (x = 0; x < width; x += 2)
 		{
 			UINT16 srcpix0 = *src++;
 			UINT16 srcpix1 = *src++;
@@ -2195,13 +2258,14 @@ INLINE void copyline_yuy16_to_argb(UINT32 *dst, const UINT16 *src, int width, co
 			*dst++ = ycc_to_rgb(srcpix0 >> 8, cb, cr);
 			*dst++ = ycc_to_rgb(srcpix1 >> 8, cb, cr);
 		}
-		if (borderpix)
+		if (xborderpix)
 		{
 			UINT16 srcpix1 = *--src;
 			UINT16 srcpix0 = *--src;
 			UINT8 cb = srcpix0 & 0xff;
 			UINT8 cr = srcpix1 & 0xff;
 			*dst++ = ycc_to_rgb(srcpix1 >> 8, cb, cr);
+			*dst++ = ycc_to_rgb(srcpix1 >> 8, cb, cr);
 		}
 	}
 }
@@ -2231,43 +2295,43 @@ static void texture_set_data(d3d_info *d3d, texture_info *texture, const render_
 		return;
 
 	// loop over Y
-	miny = 0 - texture->borderpix;
-	maxy = texsource->height + texture->borderpix;
+	miny = 0 - texture->yborderpix;
+	maxy = texsource->height + texture->yborderpix;
 	for (dsty = miny; dsty < maxy; dsty++)
 	{
 		int srcy = (dsty < 0) ? 0 : (dsty >= texsource->height) ? texsource->height - 1 : dsty;
-		void *dst = (BYTE *)rect.pBits + (dsty + texture->borderpix) * rect.Pitch;
+		void *dst = (BYTE *)rect.pBits + (dsty + texture->yborderpix) * rect.Pitch;
 
 		// switch off of the format and
 		switch (PRIMFLAG_GET_TEXFORMAT(flags))
 		{
 			case TEXFORMAT_PALETTE16:
-				copyline_palette16(dst, (UINT16 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->borderpix);
+				copyline_palette16(dst, (UINT16 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->xborderpix);
 				break;
 
 			case TEXFORMAT_PALETTEA16:
-				copyline_palettea16(dst, (UINT16 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->borderpix);
+				copyline_palettea16(dst, (UINT16 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->xborderpix);
 				break;
 
 			case TEXFORMAT_RGB15:
-				copyline_rgb15(dst, (UINT16 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->borderpix);
+				copyline_rgb15(dst, (UINT16 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->xborderpix);
 				break;
 
 			case TEXFORMAT_RGB32:
-				copyline_rgb32(dst, (UINT32 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->borderpix);
+				copyline_rgb32(dst, (UINT32 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->xborderpix);
 				break;
 
 			case TEXFORMAT_ARGB32:
-				copyline_argb32(dst, (UINT32 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->borderpix);
+				copyline_argb32(dst, (UINT32 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->xborderpix);
 				break;
 
 			case TEXFORMAT_YUY16:
 				if (d3d->yuv_format == D3DFMT_YUY2)
-					copyline_yuy16_to_yuy2(dst, (UINT16 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->borderpix);
+					copyline_yuy16_to_yuy2(dst, (UINT16 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->xborderpix);
 				else if (d3d->yuv_format == D3DFMT_UYVY)
-					copyline_yuy16_to_uyvy(dst, (UINT16 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->borderpix);
+					copyline_yuy16_to_uyvy(dst, (UINT16 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->xborderpix);
 				else
-					copyline_yuy16_to_argb(dst, (UINT16 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->borderpix);
+					copyline_yuy16_to_argb(dst, (UINT16 *)texsource->base + srcy * texsource->rowpixels, texsource->width, texsource->palette, texture->xborderpix);
 				break;
 
 			default:
@@ -2319,8 +2383,8 @@ static void texture_prescale(d3d_info *d3d, texture_info *texture)
 
 		// set the source bounds
 		source.left = source.top = 0;
-		source.right = texture->texinfo.width + 2 * texture->borderpix;
-		source.bottom = texture->texinfo.height + 2 * texture->borderpix;
+		source.right = texture->texinfo.width + 2 * texture->xborderpix;
+		source.bottom = texture->texinfo.height + 2 * texture->yborderpix;
 
 		// set the target bounds
 		dest = source;
@@ -2363,22 +2427,22 @@ static void texture_prescale(d3d_info *d3d, texture_info *texture)
 		// configure the X/Y coordinates on the target surface
 		d3d->lockedbuf[0].x = -0.5f;
 		d3d->lockedbuf[0].y = -0.5f;
-		d3d->lockedbuf[1].x = (float)((texture->texinfo.width + 2 * texture->borderpix) * texture->xprescale) - 0.5f;
+		d3d->lockedbuf[1].x = (float)((texture->texinfo.width + 2 * texture->xborderpix) * texture->xprescale) - 0.5f;
 		d3d->lockedbuf[1].y = -0.5f;
 		d3d->lockedbuf[2].x = -0.5f;
-		d3d->lockedbuf[2].y = (float)((texture->texinfo.height + 2 * texture->borderpix) * texture->yprescale) - 0.5f;
-		d3d->lockedbuf[3].x = (float)((texture->texinfo.width + 2 * texture->borderpix) * texture->xprescale) - 0.5f;
-		d3d->lockedbuf[3].y = (float)((texture->texinfo.height + 2 * texture->borderpix) * texture->yprescale) - 0.5f;
+		d3d->lockedbuf[2].y = (float)((texture->texinfo.height + 2 * texture->yborderpix) * texture->yprescale) - 0.5f;
+		d3d->lockedbuf[3].x = (float)((texture->texinfo.width + 2 * texture->xborderpix) * texture->xprescale) - 0.5f;
+		d3d->lockedbuf[3].y = (float)((texture->texinfo.height + 2 * texture->yborderpix) * texture->yprescale) - 0.5f;
 
 		// configure the U/V coordintes on the source texture
 		d3d->lockedbuf[0].u0 = 0.0f;
 		d3d->lockedbuf[0].v0 = 0.0f;
-		d3d->lockedbuf[1].u0 = (float)(texture->texinfo.width + 2 * texture->borderpix) / (float)texture->rawwidth;
+		d3d->lockedbuf[1].u0 = (float)(texture->texinfo.width + 2 * texture->xborderpix) / (float)texture->rawwidth;
 		d3d->lockedbuf[1].v0 = 0.0f;
 		d3d->lockedbuf[2].u0 = 0.0f;
-		d3d->lockedbuf[2].v0 = (float)(texture->texinfo.height + 2 * texture->borderpix) / (float)texture->rawheight;
-		d3d->lockedbuf[3].u0 = (float)(texture->texinfo.width + 2 * texture->borderpix) / (float)texture->rawwidth;
-		d3d->lockedbuf[3].v0 = (float)(texture->texinfo.height + 2 * texture->borderpix) / (float)texture->rawheight;
+		d3d->lockedbuf[2].v0 = (float)(texture->texinfo.height + 2 * texture->yborderpix) / (float)texture->rawheight;
+		d3d->lockedbuf[3].u0 = (float)(texture->texinfo.width + 2 * texture->xborderpix) / (float)texture->rawwidth;
+		d3d->lockedbuf[3].v0 = (float)(texture->texinfo.height + 2 * texture->yborderpix) / (float)texture->rawheight;
 
 		// reset the remaining vertex parameters
 		for (i = 0; i < 4; i++)
