@@ -7,9 +7,6 @@
 //
 //============================================================
 
-// needed for multimonitor
-#define _WIN32_WINNT 0x501
-
 // standard windows headers
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
@@ -23,7 +20,6 @@
 #include "render.h"
 #include "rendutil.h"
 #include "options.h"
-#include "deprecat.h"
 
 // MAMEOS headers
 #include "winmain.h"
@@ -1229,7 +1225,7 @@ static void get_adapter_for_monitor(dd_info *dd, win_monitor_info *monitor)
 
 
 //============================================================
-//  pick_best_mode
+//  enum_modes_callback
 //============================================================
 
 static HRESULT WINAPI enum_modes_callback(LPDDSURFACEDESC2 desc, LPVOID context)
@@ -1291,6 +1287,7 @@ static HRESULT WINAPI enum_modes_callback(LPDDSURFACEDESC2 desc, LPVOID context)
 
 static void pick_best_mode(win_window_info *window)
 {
+	const device_config *primary_screen = video_screen_first(window->machine->config);
 	dd_info *dd = window->drawdata;
 	mode_enum_info einfo;
 	HRESULT result;
@@ -1304,7 +1301,15 @@ static void pick_best_mode(win_window_info *window)
 	// use those as the target for now
 	einfo.target_width = einfo.minimum_width * MAX(1, video_config.prescale);
 	einfo.target_height = einfo.minimum_height * MAX(1, video_config.prescale);
-	einfo.target_refresh = ATTOSECONDS_TO_HZ(Machine->screen[0].refresh);
+
+	// determine the refresh rate of the primary screen
+	einfo.target_refresh = 60.0;
+	if (primary_screen != NULL)
+	{
+		const screen_config *config = primary_screen->inline_config;
+		einfo.target_refresh = ATTOSECONDS_TO_HZ(config->refresh);
+	}
+	printf("Target refresh = %f\n", einfo.target_refresh);
 
 	// if we're not stretching, allow some slop on the minimum since we can handle it
 	if (!video_config.hwstretch)
