@@ -10,9 +10,6 @@
 // For testing purposes: force DirectInput
 #define FORCE_DIRECTINPUT	0
 
-// Needed for RAW Input
-#define _WIN32_WINNT 0x501
-
 // standard windows headers
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
@@ -21,10 +18,6 @@
 
 // undef WINNT for dinput.h to prevent duplicate definition
 #undef WINNT
-#ifdef DIRECTINPUT_VERSION
-#undef DIRECTINPUT_VERSION
-#endif
-#define DIRECTINPUT_VERSION 0x0700
 #include <dinput.h>
 
 // standard C headers
@@ -151,6 +144,7 @@ struct _device_info
 	void					(*poll)(device_info *info);
 
 	// MAME information
+	running_machine *		machine;
 	input_device *			device;
 
 	// device state
@@ -232,7 +226,7 @@ static void device_list_poll_devices(device_info *devlist_head);
 static void device_list_reset_devices(device_info *devlist_head);
 
 // generic device management
-static device_info *generic_device_alloc(device_info **devlist_head_ptr, const TCHAR *name);
+static device_info *generic_device_alloc(running_machine *machine, device_info **devlist_head_ptr, const TCHAR *name);
 static void generic_device_free(device_info *devinfo);
 static int generic_device_index(device_info *devlist_head, device_info *devinfo);
 static void generic_device_reset(device_info *devinfo);
@@ -249,7 +243,7 @@ static void win32_lightgun_poll(device_info *devinfo);
 static void dinput_init(running_machine *machine);
 static void dinput_exit(running_machine *machine);
 static HRESULT dinput_set_dword_property(LPDIRECTINPUTDEVICE device, REFGUID property_guid, DWORD object, DWORD how, DWORD value);
-static device_info *dinput_device_create(device_info **devlist_head_ptr, LPCDIDEVICEINSTANCE instance, LPCDIDATAFORMAT format1, LPCDIDATAFORMAT format2, DWORD cooperative_level);
+static device_info *dinput_device_create(running_machine *machine, device_info **devlist_head_ptr, LPCDIDEVICEINSTANCE instance, LPCDIDATAFORMAT format1, LPCDIDATAFORMAT format2, DWORD cooperative_level);
 static void dinput_device_release(device_info *devinfo);
 static const char *dinput_device_item_name(device_info *devinfo, int offset, const TCHAR *defstring, const TCHAR *suffix);
 static HRESULT dinput_device_poll(device_info *devinfo);
@@ -264,12 +258,12 @@ static INT32 dinput_joystick_pov_get_state(void *device_internal, void *item_int
 // RawInput-specific code
 static void rawinput_init(running_machine *machine);
 static void rawinput_exit(running_machine *machine);
-static device_info *rawinput_device_create(device_info **devlist_head_ptr, PRAWINPUTDEVICELIST device);
+static device_info *rawinput_device_create(running_machine *machine, device_info **devlist_head_ptr, PRAWINPUTDEVICELIST device);
 static void rawinput_device_release(device_info *info);
 static TCHAR *rawinput_device_improve_name(TCHAR *name);
-static void rawinput_keyboard_enum(PRAWINPUTDEVICELIST device);
+static void rawinput_keyboard_enum(running_machine *machine, PRAWINPUTDEVICELIST device);
 static void rawinput_keyboard_update(HANDLE device, RAWKEYBOARD *data);
-static void rawinput_mouse_enum(PRAWINPUTDEVICELIST device);
+static void rawinput_mouse_enum(running_machine *machine, PRAWINPUTDEVICELIST device);
 static void rawinput_mouse_update(HANDLE device, RAWMOUSE *data);
 static void rawinput_mouse_poll(device_info *devinfo);
 
@@ -420,16 +414,15 @@ static const int win_key_trans_table[][4] =
 };
 
 
-
 //============================================================
 //  INLINE FUNCTIONS
 //============================================================
 
-INLINE void poll_if_necessary(void)
+INLINE void poll_if_necessary(running_machine *machine)
 {
 	// make sure we poll at least once every 1/4 second
 	if (GetTickCount() > last_poll + 1000 / 4)
-		wininput_poll();
+		wininput_poll(machine);
 }
 
 
@@ -496,7 +489,7 @@ void wininput_init(running_machine *machine)
 
 	// poll once to get the initial states
 	input_enabled = TRUE;
-	wininput_poll();
+	wininput_poll(machine);
 }
 
 
@@ -531,7 +524,7 @@ static void wininput_exit(running_machine *machine)
 //  wininput_poll
 //============================================================
 
-void wininput_poll(void)
+void wininput_poll(running_machine *machine)
 {
 	int hasfocus = winwindow_has_focus() && input_enabled;
 
@@ -543,7 +536,7 @@ void wininput_poll(void)
 
 		// periodically process events, in case they're not coming through
 		// this also will make sure the mouse state is up-to-date
-		winwindow_process_events_periodic();
+		winwindow_process_events_periodic(machine);
 
 		// track if mouse/lightgun is enabled, for mouse hiding purposes
 		mouse_enabled = input_device_class_enabled(DEVICE_CLASS_MOUSE);
@@ -595,17 +588,17 @@ int wininput_should_hide_mouse(void)
 //  wininput_handle_mouse_button
 //============================================================
 
-void wininput_handle_mouse_button(int button, int down, int x, int y)
+BOOL wininput_handle_mouse_button(int button, int down, int x, int y)
 {
 	device_info *devinfo;
 
 	// ignore if not enabled
 	if (!input_enabled)
-		return;
+		return FALSE;
 
 	// only need this for shared axis hack
 	if (!lightgun_shared_axis_mode || button >= 4)
-		return;
+		return FALSE;
 
 	// choose a device based on the button
 	devinfo = lightgun_list;
@@ -638,6 +631,7 @@ void wininput_handle_mouse_button(int button, int down, int x, int y)
 
 	// release the lock
 	osd_lock_release(input_lock);
+	return TRUE;
 }
 
 
@@ -701,42 +695,63 @@ BOOL wininput_handle_raw(HANDLE device)
 
 
 //============================================================
-//  osd_customize_inputport_list
+//  wininput_vkey_for_mame_code
 //============================================================
 
-void osd_customize_inputport_list(input_port_default_entry *defaults)
+int wininput_vkey_for_mame_code(input_code code)
 {
-	input_port_default_entry *idef = defaults;
+	// only works for keyboard switches
+	if (INPUT_CODE_DEVCLASS(code) == DEVICE_CLASS_KEYBOARD && INPUT_CODE_ITEMCLASS(code) == ITEM_CLASS_SWITCH)
+	{
+		input_item_id id = INPUT_CODE_ITEMID(code);
+		int tablenum;
 
-	// loop over all the defaults
-	for (idef = defaults; idef->type != IPT_END; idef++)
-		switch (idef->type)
+		// scan the table for a match
+		for (tablenum = 0; tablenum < ARRAY_LENGTH(win_key_trans_table); tablenum++)
+			if (win_key_trans_table[tablenum][MAME_KEY] == id)
+				return win_key_trans_table[tablenum][VIRTUAL_KEY];
+	}
+	return 0;
+}
+
+
+//============================================================
+//  osd_customize_mapping_list
+//============================================================
+
+void osd_customize_input_type_list(input_type_desc *typelist)
+{
+	input_type_desc *typedesc;
+
+	// loop over the defaults
+	for (typedesc = typelist; typedesc != NULL; typedesc = typedesc->next)
+		switch (typedesc->type)
 		{
 			// disable the config menu if the ALT key is down
 			// (allows ALT-TAB to switch between windows apps)
 			case IPT_UI_CONFIGURE:
-				input_seq_set_5(&idef->defaultseq, KEYCODE_TAB, SEQCODE_NOT, KEYCODE_LALT, SEQCODE_NOT, KEYCODE_RALT);
+				input_seq_set_5(&typedesc->seq[SEQ_TYPE_STANDARD], KEYCODE_TAB, SEQCODE_NOT, KEYCODE_LALT, SEQCODE_NOT, KEYCODE_RALT);
 				break;
 
 			// alt-enter for fullscreen
 			case IPT_OSD_1:
-				idef->token = "TOGGLE_FULLSCREEN";
-				idef->name = "Toggle Fullscreen";
-				input_seq_set_2(&idef->defaultseq, KEYCODE_LALT, KEYCODE_ENTER);
+				typedesc->token = "TOGGLE_FULLSCREEN";
+				typedesc->name = "Toggle Fullscreen";
+				input_seq_set_2(&typedesc->seq[SEQ_TYPE_STANDARD], KEYCODE_LALT, KEYCODE_ENTER);
 				break;
 
 #ifdef MESS
 			case IPT_OSD_2:
-				if (mess_use_new_ui())
+				if (ui_mess_use_new_ui())
 				{
-					idef->token = "TOGGLE_MENUBAR";
-					idef->name = "Toggle Menubar";
-					input_seq_set_1 (&idef->defaultseq, KEYCODE_SCRLOCK);
+					typedesc->token = "TOGGLE_MENUBAR";
+					typedesc->name = "Toggle Menubar";
+					input_seq_set_1 (&typedesc->seq[SEQ_TYPE_STANDARD], KEYCODE_SCRLOCK);
 				}
 				break;
 
 			case IPT_UI_THROTTLE:
-				input_seq_set_0(&idef->defaultseq);
+				input_seq_set_0(&typedesc->seq[SEQ_TYPE_STANDARD]);
 				break;
 #endif /* MESS */
 		}
@@ -774,7 +789,7 @@ static void device_list_reset_devices(device_info *devlist_head)
 //  generic_device_alloc
 //============================================================
 
-static device_info *generic_device_alloc(device_info **devlist_head_ptr, const TCHAR *name)
+static device_info *generic_device_alloc(running_machine *machine, device_info **devlist_head_ptr, const TCHAR *name)
 {
 	device_info **curdev_ptr;
 	device_info *devinfo;
@@ -783,6 +798,7 @@ static device_info *generic_device_alloc(device_info **devlist_head_ptr, const T
 	devinfo = malloc_or_die(sizeof(*devinfo));
 	memset(devinfo, 0, sizeof(*devinfo));
 	devinfo->head = devlist_head_ptr;
+	devinfo->machine = machine;
 
 	// allocate a UTF8 copy of the name
 	devinfo->name = utf8_from_tstring(name);
@@ -874,10 +890,11 @@ static void generic_device_reset(device_info *devinfo)
 
 static INT32 generic_button_get_state(void *device_internal, void *item_internal)
 {
+	device_info *devinfo = device_internal;
 	BYTE *itemdata = item_internal;
 
 	// return the current state
-	poll_if_necessary();
+	poll_if_necessary(devinfo->machine);
 	return *itemdata >> 7;
 }
 
@@ -888,10 +905,11 @@ static INT32 generic_button_get_state(void *device_internal, void *item_internal
 
 static INT32 generic_axis_get_state(void *device_internal, void *item_internal)
 {
+	device_info *devinfo = device_internal;
 	LONG *axisdata = item_internal;
 
 	// return the current state
-	poll_if_necessary();
+	poll_if_necessary(devinfo->machine);
 	return *axisdata;
 }
 
@@ -919,12 +937,12 @@ static void win32_init(running_machine *machine)
 		int axisnum, butnum;
 
 		// allocate a device
-		devinfo = generic_device_alloc(&lightgun_list, gun_names[gunnum]);
+		devinfo = generic_device_alloc(machine, &lightgun_list, gun_names[gunnum]);
 		if (devinfo == NULL)
 			break;
 
 		// add the device
-		devinfo->device = input_device_add(DEVICE_CLASS_LIGHTGUN, devinfo->name, devinfo);
+		devinfo->device = input_device_add(machine, DEVICE_CLASS_LIGHTGUN, devinfo->name, devinfo);
 
 		// populate the axes
 		for (axisnum = 0; axisnum < 2; axisnum++)
@@ -1035,6 +1053,22 @@ static void win32_lightgun_poll(device_info *devinfo)
 static void dinput_init(running_machine *machine)
 {
 	HRESULT result;
+#if DIRECTINPUT_VERSION >= 0x800
+	int didevtype_keyboard = DI8DEVCLASS_KEYBOARD;
+	int didevtype_mouse = DI8DEVCLASS_POINTER;
+	int didevtype_joystick = DI8DEVCLASS_GAMECTRL;
+
+	dinput_version = DIRECTINPUT_VERSION;
+	result = DirectInput8Create(GetModuleHandle(NULL), dinput_version, &IID_IDirectInput8, (void *)&dinput, NULL);
+	if (result != DI_OK)
+	{
+		dinput_version = 0;
+		return;
+	}
+#else
+	int didevtype_keyboard = DIDEVTYPE_KEYBOARD;
+	int didevtype_mouse = DIDEVTYPE_MOUSE;
+	int didevtype_joystick = DIDEVTYPE_JOYSTICK;
 
 	// first attempt to initialize DirectInput at the current version
 	dinput_version = DIRECTINPUT_VERSION;
@@ -1056,6 +1090,8 @@ static void dinput_init(running_machine *machine)
 			}
 		}
 	}
+#endif
+
 	mame_printf_verbose("DirectInput: Using DirectInput %d\n", dinput_version >> 8);
 
 	// we need an exit callback
@@ -1065,7 +1101,7 @@ static void dinput_init(running_machine *machine)
 	if (keyboard_list == NULL)
 	{
 		// enumerate the ones we have
-		result = IDirectInput_EnumDevices(dinput, DIDEVTYPE_KEYBOARD, dinput_keyboard_enum, 0, DIEDFL_ATTACHEDONLY);
+		result = IDirectInput_EnumDevices(dinput, didevtype_keyboard, dinput_keyboard_enum, machine, DIEDFL_ATTACHEDONLY);
 		if (result != DI_OK)
 			fatalerror("DirectInput: Unable to enumerate keyboards (result=%08X)\n", (UINT32)result);
 	}
@@ -1074,13 +1110,13 @@ static void dinput_init(running_machine *machine)
 	if (mouse_list == NULL)
 	{
 		// enumerate the ones we have
-		result = IDirectInput_EnumDevices(dinput, DIDEVTYPE_MOUSE, dinput_mouse_enum, 0, DIEDFL_ATTACHEDONLY);
+		result = IDirectInput_EnumDevices(dinput, didevtype_mouse, dinput_mouse_enum, machine, DIEDFL_ATTACHEDONLY);
 		if (result != DI_OK)
 			fatalerror("DirectInput: Unable to enumerate mice (result=%08X)\n", (UINT32)result);
 	}
 
 	// initialize joystick devices
-	result = IDirectInput_EnumDevices(dinput, DIDEVTYPE_JOYSTICK, dinput_joystick_enum, 0, DIEDFL_ATTACHEDONLY);
+	result = IDirectInput_EnumDevices(dinput, didevtype_joystick, dinput_joystick_enum, machine, DIEDFL_ATTACHEDONLY);
 	if (result != DI_OK)
 		fatalerror("DirectInput: Unable to enumerate joysticks (result=%08X)\n", (UINT32)result);
 }
@@ -1131,13 +1167,13 @@ static HRESULT dinput_set_dword_property(LPDIRECTINPUTDEVICE device, REFGUID pro
 //  dinput_device_create
 //============================================================
 
-static device_info *dinput_device_create(device_info **devlist_head_ptr, LPCDIDEVICEINSTANCE instance, LPCDIDATAFORMAT format1, LPCDIDATAFORMAT format2, DWORD cooperative_level)
+static device_info *dinput_device_create(running_machine *machine, device_info **devlist_head_ptr, LPCDIDEVICEINSTANCE instance, LPCDIDATAFORMAT format1, LPCDIDATAFORMAT format2, DWORD cooperative_level)
 {
 	device_info *devinfo;
 	HRESULT result;
 
 	// allocate memory for the device object
-	devinfo = generic_device_alloc(devlist_head_ptr, instance->tszInstanceName);
+	devinfo = generic_device_alloc(machine, devlist_head_ptr, instance->tszInstanceName);
 
 	// attempt to create a device
 	result = IDirectInput_CreateDevice(dinput, &instance->guidInstance, &devinfo->dinput.device, NULL);
@@ -1232,7 +1268,7 @@ static const char *dinput_device_item_name(device_info *devinfo, int offset, con
 		return utf8_from_tstring(namestring);
 
 	// otherwise, allocate space to add the suffix
-	combined = malloc_or_die(_tcslen(namestring) + 1 + _tcslen(suffix) + 1);
+	combined = malloc_or_die(sizeof(TCHAR) * (_tcslen(namestring) + 1 + _tcslen(suffix) + 1));
 	_tcscpy(combined, namestring);
 	_tcscat(combined, TEXT(" "));
 	_tcscat(combined, suffix);
@@ -1275,16 +1311,17 @@ static HRESULT dinput_device_poll(device_info *devinfo)
 
 static BOOL CALLBACK dinput_keyboard_enum(LPCDIDEVICEINSTANCE instance, LPVOID ref)
 {
+	running_machine *machine = ref;
 	device_info *devinfo;
 	int keynum;
 
 	// allocate and link in a new device
-	devinfo = dinput_device_create(&keyboard_list, instance, &c_dfDIKeyboard, NULL, DISCL_FOREGROUND | DISCL_NONEXCLUSIVE);
+	devinfo = dinput_device_create(machine, &keyboard_list, instance, &c_dfDIKeyboard, NULL, DISCL_FOREGROUND | DISCL_NONEXCLUSIVE);
 	if (devinfo == NULL)
 		goto exit;
 
 	// add the device
-	devinfo->device = input_device_add(DEVICE_CLASS_KEYBOARD, devinfo->name, devinfo);
+	devinfo->device = input_device_add(machine, DEVICE_CLASS_KEYBOARD, devinfo->name, devinfo);
 	devinfo->poll = dinput_keyboard_poll;
 
 	// populate it
@@ -1330,11 +1367,12 @@ static void dinput_keyboard_poll(device_info *devinfo)
 static BOOL CALLBACK dinput_mouse_enum(LPCDIDEVICEINSTANCE instance, LPVOID ref)
 {
 	device_info *devinfo, *guninfo = NULL;
+	running_machine *machine = ref;
 	int axisnum, butnum;
 	HRESULT result;
 
 	// allocate and link in a new device
-	devinfo = dinput_device_create(&mouse_list, instance, &c_dfDIMouse2, &c_dfDIMouse, DISCL_FOREGROUND | DISCL_NONEXCLUSIVE);
+	devinfo = dinput_device_create(machine, &mouse_list, instance, &c_dfDIMouse2, &c_dfDIMouse, DISCL_FOREGROUND | DISCL_NONEXCLUSIVE);
 	if (devinfo == NULL)
 		goto exit;
 
@@ -1342,7 +1380,7 @@ static BOOL CALLBACK dinput_mouse_enum(LPCDIDEVICEINSTANCE instance, LPVOID ref)
 	// we only support a single gun in dinput mode, so only add one
 	if (!lightgun_shared_axis_mode && devinfo == mouse_list)
 	{
-		guninfo = generic_device_alloc(&lightgun_list, instance->tszInstanceName);
+		guninfo = generic_device_alloc(machine, &lightgun_list, instance->tszInstanceName);
 		if (guninfo == NULL)
 			goto exit;
 	}
@@ -1356,11 +1394,11 @@ static BOOL CALLBACK dinput_mouse_enum(LPCDIDEVICEINSTANCE instance, LPVOID ref)
 	}
 
 	// add the device
-	devinfo->device = input_device_add(DEVICE_CLASS_MOUSE, devinfo->name, devinfo);
+	devinfo->device = input_device_add(machine, DEVICE_CLASS_MOUSE, devinfo->name, devinfo);
 	devinfo->poll = dinput_mouse_poll;
 	if (guninfo != NULL)
 	{
-		guninfo->device = input_device_add(DEVICE_CLASS_LIGHTGUN, guninfo->name, guninfo);
+		guninfo->device = input_device_add(machine, DEVICE_CLASS_LIGHTGUN, guninfo->name, guninfo);
 		guninfo->poll = win32_lightgun_poll;
 	}
 
@@ -1431,11 +1469,12 @@ static BOOL CALLBACK dinput_joystick_enum(LPCDIDEVICEINSTANCE instance, LPVOID r
 {
 	DWORD cooperative_level = (HAS_WINDOW_MENU ? DISCL_BACKGROUND : DISCL_FOREGROUND) | DISCL_EXCLUSIVE;
 	int axisnum, axiscount, povnum, butnum;
+	running_machine *machine = ref;
 	device_info *devinfo;
 	HRESULT result;
 
 	// allocate and link in a new device
-	devinfo = dinput_device_create(&joystick_list, instance, &c_dfDIJoystick, NULL, cooperative_level);
+	devinfo = dinput_device_create(machine, &joystick_list, instance, &c_dfDIJoystick, NULL, cooperative_level);
 	if (devinfo == NULL)
 		goto exit;
 
@@ -1460,7 +1499,7 @@ static BOOL CALLBACK dinput_joystick_enum(LPCDIDEVICEINSTANCE instance, LPVOID r
 	devinfo->dinput.caps.dwButtons = MIN(devinfo->dinput.caps.dwButtons, 128);
 
 	// add the device
-	devinfo->device = input_device_add(DEVICE_CLASS_JOYSTICK, devinfo->name, devinfo);
+	devinfo->device = input_device_add(machine, DEVICE_CLASS_JOYSTICK, devinfo->name, devinfo);
 	devinfo->poll = dinput_joystick_poll;
 
 	// populate the axes
@@ -1560,7 +1599,7 @@ static INT32 dinput_joystick_pov_get_state(void *device_internal, void *item_int
 	DWORD pov;
 
 	// get the current state
-	poll_if_necessary();
+	poll_if_necessary(devinfo->machine);
 	pov = devinfo->joystick.state.rgdwPOV[povnum];
 
 	// if invalid, return 0
@@ -1623,11 +1662,11 @@ static void rawinput_init(running_machine *machine)
 
 		// handle keyboards
 		if (device->dwType == RIM_TYPEKEYBOARD && !FORCE_DIRECTINPUT)
-			rawinput_keyboard_enum(device);
+			rawinput_keyboard_enum(machine, device);
 
 		// handle mice
 		else if (device->dwType == RIM_TYPEMOUSE && !FORCE_DIRECTINPUT)
-			rawinput_mouse_enum(device);
+			rawinput_mouse_enum(machine, device);
 	}
 
 	// finally, register to recieve raw input WM_INPUT messages
@@ -1683,7 +1722,7 @@ static void rawinput_exit(running_machine *machine)
 //  rawinput_device_create
 //============================================================
 
-static device_info *rawinput_device_create(device_info **devlist_head_ptr, PRAWINPUTDEVICELIST device)
+static device_info *rawinput_device_create(running_machine *machine, device_info **devlist_head_ptr, PRAWINPUTDEVICELIST device)
 {
 	device_info *devinfo = NULL;
 	TCHAR *tname = NULL;
@@ -1702,7 +1741,7 @@ static device_info *rawinput_device_create(device_info **devlist_head_ptr, PRAWI
 
 	// improve the name and then allocate a device
 	tname = rawinput_device_improve_name(tname);
-	devinfo = generic_device_alloc(devlist_head_ptr, tname);
+	devinfo = generic_device_alloc(machine, devlist_head_ptr, tname);
 	free(tname);
 
 	// copy the handle
@@ -1882,18 +1921,18 @@ exit:
 //  rawinput_keyboard_enum
 //============================================================
 
-static void rawinput_keyboard_enum(PRAWINPUTDEVICELIST device)
+static void rawinput_keyboard_enum(running_machine *machine, PRAWINPUTDEVICELIST device)
 {
 	device_info *devinfo;
 	int keynum;
 
 	// allocate and link in a new device
-	devinfo = rawinput_device_create(&keyboard_list, device);
+	devinfo = rawinput_device_create(machine, &keyboard_list, device);
 	if (devinfo == NULL)
 		return;
 
 	// add the device
-	devinfo->device = input_device_add(DEVICE_CLASS_KEYBOARD, devinfo->name, devinfo);
+	devinfo->device = input_device_add(machine, DEVICE_CLASS_KEYBOARD, devinfo->name, devinfo);
 
 	// populate it
 	for (keynum = 0; keynum < MAX_KEYS; keynum++)
@@ -1947,13 +1986,13 @@ static void rawinput_keyboard_update(HANDLE device, RAWKEYBOARD *data)
 //  rawinput_mouse_enum
 //============================================================
 
-static void rawinput_mouse_enum(PRAWINPUTDEVICELIST device)
+static void rawinput_mouse_enum(running_machine *machine, PRAWINPUTDEVICELIST device)
 {
 	device_info *devinfo, *guninfo = NULL;
 	int axisnum, butnum;
 
 	// allocate and link in a new mouse device
-	devinfo = rawinput_device_create(&mouse_list, device);
+	devinfo = rawinput_device_create(machine, &mouse_list, device);
 	if (devinfo == NULL)
 		return;
 	devinfo->poll = rawinput_mouse_poll;
@@ -1961,15 +2000,15 @@ static void rawinput_mouse_enum(PRAWINPUTDEVICELIST device)
 	// allocate a second device for the gun (unless we are using the shared axis mode)
 	if (!lightgun_shared_axis_mode)
 	{
-		guninfo = rawinput_device_create(&lightgun_list, device);
+		guninfo = rawinput_device_create(machine, &lightgun_list, device);
 		assert(guninfo != NULL);
 	}
 
 	// add the device
-	devinfo->device = input_device_add(DEVICE_CLASS_MOUSE, devinfo->name, devinfo);
+	devinfo->device = input_device_add(machine, DEVICE_CLASS_MOUSE, devinfo->name, devinfo);
 	if (guninfo != NULL)
 	{
-		guninfo->device = input_device_add(DEVICE_CLASS_LIGHTGUN, guninfo->name, guninfo);
+		guninfo->device = input_device_add(machine, DEVICE_CLASS_LIGHTGUN, guninfo->name, guninfo);
 		guninfo->poll = (guninfo == lightgun_list) ? win32_lightgun_poll : NULL;
 		guninfo->mouse.partner = &devinfo->mouse;
 	}
@@ -2061,7 +2100,7 @@ static void rawinput_mouse_update(HANDLE device, RAWMOUSE *data)
 
 static void rawinput_mouse_poll(device_info *devinfo)
 {
-	poll_if_necessary();
+	poll_if_necessary(devinfo->machine);
 
 	// copy the accumulated raw state to the actual state
 	osd_lock_acquire(input_lock);
