@@ -29,9 +29,6 @@
 //
 //============================================================
 
-// Needed for RAW Input
-#define _WIN32_WINNT 0x501
-
 // standard windows headers
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
@@ -45,6 +42,7 @@
 
 // MAME output header file
 typedef void running_machine;
+#include "osdcomm.h"
 #include "output.h"
 
 
@@ -384,21 +382,26 @@ static LRESULT handle_copydata(WPARAM wparam, LPARAM lparam)
 
 	// allocate memory
 	entry = malloc(sizeof(*entry));
+	if (entry == NULL)
+		return 0;
+
 	string = malloc(strlen(data->string) + 1);
+	if (string == NULL)
+	{
+		free(entry);
+		return 0;
+	}
 
 	// if all allocations worked, make a new entry
-	if (entry != NULL && string != NULL)
-	{
-		entry->next = idmaplist;
-		entry->name = string;
-		entry->id = data->id;
+	entry->next = idmaplist;
+	entry->name = string;
+	entry->id = data->id;
 
-		// copy the string and hook us into the list
-		strcpy(string, data->string);
-		idmaplist = entry;
+	// copy the string and hook us into the list
+	strcpy(string, data->string);
+	idmaplist = entry;
 
-		DEBUG_PRINTF(("  id %d = '%s'\n", entry->id, entry->name));
-	}
+	DEBUG_PRINTF(("  id %d = '%s'\n", entry->id, entry->name));
 
 	return 0;
 }
@@ -415,6 +418,7 @@ static void reset_id_to_outname_cache(void)
 	{
 		id_map_entry *temp = idmaplist;
 		idmaplist = temp->next;
+		free((void*)temp->name);
 		free(temp);
 	}
 }
