@@ -11,7 +11,6 @@
 #define LOG_TEMP_PAUSE		0
 
 // Needed for RAW Input
-#define _WIN32_WINNT 0x501
 #define WM_INPUT 0x00FF
 
 // standard windows headers
@@ -27,7 +26,7 @@
 // MAME headers
 #include "osdepend.h"
 #include "driver.h"
-#include "deprecat.h"
+#include "uiinput.h"
 
 // MAMEOS headers
 #include "winmain.h"
@@ -183,6 +182,7 @@ static void mtlog_dump(void)
 }
 #else
 void mtlog_add(const char *event) { }
+static void mtlog_dump(void) { }
 #endif
 
 
@@ -269,6 +269,10 @@ static void winwindow_exit(running_machine *machine)
 {
 	assert(GetCurrentThreadId() == main_threadid);
 
+	// possibly kill the debug window
+	if (options_get_bool(mame_options(), OPTION_DEBUG))
+		debugwin_destroy_windows();
+
 	// free all the windows
 	while (win_window_list != NULL)
 	{
@@ -286,9 +290,7 @@ static void winwindow_exit(running_machine *machine)
 		PostThreadMessage(window_threadid, WM_USER_SELF_TERMINATE, 0, 0);
 		WaitForSingleObject(window_thread, INFINITE);
 
-#if (LOG_THREADS)
 		mtlog_dump();
-#endif
 	}
 
 	// kill the UI pause event
@@ -310,7 +312,7 @@ static void winwindow_exit(running_machine *machine)
 //  (main thread)
 //============================================================
 
-void winwindow_process_events_periodic(void)
+void winwindow_process_events_periodic(running_machine *machine)
 {
 	DWORD currticks = GetTickCount();
 
@@ -319,7 +321,7 @@ void winwindow_process_events_periodic(void)
 	// update once every 1/8th of a second
 	if (currticks - last_event_check < 1000 / 8)
 		return;
-	winwindow_process_events(TRUE);
+	winwindow_process_events(machine, TRUE);
 }
 
 
@@ -346,17 +348,15 @@ static BOOL is_mame_window(HWND hwnd)
 //  (main thread)
 //============================================================
 
-void winwindow_process_events(int ingame)
+void winwindow_process_events(running_machine *machine, int ingame)
 {
 	MSG message;
 
 	assert(GetCurrentThreadId() == main_threadid);
 
 	// if we're running, disable some parts of the debugger
-#ifdef ENABLE_DEBUGGER
-	if (ingame)
-		debugwin_update_during_game();
-#endif
+	if (ingame && (machine->debug_flags & DEBUG_FLAG_ENABLED) != 0)
+		debugwin_update_during_game(machine);
 
 	// remember the last time we did this
 	last_event_check = GetTickCount();
@@ -379,66 +379,53 @@ void winwindow_process_events(int ingame)
 					// ignore keyboard messages
 					case WM_SYSKEYUP:
 					case WM_SYSKEYDOWN:
-#ifndef MESS
-					case WM_KEYUP:
-					case WM_KEYDOWN:
-					case WM_CHAR:
-#endif
 						dispatch = FALSE;
 						break;
 
 					// forward mouse button downs to the input system
 					case WM_LBUTTONDOWN:
-						wininput_handle_mouse_button(0, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-						dispatch = FALSE;
+						dispatch = !wininput_handle_mouse_button(0, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 						break;
 
 					case WM_RBUTTONDOWN:
-						wininput_handle_mouse_button(1, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-						dispatch = FALSE;
+						dispatch = !wininput_handle_mouse_button(1, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 						break;
 
 					case WM_MBUTTONDOWN:
-						wininput_handle_mouse_button(2, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-						dispatch = FALSE;
+						dispatch = !wininput_handle_mouse_button(2, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 						break;
 
 					case WM_XBUTTONDOWN:
-						wininput_handle_mouse_button(3, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-						dispatch = FALSE;
+						dispatch = !wininput_handle_mouse_button(3, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 						break;
 
 					// forward mouse button ups to the input system
 					case WM_LBUTTONUP:
-						wininput_handle_mouse_button(0, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-						dispatch = FALSE;
+						dispatch = !wininput_handle_mouse_button(0, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 						break;
 
 					case WM_RBUTTONUP:
-						wininput_handle_mouse_button(1, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-						dispatch = FALSE;
+						dispatch = !wininput_handle_mouse_button(1, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 						break;
 
 					case WM_MBUTTONUP:
-						wininput_handle_mouse_button(2, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-						dispatch = FALSE;
+						dispatch = !wininput_handle_mouse_button(2, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 						break;
 
 					case WM_XBUTTONUP:
-						wininput_handle_mouse_button(3, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-						dispatch = FALSE;
+						dispatch = !wininput_handle_mouse_button(3, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 						break;
 				}
 			}
 
 			// dispatch if necessary
 			if (dispatch)
-				winwindow_dispatch_message(&message);
+				winwindow_dispatch_message(machine, &message);
 		}
 	} while (ui_temp_pause > 0);
 
 	// update the cursor state after processing events
-	winwindow_update_cursor_state();
+	winwindow_update_cursor_state(machine);
 }
 
 
@@ -448,7 +435,7 @@ void winwindow_process_events(int ingame)
 //  (main thread)
 //============================================================
 
-void winwindow_dispatch_message(MSG *message)
+void winwindow_dispatch_message(running_machine *machine, MSG *message)
 {
 	assert(GetCurrentThreadId() == main_threadid);
 
@@ -457,12 +444,12 @@ void winwindow_dispatch_message(MSG *message)
 	{
 		// special case for quit
 		case WM_QUIT:
-			mame_schedule_exit(Machine);
+			mame_schedule_exit(machine);
 			break;
 
 		// temporary pause from the window thread
 		case WM_USER_UI_TEMP_PAUSE:
-			winwindow_ui_pause_from_main_thread(message->wParam);
+			winwindow_ui_pause_from_main_thread(machine, message->wParam);
 			break;
 
 		// execute arbitrary function
@@ -495,11 +482,9 @@ void winwindow_toggle_full_screen(void)
 
 	assert(GetCurrentThreadId() == main_threadid);
 
-#ifdef ENABLE_DEBUGGER
 	// if we are in debug mode, never go full screen
 	if (options_get_bool(mame_options(), OPTION_DEBUG))
 		return;
-#endif
 
 	// toggle the window mode
 	video_config.windowed = !video_config.windowed;
@@ -536,7 +521,7 @@ BOOL winwindow_has_focus(void)
 //  (main thread)
 //============================================================
 
-void winwindow_update_cursor_state(void)
+void winwindow_update_cursor_state(running_machine *machine)
 {
 	static POINT saved_cursor_pos = { -1, -1 };
 
@@ -548,7 +533,7 @@ void winwindow_update_cursor_state(void)
 	//   2. we also hide the cursor in full screen mode and when the window doesn't have a menu
 	//   3. we also hide the cursor in windowed mode if we're not paused and
 	//      the input system requests it
-	if (winwindow_has_focus() && ((!video_config.windowed && !win_has_menu(win_window_list)) || (!mame_is_paused(Machine) && wininput_should_hide_mouse())))
+	if (winwindow_has_focus() && ((!video_config.windowed && !win_has_menu(win_window_list)) || (!mame_is_paused(machine) && wininput_should_hide_mouse())))
 	{
 		win_window_info *window = win_window_list;
 		RECT bounds;
@@ -589,7 +574,7 @@ void winwindow_update_cursor_state(void)
 //  (main thread)
 //============================================================
 
-void winwindow_video_window_create(int index, win_monitor_info *monitor, const win_window_config *config)
+void winwindow_video_window_create(running_machine *machine, int index, win_monitor_info *monitor, const win_window_config *config)
 {
 	win_window_info *window, *win;
 	char option[20];
@@ -604,6 +589,7 @@ void winwindow_video_window_create(int index, win_monitor_info *monitor, const w
 	window->refresh = config->refresh;
 	window->monitor = monitor;
 	window->fullscreen = !video_config.windowed;
+	window->machine = machine;
 
 	// see if we are safe for fullscreen
 	window->fullscreen_safe = TRUE;
@@ -619,7 +605,7 @@ void winwindow_video_window_create(int index, win_monitor_info *monitor, const w
 	window->render_lock = osd_lock_alloc();
 
 	// load the layout
-	window->target = render_target_alloc(NULL, 0);
+	window->target = render_target_alloc(machine, NULL, 0);
 	if (window->target == NULL)
 		fatalerror("Error creating render target for window %d", index);
 
@@ -634,9 +620,9 @@ void winwindow_video_window_create(int index, win_monitor_info *monitor, const w
 
 	// make the window title
 	if (video_config.numscreens == 1)
-		sprintf(window->title, APPNAME ": %s [%s]", Machine->gamedrv->description, Machine->gamedrv->name);
+		sprintf(window->title, APPNAME ": %s [%s]", machine->gamedrv->description, machine->gamedrv->name);
 	else
-		sprintf(window->title, APPNAME ": %s [%s] - Screen %d", Machine->gamedrv->description, Machine->gamedrv->name, index);
+		sprintf(window->title, APPNAME ": %s [%s] - Screen %d", machine->gamedrv->description, machine->gamedrv->name, index);
 
 	// set the initial maximized state
 	window->startmaximized = options_get_bool(mame_options(), WINOPTION_MAXIMIZE);
@@ -731,7 +717,7 @@ void winwindow_video_window_update(win_window_info *window)
 	}
 
 	// if we're visible and running and not in the middle of a resize, draw
-	if (window->hwnd != NULL && window->target != NULL)
+	if (window->hwnd != NULL && window->target != NULL && window->drawdata != NULL)
 	{
 		int got_lock = TRUE;
 
@@ -844,7 +830,7 @@ static void create_window_class(void)
 static void set_starting_view(int index, win_window_info *window, const char *view)
 {
 	const char *defview = options_get_string(mame_options(), WINOPTION_VIEW);
-	int viewindex = -1;
+	int viewindex;
 
 	assert(GetCurrentThreadId() == main_threadid);
 
@@ -852,67 +838,8 @@ static void set_starting_view(int index, win_window_info *window, const char *vi
 	if (strcmp(view, "auto") == 0 && strcmp(defview, "auto") != 0)
 		view = defview;
 
-	// auto view just selects the nth view
-	if (strcmp(view, "auto") != 0)
-	{
-		// scan for a matching view name
-		for (viewindex = 0; ; viewindex++)
-		{
-			const char *name = render_target_get_view_name(window->target, viewindex);
-
-			// stop scanning if we hit NULL
-			if (name == NULL)
-			{
-				viewindex = -1;
-				break;
-			}
-			if (mame_strnicmp(name, view, strlen(view)) == 0)
-				break;
-		}
-	}
-
-	// if we don't have a match, default to the nth view
-	if (viewindex == -1)
-	{
-		int scrcount;
-
-		// count the number of screens
-		for (scrcount = 0; Machine->drv->screen[scrcount].tag != NULL; scrcount++) ;
-
-		// if we have enough screens to be one per monitor, assign in order
-		if (video_config.numscreens >= scrcount)
-		{
-			// find the first view with this screen and this screen only
-			for (viewindex = 0; ; viewindex++)
-			{
-				UINT32 viewscreens = render_target_get_view_screens(window->target, viewindex);
-				if (viewscreens == (1 << index))
-					break;
-				if (viewscreens == 0)
-				{
-					viewindex = -1;
-					break;
-				}
-			}
-		}
-
-		// otherwise, find the first view that has all the screens
-		if (viewindex == -1)
-		{
-			for (viewindex = 0; ; viewindex++)
-			{
-				UINT32 viewscreens = render_target_get_view_screens(window->target, viewindex);
-				if (viewscreens == (1 << scrcount) - 1)
-					break;
-				if (viewscreens == 0)
-					break;
-			}
-		}
-	}
-
-	// make sure it's a valid view
-	if (render_target_get_view_name(window->target, viewindex) == NULL)
-		viewindex = 0;
+	// query the video system to help us pick a view
+	viewindex = video_get_view_for_target(window->machine, window->target, view, index, video_config.numscreens);
 
 	// set the view
 	render_target_set_view(window->target, viewindex);
@@ -925,7 +852,7 @@ static void set_starting_view(int index, win_window_info *window, const char *vi
 //  (main thread)
 //============================================================
 
-void winwindow_ui_pause_from_main_thread(int pause)
+void winwindow_ui_pause_from_main_thread(running_machine *machine, int pause)
 {
 	int old_temp_pause = ui_temp_pause;
 
@@ -938,9 +865,9 @@ void winwindow_ui_pause_from_main_thread(int pause)
 		if (ui_temp_pause++ == 0)
 		{
 			// only call mame_pause if we weren't already paused due to some external reason
-			ui_temp_was_paused = mame_is_paused(Machine);
+			ui_temp_was_paused = mame_is_paused(machine);
 			if (!ui_temp_was_paused)
-				mame_pause(Machine, TRUE);
+				mame_pause(machine, TRUE);
 
 			SetEvent(ui_pause_event);
 		}
@@ -954,7 +881,7 @@ void winwindow_ui_pause_from_main_thread(int pause)
 		{
 			// but only do it if we were the ones who initiated it
 			if (!ui_temp_was_paused)
-				mame_pause(Machine, FALSE);
+				mame_pause(machine, FALSE);
 
 			ResetEvent(ui_pause_event);
 		}
@@ -971,7 +898,7 @@ void winwindow_ui_pause_from_main_thread(int pause)
 //  (window thread)
 //============================================================
 
-void winwindow_ui_pause_from_window_thread(int pause)
+void winwindow_ui_pause_from_window_thread(running_machine *machine, int pause)
 {
 	assert(GetCurrentThreadId() == window_threadid);
 
@@ -988,7 +915,7 @@ void winwindow_ui_pause_from_window_thread(int pause)
 
 	// otherwise, we just do it directly
 	else
-		winwindow_ui_pause_from_main_thread(pause);
+		winwindow_ui_pause_from_main_thread(machine, pause);
 }
 
 
@@ -1020,9 +947,9 @@ void winwindow_ui_exec_on_main_thread(void (*func)(void *), void *param)
 //  winwindow_ui_is_paused
 //============================================================
 
-int winwindow_ui_is_paused(void)
+int winwindow_ui_is_paused(running_machine *machine)
 {
-	return mame_is_paused(Machine) && ui_temp_was_paused;
+	return mame_is_paused(machine) && ui_temp_was_paused;
 }
 
 
@@ -1089,54 +1016,41 @@ static unsigned __stdcall thread_entry(void *param)
 				// ignore input messages here
 				case WM_SYSKEYUP:
 				case WM_SYSKEYDOWN:
-#ifndef MESS
-				case WM_KEYUP:
-				case WM_KEYDOWN:
-				case WM_CHAR:
-#endif // MESS
 					dispatch = FALSE;
 					break;
 
 				// forward mouse button downs to the input system
 				case WM_LBUTTONDOWN:
-					wininput_handle_mouse_button(0, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-					dispatch = FALSE;
+					dispatch = !wininput_handle_mouse_button(0, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 					break;
 
 				case WM_RBUTTONDOWN:
-					wininput_handle_mouse_button(1, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-					dispatch = FALSE;
+					dispatch = !wininput_handle_mouse_button(1, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 					break;
 
 				case WM_MBUTTONDOWN:
-					wininput_handle_mouse_button(2, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-					dispatch = FALSE;
+					dispatch = !wininput_handle_mouse_button(2, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 					break;
 
 				case WM_XBUTTONDOWN:
-					wininput_handle_mouse_button(3, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-					dispatch = FALSE;
+					dispatch = !wininput_handle_mouse_button(3, TRUE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 					break;
 
 				// forward mouse button ups to the input system
 				case WM_LBUTTONUP:
-					wininput_handle_mouse_button(0, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-					dispatch = FALSE;
+					dispatch = !wininput_handle_mouse_button(0, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 					break;
 
 				case WM_RBUTTONUP:
-					wininput_handle_mouse_button(1, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-					dispatch = FALSE;
+					dispatch = !wininput_handle_mouse_button(1, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 					break;
 
 				case WM_MBUTTONUP:
-					wininput_handle_mouse_button(2, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-					dispatch = FALSE;
+					dispatch = !wininput_handle_mouse_button(2, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 					break;
 
 				case WM_XBUTTONUP:
-					wininput_handle_mouse_button(3, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
-					dispatch = FALSE;
+					dispatch = !wininput_handle_mouse_button(3, FALSE, GET_X_LPARAM(message.lParam), GET_Y_LPARAM(message.lParam));
 					break;
 
 				// a terminate message to the thread posts a quit
@@ -1187,7 +1101,7 @@ static int complete_create(win_window_info *window)
 
 	// create the window menu if needed
 #if HAS_WINDOW_MENU
-	if (win_create_menu(&menu))
+	if (win_create_menu(window->machine, &menu))
 		return 1;
 #endif
 
@@ -1295,18 +1209,57 @@ LRESULT CALLBACK winwindow_video_window_proc(HWND wnd, UINT message, WPARAM wpar
 		case WM_SYSKEYDOWN:
 			break;
 
+		// input events
+		case WM_MOUSEMOVE:
+			ui_input_push_mouse_move_event(window->machine, window->target, GET_X_LPARAM(lparam), GET_Y_LPARAM(lparam));
+			break;
+
+		case WM_MOUSELEAVE:
+			ui_input_push_mouse_leave_event(window->machine, window->target);
+			break;
+
+		case WM_LBUTTONDOWN:
+		{
+			DWORD ticks = GetTickCount();
+			ui_input_push_mouse_down_event(window->machine, window->target, GET_X_LPARAM(lparam), GET_Y_LPARAM(lparam));
+
+			// check for a double-click
+			if (ticks - window->lastclicktime < GetDoubleClickTime() &&
+				GET_X_LPARAM(lparam) >= window->lastclickx - 4 && GET_X_LPARAM(lparam) <= window->lastclickx + 4 &&
+				GET_Y_LPARAM(lparam) >= window->lastclicky - 4 && GET_Y_LPARAM(lparam) <= window->lastclicky + 4)
+			{
+				window->lastclicktime = 0;
+				ui_input_push_mouse_double_click_event(window->machine, window->target, GET_X_LPARAM(lparam), GET_Y_LPARAM(lparam));
+			}
+			else
+			{
+				window->lastclicktime = ticks;
+				window->lastclickx = GET_X_LPARAM(lparam);
+				window->lastclicky = GET_Y_LPARAM(lparam);
+			}
+			break;
+		}
+
+		case WM_LBUTTONUP:
+			ui_input_push_mouse_up_event(window->machine, window->target, GET_X_LPARAM(lparam), GET_Y_LPARAM(lparam));
+			break;
+
+		case WM_CHAR:
+			ui_input_push_char_event(window->machine, window->target, (unicode_char) wparam);
+			break;
+
 		// pause the system when we start a menu or resize
 		case WM_ENTERSIZEMOVE:
 			window->resize_state = RESIZE_STATE_RESIZING;
 		case WM_ENTERMENULOOP:
-			winwindow_ui_pause_from_window_thread(TRUE);
+			winwindow_ui_pause_from_window_thread(window->machine, TRUE);
 			break;
 
 		// unpause the system when we stop a menu or resize and force a redraw
 		case WM_EXITSIZEMOVE:
 			window->resize_state = RESIZE_STATE_PENDING;
 		case WM_EXITMENULOOP:
-			winwindow_ui_pause_from_window_thread(FALSE);
+			winwindow_ui_pause_from_window_thread(window->machine, FALSE);
 			InvalidateRect(wnd, NULL, FALSE);
 			break;
 
@@ -1362,7 +1315,7 @@ LRESULT CALLBACK winwindow_video_window_proc(HWND wnd, UINT message, WPARAM wpar
 			if (multithreading_enabled)
 				PostThreadMessage(main_threadid, WM_QUIT, 0, 0);
 			else
-				mame_schedule_exit(Machine);
+				mame_schedule_exit(window->machine);
 			break;
 
 		// destroy: clean up all attached rendering bits and NULL out our hwnd
