@@ -8,7 +8,6 @@
 //============================================================
 
 // standard windows headers
-#define _WIN32_WINNT 0x0400
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #include <process.h>
@@ -27,6 +26,7 @@
 //============================================================
 
 #define KEEP_STATISTICS			(0)
+#define USE_SCALABLE_LOCKS		(0)
 
 
 
@@ -75,12 +75,16 @@ INLINE void YieldProcessor(void)
 typedef struct _scalable_lock scalable_lock;
 struct _scalable_lock
 {
+#if USE_SCALABLE_LOCKS
    struct
    {
       volatile INT32 	haslock;		// do we have the lock?
       INT32 			filler[64/4-1];	// assumes a 64-byte cache line
    } slot[WORK_MAX_THREADS];			// one slot per thread
    volatile INT32 		nextindex;		// index of next slot to use
+#else
+	CRITICAL_SECTION	section;
+#endif
 };
 
 
@@ -198,12 +202,17 @@ INLINE INT32 interlocked_add(INT32 volatile *ptr, INT32 add)
 INLINE void scalable_lock_init(scalable_lock *lock)
 {
 	memset(lock, 0, sizeof(*lock));
+#if USE_SCALABLE_LOCKS
 	lock->slot[0].haslock = TRUE;
+#else
+	InitializeCriticalSection(&lock->section);
+#endif
 }
 
 
 INLINE INT32 scalable_lock_acquire(scalable_lock *lock)
 {
+#if USE_SCALABLE_LOCKS
 	INT32 myslot = (interlocked_increment(&lock->nextindex) - 1) & (WORK_MAX_THREADS - 1);
 	INT32 backoff = 1;
 
@@ -216,12 +225,20 @@ INLINE INT32 scalable_lock_acquire(scalable_lock *lock)
 	}
 	lock->slot[myslot].haslock = FALSE;
 	return myslot;
+#else
+	EnterCriticalSection(&lock->section);
+	return 0;
+#endif
 }
 
 
 INLINE void scalable_lock_release(scalable_lock *lock, INT32 myslot)
 {
+#if USE_SCALABLE_LOCKS
 	interlocked_exchange32(&lock->slot[(myslot + 1) & (WORK_MAX_THREADS - 1)].haslock, TRUE);
+#else
+	LeaveCriticalSection(&lock->section);
+#endif
 }
 
 
@@ -427,11 +444,12 @@ void osd_work_queue_free(osd_work_queue *queue)
 					(double)thread->waittime * 100.0 / (double)total);
 		}
 #endif
-
-		// free the list
-		free(queue->thread);
 	}
 
+	// free the list
+	if (queue->thread != NULL)
+		free(queue->thread);
+
 	// free all the events
 	if (queue->doneevent != NULL)
 		CloseHandle(queue->doneevent);
@@ -474,7 +492,7 @@ void osd_work_queue_free(osd_work_queue *queue)
 
 osd_work_item *osd_work_item_queue_multiple(osd_work_queue *queue, osd_work_callback callback, INT32 numitems, void *parambase, INT32 paramstep, UINT32 flags)
 {
-	osd_work_item *itemlist = NULL;
+	osd_work_item *itemlist = NULL, *lastitem = NULL;
 	osd_work_item **item_tailptr = &itemlist;
 	INT32 lockslot;
 	int itemnum;
@@ -510,6 +528,7 @@ osd_work_item *osd_work_item_queue_multiple(osd_work_queue *queue, osd_work_call
 		item->done = FALSE;
 
 		// advance to the next
+		lastitem = item;
 		*item_tailptr = item;
 		item_tailptr = &item->next;
 		parambase = (UINT8 *)parambase + paramstep;
@@ -553,7 +572,7 @@ osd_work_item *osd_work_item_queue_multiple(osd_work_queue *queue, osd_work_call
 		worker_thread_process(queue, &queue->thread[0]);
 
 	// only return the item if it won't get released automatically
-	return (flags & WORK_ITEM_FLAG_AUTO_RELEASE) ? NULL : *item_tailptr;
+	return (flags & WORK_ITEM_FLAG_AUTO_RELEASE) ? NULL : lastitem;
 }
 
 
@@ -574,7 +593,7 @@ int osd_work_item_wait(osd_work_item *item, osd_ticks_t timeout)
 		ResetEvent(item->event);
 
 	// if we don't have an event, we need to spin (shouldn't ever really happen)
-	if (item->event != NULL)
+	if (item->event == NULL)
 	{
 		osd_ticks_t stopspin = osd_ticks() + timeout;
 		while (!item->done && osd_ticks() < stopspin)
